/*
 * ATTENTION: An "eval-source-map" devtool has been used.
 * This devtool is not neither made for production nor for readable output files.
 * It uses "eval()" calls to create a separate source file with attached SourceMaps in the browser devtools.
 * If you are trying to read the output file, select a different devtool (https://webpack.js.org/configuration/devtool/)
 * or disable the default devtool with "devtool: false".
 * If you are looking for production-ready output files, see mode: "production" (https://webpack.js.org/configuration/mode/).
 */
(self["webpackChunkhome_assistant_frontend"] = self["webpackChunkhome_assistant_frontend"] || []).push([["src_components_ha-icon_ts"],{

/***/ "./build/mdi/iconMetadata.json":
/*!*************************************!*\
  !*** ./build/mdi/iconMetadata.json ***!
  \*************************************/
/*! default exports */
/*! export parts [provided] [no usage info] [missing usage info prevents renaming] */
/*!   export 0 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 1 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 10 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 11 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 12 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 13 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 14 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 15 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 16 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 17 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 18 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 19 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 2 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 20 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 21 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 22 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 23 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 24 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 25 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 26 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 27 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 28 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 29 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 3 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 30 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 31 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 32 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 33 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 34 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 35 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 36 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 4 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 5 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 6 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 7 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 8 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   export 9 [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export file [provided] [no usage info] [missing usage info prevents renaming] */
/*!     export start [provided] [no usage info] [missing usage info prevents renaming] */
/*!     other exports [not provided] [no usage info] */
/*!   other exports [not provided] [no usage info] */
/*! export version [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: module */
/***/ ((module) => {

"use strict";
module.exports = JSON.parse("{\"version\":\"5.6.55\",\"parts\":[{\"file\":\"8f7750e029a6ef516f402ba2a18f770d535730f8\"},{\"start\":\"airp\",\"file\":\"13eee1e899d282159a04ba352d1ed4feb53e5f28\"},{\"start\":\"application-\",\"file\":\"5e09d9e60767da8826acfa939fc7a192c3017fdc\"},{\"start\":\"badge-account-horizontal-\",\"file\":\"091c6419ea09577a2cd23f58a2d444da902922bd\"},{\"start\":\"beer\",\"file\":\"c75f23577c68209caf2ee6d8abfa1e47f9fdd346\"},{\"start\":\"border-r\",\"file\":\"4a163a7cb39874ec5e31fef5a16822d472ea9d75\"},{\"start\":\"camera-\",\"file\":\"75c6554ce6c38218565310f31e330d29e610be14\"},{\"start\":\"cart-arrow-r\",\"file\":\"526db7af6ed90ba5e29e520e8420886a387c6ec1\"},{\"start\":\"cir\",\"file\":\"10f097705a1a3a9e15a4d5304588fcbf49e9cb1b\"},{\"start\":\"cog-o\",\"file\":\"14893756d8a87eee5c25262d8d2cce84e343e9f7\"},{\"start\":\"cp\",\"file\":\"43533c5a4e97f2dad8a4430e8fb2e998b77180e8\"},{\"start\":\"desktop-t\",\"file\":\"d7593366adef7e12c6f7beb0125ae03250a623c1\"},{\"start\":\"earth-box-p\",\"file\":\"897116495125bd02c7b5c74768fca0e4ef075556\"},{\"start\":\"eve\",\"file\":\"25914e849cb9677609c2e17666c7dc8787276fec\"},{\"start\":\"file-download-\",\"file\":\"393c2a9700198fd5d6ee360fec426dca07b824c1\"},{\"start\":\"flask-o\",\"file\":\"21c916bdafa6c4bc802eb2f067d52eb43d46d63c\"},{\"start\":\"format-letter-e\",\"file\":\"71adf4da7cf052ce2f72aafb39b5038640ae7eff\"},{\"start\":\"gh\",\"file\":\"b52d69de085a5028ae417fc032b8fa962b929b2c\"},{\"start\":\"hand-wash-\",\"file\":\"0fbcf56d8b33b97ba907a4aebeb8399bd200c71d\"},{\"start\":\"horizontal-rotate-co\",\"file\":\"aaf1ddc91d8dc645b638d1cead1c3928be0d4ae2\"},{\"start\":\"ju\",\"file\":\"5792fc856cff1ad97388d397c924b547dc5773ba\"},{\"start\":\"las\",\"file\":\"8a4e57c53b91f036efd825ee3924ccb927394462\"},{\"start\":\"map-marker-m\",\"file\":\"faf56ee66495fe62e00e421005abe5f362a15d5e\"},{\"start\":\"microsoft-xbox-controller-m\",\"file\":\"cb9dda8c3ba589951ab20cae22899eee3f75aaa2\"},{\"start\":\"noo\",\"file\":\"8d79d67bba34d4662998ebd3221a6f49f72d0cbd\"},{\"start\":\"pan-t\",\"file\":\"5ff2e52aedaa0c398ec4a745219c00ac5b56c564\"},{\"start\":\"pig\",\"file\":\"996e32533891ce2fcc2ed79a3fc3953057539e7c\"},{\"start\":\"qq\",\"file\":\"8a9a74c567094a8e0c21288a4eaa28bdd315a3ac\"},{\"start\":\"roller-skate-\",\"file\":\"855d84169183b3d513e65652ebd4619fbdacbfb0\"},{\"start\":\"set-c\",\"file\":\"51836c70496c6d380859ef075c18363fac468891\"},{\"start\":\"skype-\",\"file\":\"a64604d28b67e989f14df4cdd5fa33c18babb0e6\"},{\"start\":\"spotlight-\",\"file\":\"fa89d8e056827e5e5a45002258155fdf636dba89\"},{\"start\":\"table-ro\",\"file\":\"820c478bf9e136168cc68b98852a5ee1c6f57975\"},{\"start\":\"to\",\"file\":\"d7a1decb8941bb6b39a53b22cf5d660c89acc059\"},{\"start\":\"upload-network-\",\"file\":\"9bb9aae327973cf8230a9817e1e48eb6767d0601\"},{\"start\":\"water-well-\",\"file\":\"b107c580b29fb39e4bfad9c85db944ac4d3297b4\"},{\"start\":\"wrap-\",\"file\":\"0ec45795e55edbd7f9644bd3fa1943780d99a94d\"}]}");

/***/ }),

/***/ "./src/components/ha-icon.ts":
/*!***********************************!*\
  !*** ./src/components/ha-icon.ts ***!
  \***********************************/
/*! namespace exports */
/*! export HaIcon [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HaIcon\": () => /* binding */ HaIcon\n/* harmony export */ });\n/* harmony import */ var _polymer_iron_icon_iron_icon__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/iron-icon/iron-icon */ \"./node_modules/@polymer/iron-icon/iron-icon.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _ha_svg_icon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ha-svg-icon */ \"./src/components/ha-svg-icon.ts\");\n/* harmony import */ var _data_custom_iconsets__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../data/custom_iconsets */ \"./src/data/custom_iconsets.ts\");\n/* harmony import */ var _data_iconsets__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../data/iconsets */ \"./src/data/iconsets.ts\");\n/* harmony import */ var _common_util_debounce__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common/util/debounce */ \"./src/common/util/debounce.ts\");\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\n\n\n\n\n\nconst mdiDeprecatedIcons = {};\nconst chunks = {};\n(0,_data_iconsets__WEBPACK_IMPORTED_MODULE_4__.checkCacheVersion)();\nconst debouncedWriteCache = (0,_common_util_debounce__WEBPACK_IMPORTED_MODULE_5__.debounce)(() => (0,_data_iconsets__WEBPACK_IMPORTED_MODULE_4__.writeCache)(chunks), 2000);\nconst cachedIcons = {};\nlet HaIcon = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.customElement)(\"ha-icon\")], function (_initialize, _LitElement) {\n  class HaIcon extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaIcon,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)()],\n      key: \"icon\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_path\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_viewBox\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_legacy\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"updated\",\n      value: function updated(changedProps) {\n        if (changedProps.has(\"icon\")) {\n          this._path = undefined;\n          this._viewBox = undefined;\n\n          this._loadIcon();\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        if (!this.icon) {\n          return lit_element__WEBPACK_IMPORTED_MODULE_1__.html``;\n        }\n\n        if (this._legacy) {\n          return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`<iron-icon .icon=${this.icon}></iron-icon>`;\n        }\n\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`<ha-svg-icon\n      .path=${this._path}\n      .viewBox=${this._viewBox}\n    ></ha-svg-icon>`;\n      }\n    }, {\n      kind: \"method\",\n      key: \"_loadIcon\",\n      value: async function _loadIcon() {\n        if (!this.icon) {\n          return;\n        }\n\n        const [iconPrefix, origIconName] = this.icon.split(\":\", 2);\n        let iconName = origIconName;\n\n        if (!iconPrefix || !iconName) {\n          return;\n        }\n\n        if (!_data_iconsets__WEBPACK_IMPORTED_MODULE_4__.MDI_PREFIXES.includes(iconPrefix)) {\n          if (iconPrefix in _data_custom_iconsets__WEBPACK_IMPORTED_MODULE_3__.customIconsets) {\n            const customIconset = _data_custom_iconsets__WEBPACK_IMPORTED_MODULE_3__.customIconsets[iconPrefix];\n\n            if (customIconset) {\n              this._setCustomPath(customIconset(iconName));\n            }\n\n            return;\n          }\n\n          this._legacy = true;\n          return;\n        }\n\n        this._legacy = false;\n\n        if (iconName in mdiDeprecatedIcons) {\n          const deprecatedIcon = mdiDeprecatedIcons[iconName];\n          let message;\n\n          if (deprecatedIcon.newName) {\n            message = `Icon ${iconPrefix}:${iconName} was renamed to ${iconPrefix}:${deprecatedIcon.newName}, please change your config, it will be removed in version ${deprecatedIcon.removeIn}.`;\n            iconName = deprecatedIcon.newName;\n          } else {\n            message = `Icon ${iconPrefix}:${iconName} was removed from MDI, please replace this icon with an other icon in your config, it will be removed in version ${deprecatedIcon.removeIn}.`;\n          } // eslint-disable-next-line no-console\n\n\n          console.warn(message);\n          (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_6__.fireEvent)(this, \"write_log\", {\n            level: \"warning\",\n            message\n          });\n        }\n\n        if (iconName in cachedIcons) {\n          this._path = cachedIcons[iconName];\n          return;\n        }\n\n        let databaseIcon;\n\n        try {\n          databaseIcon = await (0,_data_iconsets__WEBPACK_IMPORTED_MODULE_4__.getIcon)(iconName);\n        } catch (_err) {\n          // Firefox in private mode doesn't support IDB\n          databaseIcon = undefined;\n        }\n\n        if (databaseIcon) {\n          this._path = databaseIcon;\n          cachedIcons[iconName] = databaseIcon;\n          return;\n        }\n\n        const chunk = (0,_data_iconsets__WEBPACK_IMPORTED_MODULE_4__.findIconChunk)(iconName);\n\n        if (chunk in chunks) {\n          this._setPath(chunks[chunk], iconName);\n\n          return;\n        }\n\n        const iconPromise = fetch(`/static/mdi/${chunk}.json`).then(response => response.json());\n        chunks[chunk] = iconPromise;\n\n        this._setPath(iconPromise, iconName);\n\n        debouncedWriteCache();\n      }\n    }, {\n      kind: \"method\",\n      key: \"_setCustomPath\",\n      value: async function _setCustomPath(promise) {\n        const icon = await promise;\n        this._path = icon.path;\n        this._viewBox = icon.viewBox;\n      }\n    }, {\n      kind: \"method\",\n      key: \"_setPath\",\n      value: async function _setPath(promise, iconName) {\n        const iconPack = await promise;\n        this._path = iconPack[iconName];\n        cachedIcons[iconName] = iconPack[iconName];\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.css`\n      :host {\n        fill: currentcolor;\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/components/ha-icon.ts\n");

/***/ }),

/***/ "./src/data/custom_iconsets.ts":
/*!*************************************!*\
  !*** ./src/data/custom_iconsets.ts ***!
  \*************************************/
/*! namespace exports */
/*! export customIconsets [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"customIconsets\": () => /* binding */ customIconsets\n/* harmony export */ });\nconst customIconsetsWindow = window;\n\nif (!(\"customIconsets\" in customIconsetsWindow)) {\n  customIconsetsWindow.customIconsets = {};\n}\n\nconst customIconsets = customIconsetsWindow.customIconsets;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS9jdXN0b21faWNvbnNldHMudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9kYXRhL2N1c3RvbV9pY29uc2V0cy50cz8zNTM4Il0sInNvdXJjZXNDb250ZW50IjpbImV4cG9ydCBpbnRlcmZhY2UgQ3VzdG9tSWNvbiB7XG4gIHBhdGg6IHN0cmluZztcbiAgdmlld0JveD86IHN0cmluZztcbn1cblxuZXhwb3J0IGludGVyZmFjZSBDdXN0b21JY29uc2V0c1dpbmRvdyB7XG4gIGN1c3RvbUljb25zZXRzPzogeyBba2V5OiBzdHJpbmddOiAobmFtZTogc3RyaW5nKSA9PiBQcm9taXNlPEN1c3RvbUljb24+IH07XG59XG5cbmNvbnN0IGN1c3RvbUljb25zZXRzV2luZG93ID0gd2luZG93IGFzIEN1c3RvbUljb25zZXRzV2luZG93O1xuXG5pZiAoIShcImN1c3RvbUljb25zZXRzXCIgaW4gY3VzdG9tSWNvbnNldHNXaW5kb3cpKSB7XG4gIGN1c3RvbUljb25zZXRzV2luZG93LmN1c3RvbUljb25zZXRzID0ge307XG59XG5cbmV4cG9ydCBjb25zdCBjdXN0b21JY29uc2V0cyA9IGN1c3RvbUljb25zZXRzV2luZG93LmN1c3RvbUljb25zZXRzITtcbiJdLCJtYXBwaW5ncyI6Ijs7OztBQVNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/data/custom_iconsets.ts\n");

/***/ }),

/***/ "./src/data/iconsets.ts":
/*!******************************!*\
  !*** ./src/data/iconsets.ts ***!
  \******************************/
/*! namespace exports */
/*! export MDI_PREFIXES [provided] [no usage info] [missing usage info prevents renaming] */
/*! export checkCacheVersion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export findIconChunk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getIcon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export iconStore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export writeCache [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"iconStore\": () => /* binding */ iconStore,\n/* harmony export */   \"MDI_PREFIXES\": () => /* binding */ MDI_PREFIXES,\n/* harmony export */   \"getIcon\": () => /* binding */ getIcon,\n/* harmony export */   \"findIconChunk\": () => /* binding */ findIconChunk,\n/* harmony export */   \"writeCache\": () => /* binding */ writeCache,\n/* harmony export */   \"checkCacheVersion\": () => /* binding */ checkCacheVersion\n/* harmony export */ });\n/* harmony import */ var _resources_icon_metadata__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../resources/icon-metadata */ \"./src/resources/icon-metadata.ts\");\n/* harmony import */ var idb_keyval__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! idb-keyval */ \"./node_modules/idb-keyval/dist/idb-keyval.mjs\");\n\n\nconst iconStore = new idb_keyval__WEBPACK_IMPORTED_MODULE_1__.Store(\"hass-icon-db\", \"mdi-icon-store\");\nconst MDI_PREFIXES = [\"mdi\", \"hass\", \"hassio\", \"hademo\"];\nlet toRead = []; // Queue up as many icon fetches in 1 transaction\n\nconst getIcon = iconName => new Promise((resolve, reject) => {\n  toRead.push([iconName, resolve, reject]);\n\n  if (toRead.length > 1) {\n    return;\n  }\n\n  const results = [];\n\n  iconStore._withIDBStore(\"readonly\", store => {\n    for (const [iconName_, resolve_] of toRead) {\n      results.push([resolve_, store.get(iconName_)]);\n    }\n\n    toRead = [];\n  }).then(() => {\n    for (const [resolve_, request] of results) {\n      resolve_(request.result);\n    }\n  }).catch(() => {\n    // Firefox in private mode doesn't support IDB\n    for (const [,, reject_] of toRead) {\n      reject_();\n    }\n\n    toRead = [];\n  });\n});\nconst findIconChunk = icon => {\n  let lastChunk;\n\n  for (const chunk of _resources_icon_metadata__WEBPACK_IMPORTED_MODULE_0__.iconMetadata.parts) {\n    if (chunk.start !== undefined && icon < chunk.start) {\n      break;\n    }\n\n    lastChunk = chunk;\n  }\n\n  return lastChunk.file;\n};\nconst writeCache = async chunks => {\n  const keys = Object.keys(chunks);\n  const iconsSets = await Promise.all(Object.values(chunks)); // We do a batch opening the store just once, for (considerable) performance\n\n  iconStore._withIDBStore(\"readwrite\", store => {\n    iconsSets.forEach((icons, idx) => {\n      Object.entries(icons).forEach(([name, path]) => {\n        store.put(path, name);\n      });\n      delete chunks[keys[idx]];\n    });\n  });\n};\nconst checkCacheVersion = () => {\n  (0,idb_keyval__WEBPACK_IMPORTED_MODULE_1__.get)(\"_version\", iconStore).then(version => {\n    if (!version) {\n      (0,idb_keyval__WEBPACK_IMPORTED_MODULE_1__.set)(\"_version\", _resources_icon_metadata__WEBPACK_IMPORTED_MODULE_0__.iconMetadata.version, iconStore);\n    } else if (version !== _resources_icon_metadata__WEBPACK_IMPORTED_MODULE_0__.iconMetadata.version) {\n      (0,idb_keyval__WEBPACK_IMPORTED_MODULE_1__.clear)(iconStore).then(() => (0,idb_keyval__WEBPACK_IMPORTED_MODULE_1__.set)(\"_version\", _resources_icon_metadata__WEBPACK_IMPORTED_MODULE_0__.iconMetadata.version, iconStore));\n    }\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS9pY29uc2V0cy50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2RhdGEvaWNvbnNldHMudHM/MjE5OCJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBpY29uTWV0YWRhdGEgfSBmcm9tIFwiLi4vcmVzb3VyY2VzL2ljb24tbWV0YWRhdGFcIjtcbmltcG9ydCB7IEljb25NZXRhIH0gZnJvbSBcIi4uL3R5cGVzXCI7XG5pbXBvcnQgeyBnZXQsIHNldCwgY2xlYXIsIFN0b3JlIH0gZnJvbSBcImlkYi1rZXl2YWxcIjtcblxuZXhwb3J0IGludGVyZmFjZSBJY29ucyB7XG4gIFtrZXk6IHN0cmluZ106IHN0cmluZztcbn1cblxuZXhwb3J0IGludGVyZmFjZSBDaHVua3Mge1xuICBba2V5OiBzdHJpbmddOiBQcm9taXNlPEljb25zPjtcbn1cblxuZXhwb3J0IGNvbnN0IGljb25TdG9yZSA9IG5ldyBTdG9yZShcImhhc3MtaWNvbi1kYlwiLCBcIm1kaS1pY29uLXN0b3JlXCIpO1xuXG5leHBvcnQgY29uc3QgTURJX1BSRUZJWEVTID0gW1wibWRpXCIsIFwiaGFzc1wiLCBcImhhc3Npb1wiLCBcImhhZGVtb1wiXTtcblxubGV0IHRvUmVhZDogQXJyYXk8W3N0cmluZywgKHN0cmluZykgPT4gdm9pZCwgKCkgPT4gdm9pZF0+ID0gW107XG5cbi8vIFF1ZXVlIHVwIGFzIG1hbnkgaWNvbiBmZXRjaGVzIGluIDEgdHJhbnNhY3Rpb25cbmV4cG9ydCBjb25zdCBnZXRJY29uID0gKGljb25OYW1lOiBzdHJpbmcpID0+XG4gIG5ldyBQcm9taXNlPHN0cmluZz4oKHJlc29sdmUsIHJlamVjdCkgPT4ge1xuICAgIHRvUmVhZC5wdXNoKFtpY29uTmFtZSwgcmVzb2x2ZSwgcmVqZWN0XSk7XG5cbiAgICBpZiAodG9SZWFkLmxlbmd0aCA+IDEpIHtcbiAgICAgIHJldHVybjtcbiAgICB9XG5cbiAgICBjb25zdCByZXN1bHRzOiBBcnJheTxbKHN0cmluZykgPT4gdm9pZCwgSURCUmVxdWVzdF0+ID0gW107XG5cbiAgICBpY29uU3RvcmVcbiAgICAgIC5fd2l0aElEQlN0b3JlKFwicmVhZG9ubHlcIiwgKHN0b3JlKSA9PiB7XG4gICAgICAgIGZvciAoY29uc3QgW2ljb25OYW1lXywgcmVzb2x2ZV9dIG9mIHRvUmVhZCkge1xuICAgICAgICAgIHJlc3VsdHMucHVzaChbcmVzb2x2ZV8sIHN0b3JlLmdldChpY29uTmFtZV8pXSk7XG4gICAgICAgIH1cbiAgICAgICAgdG9SZWFkID0gW107XG4gICAgICB9KVxuICAgICAgLnRoZW4oKCkgPT4ge1xuICAgICAgICBmb3IgKGNvbnN0IFtyZXNvbHZlXywgcmVxdWVzdF0gb2YgcmVzdWx0cykge1xuICAgICAgICAgIHJlc29sdmVfKHJlcXVlc3QucmVzdWx0KTtcbiAgICAgICAgfVxuICAgICAgfSlcbiAgICAgIC5jYXRjaCgoKSA9PiB7XG4gICAgICAgIC8vIEZpcmVmb3ggaW4gcHJpdmF0ZSBtb2RlIGRvZXNuJ3Qgc3VwcG9ydCBJREJcbiAgICAgICAgZm9yIChjb25zdCBbLCAsIHJlamVjdF9dIG9mIHRvUmVhZCkge1xuICAgICAgICAgIHJlamVjdF8oKTtcbiAgICAgICAgfVxuICAgICAgICB0b1JlYWQgPSBbXTtcbiAgICAgIH0pO1xuICB9KTtcblxuZXhwb3J0IGNvbnN0IGZpbmRJY29uQ2h1bmsgPSAoaWNvbik6IHN0cmluZyA9PiB7XG4gIGxldCBsYXN0Q2h1bms6IEljb25NZXRhO1xuICBmb3IgKGNvbnN0IGNodW5rIG9mIGljb25NZXRhZGF0YS5wYXJ0cykge1xuICAgIGlmIChjaHVuay5zdGFydCAhPT0gdW5kZWZpbmVkICYmIGljb24gPCBjaHVuay5zdGFydCkge1xuICAgICAgYnJlYWs7XG4gICAgfVxuICAgIGxhc3RDaHVuayA9IGNodW5rO1xuICB9XG4gIHJldHVybiBsYXN0Q2h1bmshLmZpbGU7XG59O1xuXG5leHBvcnQgY29uc3Qgd3JpdGVDYWNoZSA9IGFzeW5jIChjaHVua3M6IENodW5rcykgPT4ge1xuICBjb25zdCBrZXlzID0gT2JqZWN0LmtleXMoY2h1bmtzKTtcbiAgY29uc3QgaWNvbnNTZXRzOiBJY29uc1tdID0gYXdhaXQgUHJvbWlzZS5hbGwoT2JqZWN0LnZhbHVlcyhjaHVua3MpKTtcbiAgLy8gV2UgZG8gYSBiYXRjaCBvcGVuaW5nIHRoZSBzdG9yZSBqdXN0IG9uY2UsIGZvciAoY29uc2lkZXJhYmxlKSBwZXJmb3JtYW5jZVxuICBpY29uU3RvcmUuX3dpdGhJREJTdG9yZShcInJlYWR3cml0ZVwiLCAoc3RvcmUpID0+IHtcbiAgICBpY29uc1NldHMuZm9yRWFjaCgoaWNvbnMsIGlkeCkgPT4ge1xuICAgICAgT2JqZWN0LmVudHJpZXMoaWNvbnMpLmZvckVhY2goKFtuYW1lLCBwYXRoXSkgPT4ge1xuICAgICAgICBzdG9yZS5wdXQocGF0aCwgbmFtZSk7XG4gICAgICB9KTtcbiAgICAgIGRlbGV0ZSBjaHVua3Nba2V5c1tpZHhdXTtcbiAgICB9KTtcbiAgfSk7XG59O1xuXG5leHBvcnQgY29uc3QgY2hlY2tDYWNoZVZlcnNpb24gPSAoKSA9PiB7XG4gIGdldChcIl92ZXJzaW9uXCIsIGljb25TdG9yZSkudGhlbigodmVyc2lvbikgPT4ge1xuICAgIGlmICghdmVyc2lvbikge1xuICAgICAgc2V0KFwiX3ZlcnNpb25cIiwgaWNvbk1ldGFkYXRhLnZlcnNpb24sIGljb25TdG9yZSk7XG4gICAgfSBlbHNlIGlmICh2ZXJzaW9uICE9PSBpY29uTWV0YWRhdGEudmVyc2lvbikge1xuICAgICAgY2xlYXIoaWNvblN0b3JlKS50aGVuKCgpID0+XG4gICAgICAgIHNldChcIl92ZXJzaW9uXCIsIGljb25NZXRhZGF0YS52ZXJzaW9uLCBpY29uU3RvcmUpXG4gICAgICApO1xuICAgIH1cbiAgfSk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7Ozs7OztBQUFBO0FBRUE7QUFVQTtBQUVBO0FBRUE7QUFDQTtBQUVBO0FBRUE7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBRUE7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBRUE7QUFDQTtBQUNBO0FBQ0E7QUFFQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBRUE7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFFQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUVBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUdBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/data/iconsets.ts\n");

/***/ }),

/***/ "./src/resources/icon-metadata.ts":
/*!****************************************!*\
  !*** ./src/resources/icon-metadata.ts ***!
  \****************************************/
/*! namespace exports */
/*! export iconMetadata [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"iconMetadata\": () => /* binding */ iconMetadata\n/* harmony export */ });\n/* harmony import */ var _build_mdi_iconMetadata_json__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../build/mdi/iconMetadata.json */ \"./build/mdi/iconMetadata.json\");\n\nconst iconMetadata = _build_mdi_iconMetadata_json__WEBPACK_IMPORTED_MODULE_0__;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvcmVzb3VyY2VzL2ljb24tbWV0YWRhdGEudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9yZXNvdXJjZXMvaWNvbi1tZXRhZGF0YS50cz9hOThjIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCAqIGFzIGljb25NZXRhZGF0YV8gZnJvbSBcIi4uLy4uL2J1aWxkL21kaS9pY29uTWV0YWRhdGEuanNvblwiO1xuaW1wb3J0IHsgSWNvbk1ldGFGaWxlIH0gZnJvbSBcIi4uL3R5cGVzLmpzXCI7XG5cbmV4cG9ydCBjb25zdCBpY29uTWV0YWRhdGEgPSAoaWNvbk1ldGFkYXRhXyBhcyBhbnkpLmRlZmF1bHQgYXMgSWNvbk1ldGFGaWxlO1xuIl0sIm1hcHBpbmdzIjoiOzs7OztBQUFBO0FBR0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/resources/icon-metadata.ts\n");

/***/ })

}]);