/*
 * ATTENTION: An "eval-source-map" devtool has been used.
 * This devtool is not neither made for production nor for readable output files.
 * It uses "eval()" calls to create a separate source file with attached SourceMaps in the browser devtools.
 * If you are trying to read the output file, select a different devtool (https://webpack.js.org/configuration/devtool/)
 * or disable the default devtool with "devtool: false".
 * If you are looking for production-ready output files, see mode: "production" (https://webpack.js.org/configuration/mode/).
 */
/******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ "./node_modules/@mdi/js/mdi.js":
/*!*************************************!*\
  !*** ./node_modules/@mdi/js/mdi.js ***!
  \*************************************/
/*! namespace exports */
/*! export mdiAbTesting [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAbjadArabic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAbjadHebrew [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAbugidaDevanagari [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAbugidaThai [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPoint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointNetworkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccessPointRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountArrowLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountArrowRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCancelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountChild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountChildCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountChildOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountConvert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountConvertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountCowboyHat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountDetails [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountDetailsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountGroupOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountHardHat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountKeyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultiplePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultiplePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMultipleRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountMusicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountReactivate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountReactivateOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSupervisor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSupervisorCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSupervisorCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSupervisorOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountSwitchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTieOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTieVoice [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTieVoiceOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTieVoiceOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountTieVoiceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAccountVoice [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAdjust [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAdobe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAdobeAcrobat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirConditioner [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirFilter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirHorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirHumidifier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirHumidifierOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirPurifier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirbag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirballoon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirballoonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirplane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirplaneLanding [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirplaneOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirplaneTakeoff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAirport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmBell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmLightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmNote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmNoteOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmPanel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmPanelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlarmSnooze [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlbum [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertCircleCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertCircleCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertDecagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertDecagramOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertOctagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertOctagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertOctagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertOctagramOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertRhombus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlertRhombusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlien [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlienOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignHorizontalCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignHorizontalLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignHorizontalRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignVerticalBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignVerticalCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlignVerticalTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAllInclusive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAllergy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlpha [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaA [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaABox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaABoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaACircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaACircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaB [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaBBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaBBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaBCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaBCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaC [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaCBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaCBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaCCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaCCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaD [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaDBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaDBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaDCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaDCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaE [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaEBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaEBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaECircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaECircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaF [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaFBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaFBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaFCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaFCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaG [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaGBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaGBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaGCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaGCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaH [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaHBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaHBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaHCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaHCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaI [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaIBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaIBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaICircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaICircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaJ [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaJBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaJBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaJCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaJCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaK [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaKBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaKBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaKCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaKCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaLBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaLBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaLCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaLCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaM [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaMBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaMBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaMCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaMCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaN [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaNBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaNBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaNCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaNCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaO [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaOBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaOBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaOCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaOCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaP [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaPBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaPBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaPCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaPCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaQ [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaQBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaQBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaQCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaQCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaR [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaRBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaRBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaRCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaRCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaS [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaSBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaSBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaSCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaSCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaT [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaTBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaTBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaTCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaTCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaU [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaUBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaUBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaUCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaUCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaV [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaVBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaVBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaVCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaVCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaW [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaWBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaWBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaWCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaWCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaX [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaXBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaXBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaXCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaXCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaY [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaYBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaYBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaYCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaYCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaZ [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaZBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaZBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaZCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphaZCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetAurebesh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetCyrillic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetGreek [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetLatin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetPiqad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetTengwar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabetical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabeticalOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabeticalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAlphabeticalVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAltimeter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmazon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmazonAlexa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmbulance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmmunition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmpersand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmplifier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAmplifierOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnchor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAndroid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAndroidAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAndroidDebugBridge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAndroidMessages [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAndroidStudio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAngleAcute [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAngleObtuse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAngleRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAngular [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAngularjs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnimation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnimationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnimationPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnimationPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnsible [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAntenna [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAnvil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApacheKafka [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApiOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleAirplay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleFinder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleIcloud [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleIos [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleKeyboardCaps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleKeyboardCommand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleKeyboardControl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleKeyboardOption [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleKeyboardShift [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppleSafari [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApplication [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApplicationCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApplicationExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApplicationImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApplicationSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApproximatelyEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApproximatelyEqualBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiApps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAppsBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveArrowDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveArrowUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArchiveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArmFlex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArmFlexOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrangeBringForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrangeBringToFront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrangeSendBackward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrangeSendToBack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomLeftBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomLeftThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomLeftThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomRightBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomRightThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowBottomRightThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowCollapseVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDecision [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDecisionAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDecisionAutoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDecisionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldHexagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownDropCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownDropCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowDownThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowExpandVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowHorizontalLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldHexagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftDropCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftDropCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftRightBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftRightBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowLeftThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldHexagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightDropCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightDropCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowRightThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowSplitHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowSplitVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeftBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeftBottomRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeftBottomRightBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeftThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopLeftThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRightBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRightBottomLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRightBottomLeftBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRightThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowTopRightThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldHexagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpDownBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpDownBoldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpDropCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpDropCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowUpThinCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArrowVerticalLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiArtstation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAspectRatio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAssistant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAsterisk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAtlassian [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAtm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAtom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAtomVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAttachment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAudioVideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAudioVideoOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAugmentedReality [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAutoDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAutoFix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAutoUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAutorenew [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAvTimer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAws [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxis [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisArrowInfo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisArrowLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisXArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisXArrowLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisXRotateClockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisXRotateCounterclockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisXYArrowLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisYArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisYArrowLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisYRotateClockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisYRotateCounterclockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisZArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisZArrowLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisZRotateClockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiAxisZRotateCounterclockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyBottle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyBottleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyBuggy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyCarriage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyCarriageOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyFace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBabyFaceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackburger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackspace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackspaceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackspaceReverse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackspaceReverseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBackupRestore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBacteria [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBacteriaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccountAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccountAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccountHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccountHorizontalOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadgeAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBadminton [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagCarryOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagCarryOnCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagCarryOnOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagChecked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagPersonal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagPersonalOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagPersonalOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagPersonalOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagSuitcase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagSuitcaseOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagSuitcaseOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBagSuitcaseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaguette [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBalloon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBallot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBallotOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBallotRecount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBallotRecountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBandage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBandcamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankTransfer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankTransferIn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBankTransferOut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarcode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarcodeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarcodeScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarley [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarleyOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBarrel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaseball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaseballBat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaseballDiamond [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBaseballDiamondOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketFill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketUnfill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketballHoop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBasketballHoopOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery10Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery20 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery20Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery30 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery30Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery40 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery40Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery50 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery50Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery60 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery60Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery70 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery70Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery80 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery80Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery90 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattery90Bluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryAlertBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryAlertVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryAlertVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryBluetoothVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging100 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging20 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging30 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging40 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging50 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging60 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging70 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging80 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryCharging90 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless20 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless30 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless40 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless50 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless60 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless70 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless80 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWireless90 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWirelessAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryChargingWirelessOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryHeartVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryNegative [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryPositive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryUnknown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBatteryUnknownBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBattlenet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeach [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeakerRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedDouble [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedDoubleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedKing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedKingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedQueen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedQueenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedSingle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBedSingleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBee [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeeFlower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeehiveOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeehiveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeekeeper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCancelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellRing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellRingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellSleep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBellSleepOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBeta [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBetamax [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBiathlon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBicycle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBicycleBasket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBicycleElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBicyclePennyFarthing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBike [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBikeFast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBillboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBilliards [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBilliardsRack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBinoculars [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBiohazard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBird [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBitbucket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBitcoin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlackMesa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlender [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlenderSoftware [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlinds [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlindsOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlockHelper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlogger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBloodBag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetoothAudio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetoothConnect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetoothOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetoothSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBluetoothTransfer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlur [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlurLinear [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlurOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBlurRadial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBolnisiCross [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBolt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBomb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBombOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookAlphabet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookCross [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookInformationVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMinusMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMinusMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpenBlankVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpenPageVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpenPageVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOpenVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookPlusMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookPlusMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookRemoveMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookRemoveMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookVariantMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkMusicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookmarkRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBookshelf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomGateUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoombox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoomerang [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBootstrap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderAllVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderBottomVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderColor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderInside [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderLeftVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderNone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderNoneVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderOutside [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderRightVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderTopVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBorderVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleSoda [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleSodaClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleSodaClassicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleSodaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonicPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonicPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonicSkull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleTonicSkullOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleWine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBottleWineOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowTie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowlMix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowlMixOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowlOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBowling [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoxCutter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoxCutterOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoxShadow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBoxingGlove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBraille [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBreadSlice [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBreadSliceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBridge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseDownloadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcasePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcasePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseUploadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBriefcaseVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightness7 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightnessAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrightnessPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBroom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBrush [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBucket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBucketOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBuddhism [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBuffer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBuffet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBugCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBugCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBugOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBugle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBulldozer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBullet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBulletinBoard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBullhorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBullhornOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBullseye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBullseyeArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBulma [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBunkBed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBunkBedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusArticulatedEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusArticulatedFront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusDoubleDecker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusSchool [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusSide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusStop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusStopCovered [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiBusStopUncovered [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiButterfly [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiButterflyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCableData [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCached [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCactus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCakeLayered [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCakeVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalculator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalculatorVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalculatorVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarBlank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarBlankMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarBlankOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarCursor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMonth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMonthOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMultipleCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarMultiselect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRange [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRangeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRefreshOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarToday [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarWeek [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarWeekBegin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarWeekend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCalendarWeekendOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCallMade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCallMerge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCallMissed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCallReceived [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCallSplit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCamcorder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCamcorderOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCamera [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraBurst [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraControl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraEnhance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraEnhanceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraFlip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraFlipOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraFront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraFrontVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraGopro [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraIris [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraMeteringCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraMeteringMatrix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraMeteringPartial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraMeteringSpot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraPartyMode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraRear [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraRearVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraRetake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraRetakeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraSwitchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraTimer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCameraWirelessOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCampfire [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCandle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCandycane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCannabis [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCapsLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCar2Plus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCar3Plus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBattery [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBrakeAbs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBrakeAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBrakeHold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBrakeParking [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarBrakeRetarder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarChildSeat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarClutch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarConnected [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarConvertible [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarCoolantLevel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarCruiseControl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarDefrostFront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarDefrostRear [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarDoor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarDoorLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarElectricOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarEmergency [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarEsp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarEstate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarHatchback [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarInfo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarLiftedPickup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarLightDimmed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarLightFog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarLightHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarLimousine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarParkingLights [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarPickup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSeat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSeatCooler [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSeatHeater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarShiftPattern [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarSports [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarTireAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarTractionControl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarTurbocharger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarWash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarWindshield [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarWindshieldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarabiner [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCaravan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountDetails [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountDetailsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountDetailsStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountDetailsStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountMail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountMailOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountPhone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardAccountPhoneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulleted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulletedOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulletedOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulletedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulletedSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardBulletedSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCards [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsClub [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsDiamond [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsDiamondOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsPlayingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsSpade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCardsVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCarrot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCartVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCaseSensitiveAlt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCash100 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashRefund [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashRegister [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashUsd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCashUsdOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCassette [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCastAudio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCastConnected [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCastEducation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCastOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCastle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCctv [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCeilingLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneAndroid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneBasic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneCharging [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneDock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneErase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneInformation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneIphone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneLink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneLinkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneMessage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneMessageOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneNfc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneNfcOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphonePlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneScreenshot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneSound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCellphoneWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCelticCross [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCentos [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCertificate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCertificateOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChairRolling [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChairSchool [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCharity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartArc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartAreaspline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartAreasplineVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBarStacked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBellCurve [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBellCurveCumulative [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBoxPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartBubble [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartDonut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartDonutVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartGantt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartHistogram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartLine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartLineStacked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartLineVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartMultiline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartPie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartPpf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartSankey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartSankeyVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartScatterPlot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartScatterPlotHexbin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartTimeline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartTimelineVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartTimelineVariantShimmer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChartTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatProcessing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatProcessingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatSleep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChatSleepOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckDecagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckUnderline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckUnderlineCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckUnderlineCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckbook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlankCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlankCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlankOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlankOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxBlankOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxIntermediate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMarked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMarkedCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMarkedCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMarkedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleBlank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleBlankCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleBlankCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleBlankOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleMarked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleMarkedCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleMarkedCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckboxMultipleMarkedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckerboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckerboardMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckerboardPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheckerboardRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheese [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCheeseOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChefHat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChemicalWeapon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessBishop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessKing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessKnight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessPawn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessQueen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChessRook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDoubleDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDoubleLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDoubleRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDoubleUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDownBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDownBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDownCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronDownCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronLeftBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronLeftBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronLeftCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronLeftCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronRightBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronRightBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronRightCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronRightCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronTripleDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronTripleLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronTripleRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronTripleUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronUpBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronUpBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronUpCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChevronUpCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChiliHot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChiliMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChiliMild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChiliOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChristianity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChristianityOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiChurch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCigar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCigarOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleDouble [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleExpand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleHalfFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice7 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSlice8 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircleSmall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCircularSaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCityVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCityVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardArrowUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardCheckMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardCheckMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardFile [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardFileOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardFlow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardFlowOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardList [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardListOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlayMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlayMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPulse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardPulseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardTextMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardTextMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardTextPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClipboardTextPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClippy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockDigital [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockFast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockIn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockOut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockStart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeEight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeEightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeEleven [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeElevenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeFive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeFiveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeFour [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeFourOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeNine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeNineOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeOneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeSeven [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeSevenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeSix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeSixOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeThree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeThreeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTwelve [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTwelveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTwo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClockTimeTwoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseCircleMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseCircleMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseOctagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseOctagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloseThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClosedCaption [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClosedCaptionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloud [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudBraces [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudDownloadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudPrint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudPrintOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudTags [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCloudUploadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiClover [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoachLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoatRack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeArray [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeBraces [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeBracesBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeBrackets [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeGreaterThan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeGreaterThanOrEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeJson [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeLessThan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeLessThanOrEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeNotEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeNotEqualVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeParentheses [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeParenthesesBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeString [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeTags [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodeTagsCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCodepen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffee [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeMaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeToGo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffeeToGoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoffin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogClockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogCounterclockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogRefreshOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogTransfer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogTransferOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCogs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCollage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCollapseAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCollapseAllOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiColorHelper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiComma [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommaBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommaBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommaCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommaCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiComment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentArrowLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentArrowRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentBookmark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentBookmarkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentEyeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentFlash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentFlashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentProcessing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentProcessingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentQuote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentQuoteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentTextMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentTextMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCommentTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompareHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompareVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompassOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompassOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompassOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCompassRose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConcourseCi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConnection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConsole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConsoleLine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConsoleNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConsoleNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiConsolidate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContactlessPayment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContactlessPaymentCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContactlessPaymentCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContacts [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContactsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContainEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContainStart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentCopy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentCut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentDuplicate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentPaste [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveAllOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveMove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveMoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContentSaveSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContrast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContrastBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiContrastCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiControllerClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiControllerClassicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCookie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCoolantTemperature [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCopyright [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCordova [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCornOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCosineWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCounter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCpu32Bit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCpu64Bit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreativeCommons [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMarkerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardRefund [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardRefundOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardScanOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardWirelessOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardWirelessOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCreditCardWirelessOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCricket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCropFree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCropLandscape [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCropPortrait [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCropRotate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCropSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrosshairs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrosshairsGps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrosshairsOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrosshairsQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCryengine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCrystalBall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCube [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeSend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCubeUnfolded [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupWater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupboardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCupcake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurling [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyBdt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyBrl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyBtc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyCny [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyEth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyEur [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyEurOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyGbp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyIls [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyInr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyJpy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyKrw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyKzt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyMnt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyNgn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyPhp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyRial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyRub [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencySign [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyTry [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyTwd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyUsd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyUsdCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyUsdCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrencyUsdOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrentAc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCurrentDc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefault [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefaultClick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefaultClickOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefaultGesture [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefaultGestureOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorDefaultOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorMove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorPointer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiCursorText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDanceBallroom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDancePole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrixEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrixMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrixPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrixRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDataMatrixScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabasePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDatabaseSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeathStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeathStarVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeathlyHallows [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDebian [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDebugStepInto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDebugStepOut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDebugStepOver [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecagramOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimalComma [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimalCommaDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimalCommaIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimalDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDecimalIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDelete [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteEmptyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteForever [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteForeverOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteRestore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteSweep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteSweepOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeleteVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDelta [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeskLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeskphone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesktopClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesktopMac [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesktopMacDashboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesktopTower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDesktopTowerMonitor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDetails [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDevTo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeveloperBoard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDeviantart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDevices [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiabetes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDialpad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiameter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiameterOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiameterVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiamond [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiamondOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiamondStone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice1Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice2Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice3Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice4Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice5Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDice6Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD10Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD12 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD12Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD20 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD20Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD4Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD6Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD8 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceD8Outline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiceMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDigitalOcean [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDipSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDirections [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDirectionsFork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDisc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiscAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiscPlayer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDiscord [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDishwasher [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDishwasherAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDishwasherOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDisqus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeHorizontalCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeHorizontalLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeHorizontalRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeVerticalBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeVerticalCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDistributeVerticalTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingFlippers [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingHelmet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingScuba [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingScubaFlag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingScubaTank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingScubaTankMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivingSnorkel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivision [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDivisionBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDlna [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDna [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDns [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDnsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoNotDisturb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoNotDisturbOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDockBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDockLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDockRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDockTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDockWindow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDocker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoctor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDogService [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDogSide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDolby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDolly [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDomain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDomainOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDomainPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDomainRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDomeLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDominoMask [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDonkey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoorClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoorClosedLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoorOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoorbell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDoorbellVideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotNet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsGrid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsHexagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsHorizontalCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsHorizontalCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsVerticalCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDotsVerticalCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDouban [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDownloadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDrag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDragHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDragHorizontalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDragVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDragVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDragVerticalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDramaMasks [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDraw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDrawing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDrawingBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDresser [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDresserOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDrone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDropbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDrupal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDuck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDumbbell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiDumpTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarHearing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarHearingOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthBoxMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthBoxOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthBoxPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthBoxRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEarthRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEgg [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEggEaster [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEggOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEggOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEggOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEiffelTower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEightTrack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEject [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEjectOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElectricSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElectricSwitchClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElectronFramework [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElephant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevationDecline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevationRise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevatorDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevatorPassenger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiElevatorUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEllipse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEllipseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailMarkAsUnread [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailNewsletter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOpenMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOpenMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailReceive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailReceiveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSendOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmailVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmber [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonAngry [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonAngryOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonConfused [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonConfusedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonCool [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonCoolOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonCry [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonCryOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonDead [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonDeadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonDevil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonDevilOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonExcited [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonExcitedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonFrown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonFrownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonHappy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonHappyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonKiss [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonKissOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonLol [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonLolOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonNeutral [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonNeutralOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonPoop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonPoopOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonSad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonSadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonSick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonSickOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonTongue [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonTongueOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonWink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEmoticonWinkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEngine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEngineOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEngineOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEngineOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEpsilon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEqualBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEqualizer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEqualizerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEraser [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEraserVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEscalator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEscalatorBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEscalatorDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEscalatorUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEslint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEthereum [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEthernet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEthernetCable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEthernetCableOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugCcs1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugCcs2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugChademo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugTesla [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugType1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvPlugType2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvStation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEvernote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExcavator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExclamation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExclamationThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExitRun [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExitToApp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExpandAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExpandAllOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExpansionCard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExpansionCardVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExponent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExponentBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiExportVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyeSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropperMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropperOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropperPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropperRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiEyedropperVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceAgent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceMask [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceMaskOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceProfile [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceProfileWoman [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceRecognition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceShimmer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceShimmerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceWoman [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceWomanOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceWomanShimmer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFaceWomanShimmerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFacebook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFacebookGaming [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFacebookMessenger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFacebookWorkplace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFactory [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFamilyTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanChevronDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanChevronUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanSpeed1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanSpeed2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFanSpeed3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForward10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForward30 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForward5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForward60 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFastForwardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFax [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFeather [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFeatureSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFeatureSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFedora [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFencing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFerrisWheel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFerry [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFile [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCabinet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCadBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCancelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCertificate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCertificateOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileChart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileChartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCloud [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCloudOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCodeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileCompare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDelimited [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDelimitedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocument [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocumentEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocumentEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocumentMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocumentMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDocumentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileDownloadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExcel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExcelBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExcelBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExcelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileExportOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileEyeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileFind [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileFindOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileHidden [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileImageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileImportOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileKeyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileLink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileLinkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileMusicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePdf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePdfBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePdfBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePdfOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePercentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePhone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePhoneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePowerpoint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePowerpointBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePowerpointBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePowerpointOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilePresentationBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRefreshOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileReplace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileReplaceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRestore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileRestoreOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSendOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSwap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSwapOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTableBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTableBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTableBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTableBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTableOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileTreeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileUndo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileUndoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileUploadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileVideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileVideoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileWord [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileWordBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileWordBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFileWordOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilmstrip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilmstripBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilmstripBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilmstripOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterMenu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterMenuOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterVariantMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterVariantPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFilterVariantRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFinance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFindReplace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFingerprint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFingerprintOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFire [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireExtinguisher [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireHydrant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireHydrantAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireHydrantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFirebase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFirefox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireplace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFireplaceOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFirework [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFish [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFishOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFishbowl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFishbowlOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFitToPage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFitToPageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagCheckered [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlagVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashRedEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashlight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlashlightOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlask [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskEmptyRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRoundBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRoundBottomEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRoundBottomEmptyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlaskRoundBottomOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFleurDeLis [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlipHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlipToBack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlipToFront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlipVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloorLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloorLampDual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloorLampVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloorPlan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloppy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFloppyVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlowerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlowerPoppy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlowerTulip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFlowerTulipOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFocusAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFocusField [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFocusFieldHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFocusFieldVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderDownloadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderGoogleDrive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderHome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderHomeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderInformation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderInformationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderKeyNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderKeyNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderKeyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMarkerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMultipleImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMultiplePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMultiplePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderMusicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderPound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderPoundOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderRefreshOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderStarMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderStarMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSwap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSwapOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderTable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderTableOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderUploadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderZip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFolderZipOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFontAwesome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFood [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodApple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodAppleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodCroissant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodDrumstick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodDrumstickOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodDrumstickOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodDrumstickOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodForkDrink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodHalal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodKosher [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodSteak [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodSteakOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFoodVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFootPrint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFootball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFootballAustralian [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFootballHelmet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiForklift [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormDropdown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormSelect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormTextarea [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormTextbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormTextboxLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormTextboxPassword [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignJustify [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignMiddle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAlignTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAnnotationMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatAnnotationPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatClear [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatColorFill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatColorHighlight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatColorMarkerCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatColorText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatColumns [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFloatCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFloatLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFloatNone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFloatRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFont [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFontSizeDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatFontSizeIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeader6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeaderDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeaderEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeaderIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHeaderPound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHorizontalAlignCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHorizontalAlignLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatHorizontalAlignRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatIndentDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatIndentIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatItalic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterCase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterCaseLower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterCaseUpper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterEndsWith [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterMatches [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLetterStartsWith [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLineSpacing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLineStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatLineWeight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListBulleted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListBulletedSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListBulletedTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListBulletedType [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListCheckbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListChecks [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListNumbered [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListNumberedRtl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatListText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatOverline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatPageBreak [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatPaint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatParagraph [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatPilcrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatQuoteClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatQuoteCloseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatQuoteOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatQuoteOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatRotate90 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatSection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatSize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatStrikethrough [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatStrikethroughVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatSubscript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatSuperscript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationAngleDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationAngleUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationDownVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationNone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextRotationVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextWrappingClip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextWrappingOverflow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextWrappingWrap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextdirectionLToR [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTextdirectionRToL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatTitle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatUnderline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatVerticalAlignBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatVerticalAlignCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatVerticalAlignTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatWrapInline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatWrapSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatWrapTight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFormatWrapTopBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiForum [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiForumOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiForwardburger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFountain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFountainPen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFountainPenTip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFreebsd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFrequentlyAskedQuestions [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeBottom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrialAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrialAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrialOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrialOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeIndustrialOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariantAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariantAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariantOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFridgeVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitCherries [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitCherriesOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitCitrus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitCitrusOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitGrapes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitGrapesOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitPineapple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFruitWatermelon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFullscreen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFullscreenExit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFunction [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFunctionVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuriganaHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuriganaVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuseAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuseBlade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiFuseOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircleDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircleLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircleRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadCircleUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRoundDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRoundLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRoundOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRoundRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadRoundUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadSquareOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamepadVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGamma [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGantryCrane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarageAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarageAlertVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarageOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarageOpenVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGarageVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGasCylinder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGasStation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGasStationOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGasStationOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGasStationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateAnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateNand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateNor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateNot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateOr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateXnor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGateXor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGatsby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGauge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGaugeEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGaugeFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGaugeLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGavel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderFemale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderMale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderMaleFemale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderMaleFemaleVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderNonBinary [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGenderTransgender [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGentoo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGesture [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureDoubleTap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGesturePinch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSpread [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureSwipeVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTapBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTapButton [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTapHold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTwoDoubleTap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGestureTwoTap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGhost [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGhostOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGif [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGift [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGiftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGithub [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGitlab [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassCocktail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassCocktailOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassFlute [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassMug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassMugOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassMugVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassMugVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassPintOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassStange [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassTulip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlassWine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlasses [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlobeLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGlobeModel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGmail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGnome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoKart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoKartTrack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGolf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGolfCart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGolfTee [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGondola [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoodreads [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleAds [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleAnalytics [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleAssistant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCardboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleChrome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCircles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCirclesCommunities [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCirclesExtended [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCirclesGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleClassroom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleCloud [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleController [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleControllerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleDownasaur [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleDrive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleEarth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleFit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleGlass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleHangouts [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleHome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleKeep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleLens [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleMaps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleMyBusiness [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleNearby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGooglePhotos [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGooglePlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGooglePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGooglePodcast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleSpreadsheet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleStreetView [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGoogleTranslate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGradient [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGrain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGraph [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGraphOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGraphql [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGrass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGraveStone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGreasePencil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGreaterThan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGreaterThanOrEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGrid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGridLarge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGridOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGrill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGrillOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGuitarAcoustic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGuitarElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGuitarPick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGuitarPickOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiGuyFawkesMask [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHairDryer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHairDryerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHalloween [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHamburger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHammer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHammerScrewdriver [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHammerWrench [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandOkay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPeace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPeaceVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPointingDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPointingLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPointingRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandPointingUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandSaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandWash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandWashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandWater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandcuffs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandshake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHandshakeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHanger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHardHat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHarddisk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHarddiskPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHarddiskRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHatFedora [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHazardLights [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHdr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHdrOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHead [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadDotsHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadDotsHorizontalOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadFlash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadFlashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadLightbulb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadLightbulbOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadSnowflake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadSnowflakeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadphones [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadphonesBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadphonesBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadphonesOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadphonesSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadset [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadsetDock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeadsetOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartBroken [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartBrokenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartFlash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartHalfFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartHalfOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartPulse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHeartRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelicopter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpRhombus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHelpRhombusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexadecimal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagonSlice6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHexagramOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHighDefinition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHighDefinitionBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHighway [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHiking [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHinduism [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHistory [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHockeyPuck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHockeySticks [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHololens [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAnalytics [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAssistant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeAutomation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeCity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeCityOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeCurrencyUsd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeExportOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFlood [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloor0 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloor1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloor2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloor3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloorA [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloorB [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloorG [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloorL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeFloorNegative1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeImportOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeLightbulb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeLightbulbOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeMapMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeModern [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeRoof [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeThermometer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeThermometerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHomeVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHookOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHops [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorizontalRotateClockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorizontalRotateCounterclockwise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorseHuman [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorseVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHorseshoe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHospital [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHospitalBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHospitalBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHospitalBuilding [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHospitalMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHotTub [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHours24 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHubspot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHulu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHuman [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanBabyChangingTable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanCane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanCapacityDecrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanCapacityIncrease [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanChild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanFemale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanFemaleBoy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanFemaleDance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanFemaleFemale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanFemaleGirl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanGreeting [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanGreetingProximity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanHandsdown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanHandsup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleBoy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleChild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleFemale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleGirl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleHeight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleHeightVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanMaleMale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanPregnant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanQueue [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanScooter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumanWheelchair [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHumbleBundle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHvac [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHvacOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHydraulicOilLevel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHydraulicOilTemperature [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiHydroPower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIceCream [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIceCreamOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIcePop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIdCard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIdentifier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIdeogramCjk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIdeogramCjkVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeArray [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeArrayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeBraces [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeBracesOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeParentheses [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeParenthesesOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeVariable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIframeVariableOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageAlbum [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageArea [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageAreaClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageAutoAdjust [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageBroken [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageBrokenVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterBlackWhite [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterCenterFocus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterCenterFocusStrong [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterCenterFocusStrongOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterCenterFocusWeak [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterDrama [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterFrames [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterHdr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterNone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterTiltShift [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFilterVintage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageFrame [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageMove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImagePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageSizeSelectActual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageSizeSelectLarge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageSizeSelectSmall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImageText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxArrowDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxArrowUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxFullOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInboxRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIncognito [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIncognitoCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIncognitoCircleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIncognitoOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInfinity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInformation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInformationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInformationVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInstagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInstrumentTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInvertColors [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiInvertColorsOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIobroker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIpNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIpNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIpod [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIslam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIsland [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiIvBag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJabber [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJeepney [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJellyfish [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJellyfishOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJira [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJquery [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJsfiddle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJudaism [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiJumpRope [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKabaddi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKangaroo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKarate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeg [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleSteam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettleSteamOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKettlebell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyChain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyChainVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyChange [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyLink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardBackspace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardCaps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardEsc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF11 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF12 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF7 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF8 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardF9 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardReturn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardSpace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardTab [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKeyboardVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKhanda [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKickstarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKlingon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKnife [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKnifeMilitary [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKodi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiKubernetes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelPercentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLabelVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLadder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLadybug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLambda [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLamps [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanConnect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanDisconnect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanPending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageC [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageCpp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageCsharp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageCss3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageFortran [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageGo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageHaskell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageHtml5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageJava [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageJavascript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageKotlin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageLua [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageMarkdown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageMarkdownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguagePhp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguagePython [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageR [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageRuby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageRubyOnRails [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageRust [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageSwift [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageTypescript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLanguageXaml [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaptop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaptopChromebook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaptopMac [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaptopOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaptopWindows [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaravel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaserPointer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLasso [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLastpass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLatitude [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLaunch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLavaLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayers [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersTriple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLayersTripleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeadPencil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeaf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeafMaple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeafMapleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeafOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeak [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeakOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedStrip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedStripVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedVariantOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLedVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLeek [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLessThan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLessThanOrEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLibrary [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLibraryShelves [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLicense [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLifebuoy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbCfl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbCflOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbCflSpiral [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbCflSpiralOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbGroupOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbGroupOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbGroupOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbMultipleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbMultipleOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbOnOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightbulbOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLighthouse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLighthouseOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightningBolt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLightningBoltOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLingerie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkBoxVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkBoxVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkVariantMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkVariantPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkVariantRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinkedin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinux [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLinuxMint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLipstick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiListStatus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLitecoin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLoading [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLocationEnter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLocationExit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOpenVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockPattern [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockReset [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockSmart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLocker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLockerMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLogin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLoginVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLogout [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLogoutVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLongitude [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLooks [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLotion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLotionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLotionPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLotionPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLoupe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLumx [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiLungs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnetOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnify [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyMinusCursor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyPlusCursor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyRemoveCursor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMagnifyScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxOpenUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxOpenUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMailboxUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiManjaro [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapLegend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerDistance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerQuestionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRadius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRadiusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRemoveVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMarkerUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMapbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMargin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMarkerCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMarkerCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMastodon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMaterialDesign [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMaterialUi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathCompass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathCos [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathIntegral [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathIntegralBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathLog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathNorm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathNormBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathSin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMathTan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMatrix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMedal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMedalOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMedicalBag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMeditation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMemory [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuSwap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuSwapOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMenuUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMerge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageArrowLeftOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageArrowRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageBookmark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageBookmarkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageBulleted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageBulletedOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageCogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageDraw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageFlash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageFlashOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageImageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessagePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessagePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageProcessing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageProcessingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageReply [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageReplyText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageTextClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageTextClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageTextLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageTextLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMessageVideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMeteor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMetronome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMetronomeTick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicroSd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophonePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrophoneVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicroscope [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftAccess [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftAzure [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftAzureDevops [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftBing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftDynamics365 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftEdge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftEdgeLegacy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftExcel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftInternetExplorer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftOffice [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftOnedrive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftOnenote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftOutlook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftPowerpoint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftSharepoint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftTeams [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftVisualStudio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftVisualStudioCode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftWindows [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftWindowsClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftWord [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxController [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryCharging [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerBatteryUnknown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerMenu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftXboxControllerView [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrosoftYammer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrowave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMicrowaveOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMiddleware [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMiddlewareOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMidi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMidiPort [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinecraft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMiniSd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinidisc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircleMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircleMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircleOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMinusNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMirror [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMixedMartialArts [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMixedReality [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMolecule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoleculeCo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoleculeCo2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorCellphone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorCellphoneStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorClean [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorDashboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorScreenshot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorShare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorSpeaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorSpeakerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMonitorStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonFirstQuarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonLastQuarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonNew [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonWaningCrescent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonWaningGibbous [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonWaxingCrescent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoonWaxingGibbous [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoped [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMopedElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMopedElectricOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMopedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotherHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotherNurse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionPause [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionPauseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionSensor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotionSensorOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotorbike [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMotorbikeElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseMoveDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseMoveUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseMoveVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMouseVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoveResize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMoveResizeVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieFilter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieFilterOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieOpenOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieRoll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMovieSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMuffin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMultiplication [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMultiplicationBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMushroom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMushroomOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMushroomOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMushroomOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicAccidentalDoubleFlat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicAccidentalDoubleSharp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicAccidentalFlat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicAccidentalNatural [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicAccidentalSharp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicClefAlto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicClefBass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicClefTreble [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteBluetoothOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteEighth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteEighthDotted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteHalfDotted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNotePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteQuarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteQuarterDotted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteSixteenth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteSixteenthDotted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteWhole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicNoteWholeDotted [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicRestEighth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicRestHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicRestQuarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicRestSixteenth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMusicRestWhole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiMustache [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNas [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNativescript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNature [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNaturePeople [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNavigation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNavigationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNearMe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNecklace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNeedle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetflix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength1Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength2Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength3Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrength4Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrengthOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrengthOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNetworkStrengthOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperVariantMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperVariantMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNewspaperVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNfc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNfcSearchVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNfcTap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNfcVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNfcVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNinja [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNintendoGameBoy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNintendoSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNintendoWii [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNintendoWiiu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNodejs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoodles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotEqualVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoteMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoteMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoteText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNoteTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotebookRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNotificationClearAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNpm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNuke [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric0CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric10CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric1CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric2CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric3CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric4CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric5CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric6CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric7CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric8CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9Box [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9BoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9BoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9BoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9Circle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9CircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9Plus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumeric9PlusCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumericNegative1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNumericPositive1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNutrition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiNuxt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOcarina [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOci [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOcr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOctagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOctagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOctagram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOctagramOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOdnoklassniki [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOffer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOfficeBuilding [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOfficeBuildingMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOfficeBuildingMarkerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOfficeBuildingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOilLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOilLevel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOilTemperature [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOmega [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOneUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOnepassword [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpacity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpenInApp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpenInNew [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpenSourceInitiative [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpenid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOpera [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrbit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrbitVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderAlphabeticalAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderAlphabeticalDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderBoolAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderBoolAscendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderBoolDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderBoolDescendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderNumericAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrderNumericDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrigin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrnament [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOrnamentVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOutdoorLamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOverscan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiOwl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPacMan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPackage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPackageDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPackageUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPackageVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPackageVariantClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageFirst [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutBody [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutFooter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutHeader [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutHeaderFooter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutSidebarLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageLayoutSidebarRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageNext [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPageNextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPagePrevious [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPagePreviousOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPailRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPalette [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaletteAdvanced [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaletteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaletteSwatch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaletteSwatchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPalmTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanBottomLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanBottomRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanTopLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanTopRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanda [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPandora [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanorama [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanoramaFisheye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanoramaHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanoramaVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPanoramaWideAngle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaperCutVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaperRoll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaperRollOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaperclip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiParachute [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiParachuteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiParking [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPartyPopper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPassport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPassportBiometric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPasta [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPatioHeater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPatreon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPause [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPauseCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPauseCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPauseOctagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPauseOctagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPawOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPdfBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeanut [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeanutOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeanutOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeanutOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencil [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPencilRuler [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPenguin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPentagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPentagonOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPercentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPeriodicTable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPerspectiveLess [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPerspectiveMore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPharmacy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneBluetoothOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneCancelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneClassicOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneDial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneDialOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneForwardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneHangup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneHangupOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneInTalk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneInTalkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneIncoming [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneIncomingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneLog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneLogOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMessage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMessageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMissed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneMissedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneOutgoing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneOutgoingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhonePaused [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhonePausedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhonePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhonePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneReturn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneReturnOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRotateLandscape [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneRotatePortrait [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneSettingsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPhoneVoip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPiBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPiHole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPiano [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPickaxe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPictureInPictureBottomRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPictureInPictureBottomRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPictureInPictureTopRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPictureInPictureTopRightOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPierCrane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPig [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPigVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPiggyBank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPillar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPineTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPineTreeBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPineTreeFire [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinterest [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinwheel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPinwheelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPipe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPipeDisconnected [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPipeLeak [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPipeWrench [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPirate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPistol [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPiston [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPitchfork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPizza [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayPause [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlayProtectedContent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaySpeed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistMusicOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlaylistStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusCircleMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusCircleMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusMinusBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusMinusVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPlusThick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPodcast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPodium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPodiumBronze [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPodiumGold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPodiumSilver [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPointOfSale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPokeball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPokemonGo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPokerChip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPolaroid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPoliceBadge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPoliceBadgeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPoll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPollBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPollBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPolo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPolymer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPool [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPopcorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPost [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPostOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPostageStamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPotMix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPotMixOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPotOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPotSteam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPotSteamOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPoundBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPoundBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerCycle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerOn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerPlug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerPlugOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerPlugOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerPlugOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSleep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketAu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketDe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketEu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketFr [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketIt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketJp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketUk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerSocketUs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowerStandby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPowershell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrescription [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPresentation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPresentationPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPretzel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter3d [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter3dNozzle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter3dNozzleAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter3dNozzleAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinter3dNozzleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterPos [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPrinterWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPriorityHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPriorityLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProfessionalHexagon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressDownload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressQuestion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProgressWrench [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProjector [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProjectorScreen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPropaneTank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPropaneTankOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiProtocol [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPublish [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPulse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPump [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPumpkin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPurse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPurseOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzlePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzlePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiPuzzleStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQqchat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcodeEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcodeMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcodePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcodeRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQrcodeScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQuadcopter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQualityHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQualityLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQualityMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiQuora [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRabbit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRacingHelmet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRacquetball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiatorDisabled [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiatorOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioAm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioFm [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioHandheld [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioTower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioactive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioactiveOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioboxBlank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadioboxMarked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiologyBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiologyBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRadiusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRailroadLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRaspberryPi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayEndArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayStart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayStartArrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayStartEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayStartVertexEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRayVertex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReact [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRead [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReceipt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecord [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecordCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecordCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecordPlayer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecordRec [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRectangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRectangleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecycle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRecycleVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReddit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRedhat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRedo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRedoVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReflectHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReflectVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRefreshCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRegex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRegisteredTrademark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReiterate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationManyToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneOrManyToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOneToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationOnlyOneToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrManyToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToOneOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToOnlyOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToZeroOrMany [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelationZeroOrOneToZeroOrOne [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRelativeScale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReloadAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReminder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRemote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRemoteDesktop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRemoteOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRemoteTv [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRemoteTvOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRenameBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReorderHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReorderVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRepeat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRepeatOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRepeatOnce [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReplay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReply [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReplyAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReplyAllOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReplyCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReplyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiReproduction [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiResistor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiResistorNodes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiResize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiResizeBottomRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiResponsive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRestart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRestartAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRestartOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRestore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRestoreAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewind [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewind10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewind30 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewind5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewind60 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRewindOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombusMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombusMediumOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombusSplit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRhombusSplitOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRibbon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRice [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRickshaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRickshawElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRivet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoadVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobber [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobotIndustrial [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobotMower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobotMowerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobotVacuum [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRobotVacuumVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRocket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRocketLaunch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRocketLaunchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRocketOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRodent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRollerSkate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRollerSkateOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRollerblade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRollerbladeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRollupjs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral5 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral6 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral7 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral8 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRomanNumeral9 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoomService [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoomServiceOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotate3d [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotate3dVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotateLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotateLeftVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotateOrbit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotateRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRotateRightVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoundedCorner [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRouter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRouterNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRouterWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRouterWirelessOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRouterWirelessSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoutes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRoutesClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRowing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRss [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRssBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRssOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRugby [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRuler [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRulerSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRulerSquareCompass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRun [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRunFast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiRvTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSackPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSafe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSafeSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSafeSquareOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSafetyGoggles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSailBoat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSalesforce [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSatellite [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSatelliteUplink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSatelliteVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSausage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSawBlade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSawtoothWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSaxophone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScale [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScaleBalance [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScaleBathroom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScaleOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScanHelper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScanner [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScannerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScatterPlot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScatterPlotOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSchool [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSchoolOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScissorsCutting [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScooter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScooterElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScoreboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScoreboardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScreenRotation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScreenRotationLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewFlatTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewLag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewMachineFlatTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewMachineRoundTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewRoundTop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScrewdriver [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScript [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScriptOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScriptText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiScriptTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSealVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSearchWeb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatFlat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatFlatAngled [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatIndividualSuite [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatLegroomExtra [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatLegroomNormal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatLegroomReduced [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatPassenger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatReclineExtra [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatReclineNormal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeatbelt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSecurity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSecurityNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeedOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeedOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSeesaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSegment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelect [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectColor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectCompare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectDrag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectGroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectInverse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectMultipleMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectPlace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionDrag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionEllipse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionEllipseArrowInside [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionMultipleMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSelectionSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSemanticWeb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSendOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSerialPort [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerNetworkOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiServerSecurity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetCenterRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetLeftCenter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetLeftRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetMerge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetNone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetSplit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSetTopBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSettingsHelper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShakerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShape [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeCirclePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeOvalPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapePolygonPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeRectanglePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeSquarePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShapeSquareRoundedPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareAllOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShareVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSheep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShield [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAccountOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAccountVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAccountVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAirplane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAirplaneOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldBug [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldBugOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldCar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldCross [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldCrossOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldHalfFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldHome [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldHomeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldKeyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldLinkVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldLinkVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldRefreshOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldSun [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldSunOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShieldSyncOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShipWheel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoeBallet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoeCleat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoeFormal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoeHeel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoePrint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoeSneaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShopping [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoppingMusic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoppingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShoppingSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShovel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShovelOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShowerHead [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShredder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShuffle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShuffleDisabled [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShuffleVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiShuriken [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSigma [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSigmaLower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignCaution [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignDirection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignDirectionMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignDirectionPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignDirectionRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignPole [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignRealEstate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignal2g [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignal3g [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignal4g [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignal5g [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalCellular1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalCellular2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalCellular3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalCellularOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalDistanceVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalHspa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalHspaPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignature [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignatureFreehand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignatureImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSignatureText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverware [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverwareClean [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverwareFork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverwareForkKnife [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverwareSpoon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSilverwareVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSim [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSimpleIcons [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSinaWeibo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSineWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSitemap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeM [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeS [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeXl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeXs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeXxl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeXxs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSizeXxxl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkateboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkewLess [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkewMore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSki [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkiCrossCountry [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkiWater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipBackward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipBackwardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipForwardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipNext [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipNextCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipNextCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipNextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipPrevious [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipPreviousCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipPreviousCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkipPreviousOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkullCrossbones [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkullCrossbonesOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkullOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkullScan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkullScanOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkype [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSkypeBusiness [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlashForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlashForwardBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSleep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSleepOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlopeDownhill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlopeUphill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlotMachine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSlotMachineOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmartCard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmartCardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmartCardReader [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmartCardReaderOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmokeDetector [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmoking [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmokingOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmokingPipe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSmokingPipeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnapchat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowflake [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowflakeAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowflakeMelt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowflakeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowflakeVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSnowman [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSoccer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSoccerField [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSocialDistance2Meters [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSocialDistance6Feet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSofa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSofaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSofaSingle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSofaSingleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSolarPanel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSolarPanelLarge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSolarPower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSolderingIron [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSolid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSonyPlaystation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSort [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAlphabeticalAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAlphabeticalAscendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAlphabeticalDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAlphabeticalDescendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAlphabeticalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortBoolAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortBoolAscendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortBoolDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortBoolDescendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortCalendarAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortCalendarDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortClockAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortClockAscendingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortClockDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortClockDescendingOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortNumericAscending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortNumericAscendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortNumericDescending [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortNumericDescendingVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortNumericVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortReverseVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortVariantLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortVariantLockOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSortVariantRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSoundcloud [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceBranchSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitEnd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitEndLocal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitLocal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitNextLocal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitStart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceCommitStartNextLocal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceFork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceMerge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourcePull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceRepository [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSourceRepositoryMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSoySauce [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSoySauceOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpaceInvaders [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpaceStation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpade [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSparkles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeaker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeakerBluetooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeakerMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeakerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeakerWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeedometer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeedometerMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpeedometerSlow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpellcheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpider [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpiderThread [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpiderWeb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpiritLevel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpoonSugar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpotify [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpotlight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpotlightBeam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSpray [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSprayBottle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSprinkler [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSprinklerVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSprout [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSproutOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareMediumOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareRoot [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareRootBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareRounded [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareRoundedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareSmall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSquareWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSqueegee [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSsh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStackExchange [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStackOverflow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStackpath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStadium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStadiumVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStairs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStairsBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStairsDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStairsUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStamper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStandardDefinition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarFace [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarFourPoints [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarFourPointsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarHalf [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarHalfFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarThreePoints [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStarThreePointsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStateMachine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSteam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSteering [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSteeringOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStepBackward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStepBackward2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStepForward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStepForward2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStethoscope [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSticker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerEmoji [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStickerRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStocking [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStomach [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStopCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStopCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStore24Hour [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStoreOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStorefront [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStorefrontOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStrategy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStretchToPage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStretchToPageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStringLights [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiStringLightsOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubdirectoryArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubdirectoryArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubmarine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubtitles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubtitlesOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubway [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubwayAlertVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSubwayVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSummit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSunglasses [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSurroundSound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSurroundSound20 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSurroundSound31 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSurroundSound51 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSurroundSound71 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSvg [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapHorizontalBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapHorizontalCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapHorizontalCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapHorizontalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapVerticalBold [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapVerticalCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapVerticalCircleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwapVerticalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwim [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSword [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSwordCross [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyllabaryHangul [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyllabaryHiragana [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyllabaryKatakana [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyllabaryKatakanaHalfwidth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSymbol [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSymfony [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyncAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyncCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiSyncOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTab [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabUnselected [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableArrowDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableArrowLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableArrowUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableBorder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableCancel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableChair [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableCog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableColumn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableColumnPlusAfter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableColumnPlusBefore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableColumnRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableColumnWidth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableEyeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableFurniture [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableHeadersEye [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableHeadersEyeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableLarge [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableLargePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableLargeRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableMergeCells [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableOfContents [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTablePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRefresh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRowHeight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRowPlusAfter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRowPlusBefore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableRowRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableSettings [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableSplitCell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableSync [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTableTennis [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTablet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabletAndroid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabletCellphone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabletDashboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTabletIpad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTaco [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTag [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagFaces [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagHeart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagHeartOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTagTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTailwind [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTank [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTankerTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTapeMeasure [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTarget [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTargetAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTargetVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTaxi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTea [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTeaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTeach [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTeamviewer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelegram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelescope [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevision [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionAmbientLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionClassic [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionClassicOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionClean [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionGuide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionPause [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionPlay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTelevisionStop [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTemperatureCelsius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTemperatureFahrenheit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTemperatureKelvin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTennis [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTennisBall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTerraform [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTerrain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTestTube [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTestTubeEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTestTubeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxMultipleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextBoxSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextRecognition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextShadow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextShort [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextSubject [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextToSpeech [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextToSpeechOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTexture [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTextureBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTheater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThemeLightDark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerChevronDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerChevronUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerLines [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermometerPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermostat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThermostatBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThoughtBubble [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThoughtBubbleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThumbDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThumbDownOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThumbUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThumbUpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiThumbsUpDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicket [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketConfirmation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketConfirmationOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTicketPercentOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTie [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTilde [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelapse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimeline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineClockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineHelp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineHelpOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelinePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelinePlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimelineTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimer10 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimer3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerSand [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerSandEmpty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimerSandFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTimetable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToaster [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToasterOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToasterOven [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToggleSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToggleSwitchOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToggleSwitchOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToggleSwitchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToilet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToolbox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToolboxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTools [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipEditOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipImageOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooltipTextOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTooth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToothOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToothbrush [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToothbrushElectric [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToothbrushPaste [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTorch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTortoise [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToslink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTournament [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTowTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTowerBeach [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTowerFire [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrick [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickMarkerOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickSearch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiToyBrickSearchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrackLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrackpad [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrackpadLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTractor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTractorVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrademark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrafficCone [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrafficLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrain [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrainCar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrainVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTramSide [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTranscribe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTranscribeClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransfer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransferDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransferLeft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransferRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransferUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitConnection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitConnectionHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitConnectionVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitDetour [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitSkip [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitTransfer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransitionMasked [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTranslate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTranslateOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTransmissionTower [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrashCan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrashCanOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTray [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrayAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrayFull [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrayMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrayPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrayRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTreasureChest [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTree [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTreeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrello [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrendingDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrendingNeutral [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrendingUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTriangleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTriangleWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTriforce [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophyAward [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophyBroken [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophyVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrophyVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckDelivery [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckDeliveryOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckFast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckFastOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTruckTrailer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTrumpet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTshirtCrew [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTshirtCrewOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTshirtV [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTshirtVOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTumbleDryer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTumbleDryerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTumbleDryerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTune [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTuneVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTuneVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTuneVerticalVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTurnstile [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTurnstileOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTurtle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTwitter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTwitterRetweet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTwoFactorAuthentication [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiTypewriter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUbisoft [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUbuntu [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUfo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUfoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUltraHighDefinition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbraco [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbrella [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbrellaClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbrellaClosedOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbrellaClosedVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUmbrellaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUndo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUndoVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnfoldLessHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnfoldLessVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnfoldMoreHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnfoldMoreVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUngroup [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnicode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnicorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnicornVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnicycle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnity [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUnreal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUntappd [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUpdate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUpload [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadLock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadMultiple [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadNetwork [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadNetworkOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUploadOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUsb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUsbFlashDrive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUsbFlashDriveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiUsbPort [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiValve [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiValveClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiValveOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVanPassenger [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVanUtility [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVanish [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVanishQuarter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVanityLight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVariable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVariableBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorArrangeAbove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorArrangeBelow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorBezier [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorCircle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorCircleVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorCombine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorCurve [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorDifference [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorDifferenceAb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorDifferenceBa [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorEllipse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorIntersection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorLine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorLink [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPoint [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolygon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolyline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolylineEdit [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolylineMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolylinePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorPolylineRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorRadius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorRectangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorSelection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorSquare [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorTriangle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVectorUnion [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVhs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVibrate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVibrateOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideo3d [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideo3dOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideo3dVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideo4kBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoAccount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoBoxOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoHighDefinition [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoImage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoInputAntenna [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoInputComponent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoInputHdmi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoInputScart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoInputSvideo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoStabilization [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoSwitch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoSwitchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoVintage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoWireless [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVideoWirelessOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewAgenda [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewAgendaOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewArray [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewArrayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewCarousel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewCarouselOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewColumn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewColumnOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewComfy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewComfyOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewCompact [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewCompactOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDashboard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDashboardOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDashboardVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDashboardVariantOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDay [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewDayOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewGrid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewGridOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewGridPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewGridPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewHeadline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewList [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewListOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewModuleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewParallel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewParallelOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewQuilt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewQuiltOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewSequential [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewSequentialOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewSplitHorizontal [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewSplitVertical [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewStream [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewStreamOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewWeek [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViewWeekOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVimeo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiViolin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVirtualReality [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVirus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVirusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVlc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVoiceOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVoicemail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolleyball [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeHigh [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeLow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeMedium [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeMute [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumePlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeSource [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeVariantOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVolumeVibrate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVote [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVoteOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVpn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVuejs [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiVuetify [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWall [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallSconce [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallSconceFlat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallSconceFlatVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallSconceRound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallSconceRoundVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallet [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletGiftcard [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletMembership [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWalletTravel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWallpaper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWardrobe [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWardrobeOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWarehouse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWashingMachine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWashingMachineAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWashingMachineOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatch [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchExport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchExportVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchImport [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchImportVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchVibrate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatchVibrateOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWater [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterBoiler [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterBoilerAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterBoilerOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterCheck [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterCheckOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterMinus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterMinusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPercent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPercentAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPlus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPlusOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPolo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPump [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterPumpOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterRemove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterRemoveOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterWell [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaterWellOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWateringCan [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWateringCanOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWatermark [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaveform [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaves [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWaze [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherCloudy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherCloudyAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherCloudyArrowRight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherFog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherHail [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherHazy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherHurricane [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherLightning [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherLightningRainy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherNight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherNightPartlyCloudy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPartlyCloudy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPartlyLightning [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPartlyRainy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPartlySnowy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPartlySnowyRainy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherPouring [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherRainy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSnowy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSnowyHeavy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSnowyRainy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunny [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunnyAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunnyOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunset [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunsetDown [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherSunsetUp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherTornado [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherWindy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeatherWindyVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebClock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebcam [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebhook [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebpack [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWebrtc [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWechat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeight [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeightGram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeightKilogram [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeightLifter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWeightPound [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhatsapp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWheelBarrow [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWheelchairAccessibility [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhistle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhistleOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhiteBalanceAuto [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhiteBalanceIncandescent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhiteBalanceIridescent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWhiteBalanceSunny [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWidgets [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWidgetsOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength1 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength1Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength1Lock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength2 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength2Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength2Lock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength3 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength3Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength3Lock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength4 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength4Alert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrength4Lock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrengthAlertOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrengthLockOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrengthOff [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrengthOffOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWifiStrengthOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWikipedia [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindTurbine [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowClose [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowClosed [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowClosedVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowMaximize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowMinimize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowOpenVariant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowRestore [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowShutter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowShutterAlert [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindowShutterOpen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWindsock [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWiper [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWiperWash [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWizardHat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWordpress [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWrap [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWrapDisabled [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWrench [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiWrenchOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiXamarin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiXamarinOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiXing [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiXml [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiXmpp [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYCombinator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYahoo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYeast [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYinYang [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoga [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoutube [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoutubeGaming [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoutubeStudio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoutubeSubscription [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYoutubeTv [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiYurt [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZWave [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZend [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZigbee [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZipBox [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZipBoxOutline [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZipDisk [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacAquarius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacAries [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacCancer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacCapricorn [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacGemini [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacLeo [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacLibra [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacPisces [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacSagittarius [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacScorpio [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacTaurus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mdiZodiacVirgo [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"mdiAbTesting\": () => /* binding */ mdiAbTesting,\n/* harmony export */   \"mdiAbjadArabic\": () => /* binding */ mdiAbjadArabic,\n/* harmony export */   \"mdiAbjadHebrew\": () => /* binding */ mdiAbjadHebrew,\n/* harmony export */   \"mdiAbugidaDevanagari\": () => /* binding */ mdiAbugidaDevanagari,\n/* harmony export */   \"mdiAbugidaThai\": () => /* binding */ mdiAbugidaThai,\n/* harmony export */   \"mdiAccessPoint\": () => /* binding */ mdiAccessPoint,\n/* harmony export */   \"mdiAccessPointCheck\": () => /* binding */ mdiAccessPointCheck,\n/* harmony export */   \"mdiAccessPointMinus\": () => /* binding */ mdiAccessPointMinus,\n/* harmony export */   \"mdiAccessPointNetwork\": () => /* binding */ mdiAccessPointNetwork,\n/* harmony export */   \"mdiAccessPointNetworkOff\": () => /* binding */ mdiAccessPointNetworkOff,\n/* harmony export */   \"mdiAccessPointOff\": () => /* binding */ mdiAccessPointOff,\n/* harmony export */   \"mdiAccessPointPlus\": () => /* binding */ mdiAccessPointPlus,\n/* harmony export */   \"mdiAccessPointRemove\": () => /* binding */ mdiAccessPointRemove,\n/* harmony export */   \"mdiAccount\": () => /* binding */ mdiAccount,\n/* harmony export */   \"mdiAccountAlert\": () => /* binding */ mdiAccountAlert,\n/* harmony export */   \"mdiAccountAlertOutline\": () => /* binding */ mdiAccountAlertOutline,\n/* harmony export */   \"mdiAccountArrowLeft\": () => /* binding */ mdiAccountArrowLeft,\n/* harmony export */   \"mdiAccountArrowLeftOutline\": () => /* binding */ mdiAccountArrowLeftOutline,\n/* harmony export */   \"mdiAccountArrowRight\": () => /* binding */ mdiAccountArrowRight,\n/* harmony export */   \"mdiAccountArrowRightOutline\": () => /* binding */ mdiAccountArrowRightOutline,\n/* harmony export */   \"mdiAccountBox\": () => /* binding */ mdiAccountBox,\n/* harmony export */   \"mdiAccountBoxMultiple\": () => /* binding */ mdiAccountBoxMultiple,\n/* harmony export */   \"mdiAccountBoxMultipleOutline\": () => /* binding */ mdiAccountBoxMultipleOutline,\n/* harmony export */   \"mdiAccountBoxOutline\": () => /* binding */ mdiAccountBoxOutline,\n/* harmony export */   \"mdiAccountCancel\": () => /* binding */ mdiAccountCancel,\n/* harmony export */   \"mdiAccountCancelOutline\": () => /* binding */ mdiAccountCancelOutline,\n/* harmony export */   \"mdiAccountCash\": () => /* binding */ mdiAccountCash,\n/* harmony export */   \"mdiAccountCashOutline\": () => /* binding */ mdiAccountCashOutline,\n/* harmony export */   \"mdiAccountCheck\": () => /* binding */ mdiAccountCheck,\n/* harmony export */   \"mdiAccountCheckOutline\": () => /* binding */ mdiAccountCheckOutline,\n/* harmony export */   \"mdiAccountChild\": () => /* binding */ mdiAccountChild,\n/* harmony export */   \"mdiAccountChildCircle\": () => /* binding */ mdiAccountChildCircle,\n/* harmony export */   \"mdiAccountChildOutline\": () => /* binding */ mdiAccountChildOutline,\n/* harmony export */   \"mdiAccountCircle\": () => /* binding */ mdiAccountCircle,\n/* harmony export */   \"mdiAccountCircleOutline\": () => /* binding */ mdiAccountCircleOutline,\n/* harmony export */   \"mdiAccountClock\": () => /* binding */ mdiAccountClock,\n/* harmony export */   \"mdiAccountClockOutline\": () => /* binding */ mdiAccountClockOutline,\n/* harmony export */   \"mdiAccountCog\": () => /* binding */ mdiAccountCog,\n/* harmony export */   \"mdiAccountCogOutline\": () => /* binding */ mdiAccountCogOutline,\n/* harmony export */   \"mdiAccountConvert\": () => /* binding */ mdiAccountConvert,\n/* harmony export */   \"mdiAccountConvertOutline\": () => /* binding */ mdiAccountConvertOutline,\n/* harmony export */   \"mdiAccountCowboyHat\": () => /* binding */ mdiAccountCowboyHat,\n/* harmony export */   \"mdiAccountDetails\": () => /* binding */ mdiAccountDetails,\n/* harmony export */   \"mdiAccountDetailsOutline\": () => /* binding */ mdiAccountDetailsOutline,\n/* harmony export */   \"mdiAccountEdit\": () => /* binding */ mdiAccountEdit,\n/* harmony export */   \"mdiAccountEditOutline\": () => /* binding */ mdiAccountEditOutline,\n/* harmony export */   \"mdiAccountGroup\": () => /* binding */ mdiAccountGroup,\n/* harmony export */   \"mdiAccountGroupOutline\": () => /* binding */ mdiAccountGroupOutline,\n/* harmony export */   \"mdiAccountHardHat\": () => /* binding */ mdiAccountHardHat,\n/* harmony export */   \"mdiAccountHeart\": () => /* binding */ mdiAccountHeart,\n/* harmony export */   \"mdiAccountHeartOutline\": () => /* binding */ mdiAccountHeartOutline,\n/* harmony export */   \"mdiAccountKey\": () => /* binding */ mdiAccountKey,\n/* harmony export */   \"mdiAccountKeyOutline\": () => /* binding */ mdiAccountKeyOutline,\n/* harmony export */   \"mdiAccountLock\": () => /* binding */ mdiAccountLock,\n/* harmony export */   \"mdiAccountLockOutline\": () => /* binding */ mdiAccountLockOutline,\n/* harmony export */   \"mdiAccountMinus\": () => /* binding */ mdiAccountMinus,\n/* harmony export */   \"mdiAccountMinusOutline\": () => /* binding */ mdiAccountMinusOutline,\n/* harmony export */   \"mdiAccountMultiple\": () => /* binding */ mdiAccountMultiple,\n/* harmony export */   \"mdiAccountMultipleCheck\": () => /* binding */ mdiAccountMultipleCheck,\n/* harmony export */   \"mdiAccountMultipleCheckOutline\": () => /* binding */ mdiAccountMultipleCheckOutline,\n/* harmony export */   \"mdiAccountMultipleMinus\": () => /* binding */ mdiAccountMultipleMinus,\n/* harmony export */   \"mdiAccountMultipleMinusOutline\": () => /* binding */ mdiAccountMultipleMinusOutline,\n/* harmony export */   \"mdiAccountMultipleOutline\": () => /* binding */ mdiAccountMultipleOutline,\n/* harmony export */   \"mdiAccountMultiplePlus\": () => /* binding */ mdiAccountMultiplePlus,\n/* harmony export */   \"mdiAccountMultiplePlusOutline\": () => /* binding */ mdiAccountMultiplePlusOutline,\n/* harmony export */   \"mdiAccountMultipleRemove\": () => /* binding */ mdiAccountMultipleRemove,\n/* harmony export */   \"mdiAccountMultipleRemoveOutline\": () => /* binding */ mdiAccountMultipleRemoveOutline,\n/* harmony export */   \"mdiAccountMusic\": () => /* binding */ mdiAccountMusic,\n/* harmony export */   \"mdiAccountMusicOutline\": () => /* binding */ mdiAccountMusicOutline,\n/* harmony export */   \"mdiAccountNetwork\": () => /* binding */ mdiAccountNetwork,\n/* harmony export */   \"mdiAccountNetworkOutline\": () => /* binding */ mdiAccountNetworkOutline,\n/* harmony export */   \"mdiAccountOff\": () => /* binding */ mdiAccountOff,\n/* harmony export */   \"mdiAccountOffOutline\": () => /* binding */ mdiAccountOffOutline,\n/* harmony export */   \"mdiAccountOutline\": () => /* binding */ mdiAccountOutline,\n/* harmony export */   \"mdiAccountPlus\": () => /* binding */ mdiAccountPlus,\n/* harmony export */   \"mdiAccountPlusOutline\": () => /* binding */ mdiAccountPlusOutline,\n/* harmony export */   \"mdiAccountQuestion\": () => /* binding */ mdiAccountQuestion,\n/* harmony export */   \"mdiAccountQuestionOutline\": () => /* binding */ mdiAccountQuestionOutline,\n/* harmony export */   \"mdiAccountReactivate\": () => /* binding */ mdiAccountReactivate,\n/* harmony export */   \"mdiAccountReactivateOutline\": () => /* binding */ mdiAccountReactivateOutline,\n/* harmony export */   \"mdiAccountRemove\": () => /* binding */ mdiAccountRemove,\n/* harmony export */   \"mdiAccountRemoveOutline\": () => /* binding */ mdiAccountRemoveOutline,\n/* harmony export */   \"mdiAccountSearch\": () => /* binding */ mdiAccountSearch,\n/* harmony export */   \"mdiAccountSearchOutline\": () => /* binding */ mdiAccountSearchOutline,\n/* harmony export */   \"mdiAccountSettings\": () => /* binding */ mdiAccountSettings,\n/* harmony export */   \"mdiAccountSettingsOutline\": () => /* binding */ mdiAccountSettingsOutline,\n/* harmony export */   \"mdiAccountStar\": () => /* binding */ mdiAccountStar,\n/* harmony export */   \"mdiAccountStarOutline\": () => /* binding */ mdiAccountStarOutline,\n/* harmony export */   \"mdiAccountSupervisor\": () => /* binding */ mdiAccountSupervisor,\n/* harmony export */   \"mdiAccountSupervisorCircle\": () => /* binding */ mdiAccountSupervisorCircle,\n/* harmony export */   \"mdiAccountSupervisorCircleOutline\": () => /* binding */ mdiAccountSupervisorCircleOutline,\n/* harmony export */   \"mdiAccountSupervisorOutline\": () => /* binding */ mdiAccountSupervisorOutline,\n/* harmony export */   \"mdiAccountSwitch\": () => /* binding */ mdiAccountSwitch,\n/* harmony export */   \"mdiAccountSwitchOutline\": () => /* binding */ mdiAccountSwitchOutline,\n/* harmony export */   \"mdiAccountTie\": () => /* binding */ mdiAccountTie,\n/* harmony export */   \"mdiAccountTieOutline\": () => /* binding */ mdiAccountTieOutline,\n/* harmony export */   \"mdiAccountTieVoice\": () => /* binding */ mdiAccountTieVoice,\n/* harmony export */   \"mdiAccountTieVoiceOff\": () => /* binding */ mdiAccountTieVoiceOff,\n/* harmony export */   \"mdiAccountTieVoiceOffOutline\": () => /* binding */ mdiAccountTieVoiceOffOutline,\n/* harmony export */   \"mdiAccountTieVoiceOutline\": () => /* binding */ mdiAccountTieVoiceOutline,\n/* harmony export */   \"mdiAccountVoice\": () => /* binding */ mdiAccountVoice,\n/* harmony export */   \"mdiAdjust\": () => /* binding */ mdiAdjust,\n/* harmony export */   \"mdiAdobe\": () => /* binding */ mdiAdobe,\n/* harmony export */   \"mdiAdobeAcrobat\": () => /* binding */ mdiAdobeAcrobat,\n/* harmony export */   \"mdiAirConditioner\": () => /* binding */ mdiAirConditioner,\n/* harmony export */   \"mdiAirFilter\": () => /* binding */ mdiAirFilter,\n/* harmony export */   \"mdiAirHorn\": () => /* binding */ mdiAirHorn,\n/* harmony export */   \"mdiAirHumidifier\": () => /* binding */ mdiAirHumidifier,\n/* harmony export */   \"mdiAirHumidifierOff\": () => /* binding */ mdiAirHumidifierOff,\n/* harmony export */   \"mdiAirPurifier\": () => /* binding */ mdiAirPurifier,\n/* harmony export */   \"mdiAirbag\": () => /* binding */ mdiAirbag,\n/* harmony export */   \"mdiAirballoon\": () => /* binding */ mdiAirballoon,\n/* harmony export */   \"mdiAirballoonOutline\": () => /* binding */ mdiAirballoonOutline,\n/* harmony export */   \"mdiAirplane\": () => /* binding */ mdiAirplane,\n/* harmony export */   \"mdiAirplaneLanding\": () => /* binding */ mdiAirplaneLanding,\n/* harmony export */   \"mdiAirplaneOff\": () => /* binding */ mdiAirplaneOff,\n/* harmony export */   \"mdiAirplaneTakeoff\": () => /* binding */ mdiAirplaneTakeoff,\n/* harmony export */   \"mdiAirport\": () => /* binding */ mdiAirport,\n/* harmony export */   \"mdiAlarm\": () => /* binding */ mdiAlarm,\n/* harmony export */   \"mdiAlarmBell\": () => /* binding */ mdiAlarmBell,\n/* harmony export */   \"mdiAlarmCheck\": () => /* binding */ mdiAlarmCheck,\n/* harmony export */   \"mdiAlarmLight\": () => /* binding */ mdiAlarmLight,\n/* harmony export */   \"mdiAlarmLightOutline\": () => /* binding */ mdiAlarmLightOutline,\n/* harmony export */   \"mdiAlarmMultiple\": () => /* binding */ mdiAlarmMultiple,\n/* harmony export */   \"mdiAlarmNote\": () => /* binding */ mdiAlarmNote,\n/* harmony export */   \"mdiAlarmNoteOff\": () => /* binding */ mdiAlarmNoteOff,\n/* harmony export */   \"mdiAlarmOff\": () => /* binding */ mdiAlarmOff,\n/* harmony export */   \"mdiAlarmPanel\": () => /* binding */ mdiAlarmPanel,\n/* harmony export */   \"mdiAlarmPanelOutline\": () => /* binding */ mdiAlarmPanelOutline,\n/* harmony export */   \"mdiAlarmPlus\": () => /* binding */ mdiAlarmPlus,\n/* harmony export */   \"mdiAlarmSnooze\": () => /* binding */ mdiAlarmSnooze,\n/* harmony export */   \"mdiAlbum\": () => /* binding */ mdiAlbum,\n/* harmony export */   \"mdiAlert\": () => /* binding */ mdiAlert,\n/* harmony export */   \"mdiAlertBox\": () => /* binding */ mdiAlertBox,\n/* harmony export */   \"mdiAlertBoxOutline\": () => /* binding */ mdiAlertBoxOutline,\n/* harmony export */   \"mdiAlertCircle\": () => /* binding */ mdiAlertCircle,\n/* harmony export */   \"mdiAlertCircleCheck\": () => /* binding */ mdiAlertCircleCheck,\n/* harmony export */   \"mdiAlertCircleCheckOutline\": () => /* binding */ mdiAlertCircleCheckOutline,\n/* harmony export */   \"mdiAlertCircleOutline\": () => /* binding */ mdiAlertCircleOutline,\n/* harmony export */   \"mdiAlertDecagram\": () => /* binding */ mdiAlertDecagram,\n/* harmony export */   \"mdiAlertDecagramOutline\": () => /* binding */ mdiAlertDecagramOutline,\n/* harmony export */   \"mdiAlertMinus\": () => /* binding */ mdiAlertMinus,\n/* harmony export */   \"mdiAlertMinusOutline\": () => /* binding */ mdiAlertMinusOutline,\n/* harmony export */   \"mdiAlertOctagon\": () => /* binding */ mdiAlertOctagon,\n/* harmony export */   \"mdiAlertOctagonOutline\": () => /* binding */ mdiAlertOctagonOutline,\n/* harmony export */   \"mdiAlertOctagram\": () => /* binding */ mdiAlertOctagram,\n/* harmony export */   \"mdiAlertOctagramOutline\": () => /* binding */ mdiAlertOctagramOutline,\n/* harmony export */   \"mdiAlertOutline\": () => /* binding */ mdiAlertOutline,\n/* harmony export */   \"mdiAlertPlus\": () => /* binding */ mdiAlertPlus,\n/* harmony export */   \"mdiAlertPlusOutline\": () => /* binding */ mdiAlertPlusOutline,\n/* harmony export */   \"mdiAlertRemove\": () => /* binding */ mdiAlertRemove,\n/* harmony export */   \"mdiAlertRemoveOutline\": () => /* binding */ mdiAlertRemoveOutline,\n/* harmony export */   \"mdiAlertRhombus\": () => /* binding */ mdiAlertRhombus,\n/* harmony export */   \"mdiAlertRhombusOutline\": () => /* binding */ mdiAlertRhombusOutline,\n/* harmony export */   \"mdiAlien\": () => /* binding */ mdiAlien,\n/* harmony export */   \"mdiAlienOutline\": () => /* binding */ mdiAlienOutline,\n/* harmony export */   \"mdiAlignHorizontalCenter\": () => /* binding */ mdiAlignHorizontalCenter,\n/* harmony export */   \"mdiAlignHorizontalLeft\": () => /* binding */ mdiAlignHorizontalLeft,\n/* harmony export */   \"mdiAlignHorizontalRight\": () => /* binding */ mdiAlignHorizontalRight,\n/* harmony export */   \"mdiAlignVerticalBottom\": () => /* binding */ mdiAlignVerticalBottom,\n/* harmony export */   \"mdiAlignVerticalCenter\": () => /* binding */ mdiAlignVerticalCenter,\n/* harmony export */   \"mdiAlignVerticalTop\": () => /* binding */ mdiAlignVerticalTop,\n/* harmony export */   \"mdiAllInclusive\": () => /* binding */ mdiAllInclusive,\n/* harmony export */   \"mdiAllergy\": () => /* binding */ mdiAllergy,\n/* harmony export */   \"mdiAlpha\": () => /* binding */ mdiAlpha,\n/* harmony export */   \"mdiAlphaA\": () => /* binding */ mdiAlphaA,\n/* harmony export */   \"mdiAlphaABox\": () => /* binding */ mdiAlphaABox,\n/* harmony export */   \"mdiAlphaABoxOutline\": () => /* binding */ mdiAlphaABoxOutline,\n/* harmony export */   \"mdiAlphaACircle\": () => /* binding */ mdiAlphaACircle,\n/* harmony export */   \"mdiAlphaACircleOutline\": () => /* binding */ mdiAlphaACircleOutline,\n/* harmony export */   \"mdiAlphaB\": () => /* binding */ mdiAlphaB,\n/* harmony export */   \"mdiAlphaBBox\": () => /* binding */ mdiAlphaBBox,\n/* harmony export */   \"mdiAlphaBBoxOutline\": () => /* binding */ mdiAlphaBBoxOutline,\n/* harmony export */   \"mdiAlphaBCircle\": () => /* binding */ mdiAlphaBCircle,\n/* harmony export */   \"mdiAlphaBCircleOutline\": () => /* binding */ mdiAlphaBCircleOutline,\n/* harmony export */   \"mdiAlphaC\": () => /* binding */ mdiAlphaC,\n/* harmony export */   \"mdiAlphaCBox\": () => /* binding */ mdiAlphaCBox,\n/* harmony export */   \"mdiAlphaCBoxOutline\": () => /* binding */ mdiAlphaCBoxOutline,\n/* harmony export */   \"mdiAlphaCCircle\": () => /* binding */ mdiAlphaCCircle,\n/* harmony export */   \"mdiAlphaCCircleOutline\": () => /* binding */ mdiAlphaCCircleOutline,\n/* harmony export */   \"mdiAlphaD\": () => /* binding */ mdiAlphaD,\n/* harmony export */   \"mdiAlphaDBox\": () => /* binding */ mdiAlphaDBox,\n/* harmony export */   \"mdiAlphaDBoxOutline\": () => /* binding */ mdiAlphaDBoxOutline,\n/* harmony export */   \"mdiAlphaDCircle\": () => /* binding */ mdiAlphaDCircle,\n/* harmony export */   \"mdiAlphaDCircleOutline\": () => /* binding */ mdiAlphaDCircleOutline,\n/* harmony export */   \"mdiAlphaE\": () => /* binding */ mdiAlphaE,\n/* harmony export */   \"mdiAlphaEBox\": () => /* binding */ mdiAlphaEBox,\n/* harmony export */   \"mdiAlphaEBoxOutline\": () => /* binding */ mdiAlphaEBoxOutline,\n/* harmony export */   \"mdiAlphaECircle\": () => /* binding */ mdiAlphaECircle,\n/* harmony export */   \"mdiAlphaECircleOutline\": () => /* binding */ mdiAlphaECircleOutline,\n/* harmony export */   \"mdiAlphaF\": () => /* binding */ mdiAlphaF,\n/* harmony export */   \"mdiAlphaFBox\": () => /* binding */ mdiAlphaFBox,\n/* harmony export */   \"mdiAlphaFBoxOutline\": () => /* binding */ mdiAlphaFBoxOutline,\n/* harmony export */   \"mdiAlphaFCircle\": () => /* binding */ mdiAlphaFCircle,\n/* harmony export */   \"mdiAlphaFCircleOutline\": () => /* binding */ mdiAlphaFCircleOutline,\n/* harmony export */   \"mdiAlphaG\": () => /* binding */ mdiAlphaG,\n/* harmony export */   \"mdiAlphaGBox\": () => /* binding */ mdiAlphaGBox,\n/* harmony export */   \"mdiAlphaGBoxOutline\": () => /* binding */ mdiAlphaGBoxOutline,\n/* harmony export */   \"mdiAlphaGCircle\": () => /* binding */ mdiAlphaGCircle,\n/* harmony export */   \"mdiAlphaGCircleOutline\": () => /* binding */ mdiAlphaGCircleOutline,\n/* harmony export */   \"mdiAlphaH\": () => /* binding */ mdiAlphaH,\n/* harmony export */   \"mdiAlphaHBox\": () => /* binding */ mdiAlphaHBox,\n/* harmony export */   \"mdiAlphaHBoxOutline\": () => /* binding */ mdiAlphaHBoxOutline,\n/* harmony export */   \"mdiAlphaHCircle\": () => /* binding */ mdiAlphaHCircle,\n/* harmony export */   \"mdiAlphaHCircleOutline\": () => /* binding */ mdiAlphaHCircleOutline,\n/* harmony export */   \"mdiAlphaI\": () => /* binding */ mdiAlphaI,\n/* harmony export */   \"mdiAlphaIBox\": () => /* binding */ mdiAlphaIBox,\n/* harmony export */   \"mdiAlphaIBoxOutline\": () => /* binding */ mdiAlphaIBoxOutline,\n/* harmony export */   \"mdiAlphaICircle\": () => /* binding */ mdiAlphaICircle,\n/* harmony export */   \"mdiAlphaICircleOutline\": () => /* binding */ mdiAlphaICircleOutline,\n/* harmony export */   \"mdiAlphaJ\": () => /* binding */ mdiAlphaJ,\n/* harmony export */   \"mdiAlphaJBox\": () => /* binding */ mdiAlphaJBox,\n/* harmony export */   \"mdiAlphaJBoxOutline\": () => /* binding */ mdiAlphaJBoxOutline,\n/* harmony export */   \"mdiAlphaJCircle\": () => /* binding */ mdiAlphaJCircle,\n/* harmony export */   \"mdiAlphaJCircleOutline\": () => /* binding */ mdiAlphaJCircleOutline,\n/* harmony export */   \"mdiAlphaK\": () => /* binding */ mdiAlphaK,\n/* harmony export */   \"mdiAlphaKBox\": () => /* binding */ mdiAlphaKBox,\n/* harmony export */   \"mdiAlphaKBoxOutline\": () => /* binding */ mdiAlphaKBoxOutline,\n/* harmony export */   \"mdiAlphaKCircle\": () => /* binding */ mdiAlphaKCircle,\n/* harmony export */   \"mdiAlphaKCircleOutline\": () => /* binding */ mdiAlphaKCircleOutline,\n/* harmony export */   \"mdiAlphaL\": () => /* binding */ mdiAlphaL,\n/* harmony export */   \"mdiAlphaLBox\": () => /* binding */ mdiAlphaLBox,\n/* harmony export */   \"mdiAlphaLBoxOutline\": () => /* binding */ mdiAlphaLBoxOutline,\n/* harmony export */   \"mdiAlphaLCircle\": () => /* binding */ mdiAlphaLCircle,\n/* harmony export */   \"mdiAlphaLCircleOutline\": () => /* binding */ mdiAlphaLCircleOutline,\n/* harmony export */   \"mdiAlphaM\": () => /* binding */ mdiAlphaM,\n/* harmony export */   \"mdiAlphaMBox\": () => /* binding */ mdiAlphaMBox,\n/* harmony export */   \"mdiAlphaMBoxOutline\": () => /* binding */ mdiAlphaMBoxOutline,\n/* harmony export */   \"mdiAlphaMCircle\": () => /* binding */ mdiAlphaMCircle,\n/* harmony export */   \"mdiAlphaMCircleOutline\": () => /* binding */ mdiAlphaMCircleOutline,\n/* harmony export */   \"mdiAlphaN\": () => /* binding */ mdiAlphaN,\n/* harmony export */   \"mdiAlphaNBox\": () => /* binding */ mdiAlphaNBox,\n/* harmony export */   \"mdiAlphaNBoxOutline\": () => /* binding */ mdiAlphaNBoxOutline,\n/* harmony export */   \"mdiAlphaNCircle\": () => /* binding */ mdiAlphaNCircle,\n/* harmony export */   \"mdiAlphaNCircleOutline\": () => /* binding */ mdiAlphaNCircleOutline,\n/* harmony export */   \"mdiAlphaO\": () => /* binding */ mdiAlphaO,\n/* harmony export */   \"mdiAlphaOBox\": () => /* binding */ mdiAlphaOBox,\n/* harmony export */   \"mdiAlphaOBoxOutline\": () => /* binding */ mdiAlphaOBoxOutline,\n/* harmony export */   \"mdiAlphaOCircle\": () => /* binding */ mdiAlphaOCircle,\n/* harmony export */   \"mdiAlphaOCircleOutline\": () => /* binding */ mdiAlphaOCircleOutline,\n/* harmony export */   \"mdiAlphaP\": () => /* binding */ mdiAlphaP,\n/* harmony export */   \"mdiAlphaPBox\": () => /* binding */ mdiAlphaPBox,\n/* harmony export */   \"mdiAlphaPBoxOutline\": () => /* binding */ mdiAlphaPBoxOutline,\n/* harmony export */   \"mdiAlphaPCircle\": () => /* binding */ mdiAlphaPCircle,\n/* harmony export */   \"mdiAlphaPCircleOutline\": () => /* binding */ mdiAlphaPCircleOutline,\n/* harmony export */   \"mdiAlphaQ\": () => /* binding */ mdiAlphaQ,\n/* harmony export */   \"mdiAlphaQBox\": () => /* binding */ mdiAlphaQBox,\n/* harmony export */   \"mdiAlphaQBoxOutline\": () => /* binding */ mdiAlphaQBoxOutline,\n/* harmony export */   \"mdiAlphaQCircle\": () => /* binding */ mdiAlphaQCircle,\n/* harmony export */   \"mdiAlphaQCircleOutline\": () => /* binding */ mdiAlphaQCircleOutline,\n/* harmony export */   \"mdiAlphaR\": () => /* binding */ mdiAlphaR,\n/* harmony export */   \"mdiAlphaRBox\": () => /* binding */ mdiAlphaRBox,\n/* harmony export */   \"mdiAlphaRBoxOutline\": () => /* binding */ mdiAlphaRBoxOutline,\n/* harmony export */   \"mdiAlphaRCircle\": () => /* binding */ mdiAlphaRCircle,\n/* harmony export */   \"mdiAlphaRCircleOutline\": () => /* binding */ mdiAlphaRCircleOutline,\n/* harmony export */   \"mdiAlphaS\": () => /* binding */ mdiAlphaS,\n/* harmony export */   \"mdiAlphaSBox\": () => /* binding */ mdiAlphaSBox,\n/* harmony export */   \"mdiAlphaSBoxOutline\": () => /* binding */ mdiAlphaSBoxOutline,\n/* harmony export */   \"mdiAlphaSCircle\": () => /* binding */ mdiAlphaSCircle,\n/* harmony export */   \"mdiAlphaSCircleOutline\": () => /* binding */ mdiAlphaSCircleOutline,\n/* harmony export */   \"mdiAlphaT\": () => /* binding */ mdiAlphaT,\n/* harmony export */   \"mdiAlphaTBox\": () => /* binding */ mdiAlphaTBox,\n/* harmony export */   \"mdiAlphaTBoxOutline\": () => /* binding */ mdiAlphaTBoxOutline,\n/* harmony export */   \"mdiAlphaTCircle\": () => /* binding */ mdiAlphaTCircle,\n/* harmony export */   \"mdiAlphaTCircleOutline\": () => /* binding */ mdiAlphaTCircleOutline,\n/* harmony export */   \"mdiAlphaU\": () => /* binding */ mdiAlphaU,\n/* harmony export */   \"mdiAlphaUBox\": () => /* binding */ mdiAlphaUBox,\n/* harmony export */   \"mdiAlphaUBoxOutline\": () => /* binding */ mdiAlphaUBoxOutline,\n/* harmony export */   \"mdiAlphaUCircle\": () => /* binding */ mdiAlphaUCircle,\n/* harmony export */   \"mdiAlphaUCircleOutline\": () => /* binding */ mdiAlphaUCircleOutline,\n/* harmony export */   \"mdiAlphaV\": () => /* binding */ mdiAlphaV,\n/* harmony export */   \"mdiAlphaVBox\": () => /* binding */ mdiAlphaVBox,\n/* harmony export */   \"mdiAlphaVBoxOutline\": () => /* binding */ mdiAlphaVBoxOutline,\n/* harmony export */   \"mdiAlphaVCircle\": () => /* binding */ mdiAlphaVCircle,\n/* harmony export */   \"mdiAlphaVCircleOutline\": () => /* binding */ mdiAlphaVCircleOutline,\n/* harmony export */   \"mdiAlphaW\": () => /* binding */ mdiAlphaW,\n/* harmony export */   \"mdiAlphaWBox\": () => /* binding */ mdiAlphaWBox,\n/* harmony export */   \"mdiAlphaWBoxOutline\": () => /* binding */ mdiAlphaWBoxOutline,\n/* harmony export */   \"mdiAlphaWCircle\": () => /* binding */ mdiAlphaWCircle,\n/* harmony export */   \"mdiAlphaWCircleOutline\": () => /* binding */ mdiAlphaWCircleOutline,\n/* harmony export */   \"mdiAlphaX\": () => /* binding */ mdiAlphaX,\n/* harmony export */   \"mdiAlphaXBox\": () => /* binding */ mdiAlphaXBox,\n/* harmony export */   \"mdiAlphaXBoxOutline\": () => /* binding */ mdiAlphaXBoxOutline,\n/* harmony export */   \"mdiAlphaXCircle\": () => /* binding */ mdiAlphaXCircle,\n/* harmony export */   \"mdiAlphaXCircleOutline\": () => /* binding */ mdiAlphaXCircleOutline,\n/* harmony export */   \"mdiAlphaY\": () => /* binding */ mdiAlphaY,\n/* harmony export */   \"mdiAlphaYBox\": () => /* binding */ mdiAlphaYBox,\n/* harmony export */   \"mdiAlphaYBoxOutline\": () => /* binding */ mdiAlphaYBoxOutline,\n/* harmony export */   \"mdiAlphaYCircle\": () => /* binding */ mdiAlphaYCircle,\n/* harmony export */   \"mdiAlphaYCircleOutline\": () => /* binding */ mdiAlphaYCircleOutline,\n/* harmony export */   \"mdiAlphaZ\": () => /* binding */ mdiAlphaZ,\n/* harmony export */   \"mdiAlphaZBox\": () => /* binding */ mdiAlphaZBox,\n/* harmony export */   \"mdiAlphaZBoxOutline\": () => /* binding */ mdiAlphaZBoxOutline,\n/* harmony export */   \"mdiAlphaZCircle\": () => /* binding */ mdiAlphaZCircle,\n/* harmony export */   \"mdiAlphaZCircleOutline\": () => /* binding */ mdiAlphaZCircleOutline,\n/* harmony export */   \"mdiAlphabetAurebesh\": () => /* binding */ mdiAlphabetAurebesh,\n/* harmony export */   \"mdiAlphabetCyrillic\": () => /* binding */ mdiAlphabetCyrillic,\n/* harmony export */   \"mdiAlphabetGreek\": () => /* binding */ mdiAlphabetGreek,\n/* harmony export */   \"mdiAlphabetLatin\": () => /* binding */ mdiAlphabetLatin,\n/* harmony export */   \"mdiAlphabetPiqad\": () => /* binding */ mdiAlphabetPiqad,\n/* harmony export */   \"mdiAlphabetTengwar\": () => /* binding */ mdiAlphabetTengwar,\n/* harmony export */   \"mdiAlphabetical\": () => /* binding */ mdiAlphabetical,\n/* harmony export */   \"mdiAlphabeticalOff\": () => /* binding */ mdiAlphabeticalOff,\n/* harmony export */   \"mdiAlphabeticalVariant\": () => /* binding */ mdiAlphabeticalVariant,\n/* harmony export */   \"mdiAlphabeticalVariantOff\": () => /* binding */ mdiAlphabeticalVariantOff,\n/* harmony export */   \"mdiAltimeter\": () => /* binding */ mdiAltimeter,\n/* harmony export */   \"mdiAmazon\": () => /* binding */ mdiAmazon,\n/* harmony export */   \"mdiAmazonAlexa\": () => /* binding */ mdiAmazonAlexa,\n/* harmony export */   \"mdiAmbulance\": () => /* binding */ mdiAmbulance,\n/* harmony export */   \"mdiAmmunition\": () => /* binding */ mdiAmmunition,\n/* harmony export */   \"mdiAmpersand\": () => /* binding */ mdiAmpersand,\n/* harmony export */   \"mdiAmplifier\": () => /* binding */ mdiAmplifier,\n/* harmony export */   \"mdiAmplifierOff\": () => /* binding */ mdiAmplifierOff,\n/* harmony export */   \"mdiAnchor\": () => /* binding */ mdiAnchor,\n/* harmony export */   \"mdiAndroid\": () => /* binding */ mdiAndroid,\n/* harmony export */   \"mdiAndroidAuto\": () => /* binding */ mdiAndroidAuto,\n/* harmony export */   \"mdiAndroidDebugBridge\": () => /* binding */ mdiAndroidDebugBridge,\n/* harmony export */   \"mdiAndroidMessages\": () => /* binding */ mdiAndroidMessages,\n/* harmony export */   \"mdiAndroidStudio\": () => /* binding */ mdiAndroidStudio,\n/* harmony export */   \"mdiAngleAcute\": () => /* binding */ mdiAngleAcute,\n/* harmony export */   \"mdiAngleObtuse\": () => /* binding */ mdiAngleObtuse,\n/* harmony export */   \"mdiAngleRight\": () => /* binding */ mdiAngleRight,\n/* harmony export */   \"mdiAngular\": () => /* binding */ mdiAngular,\n/* harmony export */   \"mdiAngularjs\": () => /* binding */ mdiAngularjs,\n/* harmony export */   \"mdiAnimation\": () => /* binding */ mdiAnimation,\n/* harmony export */   \"mdiAnimationOutline\": () => /* binding */ mdiAnimationOutline,\n/* harmony export */   \"mdiAnimationPlay\": () => /* binding */ mdiAnimationPlay,\n/* harmony export */   \"mdiAnimationPlayOutline\": () => /* binding */ mdiAnimationPlayOutline,\n/* harmony export */   \"mdiAnsible\": () => /* binding */ mdiAnsible,\n/* harmony export */   \"mdiAntenna\": () => /* binding */ mdiAntenna,\n/* harmony export */   \"mdiAnvil\": () => /* binding */ mdiAnvil,\n/* harmony export */   \"mdiApacheKafka\": () => /* binding */ mdiApacheKafka,\n/* harmony export */   \"mdiApi\": () => /* binding */ mdiApi,\n/* harmony export */   \"mdiApiOff\": () => /* binding */ mdiApiOff,\n/* harmony export */   \"mdiApple\": () => /* binding */ mdiApple,\n/* harmony export */   \"mdiAppleAirplay\": () => /* binding */ mdiAppleAirplay,\n/* harmony export */   \"mdiAppleFinder\": () => /* binding */ mdiAppleFinder,\n/* harmony export */   \"mdiAppleIcloud\": () => /* binding */ mdiAppleIcloud,\n/* harmony export */   \"mdiAppleIos\": () => /* binding */ mdiAppleIos,\n/* harmony export */   \"mdiAppleKeyboardCaps\": () => /* binding */ mdiAppleKeyboardCaps,\n/* harmony export */   \"mdiAppleKeyboardCommand\": () => /* binding */ mdiAppleKeyboardCommand,\n/* harmony export */   \"mdiAppleKeyboardControl\": () => /* binding */ mdiAppleKeyboardControl,\n/* harmony export */   \"mdiAppleKeyboardOption\": () => /* binding */ mdiAppleKeyboardOption,\n/* harmony export */   \"mdiAppleKeyboardShift\": () => /* binding */ mdiAppleKeyboardShift,\n/* harmony export */   \"mdiAppleSafari\": () => /* binding */ mdiAppleSafari,\n/* harmony export */   \"mdiApplication\": () => /* binding */ mdiApplication,\n/* harmony export */   \"mdiApplicationCog\": () => /* binding */ mdiApplicationCog,\n/* harmony export */   \"mdiApplicationExport\": () => /* binding */ mdiApplicationExport,\n/* harmony export */   \"mdiApplicationImport\": () => /* binding */ mdiApplicationImport,\n/* harmony export */   \"mdiApplicationSettings\": () => /* binding */ mdiApplicationSettings,\n/* harmony export */   \"mdiApproximatelyEqual\": () => /* binding */ mdiApproximatelyEqual,\n/* harmony export */   \"mdiApproximatelyEqualBox\": () => /* binding */ mdiApproximatelyEqualBox,\n/* harmony export */   \"mdiApps\": () => /* binding */ mdiApps,\n/* harmony export */   \"mdiAppsBox\": () => /* binding */ mdiAppsBox,\n/* harmony export */   \"mdiArch\": () => /* binding */ mdiArch,\n/* harmony export */   \"mdiArchive\": () => /* binding */ mdiArchive,\n/* harmony export */   \"mdiArchiveAlert\": () => /* binding */ mdiArchiveAlert,\n/* harmony export */   \"mdiArchiveAlertOutline\": () => /* binding */ mdiArchiveAlertOutline,\n/* harmony export */   \"mdiArchiveArrowDown\": () => /* binding */ mdiArchiveArrowDown,\n/* harmony export */   \"mdiArchiveArrowDownOutline\": () => /* binding */ mdiArchiveArrowDownOutline,\n/* harmony export */   \"mdiArchiveArrowUp\": () => /* binding */ mdiArchiveArrowUp,\n/* harmony export */   \"mdiArchiveArrowUpOutline\": () => /* binding */ mdiArchiveArrowUpOutline,\n/* harmony export */   \"mdiArchiveOutline\": () => /* binding */ mdiArchiveOutline,\n/* harmony export */   \"mdiArmFlex\": () => /* binding */ mdiArmFlex,\n/* harmony export */   \"mdiArmFlexOutline\": () => /* binding */ mdiArmFlexOutline,\n/* harmony export */   \"mdiArrangeBringForward\": () => /* binding */ mdiArrangeBringForward,\n/* harmony export */   \"mdiArrangeBringToFront\": () => /* binding */ mdiArrangeBringToFront,\n/* harmony export */   \"mdiArrangeSendBackward\": () => /* binding */ mdiArrangeSendBackward,\n/* harmony export */   \"mdiArrangeSendToBack\": () => /* binding */ mdiArrangeSendToBack,\n/* harmony export */   \"mdiArrowAll\": () => /* binding */ mdiArrowAll,\n/* harmony export */   \"mdiArrowBottomLeft\": () => /* binding */ mdiArrowBottomLeft,\n/* harmony export */   \"mdiArrowBottomLeftBoldOutline\": () => /* binding */ mdiArrowBottomLeftBoldOutline,\n/* harmony export */   \"mdiArrowBottomLeftThick\": () => /* binding */ mdiArrowBottomLeftThick,\n/* harmony export */   \"mdiArrowBottomLeftThinCircleOutline\": () => /* binding */ mdiArrowBottomLeftThinCircleOutline,\n/* harmony export */   \"mdiArrowBottomRight\": () => /* binding */ mdiArrowBottomRight,\n/* harmony export */   \"mdiArrowBottomRightBoldOutline\": () => /* binding */ mdiArrowBottomRightBoldOutline,\n/* harmony export */   \"mdiArrowBottomRightThick\": () => /* binding */ mdiArrowBottomRightThick,\n/* harmony export */   \"mdiArrowBottomRightThinCircleOutline\": () => /* binding */ mdiArrowBottomRightThinCircleOutline,\n/* harmony export */   \"mdiArrowCollapse\": () => /* binding */ mdiArrowCollapse,\n/* harmony export */   \"mdiArrowCollapseAll\": () => /* binding */ mdiArrowCollapseAll,\n/* harmony export */   \"mdiArrowCollapseDown\": () => /* binding */ mdiArrowCollapseDown,\n/* harmony export */   \"mdiArrowCollapseHorizontal\": () => /* binding */ mdiArrowCollapseHorizontal,\n/* harmony export */   \"mdiArrowCollapseLeft\": () => /* binding */ mdiArrowCollapseLeft,\n/* harmony export */   \"mdiArrowCollapseRight\": () => /* binding */ mdiArrowCollapseRight,\n/* harmony export */   \"mdiArrowCollapseUp\": () => /* binding */ mdiArrowCollapseUp,\n/* harmony export */   \"mdiArrowCollapseVertical\": () => /* binding */ mdiArrowCollapseVertical,\n/* harmony export */   \"mdiArrowDecision\": () => /* binding */ mdiArrowDecision,\n/* harmony export */   \"mdiArrowDecisionAuto\": () => /* binding */ mdiArrowDecisionAuto,\n/* harmony export */   \"mdiArrowDecisionAutoOutline\": () => /* binding */ mdiArrowDecisionAutoOutline,\n/* harmony export */   \"mdiArrowDecisionOutline\": () => /* binding */ mdiArrowDecisionOutline,\n/* harmony export */   \"mdiArrowDown\": () => /* binding */ mdiArrowDown,\n/* harmony export */   \"mdiArrowDownBold\": () => /* binding */ mdiArrowDownBold,\n/* harmony export */   \"mdiArrowDownBoldBox\": () => /* binding */ mdiArrowDownBoldBox,\n/* harmony export */   \"mdiArrowDownBoldBoxOutline\": () => /* binding */ mdiArrowDownBoldBoxOutline,\n/* harmony export */   \"mdiArrowDownBoldCircle\": () => /* binding */ mdiArrowDownBoldCircle,\n/* harmony export */   \"mdiArrowDownBoldCircleOutline\": () => /* binding */ mdiArrowDownBoldCircleOutline,\n/* harmony export */   \"mdiArrowDownBoldHexagonOutline\": () => /* binding */ mdiArrowDownBoldHexagonOutline,\n/* harmony export */   \"mdiArrowDownBoldOutline\": () => /* binding */ mdiArrowDownBoldOutline,\n/* harmony export */   \"mdiArrowDownBox\": () => /* binding */ mdiArrowDownBox,\n/* harmony export */   \"mdiArrowDownCircle\": () => /* binding */ mdiArrowDownCircle,\n/* harmony export */   \"mdiArrowDownCircleOutline\": () => /* binding */ mdiArrowDownCircleOutline,\n/* harmony export */   \"mdiArrowDownDropCircle\": () => /* binding */ mdiArrowDownDropCircle,\n/* harmony export */   \"mdiArrowDownDropCircleOutline\": () => /* binding */ mdiArrowDownDropCircleOutline,\n/* harmony export */   \"mdiArrowDownThick\": () => /* binding */ mdiArrowDownThick,\n/* harmony export */   \"mdiArrowDownThinCircleOutline\": () => /* binding */ mdiArrowDownThinCircleOutline,\n/* harmony export */   \"mdiArrowExpand\": () => /* binding */ mdiArrowExpand,\n/* harmony export */   \"mdiArrowExpandAll\": () => /* binding */ mdiArrowExpandAll,\n/* harmony export */   \"mdiArrowExpandDown\": () => /* binding */ mdiArrowExpandDown,\n/* harmony export */   \"mdiArrowExpandHorizontal\": () => /* binding */ mdiArrowExpandHorizontal,\n/* harmony export */   \"mdiArrowExpandLeft\": () => /* binding */ mdiArrowExpandLeft,\n/* harmony export */   \"mdiArrowExpandRight\": () => /* binding */ mdiArrowExpandRight,\n/* harmony export */   \"mdiArrowExpandUp\": () => /* binding */ mdiArrowExpandUp,\n/* harmony export */   \"mdiArrowExpandVertical\": () => /* binding */ mdiArrowExpandVertical,\n/* harmony export */   \"mdiArrowHorizontalLock\": () => /* binding */ mdiArrowHorizontalLock,\n/* harmony export */   \"mdiArrowLeft\": () => /* binding */ mdiArrowLeft,\n/* harmony export */   \"mdiArrowLeftBold\": () => /* binding */ mdiArrowLeftBold,\n/* harmony export */   \"mdiArrowLeftBoldBox\": () => /* binding */ mdiArrowLeftBoldBox,\n/* harmony export */   \"mdiArrowLeftBoldBoxOutline\": () => /* binding */ mdiArrowLeftBoldBoxOutline,\n/* harmony export */   \"mdiArrowLeftBoldCircle\": () => /* binding */ mdiArrowLeftBoldCircle,\n/* harmony export */   \"mdiArrowLeftBoldCircleOutline\": () => /* binding */ mdiArrowLeftBoldCircleOutline,\n/* harmony export */   \"mdiArrowLeftBoldHexagonOutline\": () => /* binding */ mdiArrowLeftBoldHexagonOutline,\n/* harmony export */   \"mdiArrowLeftBoldOutline\": () => /* binding */ mdiArrowLeftBoldOutline,\n/* harmony export */   \"mdiArrowLeftBox\": () => /* binding */ mdiArrowLeftBox,\n/* harmony export */   \"mdiArrowLeftCircle\": () => /* binding */ mdiArrowLeftCircle,\n/* harmony export */   \"mdiArrowLeftCircleOutline\": () => /* binding */ mdiArrowLeftCircleOutline,\n/* harmony export */   \"mdiArrowLeftDropCircle\": () => /* binding */ mdiArrowLeftDropCircle,\n/* harmony export */   \"mdiArrowLeftDropCircleOutline\": () => /* binding */ mdiArrowLeftDropCircleOutline,\n/* harmony export */   \"mdiArrowLeftRight\": () => /* binding */ mdiArrowLeftRight,\n/* harmony export */   \"mdiArrowLeftRightBold\": () => /* binding */ mdiArrowLeftRightBold,\n/* harmony export */   \"mdiArrowLeftRightBoldOutline\": () => /* binding */ mdiArrowLeftRightBoldOutline,\n/* harmony export */   \"mdiArrowLeftThick\": () => /* binding */ mdiArrowLeftThick,\n/* harmony export */   \"mdiArrowLeftThinCircleOutline\": () => /* binding */ mdiArrowLeftThinCircleOutline,\n/* harmony export */   \"mdiArrowRight\": () => /* binding */ mdiArrowRight,\n/* harmony export */   \"mdiArrowRightBold\": () => /* binding */ mdiArrowRightBold,\n/* harmony export */   \"mdiArrowRightBoldBox\": () => /* binding */ mdiArrowRightBoldBox,\n/* harmony export */   \"mdiArrowRightBoldBoxOutline\": () => /* binding */ mdiArrowRightBoldBoxOutline,\n/* harmony export */   \"mdiArrowRightBoldCircle\": () => /* binding */ mdiArrowRightBoldCircle,\n/* harmony export */   \"mdiArrowRightBoldCircleOutline\": () => /* binding */ mdiArrowRightBoldCircleOutline,\n/* harmony export */   \"mdiArrowRightBoldHexagonOutline\": () => /* binding */ mdiArrowRightBoldHexagonOutline,\n/* harmony export */   \"mdiArrowRightBoldOutline\": () => /* binding */ mdiArrowRightBoldOutline,\n/* harmony export */   \"mdiArrowRightBox\": () => /* binding */ mdiArrowRightBox,\n/* harmony export */   \"mdiArrowRightCircle\": () => /* binding */ mdiArrowRightCircle,\n/* harmony export */   \"mdiArrowRightCircleOutline\": () => /* binding */ mdiArrowRightCircleOutline,\n/* harmony export */   \"mdiArrowRightDropCircle\": () => /* binding */ mdiArrowRightDropCircle,\n/* harmony export */   \"mdiArrowRightDropCircleOutline\": () => /* binding */ mdiArrowRightDropCircleOutline,\n/* harmony export */   \"mdiArrowRightThick\": () => /* binding */ mdiArrowRightThick,\n/* harmony export */   \"mdiArrowRightThinCircleOutline\": () => /* binding */ mdiArrowRightThinCircleOutline,\n/* harmony export */   \"mdiArrowSplitHorizontal\": () => /* binding */ mdiArrowSplitHorizontal,\n/* harmony export */   \"mdiArrowSplitVertical\": () => /* binding */ mdiArrowSplitVertical,\n/* harmony export */   \"mdiArrowTopLeft\": () => /* binding */ mdiArrowTopLeft,\n/* harmony export */   \"mdiArrowTopLeftBoldOutline\": () => /* binding */ mdiArrowTopLeftBoldOutline,\n/* harmony export */   \"mdiArrowTopLeftBottomRight\": () => /* binding */ mdiArrowTopLeftBottomRight,\n/* harmony export */   \"mdiArrowTopLeftBottomRightBold\": () => /* binding */ mdiArrowTopLeftBottomRightBold,\n/* harmony export */   \"mdiArrowTopLeftThick\": () => /* binding */ mdiArrowTopLeftThick,\n/* harmony export */   \"mdiArrowTopLeftThinCircleOutline\": () => /* binding */ mdiArrowTopLeftThinCircleOutline,\n/* harmony export */   \"mdiArrowTopRight\": () => /* binding */ mdiArrowTopRight,\n/* harmony export */   \"mdiArrowTopRightBoldOutline\": () => /* binding */ mdiArrowTopRightBoldOutline,\n/* harmony export */   \"mdiArrowTopRightBottomLeft\": () => /* binding */ mdiArrowTopRightBottomLeft,\n/* harmony export */   \"mdiArrowTopRightBottomLeftBold\": () => /* binding */ mdiArrowTopRightBottomLeftBold,\n/* harmony export */   \"mdiArrowTopRightThick\": () => /* binding */ mdiArrowTopRightThick,\n/* harmony export */   \"mdiArrowTopRightThinCircleOutline\": () => /* binding */ mdiArrowTopRightThinCircleOutline,\n/* harmony export */   \"mdiArrowUp\": () => /* binding */ mdiArrowUp,\n/* harmony export */   \"mdiArrowUpBold\": () => /* binding */ mdiArrowUpBold,\n/* harmony export */   \"mdiArrowUpBoldBox\": () => /* binding */ mdiArrowUpBoldBox,\n/* harmony export */   \"mdiArrowUpBoldBoxOutline\": () => /* binding */ mdiArrowUpBoldBoxOutline,\n/* harmony export */   \"mdiArrowUpBoldCircle\": () => /* binding */ mdiArrowUpBoldCircle,\n/* harmony export */   \"mdiArrowUpBoldCircleOutline\": () => /* binding */ mdiArrowUpBoldCircleOutline,\n/* harmony export */   \"mdiArrowUpBoldHexagonOutline\": () => /* binding */ mdiArrowUpBoldHexagonOutline,\n/* harmony export */   \"mdiArrowUpBoldOutline\": () => /* binding */ mdiArrowUpBoldOutline,\n/* harmony export */   \"mdiArrowUpBox\": () => /* binding */ mdiArrowUpBox,\n/* harmony export */   \"mdiArrowUpCircle\": () => /* binding */ mdiArrowUpCircle,\n/* harmony export */   \"mdiArrowUpCircleOutline\": () => /* binding */ mdiArrowUpCircleOutline,\n/* harmony export */   \"mdiArrowUpDown\": () => /* binding */ mdiArrowUpDown,\n/* harmony export */   \"mdiArrowUpDownBold\": () => /* binding */ mdiArrowUpDownBold,\n/* harmony export */   \"mdiArrowUpDownBoldOutline\": () => /* binding */ mdiArrowUpDownBoldOutline,\n/* harmony export */   \"mdiArrowUpDropCircle\": () => /* binding */ mdiArrowUpDropCircle,\n/* harmony export */   \"mdiArrowUpDropCircleOutline\": () => /* binding */ mdiArrowUpDropCircleOutline,\n/* harmony export */   \"mdiArrowUpThick\": () => /* binding */ mdiArrowUpThick,\n/* harmony export */   \"mdiArrowUpThinCircleOutline\": () => /* binding */ mdiArrowUpThinCircleOutline,\n/* harmony export */   \"mdiArrowVerticalLock\": () => /* binding */ mdiArrowVerticalLock,\n/* harmony export */   \"mdiArtstation\": () => /* binding */ mdiArtstation,\n/* harmony export */   \"mdiAspectRatio\": () => /* binding */ mdiAspectRatio,\n/* harmony export */   \"mdiAssistant\": () => /* binding */ mdiAssistant,\n/* harmony export */   \"mdiAsterisk\": () => /* binding */ mdiAsterisk,\n/* harmony export */   \"mdiAt\": () => /* binding */ mdiAt,\n/* harmony export */   \"mdiAtlassian\": () => /* binding */ mdiAtlassian,\n/* harmony export */   \"mdiAtm\": () => /* binding */ mdiAtm,\n/* harmony export */   \"mdiAtom\": () => /* binding */ mdiAtom,\n/* harmony export */   \"mdiAtomVariant\": () => /* binding */ mdiAtomVariant,\n/* harmony export */   \"mdiAttachment\": () => /* binding */ mdiAttachment,\n/* harmony export */   \"mdiAudioVideo\": () => /* binding */ mdiAudioVideo,\n/* harmony export */   \"mdiAudioVideoOff\": () => /* binding */ mdiAudioVideoOff,\n/* harmony export */   \"mdiAugmentedReality\": () => /* binding */ mdiAugmentedReality,\n/* harmony export */   \"mdiAutoDownload\": () => /* binding */ mdiAutoDownload,\n/* harmony export */   \"mdiAutoFix\": () => /* binding */ mdiAutoFix,\n/* harmony export */   \"mdiAutoUpload\": () => /* binding */ mdiAutoUpload,\n/* harmony export */   \"mdiAutorenew\": () => /* binding */ mdiAutorenew,\n/* harmony export */   \"mdiAvTimer\": () => /* binding */ mdiAvTimer,\n/* harmony export */   \"mdiAws\": () => /* binding */ mdiAws,\n/* harmony export */   \"mdiAxe\": () => /* binding */ mdiAxe,\n/* harmony export */   \"mdiAxis\": () => /* binding */ mdiAxis,\n/* harmony export */   \"mdiAxisArrow\": () => /* binding */ mdiAxisArrow,\n/* harmony export */   \"mdiAxisArrowInfo\": () => /* binding */ mdiAxisArrowInfo,\n/* harmony export */   \"mdiAxisArrowLock\": () => /* binding */ mdiAxisArrowLock,\n/* harmony export */   \"mdiAxisLock\": () => /* binding */ mdiAxisLock,\n/* harmony export */   \"mdiAxisXArrow\": () => /* binding */ mdiAxisXArrow,\n/* harmony export */   \"mdiAxisXArrowLock\": () => /* binding */ mdiAxisXArrowLock,\n/* harmony export */   \"mdiAxisXRotateClockwise\": () => /* binding */ mdiAxisXRotateClockwise,\n/* harmony export */   \"mdiAxisXRotateCounterclockwise\": () => /* binding */ mdiAxisXRotateCounterclockwise,\n/* harmony export */   \"mdiAxisXYArrowLock\": () => /* binding */ mdiAxisXYArrowLock,\n/* harmony export */   \"mdiAxisYArrow\": () => /* binding */ mdiAxisYArrow,\n/* harmony export */   \"mdiAxisYArrowLock\": () => /* binding */ mdiAxisYArrowLock,\n/* harmony export */   \"mdiAxisYRotateClockwise\": () => /* binding */ mdiAxisYRotateClockwise,\n/* harmony export */   \"mdiAxisYRotateCounterclockwise\": () => /* binding */ mdiAxisYRotateCounterclockwise,\n/* harmony export */   \"mdiAxisZArrow\": () => /* binding */ mdiAxisZArrow,\n/* harmony export */   \"mdiAxisZArrowLock\": () => /* binding */ mdiAxisZArrowLock,\n/* harmony export */   \"mdiAxisZRotateClockwise\": () => /* binding */ mdiAxisZRotateClockwise,\n/* harmony export */   \"mdiAxisZRotateCounterclockwise\": () => /* binding */ mdiAxisZRotateCounterclockwise,\n/* harmony export */   \"mdiBabel\": () => /* binding */ mdiBabel,\n/* harmony export */   \"mdiBaby\": () => /* binding */ mdiBaby,\n/* harmony export */   \"mdiBabyBottle\": () => /* binding */ mdiBabyBottle,\n/* harmony export */   \"mdiBabyBottleOutline\": () => /* binding */ mdiBabyBottleOutline,\n/* harmony export */   \"mdiBabyBuggy\": () => /* binding */ mdiBabyBuggy,\n/* harmony export */   \"mdiBabyCarriage\": () => /* binding */ mdiBabyCarriage,\n/* harmony export */   \"mdiBabyCarriageOff\": () => /* binding */ mdiBabyCarriageOff,\n/* harmony export */   \"mdiBabyFace\": () => /* binding */ mdiBabyFace,\n/* harmony export */   \"mdiBabyFaceOutline\": () => /* binding */ mdiBabyFaceOutline,\n/* harmony export */   \"mdiBackburger\": () => /* binding */ mdiBackburger,\n/* harmony export */   \"mdiBackspace\": () => /* binding */ mdiBackspace,\n/* harmony export */   \"mdiBackspaceOutline\": () => /* binding */ mdiBackspaceOutline,\n/* harmony export */   \"mdiBackspaceReverse\": () => /* binding */ mdiBackspaceReverse,\n/* harmony export */   \"mdiBackspaceReverseOutline\": () => /* binding */ mdiBackspaceReverseOutline,\n/* harmony export */   \"mdiBackupRestore\": () => /* binding */ mdiBackupRestore,\n/* harmony export */   \"mdiBacteria\": () => /* binding */ mdiBacteria,\n/* harmony export */   \"mdiBacteriaOutline\": () => /* binding */ mdiBacteriaOutline,\n/* harmony export */   \"mdiBadgeAccount\": () => /* binding */ mdiBadgeAccount,\n/* harmony export */   \"mdiBadgeAccountAlert\": () => /* binding */ mdiBadgeAccountAlert,\n/* harmony export */   \"mdiBadgeAccountAlertOutline\": () => /* binding */ mdiBadgeAccountAlertOutline,\n/* harmony export */   \"mdiBadgeAccountHorizontal\": () => /* binding */ mdiBadgeAccountHorizontal,\n/* harmony export */   \"mdiBadgeAccountHorizontalOutline\": () => /* binding */ mdiBadgeAccountHorizontalOutline,\n/* harmony export */   \"mdiBadgeAccountOutline\": () => /* binding */ mdiBadgeAccountOutline,\n/* harmony export */   \"mdiBadminton\": () => /* binding */ mdiBadminton,\n/* harmony export */   \"mdiBagCarryOn\": () => /* binding */ mdiBagCarryOn,\n/* harmony export */   \"mdiBagCarryOnCheck\": () => /* binding */ mdiBagCarryOnCheck,\n/* harmony export */   \"mdiBagCarryOnOff\": () => /* binding */ mdiBagCarryOnOff,\n/* harmony export */   \"mdiBagChecked\": () => /* binding */ mdiBagChecked,\n/* harmony export */   \"mdiBagPersonal\": () => /* binding */ mdiBagPersonal,\n/* harmony export */   \"mdiBagPersonalOff\": () => /* binding */ mdiBagPersonalOff,\n/* harmony export */   \"mdiBagPersonalOffOutline\": () => /* binding */ mdiBagPersonalOffOutline,\n/* harmony export */   \"mdiBagPersonalOutline\": () => /* binding */ mdiBagPersonalOutline,\n/* harmony export */   \"mdiBagSuitcase\": () => /* binding */ mdiBagSuitcase,\n/* harmony export */   \"mdiBagSuitcaseOff\": () => /* binding */ mdiBagSuitcaseOff,\n/* harmony export */   \"mdiBagSuitcaseOffOutline\": () => /* binding */ mdiBagSuitcaseOffOutline,\n/* harmony export */   \"mdiBagSuitcaseOutline\": () => /* binding */ mdiBagSuitcaseOutline,\n/* harmony export */   \"mdiBaguette\": () => /* binding */ mdiBaguette,\n/* harmony export */   \"mdiBalloon\": () => /* binding */ mdiBalloon,\n/* harmony export */   \"mdiBallot\": () => /* binding */ mdiBallot,\n/* harmony export */   \"mdiBallotOutline\": () => /* binding */ mdiBallotOutline,\n/* harmony export */   \"mdiBallotRecount\": () => /* binding */ mdiBallotRecount,\n/* harmony export */   \"mdiBallotRecountOutline\": () => /* binding */ mdiBallotRecountOutline,\n/* harmony export */   \"mdiBandage\": () => /* binding */ mdiBandage,\n/* harmony export */   \"mdiBandcamp\": () => /* binding */ mdiBandcamp,\n/* harmony export */   \"mdiBank\": () => /* binding */ mdiBank,\n/* harmony export */   \"mdiBankMinus\": () => /* binding */ mdiBankMinus,\n/* harmony export */   \"mdiBankOutline\": () => /* binding */ mdiBankOutline,\n/* harmony export */   \"mdiBankPlus\": () => /* binding */ mdiBankPlus,\n/* harmony export */   \"mdiBankRemove\": () => /* binding */ mdiBankRemove,\n/* harmony export */   \"mdiBankTransfer\": () => /* binding */ mdiBankTransfer,\n/* harmony export */   \"mdiBankTransferIn\": () => /* binding */ mdiBankTransferIn,\n/* harmony export */   \"mdiBankTransferOut\": () => /* binding */ mdiBankTransferOut,\n/* harmony export */   \"mdiBarcode\": () => /* binding */ mdiBarcode,\n/* harmony export */   \"mdiBarcodeOff\": () => /* binding */ mdiBarcodeOff,\n/* harmony export */   \"mdiBarcodeScan\": () => /* binding */ mdiBarcodeScan,\n/* harmony export */   \"mdiBarley\": () => /* binding */ mdiBarley,\n/* harmony export */   \"mdiBarleyOff\": () => /* binding */ mdiBarleyOff,\n/* harmony export */   \"mdiBarn\": () => /* binding */ mdiBarn,\n/* harmony export */   \"mdiBarrel\": () => /* binding */ mdiBarrel,\n/* harmony export */   \"mdiBaseball\": () => /* binding */ mdiBaseball,\n/* harmony export */   \"mdiBaseballBat\": () => /* binding */ mdiBaseballBat,\n/* harmony export */   \"mdiBaseballDiamond\": () => /* binding */ mdiBaseballDiamond,\n/* harmony export */   \"mdiBaseballDiamondOutline\": () => /* binding */ mdiBaseballDiamondOutline,\n/* harmony export */   \"mdiBash\": () => /* binding */ mdiBash,\n/* harmony export */   \"mdiBasket\": () => /* binding */ mdiBasket,\n/* harmony export */   \"mdiBasketFill\": () => /* binding */ mdiBasketFill,\n/* harmony export */   \"mdiBasketMinus\": () => /* binding */ mdiBasketMinus,\n/* harmony export */   \"mdiBasketMinusOutline\": () => /* binding */ mdiBasketMinusOutline,\n/* harmony export */   \"mdiBasketOff\": () => /* binding */ mdiBasketOff,\n/* harmony export */   \"mdiBasketOffOutline\": () => /* binding */ mdiBasketOffOutline,\n/* harmony export */   \"mdiBasketOutline\": () => /* binding */ mdiBasketOutline,\n/* harmony export */   \"mdiBasketPlus\": () => /* binding */ mdiBasketPlus,\n/* harmony export */   \"mdiBasketPlusOutline\": () => /* binding */ mdiBasketPlusOutline,\n/* harmony export */   \"mdiBasketRemove\": () => /* binding */ mdiBasketRemove,\n/* harmony export */   \"mdiBasketRemoveOutline\": () => /* binding */ mdiBasketRemoveOutline,\n/* harmony export */   \"mdiBasketUnfill\": () => /* binding */ mdiBasketUnfill,\n/* harmony export */   \"mdiBasketball\": () => /* binding */ mdiBasketball,\n/* harmony export */   \"mdiBasketballHoop\": () => /* binding */ mdiBasketballHoop,\n/* harmony export */   \"mdiBasketballHoopOutline\": () => /* binding */ mdiBasketballHoopOutline,\n/* harmony export */   \"mdiBat\": () => /* binding */ mdiBat,\n/* harmony export */   \"mdiBattery\": () => /* binding */ mdiBattery,\n/* harmony export */   \"mdiBattery10\": () => /* binding */ mdiBattery10,\n/* harmony export */   \"mdiBattery10Bluetooth\": () => /* binding */ mdiBattery10Bluetooth,\n/* harmony export */   \"mdiBattery20\": () => /* binding */ mdiBattery20,\n/* harmony export */   \"mdiBattery20Bluetooth\": () => /* binding */ mdiBattery20Bluetooth,\n/* harmony export */   \"mdiBattery30\": () => /* binding */ mdiBattery30,\n/* harmony export */   \"mdiBattery30Bluetooth\": () => /* binding */ mdiBattery30Bluetooth,\n/* harmony export */   \"mdiBattery40\": () => /* binding */ mdiBattery40,\n/* harmony export */   \"mdiBattery40Bluetooth\": () => /* binding */ mdiBattery40Bluetooth,\n/* harmony export */   \"mdiBattery50\": () => /* binding */ mdiBattery50,\n/* harmony export */   \"mdiBattery50Bluetooth\": () => /* binding */ mdiBattery50Bluetooth,\n/* harmony export */   \"mdiBattery60\": () => /* binding */ mdiBattery60,\n/* harmony export */   \"mdiBattery60Bluetooth\": () => /* binding */ mdiBattery60Bluetooth,\n/* harmony export */   \"mdiBattery70\": () => /* binding */ mdiBattery70,\n/* harmony export */   \"mdiBattery70Bluetooth\": () => /* binding */ mdiBattery70Bluetooth,\n/* harmony export */   \"mdiBattery80\": () => /* binding */ mdiBattery80,\n/* harmony export */   \"mdiBattery80Bluetooth\": () => /* binding */ mdiBattery80Bluetooth,\n/* harmony export */   \"mdiBattery90\": () => /* binding */ mdiBattery90,\n/* harmony export */   \"mdiBattery90Bluetooth\": () => /* binding */ mdiBattery90Bluetooth,\n/* harmony export */   \"mdiBatteryAlert\": () => /* binding */ mdiBatteryAlert,\n/* harmony export */   \"mdiBatteryAlertBluetooth\": () => /* binding */ mdiBatteryAlertBluetooth,\n/* harmony export */   \"mdiBatteryAlertVariant\": () => /* binding */ mdiBatteryAlertVariant,\n/* harmony export */   \"mdiBatteryAlertVariantOutline\": () => /* binding */ mdiBatteryAlertVariantOutline,\n/* harmony export */   \"mdiBatteryBluetooth\": () => /* binding */ mdiBatteryBluetooth,\n/* harmony export */   \"mdiBatteryBluetoothVariant\": () => /* binding */ mdiBatteryBluetoothVariant,\n/* harmony export */   \"mdiBatteryCharging\": () => /* binding */ mdiBatteryCharging,\n/* harmony export */   \"mdiBatteryCharging10\": () => /* binding */ mdiBatteryCharging10,\n/* harmony export */   \"mdiBatteryCharging100\": () => /* binding */ mdiBatteryCharging100,\n/* harmony export */   \"mdiBatteryCharging20\": () => /* binding */ mdiBatteryCharging20,\n/* harmony export */   \"mdiBatteryCharging30\": () => /* binding */ mdiBatteryCharging30,\n/* harmony export */   \"mdiBatteryCharging40\": () => /* binding */ mdiBatteryCharging40,\n/* harmony export */   \"mdiBatteryCharging50\": () => /* binding */ mdiBatteryCharging50,\n/* harmony export */   \"mdiBatteryCharging60\": () => /* binding */ mdiBatteryCharging60,\n/* harmony export */   \"mdiBatteryCharging70\": () => /* binding */ mdiBatteryCharging70,\n/* harmony export */   \"mdiBatteryCharging80\": () => /* binding */ mdiBatteryCharging80,\n/* harmony export */   \"mdiBatteryCharging90\": () => /* binding */ mdiBatteryCharging90,\n/* harmony export */   \"mdiBatteryChargingHigh\": () => /* binding */ mdiBatteryChargingHigh,\n/* harmony export */   \"mdiBatteryChargingLow\": () => /* binding */ mdiBatteryChargingLow,\n/* harmony export */   \"mdiBatteryChargingMedium\": () => /* binding */ mdiBatteryChargingMedium,\n/* harmony export */   \"mdiBatteryChargingOutline\": () => /* binding */ mdiBatteryChargingOutline,\n/* harmony export */   \"mdiBatteryChargingWireless\": () => /* binding */ mdiBatteryChargingWireless,\n/* harmony export */   \"mdiBatteryChargingWireless10\": () => /* binding */ mdiBatteryChargingWireless10,\n/* harmony export */   \"mdiBatteryChargingWireless20\": () => /* binding */ mdiBatteryChargingWireless20,\n/* harmony export */   \"mdiBatteryChargingWireless30\": () => /* binding */ mdiBatteryChargingWireless30,\n/* harmony export */   \"mdiBatteryChargingWireless40\": () => /* binding */ mdiBatteryChargingWireless40,\n/* harmony export */   \"mdiBatteryChargingWireless50\": () => /* binding */ mdiBatteryChargingWireless50,\n/* harmony export */   \"mdiBatteryChargingWireless60\": () => /* binding */ mdiBatteryChargingWireless60,\n/* harmony export */   \"mdiBatteryChargingWireless70\": () => /* binding */ mdiBatteryChargingWireless70,\n/* harmony export */   \"mdiBatteryChargingWireless80\": () => /* binding */ mdiBatteryChargingWireless80,\n/* harmony export */   \"mdiBatteryChargingWireless90\": () => /* binding */ mdiBatteryChargingWireless90,\n/* harmony export */   \"mdiBatteryChargingWirelessAlert\": () => /* binding */ mdiBatteryChargingWirelessAlert,\n/* harmony export */   \"mdiBatteryChargingWirelessOutline\": () => /* binding */ mdiBatteryChargingWirelessOutline,\n/* harmony export */   \"mdiBatteryHeart\": () => /* binding */ mdiBatteryHeart,\n/* harmony export */   \"mdiBatteryHeartOutline\": () => /* binding */ mdiBatteryHeartOutline,\n/* harmony export */   \"mdiBatteryHeartVariant\": () => /* binding */ mdiBatteryHeartVariant,\n/* harmony export */   \"mdiBatteryHigh\": () => /* binding */ mdiBatteryHigh,\n/* harmony export */   \"mdiBatteryLow\": () => /* binding */ mdiBatteryLow,\n/* harmony export */   \"mdiBatteryMedium\": () => /* binding */ mdiBatteryMedium,\n/* harmony export */   \"mdiBatteryMinus\": () => /* binding */ mdiBatteryMinus,\n/* harmony export */   \"mdiBatteryNegative\": () => /* binding */ mdiBatteryNegative,\n/* harmony export */   \"mdiBatteryOff\": () => /* binding */ mdiBatteryOff,\n/* harmony export */   \"mdiBatteryOffOutline\": () => /* binding */ mdiBatteryOffOutline,\n/* harmony export */   \"mdiBatteryOutline\": () => /* binding */ mdiBatteryOutline,\n/* harmony export */   \"mdiBatteryPlus\": () => /* binding */ mdiBatteryPlus,\n/* harmony export */   \"mdiBatteryPositive\": () => /* binding */ mdiBatteryPositive,\n/* harmony export */   \"mdiBatteryUnknown\": () => /* binding */ mdiBatteryUnknown,\n/* harmony export */   \"mdiBatteryUnknownBluetooth\": () => /* binding */ mdiBatteryUnknownBluetooth,\n/* harmony export */   \"mdiBattlenet\": () => /* binding */ mdiBattlenet,\n/* harmony export */   \"mdiBeach\": () => /* binding */ mdiBeach,\n/* harmony export */   \"mdiBeaker\": () => /* binding */ mdiBeaker,\n/* harmony export */   \"mdiBeakerAlert\": () => /* binding */ mdiBeakerAlert,\n/* harmony export */   \"mdiBeakerAlertOutline\": () => /* binding */ mdiBeakerAlertOutline,\n/* harmony export */   \"mdiBeakerCheck\": () => /* binding */ mdiBeakerCheck,\n/* harmony export */   \"mdiBeakerCheckOutline\": () => /* binding */ mdiBeakerCheckOutline,\n/* harmony export */   \"mdiBeakerMinus\": () => /* binding */ mdiBeakerMinus,\n/* harmony export */   \"mdiBeakerMinusOutline\": () => /* binding */ mdiBeakerMinusOutline,\n/* harmony export */   \"mdiBeakerOutline\": () => /* binding */ mdiBeakerOutline,\n/* harmony export */   \"mdiBeakerPlus\": () => /* binding */ mdiBeakerPlus,\n/* harmony export */   \"mdiBeakerPlusOutline\": () => /* binding */ mdiBeakerPlusOutline,\n/* harmony export */   \"mdiBeakerQuestion\": () => /* binding */ mdiBeakerQuestion,\n/* harmony export */   \"mdiBeakerQuestionOutline\": () => /* binding */ mdiBeakerQuestionOutline,\n/* harmony export */   \"mdiBeakerRemove\": () => /* binding */ mdiBeakerRemove,\n/* harmony export */   \"mdiBeakerRemoveOutline\": () => /* binding */ mdiBeakerRemoveOutline,\n/* harmony export */   \"mdiBed\": () => /* binding */ mdiBed,\n/* harmony export */   \"mdiBedDouble\": () => /* binding */ mdiBedDouble,\n/* harmony export */   \"mdiBedDoubleOutline\": () => /* binding */ mdiBedDoubleOutline,\n/* harmony export */   \"mdiBedEmpty\": () => /* binding */ mdiBedEmpty,\n/* harmony export */   \"mdiBedKing\": () => /* binding */ mdiBedKing,\n/* harmony export */   \"mdiBedKingOutline\": () => /* binding */ mdiBedKingOutline,\n/* harmony export */   \"mdiBedOutline\": () => /* binding */ mdiBedOutline,\n/* harmony export */   \"mdiBedQueen\": () => /* binding */ mdiBedQueen,\n/* harmony export */   \"mdiBedQueenOutline\": () => /* binding */ mdiBedQueenOutline,\n/* harmony export */   \"mdiBedSingle\": () => /* binding */ mdiBedSingle,\n/* harmony export */   \"mdiBedSingleOutline\": () => /* binding */ mdiBedSingleOutline,\n/* harmony export */   \"mdiBee\": () => /* binding */ mdiBee,\n/* harmony export */   \"mdiBeeFlower\": () => /* binding */ mdiBeeFlower,\n/* harmony export */   \"mdiBeehiveOffOutline\": () => /* binding */ mdiBeehiveOffOutline,\n/* harmony export */   \"mdiBeehiveOutline\": () => /* binding */ mdiBeehiveOutline,\n/* harmony export */   \"mdiBeekeeper\": () => /* binding */ mdiBeekeeper,\n/* harmony export */   \"mdiBeer\": () => /* binding */ mdiBeer,\n/* harmony export */   \"mdiBeerOutline\": () => /* binding */ mdiBeerOutline,\n/* harmony export */   \"mdiBell\": () => /* binding */ mdiBell,\n/* harmony export */   \"mdiBellAlert\": () => /* binding */ mdiBellAlert,\n/* harmony export */   \"mdiBellAlertOutline\": () => /* binding */ mdiBellAlertOutline,\n/* harmony export */   \"mdiBellCancel\": () => /* binding */ mdiBellCancel,\n/* harmony export */   \"mdiBellCancelOutline\": () => /* binding */ mdiBellCancelOutline,\n/* harmony export */   \"mdiBellCheck\": () => /* binding */ mdiBellCheck,\n/* harmony export */   \"mdiBellCheckOutline\": () => /* binding */ mdiBellCheckOutline,\n/* harmony export */   \"mdiBellCircle\": () => /* binding */ mdiBellCircle,\n/* harmony export */   \"mdiBellCircleOutline\": () => /* binding */ mdiBellCircleOutline,\n/* harmony export */   \"mdiBellMinus\": () => /* binding */ mdiBellMinus,\n/* harmony export */   \"mdiBellMinusOutline\": () => /* binding */ mdiBellMinusOutline,\n/* harmony export */   \"mdiBellOff\": () => /* binding */ mdiBellOff,\n/* harmony export */   \"mdiBellOffOutline\": () => /* binding */ mdiBellOffOutline,\n/* harmony export */   \"mdiBellOutline\": () => /* binding */ mdiBellOutline,\n/* harmony export */   \"mdiBellPlus\": () => /* binding */ mdiBellPlus,\n/* harmony export */   \"mdiBellPlusOutline\": () => /* binding */ mdiBellPlusOutline,\n/* harmony export */   \"mdiBellRemove\": () => /* binding */ mdiBellRemove,\n/* harmony export */   \"mdiBellRemoveOutline\": () => /* binding */ mdiBellRemoveOutline,\n/* harmony export */   \"mdiBellRing\": () => /* binding */ mdiBellRing,\n/* harmony export */   \"mdiBellRingOutline\": () => /* binding */ mdiBellRingOutline,\n/* harmony export */   \"mdiBellSleep\": () => /* binding */ mdiBellSleep,\n/* harmony export */   \"mdiBellSleepOutline\": () => /* binding */ mdiBellSleepOutline,\n/* harmony export */   \"mdiBeta\": () => /* binding */ mdiBeta,\n/* harmony export */   \"mdiBetamax\": () => /* binding */ mdiBetamax,\n/* harmony export */   \"mdiBiathlon\": () => /* binding */ mdiBiathlon,\n/* harmony export */   \"mdiBicycle\": () => /* binding */ mdiBicycle,\n/* harmony export */   \"mdiBicycleBasket\": () => /* binding */ mdiBicycleBasket,\n/* harmony export */   \"mdiBicycleElectric\": () => /* binding */ mdiBicycleElectric,\n/* harmony export */   \"mdiBicyclePennyFarthing\": () => /* binding */ mdiBicyclePennyFarthing,\n/* harmony export */   \"mdiBike\": () => /* binding */ mdiBike,\n/* harmony export */   \"mdiBikeFast\": () => /* binding */ mdiBikeFast,\n/* harmony export */   \"mdiBillboard\": () => /* binding */ mdiBillboard,\n/* harmony export */   \"mdiBilliards\": () => /* binding */ mdiBilliards,\n/* harmony export */   \"mdiBilliardsRack\": () => /* binding */ mdiBilliardsRack,\n/* harmony export */   \"mdiBinoculars\": () => /* binding */ mdiBinoculars,\n/* harmony export */   \"mdiBio\": () => /* binding */ mdiBio,\n/* harmony export */   \"mdiBiohazard\": () => /* binding */ mdiBiohazard,\n/* harmony export */   \"mdiBird\": () => /* binding */ mdiBird,\n/* harmony export */   \"mdiBitbucket\": () => /* binding */ mdiBitbucket,\n/* harmony export */   \"mdiBitcoin\": () => /* binding */ mdiBitcoin,\n/* harmony export */   \"mdiBlackMesa\": () => /* binding */ mdiBlackMesa,\n/* harmony export */   \"mdiBlender\": () => /* binding */ mdiBlender,\n/* harmony export */   \"mdiBlenderSoftware\": () => /* binding */ mdiBlenderSoftware,\n/* harmony export */   \"mdiBlinds\": () => /* binding */ mdiBlinds,\n/* harmony export */   \"mdiBlindsOpen\": () => /* binding */ mdiBlindsOpen,\n/* harmony export */   \"mdiBlockHelper\": () => /* binding */ mdiBlockHelper,\n/* harmony export */   \"mdiBlogger\": () => /* binding */ mdiBlogger,\n/* harmony export */   \"mdiBloodBag\": () => /* binding */ mdiBloodBag,\n/* harmony export */   \"mdiBluetooth\": () => /* binding */ mdiBluetooth,\n/* harmony export */   \"mdiBluetoothAudio\": () => /* binding */ mdiBluetoothAudio,\n/* harmony export */   \"mdiBluetoothConnect\": () => /* binding */ mdiBluetoothConnect,\n/* harmony export */   \"mdiBluetoothOff\": () => /* binding */ mdiBluetoothOff,\n/* harmony export */   \"mdiBluetoothSettings\": () => /* binding */ mdiBluetoothSettings,\n/* harmony export */   \"mdiBluetoothTransfer\": () => /* binding */ mdiBluetoothTransfer,\n/* harmony export */   \"mdiBlur\": () => /* binding */ mdiBlur,\n/* harmony export */   \"mdiBlurLinear\": () => /* binding */ mdiBlurLinear,\n/* harmony export */   \"mdiBlurOff\": () => /* binding */ mdiBlurOff,\n/* harmony export */   \"mdiBlurRadial\": () => /* binding */ mdiBlurRadial,\n/* harmony export */   \"mdiBolnisiCross\": () => /* binding */ mdiBolnisiCross,\n/* harmony export */   \"mdiBolt\": () => /* binding */ mdiBolt,\n/* harmony export */   \"mdiBomb\": () => /* binding */ mdiBomb,\n/* harmony export */   \"mdiBombOff\": () => /* binding */ mdiBombOff,\n/* harmony export */   \"mdiBone\": () => /* binding */ mdiBone,\n/* harmony export */   \"mdiBook\": () => /* binding */ mdiBook,\n/* harmony export */   \"mdiBookAccount\": () => /* binding */ mdiBookAccount,\n/* harmony export */   \"mdiBookAccountOutline\": () => /* binding */ mdiBookAccountOutline,\n/* harmony export */   \"mdiBookAlphabet\": () => /* binding */ mdiBookAlphabet,\n/* harmony export */   \"mdiBookCheck\": () => /* binding */ mdiBookCheck,\n/* harmony export */   \"mdiBookCheckOutline\": () => /* binding */ mdiBookCheckOutline,\n/* harmony export */   \"mdiBookCross\": () => /* binding */ mdiBookCross,\n/* harmony export */   \"mdiBookInformationVariant\": () => /* binding */ mdiBookInformationVariant,\n/* harmony export */   \"mdiBookLock\": () => /* binding */ mdiBookLock,\n/* harmony export */   \"mdiBookLockOpen\": () => /* binding */ mdiBookLockOpen,\n/* harmony export */   \"mdiBookMinus\": () => /* binding */ mdiBookMinus,\n/* harmony export */   \"mdiBookMinusMultiple\": () => /* binding */ mdiBookMinusMultiple,\n/* harmony export */   \"mdiBookMinusMultipleOutline\": () => /* binding */ mdiBookMinusMultipleOutline,\n/* harmony export */   \"mdiBookMultiple\": () => /* binding */ mdiBookMultiple,\n/* harmony export */   \"mdiBookMultipleOutline\": () => /* binding */ mdiBookMultipleOutline,\n/* harmony export */   \"mdiBookMusic\": () => /* binding */ mdiBookMusic,\n/* harmony export */   \"mdiBookOpen\": () => /* binding */ mdiBookOpen,\n/* harmony export */   \"mdiBookOpenBlankVariant\": () => /* binding */ mdiBookOpenBlankVariant,\n/* harmony export */   \"mdiBookOpenOutline\": () => /* binding */ mdiBookOpenOutline,\n/* harmony export */   \"mdiBookOpenPageVariant\": () => /* binding */ mdiBookOpenPageVariant,\n/* harmony export */   \"mdiBookOpenPageVariantOutline\": () => /* binding */ mdiBookOpenPageVariantOutline,\n/* harmony export */   \"mdiBookOpenVariant\": () => /* binding */ mdiBookOpenVariant,\n/* harmony export */   \"mdiBookOutline\": () => /* binding */ mdiBookOutline,\n/* harmony export */   \"mdiBookPlay\": () => /* binding */ mdiBookPlay,\n/* harmony export */   \"mdiBookPlayOutline\": () => /* binding */ mdiBookPlayOutline,\n/* harmony export */   \"mdiBookPlus\": () => /* binding */ mdiBookPlus,\n/* harmony export */   \"mdiBookPlusMultiple\": () => /* binding */ mdiBookPlusMultiple,\n/* harmony export */   \"mdiBookPlusMultipleOutline\": () => /* binding */ mdiBookPlusMultipleOutline,\n/* harmony export */   \"mdiBookRemove\": () => /* binding */ mdiBookRemove,\n/* harmony export */   \"mdiBookRemoveMultiple\": () => /* binding */ mdiBookRemoveMultiple,\n/* harmony export */   \"mdiBookRemoveMultipleOutline\": () => /* binding */ mdiBookRemoveMultipleOutline,\n/* harmony export */   \"mdiBookSearch\": () => /* binding */ mdiBookSearch,\n/* harmony export */   \"mdiBookSearchOutline\": () => /* binding */ mdiBookSearchOutline,\n/* harmony export */   \"mdiBookVariant\": () => /* binding */ mdiBookVariant,\n/* harmony export */   \"mdiBookVariantMultiple\": () => /* binding */ mdiBookVariantMultiple,\n/* harmony export */   \"mdiBookmark\": () => /* binding */ mdiBookmark,\n/* harmony export */   \"mdiBookmarkCheck\": () => /* binding */ mdiBookmarkCheck,\n/* harmony export */   \"mdiBookmarkCheckOutline\": () => /* binding */ mdiBookmarkCheckOutline,\n/* harmony export */   \"mdiBookmarkMinus\": () => /* binding */ mdiBookmarkMinus,\n/* harmony export */   \"mdiBookmarkMinusOutline\": () => /* binding */ mdiBookmarkMinusOutline,\n/* harmony export */   \"mdiBookmarkMultiple\": () => /* binding */ mdiBookmarkMultiple,\n/* harmony export */   \"mdiBookmarkMultipleOutline\": () => /* binding */ mdiBookmarkMultipleOutline,\n/* harmony export */   \"mdiBookmarkMusic\": () => /* binding */ mdiBookmarkMusic,\n/* harmony export */   \"mdiBookmarkMusicOutline\": () => /* binding */ mdiBookmarkMusicOutline,\n/* harmony export */   \"mdiBookmarkOff\": () => /* binding */ mdiBookmarkOff,\n/* harmony export */   \"mdiBookmarkOffOutline\": () => /* binding */ mdiBookmarkOffOutline,\n/* harmony export */   \"mdiBookmarkOutline\": () => /* binding */ mdiBookmarkOutline,\n/* harmony export */   \"mdiBookmarkPlus\": () => /* binding */ mdiBookmarkPlus,\n/* harmony export */   \"mdiBookmarkPlusOutline\": () => /* binding */ mdiBookmarkPlusOutline,\n/* harmony export */   \"mdiBookmarkRemove\": () => /* binding */ mdiBookmarkRemove,\n/* harmony export */   \"mdiBookmarkRemoveOutline\": () => /* binding */ mdiBookmarkRemoveOutline,\n/* harmony export */   \"mdiBookshelf\": () => /* binding */ mdiBookshelf,\n/* harmony export */   \"mdiBoomGate\": () => /* binding */ mdiBoomGate,\n/* harmony export */   \"mdiBoomGateAlert\": () => /* binding */ mdiBoomGateAlert,\n/* harmony export */   \"mdiBoomGateAlertOutline\": () => /* binding */ mdiBoomGateAlertOutline,\n/* harmony export */   \"mdiBoomGateDown\": () => /* binding */ mdiBoomGateDown,\n/* harmony export */   \"mdiBoomGateDownOutline\": () => /* binding */ mdiBoomGateDownOutline,\n/* harmony export */   \"mdiBoomGateOutline\": () => /* binding */ mdiBoomGateOutline,\n/* harmony export */   \"mdiBoomGateUp\": () => /* binding */ mdiBoomGateUp,\n/* harmony export */   \"mdiBoomGateUpOutline\": () => /* binding */ mdiBoomGateUpOutline,\n/* harmony export */   \"mdiBoombox\": () => /* binding */ mdiBoombox,\n/* harmony export */   \"mdiBoomerang\": () => /* binding */ mdiBoomerang,\n/* harmony export */   \"mdiBootstrap\": () => /* binding */ mdiBootstrap,\n/* harmony export */   \"mdiBorderAll\": () => /* binding */ mdiBorderAll,\n/* harmony export */   \"mdiBorderAllVariant\": () => /* binding */ mdiBorderAllVariant,\n/* harmony export */   \"mdiBorderBottom\": () => /* binding */ mdiBorderBottom,\n/* harmony export */   \"mdiBorderBottomVariant\": () => /* binding */ mdiBorderBottomVariant,\n/* harmony export */   \"mdiBorderColor\": () => /* binding */ mdiBorderColor,\n/* harmony export */   \"mdiBorderHorizontal\": () => /* binding */ mdiBorderHorizontal,\n/* harmony export */   \"mdiBorderInside\": () => /* binding */ mdiBorderInside,\n/* harmony export */   \"mdiBorderLeft\": () => /* binding */ mdiBorderLeft,\n/* harmony export */   \"mdiBorderLeftVariant\": () => /* binding */ mdiBorderLeftVariant,\n/* harmony export */   \"mdiBorderNone\": () => /* binding */ mdiBorderNone,\n/* harmony export */   \"mdiBorderNoneVariant\": () => /* binding */ mdiBorderNoneVariant,\n/* harmony export */   \"mdiBorderOutside\": () => /* binding */ mdiBorderOutside,\n/* harmony export */   \"mdiBorderRight\": () => /* binding */ mdiBorderRight,\n/* harmony export */   \"mdiBorderRightVariant\": () => /* binding */ mdiBorderRightVariant,\n/* harmony export */   \"mdiBorderStyle\": () => /* binding */ mdiBorderStyle,\n/* harmony export */   \"mdiBorderTop\": () => /* binding */ mdiBorderTop,\n/* harmony export */   \"mdiBorderTopVariant\": () => /* binding */ mdiBorderTopVariant,\n/* harmony export */   \"mdiBorderVertical\": () => /* binding */ mdiBorderVertical,\n/* harmony export */   \"mdiBottleSoda\": () => /* binding */ mdiBottleSoda,\n/* harmony export */   \"mdiBottleSodaClassic\": () => /* binding */ mdiBottleSodaClassic,\n/* harmony export */   \"mdiBottleSodaClassicOutline\": () => /* binding */ mdiBottleSodaClassicOutline,\n/* harmony export */   \"mdiBottleSodaOutline\": () => /* binding */ mdiBottleSodaOutline,\n/* harmony export */   \"mdiBottleTonic\": () => /* binding */ mdiBottleTonic,\n/* harmony export */   \"mdiBottleTonicOutline\": () => /* binding */ mdiBottleTonicOutline,\n/* harmony export */   \"mdiBottleTonicPlus\": () => /* binding */ mdiBottleTonicPlus,\n/* harmony export */   \"mdiBottleTonicPlusOutline\": () => /* binding */ mdiBottleTonicPlusOutline,\n/* harmony export */   \"mdiBottleTonicSkull\": () => /* binding */ mdiBottleTonicSkull,\n/* harmony export */   \"mdiBottleTonicSkullOutline\": () => /* binding */ mdiBottleTonicSkullOutline,\n/* harmony export */   \"mdiBottleWine\": () => /* binding */ mdiBottleWine,\n/* harmony export */   \"mdiBottleWineOutline\": () => /* binding */ mdiBottleWineOutline,\n/* harmony export */   \"mdiBowTie\": () => /* binding */ mdiBowTie,\n/* harmony export */   \"mdiBowl\": () => /* binding */ mdiBowl,\n/* harmony export */   \"mdiBowlMix\": () => /* binding */ mdiBowlMix,\n/* harmony export */   \"mdiBowlMixOutline\": () => /* binding */ mdiBowlMixOutline,\n/* harmony export */   \"mdiBowlOutline\": () => /* binding */ mdiBowlOutline,\n/* harmony export */   \"mdiBowling\": () => /* binding */ mdiBowling,\n/* harmony export */   \"mdiBox\": () => /* binding */ mdiBox,\n/* harmony export */   \"mdiBoxCutter\": () => /* binding */ mdiBoxCutter,\n/* harmony export */   \"mdiBoxCutterOff\": () => /* binding */ mdiBoxCutterOff,\n/* harmony export */   \"mdiBoxShadow\": () => /* binding */ mdiBoxShadow,\n/* harmony export */   \"mdiBoxingGlove\": () => /* binding */ mdiBoxingGlove,\n/* harmony export */   \"mdiBraille\": () => /* binding */ mdiBraille,\n/* harmony export */   \"mdiBrain\": () => /* binding */ mdiBrain,\n/* harmony export */   \"mdiBreadSlice\": () => /* binding */ mdiBreadSlice,\n/* harmony export */   \"mdiBreadSliceOutline\": () => /* binding */ mdiBreadSliceOutline,\n/* harmony export */   \"mdiBridge\": () => /* binding */ mdiBridge,\n/* harmony export */   \"mdiBriefcase\": () => /* binding */ mdiBriefcase,\n/* harmony export */   \"mdiBriefcaseAccount\": () => /* binding */ mdiBriefcaseAccount,\n/* harmony export */   \"mdiBriefcaseAccountOutline\": () => /* binding */ mdiBriefcaseAccountOutline,\n/* harmony export */   \"mdiBriefcaseCheck\": () => /* binding */ mdiBriefcaseCheck,\n/* harmony export */   \"mdiBriefcaseCheckOutline\": () => /* binding */ mdiBriefcaseCheckOutline,\n/* harmony export */   \"mdiBriefcaseClock\": () => /* binding */ mdiBriefcaseClock,\n/* harmony export */   \"mdiBriefcaseClockOutline\": () => /* binding */ mdiBriefcaseClockOutline,\n/* harmony export */   \"mdiBriefcaseDownload\": () => /* binding */ mdiBriefcaseDownload,\n/* harmony export */   \"mdiBriefcaseDownloadOutline\": () => /* binding */ mdiBriefcaseDownloadOutline,\n/* harmony export */   \"mdiBriefcaseEdit\": () => /* binding */ mdiBriefcaseEdit,\n/* harmony export */   \"mdiBriefcaseEditOutline\": () => /* binding */ mdiBriefcaseEditOutline,\n/* harmony export */   \"mdiBriefcaseMinus\": () => /* binding */ mdiBriefcaseMinus,\n/* harmony export */   \"mdiBriefcaseMinusOutline\": () => /* binding */ mdiBriefcaseMinusOutline,\n/* harmony export */   \"mdiBriefcaseOutline\": () => /* binding */ mdiBriefcaseOutline,\n/* harmony export */   \"mdiBriefcasePlus\": () => /* binding */ mdiBriefcasePlus,\n/* harmony export */   \"mdiBriefcasePlusOutline\": () => /* binding */ mdiBriefcasePlusOutline,\n/* harmony export */   \"mdiBriefcaseRemove\": () => /* binding */ mdiBriefcaseRemove,\n/* harmony export */   \"mdiBriefcaseRemoveOutline\": () => /* binding */ mdiBriefcaseRemoveOutline,\n/* harmony export */   \"mdiBriefcaseSearch\": () => /* binding */ mdiBriefcaseSearch,\n/* harmony export */   \"mdiBriefcaseSearchOutline\": () => /* binding */ mdiBriefcaseSearchOutline,\n/* harmony export */   \"mdiBriefcaseUpload\": () => /* binding */ mdiBriefcaseUpload,\n/* harmony export */   \"mdiBriefcaseUploadOutline\": () => /* binding */ mdiBriefcaseUploadOutline,\n/* harmony export */   \"mdiBriefcaseVariant\": () => /* binding */ mdiBriefcaseVariant,\n/* harmony export */   \"mdiBriefcaseVariantOutline\": () => /* binding */ mdiBriefcaseVariantOutline,\n/* harmony export */   \"mdiBrightness1\": () => /* binding */ mdiBrightness1,\n/* harmony export */   \"mdiBrightness2\": () => /* binding */ mdiBrightness2,\n/* harmony export */   \"mdiBrightness3\": () => /* binding */ mdiBrightness3,\n/* harmony export */   \"mdiBrightness4\": () => /* binding */ mdiBrightness4,\n/* harmony export */   \"mdiBrightness5\": () => /* binding */ mdiBrightness5,\n/* harmony export */   \"mdiBrightness6\": () => /* binding */ mdiBrightness6,\n/* harmony export */   \"mdiBrightness7\": () => /* binding */ mdiBrightness7,\n/* harmony export */   \"mdiBrightnessAuto\": () => /* binding */ mdiBrightnessAuto,\n/* harmony export */   \"mdiBrightnessPercent\": () => /* binding */ mdiBrightnessPercent,\n/* harmony export */   \"mdiBroom\": () => /* binding */ mdiBroom,\n/* harmony export */   \"mdiBrush\": () => /* binding */ mdiBrush,\n/* harmony export */   \"mdiBucket\": () => /* binding */ mdiBucket,\n/* harmony export */   \"mdiBucketOutline\": () => /* binding */ mdiBucketOutline,\n/* harmony export */   \"mdiBuddhism\": () => /* binding */ mdiBuddhism,\n/* harmony export */   \"mdiBuffer\": () => /* binding */ mdiBuffer,\n/* harmony export */   \"mdiBuffet\": () => /* binding */ mdiBuffet,\n/* harmony export */   \"mdiBug\": () => /* binding */ mdiBug,\n/* harmony export */   \"mdiBugCheck\": () => /* binding */ mdiBugCheck,\n/* harmony export */   \"mdiBugCheckOutline\": () => /* binding */ mdiBugCheckOutline,\n/* harmony export */   \"mdiBugOutline\": () => /* binding */ mdiBugOutline,\n/* harmony export */   \"mdiBugle\": () => /* binding */ mdiBugle,\n/* harmony export */   \"mdiBulldozer\": () => /* binding */ mdiBulldozer,\n/* harmony export */   \"mdiBullet\": () => /* binding */ mdiBullet,\n/* harmony export */   \"mdiBulletinBoard\": () => /* binding */ mdiBulletinBoard,\n/* harmony export */   \"mdiBullhorn\": () => /* binding */ mdiBullhorn,\n/* harmony export */   \"mdiBullhornOutline\": () => /* binding */ mdiBullhornOutline,\n/* harmony export */   \"mdiBullseye\": () => /* binding */ mdiBullseye,\n/* harmony export */   \"mdiBullseyeArrow\": () => /* binding */ mdiBullseyeArrow,\n/* harmony export */   \"mdiBulma\": () => /* binding */ mdiBulma,\n/* harmony export */   \"mdiBunkBed\": () => /* binding */ mdiBunkBed,\n/* harmony export */   \"mdiBunkBedOutline\": () => /* binding */ mdiBunkBedOutline,\n/* harmony export */   \"mdiBus\": () => /* binding */ mdiBus,\n/* harmony export */   \"mdiBusAlert\": () => /* binding */ mdiBusAlert,\n/* harmony export */   \"mdiBusArticulatedEnd\": () => /* binding */ mdiBusArticulatedEnd,\n/* harmony export */   \"mdiBusArticulatedFront\": () => /* binding */ mdiBusArticulatedFront,\n/* harmony export */   \"mdiBusClock\": () => /* binding */ mdiBusClock,\n/* harmony export */   \"mdiBusDoubleDecker\": () => /* binding */ mdiBusDoubleDecker,\n/* harmony export */   \"mdiBusMarker\": () => /* binding */ mdiBusMarker,\n/* harmony export */   \"mdiBusMultiple\": () => /* binding */ mdiBusMultiple,\n/* harmony export */   \"mdiBusSchool\": () => /* binding */ mdiBusSchool,\n/* harmony export */   \"mdiBusSide\": () => /* binding */ mdiBusSide,\n/* harmony export */   \"mdiBusStop\": () => /* binding */ mdiBusStop,\n/* harmony export */   \"mdiBusStopCovered\": () => /* binding */ mdiBusStopCovered,\n/* harmony export */   \"mdiBusStopUncovered\": () => /* binding */ mdiBusStopUncovered,\n/* harmony export */   \"mdiButterfly\": () => /* binding */ mdiButterfly,\n/* harmony export */   \"mdiButterflyOutline\": () => /* binding */ mdiButterflyOutline,\n/* harmony export */   \"mdiCableData\": () => /* binding */ mdiCableData,\n/* harmony export */   \"mdiCached\": () => /* binding */ mdiCached,\n/* harmony export */   \"mdiCactus\": () => /* binding */ mdiCactus,\n/* harmony export */   \"mdiCake\": () => /* binding */ mdiCake,\n/* harmony export */   \"mdiCakeLayered\": () => /* binding */ mdiCakeLayered,\n/* harmony export */   \"mdiCakeVariant\": () => /* binding */ mdiCakeVariant,\n/* harmony export */   \"mdiCalculator\": () => /* binding */ mdiCalculator,\n/* harmony export */   \"mdiCalculatorVariant\": () => /* binding */ mdiCalculatorVariant,\n/* harmony export */   \"mdiCalculatorVariantOutline\": () => /* binding */ mdiCalculatorVariantOutline,\n/* harmony export */   \"mdiCalendar\": () => /* binding */ mdiCalendar,\n/* harmony export */   \"mdiCalendarAccount\": () => /* binding */ mdiCalendarAccount,\n/* harmony export */   \"mdiCalendarAccountOutline\": () => /* binding */ mdiCalendarAccountOutline,\n/* harmony export */   \"mdiCalendarAlert\": () => /* binding */ mdiCalendarAlert,\n/* harmony export */   \"mdiCalendarArrowLeft\": () => /* binding */ mdiCalendarArrowLeft,\n/* harmony export */   \"mdiCalendarArrowRight\": () => /* binding */ mdiCalendarArrowRight,\n/* harmony export */   \"mdiCalendarBlank\": () => /* binding */ mdiCalendarBlank,\n/* harmony export */   \"mdiCalendarBlankMultiple\": () => /* binding */ mdiCalendarBlankMultiple,\n/* harmony export */   \"mdiCalendarBlankOutline\": () => /* binding */ mdiCalendarBlankOutline,\n/* harmony export */   \"mdiCalendarCheck\": () => /* binding */ mdiCalendarCheck,\n/* harmony export */   \"mdiCalendarCheckOutline\": () => /* binding */ mdiCalendarCheckOutline,\n/* harmony export */   \"mdiCalendarClock\": () => /* binding */ mdiCalendarClock,\n/* harmony export */   \"mdiCalendarCursor\": () => /* binding */ mdiCalendarCursor,\n/* harmony export */   \"mdiCalendarEdit\": () => /* binding */ mdiCalendarEdit,\n/* harmony export */   \"mdiCalendarExport\": () => /* binding */ mdiCalendarExport,\n/* harmony export */   \"mdiCalendarHeart\": () => /* binding */ mdiCalendarHeart,\n/* harmony export */   \"mdiCalendarImport\": () => /* binding */ mdiCalendarImport,\n/* harmony export */   \"mdiCalendarMinus\": () => /* binding */ mdiCalendarMinus,\n/* harmony export */   \"mdiCalendarMonth\": () => /* binding */ mdiCalendarMonth,\n/* harmony export */   \"mdiCalendarMonthOutline\": () => /* binding */ mdiCalendarMonthOutline,\n/* harmony export */   \"mdiCalendarMultiple\": () => /* binding */ mdiCalendarMultiple,\n/* harmony export */   \"mdiCalendarMultipleCheck\": () => /* binding */ mdiCalendarMultipleCheck,\n/* harmony export */   \"mdiCalendarMultiselect\": () => /* binding */ mdiCalendarMultiselect,\n/* harmony export */   \"mdiCalendarOutline\": () => /* binding */ mdiCalendarOutline,\n/* harmony export */   \"mdiCalendarPlus\": () => /* binding */ mdiCalendarPlus,\n/* harmony export */   \"mdiCalendarQuestion\": () => /* binding */ mdiCalendarQuestion,\n/* harmony export */   \"mdiCalendarRange\": () => /* binding */ mdiCalendarRange,\n/* harmony export */   \"mdiCalendarRangeOutline\": () => /* binding */ mdiCalendarRangeOutline,\n/* harmony export */   \"mdiCalendarRefresh\": () => /* binding */ mdiCalendarRefresh,\n/* harmony export */   \"mdiCalendarRefreshOutline\": () => /* binding */ mdiCalendarRefreshOutline,\n/* harmony export */   \"mdiCalendarRemove\": () => /* binding */ mdiCalendarRemove,\n/* harmony export */   \"mdiCalendarRemoveOutline\": () => /* binding */ mdiCalendarRemoveOutline,\n/* harmony export */   \"mdiCalendarSearch\": () => /* binding */ mdiCalendarSearch,\n/* harmony export */   \"mdiCalendarStar\": () => /* binding */ mdiCalendarStar,\n/* harmony export */   \"mdiCalendarSync\": () => /* binding */ mdiCalendarSync,\n/* harmony export */   \"mdiCalendarSyncOutline\": () => /* binding */ mdiCalendarSyncOutline,\n/* harmony export */   \"mdiCalendarText\": () => /* binding */ mdiCalendarText,\n/* harmony export */   \"mdiCalendarTextOutline\": () => /* binding */ mdiCalendarTextOutline,\n/* harmony export */   \"mdiCalendarToday\": () => /* binding */ mdiCalendarToday,\n/* harmony export */   \"mdiCalendarWeek\": () => /* binding */ mdiCalendarWeek,\n/* harmony export */   \"mdiCalendarWeekBegin\": () => /* binding */ mdiCalendarWeekBegin,\n/* harmony export */   \"mdiCalendarWeekend\": () => /* binding */ mdiCalendarWeekend,\n/* harmony export */   \"mdiCalendarWeekendOutline\": () => /* binding */ mdiCalendarWeekendOutline,\n/* harmony export */   \"mdiCallMade\": () => /* binding */ mdiCallMade,\n/* harmony export */   \"mdiCallMerge\": () => /* binding */ mdiCallMerge,\n/* harmony export */   \"mdiCallMissed\": () => /* binding */ mdiCallMissed,\n/* harmony export */   \"mdiCallReceived\": () => /* binding */ mdiCallReceived,\n/* harmony export */   \"mdiCallSplit\": () => /* binding */ mdiCallSplit,\n/* harmony export */   \"mdiCamcorder\": () => /* binding */ mdiCamcorder,\n/* harmony export */   \"mdiCamcorderOff\": () => /* binding */ mdiCamcorderOff,\n/* harmony export */   \"mdiCamera\": () => /* binding */ mdiCamera,\n/* harmony export */   \"mdiCameraAccount\": () => /* binding */ mdiCameraAccount,\n/* harmony export */   \"mdiCameraBurst\": () => /* binding */ mdiCameraBurst,\n/* harmony export */   \"mdiCameraControl\": () => /* binding */ mdiCameraControl,\n/* harmony export */   \"mdiCameraEnhance\": () => /* binding */ mdiCameraEnhance,\n/* harmony export */   \"mdiCameraEnhanceOutline\": () => /* binding */ mdiCameraEnhanceOutline,\n/* harmony export */   \"mdiCameraFlip\": () => /* binding */ mdiCameraFlip,\n/* harmony export */   \"mdiCameraFlipOutline\": () => /* binding */ mdiCameraFlipOutline,\n/* harmony export */   \"mdiCameraFront\": () => /* binding */ mdiCameraFront,\n/* harmony export */   \"mdiCameraFrontVariant\": () => /* binding */ mdiCameraFrontVariant,\n/* harmony export */   \"mdiCameraGopro\": () => /* binding */ mdiCameraGopro,\n/* harmony export */   \"mdiCameraImage\": () => /* binding */ mdiCameraImage,\n/* harmony export */   \"mdiCameraIris\": () => /* binding */ mdiCameraIris,\n/* harmony export */   \"mdiCameraMeteringCenter\": () => /* binding */ mdiCameraMeteringCenter,\n/* harmony export */   \"mdiCameraMeteringMatrix\": () => /* binding */ mdiCameraMeteringMatrix,\n/* harmony export */   \"mdiCameraMeteringPartial\": () => /* binding */ mdiCameraMeteringPartial,\n/* harmony export */   \"mdiCameraMeteringSpot\": () => /* binding */ mdiCameraMeteringSpot,\n/* harmony export */   \"mdiCameraOff\": () => /* binding */ mdiCameraOff,\n/* harmony export */   \"mdiCameraOutline\": () => /* binding */ mdiCameraOutline,\n/* harmony export */   \"mdiCameraPartyMode\": () => /* binding */ mdiCameraPartyMode,\n/* harmony export */   \"mdiCameraPlus\": () => /* binding */ mdiCameraPlus,\n/* harmony export */   \"mdiCameraPlusOutline\": () => /* binding */ mdiCameraPlusOutline,\n/* harmony export */   \"mdiCameraRear\": () => /* binding */ mdiCameraRear,\n/* harmony export */   \"mdiCameraRearVariant\": () => /* binding */ mdiCameraRearVariant,\n/* harmony export */   \"mdiCameraRetake\": () => /* binding */ mdiCameraRetake,\n/* harmony export */   \"mdiCameraRetakeOutline\": () => /* binding */ mdiCameraRetakeOutline,\n/* harmony export */   \"mdiCameraSwitch\": () => /* binding */ mdiCameraSwitch,\n/* harmony export */   \"mdiCameraSwitchOutline\": () => /* binding */ mdiCameraSwitchOutline,\n/* harmony export */   \"mdiCameraTimer\": () => /* binding */ mdiCameraTimer,\n/* harmony export */   \"mdiCameraWireless\": () => /* binding */ mdiCameraWireless,\n/* harmony export */   \"mdiCameraWirelessOutline\": () => /* binding */ mdiCameraWirelessOutline,\n/* harmony export */   \"mdiCampfire\": () => /* binding */ mdiCampfire,\n/* harmony export */   \"mdiCancel\": () => /* binding */ mdiCancel,\n/* harmony export */   \"mdiCandle\": () => /* binding */ mdiCandle,\n/* harmony export */   \"mdiCandycane\": () => /* binding */ mdiCandycane,\n/* harmony export */   \"mdiCannabis\": () => /* binding */ mdiCannabis,\n/* harmony export */   \"mdiCapsLock\": () => /* binding */ mdiCapsLock,\n/* harmony export */   \"mdiCar\": () => /* binding */ mdiCar,\n/* harmony export */   \"mdiCar2Plus\": () => /* binding */ mdiCar2Plus,\n/* harmony export */   \"mdiCar3Plus\": () => /* binding */ mdiCar3Plus,\n/* harmony export */   \"mdiCarArrowLeft\": () => /* binding */ mdiCarArrowLeft,\n/* harmony export */   \"mdiCarArrowRight\": () => /* binding */ mdiCarArrowRight,\n/* harmony export */   \"mdiCarBack\": () => /* binding */ mdiCarBack,\n/* harmony export */   \"mdiCarBattery\": () => /* binding */ mdiCarBattery,\n/* harmony export */   \"mdiCarBrakeAbs\": () => /* binding */ mdiCarBrakeAbs,\n/* harmony export */   \"mdiCarBrakeAlert\": () => /* binding */ mdiCarBrakeAlert,\n/* harmony export */   \"mdiCarBrakeHold\": () => /* binding */ mdiCarBrakeHold,\n/* harmony export */   \"mdiCarBrakeParking\": () => /* binding */ mdiCarBrakeParking,\n/* harmony export */   \"mdiCarBrakeRetarder\": () => /* binding */ mdiCarBrakeRetarder,\n/* harmony export */   \"mdiCarChildSeat\": () => /* binding */ mdiCarChildSeat,\n/* harmony export */   \"mdiCarClutch\": () => /* binding */ mdiCarClutch,\n/* harmony export */   \"mdiCarCog\": () => /* binding */ mdiCarCog,\n/* harmony export */   \"mdiCarConnected\": () => /* binding */ mdiCarConnected,\n/* harmony export */   \"mdiCarConvertible\": () => /* binding */ mdiCarConvertible,\n/* harmony export */   \"mdiCarCoolantLevel\": () => /* binding */ mdiCarCoolantLevel,\n/* harmony export */   \"mdiCarCruiseControl\": () => /* binding */ mdiCarCruiseControl,\n/* harmony export */   \"mdiCarDefrostFront\": () => /* binding */ mdiCarDefrostFront,\n/* harmony export */   \"mdiCarDefrostRear\": () => /* binding */ mdiCarDefrostRear,\n/* harmony export */   \"mdiCarDoor\": () => /* binding */ mdiCarDoor,\n/* harmony export */   \"mdiCarDoorLock\": () => /* binding */ mdiCarDoorLock,\n/* harmony export */   \"mdiCarElectric\": () => /* binding */ mdiCarElectric,\n/* harmony export */   \"mdiCarElectricOutline\": () => /* binding */ mdiCarElectricOutline,\n/* harmony export */   \"mdiCarEmergency\": () => /* binding */ mdiCarEmergency,\n/* harmony export */   \"mdiCarEsp\": () => /* binding */ mdiCarEsp,\n/* harmony export */   \"mdiCarEstate\": () => /* binding */ mdiCarEstate,\n/* harmony export */   \"mdiCarHatchback\": () => /* binding */ mdiCarHatchback,\n/* harmony export */   \"mdiCarInfo\": () => /* binding */ mdiCarInfo,\n/* harmony export */   \"mdiCarKey\": () => /* binding */ mdiCarKey,\n/* harmony export */   \"mdiCarLiftedPickup\": () => /* binding */ mdiCarLiftedPickup,\n/* harmony export */   \"mdiCarLightDimmed\": () => /* binding */ mdiCarLightDimmed,\n/* harmony export */   \"mdiCarLightFog\": () => /* binding */ mdiCarLightFog,\n/* harmony export */   \"mdiCarLightHigh\": () => /* binding */ mdiCarLightHigh,\n/* harmony export */   \"mdiCarLimousine\": () => /* binding */ mdiCarLimousine,\n/* harmony export */   \"mdiCarMultiple\": () => /* binding */ mdiCarMultiple,\n/* harmony export */   \"mdiCarOff\": () => /* binding */ mdiCarOff,\n/* harmony export */   \"mdiCarOutline\": () => /* binding */ mdiCarOutline,\n/* harmony export */   \"mdiCarParkingLights\": () => /* binding */ mdiCarParkingLights,\n/* harmony export */   \"mdiCarPickup\": () => /* binding */ mdiCarPickup,\n/* harmony export */   \"mdiCarSeat\": () => /* binding */ mdiCarSeat,\n/* harmony export */   \"mdiCarSeatCooler\": () => /* binding */ mdiCarSeatCooler,\n/* harmony export */   \"mdiCarSeatHeater\": () => /* binding */ mdiCarSeatHeater,\n/* harmony export */   \"mdiCarSettings\": () => /* binding */ mdiCarSettings,\n/* harmony export */   \"mdiCarShiftPattern\": () => /* binding */ mdiCarShiftPattern,\n/* harmony export */   \"mdiCarSide\": () => /* binding */ mdiCarSide,\n/* harmony export */   \"mdiCarSports\": () => /* binding */ mdiCarSports,\n/* harmony export */   \"mdiCarTireAlert\": () => /* binding */ mdiCarTireAlert,\n/* harmony export */   \"mdiCarTractionControl\": () => /* binding */ mdiCarTractionControl,\n/* harmony export */   \"mdiCarTurbocharger\": () => /* binding */ mdiCarTurbocharger,\n/* harmony export */   \"mdiCarWash\": () => /* binding */ mdiCarWash,\n/* harmony export */   \"mdiCarWindshield\": () => /* binding */ mdiCarWindshield,\n/* harmony export */   \"mdiCarWindshieldOutline\": () => /* binding */ mdiCarWindshieldOutline,\n/* harmony export */   \"mdiCarabiner\": () => /* binding */ mdiCarabiner,\n/* harmony export */   \"mdiCaravan\": () => /* binding */ mdiCaravan,\n/* harmony export */   \"mdiCard\": () => /* binding */ mdiCard,\n/* harmony export */   \"mdiCardAccountDetails\": () => /* binding */ mdiCardAccountDetails,\n/* harmony export */   \"mdiCardAccountDetailsOutline\": () => /* binding */ mdiCardAccountDetailsOutline,\n/* harmony export */   \"mdiCardAccountDetailsStar\": () => /* binding */ mdiCardAccountDetailsStar,\n/* harmony export */   \"mdiCardAccountDetailsStarOutline\": () => /* binding */ mdiCardAccountDetailsStarOutline,\n/* harmony export */   \"mdiCardAccountMail\": () => /* binding */ mdiCardAccountMail,\n/* harmony export */   \"mdiCardAccountMailOutline\": () => /* binding */ mdiCardAccountMailOutline,\n/* harmony export */   \"mdiCardAccountPhone\": () => /* binding */ mdiCardAccountPhone,\n/* harmony export */   \"mdiCardAccountPhoneOutline\": () => /* binding */ mdiCardAccountPhoneOutline,\n/* harmony export */   \"mdiCardBulleted\": () => /* binding */ mdiCardBulleted,\n/* harmony export */   \"mdiCardBulletedOff\": () => /* binding */ mdiCardBulletedOff,\n/* harmony export */   \"mdiCardBulletedOffOutline\": () => /* binding */ mdiCardBulletedOffOutline,\n/* harmony export */   \"mdiCardBulletedOutline\": () => /* binding */ mdiCardBulletedOutline,\n/* harmony export */   \"mdiCardBulletedSettings\": () => /* binding */ mdiCardBulletedSettings,\n/* harmony export */   \"mdiCardBulletedSettingsOutline\": () => /* binding */ mdiCardBulletedSettingsOutline,\n/* harmony export */   \"mdiCardMinus\": () => /* binding */ mdiCardMinus,\n/* harmony export */   \"mdiCardMinusOutline\": () => /* binding */ mdiCardMinusOutline,\n/* harmony export */   \"mdiCardOff\": () => /* binding */ mdiCardOff,\n/* harmony export */   \"mdiCardOffOutline\": () => /* binding */ mdiCardOffOutline,\n/* harmony export */   \"mdiCardOutline\": () => /* binding */ mdiCardOutline,\n/* harmony export */   \"mdiCardPlus\": () => /* binding */ mdiCardPlus,\n/* harmony export */   \"mdiCardPlusOutline\": () => /* binding */ mdiCardPlusOutline,\n/* harmony export */   \"mdiCardRemove\": () => /* binding */ mdiCardRemove,\n/* harmony export */   \"mdiCardRemoveOutline\": () => /* binding */ mdiCardRemoveOutline,\n/* harmony export */   \"mdiCardSearch\": () => /* binding */ mdiCardSearch,\n/* harmony export */   \"mdiCardSearchOutline\": () => /* binding */ mdiCardSearchOutline,\n/* harmony export */   \"mdiCardText\": () => /* binding */ mdiCardText,\n/* harmony export */   \"mdiCardTextOutline\": () => /* binding */ mdiCardTextOutline,\n/* harmony export */   \"mdiCards\": () => /* binding */ mdiCards,\n/* harmony export */   \"mdiCardsClub\": () => /* binding */ mdiCardsClub,\n/* harmony export */   \"mdiCardsDiamond\": () => /* binding */ mdiCardsDiamond,\n/* harmony export */   \"mdiCardsDiamondOutline\": () => /* binding */ mdiCardsDiamondOutline,\n/* harmony export */   \"mdiCardsHeart\": () => /* binding */ mdiCardsHeart,\n/* harmony export */   \"mdiCardsOutline\": () => /* binding */ mdiCardsOutline,\n/* harmony export */   \"mdiCardsPlayingOutline\": () => /* binding */ mdiCardsPlayingOutline,\n/* harmony export */   \"mdiCardsSpade\": () => /* binding */ mdiCardsSpade,\n/* harmony export */   \"mdiCardsVariant\": () => /* binding */ mdiCardsVariant,\n/* harmony export */   \"mdiCarrot\": () => /* binding */ mdiCarrot,\n/* harmony export */   \"mdiCart\": () => /* binding */ mdiCart,\n/* harmony export */   \"mdiCartArrowDown\": () => /* binding */ mdiCartArrowDown,\n/* harmony export */   \"mdiCartArrowRight\": () => /* binding */ mdiCartArrowRight,\n/* harmony export */   \"mdiCartArrowUp\": () => /* binding */ mdiCartArrowUp,\n/* harmony export */   \"mdiCartCheck\": () => /* binding */ mdiCartCheck,\n/* harmony export */   \"mdiCartMinus\": () => /* binding */ mdiCartMinus,\n/* harmony export */   \"mdiCartOff\": () => /* binding */ mdiCartOff,\n/* harmony export */   \"mdiCartOutline\": () => /* binding */ mdiCartOutline,\n/* harmony export */   \"mdiCartPlus\": () => /* binding */ mdiCartPlus,\n/* harmony export */   \"mdiCartRemove\": () => /* binding */ mdiCartRemove,\n/* harmony export */   \"mdiCartVariant\": () => /* binding */ mdiCartVariant,\n/* harmony export */   \"mdiCaseSensitiveAlt\": () => /* binding */ mdiCaseSensitiveAlt,\n/* harmony export */   \"mdiCash\": () => /* binding */ mdiCash,\n/* harmony export */   \"mdiCash100\": () => /* binding */ mdiCash100,\n/* harmony export */   \"mdiCashCheck\": () => /* binding */ mdiCashCheck,\n/* harmony export */   \"mdiCashLock\": () => /* binding */ mdiCashLock,\n/* harmony export */   \"mdiCashLockOpen\": () => /* binding */ mdiCashLockOpen,\n/* harmony export */   \"mdiCashMarker\": () => /* binding */ mdiCashMarker,\n/* harmony export */   \"mdiCashMinus\": () => /* binding */ mdiCashMinus,\n/* harmony export */   \"mdiCashMultiple\": () => /* binding */ mdiCashMultiple,\n/* harmony export */   \"mdiCashPlus\": () => /* binding */ mdiCashPlus,\n/* harmony export */   \"mdiCashRefund\": () => /* binding */ mdiCashRefund,\n/* harmony export */   \"mdiCashRegister\": () => /* binding */ mdiCashRegister,\n/* harmony export */   \"mdiCashRemove\": () => /* binding */ mdiCashRemove,\n/* harmony export */   \"mdiCashUsd\": () => /* binding */ mdiCashUsd,\n/* harmony export */   \"mdiCashUsdOutline\": () => /* binding */ mdiCashUsdOutline,\n/* harmony export */   \"mdiCassette\": () => /* binding */ mdiCassette,\n/* harmony export */   \"mdiCast\": () => /* binding */ mdiCast,\n/* harmony export */   \"mdiCastAudio\": () => /* binding */ mdiCastAudio,\n/* harmony export */   \"mdiCastConnected\": () => /* binding */ mdiCastConnected,\n/* harmony export */   \"mdiCastEducation\": () => /* binding */ mdiCastEducation,\n/* harmony export */   \"mdiCastOff\": () => /* binding */ mdiCastOff,\n/* harmony export */   \"mdiCastle\": () => /* binding */ mdiCastle,\n/* harmony export */   \"mdiCat\": () => /* binding */ mdiCat,\n/* harmony export */   \"mdiCctv\": () => /* binding */ mdiCctv,\n/* harmony export */   \"mdiCeilingLight\": () => /* binding */ mdiCeilingLight,\n/* harmony export */   \"mdiCellphone\": () => /* binding */ mdiCellphone,\n/* harmony export */   \"mdiCellphoneAndroid\": () => /* binding */ mdiCellphoneAndroid,\n/* harmony export */   \"mdiCellphoneArrowDown\": () => /* binding */ mdiCellphoneArrowDown,\n/* harmony export */   \"mdiCellphoneBasic\": () => /* binding */ mdiCellphoneBasic,\n/* harmony export */   \"mdiCellphoneCharging\": () => /* binding */ mdiCellphoneCharging,\n/* harmony export */   \"mdiCellphoneCog\": () => /* binding */ mdiCellphoneCog,\n/* harmony export */   \"mdiCellphoneDock\": () => /* binding */ mdiCellphoneDock,\n/* harmony export */   \"mdiCellphoneErase\": () => /* binding */ mdiCellphoneErase,\n/* harmony export */   \"mdiCellphoneInformation\": () => /* binding */ mdiCellphoneInformation,\n/* harmony export */   \"mdiCellphoneIphone\": () => /* binding */ mdiCellphoneIphone,\n/* harmony export */   \"mdiCellphoneKey\": () => /* binding */ mdiCellphoneKey,\n/* harmony export */   \"mdiCellphoneLink\": () => /* binding */ mdiCellphoneLink,\n/* harmony export */   \"mdiCellphoneLinkOff\": () => /* binding */ mdiCellphoneLinkOff,\n/* harmony export */   \"mdiCellphoneLock\": () => /* binding */ mdiCellphoneLock,\n/* harmony export */   \"mdiCellphoneMessage\": () => /* binding */ mdiCellphoneMessage,\n/* harmony export */   \"mdiCellphoneMessageOff\": () => /* binding */ mdiCellphoneMessageOff,\n/* harmony export */   \"mdiCellphoneNfc\": () => /* binding */ mdiCellphoneNfc,\n/* harmony export */   \"mdiCellphoneNfcOff\": () => /* binding */ mdiCellphoneNfcOff,\n/* harmony export */   \"mdiCellphoneOff\": () => /* binding */ mdiCellphoneOff,\n/* harmony export */   \"mdiCellphonePlay\": () => /* binding */ mdiCellphonePlay,\n/* harmony export */   \"mdiCellphoneScreenshot\": () => /* binding */ mdiCellphoneScreenshot,\n/* harmony export */   \"mdiCellphoneSettings\": () => /* binding */ mdiCellphoneSettings,\n/* harmony export */   \"mdiCellphoneSound\": () => /* binding */ mdiCellphoneSound,\n/* harmony export */   \"mdiCellphoneText\": () => /* binding */ mdiCellphoneText,\n/* harmony export */   \"mdiCellphoneWireless\": () => /* binding */ mdiCellphoneWireless,\n/* harmony export */   \"mdiCelticCross\": () => /* binding */ mdiCelticCross,\n/* harmony export */   \"mdiCentos\": () => /* binding */ mdiCentos,\n/* harmony export */   \"mdiCertificate\": () => /* binding */ mdiCertificate,\n/* harmony export */   \"mdiCertificateOutline\": () => /* binding */ mdiCertificateOutline,\n/* harmony export */   \"mdiChairRolling\": () => /* binding */ mdiChairRolling,\n/* harmony export */   \"mdiChairSchool\": () => /* binding */ mdiChairSchool,\n/* harmony export */   \"mdiCharity\": () => /* binding */ mdiCharity,\n/* harmony export */   \"mdiChartArc\": () => /* binding */ mdiChartArc,\n/* harmony export */   \"mdiChartAreaspline\": () => /* binding */ mdiChartAreaspline,\n/* harmony export */   \"mdiChartAreasplineVariant\": () => /* binding */ mdiChartAreasplineVariant,\n/* harmony export */   \"mdiChartBar\": () => /* binding */ mdiChartBar,\n/* harmony export */   \"mdiChartBarStacked\": () => /* binding */ mdiChartBarStacked,\n/* harmony export */   \"mdiChartBellCurve\": () => /* binding */ mdiChartBellCurve,\n/* harmony export */   \"mdiChartBellCurveCumulative\": () => /* binding */ mdiChartBellCurveCumulative,\n/* harmony export */   \"mdiChartBox\": () => /* binding */ mdiChartBox,\n/* harmony export */   \"mdiChartBoxOutline\": () => /* binding */ mdiChartBoxOutline,\n/* harmony export */   \"mdiChartBoxPlusOutline\": () => /* binding */ mdiChartBoxPlusOutline,\n/* harmony export */   \"mdiChartBubble\": () => /* binding */ mdiChartBubble,\n/* harmony export */   \"mdiChartDonut\": () => /* binding */ mdiChartDonut,\n/* harmony export */   \"mdiChartDonutVariant\": () => /* binding */ mdiChartDonutVariant,\n/* harmony export */   \"mdiChartGantt\": () => /* binding */ mdiChartGantt,\n/* harmony export */   \"mdiChartHistogram\": () => /* binding */ mdiChartHistogram,\n/* harmony export */   \"mdiChartLine\": () => /* binding */ mdiChartLine,\n/* harmony export */   \"mdiChartLineStacked\": () => /* binding */ mdiChartLineStacked,\n/* harmony export */   \"mdiChartLineVariant\": () => /* binding */ mdiChartLineVariant,\n/* harmony export */   \"mdiChartMultiline\": () => /* binding */ mdiChartMultiline,\n/* harmony export */   \"mdiChartMultiple\": () => /* binding */ mdiChartMultiple,\n/* harmony export */   \"mdiChartPie\": () => /* binding */ mdiChartPie,\n/* harmony export */   \"mdiChartPpf\": () => /* binding */ mdiChartPpf,\n/* harmony export */   \"mdiChartSankey\": () => /* binding */ mdiChartSankey,\n/* harmony export */   \"mdiChartSankeyVariant\": () => /* binding */ mdiChartSankeyVariant,\n/* harmony export */   \"mdiChartScatterPlot\": () => /* binding */ mdiChartScatterPlot,\n/* harmony export */   \"mdiChartScatterPlotHexbin\": () => /* binding */ mdiChartScatterPlotHexbin,\n/* harmony export */   \"mdiChartTimeline\": () => /* binding */ mdiChartTimeline,\n/* harmony export */   \"mdiChartTimelineVariant\": () => /* binding */ mdiChartTimelineVariant,\n/* harmony export */   \"mdiChartTimelineVariantShimmer\": () => /* binding */ mdiChartTimelineVariantShimmer,\n/* harmony export */   \"mdiChartTree\": () => /* binding */ mdiChartTree,\n/* harmony export */   \"mdiChat\": () => /* binding */ mdiChat,\n/* harmony export */   \"mdiChatAlert\": () => /* binding */ mdiChatAlert,\n/* harmony export */   \"mdiChatAlertOutline\": () => /* binding */ mdiChatAlertOutline,\n/* harmony export */   \"mdiChatMinus\": () => /* binding */ mdiChatMinus,\n/* harmony export */   \"mdiChatMinusOutline\": () => /* binding */ mdiChatMinusOutline,\n/* harmony export */   \"mdiChatOutline\": () => /* binding */ mdiChatOutline,\n/* harmony export */   \"mdiChatPlus\": () => /* binding */ mdiChatPlus,\n/* harmony export */   \"mdiChatPlusOutline\": () => /* binding */ mdiChatPlusOutline,\n/* harmony export */   \"mdiChatProcessing\": () => /* binding */ mdiChatProcessing,\n/* harmony export */   \"mdiChatProcessingOutline\": () => /* binding */ mdiChatProcessingOutline,\n/* harmony export */   \"mdiChatRemove\": () => /* binding */ mdiChatRemove,\n/* harmony export */   \"mdiChatRemoveOutline\": () => /* binding */ mdiChatRemoveOutline,\n/* harmony export */   \"mdiChatSleep\": () => /* binding */ mdiChatSleep,\n/* harmony export */   \"mdiChatSleepOutline\": () => /* binding */ mdiChatSleepOutline,\n/* harmony export */   \"mdiCheck\": () => /* binding */ mdiCheck,\n/* harmony export */   \"mdiCheckAll\": () => /* binding */ mdiCheckAll,\n/* harmony export */   \"mdiCheckBold\": () => /* binding */ mdiCheckBold,\n/* harmony export */   \"mdiCheckBoxMultipleOutline\": () => /* binding */ mdiCheckBoxMultipleOutline,\n/* harmony export */   \"mdiCheckBoxOutline\": () => /* binding */ mdiCheckBoxOutline,\n/* harmony export */   \"mdiCheckCircle\": () => /* binding */ mdiCheckCircle,\n/* harmony export */   \"mdiCheckCircleOutline\": () => /* binding */ mdiCheckCircleOutline,\n/* harmony export */   \"mdiCheckDecagram\": () => /* binding */ mdiCheckDecagram,\n/* harmony export */   \"mdiCheckNetwork\": () => /* binding */ mdiCheckNetwork,\n/* harmony export */   \"mdiCheckNetworkOutline\": () => /* binding */ mdiCheckNetworkOutline,\n/* harmony export */   \"mdiCheckOutline\": () => /* binding */ mdiCheckOutline,\n/* harmony export */   \"mdiCheckUnderline\": () => /* binding */ mdiCheckUnderline,\n/* harmony export */   \"mdiCheckUnderlineCircle\": () => /* binding */ mdiCheckUnderlineCircle,\n/* harmony export */   \"mdiCheckUnderlineCircleOutline\": () => /* binding */ mdiCheckUnderlineCircleOutline,\n/* harmony export */   \"mdiCheckbook\": () => /* binding */ mdiCheckbook,\n/* harmony export */   \"mdiCheckboxBlank\": () => /* binding */ mdiCheckboxBlank,\n/* harmony export */   \"mdiCheckboxBlankCircle\": () => /* binding */ mdiCheckboxBlankCircle,\n/* harmony export */   \"mdiCheckboxBlankCircleOutline\": () => /* binding */ mdiCheckboxBlankCircleOutline,\n/* harmony export */   \"mdiCheckboxBlankOff\": () => /* binding */ mdiCheckboxBlankOff,\n/* harmony export */   \"mdiCheckboxBlankOffOutline\": () => /* binding */ mdiCheckboxBlankOffOutline,\n/* harmony export */   \"mdiCheckboxBlankOutline\": () => /* binding */ mdiCheckboxBlankOutline,\n/* harmony export */   \"mdiCheckboxIntermediate\": () => /* binding */ mdiCheckboxIntermediate,\n/* harmony export */   \"mdiCheckboxMarked\": () => /* binding */ mdiCheckboxMarked,\n/* harmony export */   \"mdiCheckboxMarkedCircle\": () => /* binding */ mdiCheckboxMarkedCircle,\n/* harmony export */   \"mdiCheckboxMarkedCircleOutline\": () => /* binding */ mdiCheckboxMarkedCircleOutline,\n/* harmony export */   \"mdiCheckboxMarkedOutline\": () => /* binding */ mdiCheckboxMarkedOutline,\n/* harmony export */   \"mdiCheckboxMultipleBlank\": () => /* binding */ mdiCheckboxMultipleBlank,\n/* harmony export */   \"mdiCheckboxMultipleBlankCircle\": () => /* binding */ mdiCheckboxMultipleBlankCircle,\n/* harmony export */   \"mdiCheckboxMultipleBlankCircleOutline\": () => /* binding */ mdiCheckboxMultipleBlankCircleOutline,\n/* harmony export */   \"mdiCheckboxMultipleBlankOutline\": () => /* binding */ mdiCheckboxMultipleBlankOutline,\n/* harmony export */   \"mdiCheckboxMultipleMarked\": () => /* binding */ mdiCheckboxMultipleMarked,\n/* harmony export */   \"mdiCheckboxMultipleMarkedCircle\": () => /* binding */ mdiCheckboxMultipleMarkedCircle,\n/* harmony export */   \"mdiCheckboxMultipleMarkedCircleOutline\": () => /* binding */ mdiCheckboxMultipleMarkedCircleOutline,\n/* harmony export */   \"mdiCheckboxMultipleMarkedOutline\": () => /* binding */ mdiCheckboxMultipleMarkedOutline,\n/* harmony export */   \"mdiCheckerboard\": () => /* binding */ mdiCheckerboard,\n/* harmony export */   \"mdiCheckerboardMinus\": () => /* binding */ mdiCheckerboardMinus,\n/* harmony export */   \"mdiCheckerboardPlus\": () => /* binding */ mdiCheckerboardPlus,\n/* harmony export */   \"mdiCheckerboardRemove\": () => /* binding */ mdiCheckerboardRemove,\n/* harmony export */   \"mdiCheese\": () => /* binding */ mdiCheese,\n/* harmony export */   \"mdiCheeseOff\": () => /* binding */ mdiCheeseOff,\n/* harmony export */   \"mdiChefHat\": () => /* binding */ mdiChefHat,\n/* harmony export */   \"mdiChemicalWeapon\": () => /* binding */ mdiChemicalWeapon,\n/* harmony export */   \"mdiChessBishop\": () => /* binding */ mdiChessBishop,\n/* harmony export */   \"mdiChessKing\": () => /* binding */ mdiChessKing,\n/* harmony export */   \"mdiChessKnight\": () => /* binding */ mdiChessKnight,\n/* harmony export */   \"mdiChessPawn\": () => /* binding */ mdiChessPawn,\n/* harmony export */   \"mdiChessQueen\": () => /* binding */ mdiChessQueen,\n/* harmony export */   \"mdiChessRook\": () => /* binding */ mdiChessRook,\n/* harmony export */   \"mdiChevronDoubleDown\": () => /* binding */ mdiChevronDoubleDown,\n/* harmony export */   \"mdiChevronDoubleLeft\": () => /* binding */ mdiChevronDoubleLeft,\n/* harmony export */   \"mdiChevronDoubleRight\": () => /* binding */ mdiChevronDoubleRight,\n/* harmony export */   \"mdiChevronDoubleUp\": () => /* binding */ mdiChevronDoubleUp,\n/* harmony export */   \"mdiChevronDown\": () => /* binding */ mdiChevronDown,\n/* harmony export */   \"mdiChevronDownBox\": () => /* binding */ mdiChevronDownBox,\n/* harmony export */   \"mdiChevronDownBoxOutline\": () => /* binding */ mdiChevronDownBoxOutline,\n/* harmony export */   \"mdiChevronDownCircle\": () => /* binding */ mdiChevronDownCircle,\n/* harmony export */   \"mdiChevronDownCircleOutline\": () => /* binding */ mdiChevronDownCircleOutline,\n/* harmony export */   \"mdiChevronLeft\": () => /* binding */ mdiChevronLeft,\n/* harmony export */   \"mdiChevronLeftBox\": () => /* binding */ mdiChevronLeftBox,\n/* harmony export */   \"mdiChevronLeftBoxOutline\": () => /* binding */ mdiChevronLeftBoxOutline,\n/* harmony export */   \"mdiChevronLeftCircle\": () => /* binding */ mdiChevronLeftCircle,\n/* harmony export */   \"mdiChevronLeftCircleOutline\": () => /* binding */ mdiChevronLeftCircleOutline,\n/* harmony export */   \"mdiChevronRight\": () => /* binding */ mdiChevronRight,\n/* harmony export */   \"mdiChevronRightBox\": () => /* binding */ mdiChevronRightBox,\n/* harmony export */   \"mdiChevronRightBoxOutline\": () => /* binding */ mdiChevronRightBoxOutline,\n/* harmony export */   \"mdiChevronRightCircle\": () => /* binding */ mdiChevronRightCircle,\n/* harmony export */   \"mdiChevronRightCircleOutline\": () => /* binding */ mdiChevronRightCircleOutline,\n/* harmony export */   \"mdiChevronTripleDown\": () => /* binding */ mdiChevronTripleDown,\n/* harmony export */   \"mdiChevronTripleLeft\": () => /* binding */ mdiChevronTripleLeft,\n/* harmony export */   \"mdiChevronTripleRight\": () => /* binding */ mdiChevronTripleRight,\n/* harmony export */   \"mdiChevronTripleUp\": () => /* binding */ mdiChevronTripleUp,\n/* harmony export */   \"mdiChevronUp\": () => /* binding */ mdiChevronUp,\n/* harmony export */   \"mdiChevronUpBox\": () => /* binding */ mdiChevronUpBox,\n/* harmony export */   \"mdiChevronUpBoxOutline\": () => /* binding */ mdiChevronUpBoxOutline,\n/* harmony export */   \"mdiChevronUpCircle\": () => /* binding */ mdiChevronUpCircle,\n/* harmony export */   \"mdiChevronUpCircleOutline\": () => /* binding */ mdiChevronUpCircleOutline,\n/* harmony export */   \"mdiChiliHot\": () => /* binding */ mdiChiliHot,\n/* harmony export */   \"mdiChiliMedium\": () => /* binding */ mdiChiliMedium,\n/* harmony export */   \"mdiChiliMild\": () => /* binding */ mdiChiliMild,\n/* harmony export */   \"mdiChiliOff\": () => /* binding */ mdiChiliOff,\n/* harmony export */   \"mdiChip\": () => /* binding */ mdiChip,\n/* harmony export */   \"mdiChristianity\": () => /* binding */ mdiChristianity,\n/* harmony export */   \"mdiChristianityOutline\": () => /* binding */ mdiChristianityOutline,\n/* harmony export */   \"mdiChurch\": () => /* binding */ mdiChurch,\n/* harmony export */   \"mdiCigar\": () => /* binding */ mdiCigar,\n/* harmony export */   \"mdiCigarOff\": () => /* binding */ mdiCigarOff,\n/* harmony export */   \"mdiCircle\": () => /* binding */ mdiCircle,\n/* harmony export */   \"mdiCircleBox\": () => /* binding */ mdiCircleBox,\n/* harmony export */   \"mdiCircleBoxOutline\": () => /* binding */ mdiCircleBoxOutline,\n/* harmony export */   \"mdiCircleDouble\": () => /* binding */ mdiCircleDouble,\n/* harmony export */   \"mdiCircleEditOutline\": () => /* binding */ mdiCircleEditOutline,\n/* harmony export */   \"mdiCircleExpand\": () => /* binding */ mdiCircleExpand,\n/* harmony export */   \"mdiCircleHalf\": () => /* binding */ mdiCircleHalf,\n/* harmony export */   \"mdiCircleHalfFull\": () => /* binding */ mdiCircleHalfFull,\n/* harmony export */   \"mdiCircleMedium\": () => /* binding */ mdiCircleMedium,\n/* harmony export */   \"mdiCircleMultiple\": () => /* binding */ mdiCircleMultiple,\n/* harmony export */   \"mdiCircleMultipleOutline\": () => /* binding */ mdiCircleMultipleOutline,\n/* harmony export */   \"mdiCircleOffOutline\": () => /* binding */ mdiCircleOffOutline,\n/* harmony export */   \"mdiCircleOutline\": () => /* binding */ mdiCircleOutline,\n/* harmony export */   \"mdiCircleSlice1\": () => /* binding */ mdiCircleSlice1,\n/* harmony export */   \"mdiCircleSlice2\": () => /* binding */ mdiCircleSlice2,\n/* harmony export */   \"mdiCircleSlice3\": () => /* binding */ mdiCircleSlice3,\n/* harmony export */   \"mdiCircleSlice4\": () => /* binding */ mdiCircleSlice4,\n/* harmony export */   \"mdiCircleSlice5\": () => /* binding */ mdiCircleSlice5,\n/* harmony export */   \"mdiCircleSlice6\": () => /* binding */ mdiCircleSlice6,\n/* harmony export */   \"mdiCircleSlice7\": () => /* binding */ mdiCircleSlice7,\n/* harmony export */   \"mdiCircleSlice8\": () => /* binding */ mdiCircleSlice8,\n/* harmony export */   \"mdiCircleSmall\": () => /* binding */ mdiCircleSmall,\n/* harmony export */   \"mdiCircularSaw\": () => /* binding */ mdiCircularSaw,\n/* harmony export */   \"mdiCity\": () => /* binding */ mdiCity,\n/* harmony export */   \"mdiCityVariant\": () => /* binding */ mdiCityVariant,\n/* harmony export */   \"mdiCityVariantOutline\": () => /* binding */ mdiCityVariantOutline,\n/* harmony export */   \"mdiClipboard\": () => /* binding */ mdiClipboard,\n/* harmony export */   \"mdiClipboardAccount\": () => /* binding */ mdiClipboardAccount,\n/* harmony export */   \"mdiClipboardAccountOutline\": () => /* binding */ mdiClipboardAccountOutline,\n/* harmony export */   \"mdiClipboardAlert\": () => /* binding */ mdiClipboardAlert,\n/* harmony export */   \"mdiClipboardAlertOutline\": () => /* binding */ mdiClipboardAlertOutline,\n/* harmony export */   \"mdiClipboardArrowDown\": () => /* binding */ mdiClipboardArrowDown,\n/* harmony export */   \"mdiClipboardArrowDownOutline\": () => /* binding */ mdiClipboardArrowDownOutline,\n/* harmony export */   \"mdiClipboardArrowLeft\": () => /* binding */ mdiClipboardArrowLeft,\n/* harmony export */   \"mdiClipboardArrowLeftOutline\": () => /* binding */ mdiClipboardArrowLeftOutline,\n/* harmony export */   \"mdiClipboardArrowRight\": () => /* binding */ mdiClipboardArrowRight,\n/* harmony export */   \"mdiClipboardArrowRightOutline\": () => /* binding */ mdiClipboardArrowRightOutline,\n/* harmony export */   \"mdiClipboardArrowUp\": () => /* binding */ mdiClipboardArrowUp,\n/* harmony export */   \"mdiClipboardArrowUpOutline\": () => /* binding */ mdiClipboardArrowUpOutline,\n/* harmony export */   \"mdiClipboardCheck\": () => /* binding */ mdiClipboardCheck,\n/* harmony export */   \"mdiClipboardCheckMultiple\": () => /* binding */ mdiClipboardCheckMultiple,\n/* harmony export */   \"mdiClipboardCheckMultipleOutline\": () => /* binding */ mdiClipboardCheckMultipleOutline,\n/* harmony export */   \"mdiClipboardCheckOutline\": () => /* binding */ mdiClipboardCheckOutline,\n/* harmony export */   \"mdiClipboardEdit\": () => /* binding */ mdiClipboardEdit,\n/* harmony export */   \"mdiClipboardEditOutline\": () => /* binding */ mdiClipboardEditOutline,\n/* harmony export */   \"mdiClipboardFile\": () => /* binding */ mdiClipboardFile,\n/* harmony export */   \"mdiClipboardFileOutline\": () => /* binding */ mdiClipboardFileOutline,\n/* harmony export */   \"mdiClipboardFlow\": () => /* binding */ mdiClipboardFlow,\n/* harmony export */   \"mdiClipboardFlowOutline\": () => /* binding */ mdiClipboardFlowOutline,\n/* harmony export */   \"mdiClipboardList\": () => /* binding */ mdiClipboardList,\n/* harmony export */   \"mdiClipboardListOutline\": () => /* binding */ mdiClipboardListOutline,\n/* harmony export */   \"mdiClipboardMultiple\": () => /* binding */ mdiClipboardMultiple,\n/* harmony export */   \"mdiClipboardMultipleOutline\": () => /* binding */ mdiClipboardMultipleOutline,\n/* harmony export */   \"mdiClipboardOutline\": () => /* binding */ mdiClipboardOutline,\n/* harmony export */   \"mdiClipboardPlay\": () => /* binding */ mdiClipboardPlay,\n/* harmony export */   \"mdiClipboardPlayMultiple\": () => /* binding */ mdiClipboardPlayMultiple,\n/* harmony export */   \"mdiClipboardPlayMultipleOutline\": () => /* binding */ mdiClipboardPlayMultipleOutline,\n/* harmony export */   \"mdiClipboardPlayOutline\": () => /* binding */ mdiClipboardPlayOutline,\n/* harmony export */   \"mdiClipboardPlus\": () => /* binding */ mdiClipboardPlus,\n/* harmony export */   \"mdiClipboardPlusOutline\": () => /* binding */ mdiClipboardPlusOutline,\n/* harmony export */   \"mdiClipboardPulse\": () => /* binding */ mdiClipboardPulse,\n/* harmony export */   \"mdiClipboardPulseOutline\": () => /* binding */ mdiClipboardPulseOutline,\n/* harmony export */   \"mdiClipboardText\": () => /* binding */ mdiClipboardText,\n/* harmony export */   \"mdiClipboardTextMultiple\": () => /* binding */ mdiClipboardTextMultiple,\n/* harmony export */   \"mdiClipboardTextMultipleOutline\": () => /* binding */ mdiClipboardTextMultipleOutline,\n/* harmony export */   \"mdiClipboardTextOutline\": () => /* binding */ mdiClipboardTextOutline,\n/* harmony export */   \"mdiClipboardTextPlay\": () => /* binding */ mdiClipboardTextPlay,\n/* harmony export */   \"mdiClipboardTextPlayOutline\": () => /* binding */ mdiClipboardTextPlayOutline,\n/* harmony export */   \"mdiClippy\": () => /* binding */ mdiClippy,\n/* harmony export */   \"mdiClock\": () => /* binding */ mdiClock,\n/* harmony export */   \"mdiClockAlert\": () => /* binding */ mdiClockAlert,\n/* harmony export */   \"mdiClockAlertOutline\": () => /* binding */ mdiClockAlertOutline,\n/* harmony export */   \"mdiClockCheck\": () => /* binding */ mdiClockCheck,\n/* harmony export */   \"mdiClockCheckOutline\": () => /* binding */ mdiClockCheckOutline,\n/* harmony export */   \"mdiClockDigital\": () => /* binding */ mdiClockDigital,\n/* harmony export */   \"mdiClockEnd\": () => /* binding */ mdiClockEnd,\n/* harmony export */   \"mdiClockFast\": () => /* binding */ mdiClockFast,\n/* harmony export */   \"mdiClockIn\": () => /* binding */ mdiClockIn,\n/* harmony export */   \"mdiClockOut\": () => /* binding */ mdiClockOut,\n/* harmony export */   \"mdiClockOutline\": () => /* binding */ mdiClockOutline,\n/* harmony export */   \"mdiClockStart\": () => /* binding */ mdiClockStart,\n/* harmony export */   \"mdiClockTimeEight\": () => /* binding */ mdiClockTimeEight,\n/* harmony export */   \"mdiClockTimeEightOutline\": () => /* binding */ mdiClockTimeEightOutline,\n/* harmony export */   \"mdiClockTimeEleven\": () => /* binding */ mdiClockTimeEleven,\n/* harmony export */   \"mdiClockTimeElevenOutline\": () => /* binding */ mdiClockTimeElevenOutline,\n/* harmony export */   \"mdiClockTimeFive\": () => /* binding */ mdiClockTimeFive,\n/* harmony export */   \"mdiClockTimeFiveOutline\": () => /* binding */ mdiClockTimeFiveOutline,\n/* harmony export */   \"mdiClockTimeFour\": () => /* binding */ mdiClockTimeFour,\n/* harmony export */   \"mdiClockTimeFourOutline\": () => /* binding */ mdiClockTimeFourOutline,\n/* harmony export */   \"mdiClockTimeNine\": () => /* binding */ mdiClockTimeNine,\n/* harmony export */   \"mdiClockTimeNineOutline\": () => /* binding */ mdiClockTimeNineOutline,\n/* harmony export */   \"mdiClockTimeOne\": () => /* binding */ mdiClockTimeOne,\n/* harmony export */   \"mdiClockTimeOneOutline\": () => /* binding */ mdiClockTimeOneOutline,\n/* harmony export */   \"mdiClockTimeSeven\": () => /* binding */ mdiClockTimeSeven,\n/* harmony export */   \"mdiClockTimeSevenOutline\": () => /* binding */ mdiClockTimeSevenOutline,\n/* harmony export */   \"mdiClockTimeSix\": () => /* binding */ mdiClockTimeSix,\n/* harmony export */   \"mdiClockTimeSixOutline\": () => /* binding */ mdiClockTimeSixOutline,\n/* harmony export */   \"mdiClockTimeTen\": () => /* binding */ mdiClockTimeTen,\n/* harmony export */   \"mdiClockTimeTenOutline\": () => /* binding */ mdiClockTimeTenOutline,\n/* harmony export */   \"mdiClockTimeThree\": () => /* binding */ mdiClockTimeThree,\n/* harmony export */   \"mdiClockTimeThreeOutline\": () => /* binding */ mdiClockTimeThreeOutline,\n/* harmony export */   \"mdiClockTimeTwelve\": () => /* binding */ mdiClockTimeTwelve,\n/* harmony export */   \"mdiClockTimeTwelveOutline\": () => /* binding */ mdiClockTimeTwelveOutline,\n/* harmony export */   \"mdiClockTimeTwo\": () => /* binding */ mdiClockTimeTwo,\n/* harmony export */   \"mdiClockTimeTwoOutline\": () => /* binding */ mdiClockTimeTwoOutline,\n/* harmony export */   \"mdiClose\": () => /* binding */ mdiClose,\n/* harmony export */   \"mdiCloseBox\": () => /* binding */ mdiCloseBox,\n/* harmony export */   \"mdiCloseBoxMultiple\": () => /* binding */ mdiCloseBoxMultiple,\n/* harmony export */   \"mdiCloseBoxMultipleOutline\": () => /* binding */ mdiCloseBoxMultipleOutline,\n/* harmony export */   \"mdiCloseBoxOutline\": () => /* binding */ mdiCloseBoxOutline,\n/* harmony export */   \"mdiCloseCircle\": () => /* binding */ mdiCloseCircle,\n/* harmony export */   \"mdiCloseCircleMultiple\": () => /* binding */ mdiCloseCircleMultiple,\n/* harmony export */   \"mdiCloseCircleMultipleOutline\": () => /* binding */ mdiCloseCircleMultipleOutline,\n/* harmony export */   \"mdiCloseCircleOutline\": () => /* binding */ mdiCloseCircleOutline,\n/* harmony export */   \"mdiCloseNetwork\": () => /* binding */ mdiCloseNetwork,\n/* harmony export */   \"mdiCloseNetworkOutline\": () => /* binding */ mdiCloseNetworkOutline,\n/* harmony export */   \"mdiCloseOctagon\": () => /* binding */ mdiCloseOctagon,\n/* harmony export */   \"mdiCloseOctagonOutline\": () => /* binding */ mdiCloseOctagonOutline,\n/* harmony export */   \"mdiCloseOutline\": () => /* binding */ mdiCloseOutline,\n/* harmony export */   \"mdiCloseThick\": () => /* binding */ mdiCloseThick,\n/* harmony export */   \"mdiClosedCaption\": () => /* binding */ mdiClosedCaption,\n/* harmony export */   \"mdiClosedCaptionOutline\": () => /* binding */ mdiClosedCaptionOutline,\n/* harmony export */   \"mdiCloud\": () => /* binding */ mdiCloud,\n/* harmony export */   \"mdiCloudAlert\": () => /* binding */ mdiCloudAlert,\n/* harmony export */   \"mdiCloudBraces\": () => /* binding */ mdiCloudBraces,\n/* harmony export */   \"mdiCloudCheck\": () => /* binding */ mdiCloudCheck,\n/* harmony export */   \"mdiCloudCheckOutline\": () => /* binding */ mdiCloudCheckOutline,\n/* harmony export */   \"mdiCloudCircle\": () => /* binding */ mdiCloudCircle,\n/* harmony export */   \"mdiCloudDownload\": () => /* binding */ mdiCloudDownload,\n/* harmony export */   \"mdiCloudDownloadOutline\": () => /* binding */ mdiCloudDownloadOutline,\n/* harmony export */   \"mdiCloudLock\": () => /* binding */ mdiCloudLock,\n/* harmony export */   \"mdiCloudLockOutline\": () => /* binding */ mdiCloudLockOutline,\n/* harmony export */   \"mdiCloudOffOutline\": () => /* binding */ mdiCloudOffOutline,\n/* harmony export */   \"mdiCloudOutline\": () => /* binding */ mdiCloudOutline,\n/* harmony export */   \"mdiCloudPrint\": () => /* binding */ mdiCloudPrint,\n/* harmony export */   \"mdiCloudPrintOutline\": () => /* binding */ mdiCloudPrintOutline,\n/* harmony export */   \"mdiCloudQuestion\": () => /* binding */ mdiCloudQuestion,\n/* harmony export */   \"mdiCloudRefresh\": () => /* binding */ mdiCloudRefresh,\n/* harmony export */   \"mdiCloudSearch\": () => /* binding */ mdiCloudSearch,\n/* harmony export */   \"mdiCloudSearchOutline\": () => /* binding */ mdiCloudSearchOutline,\n/* harmony export */   \"mdiCloudSync\": () => /* binding */ mdiCloudSync,\n/* harmony export */   \"mdiCloudSyncOutline\": () => /* binding */ mdiCloudSyncOutline,\n/* harmony export */   \"mdiCloudTags\": () => /* binding */ mdiCloudTags,\n/* harmony export */   \"mdiCloudUpload\": () => /* binding */ mdiCloudUpload,\n/* harmony export */   \"mdiCloudUploadOutline\": () => /* binding */ mdiCloudUploadOutline,\n/* harmony export */   \"mdiClover\": () => /* binding */ mdiClover,\n/* harmony export */   \"mdiCoachLamp\": () => /* binding */ mdiCoachLamp,\n/* harmony export */   \"mdiCoatRack\": () => /* binding */ mdiCoatRack,\n/* harmony export */   \"mdiCodeArray\": () => /* binding */ mdiCodeArray,\n/* harmony export */   \"mdiCodeBraces\": () => /* binding */ mdiCodeBraces,\n/* harmony export */   \"mdiCodeBracesBox\": () => /* binding */ mdiCodeBracesBox,\n/* harmony export */   \"mdiCodeBrackets\": () => /* binding */ mdiCodeBrackets,\n/* harmony export */   \"mdiCodeEqual\": () => /* binding */ mdiCodeEqual,\n/* harmony export */   \"mdiCodeGreaterThan\": () => /* binding */ mdiCodeGreaterThan,\n/* harmony export */   \"mdiCodeGreaterThanOrEqual\": () => /* binding */ mdiCodeGreaterThanOrEqual,\n/* harmony export */   \"mdiCodeJson\": () => /* binding */ mdiCodeJson,\n/* harmony export */   \"mdiCodeLessThan\": () => /* binding */ mdiCodeLessThan,\n/* harmony export */   \"mdiCodeLessThanOrEqual\": () => /* binding */ mdiCodeLessThanOrEqual,\n/* harmony export */   \"mdiCodeNotEqual\": () => /* binding */ mdiCodeNotEqual,\n/* harmony export */   \"mdiCodeNotEqualVariant\": () => /* binding */ mdiCodeNotEqualVariant,\n/* harmony export */   \"mdiCodeParentheses\": () => /* binding */ mdiCodeParentheses,\n/* harmony export */   \"mdiCodeParenthesesBox\": () => /* binding */ mdiCodeParenthesesBox,\n/* harmony export */   \"mdiCodeString\": () => /* binding */ mdiCodeString,\n/* harmony export */   \"mdiCodeTags\": () => /* binding */ mdiCodeTags,\n/* harmony export */   \"mdiCodeTagsCheck\": () => /* binding */ mdiCodeTagsCheck,\n/* harmony export */   \"mdiCodepen\": () => /* binding */ mdiCodepen,\n/* harmony export */   \"mdiCoffee\": () => /* binding */ mdiCoffee,\n/* harmony export */   \"mdiCoffeeMaker\": () => /* binding */ mdiCoffeeMaker,\n/* harmony export */   \"mdiCoffeeOff\": () => /* binding */ mdiCoffeeOff,\n/* harmony export */   \"mdiCoffeeOffOutline\": () => /* binding */ mdiCoffeeOffOutline,\n/* harmony export */   \"mdiCoffeeOutline\": () => /* binding */ mdiCoffeeOutline,\n/* harmony export */   \"mdiCoffeeToGo\": () => /* binding */ mdiCoffeeToGo,\n/* harmony export */   \"mdiCoffeeToGoOutline\": () => /* binding */ mdiCoffeeToGoOutline,\n/* harmony export */   \"mdiCoffin\": () => /* binding */ mdiCoffin,\n/* harmony export */   \"mdiCog\": () => /* binding */ mdiCog,\n/* harmony export */   \"mdiCogBox\": () => /* binding */ mdiCogBox,\n/* harmony export */   \"mdiCogClockwise\": () => /* binding */ mdiCogClockwise,\n/* harmony export */   \"mdiCogCounterclockwise\": () => /* binding */ mdiCogCounterclockwise,\n/* harmony export */   \"mdiCogOff\": () => /* binding */ mdiCogOff,\n/* harmony export */   \"mdiCogOffOutline\": () => /* binding */ mdiCogOffOutline,\n/* harmony export */   \"mdiCogOutline\": () => /* binding */ mdiCogOutline,\n/* harmony export */   \"mdiCogRefresh\": () => /* binding */ mdiCogRefresh,\n/* harmony export */   \"mdiCogRefreshOutline\": () => /* binding */ mdiCogRefreshOutline,\n/* harmony export */   \"mdiCogSync\": () => /* binding */ mdiCogSync,\n/* harmony export */   \"mdiCogSyncOutline\": () => /* binding */ mdiCogSyncOutline,\n/* harmony export */   \"mdiCogTransfer\": () => /* binding */ mdiCogTransfer,\n/* harmony export */   \"mdiCogTransferOutline\": () => /* binding */ mdiCogTransferOutline,\n/* harmony export */   \"mdiCogs\": () => /* binding */ mdiCogs,\n/* harmony export */   \"mdiCollage\": () => /* binding */ mdiCollage,\n/* harmony export */   \"mdiCollapseAll\": () => /* binding */ mdiCollapseAll,\n/* harmony export */   \"mdiCollapseAllOutline\": () => /* binding */ mdiCollapseAllOutline,\n/* harmony export */   \"mdiColorHelper\": () => /* binding */ mdiColorHelper,\n/* harmony export */   \"mdiComma\": () => /* binding */ mdiComma,\n/* harmony export */   \"mdiCommaBox\": () => /* binding */ mdiCommaBox,\n/* harmony export */   \"mdiCommaBoxOutline\": () => /* binding */ mdiCommaBoxOutline,\n/* harmony export */   \"mdiCommaCircle\": () => /* binding */ mdiCommaCircle,\n/* harmony export */   \"mdiCommaCircleOutline\": () => /* binding */ mdiCommaCircleOutline,\n/* harmony export */   \"mdiComment\": () => /* binding */ mdiComment,\n/* harmony export */   \"mdiCommentAccount\": () => /* binding */ mdiCommentAccount,\n/* harmony export */   \"mdiCommentAccountOutline\": () => /* binding */ mdiCommentAccountOutline,\n/* harmony export */   \"mdiCommentAlert\": () => /* binding */ mdiCommentAlert,\n/* harmony export */   \"mdiCommentAlertOutline\": () => /* binding */ mdiCommentAlertOutline,\n/* harmony export */   \"mdiCommentArrowLeft\": () => /* binding */ mdiCommentArrowLeft,\n/* harmony export */   \"mdiCommentArrowLeftOutline\": () => /* binding */ mdiCommentArrowLeftOutline,\n/* harmony export */   \"mdiCommentArrowRight\": () => /* binding */ mdiCommentArrowRight,\n/* harmony export */   \"mdiCommentArrowRightOutline\": () => /* binding */ mdiCommentArrowRightOutline,\n/* harmony export */   \"mdiCommentBookmark\": () => /* binding */ mdiCommentBookmark,\n/* harmony export */   \"mdiCommentBookmarkOutline\": () => /* binding */ mdiCommentBookmarkOutline,\n/* harmony export */   \"mdiCommentCheck\": () => /* binding */ mdiCommentCheck,\n/* harmony export */   \"mdiCommentCheckOutline\": () => /* binding */ mdiCommentCheckOutline,\n/* harmony export */   \"mdiCommentEdit\": () => /* binding */ mdiCommentEdit,\n/* harmony export */   \"mdiCommentEditOutline\": () => /* binding */ mdiCommentEditOutline,\n/* harmony export */   \"mdiCommentEye\": () => /* binding */ mdiCommentEye,\n/* harmony export */   \"mdiCommentEyeOutline\": () => /* binding */ mdiCommentEyeOutline,\n/* harmony export */   \"mdiCommentFlash\": () => /* binding */ mdiCommentFlash,\n/* harmony export */   \"mdiCommentFlashOutline\": () => /* binding */ mdiCommentFlashOutline,\n/* harmony export */   \"mdiCommentMinus\": () => /* binding */ mdiCommentMinus,\n/* harmony export */   \"mdiCommentMinusOutline\": () => /* binding */ mdiCommentMinusOutline,\n/* harmony export */   \"mdiCommentMultiple\": () => /* binding */ mdiCommentMultiple,\n/* harmony export */   \"mdiCommentMultipleOutline\": () => /* binding */ mdiCommentMultipleOutline,\n/* harmony export */   \"mdiCommentOff\": () => /* binding */ mdiCommentOff,\n/* harmony export */   \"mdiCommentOffOutline\": () => /* binding */ mdiCommentOffOutline,\n/* harmony export */   \"mdiCommentOutline\": () => /* binding */ mdiCommentOutline,\n/* harmony export */   \"mdiCommentPlus\": () => /* binding */ mdiCommentPlus,\n/* harmony export */   \"mdiCommentPlusOutline\": () => /* binding */ mdiCommentPlusOutline,\n/* harmony export */   \"mdiCommentProcessing\": () => /* binding */ mdiCommentProcessing,\n/* harmony export */   \"mdiCommentProcessingOutline\": () => /* binding */ mdiCommentProcessingOutline,\n/* harmony export */   \"mdiCommentQuestion\": () => /* binding */ mdiCommentQuestion,\n/* harmony export */   \"mdiCommentQuestionOutline\": () => /* binding */ mdiCommentQuestionOutline,\n/* harmony export */   \"mdiCommentQuote\": () => /* binding */ mdiCommentQuote,\n/* harmony export */   \"mdiCommentQuoteOutline\": () => /* binding */ mdiCommentQuoteOutline,\n/* harmony export */   \"mdiCommentRemove\": () => /* binding */ mdiCommentRemove,\n/* harmony export */   \"mdiCommentRemoveOutline\": () => /* binding */ mdiCommentRemoveOutline,\n/* harmony export */   \"mdiCommentSearch\": () => /* binding */ mdiCommentSearch,\n/* harmony export */   \"mdiCommentSearchOutline\": () => /* binding */ mdiCommentSearchOutline,\n/* harmony export */   \"mdiCommentText\": () => /* binding */ mdiCommentText,\n/* harmony export */   \"mdiCommentTextMultiple\": () => /* binding */ mdiCommentTextMultiple,\n/* harmony export */   \"mdiCommentTextMultipleOutline\": () => /* binding */ mdiCommentTextMultipleOutline,\n/* harmony export */   \"mdiCommentTextOutline\": () => /* binding */ mdiCommentTextOutline,\n/* harmony export */   \"mdiCompare\": () => /* binding */ mdiCompare,\n/* harmony export */   \"mdiCompareHorizontal\": () => /* binding */ mdiCompareHorizontal,\n/* harmony export */   \"mdiCompareVertical\": () => /* binding */ mdiCompareVertical,\n/* harmony export */   \"mdiCompass\": () => /* binding */ mdiCompass,\n/* harmony export */   \"mdiCompassOff\": () => /* binding */ mdiCompassOff,\n/* harmony export */   \"mdiCompassOffOutline\": () => /* binding */ mdiCompassOffOutline,\n/* harmony export */   \"mdiCompassOutline\": () => /* binding */ mdiCompassOutline,\n/* harmony export */   \"mdiCompassRose\": () => /* binding */ mdiCompassRose,\n/* harmony export */   \"mdiConcourseCi\": () => /* binding */ mdiConcourseCi,\n/* harmony export */   \"mdiConnection\": () => /* binding */ mdiConnection,\n/* harmony export */   \"mdiConsole\": () => /* binding */ mdiConsole,\n/* harmony export */   \"mdiConsoleLine\": () => /* binding */ mdiConsoleLine,\n/* harmony export */   \"mdiConsoleNetwork\": () => /* binding */ mdiConsoleNetwork,\n/* harmony export */   \"mdiConsoleNetworkOutline\": () => /* binding */ mdiConsoleNetworkOutline,\n/* harmony export */   \"mdiConsolidate\": () => /* binding */ mdiConsolidate,\n/* harmony export */   \"mdiContactlessPayment\": () => /* binding */ mdiContactlessPayment,\n/* harmony export */   \"mdiContactlessPaymentCircle\": () => /* binding */ mdiContactlessPaymentCircle,\n/* harmony export */   \"mdiContactlessPaymentCircleOutline\": () => /* binding */ mdiContactlessPaymentCircleOutline,\n/* harmony export */   \"mdiContacts\": () => /* binding */ mdiContacts,\n/* harmony export */   \"mdiContactsOutline\": () => /* binding */ mdiContactsOutline,\n/* harmony export */   \"mdiContain\": () => /* binding */ mdiContain,\n/* harmony export */   \"mdiContainEnd\": () => /* binding */ mdiContainEnd,\n/* harmony export */   \"mdiContainStart\": () => /* binding */ mdiContainStart,\n/* harmony export */   \"mdiContentCopy\": () => /* binding */ mdiContentCopy,\n/* harmony export */   \"mdiContentCut\": () => /* binding */ mdiContentCut,\n/* harmony export */   \"mdiContentDuplicate\": () => /* binding */ mdiContentDuplicate,\n/* harmony export */   \"mdiContentPaste\": () => /* binding */ mdiContentPaste,\n/* harmony export */   \"mdiContentSave\": () => /* binding */ mdiContentSave,\n/* harmony export */   \"mdiContentSaveAlert\": () => /* binding */ mdiContentSaveAlert,\n/* harmony export */   \"mdiContentSaveAlertOutline\": () => /* binding */ mdiContentSaveAlertOutline,\n/* harmony export */   \"mdiContentSaveAll\": () => /* binding */ mdiContentSaveAll,\n/* harmony export */   \"mdiContentSaveAllOutline\": () => /* binding */ mdiContentSaveAllOutline,\n/* harmony export */   \"mdiContentSaveCog\": () => /* binding */ mdiContentSaveCog,\n/* harmony export */   \"mdiContentSaveCogOutline\": () => /* binding */ mdiContentSaveCogOutline,\n/* harmony export */   \"mdiContentSaveEdit\": () => /* binding */ mdiContentSaveEdit,\n/* harmony export */   \"mdiContentSaveEditOutline\": () => /* binding */ mdiContentSaveEditOutline,\n/* harmony export */   \"mdiContentSaveMove\": () => /* binding */ mdiContentSaveMove,\n/* harmony export */   \"mdiContentSaveMoveOutline\": () => /* binding */ mdiContentSaveMoveOutline,\n/* harmony export */   \"mdiContentSaveOutline\": () => /* binding */ mdiContentSaveOutline,\n/* harmony export */   \"mdiContentSaveSettings\": () => /* binding */ mdiContentSaveSettings,\n/* harmony export */   \"mdiContentSaveSettingsOutline\": () => /* binding */ mdiContentSaveSettingsOutline,\n/* harmony export */   \"mdiContrast\": () => /* binding */ mdiContrast,\n/* harmony export */   \"mdiContrastBox\": () => /* binding */ mdiContrastBox,\n/* harmony export */   \"mdiContrastCircle\": () => /* binding */ mdiContrastCircle,\n/* harmony export */   \"mdiControllerClassic\": () => /* binding */ mdiControllerClassic,\n/* harmony export */   \"mdiControllerClassicOutline\": () => /* binding */ mdiControllerClassicOutline,\n/* harmony export */   \"mdiCookie\": () => /* binding */ mdiCookie,\n/* harmony export */   \"mdiCoolantTemperature\": () => /* binding */ mdiCoolantTemperature,\n/* harmony export */   \"mdiCopyright\": () => /* binding */ mdiCopyright,\n/* harmony export */   \"mdiCordova\": () => /* binding */ mdiCordova,\n/* harmony export */   \"mdiCorn\": () => /* binding */ mdiCorn,\n/* harmony export */   \"mdiCornOff\": () => /* binding */ mdiCornOff,\n/* harmony export */   \"mdiCosineWave\": () => /* binding */ mdiCosineWave,\n/* harmony export */   \"mdiCounter\": () => /* binding */ mdiCounter,\n/* harmony export */   \"mdiCow\": () => /* binding */ mdiCow,\n/* harmony export */   \"mdiCpu32Bit\": () => /* binding */ mdiCpu32Bit,\n/* harmony export */   \"mdiCpu64Bit\": () => /* binding */ mdiCpu64Bit,\n/* harmony export */   \"mdiCrane\": () => /* binding */ mdiCrane,\n/* harmony export */   \"mdiCreation\": () => /* binding */ mdiCreation,\n/* harmony export */   \"mdiCreativeCommons\": () => /* binding */ mdiCreativeCommons,\n/* harmony export */   \"mdiCreditCard\": () => /* binding */ mdiCreditCard,\n/* harmony export */   \"mdiCreditCardCheck\": () => /* binding */ mdiCreditCardCheck,\n/* harmony export */   \"mdiCreditCardCheckOutline\": () => /* binding */ mdiCreditCardCheckOutline,\n/* harmony export */   \"mdiCreditCardClock\": () => /* binding */ mdiCreditCardClock,\n/* harmony export */   \"mdiCreditCardClockOutline\": () => /* binding */ mdiCreditCardClockOutline,\n/* harmony export */   \"mdiCreditCardMarker\": () => /* binding */ mdiCreditCardMarker,\n/* harmony export */   \"mdiCreditCardMarkerOutline\": () => /* binding */ mdiCreditCardMarkerOutline,\n/* harmony export */   \"mdiCreditCardMinus\": () => /* binding */ mdiCreditCardMinus,\n/* harmony export */   \"mdiCreditCardMinusOutline\": () => /* binding */ mdiCreditCardMinusOutline,\n/* harmony export */   \"mdiCreditCardMultiple\": () => /* binding */ mdiCreditCardMultiple,\n/* harmony export */   \"mdiCreditCardMultipleOutline\": () => /* binding */ mdiCreditCardMultipleOutline,\n/* harmony export */   \"mdiCreditCardOff\": () => /* binding */ mdiCreditCardOff,\n/* harmony export */   \"mdiCreditCardOffOutline\": () => /* binding */ mdiCreditCardOffOutline,\n/* harmony export */   \"mdiCreditCardOutline\": () => /* binding */ mdiCreditCardOutline,\n/* harmony export */   \"mdiCreditCardPlus\": () => /* binding */ mdiCreditCardPlus,\n/* harmony export */   \"mdiCreditCardPlusOutline\": () => /* binding */ mdiCreditCardPlusOutline,\n/* harmony export */   \"mdiCreditCardRefund\": () => /* binding */ mdiCreditCardRefund,\n/* harmony export */   \"mdiCreditCardRefundOutline\": () => /* binding */ mdiCreditCardRefundOutline,\n/* harmony export */   \"mdiCreditCardRemove\": () => /* binding */ mdiCreditCardRemove,\n/* harmony export */   \"mdiCreditCardRemoveOutline\": () => /* binding */ mdiCreditCardRemoveOutline,\n/* harmony export */   \"mdiCreditCardScan\": () => /* binding */ mdiCreditCardScan,\n/* harmony export */   \"mdiCreditCardScanOutline\": () => /* binding */ mdiCreditCardScanOutline,\n/* harmony export */   \"mdiCreditCardSettings\": () => /* binding */ mdiCreditCardSettings,\n/* harmony export */   \"mdiCreditCardSettingsOutline\": () => /* binding */ mdiCreditCardSettingsOutline,\n/* harmony export */   \"mdiCreditCardWireless\": () => /* binding */ mdiCreditCardWireless,\n/* harmony export */   \"mdiCreditCardWirelessOff\": () => /* binding */ mdiCreditCardWirelessOff,\n/* harmony export */   \"mdiCreditCardWirelessOffOutline\": () => /* binding */ mdiCreditCardWirelessOffOutline,\n/* harmony export */   \"mdiCreditCardWirelessOutline\": () => /* binding */ mdiCreditCardWirelessOutline,\n/* harmony export */   \"mdiCricket\": () => /* binding */ mdiCricket,\n/* harmony export */   \"mdiCrop\": () => /* binding */ mdiCrop,\n/* harmony export */   \"mdiCropFree\": () => /* binding */ mdiCropFree,\n/* harmony export */   \"mdiCropLandscape\": () => /* binding */ mdiCropLandscape,\n/* harmony export */   \"mdiCropPortrait\": () => /* binding */ mdiCropPortrait,\n/* harmony export */   \"mdiCropRotate\": () => /* binding */ mdiCropRotate,\n/* harmony export */   \"mdiCropSquare\": () => /* binding */ mdiCropSquare,\n/* harmony export */   \"mdiCrosshairs\": () => /* binding */ mdiCrosshairs,\n/* harmony export */   \"mdiCrosshairsGps\": () => /* binding */ mdiCrosshairsGps,\n/* harmony export */   \"mdiCrosshairsOff\": () => /* binding */ mdiCrosshairsOff,\n/* harmony export */   \"mdiCrosshairsQuestion\": () => /* binding */ mdiCrosshairsQuestion,\n/* harmony export */   \"mdiCrown\": () => /* binding */ mdiCrown,\n/* harmony export */   \"mdiCrownOutline\": () => /* binding */ mdiCrownOutline,\n/* harmony export */   \"mdiCryengine\": () => /* binding */ mdiCryengine,\n/* harmony export */   \"mdiCrystalBall\": () => /* binding */ mdiCrystalBall,\n/* harmony export */   \"mdiCube\": () => /* binding */ mdiCube,\n/* harmony export */   \"mdiCubeOff\": () => /* binding */ mdiCubeOff,\n/* harmony export */   \"mdiCubeOffOutline\": () => /* binding */ mdiCubeOffOutline,\n/* harmony export */   \"mdiCubeOutline\": () => /* binding */ mdiCubeOutline,\n/* harmony export */   \"mdiCubeScan\": () => /* binding */ mdiCubeScan,\n/* harmony export */   \"mdiCubeSend\": () => /* binding */ mdiCubeSend,\n/* harmony export */   \"mdiCubeUnfolded\": () => /* binding */ mdiCubeUnfolded,\n/* harmony export */   \"mdiCup\": () => /* binding */ mdiCup,\n/* harmony export */   \"mdiCupOff\": () => /* binding */ mdiCupOff,\n/* harmony export */   \"mdiCupOffOutline\": () => /* binding */ mdiCupOffOutline,\n/* harmony export */   \"mdiCupOutline\": () => /* binding */ mdiCupOutline,\n/* harmony export */   \"mdiCupWater\": () => /* binding */ mdiCupWater,\n/* harmony export */   \"mdiCupboard\": () => /* binding */ mdiCupboard,\n/* harmony export */   \"mdiCupboardOutline\": () => /* binding */ mdiCupboardOutline,\n/* harmony export */   \"mdiCupcake\": () => /* binding */ mdiCupcake,\n/* harmony export */   \"mdiCurling\": () => /* binding */ mdiCurling,\n/* harmony export */   \"mdiCurrencyBdt\": () => /* binding */ mdiCurrencyBdt,\n/* harmony export */   \"mdiCurrencyBrl\": () => /* binding */ mdiCurrencyBrl,\n/* harmony export */   \"mdiCurrencyBtc\": () => /* binding */ mdiCurrencyBtc,\n/* harmony export */   \"mdiCurrencyCny\": () => /* binding */ mdiCurrencyCny,\n/* harmony export */   \"mdiCurrencyEth\": () => /* binding */ mdiCurrencyEth,\n/* harmony export */   \"mdiCurrencyEur\": () => /* binding */ mdiCurrencyEur,\n/* harmony export */   \"mdiCurrencyEurOff\": () => /* binding */ mdiCurrencyEurOff,\n/* harmony export */   \"mdiCurrencyGbp\": () => /* binding */ mdiCurrencyGbp,\n/* harmony export */   \"mdiCurrencyIls\": () => /* binding */ mdiCurrencyIls,\n/* harmony export */   \"mdiCurrencyInr\": () => /* binding */ mdiCurrencyInr,\n/* harmony export */   \"mdiCurrencyJpy\": () => /* binding */ mdiCurrencyJpy,\n/* harmony export */   \"mdiCurrencyKrw\": () => /* binding */ mdiCurrencyKrw,\n/* harmony export */   \"mdiCurrencyKzt\": () => /* binding */ mdiCurrencyKzt,\n/* harmony export */   \"mdiCurrencyMnt\": () => /* binding */ mdiCurrencyMnt,\n/* harmony export */   \"mdiCurrencyNgn\": () => /* binding */ mdiCurrencyNgn,\n/* harmony export */   \"mdiCurrencyPhp\": () => /* binding */ mdiCurrencyPhp,\n/* harmony export */   \"mdiCurrencyRial\": () => /* binding */ mdiCurrencyRial,\n/* harmony export */   \"mdiCurrencyRub\": () => /* binding */ mdiCurrencyRub,\n/* harmony export */   \"mdiCurrencySign\": () => /* binding */ mdiCurrencySign,\n/* harmony export */   \"mdiCurrencyTry\": () => /* binding */ mdiCurrencyTry,\n/* harmony export */   \"mdiCurrencyTwd\": () => /* binding */ mdiCurrencyTwd,\n/* harmony export */   \"mdiCurrencyUsd\": () => /* binding */ mdiCurrencyUsd,\n/* harmony export */   \"mdiCurrencyUsdCircle\": () => /* binding */ mdiCurrencyUsdCircle,\n/* harmony export */   \"mdiCurrencyUsdCircleOutline\": () => /* binding */ mdiCurrencyUsdCircleOutline,\n/* harmony export */   \"mdiCurrencyUsdOff\": () => /* binding */ mdiCurrencyUsdOff,\n/* harmony export */   \"mdiCurrentAc\": () => /* binding */ mdiCurrentAc,\n/* harmony export */   \"mdiCurrentDc\": () => /* binding */ mdiCurrentDc,\n/* harmony export */   \"mdiCursorDefault\": () => /* binding */ mdiCursorDefault,\n/* harmony export */   \"mdiCursorDefaultClick\": () => /* binding */ mdiCursorDefaultClick,\n/* harmony export */   \"mdiCursorDefaultClickOutline\": () => /* binding */ mdiCursorDefaultClickOutline,\n/* harmony export */   \"mdiCursorDefaultGesture\": () => /* binding */ mdiCursorDefaultGesture,\n/* harmony export */   \"mdiCursorDefaultGestureOutline\": () => /* binding */ mdiCursorDefaultGestureOutline,\n/* harmony export */   \"mdiCursorDefaultOutline\": () => /* binding */ mdiCursorDefaultOutline,\n/* harmony export */   \"mdiCursorMove\": () => /* binding */ mdiCursorMove,\n/* harmony export */   \"mdiCursorPointer\": () => /* binding */ mdiCursorPointer,\n/* harmony export */   \"mdiCursorText\": () => /* binding */ mdiCursorText,\n/* harmony export */   \"mdiDanceBallroom\": () => /* binding */ mdiDanceBallroom,\n/* harmony export */   \"mdiDancePole\": () => /* binding */ mdiDancePole,\n/* harmony export */   \"mdiDataMatrix\": () => /* binding */ mdiDataMatrix,\n/* harmony export */   \"mdiDataMatrixEdit\": () => /* binding */ mdiDataMatrixEdit,\n/* harmony export */   \"mdiDataMatrixMinus\": () => /* binding */ mdiDataMatrixMinus,\n/* harmony export */   \"mdiDataMatrixPlus\": () => /* binding */ mdiDataMatrixPlus,\n/* harmony export */   \"mdiDataMatrixRemove\": () => /* binding */ mdiDataMatrixRemove,\n/* harmony export */   \"mdiDataMatrixScan\": () => /* binding */ mdiDataMatrixScan,\n/* harmony export */   \"mdiDatabase\": () => /* binding */ mdiDatabase,\n/* harmony export */   \"mdiDatabaseCheck\": () => /* binding */ mdiDatabaseCheck,\n/* harmony export */   \"mdiDatabaseEdit\": () => /* binding */ mdiDatabaseEdit,\n/* harmony export */   \"mdiDatabaseExport\": () => /* binding */ mdiDatabaseExport,\n/* harmony export */   \"mdiDatabaseImport\": () => /* binding */ mdiDatabaseImport,\n/* harmony export */   \"mdiDatabaseLock\": () => /* binding */ mdiDatabaseLock,\n/* harmony export */   \"mdiDatabaseMarker\": () => /* binding */ mdiDatabaseMarker,\n/* harmony export */   \"mdiDatabaseMinus\": () => /* binding */ mdiDatabaseMinus,\n/* harmony export */   \"mdiDatabasePlus\": () => /* binding */ mdiDatabasePlus,\n/* harmony export */   \"mdiDatabaseRefresh\": () => /* binding */ mdiDatabaseRefresh,\n/* harmony export */   \"mdiDatabaseRemove\": () => /* binding */ mdiDatabaseRemove,\n/* harmony export */   \"mdiDatabaseSearch\": () => /* binding */ mdiDatabaseSearch,\n/* harmony export */   \"mdiDatabaseSettings\": () => /* binding */ mdiDatabaseSettings,\n/* harmony export */   \"mdiDatabaseSync\": () => /* binding */ mdiDatabaseSync,\n/* harmony export */   \"mdiDeathStar\": () => /* binding */ mdiDeathStar,\n/* harmony export */   \"mdiDeathStarVariant\": () => /* binding */ mdiDeathStarVariant,\n/* harmony export */   \"mdiDeathlyHallows\": () => /* binding */ mdiDeathlyHallows,\n/* harmony export */   \"mdiDebian\": () => /* binding */ mdiDebian,\n/* harmony export */   \"mdiDebugStepInto\": () => /* binding */ mdiDebugStepInto,\n/* harmony export */   \"mdiDebugStepOut\": () => /* binding */ mdiDebugStepOut,\n/* harmony export */   \"mdiDebugStepOver\": () => /* binding */ mdiDebugStepOver,\n/* harmony export */   \"mdiDecagram\": () => /* binding */ mdiDecagram,\n/* harmony export */   \"mdiDecagramOutline\": () => /* binding */ mdiDecagramOutline,\n/* harmony export */   \"mdiDecimal\": () => /* binding */ mdiDecimal,\n/* harmony export */   \"mdiDecimalComma\": () => /* binding */ mdiDecimalComma,\n/* harmony export */   \"mdiDecimalCommaDecrease\": () => /* binding */ mdiDecimalCommaDecrease,\n/* harmony export */   \"mdiDecimalCommaIncrease\": () => /* binding */ mdiDecimalCommaIncrease,\n/* harmony export */   \"mdiDecimalDecrease\": () => /* binding */ mdiDecimalDecrease,\n/* harmony export */   \"mdiDecimalIncrease\": () => /* binding */ mdiDecimalIncrease,\n/* harmony export */   \"mdiDelete\": () => /* binding */ mdiDelete,\n/* harmony export */   \"mdiDeleteAlert\": () => /* binding */ mdiDeleteAlert,\n/* harmony export */   \"mdiDeleteAlertOutline\": () => /* binding */ mdiDeleteAlertOutline,\n/* harmony export */   \"mdiDeleteCircle\": () => /* binding */ mdiDeleteCircle,\n/* harmony export */   \"mdiDeleteCircleOutline\": () => /* binding */ mdiDeleteCircleOutline,\n/* harmony export */   \"mdiDeleteClock\": () => /* binding */ mdiDeleteClock,\n/* harmony export */   \"mdiDeleteClockOutline\": () => /* binding */ mdiDeleteClockOutline,\n/* harmony export */   \"mdiDeleteEmpty\": () => /* binding */ mdiDeleteEmpty,\n/* harmony export */   \"mdiDeleteEmptyOutline\": () => /* binding */ mdiDeleteEmptyOutline,\n/* harmony export */   \"mdiDeleteForever\": () => /* binding */ mdiDeleteForever,\n/* harmony export */   \"mdiDeleteForeverOutline\": () => /* binding */ mdiDeleteForeverOutline,\n/* harmony export */   \"mdiDeleteOff\": () => /* binding */ mdiDeleteOff,\n/* harmony export */   \"mdiDeleteOffOutline\": () => /* binding */ mdiDeleteOffOutline,\n/* harmony export */   \"mdiDeleteOutline\": () => /* binding */ mdiDeleteOutline,\n/* harmony export */   \"mdiDeleteRestore\": () => /* binding */ mdiDeleteRestore,\n/* harmony export */   \"mdiDeleteSweep\": () => /* binding */ mdiDeleteSweep,\n/* harmony export */   \"mdiDeleteSweepOutline\": () => /* binding */ mdiDeleteSweepOutline,\n/* harmony export */   \"mdiDeleteVariant\": () => /* binding */ mdiDeleteVariant,\n/* harmony export */   \"mdiDelta\": () => /* binding */ mdiDelta,\n/* harmony export */   \"mdiDesk\": () => /* binding */ mdiDesk,\n/* harmony export */   \"mdiDeskLamp\": () => /* binding */ mdiDeskLamp,\n/* harmony export */   \"mdiDeskphone\": () => /* binding */ mdiDeskphone,\n/* harmony export */   \"mdiDesktopClassic\": () => /* binding */ mdiDesktopClassic,\n/* harmony export */   \"mdiDesktopMac\": () => /* binding */ mdiDesktopMac,\n/* harmony export */   \"mdiDesktopMacDashboard\": () => /* binding */ mdiDesktopMacDashboard,\n/* harmony export */   \"mdiDesktopTower\": () => /* binding */ mdiDesktopTower,\n/* harmony export */   \"mdiDesktopTowerMonitor\": () => /* binding */ mdiDesktopTowerMonitor,\n/* harmony export */   \"mdiDetails\": () => /* binding */ mdiDetails,\n/* harmony export */   \"mdiDevTo\": () => /* binding */ mdiDevTo,\n/* harmony export */   \"mdiDeveloperBoard\": () => /* binding */ mdiDeveloperBoard,\n/* harmony export */   \"mdiDeviantart\": () => /* binding */ mdiDeviantart,\n/* harmony export */   \"mdiDevices\": () => /* binding */ mdiDevices,\n/* harmony export */   \"mdiDiabetes\": () => /* binding */ mdiDiabetes,\n/* harmony export */   \"mdiDialpad\": () => /* binding */ mdiDialpad,\n/* harmony export */   \"mdiDiameter\": () => /* binding */ mdiDiameter,\n/* harmony export */   \"mdiDiameterOutline\": () => /* binding */ mdiDiameterOutline,\n/* harmony export */   \"mdiDiameterVariant\": () => /* binding */ mdiDiameterVariant,\n/* harmony export */   \"mdiDiamond\": () => /* binding */ mdiDiamond,\n/* harmony export */   \"mdiDiamondOutline\": () => /* binding */ mdiDiamondOutline,\n/* harmony export */   \"mdiDiamondStone\": () => /* binding */ mdiDiamondStone,\n/* harmony export */   \"mdiDice1\": () => /* binding */ mdiDice1,\n/* harmony export */   \"mdiDice1Outline\": () => /* binding */ mdiDice1Outline,\n/* harmony export */   \"mdiDice2\": () => /* binding */ mdiDice2,\n/* harmony export */   \"mdiDice2Outline\": () => /* binding */ mdiDice2Outline,\n/* harmony export */   \"mdiDice3\": () => /* binding */ mdiDice3,\n/* harmony export */   \"mdiDice3Outline\": () => /* binding */ mdiDice3Outline,\n/* harmony export */   \"mdiDice4\": () => /* binding */ mdiDice4,\n/* harmony export */   \"mdiDice4Outline\": () => /* binding */ mdiDice4Outline,\n/* harmony export */   \"mdiDice5\": () => /* binding */ mdiDice5,\n/* harmony export */   \"mdiDice5Outline\": () => /* binding */ mdiDice5Outline,\n/* harmony export */   \"mdiDice6\": () => /* binding */ mdiDice6,\n/* harmony export */   \"mdiDice6Outline\": () => /* binding */ mdiDice6Outline,\n/* harmony export */   \"mdiDiceD10\": () => /* binding */ mdiDiceD10,\n/* harmony export */   \"mdiDiceD10Outline\": () => /* binding */ mdiDiceD10Outline,\n/* harmony export */   \"mdiDiceD12\": () => /* binding */ mdiDiceD12,\n/* harmony export */   \"mdiDiceD12Outline\": () => /* binding */ mdiDiceD12Outline,\n/* harmony export */   \"mdiDiceD20\": () => /* binding */ mdiDiceD20,\n/* harmony export */   \"mdiDiceD20Outline\": () => /* binding */ mdiDiceD20Outline,\n/* harmony export */   \"mdiDiceD4\": () => /* binding */ mdiDiceD4,\n/* harmony export */   \"mdiDiceD4Outline\": () => /* binding */ mdiDiceD4Outline,\n/* harmony export */   \"mdiDiceD6\": () => /* binding */ mdiDiceD6,\n/* harmony export */   \"mdiDiceD6Outline\": () => /* binding */ mdiDiceD6Outline,\n/* harmony export */   \"mdiDiceD8\": () => /* binding */ mdiDiceD8,\n/* harmony export */   \"mdiDiceD8Outline\": () => /* binding */ mdiDiceD8Outline,\n/* harmony export */   \"mdiDiceMultiple\": () => /* binding */ mdiDiceMultiple,\n/* harmony export */   \"mdiDiceMultipleOutline\": () => /* binding */ mdiDiceMultipleOutline,\n/* harmony export */   \"mdiDigitalOcean\": () => /* binding */ mdiDigitalOcean,\n/* harmony export */   \"mdiDipSwitch\": () => /* binding */ mdiDipSwitch,\n/* harmony export */   \"mdiDirections\": () => /* binding */ mdiDirections,\n/* harmony export */   \"mdiDirectionsFork\": () => /* binding */ mdiDirectionsFork,\n/* harmony export */   \"mdiDisc\": () => /* binding */ mdiDisc,\n/* harmony export */   \"mdiDiscAlert\": () => /* binding */ mdiDiscAlert,\n/* harmony export */   \"mdiDiscPlayer\": () => /* binding */ mdiDiscPlayer,\n/* harmony export */   \"mdiDiscord\": () => /* binding */ mdiDiscord,\n/* harmony export */   \"mdiDishwasher\": () => /* binding */ mdiDishwasher,\n/* harmony export */   \"mdiDishwasherAlert\": () => /* binding */ mdiDishwasherAlert,\n/* harmony export */   \"mdiDishwasherOff\": () => /* binding */ mdiDishwasherOff,\n/* harmony export */   \"mdiDisqus\": () => /* binding */ mdiDisqus,\n/* harmony export */   \"mdiDistributeHorizontalCenter\": () => /* binding */ mdiDistributeHorizontalCenter,\n/* harmony export */   \"mdiDistributeHorizontalLeft\": () => /* binding */ mdiDistributeHorizontalLeft,\n/* harmony export */   \"mdiDistributeHorizontalRight\": () => /* binding */ mdiDistributeHorizontalRight,\n/* harmony export */   \"mdiDistributeVerticalBottom\": () => /* binding */ mdiDistributeVerticalBottom,\n/* harmony export */   \"mdiDistributeVerticalCenter\": () => /* binding */ mdiDistributeVerticalCenter,\n/* harmony export */   \"mdiDistributeVerticalTop\": () => /* binding */ mdiDistributeVerticalTop,\n/* harmony export */   \"mdiDivingFlippers\": () => /* binding */ mdiDivingFlippers,\n/* harmony export */   \"mdiDivingHelmet\": () => /* binding */ mdiDivingHelmet,\n/* harmony export */   \"mdiDivingScuba\": () => /* binding */ mdiDivingScuba,\n/* harmony export */   \"mdiDivingScubaFlag\": () => /* binding */ mdiDivingScubaFlag,\n/* harmony export */   \"mdiDivingScubaTank\": () => /* binding */ mdiDivingScubaTank,\n/* harmony export */   \"mdiDivingScubaTankMultiple\": () => /* binding */ mdiDivingScubaTankMultiple,\n/* harmony export */   \"mdiDivingSnorkel\": () => /* binding */ mdiDivingSnorkel,\n/* harmony export */   \"mdiDivision\": () => /* binding */ mdiDivision,\n/* harmony export */   \"mdiDivisionBox\": () => /* binding */ mdiDivisionBox,\n/* harmony export */   \"mdiDlna\": () => /* binding */ mdiDlna,\n/* harmony export */   \"mdiDna\": () => /* binding */ mdiDna,\n/* harmony export */   \"mdiDns\": () => /* binding */ mdiDns,\n/* harmony export */   \"mdiDnsOutline\": () => /* binding */ mdiDnsOutline,\n/* harmony export */   \"mdiDoNotDisturb\": () => /* binding */ mdiDoNotDisturb,\n/* harmony export */   \"mdiDoNotDisturbOff\": () => /* binding */ mdiDoNotDisturbOff,\n/* harmony export */   \"mdiDockBottom\": () => /* binding */ mdiDockBottom,\n/* harmony export */   \"mdiDockLeft\": () => /* binding */ mdiDockLeft,\n/* harmony export */   \"mdiDockRight\": () => /* binding */ mdiDockRight,\n/* harmony export */   \"mdiDockTop\": () => /* binding */ mdiDockTop,\n/* harmony export */   \"mdiDockWindow\": () => /* binding */ mdiDockWindow,\n/* harmony export */   \"mdiDocker\": () => /* binding */ mdiDocker,\n/* harmony export */   \"mdiDoctor\": () => /* binding */ mdiDoctor,\n/* harmony export */   \"mdiDog\": () => /* binding */ mdiDog,\n/* harmony export */   \"mdiDogService\": () => /* binding */ mdiDogService,\n/* harmony export */   \"mdiDogSide\": () => /* binding */ mdiDogSide,\n/* harmony export */   \"mdiDolby\": () => /* binding */ mdiDolby,\n/* harmony export */   \"mdiDolly\": () => /* binding */ mdiDolly,\n/* harmony export */   \"mdiDomain\": () => /* binding */ mdiDomain,\n/* harmony export */   \"mdiDomainOff\": () => /* binding */ mdiDomainOff,\n/* harmony export */   \"mdiDomainPlus\": () => /* binding */ mdiDomainPlus,\n/* harmony export */   \"mdiDomainRemove\": () => /* binding */ mdiDomainRemove,\n/* harmony export */   \"mdiDomeLight\": () => /* binding */ mdiDomeLight,\n/* harmony export */   \"mdiDominoMask\": () => /* binding */ mdiDominoMask,\n/* harmony export */   \"mdiDonkey\": () => /* binding */ mdiDonkey,\n/* harmony export */   \"mdiDoor\": () => /* binding */ mdiDoor,\n/* harmony export */   \"mdiDoorClosed\": () => /* binding */ mdiDoorClosed,\n/* harmony export */   \"mdiDoorClosedLock\": () => /* binding */ mdiDoorClosedLock,\n/* harmony export */   \"mdiDoorOpen\": () => /* binding */ mdiDoorOpen,\n/* harmony export */   \"mdiDoorbell\": () => /* binding */ mdiDoorbell,\n/* harmony export */   \"mdiDoorbellVideo\": () => /* binding */ mdiDoorbellVideo,\n/* harmony export */   \"mdiDotNet\": () => /* binding */ mdiDotNet,\n/* harmony export */   \"mdiDotsGrid\": () => /* binding */ mdiDotsGrid,\n/* harmony export */   \"mdiDotsHexagon\": () => /* binding */ mdiDotsHexagon,\n/* harmony export */   \"mdiDotsHorizontal\": () => /* binding */ mdiDotsHorizontal,\n/* harmony export */   \"mdiDotsHorizontalCircle\": () => /* binding */ mdiDotsHorizontalCircle,\n/* harmony export */   \"mdiDotsHorizontalCircleOutline\": () => /* binding */ mdiDotsHorizontalCircleOutline,\n/* harmony export */   \"mdiDotsSquare\": () => /* binding */ mdiDotsSquare,\n/* harmony export */   \"mdiDotsTriangle\": () => /* binding */ mdiDotsTriangle,\n/* harmony export */   \"mdiDotsVertical\": () => /* binding */ mdiDotsVertical,\n/* harmony export */   \"mdiDotsVerticalCircle\": () => /* binding */ mdiDotsVerticalCircle,\n/* harmony export */   \"mdiDotsVerticalCircleOutline\": () => /* binding */ mdiDotsVerticalCircleOutline,\n/* harmony export */   \"mdiDouban\": () => /* binding */ mdiDouban,\n/* harmony export */   \"mdiDownload\": () => /* binding */ mdiDownload,\n/* harmony export */   \"mdiDownloadBox\": () => /* binding */ mdiDownloadBox,\n/* harmony export */   \"mdiDownloadBoxOutline\": () => /* binding */ mdiDownloadBoxOutline,\n/* harmony export */   \"mdiDownloadCircle\": () => /* binding */ mdiDownloadCircle,\n/* harmony export */   \"mdiDownloadCircleOutline\": () => /* binding */ mdiDownloadCircleOutline,\n/* harmony export */   \"mdiDownloadLock\": () => /* binding */ mdiDownloadLock,\n/* harmony export */   \"mdiDownloadLockOutline\": () => /* binding */ mdiDownloadLockOutline,\n/* harmony export */   \"mdiDownloadMultiple\": () => /* binding */ mdiDownloadMultiple,\n/* harmony export */   \"mdiDownloadNetwork\": () => /* binding */ mdiDownloadNetwork,\n/* harmony export */   \"mdiDownloadNetworkOutline\": () => /* binding */ mdiDownloadNetworkOutline,\n/* harmony export */   \"mdiDownloadOff\": () => /* binding */ mdiDownloadOff,\n/* harmony export */   \"mdiDownloadOffOutline\": () => /* binding */ mdiDownloadOffOutline,\n/* harmony export */   \"mdiDownloadOutline\": () => /* binding */ mdiDownloadOutline,\n/* harmony export */   \"mdiDrag\": () => /* binding */ mdiDrag,\n/* harmony export */   \"mdiDragHorizontal\": () => /* binding */ mdiDragHorizontal,\n/* harmony export */   \"mdiDragHorizontalVariant\": () => /* binding */ mdiDragHorizontalVariant,\n/* harmony export */   \"mdiDragVariant\": () => /* binding */ mdiDragVariant,\n/* harmony export */   \"mdiDragVertical\": () => /* binding */ mdiDragVertical,\n/* harmony export */   \"mdiDragVerticalVariant\": () => /* binding */ mdiDragVerticalVariant,\n/* harmony export */   \"mdiDramaMasks\": () => /* binding */ mdiDramaMasks,\n/* harmony export */   \"mdiDraw\": () => /* binding */ mdiDraw,\n/* harmony export */   \"mdiDrawing\": () => /* binding */ mdiDrawing,\n/* harmony export */   \"mdiDrawingBox\": () => /* binding */ mdiDrawingBox,\n/* harmony export */   \"mdiDresser\": () => /* binding */ mdiDresser,\n/* harmony export */   \"mdiDresserOutline\": () => /* binding */ mdiDresserOutline,\n/* harmony export */   \"mdiDrone\": () => /* binding */ mdiDrone,\n/* harmony export */   \"mdiDropbox\": () => /* binding */ mdiDropbox,\n/* harmony export */   \"mdiDrupal\": () => /* binding */ mdiDrupal,\n/* harmony export */   \"mdiDuck\": () => /* binding */ mdiDuck,\n/* harmony export */   \"mdiDumbbell\": () => /* binding */ mdiDumbbell,\n/* harmony export */   \"mdiDumpTruck\": () => /* binding */ mdiDumpTruck,\n/* harmony export */   \"mdiEarHearing\": () => /* binding */ mdiEarHearing,\n/* harmony export */   \"mdiEarHearingOff\": () => /* binding */ mdiEarHearingOff,\n/* harmony export */   \"mdiEarth\": () => /* binding */ mdiEarth,\n/* harmony export */   \"mdiEarthArrowRight\": () => /* binding */ mdiEarthArrowRight,\n/* harmony export */   \"mdiEarthBox\": () => /* binding */ mdiEarthBox,\n/* harmony export */   \"mdiEarthBoxMinus\": () => /* binding */ mdiEarthBoxMinus,\n/* harmony export */   \"mdiEarthBoxOff\": () => /* binding */ mdiEarthBoxOff,\n/* harmony export */   \"mdiEarthBoxPlus\": () => /* binding */ mdiEarthBoxPlus,\n/* harmony export */   \"mdiEarthBoxRemove\": () => /* binding */ mdiEarthBoxRemove,\n/* harmony export */   \"mdiEarthMinus\": () => /* binding */ mdiEarthMinus,\n/* harmony export */   \"mdiEarthOff\": () => /* binding */ mdiEarthOff,\n/* harmony export */   \"mdiEarthPlus\": () => /* binding */ mdiEarthPlus,\n/* harmony export */   \"mdiEarthRemove\": () => /* binding */ mdiEarthRemove,\n/* harmony export */   \"mdiEgg\": () => /* binding */ mdiEgg,\n/* harmony export */   \"mdiEggEaster\": () => /* binding */ mdiEggEaster,\n/* harmony export */   \"mdiEggOff\": () => /* binding */ mdiEggOff,\n/* harmony export */   \"mdiEggOffOutline\": () => /* binding */ mdiEggOffOutline,\n/* harmony export */   \"mdiEggOutline\": () => /* binding */ mdiEggOutline,\n/* harmony export */   \"mdiEiffelTower\": () => /* binding */ mdiEiffelTower,\n/* harmony export */   \"mdiEightTrack\": () => /* binding */ mdiEightTrack,\n/* harmony export */   \"mdiEject\": () => /* binding */ mdiEject,\n/* harmony export */   \"mdiEjectOutline\": () => /* binding */ mdiEjectOutline,\n/* harmony export */   \"mdiElectricSwitch\": () => /* binding */ mdiElectricSwitch,\n/* harmony export */   \"mdiElectricSwitchClosed\": () => /* binding */ mdiElectricSwitchClosed,\n/* harmony export */   \"mdiElectronFramework\": () => /* binding */ mdiElectronFramework,\n/* harmony export */   \"mdiElephant\": () => /* binding */ mdiElephant,\n/* harmony export */   \"mdiElevationDecline\": () => /* binding */ mdiElevationDecline,\n/* harmony export */   \"mdiElevationRise\": () => /* binding */ mdiElevationRise,\n/* harmony export */   \"mdiElevator\": () => /* binding */ mdiElevator,\n/* harmony export */   \"mdiElevatorDown\": () => /* binding */ mdiElevatorDown,\n/* harmony export */   \"mdiElevatorPassenger\": () => /* binding */ mdiElevatorPassenger,\n/* harmony export */   \"mdiElevatorUp\": () => /* binding */ mdiElevatorUp,\n/* harmony export */   \"mdiEllipse\": () => /* binding */ mdiEllipse,\n/* harmony export */   \"mdiEllipseOutline\": () => /* binding */ mdiEllipseOutline,\n/* harmony export */   \"mdiEmail\": () => /* binding */ mdiEmail,\n/* harmony export */   \"mdiEmailAlert\": () => /* binding */ mdiEmailAlert,\n/* harmony export */   \"mdiEmailAlertOutline\": () => /* binding */ mdiEmailAlertOutline,\n/* harmony export */   \"mdiEmailBox\": () => /* binding */ mdiEmailBox,\n/* harmony export */   \"mdiEmailCheck\": () => /* binding */ mdiEmailCheck,\n/* harmony export */   \"mdiEmailCheckOutline\": () => /* binding */ mdiEmailCheckOutline,\n/* harmony export */   \"mdiEmailEdit\": () => /* binding */ mdiEmailEdit,\n/* harmony export */   \"mdiEmailEditOutline\": () => /* binding */ mdiEmailEditOutline,\n/* harmony export */   \"mdiEmailLock\": () => /* binding */ mdiEmailLock,\n/* harmony export */   \"mdiEmailMarkAsUnread\": () => /* binding */ mdiEmailMarkAsUnread,\n/* harmony export */   \"mdiEmailMinus\": () => /* binding */ mdiEmailMinus,\n/* harmony export */   \"mdiEmailMinusOutline\": () => /* binding */ mdiEmailMinusOutline,\n/* harmony export */   \"mdiEmailMultiple\": () => /* binding */ mdiEmailMultiple,\n/* harmony export */   \"mdiEmailMultipleOutline\": () => /* binding */ mdiEmailMultipleOutline,\n/* harmony export */   \"mdiEmailNewsletter\": () => /* binding */ mdiEmailNewsletter,\n/* harmony export */   \"mdiEmailOff\": () => /* binding */ mdiEmailOff,\n/* harmony export */   \"mdiEmailOffOutline\": () => /* binding */ mdiEmailOffOutline,\n/* harmony export */   \"mdiEmailOpen\": () => /* binding */ mdiEmailOpen,\n/* harmony export */   \"mdiEmailOpenMultiple\": () => /* binding */ mdiEmailOpenMultiple,\n/* harmony export */   \"mdiEmailOpenMultipleOutline\": () => /* binding */ mdiEmailOpenMultipleOutline,\n/* harmony export */   \"mdiEmailOpenOutline\": () => /* binding */ mdiEmailOpenOutline,\n/* harmony export */   \"mdiEmailOutline\": () => /* binding */ mdiEmailOutline,\n/* harmony export */   \"mdiEmailPlus\": () => /* binding */ mdiEmailPlus,\n/* harmony export */   \"mdiEmailPlusOutline\": () => /* binding */ mdiEmailPlusOutline,\n/* harmony export */   \"mdiEmailReceive\": () => /* binding */ mdiEmailReceive,\n/* harmony export */   \"mdiEmailReceiveOutline\": () => /* binding */ mdiEmailReceiveOutline,\n/* harmony export */   \"mdiEmailSearch\": () => /* binding */ mdiEmailSearch,\n/* harmony export */   \"mdiEmailSearchOutline\": () => /* binding */ mdiEmailSearchOutline,\n/* harmony export */   \"mdiEmailSend\": () => /* binding */ mdiEmailSend,\n/* harmony export */   \"mdiEmailSendOutline\": () => /* binding */ mdiEmailSendOutline,\n/* harmony export */   \"mdiEmailSync\": () => /* binding */ mdiEmailSync,\n/* harmony export */   \"mdiEmailSyncOutline\": () => /* binding */ mdiEmailSyncOutline,\n/* harmony export */   \"mdiEmailVariant\": () => /* binding */ mdiEmailVariant,\n/* harmony export */   \"mdiEmber\": () => /* binding */ mdiEmber,\n/* harmony export */   \"mdiEmby\": () => /* binding */ mdiEmby,\n/* harmony export */   \"mdiEmoticon\": () => /* binding */ mdiEmoticon,\n/* harmony export */   \"mdiEmoticonAngry\": () => /* binding */ mdiEmoticonAngry,\n/* harmony export */   \"mdiEmoticonAngryOutline\": () => /* binding */ mdiEmoticonAngryOutline,\n/* harmony export */   \"mdiEmoticonConfused\": () => /* binding */ mdiEmoticonConfused,\n/* harmony export */   \"mdiEmoticonConfusedOutline\": () => /* binding */ mdiEmoticonConfusedOutline,\n/* harmony export */   \"mdiEmoticonCool\": () => /* binding */ mdiEmoticonCool,\n/* harmony export */   \"mdiEmoticonCoolOutline\": () => /* binding */ mdiEmoticonCoolOutline,\n/* harmony export */   \"mdiEmoticonCry\": () => /* binding */ mdiEmoticonCry,\n/* harmony export */   \"mdiEmoticonCryOutline\": () => /* binding */ mdiEmoticonCryOutline,\n/* harmony export */   \"mdiEmoticonDead\": () => /* binding */ mdiEmoticonDead,\n/* harmony export */   \"mdiEmoticonDeadOutline\": () => /* binding */ mdiEmoticonDeadOutline,\n/* harmony export */   \"mdiEmoticonDevil\": () => /* binding */ mdiEmoticonDevil,\n/* harmony export */   \"mdiEmoticonDevilOutline\": () => /* binding */ mdiEmoticonDevilOutline,\n/* harmony export */   \"mdiEmoticonExcited\": () => /* binding */ mdiEmoticonExcited,\n/* harmony export */   \"mdiEmoticonExcitedOutline\": () => /* binding */ mdiEmoticonExcitedOutline,\n/* harmony export */   \"mdiEmoticonFrown\": () => /* binding */ mdiEmoticonFrown,\n/* harmony export */   \"mdiEmoticonFrownOutline\": () => /* binding */ mdiEmoticonFrownOutline,\n/* harmony export */   \"mdiEmoticonHappy\": () => /* binding */ mdiEmoticonHappy,\n/* harmony export */   \"mdiEmoticonHappyOutline\": () => /* binding */ mdiEmoticonHappyOutline,\n/* harmony export */   \"mdiEmoticonKiss\": () => /* binding */ mdiEmoticonKiss,\n/* harmony export */   \"mdiEmoticonKissOutline\": () => /* binding */ mdiEmoticonKissOutline,\n/* harmony export */   \"mdiEmoticonLol\": () => /* binding */ mdiEmoticonLol,\n/* harmony export */   \"mdiEmoticonLolOutline\": () => /* binding */ mdiEmoticonLolOutline,\n/* harmony export */   \"mdiEmoticonNeutral\": () => /* binding */ mdiEmoticonNeutral,\n/* harmony export */   \"mdiEmoticonNeutralOutline\": () => /* binding */ mdiEmoticonNeutralOutline,\n/* harmony export */   \"mdiEmoticonOutline\": () => /* binding */ mdiEmoticonOutline,\n/* harmony export */   \"mdiEmoticonPoop\": () => /* binding */ mdiEmoticonPoop,\n/* harmony export */   \"mdiEmoticonPoopOutline\": () => /* binding */ mdiEmoticonPoopOutline,\n/* harmony export */   \"mdiEmoticonSad\": () => /* binding */ mdiEmoticonSad,\n/* harmony export */   \"mdiEmoticonSadOutline\": () => /* binding */ mdiEmoticonSadOutline,\n/* harmony export */   \"mdiEmoticonSick\": () => /* binding */ mdiEmoticonSick,\n/* harmony export */   \"mdiEmoticonSickOutline\": () => /* binding */ mdiEmoticonSickOutline,\n/* harmony export */   \"mdiEmoticonTongue\": () => /* binding */ mdiEmoticonTongue,\n/* harmony export */   \"mdiEmoticonTongueOutline\": () => /* binding */ mdiEmoticonTongueOutline,\n/* harmony export */   \"mdiEmoticonWink\": () => /* binding */ mdiEmoticonWink,\n/* harmony export */   \"mdiEmoticonWinkOutline\": () => /* binding */ mdiEmoticonWinkOutline,\n/* harmony export */   \"mdiEngine\": () => /* binding */ mdiEngine,\n/* harmony export */   \"mdiEngineOff\": () => /* binding */ mdiEngineOff,\n/* harmony export */   \"mdiEngineOffOutline\": () => /* binding */ mdiEngineOffOutline,\n/* harmony export */   \"mdiEngineOutline\": () => /* binding */ mdiEngineOutline,\n/* harmony export */   \"mdiEpsilon\": () => /* binding */ mdiEpsilon,\n/* harmony export */   \"mdiEqual\": () => /* binding */ mdiEqual,\n/* harmony export */   \"mdiEqualBox\": () => /* binding */ mdiEqualBox,\n/* harmony export */   \"mdiEqualizer\": () => /* binding */ mdiEqualizer,\n/* harmony export */   \"mdiEqualizerOutline\": () => /* binding */ mdiEqualizerOutline,\n/* harmony export */   \"mdiEraser\": () => /* binding */ mdiEraser,\n/* harmony export */   \"mdiEraserVariant\": () => /* binding */ mdiEraserVariant,\n/* harmony export */   \"mdiEscalator\": () => /* binding */ mdiEscalator,\n/* harmony export */   \"mdiEscalatorBox\": () => /* binding */ mdiEscalatorBox,\n/* harmony export */   \"mdiEscalatorDown\": () => /* binding */ mdiEscalatorDown,\n/* harmony export */   \"mdiEscalatorUp\": () => /* binding */ mdiEscalatorUp,\n/* harmony export */   \"mdiEslint\": () => /* binding */ mdiEslint,\n/* harmony export */   \"mdiEt\": () => /* binding */ mdiEt,\n/* harmony export */   \"mdiEthereum\": () => /* binding */ mdiEthereum,\n/* harmony export */   \"mdiEthernet\": () => /* binding */ mdiEthernet,\n/* harmony export */   \"mdiEthernetCable\": () => /* binding */ mdiEthernetCable,\n/* harmony export */   \"mdiEthernetCableOff\": () => /* binding */ mdiEthernetCableOff,\n/* harmony export */   \"mdiEvPlugCcs1\": () => /* binding */ mdiEvPlugCcs1,\n/* harmony export */   \"mdiEvPlugCcs2\": () => /* binding */ mdiEvPlugCcs2,\n/* harmony export */   \"mdiEvPlugChademo\": () => /* binding */ mdiEvPlugChademo,\n/* harmony export */   \"mdiEvPlugTesla\": () => /* binding */ mdiEvPlugTesla,\n/* harmony export */   \"mdiEvPlugType1\": () => /* binding */ mdiEvPlugType1,\n/* harmony export */   \"mdiEvPlugType2\": () => /* binding */ mdiEvPlugType2,\n/* harmony export */   \"mdiEvStation\": () => /* binding */ mdiEvStation,\n/* harmony export */   \"mdiEvernote\": () => /* binding */ mdiEvernote,\n/* harmony export */   \"mdiExcavator\": () => /* binding */ mdiExcavator,\n/* harmony export */   \"mdiExclamation\": () => /* binding */ mdiExclamation,\n/* harmony export */   \"mdiExclamationThick\": () => /* binding */ mdiExclamationThick,\n/* harmony export */   \"mdiExitRun\": () => /* binding */ mdiExitRun,\n/* harmony export */   \"mdiExitToApp\": () => /* binding */ mdiExitToApp,\n/* harmony export */   \"mdiExpandAll\": () => /* binding */ mdiExpandAll,\n/* harmony export */   \"mdiExpandAllOutline\": () => /* binding */ mdiExpandAllOutline,\n/* harmony export */   \"mdiExpansionCard\": () => /* binding */ mdiExpansionCard,\n/* harmony export */   \"mdiExpansionCardVariant\": () => /* binding */ mdiExpansionCardVariant,\n/* harmony export */   \"mdiExponent\": () => /* binding */ mdiExponent,\n/* harmony export */   \"mdiExponentBox\": () => /* binding */ mdiExponentBox,\n/* harmony export */   \"mdiExport\": () => /* binding */ mdiExport,\n/* harmony export */   \"mdiExportVariant\": () => /* binding */ mdiExportVariant,\n/* harmony export */   \"mdiEye\": () => /* binding */ mdiEye,\n/* harmony export */   \"mdiEyeCheck\": () => /* binding */ mdiEyeCheck,\n/* harmony export */   \"mdiEyeCheckOutline\": () => /* binding */ mdiEyeCheckOutline,\n/* harmony export */   \"mdiEyeCircle\": () => /* binding */ mdiEyeCircle,\n/* harmony export */   \"mdiEyeCircleOutline\": () => /* binding */ mdiEyeCircleOutline,\n/* harmony export */   \"mdiEyeMinus\": () => /* binding */ mdiEyeMinus,\n/* harmony export */   \"mdiEyeMinusOutline\": () => /* binding */ mdiEyeMinusOutline,\n/* harmony export */   \"mdiEyeOff\": () => /* binding */ mdiEyeOff,\n/* harmony export */   \"mdiEyeOffOutline\": () => /* binding */ mdiEyeOffOutline,\n/* harmony export */   \"mdiEyeOutline\": () => /* binding */ mdiEyeOutline,\n/* harmony export */   \"mdiEyePlus\": () => /* binding */ mdiEyePlus,\n/* harmony export */   \"mdiEyePlusOutline\": () => /* binding */ mdiEyePlusOutline,\n/* harmony export */   \"mdiEyeRemove\": () => /* binding */ mdiEyeRemove,\n/* harmony export */   \"mdiEyeRemoveOutline\": () => /* binding */ mdiEyeRemoveOutline,\n/* harmony export */   \"mdiEyeSettings\": () => /* binding */ mdiEyeSettings,\n/* harmony export */   \"mdiEyeSettingsOutline\": () => /* binding */ mdiEyeSettingsOutline,\n/* harmony export */   \"mdiEyedropper\": () => /* binding */ mdiEyedropper,\n/* harmony export */   \"mdiEyedropperMinus\": () => /* binding */ mdiEyedropperMinus,\n/* harmony export */   \"mdiEyedropperOff\": () => /* binding */ mdiEyedropperOff,\n/* harmony export */   \"mdiEyedropperPlus\": () => /* binding */ mdiEyedropperPlus,\n/* harmony export */   \"mdiEyedropperRemove\": () => /* binding */ mdiEyedropperRemove,\n/* harmony export */   \"mdiEyedropperVariant\": () => /* binding */ mdiEyedropperVariant,\n/* harmony export */   \"mdiFace\": () => /* binding */ mdiFace,\n/* harmony export */   \"mdiFaceAgent\": () => /* binding */ mdiFaceAgent,\n/* harmony export */   \"mdiFaceMask\": () => /* binding */ mdiFaceMask,\n/* harmony export */   \"mdiFaceMaskOutline\": () => /* binding */ mdiFaceMaskOutline,\n/* harmony export */   \"mdiFaceOutline\": () => /* binding */ mdiFaceOutline,\n/* harmony export */   \"mdiFaceProfile\": () => /* binding */ mdiFaceProfile,\n/* harmony export */   \"mdiFaceProfileWoman\": () => /* binding */ mdiFaceProfileWoman,\n/* harmony export */   \"mdiFaceRecognition\": () => /* binding */ mdiFaceRecognition,\n/* harmony export */   \"mdiFaceShimmer\": () => /* binding */ mdiFaceShimmer,\n/* harmony export */   \"mdiFaceShimmerOutline\": () => /* binding */ mdiFaceShimmerOutline,\n/* harmony export */   \"mdiFaceWoman\": () => /* binding */ mdiFaceWoman,\n/* harmony export */   \"mdiFaceWomanOutline\": () => /* binding */ mdiFaceWomanOutline,\n/* harmony export */   \"mdiFaceWomanShimmer\": () => /* binding */ mdiFaceWomanShimmer,\n/* harmony export */   \"mdiFaceWomanShimmerOutline\": () => /* binding */ mdiFaceWomanShimmerOutline,\n/* harmony export */   \"mdiFacebook\": () => /* binding */ mdiFacebook,\n/* harmony export */   \"mdiFacebookGaming\": () => /* binding */ mdiFacebookGaming,\n/* harmony export */   \"mdiFacebookMessenger\": () => /* binding */ mdiFacebookMessenger,\n/* harmony export */   \"mdiFacebookWorkplace\": () => /* binding */ mdiFacebookWorkplace,\n/* harmony export */   \"mdiFactory\": () => /* binding */ mdiFactory,\n/* harmony export */   \"mdiFamilyTree\": () => /* binding */ mdiFamilyTree,\n/* harmony export */   \"mdiFan\": () => /* binding */ mdiFan,\n/* harmony export */   \"mdiFanAlert\": () => /* binding */ mdiFanAlert,\n/* harmony export */   \"mdiFanChevronDown\": () => /* binding */ mdiFanChevronDown,\n/* harmony export */   \"mdiFanChevronUp\": () => /* binding */ mdiFanChevronUp,\n/* harmony export */   \"mdiFanMinus\": () => /* binding */ mdiFanMinus,\n/* harmony export */   \"mdiFanOff\": () => /* binding */ mdiFanOff,\n/* harmony export */   \"mdiFanPlus\": () => /* binding */ mdiFanPlus,\n/* harmony export */   \"mdiFanRemove\": () => /* binding */ mdiFanRemove,\n/* harmony export */   \"mdiFanSpeed1\": () => /* binding */ mdiFanSpeed1,\n/* harmony export */   \"mdiFanSpeed2\": () => /* binding */ mdiFanSpeed2,\n/* harmony export */   \"mdiFanSpeed3\": () => /* binding */ mdiFanSpeed3,\n/* harmony export */   \"mdiFastForward\": () => /* binding */ mdiFastForward,\n/* harmony export */   \"mdiFastForward10\": () => /* binding */ mdiFastForward10,\n/* harmony export */   \"mdiFastForward30\": () => /* binding */ mdiFastForward30,\n/* harmony export */   \"mdiFastForward5\": () => /* binding */ mdiFastForward5,\n/* harmony export */   \"mdiFastForward60\": () => /* binding */ mdiFastForward60,\n/* harmony export */   \"mdiFastForwardOutline\": () => /* binding */ mdiFastForwardOutline,\n/* harmony export */   \"mdiFax\": () => /* binding */ mdiFax,\n/* harmony export */   \"mdiFeather\": () => /* binding */ mdiFeather,\n/* harmony export */   \"mdiFeatureSearch\": () => /* binding */ mdiFeatureSearch,\n/* harmony export */   \"mdiFeatureSearchOutline\": () => /* binding */ mdiFeatureSearchOutline,\n/* harmony export */   \"mdiFedora\": () => /* binding */ mdiFedora,\n/* harmony export */   \"mdiFencing\": () => /* binding */ mdiFencing,\n/* harmony export */   \"mdiFerrisWheel\": () => /* binding */ mdiFerrisWheel,\n/* harmony export */   \"mdiFerry\": () => /* binding */ mdiFerry,\n/* harmony export */   \"mdiFile\": () => /* binding */ mdiFile,\n/* harmony export */   \"mdiFileAccount\": () => /* binding */ mdiFileAccount,\n/* harmony export */   \"mdiFileAccountOutline\": () => /* binding */ mdiFileAccountOutline,\n/* harmony export */   \"mdiFileAlert\": () => /* binding */ mdiFileAlert,\n/* harmony export */   \"mdiFileAlertOutline\": () => /* binding */ mdiFileAlertOutline,\n/* harmony export */   \"mdiFileCabinet\": () => /* binding */ mdiFileCabinet,\n/* harmony export */   \"mdiFileCad\": () => /* binding */ mdiFileCad,\n/* harmony export */   \"mdiFileCadBox\": () => /* binding */ mdiFileCadBox,\n/* harmony export */   \"mdiFileCancel\": () => /* binding */ mdiFileCancel,\n/* harmony export */   \"mdiFileCancelOutline\": () => /* binding */ mdiFileCancelOutline,\n/* harmony export */   \"mdiFileCertificate\": () => /* binding */ mdiFileCertificate,\n/* harmony export */   \"mdiFileCertificateOutline\": () => /* binding */ mdiFileCertificateOutline,\n/* harmony export */   \"mdiFileChart\": () => /* binding */ mdiFileChart,\n/* harmony export */   \"mdiFileChartOutline\": () => /* binding */ mdiFileChartOutline,\n/* harmony export */   \"mdiFileCheck\": () => /* binding */ mdiFileCheck,\n/* harmony export */   \"mdiFileCheckOutline\": () => /* binding */ mdiFileCheckOutline,\n/* harmony export */   \"mdiFileClock\": () => /* binding */ mdiFileClock,\n/* harmony export */   \"mdiFileClockOutline\": () => /* binding */ mdiFileClockOutline,\n/* harmony export */   \"mdiFileCloud\": () => /* binding */ mdiFileCloud,\n/* harmony export */   \"mdiFileCloudOutline\": () => /* binding */ mdiFileCloudOutline,\n/* harmony export */   \"mdiFileCode\": () => /* binding */ mdiFileCode,\n/* harmony export */   \"mdiFileCodeOutline\": () => /* binding */ mdiFileCodeOutline,\n/* harmony export */   \"mdiFileCog\": () => /* binding */ mdiFileCog,\n/* harmony export */   \"mdiFileCogOutline\": () => /* binding */ mdiFileCogOutline,\n/* harmony export */   \"mdiFileCompare\": () => /* binding */ mdiFileCompare,\n/* harmony export */   \"mdiFileDelimited\": () => /* binding */ mdiFileDelimited,\n/* harmony export */   \"mdiFileDelimitedOutline\": () => /* binding */ mdiFileDelimitedOutline,\n/* harmony export */   \"mdiFileDocument\": () => /* binding */ mdiFileDocument,\n/* harmony export */   \"mdiFileDocumentEdit\": () => /* binding */ mdiFileDocumentEdit,\n/* harmony export */   \"mdiFileDocumentEditOutline\": () => /* binding */ mdiFileDocumentEditOutline,\n/* harmony export */   \"mdiFileDocumentMultiple\": () => /* binding */ mdiFileDocumentMultiple,\n/* harmony export */   \"mdiFileDocumentMultipleOutline\": () => /* binding */ mdiFileDocumentMultipleOutline,\n/* harmony export */   \"mdiFileDocumentOutline\": () => /* binding */ mdiFileDocumentOutline,\n/* harmony export */   \"mdiFileDownload\": () => /* binding */ mdiFileDownload,\n/* harmony export */   \"mdiFileDownloadOutline\": () => /* binding */ mdiFileDownloadOutline,\n/* harmony export */   \"mdiFileEdit\": () => /* binding */ mdiFileEdit,\n/* harmony export */   \"mdiFileEditOutline\": () => /* binding */ mdiFileEditOutline,\n/* harmony export */   \"mdiFileExcel\": () => /* binding */ mdiFileExcel,\n/* harmony export */   \"mdiFileExcelBox\": () => /* binding */ mdiFileExcelBox,\n/* harmony export */   \"mdiFileExcelBoxOutline\": () => /* binding */ mdiFileExcelBoxOutline,\n/* harmony export */   \"mdiFileExcelOutline\": () => /* binding */ mdiFileExcelOutline,\n/* harmony export */   \"mdiFileExport\": () => /* binding */ mdiFileExport,\n/* harmony export */   \"mdiFileExportOutline\": () => /* binding */ mdiFileExportOutline,\n/* harmony export */   \"mdiFileEye\": () => /* binding */ mdiFileEye,\n/* harmony export */   \"mdiFileEyeOutline\": () => /* binding */ mdiFileEyeOutline,\n/* harmony export */   \"mdiFileFind\": () => /* binding */ mdiFileFind,\n/* harmony export */   \"mdiFileFindOutline\": () => /* binding */ mdiFileFindOutline,\n/* harmony export */   \"mdiFileHidden\": () => /* binding */ mdiFileHidden,\n/* harmony export */   \"mdiFileImage\": () => /* binding */ mdiFileImage,\n/* harmony export */   \"mdiFileImageOutline\": () => /* binding */ mdiFileImageOutline,\n/* harmony export */   \"mdiFileImport\": () => /* binding */ mdiFileImport,\n/* harmony export */   \"mdiFileImportOutline\": () => /* binding */ mdiFileImportOutline,\n/* harmony export */   \"mdiFileKey\": () => /* binding */ mdiFileKey,\n/* harmony export */   \"mdiFileKeyOutline\": () => /* binding */ mdiFileKeyOutline,\n/* harmony export */   \"mdiFileLink\": () => /* binding */ mdiFileLink,\n/* harmony export */   \"mdiFileLinkOutline\": () => /* binding */ mdiFileLinkOutline,\n/* harmony export */   \"mdiFileLock\": () => /* binding */ mdiFileLock,\n/* harmony export */   \"mdiFileLockOutline\": () => /* binding */ mdiFileLockOutline,\n/* harmony export */   \"mdiFileMove\": () => /* binding */ mdiFileMove,\n/* harmony export */   \"mdiFileMoveOutline\": () => /* binding */ mdiFileMoveOutline,\n/* harmony export */   \"mdiFileMultiple\": () => /* binding */ mdiFileMultiple,\n/* harmony export */   \"mdiFileMultipleOutline\": () => /* binding */ mdiFileMultipleOutline,\n/* harmony export */   \"mdiFileMusic\": () => /* binding */ mdiFileMusic,\n/* harmony export */   \"mdiFileMusicOutline\": () => /* binding */ mdiFileMusicOutline,\n/* harmony export */   \"mdiFileOutline\": () => /* binding */ mdiFileOutline,\n/* harmony export */   \"mdiFilePdf\": () => /* binding */ mdiFilePdf,\n/* harmony export */   \"mdiFilePdfBox\": () => /* binding */ mdiFilePdfBox,\n/* harmony export */   \"mdiFilePdfBoxOutline\": () => /* binding */ mdiFilePdfBoxOutline,\n/* harmony export */   \"mdiFilePdfOutline\": () => /* binding */ mdiFilePdfOutline,\n/* harmony export */   \"mdiFilePercent\": () => /* binding */ mdiFilePercent,\n/* harmony export */   \"mdiFilePercentOutline\": () => /* binding */ mdiFilePercentOutline,\n/* harmony export */   \"mdiFilePhone\": () => /* binding */ mdiFilePhone,\n/* harmony export */   \"mdiFilePhoneOutline\": () => /* binding */ mdiFilePhoneOutline,\n/* harmony export */   \"mdiFilePlus\": () => /* binding */ mdiFilePlus,\n/* harmony export */   \"mdiFilePlusOutline\": () => /* binding */ mdiFilePlusOutline,\n/* harmony export */   \"mdiFilePowerpoint\": () => /* binding */ mdiFilePowerpoint,\n/* harmony export */   \"mdiFilePowerpointBox\": () => /* binding */ mdiFilePowerpointBox,\n/* harmony export */   \"mdiFilePowerpointBoxOutline\": () => /* binding */ mdiFilePowerpointBoxOutline,\n/* harmony export */   \"mdiFilePowerpointOutline\": () => /* binding */ mdiFilePowerpointOutline,\n/* harmony export */   \"mdiFilePresentationBox\": () => /* binding */ mdiFilePresentationBox,\n/* harmony export */   \"mdiFileQuestion\": () => /* binding */ mdiFileQuestion,\n/* harmony export */   \"mdiFileQuestionOutline\": () => /* binding */ mdiFileQuestionOutline,\n/* harmony export */   \"mdiFileRefresh\": () => /* binding */ mdiFileRefresh,\n/* harmony export */   \"mdiFileRefreshOutline\": () => /* binding */ mdiFileRefreshOutline,\n/* harmony export */   \"mdiFileRemove\": () => /* binding */ mdiFileRemove,\n/* harmony export */   \"mdiFileRemoveOutline\": () => /* binding */ mdiFileRemoveOutline,\n/* harmony export */   \"mdiFileReplace\": () => /* binding */ mdiFileReplace,\n/* harmony export */   \"mdiFileReplaceOutline\": () => /* binding */ mdiFileReplaceOutline,\n/* harmony export */   \"mdiFileRestore\": () => /* binding */ mdiFileRestore,\n/* harmony export */   \"mdiFileRestoreOutline\": () => /* binding */ mdiFileRestoreOutline,\n/* harmony export */   \"mdiFileSearch\": () => /* binding */ mdiFileSearch,\n/* harmony export */   \"mdiFileSearchOutline\": () => /* binding */ mdiFileSearchOutline,\n/* harmony export */   \"mdiFileSend\": () => /* binding */ mdiFileSend,\n/* harmony export */   \"mdiFileSendOutline\": () => /* binding */ mdiFileSendOutline,\n/* harmony export */   \"mdiFileSettings\": () => /* binding */ mdiFileSettings,\n/* harmony export */   \"mdiFileSettingsOutline\": () => /* binding */ mdiFileSettingsOutline,\n/* harmony export */   \"mdiFileStar\": () => /* binding */ mdiFileStar,\n/* harmony export */   \"mdiFileStarOutline\": () => /* binding */ mdiFileStarOutline,\n/* harmony export */   \"mdiFileSwap\": () => /* binding */ mdiFileSwap,\n/* harmony export */   \"mdiFileSwapOutline\": () => /* binding */ mdiFileSwapOutline,\n/* harmony export */   \"mdiFileSync\": () => /* binding */ mdiFileSync,\n/* harmony export */   \"mdiFileSyncOutline\": () => /* binding */ mdiFileSyncOutline,\n/* harmony export */   \"mdiFileTable\": () => /* binding */ mdiFileTable,\n/* harmony export */   \"mdiFileTableBox\": () => /* binding */ mdiFileTableBox,\n/* harmony export */   \"mdiFileTableBoxMultiple\": () => /* binding */ mdiFileTableBoxMultiple,\n/* harmony export */   \"mdiFileTableBoxMultipleOutline\": () => /* binding */ mdiFileTableBoxMultipleOutline,\n/* harmony export */   \"mdiFileTableBoxOutline\": () => /* binding */ mdiFileTableBoxOutline,\n/* harmony export */   \"mdiFileTableOutline\": () => /* binding */ mdiFileTableOutline,\n/* harmony export */   \"mdiFileTree\": () => /* binding */ mdiFileTree,\n/* harmony export */   \"mdiFileTreeOutline\": () => /* binding */ mdiFileTreeOutline,\n/* harmony export */   \"mdiFileUndo\": () => /* binding */ mdiFileUndo,\n/* harmony export */   \"mdiFileUndoOutline\": () => /* binding */ mdiFileUndoOutline,\n/* harmony export */   \"mdiFileUpload\": () => /* binding */ mdiFileUpload,\n/* harmony export */   \"mdiFileUploadOutline\": () => /* binding */ mdiFileUploadOutline,\n/* harmony export */   \"mdiFileVideo\": () => /* binding */ mdiFileVideo,\n/* harmony export */   \"mdiFileVideoOutline\": () => /* binding */ mdiFileVideoOutline,\n/* harmony export */   \"mdiFileWord\": () => /* binding */ mdiFileWord,\n/* harmony export */   \"mdiFileWordBox\": () => /* binding */ mdiFileWordBox,\n/* harmony export */   \"mdiFileWordBoxOutline\": () => /* binding */ mdiFileWordBoxOutline,\n/* harmony export */   \"mdiFileWordOutline\": () => /* binding */ mdiFileWordOutline,\n/* harmony export */   \"mdiFilm\": () => /* binding */ mdiFilm,\n/* harmony export */   \"mdiFilmstrip\": () => /* binding */ mdiFilmstrip,\n/* harmony export */   \"mdiFilmstripBox\": () => /* binding */ mdiFilmstripBox,\n/* harmony export */   \"mdiFilmstripBoxMultiple\": () => /* binding */ mdiFilmstripBoxMultiple,\n/* harmony export */   \"mdiFilmstripOff\": () => /* binding */ mdiFilmstripOff,\n/* harmony export */   \"mdiFilter\": () => /* binding */ mdiFilter,\n/* harmony export */   \"mdiFilterMenu\": () => /* binding */ mdiFilterMenu,\n/* harmony export */   \"mdiFilterMenuOutline\": () => /* binding */ mdiFilterMenuOutline,\n/* harmony export */   \"mdiFilterMinus\": () => /* binding */ mdiFilterMinus,\n/* harmony export */   \"mdiFilterMinusOutline\": () => /* binding */ mdiFilterMinusOutline,\n/* harmony export */   \"mdiFilterOff\": () => /* binding */ mdiFilterOff,\n/* harmony export */   \"mdiFilterOffOutline\": () => /* binding */ mdiFilterOffOutline,\n/* harmony export */   \"mdiFilterOutline\": () => /* binding */ mdiFilterOutline,\n/* harmony export */   \"mdiFilterPlus\": () => /* binding */ mdiFilterPlus,\n/* harmony export */   \"mdiFilterPlusOutline\": () => /* binding */ mdiFilterPlusOutline,\n/* harmony export */   \"mdiFilterRemove\": () => /* binding */ mdiFilterRemove,\n/* harmony export */   \"mdiFilterRemoveOutline\": () => /* binding */ mdiFilterRemoveOutline,\n/* harmony export */   \"mdiFilterVariant\": () => /* binding */ mdiFilterVariant,\n/* harmony export */   \"mdiFilterVariantMinus\": () => /* binding */ mdiFilterVariantMinus,\n/* harmony export */   \"mdiFilterVariantPlus\": () => /* binding */ mdiFilterVariantPlus,\n/* harmony export */   \"mdiFilterVariantRemove\": () => /* binding */ mdiFilterVariantRemove,\n/* harmony export */   \"mdiFinance\": () => /* binding */ mdiFinance,\n/* harmony export */   \"mdiFindReplace\": () => /* binding */ mdiFindReplace,\n/* harmony export */   \"mdiFingerprint\": () => /* binding */ mdiFingerprint,\n/* harmony export */   \"mdiFingerprintOff\": () => /* binding */ mdiFingerprintOff,\n/* harmony export */   \"mdiFire\": () => /* binding */ mdiFire,\n/* harmony export */   \"mdiFireAlert\": () => /* binding */ mdiFireAlert,\n/* harmony export */   \"mdiFireExtinguisher\": () => /* binding */ mdiFireExtinguisher,\n/* harmony export */   \"mdiFireHydrant\": () => /* binding */ mdiFireHydrant,\n/* harmony export */   \"mdiFireHydrantAlert\": () => /* binding */ mdiFireHydrantAlert,\n/* harmony export */   \"mdiFireHydrantOff\": () => /* binding */ mdiFireHydrantOff,\n/* harmony export */   \"mdiFireTruck\": () => /* binding */ mdiFireTruck,\n/* harmony export */   \"mdiFirebase\": () => /* binding */ mdiFirebase,\n/* harmony export */   \"mdiFirefox\": () => /* binding */ mdiFirefox,\n/* harmony export */   \"mdiFireplace\": () => /* binding */ mdiFireplace,\n/* harmony export */   \"mdiFireplaceOff\": () => /* binding */ mdiFireplaceOff,\n/* harmony export */   \"mdiFirework\": () => /* binding */ mdiFirework,\n/* harmony export */   \"mdiFish\": () => /* binding */ mdiFish,\n/* harmony export */   \"mdiFishOff\": () => /* binding */ mdiFishOff,\n/* harmony export */   \"mdiFishbowl\": () => /* binding */ mdiFishbowl,\n/* harmony export */   \"mdiFishbowlOutline\": () => /* binding */ mdiFishbowlOutline,\n/* harmony export */   \"mdiFitToPage\": () => /* binding */ mdiFitToPage,\n/* harmony export */   \"mdiFitToPageOutline\": () => /* binding */ mdiFitToPageOutline,\n/* harmony export */   \"mdiFlag\": () => /* binding */ mdiFlag,\n/* harmony export */   \"mdiFlagCheckered\": () => /* binding */ mdiFlagCheckered,\n/* harmony export */   \"mdiFlagMinus\": () => /* binding */ mdiFlagMinus,\n/* harmony export */   \"mdiFlagMinusOutline\": () => /* binding */ mdiFlagMinusOutline,\n/* harmony export */   \"mdiFlagOutline\": () => /* binding */ mdiFlagOutline,\n/* harmony export */   \"mdiFlagPlus\": () => /* binding */ mdiFlagPlus,\n/* harmony export */   \"mdiFlagPlusOutline\": () => /* binding */ mdiFlagPlusOutline,\n/* harmony export */   \"mdiFlagRemove\": () => /* binding */ mdiFlagRemove,\n/* harmony export */   \"mdiFlagRemoveOutline\": () => /* binding */ mdiFlagRemoveOutline,\n/* harmony export */   \"mdiFlagTriangle\": () => /* binding */ mdiFlagTriangle,\n/* harmony export */   \"mdiFlagVariant\": () => /* binding */ mdiFlagVariant,\n/* harmony export */   \"mdiFlagVariantOutline\": () => /* binding */ mdiFlagVariantOutline,\n/* harmony export */   \"mdiFlare\": () => /* binding */ mdiFlare,\n/* harmony export */   \"mdiFlash\": () => /* binding */ mdiFlash,\n/* harmony export */   \"mdiFlashAlert\": () => /* binding */ mdiFlashAlert,\n/* harmony export */   \"mdiFlashAlertOutline\": () => /* binding */ mdiFlashAlertOutline,\n/* harmony export */   \"mdiFlashAuto\": () => /* binding */ mdiFlashAuto,\n/* harmony export */   \"mdiFlashCircle\": () => /* binding */ mdiFlashCircle,\n/* harmony export */   \"mdiFlashOff\": () => /* binding */ mdiFlashOff,\n/* harmony export */   \"mdiFlashOutline\": () => /* binding */ mdiFlashOutline,\n/* harmony export */   \"mdiFlashRedEye\": () => /* binding */ mdiFlashRedEye,\n/* harmony export */   \"mdiFlashlight\": () => /* binding */ mdiFlashlight,\n/* harmony export */   \"mdiFlashlightOff\": () => /* binding */ mdiFlashlightOff,\n/* harmony export */   \"mdiFlask\": () => /* binding */ mdiFlask,\n/* harmony export */   \"mdiFlaskEmpty\": () => /* binding */ mdiFlaskEmpty,\n/* harmony export */   \"mdiFlaskEmptyMinus\": () => /* binding */ mdiFlaskEmptyMinus,\n/* harmony export */   \"mdiFlaskEmptyMinusOutline\": () => /* binding */ mdiFlaskEmptyMinusOutline,\n/* harmony export */   \"mdiFlaskEmptyOff\": () => /* binding */ mdiFlaskEmptyOff,\n/* harmony export */   \"mdiFlaskEmptyOffOutline\": () => /* binding */ mdiFlaskEmptyOffOutline,\n/* harmony export */   \"mdiFlaskEmptyOutline\": () => /* binding */ mdiFlaskEmptyOutline,\n/* harmony export */   \"mdiFlaskEmptyPlus\": () => /* binding */ mdiFlaskEmptyPlus,\n/* harmony export */   \"mdiFlaskEmptyPlusOutline\": () => /* binding */ mdiFlaskEmptyPlusOutline,\n/* harmony export */   \"mdiFlaskEmptyRemove\": () => /* binding */ mdiFlaskEmptyRemove,\n/* harmony export */   \"mdiFlaskEmptyRemoveOutline\": () => /* binding */ mdiFlaskEmptyRemoveOutline,\n/* harmony export */   \"mdiFlaskMinus\": () => /* binding */ mdiFlaskMinus,\n/* harmony export */   \"mdiFlaskMinusOutline\": () => /* binding */ mdiFlaskMinusOutline,\n/* harmony export */   \"mdiFlaskOff\": () => /* binding */ mdiFlaskOff,\n/* harmony export */   \"mdiFlaskOffOutline\": () => /* binding */ mdiFlaskOffOutline,\n/* harmony export */   \"mdiFlaskOutline\": () => /* binding */ mdiFlaskOutline,\n/* harmony export */   \"mdiFlaskPlus\": () => /* binding */ mdiFlaskPlus,\n/* harmony export */   \"mdiFlaskPlusOutline\": () => /* binding */ mdiFlaskPlusOutline,\n/* harmony export */   \"mdiFlaskRemove\": () => /* binding */ mdiFlaskRemove,\n/* harmony export */   \"mdiFlaskRemoveOutline\": () => /* binding */ mdiFlaskRemoveOutline,\n/* harmony export */   \"mdiFlaskRoundBottom\": () => /* binding */ mdiFlaskRoundBottom,\n/* harmony export */   \"mdiFlaskRoundBottomEmpty\": () => /* binding */ mdiFlaskRoundBottomEmpty,\n/* harmony export */   \"mdiFlaskRoundBottomEmptyOutline\": () => /* binding */ mdiFlaskRoundBottomEmptyOutline,\n/* harmony export */   \"mdiFlaskRoundBottomOutline\": () => /* binding */ mdiFlaskRoundBottomOutline,\n/* harmony export */   \"mdiFleurDeLis\": () => /* binding */ mdiFleurDeLis,\n/* harmony export */   \"mdiFlipHorizontal\": () => /* binding */ mdiFlipHorizontal,\n/* harmony export */   \"mdiFlipToBack\": () => /* binding */ mdiFlipToBack,\n/* harmony export */   \"mdiFlipToFront\": () => /* binding */ mdiFlipToFront,\n/* harmony export */   \"mdiFlipVertical\": () => /* binding */ mdiFlipVertical,\n/* harmony export */   \"mdiFloorLamp\": () => /* binding */ mdiFloorLamp,\n/* harmony export */   \"mdiFloorLampDual\": () => /* binding */ mdiFloorLampDual,\n/* harmony export */   \"mdiFloorLampVariant\": () => /* binding */ mdiFloorLampVariant,\n/* harmony export */   \"mdiFloorPlan\": () => /* binding */ mdiFloorPlan,\n/* harmony export */   \"mdiFloppy\": () => /* binding */ mdiFloppy,\n/* harmony export */   \"mdiFloppyVariant\": () => /* binding */ mdiFloppyVariant,\n/* harmony export */   \"mdiFlower\": () => /* binding */ mdiFlower,\n/* harmony export */   \"mdiFlowerOutline\": () => /* binding */ mdiFlowerOutline,\n/* harmony export */   \"mdiFlowerPoppy\": () => /* binding */ mdiFlowerPoppy,\n/* harmony export */   \"mdiFlowerTulip\": () => /* binding */ mdiFlowerTulip,\n/* harmony export */   \"mdiFlowerTulipOutline\": () => /* binding */ mdiFlowerTulipOutline,\n/* harmony export */   \"mdiFocusAuto\": () => /* binding */ mdiFocusAuto,\n/* harmony export */   \"mdiFocusField\": () => /* binding */ mdiFocusField,\n/* harmony export */   \"mdiFocusFieldHorizontal\": () => /* binding */ mdiFocusFieldHorizontal,\n/* harmony export */   \"mdiFocusFieldVertical\": () => /* binding */ mdiFocusFieldVertical,\n/* harmony export */   \"mdiFolder\": () => /* binding */ mdiFolder,\n/* harmony export */   \"mdiFolderAccount\": () => /* binding */ mdiFolderAccount,\n/* harmony export */   \"mdiFolderAccountOutline\": () => /* binding */ mdiFolderAccountOutline,\n/* harmony export */   \"mdiFolderAlert\": () => /* binding */ mdiFolderAlert,\n/* harmony export */   \"mdiFolderAlertOutline\": () => /* binding */ mdiFolderAlertOutline,\n/* harmony export */   \"mdiFolderClock\": () => /* binding */ mdiFolderClock,\n/* harmony export */   \"mdiFolderClockOutline\": () => /* binding */ mdiFolderClockOutline,\n/* harmony export */   \"mdiFolderCog\": () => /* binding */ mdiFolderCog,\n/* harmony export */   \"mdiFolderCogOutline\": () => /* binding */ mdiFolderCogOutline,\n/* harmony export */   \"mdiFolderDownload\": () => /* binding */ mdiFolderDownload,\n/* harmony export */   \"mdiFolderDownloadOutline\": () => /* binding */ mdiFolderDownloadOutline,\n/* harmony export */   \"mdiFolderEdit\": () => /* binding */ mdiFolderEdit,\n/* harmony export */   \"mdiFolderEditOutline\": () => /* binding */ mdiFolderEditOutline,\n/* harmony export */   \"mdiFolderGoogleDrive\": () => /* binding */ mdiFolderGoogleDrive,\n/* harmony export */   \"mdiFolderHeart\": () => /* binding */ mdiFolderHeart,\n/* harmony export */   \"mdiFolderHeartOutline\": () => /* binding */ mdiFolderHeartOutline,\n/* harmony export */   \"mdiFolderHome\": () => /* binding */ mdiFolderHome,\n/* harmony export */   \"mdiFolderHomeOutline\": () => /* binding */ mdiFolderHomeOutline,\n/* harmony export */   \"mdiFolderImage\": () => /* binding */ mdiFolderImage,\n/* harmony export */   \"mdiFolderInformation\": () => /* binding */ mdiFolderInformation,\n/* harmony export */   \"mdiFolderInformationOutline\": () => /* binding */ mdiFolderInformationOutline,\n/* harmony export */   \"mdiFolderKey\": () => /* binding */ mdiFolderKey,\n/* harmony export */   \"mdiFolderKeyNetwork\": () => /* binding */ mdiFolderKeyNetwork,\n/* harmony export */   \"mdiFolderKeyNetworkOutline\": () => /* binding */ mdiFolderKeyNetworkOutline,\n/* harmony export */   \"mdiFolderKeyOutline\": () => /* binding */ mdiFolderKeyOutline,\n/* harmony export */   \"mdiFolderLock\": () => /* binding */ mdiFolderLock,\n/* harmony export */   \"mdiFolderLockOpen\": () => /* binding */ mdiFolderLockOpen,\n/* harmony export */   \"mdiFolderMarker\": () => /* binding */ mdiFolderMarker,\n/* harmony export */   \"mdiFolderMarkerOutline\": () => /* binding */ mdiFolderMarkerOutline,\n/* harmony export */   \"mdiFolderMove\": () => /* binding */ mdiFolderMove,\n/* harmony export */   \"mdiFolderMoveOutline\": () => /* binding */ mdiFolderMoveOutline,\n/* harmony export */   \"mdiFolderMultiple\": () => /* binding */ mdiFolderMultiple,\n/* harmony export */   \"mdiFolderMultipleImage\": () => /* binding */ mdiFolderMultipleImage,\n/* harmony export */   \"mdiFolderMultipleOutline\": () => /* binding */ mdiFolderMultipleOutline,\n/* harmony export */   \"mdiFolderMultiplePlus\": () => /* binding */ mdiFolderMultiplePlus,\n/* harmony export */   \"mdiFolderMultiplePlusOutline\": () => /* binding */ mdiFolderMultiplePlusOutline,\n/* harmony export */   \"mdiFolderMusic\": () => /* binding */ mdiFolderMusic,\n/* harmony export */   \"mdiFolderMusicOutline\": () => /* binding */ mdiFolderMusicOutline,\n/* harmony export */   \"mdiFolderNetwork\": () => /* binding */ mdiFolderNetwork,\n/* harmony export */   \"mdiFolderNetworkOutline\": () => /* binding */ mdiFolderNetworkOutline,\n/* harmony export */   \"mdiFolderOpen\": () => /* binding */ mdiFolderOpen,\n/* harmony export */   \"mdiFolderOpenOutline\": () => /* binding */ mdiFolderOpenOutline,\n/* harmony export */   \"mdiFolderOutline\": () => /* binding */ mdiFolderOutline,\n/* harmony export */   \"mdiFolderPlus\": () => /* binding */ mdiFolderPlus,\n/* harmony export */   \"mdiFolderPlusOutline\": () => /* binding */ mdiFolderPlusOutline,\n/* harmony export */   \"mdiFolderPound\": () => /* binding */ mdiFolderPound,\n/* harmony export */   \"mdiFolderPoundOutline\": () => /* binding */ mdiFolderPoundOutline,\n/* harmony export */   \"mdiFolderRefresh\": () => /* binding */ mdiFolderRefresh,\n/* harmony export */   \"mdiFolderRefreshOutline\": () => /* binding */ mdiFolderRefreshOutline,\n/* harmony export */   \"mdiFolderRemove\": () => /* binding */ mdiFolderRemove,\n/* harmony export */   \"mdiFolderRemoveOutline\": () => /* binding */ mdiFolderRemoveOutline,\n/* harmony export */   \"mdiFolderSearch\": () => /* binding */ mdiFolderSearch,\n/* harmony export */   \"mdiFolderSearchOutline\": () => /* binding */ mdiFolderSearchOutline,\n/* harmony export */   \"mdiFolderSettings\": () => /* binding */ mdiFolderSettings,\n/* harmony export */   \"mdiFolderSettingsOutline\": () => /* binding */ mdiFolderSettingsOutline,\n/* harmony export */   \"mdiFolderStar\": () => /* binding */ mdiFolderStar,\n/* harmony export */   \"mdiFolderStarMultiple\": () => /* binding */ mdiFolderStarMultiple,\n/* harmony export */   \"mdiFolderStarMultipleOutline\": () => /* binding */ mdiFolderStarMultipleOutline,\n/* harmony export */   \"mdiFolderStarOutline\": () => /* binding */ mdiFolderStarOutline,\n/* harmony export */   \"mdiFolderSwap\": () => /* binding */ mdiFolderSwap,\n/* harmony export */   \"mdiFolderSwapOutline\": () => /* binding */ mdiFolderSwapOutline,\n/* harmony export */   \"mdiFolderSync\": () => /* binding */ mdiFolderSync,\n/* harmony export */   \"mdiFolderSyncOutline\": () => /* binding */ mdiFolderSyncOutline,\n/* harmony export */   \"mdiFolderTable\": () => /* binding */ mdiFolderTable,\n/* harmony export */   \"mdiFolderTableOutline\": () => /* binding */ mdiFolderTableOutline,\n/* harmony export */   \"mdiFolderText\": () => /* binding */ mdiFolderText,\n/* harmony export */   \"mdiFolderTextOutline\": () => /* binding */ mdiFolderTextOutline,\n/* harmony export */   \"mdiFolderUpload\": () => /* binding */ mdiFolderUpload,\n/* harmony export */   \"mdiFolderUploadOutline\": () => /* binding */ mdiFolderUploadOutline,\n/* harmony export */   \"mdiFolderZip\": () => /* binding */ mdiFolderZip,\n/* harmony export */   \"mdiFolderZipOutline\": () => /* binding */ mdiFolderZipOutline,\n/* harmony export */   \"mdiFontAwesome\": () => /* binding */ mdiFontAwesome,\n/* harmony export */   \"mdiFood\": () => /* binding */ mdiFood,\n/* harmony export */   \"mdiFoodApple\": () => /* binding */ mdiFoodApple,\n/* harmony export */   \"mdiFoodAppleOutline\": () => /* binding */ mdiFoodAppleOutline,\n/* harmony export */   \"mdiFoodCroissant\": () => /* binding */ mdiFoodCroissant,\n/* harmony export */   \"mdiFoodDrumstick\": () => /* binding */ mdiFoodDrumstick,\n/* harmony export */   \"mdiFoodDrumstickOff\": () => /* binding */ mdiFoodDrumstickOff,\n/* harmony export */   \"mdiFoodDrumstickOffOutline\": () => /* binding */ mdiFoodDrumstickOffOutline,\n/* harmony export */   \"mdiFoodDrumstickOutline\": () => /* binding */ mdiFoodDrumstickOutline,\n/* harmony export */   \"mdiFoodForkDrink\": () => /* binding */ mdiFoodForkDrink,\n/* harmony export */   \"mdiFoodHalal\": () => /* binding */ mdiFoodHalal,\n/* harmony export */   \"mdiFoodKosher\": () => /* binding */ mdiFoodKosher,\n/* harmony export */   \"mdiFoodOff\": () => /* binding */ mdiFoodOff,\n/* harmony export */   \"mdiFoodSteak\": () => /* binding */ mdiFoodSteak,\n/* harmony export */   \"mdiFoodSteakOff\": () => /* binding */ mdiFoodSteakOff,\n/* harmony export */   \"mdiFoodVariant\": () => /* binding */ mdiFoodVariant,\n/* harmony export */   \"mdiFoodVariantOff\": () => /* binding */ mdiFoodVariantOff,\n/* harmony export */   \"mdiFootPrint\": () => /* binding */ mdiFootPrint,\n/* harmony export */   \"mdiFootball\": () => /* binding */ mdiFootball,\n/* harmony export */   \"mdiFootballAustralian\": () => /* binding */ mdiFootballAustralian,\n/* harmony export */   \"mdiFootballHelmet\": () => /* binding */ mdiFootballHelmet,\n/* harmony export */   \"mdiForklift\": () => /* binding */ mdiForklift,\n/* harmony export */   \"mdiFormDropdown\": () => /* binding */ mdiFormDropdown,\n/* harmony export */   \"mdiFormSelect\": () => /* binding */ mdiFormSelect,\n/* harmony export */   \"mdiFormTextarea\": () => /* binding */ mdiFormTextarea,\n/* harmony export */   \"mdiFormTextbox\": () => /* binding */ mdiFormTextbox,\n/* harmony export */   \"mdiFormTextboxLock\": () => /* binding */ mdiFormTextboxLock,\n/* harmony export */   \"mdiFormTextboxPassword\": () => /* binding */ mdiFormTextboxPassword,\n/* harmony export */   \"mdiFormatAlignBottom\": () => /* binding */ mdiFormatAlignBottom,\n/* harmony export */   \"mdiFormatAlignCenter\": () => /* binding */ mdiFormatAlignCenter,\n/* harmony export */   \"mdiFormatAlignJustify\": () => /* binding */ mdiFormatAlignJustify,\n/* harmony export */   \"mdiFormatAlignLeft\": () => /* binding */ mdiFormatAlignLeft,\n/* harmony export */   \"mdiFormatAlignMiddle\": () => /* binding */ mdiFormatAlignMiddle,\n/* harmony export */   \"mdiFormatAlignRight\": () => /* binding */ mdiFormatAlignRight,\n/* harmony export */   \"mdiFormatAlignTop\": () => /* binding */ mdiFormatAlignTop,\n/* harmony export */   \"mdiFormatAnnotationMinus\": () => /* binding */ mdiFormatAnnotationMinus,\n/* harmony export */   \"mdiFormatAnnotationPlus\": () => /* binding */ mdiFormatAnnotationPlus,\n/* harmony export */   \"mdiFormatBold\": () => /* binding */ mdiFormatBold,\n/* harmony export */   \"mdiFormatClear\": () => /* binding */ mdiFormatClear,\n/* harmony export */   \"mdiFormatColorFill\": () => /* binding */ mdiFormatColorFill,\n/* harmony export */   \"mdiFormatColorHighlight\": () => /* binding */ mdiFormatColorHighlight,\n/* harmony export */   \"mdiFormatColorMarkerCancel\": () => /* binding */ mdiFormatColorMarkerCancel,\n/* harmony export */   \"mdiFormatColorText\": () => /* binding */ mdiFormatColorText,\n/* harmony export */   \"mdiFormatColumns\": () => /* binding */ mdiFormatColumns,\n/* harmony export */   \"mdiFormatFloatCenter\": () => /* binding */ mdiFormatFloatCenter,\n/* harmony export */   \"mdiFormatFloatLeft\": () => /* binding */ mdiFormatFloatLeft,\n/* harmony export */   \"mdiFormatFloatNone\": () => /* binding */ mdiFormatFloatNone,\n/* harmony export */   \"mdiFormatFloatRight\": () => /* binding */ mdiFormatFloatRight,\n/* harmony export */   \"mdiFormatFont\": () => /* binding */ mdiFormatFont,\n/* harmony export */   \"mdiFormatFontSizeDecrease\": () => /* binding */ mdiFormatFontSizeDecrease,\n/* harmony export */   \"mdiFormatFontSizeIncrease\": () => /* binding */ mdiFormatFontSizeIncrease,\n/* harmony export */   \"mdiFormatHeader1\": () => /* binding */ mdiFormatHeader1,\n/* harmony export */   \"mdiFormatHeader2\": () => /* binding */ mdiFormatHeader2,\n/* harmony export */   \"mdiFormatHeader3\": () => /* binding */ mdiFormatHeader3,\n/* harmony export */   \"mdiFormatHeader4\": () => /* binding */ mdiFormatHeader4,\n/* harmony export */   \"mdiFormatHeader5\": () => /* binding */ mdiFormatHeader5,\n/* harmony export */   \"mdiFormatHeader6\": () => /* binding */ mdiFormatHeader6,\n/* harmony export */   \"mdiFormatHeaderDecrease\": () => /* binding */ mdiFormatHeaderDecrease,\n/* harmony export */   \"mdiFormatHeaderEqual\": () => /* binding */ mdiFormatHeaderEqual,\n/* harmony export */   \"mdiFormatHeaderIncrease\": () => /* binding */ mdiFormatHeaderIncrease,\n/* harmony export */   \"mdiFormatHeaderPound\": () => /* binding */ mdiFormatHeaderPound,\n/* harmony export */   \"mdiFormatHorizontalAlignCenter\": () => /* binding */ mdiFormatHorizontalAlignCenter,\n/* harmony export */   \"mdiFormatHorizontalAlignLeft\": () => /* binding */ mdiFormatHorizontalAlignLeft,\n/* harmony export */   \"mdiFormatHorizontalAlignRight\": () => /* binding */ mdiFormatHorizontalAlignRight,\n/* harmony export */   \"mdiFormatIndentDecrease\": () => /* binding */ mdiFormatIndentDecrease,\n/* harmony export */   \"mdiFormatIndentIncrease\": () => /* binding */ mdiFormatIndentIncrease,\n/* harmony export */   \"mdiFormatItalic\": () => /* binding */ mdiFormatItalic,\n/* harmony export */   \"mdiFormatLetterCase\": () => /* binding */ mdiFormatLetterCase,\n/* harmony export */   \"mdiFormatLetterCaseLower\": () => /* binding */ mdiFormatLetterCaseLower,\n/* harmony export */   \"mdiFormatLetterCaseUpper\": () => /* binding */ mdiFormatLetterCaseUpper,\n/* harmony export */   \"mdiFormatLetterEndsWith\": () => /* binding */ mdiFormatLetterEndsWith,\n/* harmony export */   \"mdiFormatLetterMatches\": () => /* binding */ mdiFormatLetterMatches,\n/* harmony export */   \"mdiFormatLetterStartsWith\": () => /* binding */ mdiFormatLetterStartsWith,\n/* harmony export */   \"mdiFormatLineSpacing\": () => /* binding */ mdiFormatLineSpacing,\n/* harmony export */   \"mdiFormatLineStyle\": () => /* binding */ mdiFormatLineStyle,\n/* harmony export */   \"mdiFormatLineWeight\": () => /* binding */ mdiFormatLineWeight,\n/* harmony export */   \"mdiFormatListBulleted\": () => /* binding */ mdiFormatListBulleted,\n/* harmony export */   \"mdiFormatListBulletedSquare\": () => /* binding */ mdiFormatListBulletedSquare,\n/* harmony export */   \"mdiFormatListBulletedTriangle\": () => /* binding */ mdiFormatListBulletedTriangle,\n/* harmony export */   \"mdiFormatListBulletedType\": () => /* binding */ mdiFormatListBulletedType,\n/* harmony export */   \"mdiFormatListCheckbox\": () => /* binding */ mdiFormatListCheckbox,\n/* harmony export */   \"mdiFormatListChecks\": () => /* binding */ mdiFormatListChecks,\n/* harmony export */   \"mdiFormatListNumbered\": () => /* binding */ mdiFormatListNumbered,\n/* harmony export */   \"mdiFormatListNumberedRtl\": () => /* binding */ mdiFormatListNumberedRtl,\n/* harmony export */   \"mdiFormatListText\": () => /* binding */ mdiFormatListText,\n/* harmony export */   \"mdiFormatOverline\": () => /* binding */ mdiFormatOverline,\n/* harmony export */   \"mdiFormatPageBreak\": () => /* binding */ mdiFormatPageBreak,\n/* harmony export */   \"mdiFormatPaint\": () => /* binding */ mdiFormatPaint,\n/* harmony export */   \"mdiFormatParagraph\": () => /* binding */ mdiFormatParagraph,\n/* harmony export */   \"mdiFormatPilcrow\": () => /* binding */ mdiFormatPilcrow,\n/* harmony export */   \"mdiFormatQuoteClose\": () => /* binding */ mdiFormatQuoteClose,\n/* harmony export */   \"mdiFormatQuoteCloseOutline\": () => /* binding */ mdiFormatQuoteCloseOutline,\n/* harmony export */   \"mdiFormatQuoteOpen\": () => /* binding */ mdiFormatQuoteOpen,\n/* harmony export */   \"mdiFormatQuoteOpenOutline\": () => /* binding */ mdiFormatQuoteOpenOutline,\n/* harmony export */   \"mdiFormatRotate90\": () => /* binding */ mdiFormatRotate90,\n/* harmony export */   \"mdiFormatSection\": () => /* binding */ mdiFormatSection,\n/* harmony export */   \"mdiFormatSize\": () => /* binding */ mdiFormatSize,\n/* harmony export */   \"mdiFormatStrikethrough\": () => /* binding */ mdiFormatStrikethrough,\n/* harmony export */   \"mdiFormatStrikethroughVariant\": () => /* binding */ mdiFormatStrikethroughVariant,\n/* harmony export */   \"mdiFormatSubscript\": () => /* binding */ mdiFormatSubscript,\n/* harmony export */   \"mdiFormatSuperscript\": () => /* binding */ mdiFormatSuperscript,\n/* harmony export */   \"mdiFormatText\": () => /* binding */ mdiFormatText,\n/* harmony export */   \"mdiFormatTextRotationAngleDown\": () => /* binding */ mdiFormatTextRotationAngleDown,\n/* harmony export */   \"mdiFormatTextRotationAngleUp\": () => /* binding */ mdiFormatTextRotationAngleUp,\n/* harmony export */   \"mdiFormatTextRotationDown\": () => /* binding */ mdiFormatTextRotationDown,\n/* harmony export */   \"mdiFormatTextRotationDownVertical\": () => /* binding */ mdiFormatTextRotationDownVertical,\n/* harmony export */   \"mdiFormatTextRotationNone\": () => /* binding */ mdiFormatTextRotationNone,\n/* harmony export */   \"mdiFormatTextRotationUp\": () => /* binding */ mdiFormatTextRotationUp,\n/* harmony export */   \"mdiFormatTextRotationVertical\": () => /* binding */ mdiFormatTextRotationVertical,\n/* harmony export */   \"mdiFormatTextVariant\": () => /* binding */ mdiFormatTextVariant,\n/* harmony export */   \"mdiFormatTextVariantOutline\": () => /* binding */ mdiFormatTextVariantOutline,\n/* harmony export */   \"mdiFormatTextWrappingClip\": () => /* binding */ mdiFormatTextWrappingClip,\n/* harmony export */   \"mdiFormatTextWrappingOverflow\": () => /* binding */ mdiFormatTextWrappingOverflow,\n/* harmony export */   \"mdiFormatTextWrappingWrap\": () => /* binding */ mdiFormatTextWrappingWrap,\n/* harmony export */   \"mdiFormatTextbox\": () => /* binding */ mdiFormatTextbox,\n/* harmony export */   \"mdiFormatTextdirectionLToR\": () => /* binding */ mdiFormatTextdirectionLToR,\n/* harmony export */   \"mdiFormatTextdirectionRToL\": () => /* binding */ mdiFormatTextdirectionRToL,\n/* harmony export */   \"mdiFormatTitle\": () => /* binding */ mdiFormatTitle,\n/* harmony export */   \"mdiFormatUnderline\": () => /* binding */ mdiFormatUnderline,\n/* harmony export */   \"mdiFormatVerticalAlignBottom\": () => /* binding */ mdiFormatVerticalAlignBottom,\n/* harmony export */   \"mdiFormatVerticalAlignCenter\": () => /* binding */ mdiFormatVerticalAlignCenter,\n/* harmony export */   \"mdiFormatVerticalAlignTop\": () => /* binding */ mdiFormatVerticalAlignTop,\n/* harmony export */   \"mdiFormatWrapInline\": () => /* binding */ mdiFormatWrapInline,\n/* harmony export */   \"mdiFormatWrapSquare\": () => /* binding */ mdiFormatWrapSquare,\n/* harmony export */   \"mdiFormatWrapTight\": () => /* binding */ mdiFormatWrapTight,\n/* harmony export */   \"mdiFormatWrapTopBottom\": () => /* binding */ mdiFormatWrapTopBottom,\n/* harmony export */   \"mdiForum\": () => /* binding */ mdiForum,\n/* harmony export */   \"mdiForumOutline\": () => /* binding */ mdiForumOutline,\n/* harmony export */   \"mdiForward\": () => /* binding */ mdiForward,\n/* harmony export */   \"mdiForwardburger\": () => /* binding */ mdiForwardburger,\n/* harmony export */   \"mdiFountain\": () => /* binding */ mdiFountain,\n/* harmony export */   \"mdiFountainPen\": () => /* binding */ mdiFountainPen,\n/* harmony export */   \"mdiFountainPenTip\": () => /* binding */ mdiFountainPenTip,\n/* harmony export */   \"mdiFreebsd\": () => /* binding */ mdiFreebsd,\n/* harmony export */   \"mdiFrequentlyAskedQuestions\": () => /* binding */ mdiFrequentlyAskedQuestions,\n/* harmony export */   \"mdiFridge\": () => /* binding */ mdiFridge,\n/* harmony export */   \"mdiFridgeAlert\": () => /* binding */ mdiFridgeAlert,\n/* harmony export */   \"mdiFridgeAlertOutline\": () => /* binding */ mdiFridgeAlertOutline,\n/* harmony export */   \"mdiFridgeBottom\": () => /* binding */ mdiFridgeBottom,\n/* harmony export */   \"mdiFridgeIndustrial\": () => /* binding */ mdiFridgeIndustrial,\n/* harmony export */   \"mdiFridgeIndustrialAlert\": () => /* binding */ mdiFridgeIndustrialAlert,\n/* harmony export */   \"mdiFridgeIndustrialAlertOutline\": () => /* binding */ mdiFridgeIndustrialAlertOutline,\n/* harmony export */   \"mdiFridgeIndustrialOff\": () => /* binding */ mdiFridgeIndustrialOff,\n/* harmony export */   \"mdiFridgeIndustrialOffOutline\": () => /* binding */ mdiFridgeIndustrialOffOutline,\n/* harmony export */   \"mdiFridgeIndustrialOutline\": () => /* binding */ mdiFridgeIndustrialOutline,\n/* harmony export */   \"mdiFridgeOff\": () => /* binding */ mdiFridgeOff,\n/* harmony export */   \"mdiFridgeOffOutline\": () => /* binding */ mdiFridgeOffOutline,\n/* harmony export */   \"mdiFridgeOutline\": () => /* binding */ mdiFridgeOutline,\n/* harmony export */   \"mdiFridgeTop\": () => /* binding */ mdiFridgeTop,\n/* harmony export */   \"mdiFridgeVariant\": () => /* binding */ mdiFridgeVariant,\n/* harmony export */   \"mdiFridgeVariantAlert\": () => /* binding */ mdiFridgeVariantAlert,\n/* harmony export */   \"mdiFridgeVariantAlertOutline\": () => /* binding */ mdiFridgeVariantAlertOutline,\n/* harmony export */   \"mdiFridgeVariantOff\": () => /* binding */ mdiFridgeVariantOff,\n/* harmony export */   \"mdiFridgeVariantOffOutline\": () => /* binding */ mdiFridgeVariantOffOutline,\n/* harmony export */   \"mdiFridgeVariantOutline\": () => /* binding */ mdiFridgeVariantOutline,\n/* harmony export */   \"mdiFruitCherries\": () => /* binding */ mdiFruitCherries,\n/* harmony export */   \"mdiFruitCherriesOff\": () => /* binding */ mdiFruitCherriesOff,\n/* harmony export */   \"mdiFruitCitrus\": () => /* binding */ mdiFruitCitrus,\n/* harmony export */   \"mdiFruitCitrusOff\": () => /* binding */ mdiFruitCitrusOff,\n/* harmony export */   \"mdiFruitGrapes\": () => /* binding */ mdiFruitGrapes,\n/* harmony export */   \"mdiFruitGrapesOutline\": () => /* binding */ mdiFruitGrapesOutline,\n/* harmony export */   \"mdiFruitPineapple\": () => /* binding */ mdiFruitPineapple,\n/* harmony export */   \"mdiFruitWatermelon\": () => /* binding */ mdiFruitWatermelon,\n/* harmony export */   \"mdiFuel\": () => /* binding */ mdiFuel,\n/* harmony export */   \"mdiFullscreen\": () => /* binding */ mdiFullscreen,\n/* harmony export */   \"mdiFullscreenExit\": () => /* binding */ mdiFullscreenExit,\n/* harmony export */   \"mdiFunction\": () => /* binding */ mdiFunction,\n/* harmony export */   \"mdiFunctionVariant\": () => /* binding */ mdiFunctionVariant,\n/* harmony export */   \"mdiFuriganaHorizontal\": () => /* binding */ mdiFuriganaHorizontal,\n/* harmony export */   \"mdiFuriganaVertical\": () => /* binding */ mdiFuriganaVertical,\n/* harmony export */   \"mdiFuse\": () => /* binding */ mdiFuse,\n/* harmony export */   \"mdiFuseAlert\": () => /* binding */ mdiFuseAlert,\n/* harmony export */   \"mdiFuseBlade\": () => /* binding */ mdiFuseBlade,\n/* harmony export */   \"mdiFuseOff\": () => /* binding */ mdiFuseOff,\n/* harmony export */   \"mdiGamepad\": () => /* binding */ mdiGamepad,\n/* harmony export */   \"mdiGamepadCircle\": () => /* binding */ mdiGamepadCircle,\n/* harmony export */   \"mdiGamepadCircleDown\": () => /* binding */ mdiGamepadCircleDown,\n/* harmony export */   \"mdiGamepadCircleLeft\": () => /* binding */ mdiGamepadCircleLeft,\n/* harmony export */   \"mdiGamepadCircleOutline\": () => /* binding */ mdiGamepadCircleOutline,\n/* harmony export */   \"mdiGamepadCircleRight\": () => /* binding */ mdiGamepadCircleRight,\n/* harmony export */   \"mdiGamepadCircleUp\": () => /* binding */ mdiGamepadCircleUp,\n/* harmony export */   \"mdiGamepadDown\": () => /* binding */ mdiGamepadDown,\n/* harmony export */   \"mdiGamepadLeft\": () => /* binding */ mdiGamepadLeft,\n/* harmony export */   \"mdiGamepadRight\": () => /* binding */ mdiGamepadRight,\n/* harmony export */   \"mdiGamepadRound\": () => /* binding */ mdiGamepadRound,\n/* harmony export */   \"mdiGamepadRoundDown\": () => /* binding */ mdiGamepadRoundDown,\n/* harmony export */   \"mdiGamepadRoundLeft\": () => /* binding */ mdiGamepadRoundLeft,\n/* harmony export */   \"mdiGamepadRoundOutline\": () => /* binding */ mdiGamepadRoundOutline,\n/* harmony export */   \"mdiGamepadRoundRight\": () => /* binding */ mdiGamepadRoundRight,\n/* harmony export */   \"mdiGamepadRoundUp\": () => /* binding */ mdiGamepadRoundUp,\n/* harmony export */   \"mdiGamepadSquare\": () => /* binding */ mdiGamepadSquare,\n/* harmony export */   \"mdiGamepadSquareOutline\": () => /* binding */ mdiGamepadSquareOutline,\n/* harmony export */   \"mdiGamepadUp\": () => /* binding */ mdiGamepadUp,\n/* harmony export */   \"mdiGamepadVariant\": () => /* binding */ mdiGamepadVariant,\n/* harmony export */   \"mdiGamepadVariantOutline\": () => /* binding */ mdiGamepadVariantOutline,\n/* harmony export */   \"mdiGamma\": () => /* binding */ mdiGamma,\n/* harmony export */   \"mdiGantryCrane\": () => /* binding */ mdiGantryCrane,\n/* harmony export */   \"mdiGarage\": () => /* binding */ mdiGarage,\n/* harmony export */   \"mdiGarageAlert\": () => /* binding */ mdiGarageAlert,\n/* harmony export */   \"mdiGarageAlertVariant\": () => /* binding */ mdiGarageAlertVariant,\n/* harmony export */   \"mdiGarageOpen\": () => /* binding */ mdiGarageOpen,\n/* harmony export */   \"mdiGarageOpenVariant\": () => /* binding */ mdiGarageOpenVariant,\n/* harmony export */   \"mdiGarageVariant\": () => /* binding */ mdiGarageVariant,\n/* harmony export */   \"mdiGasCylinder\": () => /* binding */ mdiGasCylinder,\n/* harmony export */   \"mdiGasStation\": () => /* binding */ mdiGasStation,\n/* harmony export */   \"mdiGasStationOff\": () => /* binding */ mdiGasStationOff,\n/* harmony export */   \"mdiGasStationOffOutline\": () => /* binding */ mdiGasStationOffOutline,\n/* harmony export */   \"mdiGasStationOutline\": () => /* binding */ mdiGasStationOutline,\n/* harmony export */   \"mdiGate\": () => /* binding */ mdiGate,\n/* harmony export */   \"mdiGateAnd\": () => /* binding */ mdiGateAnd,\n/* harmony export */   \"mdiGateArrowRight\": () => /* binding */ mdiGateArrowRight,\n/* harmony export */   \"mdiGateNand\": () => /* binding */ mdiGateNand,\n/* harmony export */   \"mdiGateNor\": () => /* binding */ mdiGateNor,\n/* harmony export */   \"mdiGateNot\": () => /* binding */ mdiGateNot,\n/* harmony export */   \"mdiGateOpen\": () => /* binding */ mdiGateOpen,\n/* harmony export */   \"mdiGateOr\": () => /* binding */ mdiGateOr,\n/* harmony export */   \"mdiGateXnor\": () => /* binding */ mdiGateXnor,\n/* harmony export */   \"mdiGateXor\": () => /* binding */ mdiGateXor,\n/* harmony export */   \"mdiGatsby\": () => /* binding */ mdiGatsby,\n/* harmony export */   \"mdiGauge\": () => /* binding */ mdiGauge,\n/* harmony export */   \"mdiGaugeEmpty\": () => /* binding */ mdiGaugeEmpty,\n/* harmony export */   \"mdiGaugeFull\": () => /* binding */ mdiGaugeFull,\n/* harmony export */   \"mdiGaugeLow\": () => /* binding */ mdiGaugeLow,\n/* harmony export */   \"mdiGavel\": () => /* binding */ mdiGavel,\n/* harmony export */   \"mdiGenderFemale\": () => /* binding */ mdiGenderFemale,\n/* harmony export */   \"mdiGenderMale\": () => /* binding */ mdiGenderMale,\n/* harmony export */   \"mdiGenderMaleFemale\": () => /* binding */ mdiGenderMaleFemale,\n/* harmony export */   \"mdiGenderMaleFemaleVariant\": () => /* binding */ mdiGenderMaleFemaleVariant,\n/* harmony export */   \"mdiGenderNonBinary\": () => /* binding */ mdiGenderNonBinary,\n/* harmony export */   \"mdiGenderTransgender\": () => /* binding */ mdiGenderTransgender,\n/* harmony export */   \"mdiGentoo\": () => /* binding */ mdiGentoo,\n/* harmony export */   \"mdiGesture\": () => /* binding */ mdiGesture,\n/* harmony export */   \"mdiGestureDoubleTap\": () => /* binding */ mdiGestureDoubleTap,\n/* harmony export */   \"mdiGesturePinch\": () => /* binding */ mdiGesturePinch,\n/* harmony export */   \"mdiGestureSpread\": () => /* binding */ mdiGestureSpread,\n/* harmony export */   \"mdiGestureSwipe\": () => /* binding */ mdiGestureSwipe,\n/* harmony export */   \"mdiGestureSwipeDown\": () => /* binding */ mdiGestureSwipeDown,\n/* harmony export */   \"mdiGestureSwipeHorizontal\": () => /* binding */ mdiGestureSwipeHorizontal,\n/* harmony export */   \"mdiGestureSwipeLeft\": () => /* binding */ mdiGestureSwipeLeft,\n/* harmony export */   \"mdiGestureSwipeRight\": () => /* binding */ mdiGestureSwipeRight,\n/* harmony export */   \"mdiGestureSwipeUp\": () => /* binding */ mdiGestureSwipeUp,\n/* harmony export */   \"mdiGestureSwipeVertical\": () => /* binding */ mdiGestureSwipeVertical,\n/* harmony export */   \"mdiGestureTap\": () => /* binding */ mdiGestureTap,\n/* harmony export */   \"mdiGestureTapBox\": () => /* binding */ mdiGestureTapBox,\n/* harmony export */   \"mdiGestureTapButton\": () => /* binding */ mdiGestureTapButton,\n/* harmony export */   \"mdiGestureTapHold\": () => /* binding */ mdiGestureTapHold,\n/* harmony export */   \"mdiGestureTwoDoubleTap\": () => /* binding */ mdiGestureTwoDoubleTap,\n/* harmony export */   \"mdiGestureTwoTap\": () => /* binding */ mdiGestureTwoTap,\n/* harmony export */   \"mdiGhost\": () => /* binding */ mdiGhost,\n/* harmony export */   \"mdiGhostOff\": () => /* binding */ mdiGhostOff,\n/* harmony export */   \"mdiGif\": () => /* binding */ mdiGif,\n/* harmony export */   \"mdiGift\": () => /* binding */ mdiGift,\n/* harmony export */   \"mdiGiftOutline\": () => /* binding */ mdiGiftOutline,\n/* harmony export */   \"mdiGit\": () => /* binding */ mdiGit,\n/* harmony export */   \"mdiGithub\": () => /* binding */ mdiGithub,\n/* harmony export */   \"mdiGitlab\": () => /* binding */ mdiGitlab,\n/* harmony export */   \"mdiGlassCocktail\": () => /* binding */ mdiGlassCocktail,\n/* harmony export */   \"mdiGlassCocktailOff\": () => /* binding */ mdiGlassCocktailOff,\n/* harmony export */   \"mdiGlassFlute\": () => /* binding */ mdiGlassFlute,\n/* harmony export */   \"mdiGlassMug\": () => /* binding */ mdiGlassMug,\n/* harmony export */   \"mdiGlassMugOff\": () => /* binding */ mdiGlassMugOff,\n/* harmony export */   \"mdiGlassMugVariant\": () => /* binding */ mdiGlassMugVariant,\n/* harmony export */   \"mdiGlassMugVariantOff\": () => /* binding */ mdiGlassMugVariantOff,\n/* harmony export */   \"mdiGlassPintOutline\": () => /* binding */ mdiGlassPintOutline,\n/* harmony export */   \"mdiGlassStange\": () => /* binding */ mdiGlassStange,\n/* harmony export */   \"mdiGlassTulip\": () => /* binding */ mdiGlassTulip,\n/* harmony export */   \"mdiGlassWine\": () => /* binding */ mdiGlassWine,\n/* harmony export */   \"mdiGlasses\": () => /* binding */ mdiGlasses,\n/* harmony export */   \"mdiGlobeLight\": () => /* binding */ mdiGlobeLight,\n/* harmony export */   \"mdiGlobeModel\": () => /* binding */ mdiGlobeModel,\n/* harmony export */   \"mdiGmail\": () => /* binding */ mdiGmail,\n/* harmony export */   \"mdiGnome\": () => /* binding */ mdiGnome,\n/* harmony export */   \"mdiGoKart\": () => /* binding */ mdiGoKart,\n/* harmony export */   \"mdiGoKartTrack\": () => /* binding */ mdiGoKartTrack,\n/* harmony export */   \"mdiGog\": () => /* binding */ mdiGog,\n/* harmony export */   \"mdiGold\": () => /* binding */ mdiGold,\n/* harmony export */   \"mdiGolf\": () => /* binding */ mdiGolf,\n/* harmony export */   \"mdiGolfCart\": () => /* binding */ mdiGolfCart,\n/* harmony export */   \"mdiGolfTee\": () => /* binding */ mdiGolfTee,\n/* harmony export */   \"mdiGondola\": () => /* binding */ mdiGondola,\n/* harmony export */   \"mdiGoodreads\": () => /* binding */ mdiGoodreads,\n/* harmony export */   \"mdiGoogle\": () => /* binding */ mdiGoogle,\n/* harmony export */   \"mdiGoogleAds\": () => /* binding */ mdiGoogleAds,\n/* harmony export */   \"mdiGoogleAnalytics\": () => /* binding */ mdiGoogleAnalytics,\n/* harmony export */   \"mdiGoogleAssistant\": () => /* binding */ mdiGoogleAssistant,\n/* harmony export */   \"mdiGoogleCardboard\": () => /* binding */ mdiGoogleCardboard,\n/* harmony export */   \"mdiGoogleChrome\": () => /* binding */ mdiGoogleChrome,\n/* harmony export */   \"mdiGoogleCircles\": () => /* binding */ mdiGoogleCircles,\n/* harmony export */   \"mdiGoogleCirclesCommunities\": () => /* binding */ mdiGoogleCirclesCommunities,\n/* harmony export */   \"mdiGoogleCirclesExtended\": () => /* binding */ mdiGoogleCirclesExtended,\n/* harmony export */   \"mdiGoogleCirclesGroup\": () => /* binding */ mdiGoogleCirclesGroup,\n/* harmony export */   \"mdiGoogleClassroom\": () => /* binding */ mdiGoogleClassroom,\n/* harmony export */   \"mdiGoogleCloud\": () => /* binding */ mdiGoogleCloud,\n/* harmony export */   \"mdiGoogleController\": () => /* binding */ mdiGoogleController,\n/* harmony export */   \"mdiGoogleControllerOff\": () => /* binding */ mdiGoogleControllerOff,\n/* harmony export */   \"mdiGoogleDownasaur\": () => /* binding */ mdiGoogleDownasaur,\n/* harmony export */   \"mdiGoogleDrive\": () => /* binding */ mdiGoogleDrive,\n/* harmony export */   \"mdiGoogleEarth\": () => /* binding */ mdiGoogleEarth,\n/* harmony export */   \"mdiGoogleFit\": () => /* binding */ mdiGoogleFit,\n/* harmony export */   \"mdiGoogleGlass\": () => /* binding */ mdiGoogleGlass,\n/* harmony export */   \"mdiGoogleHangouts\": () => /* binding */ mdiGoogleHangouts,\n/* harmony export */   \"mdiGoogleHome\": () => /* binding */ mdiGoogleHome,\n/* harmony export */   \"mdiGoogleKeep\": () => /* binding */ mdiGoogleKeep,\n/* harmony export */   \"mdiGoogleLens\": () => /* binding */ mdiGoogleLens,\n/* harmony export */   \"mdiGoogleMaps\": () => /* binding */ mdiGoogleMaps,\n/* harmony export */   \"mdiGoogleMyBusiness\": () => /* binding */ mdiGoogleMyBusiness,\n/* harmony export */   \"mdiGoogleNearby\": () => /* binding */ mdiGoogleNearby,\n/* harmony export */   \"mdiGooglePhotos\": () => /* binding */ mdiGooglePhotos,\n/* harmony export */   \"mdiGooglePlay\": () => /* binding */ mdiGooglePlay,\n/* harmony export */   \"mdiGooglePlus\": () => /* binding */ mdiGooglePlus,\n/* harmony export */   \"mdiGooglePodcast\": () => /* binding */ mdiGooglePodcast,\n/* harmony export */   \"mdiGoogleSpreadsheet\": () => /* binding */ mdiGoogleSpreadsheet,\n/* harmony export */   \"mdiGoogleStreetView\": () => /* binding */ mdiGoogleStreetView,\n/* harmony export */   \"mdiGoogleTranslate\": () => /* binding */ mdiGoogleTranslate,\n/* harmony export */   \"mdiGradient\": () => /* binding */ mdiGradient,\n/* harmony export */   \"mdiGrain\": () => /* binding */ mdiGrain,\n/* harmony export */   \"mdiGraph\": () => /* binding */ mdiGraph,\n/* harmony export */   \"mdiGraphOutline\": () => /* binding */ mdiGraphOutline,\n/* harmony export */   \"mdiGraphql\": () => /* binding */ mdiGraphql,\n/* harmony export */   \"mdiGrass\": () => /* binding */ mdiGrass,\n/* harmony export */   \"mdiGraveStone\": () => /* binding */ mdiGraveStone,\n/* harmony export */   \"mdiGreasePencil\": () => /* binding */ mdiGreasePencil,\n/* harmony export */   \"mdiGreaterThan\": () => /* binding */ mdiGreaterThan,\n/* harmony export */   \"mdiGreaterThanOrEqual\": () => /* binding */ mdiGreaterThanOrEqual,\n/* harmony export */   \"mdiGrid\": () => /* binding */ mdiGrid,\n/* harmony export */   \"mdiGridLarge\": () => /* binding */ mdiGridLarge,\n/* harmony export */   \"mdiGridOff\": () => /* binding */ mdiGridOff,\n/* harmony export */   \"mdiGrill\": () => /* binding */ mdiGrill,\n/* harmony export */   \"mdiGrillOutline\": () => /* binding */ mdiGrillOutline,\n/* harmony export */   \"mdiGroup\": () => /* binding */ mdiGroup,\n/* harmony export */   \"mdiGuitarAcoustic\": () => /* binding */ mdiGuitarAcoustic,\n/* harmony export */   \"mdiGuitarElectric\": () => /* binding */ mdiGuitarElectric,\n/* harmony export */   \"mdiGuitarPick\": () => /* binding */ mdiGuitarPick,\n/* harmony export */   \"mdiGuitarPickOutline\": () => /* binding */ mdiGuitarPickOutline,\n/* harmony export */   \"mdiGuyFawkesMask\": () => /* binding */ mdiGuyFawkesMask,\n/* harmony export */   \"mdiHail\": () => /* binding */ mdiHail,\n/* harmony export */   \"mdiHairDryer\": () => /* binding */ mdiHairDryer,\n/* harmony export */   \"mdiHairDryerOutline\": () => /* binding */ mdiHairDryerOutline,\n/* harmony export */   \"mdiHalloween\": () => /* binding */ mdiHalloween,\n/* harmony export */   \"mdiHamburger\": () => /* binding */ mdiHamburger,\n/* harmony export */   \"mdiHammer\": () => /* binding */ mdiHammer,\n/* harmony export */   \"mdiHammerScrewdriver\": () => /* binding */ mdiHammerScrewdriver,\n/* harmony export */   \"mdiHammerWrench\": () => /* binding */ mdiHammerWrench,\n/* harmony export */   \"mdiHand\": () => /* binding */ mdiHand,\n/* harmony export */   \"mdiHandHeart\": () => /* binding */ mdiHandHeart,\n/* harmony export */   \"mdiHandHeartOutline\": () => /* binding */ mdiHandHeartOutline,\n/* harmony export */   \"mdiHandLeft\": () => /* binding */ mdiHandLeft,\n/* harmony export */   \"mdiHandOkay\": () => /* binding */ mdiHandOkay,\n/* harmony export */   \"mdiHandPeace\": () => /* binding */ mdiHandPeace,\n/* harmony export */   \"mdiHandPeaceVariant\": () => /* binding */ mdiHandPeaceVariant,\n/* harmony export */   \"mdiHandPointingDown\": () => /* binding */ mdiHandPointingDown,\n/* harmony export */   \"mdiHandPointingLeft\": () => /* binding */ mdiHandPointingLeft,\n/* harmony export */   \"mdiHandPointingRight\": () => /* binding */ mdiHandPointingRight,\n/* harmony export */   \"mdiHandPointingUp\": () => /* binding */ mdiHandPointingUp,\n/* harmony export */   \"mdiHandRight\": () => /* binding */ mdiHandRight,\n/* harmony export */   \"mdiHandSaw\": () => /* binding */ mdiHandSaw,\n/* harmony export */   \"mdiHandWash\": () => /* binding */ mdiHandWash,\n/* harmony export */   \"mdiHandWashOutline\": () => /* binding */ mdiHandWashOutline,\n/* harmony export */   \"mdiHandWater\": () => /* binding */ mdiHandWater,\n/* harmony export */   \"mdiHandball\": () => /* binding */ mdiHandball,\n/* harmony export */   \"mdiHandcuffs\": () => /* binding */ mdiHandcuffs,\n/* harmony export */   \"mdiHandshake\": () => /* binding */ mdiHandshake,\n/* harmony export */   \"mdiHandshakeOutline\": () => /* binding */ mdiHandshakeOutline,\n/* harmony export */   \"mdiHanger\": () => /* binding */ mdiHanger,\n/* harmony export */   \"mdiHardHat\": () => /* binding */ mdiHardHat,\n/* harmony export */   \"mdiHarddisk\": () => /* binding */ mdiHarddisk,\n/* harmony export */   \"mdiHarddiskPlus\": () => /* binding */ mdiHarddiskPlus,\n/* harmony export */   \"mdiHarddiskRemove\": () => /* binding */ mdiHarddiskRemove,\n/* harmony export */   \"mdiHatFedora\": () => /* binding */ mdiHatFedora,\n/* harmony export */   \"mdiHazardLights\": () => /* binding */ mdiHazardLights,\n/* harmony export */   \"mdiHdr\": () => /* binding */ mdiHdr,\n/* harmony export */   \"mdiHdrOff\": () => /* binding */ mdiHdrOff,\n/* harmony export */   \"mdiHead\": () => /* binding */ mdiHead,\n/* harmony export */   \"mdiHeadAlert\": () => /* binding */ mdiHeadAlert,\n/* harmony export */   \"mdiHeadAlertOutline\": () => /* binding */ mdiHeadAlertOutline,\n/* harmony export */   \"mdiHeadCheck\": () => /* binding */ mdiHeadCheck,\n/* harmony export */   \"mdiHeadCheckOutline\": () => /* binding */ mdiHeadCheckOutline,\n/* harmony export */   \"mdiHeadCog\": () => /* binding */ mdiHeadCog,\n/* harmony export */   \"mdiHeadCogOutline\": () => /* binding */ mdiHeadCogOutline,\n/* harmony export */   \"mdiHeadDotsHorizontal\": () => /* binding */ mdiHeadDotsHorizontal,\n/* harmony export */   \"mdiHeadDotsHorizontalOutline\": () => /* binding */ mdiHeadDotsHorizontalOutline,\n/* harmony export */   \"mdiHeadFlash\": () => /* binding */ mdiHeadFlash,\n/* harmony export */   \"mdiHeadFlashOutline\": () => /* binding */ mdiHeadFlashOutline,\n/* harmony export */   \"mdiHeadHeart\": () => /* binding */ mdiHeadHeart,\n/* harmony export */   \"mdiHeadHeartOutline\": () => /* binding */ mdiHeadHeartOutline,\n/* harmony export */   \"mdiHeadLightbulb\": () => /* binding */ mdiHeadLightbulb,\n/* harmony export */   \"mdiHeadLightbulbOutline\": () => /* binding */ mdiHeadLightbulbOutline,\n/* harmony export */   \"mdiHeadMinus\": () => /* binding */ mdiHeadMinus,\n/* harmony export */   \"mdiHeadMinusOutline\": () => /* binding */ mdiHeadMinusOutline,\n/* harmony export */   \"mdiHeadOutline\": () => /* binding */ mdiHeadOutline,\n/* harmony export */   \"mdiHeadPlus\": () => /* binding */ mdiHeadPlus,\n/* harmony export */   \"mdiHeadPlusOutline\": () => /* binding */ mdiHeadPlusOutline,\n/* harmony export */   \"mdiHeadQuestion\": () => /* binding */ mdiHeadQuestion,\n/* harmony export */   \"mdiHeadQuestionOutline\": () => /* binding */ mdiHeadQuestionOutline,\n/* harmony export */   \"mdiHeadRemove\": () => /* binding */ mdiHeadRemove,\n/* harmony export */   \"mdiHeadRemoveOutline\": () => /* binding */ mdiHeadRemoveOutline,\n/* harmony export */   \"mdiHeadSnowflake\": () => /* binding */ mdiHeadSnowflake,\n/* harmony export */   \"mdiHeadSnowflakeOutline\": () => /* binding */ mdiHeadSnowflakeOutline,\n/* harmony export */   \"mdiHeadSync\": () => /* binding */ mdiHeadSync,\n/* harmony export */   \"mdiHeadSyncOutline\": () => /* binding */ mdiHeadSyncOutline,\n/* harmony export */   \"mdiHeadphones\": () => /* binding */ mdiHeadphones,\n/* harmony export */   \"mdiHeadphonesBluetooth\": () => /* binding */ mdiHeadphonesBluetooth,\n/* harmony export */   \"mdiHeadphonesBox\": () => /* binding */ mdiHeadphonesBox,\n/* harmony export */   \"mdiHeadphonesOff\": () => /* binding */ mdiHeadphonesOff,\n/* harmony export */   \"mdiHeadphonesSettings\": () => /* binding */ mdiHeadphonesSettings,\n/* harmony export */   \"mdiHeadset\": () => /* binding */ mdiHeadset,\n/* harmony export */   \"mdiHeadsetDock\": () => /* binding */ mdiHeadsetDock,\n/* harmony export */   \"mdiHeadsetOff\": () => /* binding */ mdiHeadsetOff,\n/* harmony export */   \"mdiHeart\": () => /* binding */ mdiHeart,\n/* harmony export */   \"mdiHeartBox\": () => /* binding */ mdiHeartBox,\n/* harmony export */   \"mdiHeartBoxOutline\": () => /* binding */ mdiHeartBoxOutline,\n/* harmony export */   \"mdiHeartBroken\": () => /* binding */ mdiHeartBroken,\n/* harmony export */   \"mdiHeartBrokenOutline\": () => /* binding */ mdiHeartBrokenOutline,\n/* harmony export */   \"mdiHeartCircle\": () => /* binding */ mdiHeartCircle,\n/* harmony export */   \"mdiHeartCircleOutline\": () => /* binding */ mdiHeartCircleOutline,\n/* harmony export */   \"mdiHeartFlash\": () => /* binding */ mdiHeartFlash,\n/* harmony export */   \"mdiHeartHalf\": () => /* binding */ mdiHeartHalf,\n/* harmony export */   \"mdiHeartHalfFull\": () => /* binding */ mdiHeartHalfFull,\n/* harmony export */   \"mdiHeartHalfOutline\": () => /* binding */ mdiHeartHalfOutline,\n/* harmony export */   \"mdiHeartMinus\": () => /* binding */ mdiHeartMinus,\n/* harmony export */   \"mdiHeartMinusOutline\": () => /* binding */ mdiHeartMinusOutline,\n/* harmony export */   \"mdiHeartMultiple\": () => /* binding */ mdiHeartMultiple,\n/* harmony export */   \"mdiHeartMultipleOutline\": () => /* binding */ mdiHeartMultipleOutline,\n/* harmony export */   \"mdiHeartOff\": () => /* binding */ mdiHeartOff,\n/* harmony export */   \"mdiHeartOffOutline\": () => /* binding */ mdiHeartOffOutline,\n/* harmony export */   \"mdiHeartOutline\": () => /* binding */ mdiHeartOutline,\n/* harmony export */   \"mdiHeartPlus\": () => /* binding */ mdiHeartPlus,\n/* harmony export */   \"mdiHeartPlusOutline\": () => /* binding */ mdiHeartPlusOutline,\n/* harmony export */   \"mdiHeartPulse\": () => /* binding */ mdiHeartPulse,\n/* harmony export */   \"mdiHeartRemove\": () => /* binding */ mdiHeartRemove,\n/* harmony export */   \"mdiHeartRemoveOutline\": () => /* binding */ mdiHeartRemoveOutline,\n/* harmony export */   \"mdiHelicopter\": () => /* binding */ mdiHelicopter,\n/* harmony export */   \"mdiHelp\": () => /* binding */ mdiHelp,\n/* harmony export */   \"mdiHelpBox\": () => /* binding */ mdiHelpBox,\n/* harmony export */   \"mdiHelpCircle\": () => /* binding */ mdiHelpCircle,\n/* harmony export */   \"mdiHelpCircleOutline\": () => /* binding */ mdiHelpCircleOutline,\n/* harmony export */   \"mdiHelpNetwork\": () => /* binding */ mdiHelpNetwork,\n/* harmony export */   \"mdiHelpNetworkOutline\": () => /* binding */ mdiHelpNetworkOutline,\n/* harmony export */   \"mdiHelpRhombus\": () => /* binding */ mdiHelpRhombus,\n/* harmony export */   \"mdiHelpRhombusOutline\": () => /* binding */ mdiHelpRhombusOutline,\n/* harmony export */   \"mdiHexadecimal\": () => /* binding */ mdiHexadecimal,\n/* harmony export */   \"mdiHexagon\": () => /* binding */ mdiHexagon,\n/* harmony export */   \"mdiHexagonMultiple\": () => /* binding */ mdiHexagonMultiple,\n/* harmony export */   \"mdiHexagonMultipleOutline\": () => /* binding */ mdiHexagonMultipleOutline,\n/* harmony export */   \"mdiHexagonOutline\": () => /* binding */ mdiHexagonOutline,\n/* harmony export */   \"mdiHexagonSlice1\": () => /* binding */ mdiHexagonSlice1,\n/* harmony export */   \"mdiHexagonSlice2\": () => /* binding */ mdiHexagonSlice2,\n/* harmony export */   \"mdiHexagonSlice3\": () => /* binding */ mdiHexagonSlice3,\n/* harmony export */   \"mdiHexagonSlice4\": () => /* binding */ mdiHexagonSlice4,\n/* harmony export */   \"mdiHexagonSlice5\": () => /* binding */ mdiHexagonSlice5,\n/* harmony export */   \"mdiHexagonSlice6\": () => /* binding */ mdiHexagonSlice6,\n/* harmony export */   \"mdiHexagram\": () => /* binding */ mdiHexagram,\n/* harmony export */   \"mdiHexagramOutline\": () => /* binding */ mdiHexagramOutline,\n/* harmony export */   \"mdiHighDefinition\": () => /* binding */ mdiHighDefinition,\n/* harmony export */   \"mdiHighDefinitionBox\": () => /* binding */ mdiHighDefinitionBox,\n/* harmony export */   \"mdiHighway\": () => /* binding */ mdiHighway,\n/* harmony export */   \"mdiHiking\": () => /* binding */ mdiHiking,\n/* harmony export */   \"mdiHinduism\": () => /* binding */ mdiHinduism,\n/* harmony export */   \"mdiHistory\": () => /* binding */ mdiHistory,\n/* harmony export */   \"mdiHockeyPuck\": () => /* binding */ mdiHockeyPuck,\n/* harmony export */   \"mdiHockeySticks\": () => /* binding */ mdiHockeySticks,\n/* harmony export */   \"mdiHololens\": () => /* binding */ mdiHololens,\n/* harmony export */   \"mdiHome\": () => /* binding */ mdiHome,\n/* harmony export */   \"mdiHomeAccount\": () => /* binding */ mdiHomeAccount,\n/* harmony export */   \"mdiHomeAlert\": () => /* binding */ mdiHomeAlert,\n/* harmony export */   \"mdiHomeAlertOutline\": () => /* binding */ mdiHomeAlertOutline,\n/* harmony export */   \"mdiHomeAnalytics\": () => /* binding */ mdiHomeAnalytics,\n/* harmony export */   \"mdiHomeAssistant\": () => /* binding */ mdiHomeAssistant,\n/* harmony export */   \"mdiHomeAutomation\": () => /* binding */ mdiHomeAutomation,\n/* harmony export */   \"mdiHomeCircle\": () => /* binding */ mdiHomeCircle,\n/* harmony export */   \"mdiHomeCircleOutline\": () => /* binding */ mdiHomeCircleOutline,\n/* harmony export */   \"mdiHomeCity\": () => /* binding */ mdiHomeCity,\n/* harmony export */   \"mdiHomeCityOutline\": () => /* binding */ mdiHomeCityOutline,\n/* harmony export */   \"mdiHomeCurrencyUsd\": () => /* binding */ mdiHomeCurrencyUsd,\n/* harmony export */   \"mdiHomeEdit\": () => /* binding */ mdiHomeEdit,\n/* harmony export */   \"mdiHomeEditOutline\": () => /* binding */ mdiHomeEditOutline,\n/* harmony export */   \"mdiHomeExportOutline\": () => /* binding */ mdiHomeExportOutline,\n/* harmony export */   \"mdiHomeFlood\": () => /* binding */ mdiHomeFlood,\n/* harmony export */   \"mdiHomeFloor0\": () => /* binding */ mdiHomeFloor0,\n/* harmony export */   \"mdiHomeFloor1\": () => /* binding */ mdiHomeFloor1,\n/* harmony export */   \"mdiHomeFloor2\": () => /* binding */ mdiHomeFloor2,\n/* harmony export */   \"mdiHomeFloor3\": () => /* binding */ mdiHomeFloor3,\n/* harmony export */   \"mdiHomeFloorA\": () => /* binding */ mdiHomeFloorA,\n/* harmony export */   \"mdiHomeFloorB\": () => /* binding */ mdiHomeFloorB,\n/* harmony export */   \"mdiHomeFloorG\": () => /* binding */ mdiHomeFloorG,\n/* harmony export */   \"mdiHomeFloorL\": () => /* binding */ mdiHomeFloorL,\n/* harmony export */   \"mdiHomeFloorNegative1\": () => /* binding */ mdiHomeFloorNegative1,\n/* harmony export */   \"mdiHomeGroup\": () => /* binding */ mdiHomeGroup,\n/* harmony export */   \"mdiHomeHeart\": () => /* binding */ mdiHomeHeart,\n/* harmony export */   \"mdiHomeImportOutline\": () => /* binding */ mdiHomeImportOutline,\n/* harmony export */   \"mdiHomeLightbulb\": () => /* binding */ mdiHomeLightbulb,\n/* harmony export */   \"mdiHomeLightbulbOutline\": () => /* binding */ mdiHomeLightbulbOutline,\n/* harmony export */   \"mdiHomeLock\": () => /* binding */ mdiHomeLock,\n/* harmony export */   \"mdiHomeLockOpen\": () => /* binding */ mdiHomeLockOpen,\n/* harmony export */   \"mdiHomeMapMarker\": () => /* binding */ mdiHomeMapMarker,\n/* harmony export */   \"mdiHomeMinus\": () => /* binding */ mdiHomeMinus,\n/* harmony export */   \"mdiHomeMinusOutline\": () => /* binding */ mdiHomeMinusOutline,\n/* harmony export */   \"mdiHomeModern\": () => /* binding */ mdiHomeModern,\n/* harmony export */   \"mdiHomeOutline\": () => /* binding */ mdiHomeOutline,\n/* harmony export */   \"mdiHomePlus\": () => /* binding */ mdiHomePlus,\n/* harmony export */   \"mdiHomePlusOutline\": () => /* binding */ mdiHomePlusOutline,\n/* harmony export */   \"mdiHomeRemove\": () => /* binding */ mdiHomeRemove,\n/* harmony export */   \"mdiHomeRemoveOutline\": () => /* binding */ mdiHomeRemoveOutline,\n/* harmony export */   \"mdiHomeRoof\": () => /* binding */ mdiHomeRoof,\n/* harmony export */   \"mdiHomeSearch\": () => /* binding */ mdiHomeSearch,\n/* harmony export */   \"mdiHomeSearchOutline\": () => /* binding */ mdiHomeSearchOutline,\n/* harmony export */   \"mdiHomeThermometer\": () => /* binding */ mdiHomeThermometer,\n/* harmony export */   \"mdiHomeThermometerOutline\": () => /* binding */ mdiHomeThermometerOutline,\n/* harmony export */   \"mdiHomeVariant\": () => /* binding */ mdiHomeVariant,\n/* harmony export */   \"mdiHomeVariantOutline\": () => /* binding */ mdiHomeVariantOutline,\n/* harmony export */   \"mdiHook\": () => /* binding */ mdiHook,\n/* harmony export */   \"mdiHookOff\": () => /* binding */ mdiHookOff,\n/* harmony export */   \"mdiHops\": () => /* binding */ mdiHops,\n/* harmony export */   \"mdiHorizontalRotateClockwise\": () => /* binding */ mdiHorizontalRotateClockwise,\n/* harmony export */   \"mdiHorizontalRotateCounterclockwise\": () => /* binding */ mdiHorizontalRotateCounterclockwise,\n/* harmony export */   \"mdiHorse\": () => /* binding */ mdiHorse,\n/* harmony export */   \"mdiHorseHuman\": () => /* binding */ mdiHorseHuman,\n/* harmony export */   \"mdiHorseVariant\": () => /* binding */ mdiHorseVariant,\n/* harmony export */   \"mdiHorseshoe\": () => /* binding */ mdiHorseshoe,\n/* harmony export */   \"mdiHospital\": () => /* binding */ mdiHospital,\n/* harmony export */   \"mdiHospitalBox\": () => /* binding */ mdiHospitalBox,\n/* harmony export */   \"mdiHospitalBoxOutline\": () => /* binding */ mdiHospitalBoxOutline,\n/* harmony export */   \"mdiHospitalBuilding\": () => /* binding */ mdiHospitalBuilding,\n/* harmony export */   \"mdiHospitalMarker\": () => /* binding */ mdiHospitalMarker,\n/* harmony export */   \"mdiHotTub\": () => /* binding */ mdiHotTub,\n/* harmony export */   \"mdiHours24\": () => /* binding */ mdiHours24,\n/* harmony export */   \"mdiHubspot\": () => /* binding */ mdiHubspot,\n/* harmony export */   \"mdiHulu\": () => /* binding */ mdiHulu,\n/* harmony export */   \"mdiHuman\": () => /* binding */ mdiHuman,\n/* harmony export */   \"mdiHumanBabyChangingTable\": () => /* binding */ mdiHumanBabyChangingTable,\n/* harmony export */   \"mdiHumanCane\": () => /* binding */ mdiHumanCane,\n/* harmony export */   \"mdiHumanCapacityDecrease\": () => /* binding */ mdiHumanCapacityDecrease,\n/* harmony export */   \"mdiHumanCapacityIncrease\": () => /* binding */ mdiHumanCapacityIncrease,\n/* harmony export */   \"mdiHumanChild\": () => /* binding */ mdiHumanChild,\n/* harmony export */   \"mdiHumanEdit\": () => /* binding */ mdiHumanEdit,\n/* harmony export */   \"mdiHumanFemale\": () => /* binding */ mdiHumanFemale,\n/* harmony export */   \"mdiHumanFemaleBoy\": () => /* binding */ mdiHumanFemaleBoy,\n/* harmony export */   \"mdiHumanFemaleDance\": () => /* binding */ mdiHumanFemaleDance,\n/* harmony export */   \"mdiHumanFemaleFemale\": () => /* binding */ mdiHumanFemaleFemale,\n/* harmony export */   \"mdiHumanFemaleGirl\": () => /* binding */ mdiHumanFemaleGirl,\n/* harmony export */   \"mdiHumanGreeting\": () => /* binding */ mdiHumanGreeting,\n/* harmony export */   \"mdiHumanGreetingProximity\": () => /* binding */ mdiHumanGreetingProximity,\n/* harmony export */   \"mdiHumanHandsdown\": () => /* binding */ mdiHumanHandsdown,\n/* harmony export */   \"mdiHumanHandsup\": () => /* binding */ mdiHumanHandsup,\n/* harmony export */   \"mdiHumanMale\": () => /* binding */ mdiHumanMale,\n/* harmony export */   \"mdiHumanMaleBoy\": () => /* binding */ mdiHumanMaleBoy,\n/* harmony export */   \"mdiHumanMaleChild\": () => /* binding */ mdiHumanMaleChild,\n/* harmony export */   \"mdiHumanMaleFemale\": () => /* binding */ mdiHumanMaleFemale,\n/* harmony export */   \"mdiHumanMaleGirl\": () => /* binding */ mdiHumanMaleGirl,\n/* harmony export */   \"mdiHumanMaleHeight\": () => /* binding */ mdiHumanMaleHeight,\n/* harmony export */   \"mdiHumanMaleHeightVariant\": () => /* binding */ mdiHumanMaleHeightVariant,\n/* harmony export */   \"mdiHumanMaleMale\": () => /* binding */ mdiHumanMaleMale,\n/* harmony export */   \"mdiHumanPregnant\": () => /* binding */ mdiHumanPregnant,\n/* harmony export */   \"mdiHumanQueue\": () => /* binding */ mdiHumanQueue,\n/* harmony export */   \"mdiHumanScooter\": () => /* binding */ mdiHumanScooter,\n/* harmony export */   \"mdiHumanWheelchair\": () => /* binding */ mdiHumanWheelchair,\n/* harmony export */   \"mdiHumbleBundle\": () => /* binding */ mdiHumbleBundle,\n/* harmony export */   \"mdiHvac\": () => /* binding */ mdiHvac,\n/* harmony export */   \"mdiHvacOff\": () => /* binding */ mdiHvacOff,\n/* harmony export */   \"mdiHydraulicOilLevel\": () => /* binding */ mdiHydraulicOilLevel,\n/* harmony export */   \"mdiHydraulicOilTemperature\": () => /* binding */ mdiHydraulicOilTemperature,\n/* harmony export */   \"mdiHydroPower\": () => /* binding */ mdiHydroPower,\n/* harmony export */   \"mdiIceCream\": () => /* binding */ mdiIceCream,\n/* harmony export */   \"mdiIceCreamOff\": () => /* binding */ mdiIceCreamOff,\n/* harmony export */   \"mdiIcePop\": () => /* binding */ mdiIcePop,\n/* harmony export */   \"mdiIdCard\": () => /* binding */ mdiIdCard,\n/* harmony export */   \"mdiIdentifier\": () => /* binding */ mdiIdentifier,\n/* harmony export */   \"mdiIdeogramCjk\": () => /* binding */ mdiIdeogramCjk,\n/* harmony export */   \"mdiIdeogramCjkVariant\": () => /* binding */ mdiIdeogramCjkVariant,\n/* harmony export */   \"mdiIframe\": () => /* binding */ mdiIframe,\n/* harmony export */   \"mdiIframeArray\": () => /* binding */ mdiIframeArray,\n/* harmony export */   \"mdiIframeArrayOutline\": () => /* binding */ mdiIframeArrayOutline,\n/* harmony export */   \"mdiIframeBraces\": () => /* binding */ mdiIframeBraces,\n/* harmony export */   \"mdiIframeBracesOutline\": () => /* binding */ mdiIframeBracesOutline,\n/* harmony export */   \"mdiIframeOutline\": () => /* binding */ mdiIframeOutline,\n/* harmony export */   \"mdiIframeParentheses\": () => /* binding */ mdiIframeParentheses,\n/* harmony export */   \"mdiIframeParenthesesOutline\": () => /* binding */ mdiIframeParenthesesOutline,\n/* harmony export */   \"mdiIframeVariable\": () => /* binding */ mdiIframeVariable,\n/* harmony export */   \"mdiIframeVariableOutline\": () => /* binding */ mdiIframeVariableOutline,\n/* harmony export */   \"mdiImage\": () => /* binding */ mdiImage,\n/* harmony export */   \"mdiImageAlbum\": () => /* binding */ mdiImageAlbum,\n/* harmony export */   \"mdiImageArea\": () => /* binding */ mdiImageArea,\n/* harmony export */   \"mdiImageAreaClose\": () => /* binding */ mdiImageAreaClose,\n/* harmony export */   \"mdiImageAutoAdjust\": () => /* binding */ mdiImageAutoAdjust,\n/* harmony export */   \"mdiImageBroken\": () => /* binding */ mdiImageBroken,\n/* harmony export */   \"mdiImageBrokenVariant\": () => /* binding */ mdiImageBrokenVariant,\n/* harmony export */   \"mdiImageEdit\": () => /* binding */ mdiImageEdit,\n/* harmony export */   \"mdiImageEditOutline\": () => /* binding */ mdiImageEditOutline,\n/* harmony export */   \"mdiImageFilterBlackWhite\": () => /* binding */ mdiImageFilterBlackWhite,\n/* harmony export */   \"mdiImageFilterCenterFocus\": () => /* binding */ mdiImageFilterCenterFocus,\n/* harmony export */   \"mdiImageFilterCenterFocusStrong\": () => /* binding */ mdiImageFilterCenterFocusStrong,\n/* harmony export */   \"mdiImageFilterCenterFocusStrongOutline\": () => /* binding */ mdiImageFilterCenterFocusStrongOutline,\n/* harmony export */   \"mdiImageFilterCenterFocusWeak\": () => /* binding */ mdiImageFilterCenterFocusWeak,\n/* harmony export */   \"mdiImageFilterDrama\": () => /* binding */ mdiImageFilterDrama,\n/* harmony export */   \"mdiImageFilterFrames\": () => /* binding */ mdiImageFilterFrames,\n/* harmony export */   \"mdiImageFilterHdr\": () => /* binding */ mdiImageFilterHdr,\n/* harmony export */   \"mdiImageFilterNone\": () => /* binding */ mdiImageFilterNone,\n/* harmony export */   \"mdiImageFilterTiltShift\": () => /* binding */ mdiImageFilterTiltShift,\n/* harmony export */   \"mdiImageFilterVintage\": () => /* binding */ mdiImageFilterVintage,\n/* harmony export */   \"mdiImageFrame\": () => /* binding */ mdiImageFrame,\n/* harmony export */   \"mdiImageMinus\": () => /* binding */ mdiImageMinus,\n/* harmony export */   \"mdiImageMove\": () => /* binding */ mdiImageMove,\n/* harmony export */   \"mdiImageMultiple\": () => /* binding */ mdiImageMultiple,\n/* harmony export */   \"mdiImageMultipleOutline\": () => /* binding */ mdiImageMultipleOutline,\n/* harmony export */   \"mdiImageOff\": () => /* binding */ mdiImageOff,\n/* harmony export */   \"mdiImageOffOutline\": () => /* binding */ mdiImageOffOutline,\n/* harmony export */   \"mdiImageOutline\": () => /* binding */ mdiImageOutline,\n/* harmony export */   \"mdiImagePlus\": () => /* binding */ mdiImagePlus,\n/* harmony export */   \"mdiImageRemove\": () => /* binding */ mdiImageRemove,\n/* harmony export */   \"mdiImageSearch\": () => /* binding */ mdiImageSearch,\n/* harmony export */   \"mdiImageSearchOutline\": () => /* binding */ mdiImageSearchOutline,\n/* harmony export */   \"mdiImageSizeSelectActual\": () => /* binding */ mdiImageSizeSelectActual,\n/* harmony export */   \"mdiImageSizeSelectLarge\": () => /* binding */ mdiImageSizeSelectLarge,\n/* harmony export */   \"mdiImageSizeSelectSmall\": () => /* binding */ mdiImageSizeSelectSmall,\n/* harmony export */   \"mdiImageText\": () => /* binding */ mdiImageText,\n/* harmony export */   \"mdiImport\": () => /* binding */ mdiImport,\n/* harmony export */   \"mdiInbox\": () => /* binding */ mdiInbox,\n/* harmony export */   \"mdiInboxArrowDown\": () => /* binding */ mdiInboxArrowDown,\n/* harmony export */   \"mdiInboxArrowDownOutline\": () => /* binding */ mdiInboxArrowDownOutline,\n/* harmony export */   \"mdiInboxArrowUp\": () => /* binding */ mdiInboxArrowUp,\n/* harmony export */   \"mdiInboxArrowUpOutline\": () => /* binding */ mdiInboxArrowUpOutline,\n/* harmony export */   \"mdiInboxFull\": () => /* binding */ mdiInboxFull,\n/* harmony export */   \"mdiInboxFullOutline\": () => /* binding */ mdiInboxFullOutline,\n/* harmony export */   \"mdiInboxMultiple\": () => /* binding */ mdiInboxMultiple,\n/* harmony export */   \"mdiInboxMultipleOutline\": () => /* binding */ mdiInboxMultipleOutline,\n/* harmony export */   \"mdiInboxOutline\": () => /* binding */ mdiInboxOutline,\n/* harmony export */   \"mdiInboxRemove\": () => /* binding */ mdiInboxRemove,\n/* harmony export */   \"mdiInboxRemoveOutline\": () => /* binding */ mdiInboxRemoveOutline,\n/* harmony export */   \"mdiIncognito\": () => /* binding */ mdiIncognito,\n/* harmony export */   \"mdiIncognitoCircle\": () => /* binding */ mdiIncognitoCircle,\n/* harmony export */   \"mdiIncognitoCircleOff\": () => /* binding */ mdiIncognitoCircleOff,\n/* harmony export */   \"mdiIncognitoOff\": () => /* binding */ mdiIncognitoOff,\n/* harmony export */   \"mdiInfinity\": () => /* binding */ mdiInfinity,\n/* harmony export */   \"mdiInformation\": () => /* binding */ mdiInformation,\n/* harmony export */   \"mdiInformationOutline\": () => /* binding */ mdiInformationOutline,\n/* harmony export */   \"mdiInformationVariant\": () => /* binding */ mdiInformationVariant,\n/* harmony export */   \"mdiInstagram\": () => /* binding */ mdiInstagram,\n/* harmony export */   \"mdiInstrumentTriangle\": () => /* binding */ mdiInstrumentTriangle,\n/* harmony export */   \"mdiInvertColors\": () => /* binding */ mdiInvertColors,\n/* harmony export */   \"mdiInvertColorsOff\": () => /* binding */ mdiInvertColorsOff,\n/* harmony export */   \"mdiIobroker\": () => /* binding */ mdiIobroker,\n/* harmony export */   \"mdiIp\": () => /* binding */ mdiIp,\n/* harmony export */   \"mdiIpNetwork\": () => /* binding */ mdiIpNetwork,\n/* harmony export */   \"mdiIpNetworkOutline\": () => /* binding */ mdiIpNetworkOutline,\n/* harmony export */   \"mdiIpod\": () => /* binding */ mdiIpod,\n/* harmony export */   \"mdiIslam\": () => /* binding */ mdiIslam,\n/* harmony export */   \"mdiIsland\": () => /* binding */ mdiIsland,\n/* harmony export */   \"mdiIvBag\": () => /* binding */ mdiIvBag,\n/* harmony export */   \"mdiJabber\": () => /* binding */ mdiJabber,\n/* harmony export */   \"mdiJeepney\": () => /* binding */ mdiJeepney,\n/* harmony export */   \"mdiJellyfish\": () => /* binding */ mdiJellyfish,\n/* harmony export */   \"mdiJellyfishOutline\": () => /* binding */ mdiJellyfishOutline,\n/* harmony export */   \"mdiJira\": () => /* binding */ mdiJira,\n/* harmony export */   \"mdiJquery\": () => /* binding */ mdiJquery,\n/* harmony export */   \"mdiJsfiddle\": () => /* binding */ mdiJsfiddle,\n/* harmony export */   \"mdiJudaism\": () => /* binding */ mdiJudaism,\n/* harmony export */   \"mdiJumpRope\": () => /* binding */ mdiJumpRope,\n/* harmony export */   \"mdiKabaddi\": () => /* binding */ mdiKabaddi,\n/* harmony export */   \"mdiKangaroo\": () => /* binding */ mdiKangaroo,\n/* harmony export */   \"mdiKarate\": () => /* binding */ mdiKarate,\n/* harmony export */   \"mdiKeg\": () => /* binding */ mdiKeg,\n/* harmony export */   \"mdiKettle\": () => /* binding */ mdiKettle,\n/* harmony export */   \"mdiKettleAlert\": () => /* binding */ mdiKettleAlert,\n/* harmony export */   \"mdiKettleAlertOutline\": () => /* binding */ mdiKettleAlertOutline,\n/* harmony export */   \"mdiKettleOff\": () => /* binding */ mdiKettleOff,\n/* harmony export */   \"mdiKettleOffOutline\": () => /* binding */ mdiKettleOffOutline,\n/* harmony export */   \"mdiKettleOutline\": () => /* binding */ mdiKettleOutline,\n/* harmony export */   \"mdiKettleSteam\": () => /* binding */ mdiKettleSteam,\n/* harmony export */   \"mdiKettleSteamOutline\": () => /* binding */ mdiKettleSteamOutline,\n/* harmony export */   \"mdiKettlebell\": () => /* binding */ mdiKettlebell,\n/* harmony export */   \"mdiKey\": () => /* binding */ mdiKey,\n/* harmony export */   \"mdiKeyArrowRight\": () => /* binding */ mdiKeyArrowRight,\n/* harmony export */   \"mdiKeyChain\": () => /* binding */ mdiKeyChain,\n/* harmony export */   \"mdiKeyChainVariant\": () => /* binding */ mdiKeyChainVariant,\n/* harmony export */   \"mdiKeyChange\": () => /* binding */ mdiKeyChange,\n/* harmony export */   \"mdiKeyLink\": () => /* binding */ mdiKeyLink,\n/* harmony export */   \"mdiKeyMinus\": () => /* binding */ mdiKeyMinus,\n/* harmony export */   \"mdiKeyOutline\": () => /* binding */ mdiKeyOutline,\n/* harmony export */   \"mdiKeyPlus\": () => /* binding */ mdiKeyPlus,\n/* harmony export */   \"mdiKeyRemove\": () => /* binding */ mdiKeyRemove,\n/* harmony export */   \"mdiKeyStar\": () => /* binding */ mdiKeyStar,\n/* harmony export */   \"mdiKeyVariant\": () => /* binding */ mdiKeyVariant,\n/* harmony export */   \"mdiKeyWireless\": () => /* binding */ mdiKeyWireless,\n/* harmony export */   \"mdiKeyboard\": () => /* binding */ mdiKeyboard,\n/* harmony export */   \"mdiKeyboardBackspace\": () => /* binding */ mdiKeyboardBackspace,\n/* harmony export */   \"mdiKeyboardCaps\": () => /* binding */ mdiKeyboardCaps,\n/* harmony export */   \"mdiKeyboardClose\": () => /* binding */ mdiKeyboardClose,\n/* harmony export */   \"mdiKeyboardEsc\": () => /* binding */ mdiKeyboardEsc,\n/* harmony export */   \"mdiKeyboardF1\": () => /* binding */ mdiKeyboardF1,\n/* harmony export */   \"mdiKeyboardF10\": () => /* binding */ mdiKeyboardF10,\n/* harmony export */   \"mdiKeyboardF11\": () => /* binding */ mdiKeyboardF11,\n/* harmony export */   \"mdiKeyboardF12\": () => /* binding */ mdiKeyboardF12,\n/* harmony export */   \"mdiKeyboardF2\": () => /* binding */ mdiKeyboardF2,\n/* harmony export */   \"mdiKeyboardF3\": () => /* binding */ mdiKeyboardF3,\n/* harmony export */   \"mdiKeyboardF4\": () => /* binding */ mdiKeyboardF4,\n/* harmony export */   \"mdiKeyboardF5\": () => /* binding */ mdiKeyboardF5,\n/* harmony export */   \"mdiKeyboardF6\": () => /* binding */ mdiKeyboardF6,\n/* harmony export */   \"mdiKeyboardF7\": () => /* binding */ mdiKeyboardF7,\n/* harmony export */   \"mdiKeyboardF8\": () => /* binding */ mdiKeyboardF8,\n/* harmony export */   \"mdiKeyboardF9\": () => /* binding */ mdiKeyboardF9,\n/* harmony export */   \"mdiKeyboardOff\": () => /* binding */ mdiKeyboardOff,\n/* harmony export */   \"mdiKeyboardOffOutline\": () => /* binding */ mdiKeyboardOffOutline,\n/* harmony export */   \"mdiKeyboardOutline\": () => /* binding */ mdiKeyboardOutline,\n/* harmony export */   \"mdiKeyboardReturn\": () => /* binding */ mdiKeyboardReturn,\n/* harmony export */   \"mdiKeyboardSettings\": () => /* binding */ mdiKeyboardSettings,\n/* harmony export */   \"mdiKeyboardSettingsOutline\": () => /* binding */ mdiKeyboardSettingsOutline,\n/* harmony export */   \"mdiKeyboardSpace\": () => /* binding */ mdiKeyboardSpace,\n/* harmony export */   \"mdiKeyboardTab\": () => /* binding */ mdiKeyboardTab,\n/* harmony export */   \"mdiKeyboardVariant\": () => /* binding */ mdiKeyboardVariant,\n/* harmony export */   \"mdiKhanda\": () => /* binding */ mdiKhanda,\n/* harmony export */   \"mdiKickstarter\": () => /* binding */ mdiKickstarter,\n/* harmony export */   \"mdiKlingon\": () => /* binding */ mdiKlingon,\n/* harmony export */   \"mdiKnife\": () => /* binding */ mdiKnife,\n/* harmony export */   \"mdiKnifeMilitary\": () => /* binding */ mdiKnifeMilitary,\n/* harmony export */   \"mdiKodi\": () => /* binding */ mdiKodi,\n/* harmony export */   \"mdiKubernetes\": () => /* binding */ mdiKubernetes,\n/* harmony export */   \"mdiLabel\": () => /* binding */ mdiLabel,\n/* harmony export */   \"mdiLabelMultiple\": () => /* binding */ mdiLabelMultiple,\n/* harmony export */   \"mdiLabelMultipleOutline\": () => /* binding */ mdiLabelMultipleOutline,\n/* harmony export */   \"mdiLabelOff\": () => /* binding */ mdiLabelOff,\n/* harmony export */   \"mdiLabelOffOutline\": () => /* binding */ mdiLabelOffOutline,\n/* harmony export */   \"mdiLabelOutline\": () => /* binding */ mdiLabelOutline,\n/* harmony export */   \"mdiLabelPercent\": () => /* binding */ mdiLabelPercent,\n/* harmony export */   \"mdiLabelPercentOutline\": () => /* binding */ mdiLabelPercentOutline,\n/* harmony export */   \"mdiLabelVariant\": () => /* binding */ mdiLabelVariant,\n/* harmony export */   \"mdiLabelVariantOutline\": () => /* binding */ mdiLabelVariantOutline,\n/* harmony export */   \"mdiLadder\": () => /* binding */ mdiLadder,\n/* harmony export */   \"mdiLadybug\": () => /* binding */ mdiLadybug,\n/* harmony export */   \"mdiLambda\": () => /* binding */ mdiLambda,\n/* harmony export */   \"mdiLamp\": () => /* binding */ mdiLamp,\n/* harmony export */   \"mdiLamps\": () => /* binding */ mdiLamps,\n/* harmony export */   \"mdiLan\": () => /* binding */ mdiLan,\n/* harmony export */   \"mdiLanCheck\": () => /* binding */ mdiLanCheck,\n/* harmony export */   \"mdiLanConnect\": () => /* binding */ mdiLanConnect,\n/* harmony export */   \"mdiLanDisconnect\": () => /* binding */ mdiLanDisconnect,\n/* harmony export */   \"mdiLanPending\": () => /* binding */ mdiLanPending,\n/* harmony export */   \"mdiLanguageC\": () => /* binding */ mdiLanguageC,\n/* harmony export */   \"mdiLanguageCpp\": () => /* binding */ mdiLanguageCpp,\n/* harmony export */   \"mdiLanguageCsharp\": () => /* binding */ mdiLanguageCsharp,\n/* harmony export */   \"mdiLanguageCss3\": () => /* binding */ mdiLanguageCss3,\n/* harmony export */   \"mdiLanguageFortran\": () => /* binding */ mdiLanguageFortran,\n/* harmony export */   \"mdiLanguageGo\": () => /* binding */ mdiLanguageGo,\n/* harmony export */   \"mdiLanguageHaskell\": () => /* binding */ mdiLanguageHaskell,\n/* harmony export */   \"mdiLanguageHtml5\": () => /* binding */ mdiLanguageHtml5,\n/* harmony export */   \"mdiLanguageJava\": () => /* binding */ mdiLanguageJava,\n/* harmony export */   \"mdiLanguageJavascript\": () => /* binding */ mdiLanguageJavascript,\n/* harmony export */   \"mdiLanguageKotlin\": () => /* binding */ mdiLanguageKotlin,\n/* harmony export */   \"mdiLanguageLua\": () => /* binding */ mdiLanguageLua,\n/* harmony export */   \"mdiLanguageMarkdown\": () => /* binding */ mdiLanguageMarkdown,\n/* harmony export */   \"mdiLanguageMarkdownOutline\": () => /* binding */ mdiLanguageMarkdownOutline,\n/* harmony export */   \"mdiLanguagePhp\": () => /* binding */ mdiLanguagePhp,\n/* harmony export */   \"mdiLanguagePython\": () => /* binding */ mdiLanguagePython,\n/* harmony export */   \"mdiLanguageR\": () => /* binding */ mdiLanguageR,\n/* harmony export */   \"mdiLanguageRuby\": () => /* binding */ mdiLanguageRuby,\n/* harmony export */   \"mdiLanguageRubyOnRails\": () => /* binding */ mdiLanguageRubyOnRails,\n/* harmony export */   \"mdiLanguageRust\": () => /* binding */ mdiLanguageRust,\n/* harmony export */   \"mdiLanguageSwift\": () => /* binding */ mdiLanguageSwift,\n/* harmony export */   \"mdiLanguageTypescript\": () => /* binding */ mdiLanguageTypescript,\n/* harmony export */   \"mdiLanguageXaml\": () => /* binding */ mdiLanguageXaml,\n/* harmony export */   \"mdiLaptop\": () => /* binding */ mdiLaptop,\n/* harmony export */   \"mdiLaptopChromebook\": () => /* binding */ mdiLaptopChromebook,\n/* harmony export */   \"mdiLaptopMac\": () => /* binding */ mdiLaptopMac,\n/* harmony export */   \"mdiLaptopOff\": () => /* binding */ mdiLaptopOff,\n/* harmony export */   \"mdiLaptopWindows\": () => /* binding */ mdiLaptopWindows,\n/* harmony export */   \"mdiLaravel\": () => /* binding */ mdiLaravel,\n/* harmony export */   \"mdiLaserPointer\": () => /* binding */ mdiLaserPointer,\n/* harmony export */   \"mdiLasso\": () => /* binding */ mdiLasso,\n/* harmony export */   \"mdiLastpass\": () => /* binding */ mdiLastpass,\n/* harmony export */   \"mdiLatitude\": () => /* binding */ mdiLatitude,\n/* harmony export */   \"mdiLaunch\": () => /* binding */ mdiLaunch,\n/* harmony export */   \"mdiLavaLamp\": () => /* binding */ mdiLavaLamp,\n/* harmony export */   \"mdiLayers\": () => /* binding */ mdiLayers,\n/* harmony export */   \"mdiLayersMinus\": () => /* binding */ mdiLayersMinus,\n/* harmony export */   \"mdiLayersOff\": () => /* binding */ mdiLayersOff,\n/* harmony export */   \"mdiLayersOffOutline\": () => /* binding */ mdiLayersOffOutline,\n/* harmony export */   \"mdiLayersOutline\": () => /* binding */ mdiLayersOutline,\n/* harmony export */   \"mdiLayersPlus\": () => /* binding */ mdiLayersPlus,\n/* harmony export */   \"mdiLayersRemove\": () => /* binding */ mdiLayersRemove,\n/* harmony export */   \"mdiLayersSearch\": () => /* binding */ mdiLayersSearch,\n/* harmony export */   \"mdiLayersSearchOutline\": () => /* binding */ mdiLayersSearchOutline,\n/* harmony export */   \"mdiLayersTriple\": () => /* binding */ mdiLayersTriple,\n/* harmony export */   \"mdiLayersTripleOutline\": () => /* binding */ mdiLayersTripleOutline,\n/* harmony export */   \"mdiLeadPencil\": () => /* binding */ mdiLeadPencil,\n/* harmony export */   \"mdiLeaf\": () => /* binding */ mdiLeaf,\n/* harmony export */   \"mdiLeafMaple\": () => /* binding */ mdiLeafMaple,\n/* harmony export */   \"mdiLeafMapleOff\": () => /* binding */ mdiLeafMapleOff,\n/* harmony export */   \"mdiLeafOff\": () => /* binding */ mdiLeafOff,\n/* harmony export */   \"mdiLeak\": () => /* binding */ mdiLeak,\n/* harmony export */   \"mdiLeakOff\": () => /* binding */ mdiLeakOff,\n/* harmony export */   \"mdiLedOff\": () => /* binding */ mdiLedOff,\n/* harmony export */   \"mdiLedOn\": () => /* binding */ mdiLedOn,\n/* harmony export */   \"mdiLedOutline\": () => /* binding */ mdiLedOutline,\n/* harmony export */   \"mdiLedStrip\": () => /* binding */ mdiLedStrip,\n/* harmony export */   \"mdiLedStripVariant\": () => /* binding */ mdiLedStripVariant,\n/* harmony export */   \"mdiLedVariantOff\": () => /* binding */ mdiLedVariantOff,\n/* harmony export */   \"mdiLedVariantOn\": () => /* binding */ mdiLedVariantOn,\n/* harmony export */   \"mdiLedVariantOutline\": () => /* binding */ mdiLedVariantOutline,\n/* harmony export */   \"mdiLeek\": () => /* binding */ mdiLeek,\n/* harmony export */   \"mdiLessThan\": () => /* binding */ mdiLessThan,\n/* harmony export */   \"mdiLessThanOrEqual\": () => /* binding */ mdiLessThanOrEqual,\n/* harmony export */   \"mdiLibrary\": () => /* binding */ mdiLibrary,\n/* harmony export */   \"mdiLibraryShelves\": () => /* binding */ mdiLibraryShelves,\n/* harmony export */   \"mdiLicense\": () => /* binding */ mdiLicense,\n/* harmony export */   \"mdiLifebuoy\": () => /* binding */ mdiLifebuoy,\n/* harmony export */   \"mdiLightSwitch\": () => /* binding */ mdiLightSwitch,\n/* harmony export */   \"mdiLightbulb\": () => /* binding */ mdiLightbulb,\n/* harmony export */   \"mdiLightbulbCfl\": () => /* binding */ mdiLightbulbCfl,\n/* harmony export */   \"mdiLightbulbCflOff\": () => /* binding */ mdiLightbulbCflOff,\n/* harmony export */   \"mdiLightbulbCflSpiral\": () => /* binding */ mdiLightbulbCflSpiral,\n/* harmony export */   \"mdiLightbulbCflSpiralOff\": () => /* binding */ mdiLightbulbCflSpiralOff,\n/* harmony export */   \"mdiLightbulbGroup\": () => /* binding */ mdiLightbulbGroup,\n/* harmony export */   \"mdiLightbulbGroupOff\": () => /* binding */ mdiLightbulbGroupOff,\n/* harmony export */   \"mdiLightbulbGroupOffOutline\": () => /* binding */ mdiLightbulbGroupOffOutline,\n/* harmony export */   \"mdiLightbulbGroupOutline\": () => /* binding */ mdiLightbulbGroupOutline,\n/* harmony export */   \"mdiLightbulbMultiple\": () => /* binding */ mdiLightbulbMultiple,\n/* harmony export */   \"mdiLightbulbMultipleOff\": () => /* binding */ mdiLightbulbMultipleOff,\n/* harmony export */   \"mdiLightbulbMultipleOffOutline\": () => /* binding */ mdiLightbulbMultipleOffOutline,\n/* harmony export */   \"mdiLightbulbMultipleOutline\": () => /* binding */ mdiLightbulbMultipleOutline,\n/* harmony export */   \"mdiLightbulbOff\": () => /* binding */ mdiLightbulbOff,\n/* harmony export */   \"mdiLightbulbOffOutline\": () => /* binding */ mdiLightbulbOffOutline,\n/* harmony export */   \"mdiLightbulbOn\": () => /* binding */ mdiLightbulbOn,\n/* harmony export */   \"mdiLightbulbOnOutline\": () => /* binding */ mdiLightbulbOnOutline,\n/* harmony export */   \"mdiLightbulbOutline\": () => /* binding */ mdiLightbulbOutline,\n/* harmony export */   \"mdiLighthouse\": () => /* binding */ mdiLighthouse,\n/* harmony export */   \"mdiLighthouseOn\": () => /* binding */ mdiLighthouseOn,\n/* harmony export */   \"mdiLightningBolt\": () => /* binding */ mdiLightningBolt,\n/* harmony export */   \"mdiLightningBoltOutline\": () => /* binding */ mdiLightningBoltOutline,\n/* harmony export */   \"mdiLingerie\": () => /* binding */ mdiLingerie,\n/* harmony export */   \"mdiLink\": () => /* binding */ mdiLink,\n/* harmony export */   \"mdiLinkBox\": () => /* binding */ mdiLinkBox,\n/* harmony export */   \"mdiLinkBoxOutline\": () => /* binding */ mdiLinkBoxOutline,\n/* harmony export */   \"mdiLinkBoxVariant\": () => /* binding */ mdiLinkBoxVariant,\n/* harmony export */   \"mdiLinkBoxVariantOutline\": () => /* binding */ mdiLinkBoxVariantOutline,\n/* harmony export */   \"mdiLinkLock\": () => /* binding */ mdiLinkLock,\n/* harmony export */   \"mdiLinkOff\": () => /* binding */ mdiLinkOff,\n/* harmony export */   \"mdiLinkPlus\": () => /* binding */ mdiLinkPlus,\n/* harmony export */   \"mdiLinkVariant\": () => /* binding */ mdiLinkVariant,\n/* harmony export */   \"mdiLinkVariantMinus\": () => /* binding */ mdiLinkVariantMinus,\n/* harmony export */   \"mdiLinkVariantOff\": () => /* binding */ mdiLinkVariantOff,\n/* harmony export */   \"mdiLinkVariantPlus\": () => /* binding */ mdiLinkVariantPlus,\n/* harmony export */   \"mdiLinkVariantRemove\": () => /* binding */ mdiLinkVariantRemove,\n/* harmony export */   \"mdiLinkedin\": () => /* binding */ mdiLinkedin,\n/* harmony export */   \"mdiLinux\": () => /* binding */ mdiLinux,\n/* harmony export */   \"mdiLinuxMint\": () => /* binding */ mdiLinuxMint,\n/* harmony export */   \"mdiLipstick\": () => /* binding */ mdiLipstick,\n/* harmony export */   \"mdiListStatus\": () => /* binding */ mdiListStatus,\n/* harmony export */   \"mdiLitecoin\": () => /* binding */ mdiLitecoin,\n/* harmony export */   \"mdiLoading\": () => /* binding */ mdiLoading,\n/* harmony export */   \"mdiLocationEnter\": () => /* binding */ mdiLocationEnter,\n/* harmony export */   \"mdiLocationExit\": () => /* binding */ mdiLocationExit,\n/* harmony export */   \"mdiLock\": () => /* binding */ mdiLock,\n/* harmony export */   \"mdiLockAlert\": () => /* binding */ mdiLockAlert,\n/* harmony export */   \"mdiLockAlertOutline\": () => /* binding */ mdiLockAlertOutline,\n/* harmony export */   \"mdiLockCheck\": () => /* binding */ mdiLockCheck,\n/* harmony export */   \"mdiLockClock\": () => /* binding */ mdiLockClock,\n/* harmony export */   \"mdiLockOpen\": () => /* binding */ mdiLockOpen,\n/* harmony export */   \"mdiLockOpenAlert\": () => /* binding */ mdiLockOpenAlert,\n/* harmony export */   \"mdiLockOpenAlertOutline\": () => /* binding */ mdiLockOpenAlertOutline,\n/* harmony export */   \"mdiLockOpenCheck\": () => /* binding */ mdiLockOpenCheck,\n/* harmony export */   \"mdiLockOpenOutline\": () => /* binding */ mdiLockOpenOutline,\n/* harmony export */   \"mdiLockOpenVariant\": () => /* binding */ mdiLockOpenVariant,\n/* harmony export */   \"mdiLockOpenVariantOutline\": () => /* binding */ mdiLockOpenVariantOutline,\n/* harmony export */   \"mdiLockOutline\": () => /* binding */ mdiLockOutline,\n/* harmony export */   \"mdiLockPattern\": () => /* binding */ mdiLockPattern,\n/* harmony export */   \"mdiLockPlus\": () => /* binding */ mdiLockPlus,\n/* harmony export */   \"mdiLockQuestion\": () => /* binding */ mdiLockQuestion,\n/* harmony export */   \"mdiLockReset\": () => /* binding */ mdiLockReset,\n/* harmony export */   \"mdiLockSmart\": () => /* binding */ mdiLockSmart,\n/* harmony export */   \"mdiLocker\": () => /* binding */ mdiLocker,\n/* harmony export */   \"mdiLockerMultiple\": () => /* binding */ mdiLockerMultiple,\n/* harmony export */   \"mdiLogin\": () => /* binding */ mdiLogin,\n/* harmony export */   \"mdiLoginVariant\": () => /* binding */ mdiLoginVariant,\n/* harmony export */   \"mdiLogout\": () => /* binding */ mdiLogout,\n/* harmony export */   \"mdiLogoutVariant\": () => /* binding */ mdiLogoutVariant,\n/* harmony export */   \"mdiLongitude\": () => /* binding */ mdiLongitude,\n/* harmony export */   \"mdiLooks\": () => /* binding */ mdiLooks,\n/* harmony export */   \"mdiLotion\": () => /* binding */ mdiLotion,\n/* harmony export */   \"mdiLotionOutline\": () => /* binding */ mdiLotionOutline,\n/* harmony export */   \"mdiLotionPlus\": () => /* binding */ mdiLotionPlus,\n/* harmony export */   \"mdiLotionPlusOutline\": () => /* binding */ mdiLotionPlusOutline,\n/* harmony export */   \"mdiLoupe\": () => /* binding */ mdiLoupe,\n/* harmony export */   \"mdiLumx\": () => /* binding */ mdiLumx,\n/* harmony export */   \"mdiLungs\": () => /* binding */ mdiLungs,\n/* harmony export */   \"mdiMagnet\": () => /* binding */ mdiMagnet,\n/* harmony export */   \"mdiMagnetOn\": () => /* binding */ mdiMagnetOn,\n/* harmony export */   \"mdiMagnify\": () => /* binding */ mdiMagnify,\n/* harmony export */   \"mdiMagnifyClose\": () => /* binding */ mdiMagnifyClose,\n/* harmony export */   \"mdiMagnifyMinus\": () => /* binding */ mdiMagnifyMinus,\n/* harmony export */   \"mdiMagnifyMinusCursor\": () => /* binding */ mdiMagnifyMinusCursor,\n/* harmony export */   \"mdiMagnifyMinusOutline\": () => /* binding */ mdiMagnifyMinusOutline,\n/* harmony export */   \"mdiMagnifyPlus\": () => /* binding */ mdiMagnifyPlus,\n/* harmony export */   \"mdiMagnifyPlusCursor\": () => /* binding */ mdiMagnifyPlusCursor,\n/* harmony export */   \"mdiMagnifyPlusOutline\": () => /* binding */ mdiMagnifyPlusOutline,\n/* harmony export */   \"mdiMagnifyRemoveCursor\": () => /* binding */ mdiMagnifyRemoveCursor,\n/* harmony export */   \"mdiMagnifyRemoveOutline\": () => /* binding */ mdiMagnifyRemoveOutline,\n/* harmony export */   \"mdiMagnifyScan\": () => /* binding */ mdiMagnifyScan,\n/* harmony export */   \"mdiMail\": () => /* binding */ mdiMail,\n/* harmony export */   \"mdiMailbox\": () => /* binding */ mdiMailbox,\n/* harmony export */   \"mdiMailboxOpen\": () => /* binding */ mdiMailboxOpen,\n/* harmony export */   \"mdiMailboxOpenOutline\": () => /* binding */ mdiMailboxOpenOutline,\n/* harmony export */   \"mdiMailboxOpenUp\": () => /* binding */ mdiMailboxOpenUp,\n/* harmony export */   \"mdiMailboxOpenUpOutline\": () => /* binding */ mdiMailboxOpenUpOutline,\n/* harmony export */   \"mdiMailboxOutline\": () => /* binding */ mdiMailboxOutline,\n/* harmony export */   \"mdiMailboxUp\": () => /* binding */ mdiMailboxUp,\n/* harmony export */   \"mdiMailboxUpOutline\": () => /* binding */ mdiMailboxUpOutline,\n/* harmony export */   \"mdiManjaro\": () => /* binding */ mdiManjaro,\n/* harmony export */   \"mdiMap\": () => /* binding */ mdiMap,\n/* harmony export */   \"mdiMapCheck\": () => /* binding */ mdiMapCheck,\n/* harmony export */   \"mdiMapCheckOutline\": () => /* binding */ mdiMapCheckOutline,\n/* harmony export */   \"mdiMapClock\": () => /* binding */ mdiMapClock,\n/* harmony export */   \"mdiMapClockOutline\": () => /* binding */ mdiMapClockOutline,\n/* harmony export */   \"mdiMapLegend\": () => /* binding */ mdiMapLegend,\n/* harmony export */   \"mdiMapMarker\": () => /* binding */ mdiMapMarker,\n/* harmony export */   \"mdiMapMarkerAlert\": () => /* binding */ mdiMapMarkerAlert,\n/* harmony export */   \"mdiMapMarkerAlertOutline\": () => /* binding */ mdiMapMarkerAlertOutline,\n/* harmony export */   \"mdiMapMarkerCheck\": () => /* binding */ mdiMapMarkerCheck,\n/* harmony export */   \"mdiMapMarkerCheckOutline\": () => /* binding */ mdiMapMarkerCheckOutline,\n/* harmony export */   \"mdiMapMarkerCircle\": () => /* binding */ mdiMapMarkerCircle,\n/* harmony export */   \"mdiMapMarkerDistance\": () => /* binding */ mdiMapMarkerDistance,\n/* harmony export */   \"mdiMapMarkerDown\": () => /* binding */ mdiMapMarkerDown,\n/* harmony export */   \"mdiMapMarkerLeft\": () => /* binding */ mdiMapMarkerLeft,\n/* harmony export */   \"mdiMapMarkerLeftOutline\": () => /* binding */ mdiMapMarkerLeftOutline,\n/* harmony export */   \"mdiMapMarkerMinus\": () => /* binding */ mdiMapMarkerMinus,\n/* harmony export */   \"mdiMapMarkerMinusOutline\": () => /* binding */ mdiMapMarkerMinusOutline,\n/* harmony export */   \"mdiMapMarkerMultiple\": () => /* binding */ mdiMapMarkerMultiple,\n/* harmony export */   \"mdiMapMarkerMultipleOutline\": () => /* binding */ mdiMapMarkerMultipleOutline,\n/* harmony export */   \"mdiMapMarkerOff\": () => /* binding */ mdiMapMarkerOff,\n/* harmony export */   \"mdiMapMarkerOffOutline\": () => /* binding */ mdiMapMarkerOffOutline,\n/* harmony export */   \"mdiMapMarkerOutline\": () => /* binding */ mdiMapMarkerOutline,\n/* harmony export */   \"mdiMapMarkerPath\": () => /* binding */ mdiMapMarkerPath,\n/* harmony export */   \"mdiMapMarkerPlus\": () => /* binding */ mdiMapMarkerPlus,\n/* harmony export */   \"mdiMapMarkerPlusOutline\": () => /* binding */ mdiMapMarkerPlusOutline,\n/* harmony export */   \"mdiMapMarkerQuestion\": () => /* binding */ mdiMapMarkerQuestion,\n/* harmony export */   \"mdiMapMarkerQuestionOutline\": () => /* binding */ mdiMapMarkerQuestionOutline,\n/* harmony export */   \"mdiMapMarkerRadius\": () => /* binding */ mdiMapMarkerRadius,\n/* harmony export */   \"mdiMapMarkerRadiusOutline\": () => /* binding */ mdiMapMarkerRadiusOutline,\n/* harmony export */   \"mdiMapMarkerRemove\": () => /* binding */ mdiMapMarkerRemove,\n/* harmony export */   \"mdiMapMarkerRemoveOutline\": () => /* binding */ mdiMapMarkerRemoveOutline,\n/* harmony export */   \"mdiMapMarkerRemoveVariant\": () => /* binding */ mdiMapMarkerRemoveVariant,\n/* harmony export */   \"mdiMapMarkerRight\": () => /* binding */ mdiMapMarkerRight,\n/* harmony export */   \"mdiMapMarkerRightOutline\": () => /* binding */ mdiMapMarkerRightOutline,\n/* harmony export */   \"mdiMapMarkerStar\": () => /* binding */ mdiMapMarkerStar,\n/* harmony export */   \"mdiMapMarkerStarOutline\": () => /* binding */ mdiMapMarkerStarOutline,\n/* harmony export */   \"mdiMapMarkerUp\": () => /* binding */ mdiMapMarkerUp,\n/* harmony export */   \"mdiMapMinus\": () => /* binding */ mdiMapMinus,\n/* harmony export */   \"mdiMapOutline\": () => /* binding */ mdiMapOutline,\n/* harmony export */   \"mdiMapPlus\": () => /* binding */ mdiMapPlus,\n/* harmony export */   \"mdiMapSearch\": () => /* binding */ mdiMapSearch,\n/* harmony export */   \"mdiMapSearchOutline\": () => /* binding */ mdiMapSearchOutline,\n/* harmony export */   \"mdiMapbox\": () => /* binding */ mdiMapbox,\n/* harmony export */   \"mdiMargin\": () => /* binding */ mdiMargin,\n/* harmony export */   \"mdiMarker\": () => /* binding */ mdiMarker,\n/* harmony export */   \"mdiMarkerCancel\": () => /* binding */ mdiMarkerCancel,\n/* harmony export */   \"mdiMarkerCheck\": () => /* binding */ mdiMarkerCheck,\n/* harmony export */   \"mdiMastodon\": () => /* binding */ mdiMastodon,\n/* harmony export */   \"mdiMaterialDesign\": () => /* binding */ mdiMaterialDesign,\n/* harmony export */   \"mdiMaterialUi\": () => /* binding */ mdiMaterialUi,\n/* harmony export */   \"mdiMathCompass\": () => /* binding */ mdiMathCompass,\n/* harmony export */   \"mdiMathCos\": () => /* binding */ mdiMathCos,\n/* harmony export */   \"mdiMathIntegral\": () => /* binding */ mdiMathIntegral,\n/* harmony export */   \"mdiMathIntegralBox\": () => /* binding */ mdiMathIntegralBox,\n/* harmony export */   \"mdiMathLog\": () => /* binding */ mdiMathLog,\n/* harmony export */   \"mdiMathNorm\": () => /* binding */ mdiMathNorm,\n/* harmony export */   \"mdiMathNormBox\": () => /* binding */ mdiMathNormBox,\n/* harmony export */   \"mdiMathSin\": () => /* binding */ mdiMathSin,\n/* harmony export */   \"mdiMathTan\": () => /* binding */ mdiMathTan,\n/* harmony export */   \"mdiMatrix\": () => /* binding */ mdiMatrix,\n/* harmony export */   \"mdiMedal\": () => /* binding */ mdiMedal,\n/* harmony export */   \"mdiMedalOutline\": () => /* binding */ mdiMedalOutline,\n/* harmony export */   \"mdiMedicalBag\": () => /* binding */ mdiMedicalBag,\n/* harmony export */   \"mdiMeditation\": () => /* binding */ mdiMeditation,\n/* harmony export */   \"mdiMemory\": () => /* binding */ mdiMemory,\n/* harmony export */   \"mdiMenu\": () => /* binding */ mdiMenu,\n/* harmony export */   \"mdiMenuDown\": () => /* binding */ mdiMenuDown,\n/* harmony export */   \"mdiMenuDownOutline\": () => /* binding */ mdiMenuDownOutline,\n/* harmony export */   \"mdiMenuLeft\": () => /* binding */ mdiMenuLeft,\n/* harmony export */   \"mdiMenuLeftOutline\": () => /* binding */ mdiMenuLeftOutline,\n/* harmony export */   \"mdiMenuOpen\": () => /* binding */ mdiMenuOpen,\n/* harmony export */   \"mdiMenuRight\": () => /* binding */ mdiMenuRight,\n/* harmony export */   \"mdiMenuRightOutline\": () => /* binding */ mdiMenuRightOutline,\n/* harmony export */   \"mdiMenuSwap\": () => /* binding */ mdiMenuSwap,\n/* harmony export */   \"mdiMenuSwapOutline\": () => /* binding */ mdiMenuSwapOutline,\n/* harmony export */   \"mdiMenuUp\": () => /* binding */ mdiMenuUp,\n/* harmony export */   \"mdiMenuUpOutline\": () => /* binding */ mdiMenuUpOutline,\n/* harmony export */   \"mdiMerge\": () => /* binding */ mdiMerge,\n/* harmony export */   \"mdiMessage\": () => /* binding */ mdiMessage,\n/* harmony export */   \"mdiMessageAlert\": () => /* binding */ mdiMessageAlert,\n/* harmony export */   \"mdiMessageAlertOutline\": () => /* binding */ mdiMessageAlertOutline,\n/* harmony export */   \"mdiMessageArrowLeft\": () => /* binding */ mdiMessageArrowLeft,\n/* harmony export */   \"mdiMessageArrowLeftOutline\": () => /* binding */ mdiMessageArrowLeftOutline,\n/* harmony export */   \"mdiMessageArrowRight\": () => /* binding */ mdiMessageArrowRight,\n/* harmony export */   \"mdiMessageArrowRightOutline\": () => /* binding */ mdiMessageArrowRightOutline,\n/* harmony export */   \"mdiMessageBookmark\": () => /* binding */ mdiMessageBookmark,\n/* harmony export */   \"mdiMessageBookmarkOutline\": () => /* binding */ mdiMessageBookmarkOutline,\n/* harmony export */   \"mdiMessageBulleted\": () => /* binding */ mdiMessageBulleted,\n/* harmony export */   \"mdiMessageBulletedOff\": () => /* binding */ mdiMessageBulletedOff,\n/* harmony export */   \"mdiMessageCog\": () => /* binding */ mdiMessageCog,\n/* harmony export */   \"mdiMessageCogOutline\": () => /* binding */ mdiMessageCogOutline,\n/* harmony export */   \"mdiMessageDraw\": () => /* binding */ mdiMessageDraw,\n/* harmony export */   \"mdiMessageFlash\": () => /* binding */ mdiMessageFlash,\n/* harmony export */   \"mdiMessageFlashOutline\": () => /* binding */ mdiMessageFlashOutline,\n/* harmony export */   \"mdiMessageImage\": () => /* binding */ mdiMessageImage,\n/* harmony export */   \"mdiMessageImageOutline\": () => /* binding */ mdiMessageImageOutline,\n/* harmony export */   \"mdiMessageLock\": () => /* binding */ mdiMessageLock,\n/* harmony export */   \"mdiMessageLockOutline\": () => /* binding */ mdiMessageLockOutline,\n/* harmony export */   \"mdiMessageMinus\": () => /* binding */ mdiMessageMinus,\n/* harmony export */   \"mdiMessageMinusOutline\": () => /* binding */ mdiMessageMinusOutline,\n/* harmony export */   \"mdiMessageOutline\": () => /* binding */ mdiMessageOutline,\n/* harmony export */   \"mdiMessagePlus\": () => /* binding */ mdiMessagePlus,\n/* harmony export */   \"mdiMessagePlusOutline\": () => /* binding */ mdiMessagePlusOutline,\n/* harmony export */   \"mdiMessageProcessing\": () => /* binding */ mdiMessageProcessing,\n/* harmony export */   \"mdiMessageProcessingOutline\": () => /* binding */ mdiMessageProcessingOutline,\n/* harmony export */   \"mdiMessageReply\": () => /* binding */ mdiMessageReply,\n/* harmony export */   \"mdiMessageReplyText\": () => /* binding */ mdiMessageReplyText,\n/* harmony export */   \"mdiMessageSettings\": () => /* binding */ mdiMessageSettings,\n/* harmony export */   \"mdiMessageSettingsOutline\": () => /* binding */ mdiMessageSettingsOutline,\n/* harmony export */   \"mdiMessageText\": () => /* binding */ mdiMessageText,\n/* harmony export */   \"mdiMessageTextClock\": () => /* binding */ mdiMessageTextClock,\n/* harmony export */   \"mdiMessageTextClockOutline\": () => /* binding */ mdiMessageTextClockOutline,\n/* harmony export */   \"mdiMessageTextLock\": () => /* binding */ mdiMessageTextLock,\n/* harmony export */   \"mdiMessageTextLockOutline\": () => /* binding */ mdiMessageTextLockOutline,\n/* harmony export */   \"mdiMessageTextOutline\": () => /* binding */ mdiMessageTextOutline,\n/* harmony export */   \"mdiMessageVideo\": () => /* binding */ mdiMessageVideo,\n/* harmony export */   \"mdiMeteor\": () => /* binding */ mdiMeteor,\n/* harmony export */   \"mdiMetronome\": () => /* binding */ mdiMetronome,\n/* harmony export */   \"mdiMetronomeTick\": () => /* binding */ mdiMetronomeTick,\n/* harmony export */   \"mdiMicroSd\": () => /* binding */ mdiMicroSd,\n/* harmony export */   \"mdiMicrophone\": () => /* binding */ mdiMicrophone,\n/* harmony export */   \"mdiMicrophoneMinus\": () => /* binding */ mdiMicrophoneMinus,\n/* harmony export */   \"mdiMicrophoneOff\": () => /* binding */ mdiMicrophoneOff,\n/* harmony export */   \"mdiMicrophoneOutline\": () => /* binding */ mdiMicrophoneOutline,\n/* harmony export */   \"mdiMicrophonePlus\": () => /* binding */ mdiMicrophonePlus,\n/* harmony export */   \"mdiMicrophoneSettings\": () => /* binding */ mdiMicrophoneSettings,\n/* harmony export */   \"mdiMicrophoneVariant\": () => /* binding */ mdiMicrophoneVariant,\n/* harmony export */   \"mdiMicrophoneVariantOff\": () => /* binding */ mdiMicrophoneVariantOff,\n/* harmony export */   \"mdiMicroscope\": () => /* binding */ mdiMicroscope,\n/* harmony export */   \"mdiMicrosoft\": () => /* binding */ mdiMicrosoft,\n/* harmony export */   \"mdiMicrosoftAccess\": () => /* binding */ mdiMicrosoftAccess,\n/* harmony export */   \"mdiMicrosoftAzure\": () => /* binding */ mdiMicrosoftAzure,\n/* harmony export */   \"mdiMicrosoftAzureDevops\": () => /* binding */ mdiMicrosoftAzureDevops,\n/* harmony export */   \"mdiMicrosoftBing\": () => /* binding */ mdiMicrosoftBing,\n/* harmony export */   \"mdiMicrosoftDynamics365\": () => /* binding */ mdiMicrosoftDynamics365,\n/* harmony export */   \"mdiMicrosoftEdge\": () => /* binding */ mdiMicrosoftEdge,\n/* harmony export */   \"mdiMicrosoftEdgeLegacy\": () => /* binding */ mdiMicrosoftEdgeLegacy,\n/* harmony export */   \"mdiMicrosoftExcel\": () => /* binding */ mdiMicrosoftExcel,\n/* harmony export */   \"mdiMicrosoftInternetExplorer\": () => /* binding */ mdiMicrosoftInternetExplorer,\n/* harmony export */   \"mdiMicrosoftOffice\": () => /* binding */ mdiMicrosoftOffice,\n/* harmony export */   \"mdiMicrosoftOnedrive\": () => /* binding */ mdiMicrosoftOnedrive,\n/* harmony export */   \"mdiMicrosoftOnenote\": () => /* binding */ mdiMicrosoftOnenote,\n/* harmony export */   \"mdiMicrosoftOutlook\": () => /* binding */ mdiMicrosoftOutlook,\n/* harmony export */   \"mdiMicrosoftPowerpoint\": () => /* binding */ mdiMicrosoftPowerpoint,\n/* harmony export */   \"mdiMicrosoftSharepoint\": () => /* binding */ mdiMicrosoftSharepoint,\n/* harmony export */   \"mdiMicrosoftTeams\": () => /* binding */ mdiMicrosoftTeams,\n/* harmony export */   \"mdiMicrosoftVisualStudio\": () => /* binding */ mdiMicrosoftVisualStudio,\n/* harmony export */   \"mdiMicrosoftVisualStudioCode\": () => /* binding */ mdiMicrosoftVisualStudioCode,\n/* harmony export */   \"mdiMicrosoftWindows\": () => /* binding */ mdiMicrosoftWindows,\n/* harmony export */   \"mdiMicrosoftWindowsClassic\": () => /* binding */ mdiMicrosoftWindowsClassic,\n/* harmony export */   \"mdiMicrosoftWord\": () => /* binding */ mdiMicrosoftWord,\n/* harmony export */   \"mdiMicrosoftXbox\": () => /* binding */ mdiMicrosoftXbox,\n/* harmony export */   \"mdiMicrosoftXboxController\": () => /* binding */ mdiMicrosoftXboxController,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryAlert\": () => /* binding */ mdiMicrosoftXboxControllerBatteryAlert,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryCharging\": () => /* binding */ mdiMicrosoftXboxControllerBatteryCharging,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryEmpty\": () => /* binding */ mdiMicrosoftXboxControllerBatteryEmpty,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryFull\": () => /* binding */ mdiMicrosoftXboxControllerBatteryFull,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryLow\": () => /* binding */ mdiMicrosoftXboxControllerBatteryLow,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryMedium\": () => /* binding */ mdiMicrosoftXboxControllerBatteryMedium,\n/* harmony export */   \"mdiMicrosoftXboxControllerBatteryUnknown\": () => /* binding */ mdiMicrosoftXboxControllerBatteryUnknown,\n/* harmony export */   \"mdiMicrosoftXboxControllerMenu\": () => /* binding */ mdiMicrosoftXboxControllerMenu,\n/* harmony export */   \"mdiMicrosoftXboxControllerOff\": () => /* binding */ mdiMicrosoftXboxControllerOff,\n/* harmony export */   \"mdiMicrosoftXboxControllerView\": () => /* binding */ mdiMicrosoftXboxControllerView,\n/* harmony export */   \"mdiMicrosoftYammer\": () => /* binding */ mdiMicrosoftYammer,\n/* harmony export */   \"mdiMicrowave\": () => /* binding */ mdiMicrowave,\n/* harmony export */   \"mdiMicrowaveOff\": () => /* binding */ mdiMicrowaveOff,\n/* harmony export */   \"mdiMiddleware\": () => /* binding */ mdiMiddleware,\n/* harmony export */   \"mdiMiddlewareOutline\": () => /* binding */ mdiMiddlewareOutline,\n/* harmony export */   \"mdiMidi\": () => /* binding */ mdiMidi,\n/* harmony export */   \"mdiMidiPort\": () => /* binding */ mdiMidiPort,\n/* harmony export */   \"mdiMine\": () => /* binding */ mdiMine,\n/* harmony export */   \"mdiMinecraft\": () => /* binding */ mdiMinecraft,\n/* harmony export */   \"mdiMiniSd\": () => /* binding */ mdiMiniSd,\n/* harmony export */   \"mdiMinidisc\": () => /* binding */ mdiMinidisc,\n/* harmony export */   \"mdiMinus\": () => /* binding */ mdiMinus,\n/* harmony export */   \"mdiMinusBox\": () => /* binding */ mdiMinusBox,\n/* harmony export */   \"mdiMinusBoxMultiple\": () => /* binding */ mdiMinusBoxMultiple,\n/* harmony export */   \"mdiMinusBoxMultipleOutline\": () => /* binding */ mdiMinusBoxMultipleOutline,\n/* harmony export */   \"mdiMinusBoxOutline\": () => /* binding */ mdiMinusBoxOutline,\n/* harmony export */   \"mdiMinusCircle\": () => /* binding */ mdiMinusCircle,\n/* harmony export */   \"mdiMinusCircleMultiple\": () => /* binding */ mdiMinusCircleMultiple,\n/* harmony export */   \"mdiMinusCircleMultipleOutline\": () => /* binding */ mdiMinusCircleMultipleOutline,\n/* harmony export */   \"mdiMinusCircleOff\": () => /* binding */ mdiMinusCircleOff,\n/* harmony export */   \"mdiMinusCircleOffOutline\": () => /* binding */ mdiMinusCircleOffOutline,\n/* harmony export */   \"mdiMinusCircleOutline\": () => /* binding */ mdiMinusCircleOutline,\n/* harmony export */   \"mdiMinusNetwork\": () => /* binding */ mdiMinusNetwork,\n/* harmony export */   \"mdiMinusNetworkOutline\": () => /* binding */ mdiMinusNetworkOutline,\n/* harmony export */   \"mdiMirror\": () => /* binding */ mdiMirror,\n/* harmony export */   \"mdiMixedMartialArts\": () => /* binding */ mdiMixedMartialArts,\n/* harmony export */   \"mdiMixedReality\": () => /* binding */ mdiMixedReality,\n/* harmony export */   \"mdiMolecule\": () => /* binding */ mdiMolecule,\n/* harmony export */   \"mdiMoleculeCo\": () => /* binding */ mdiMoleculeCo,\n/* harmony export */   \"mdiMoleculeCo2\": () => /* binding */ mdiMoleculeCo2,\n/* harmony export */   \"mdiMonitor\": () => /* binding */ mdiMonitor,\n/* harmony export */   \"mdiMonitorCellphone\": () => /* binding */ mdiMonitorCellphone,\n/* harmony export */   \"mdiMonitorCellphoneStar\": () => /* binding */ mdiMonitorCellphoneStar,\n/* harmony export */   \"mdiMonitorClean\": () => /* binding */ mdiMonitorClean,\n/* harmony export */   \"mdiMonitorDashboard\": () => /* binding */ mdiMonitorDashboard,\n/* harmony export */   \"mdiMonitorEdit\": () => /* binding */ mdiMonitorEdit,\n/* harmony export */   \"mdiMonitorEye\": () => /* binding */ mdiMonitorEye,\n/* harmony export */   \"mdiMonitorLock\": () => /* binding */ mdiMonitorLock,\n/* harmony export */   \"mdiMonitorMultiple\": () => /* binding */ mdiMonitorMultiple,\n/* harmony export */   \"mdiMonitorOff\": () => /* binding */ mdiMonitorOff,\n/* harmony export */   \"mdiMonitorScreenshot\": () => /* binding */ mdiMonitorScreenshot,\n/* harmony export */   \"mdiMonitorShare\": () => /* binding */ mdiMonitorShare,\n/* harmony export */   \"mdiMonitorSpeaker\": () => /* binding */ mdiMonitorSpeaker,\n/* harmony export */   \"mdiMonitorSpeakerOff\": () => /* binding */ mdiMonitorSpeakerOff,\n/* harmony export */   \"mdiMonitorStar\": () => /* binding */ mdiMonitorStar,\n/* harmony export */   \"mdiMoonFirstQuarter\": () => /* binding */ mdiMoonFirstQuarter,\n/* harmony export */   \"mdiMoonFull\": () => /* binding */ mdiMoonFull,\n/* harmony export */   \"mdiMoonLastQuarter\": () => /* binding */ mdiMoonLastQuarter,\n/* harmony export */   \"mdiMoonNew\": () => /* binding */ mdiMoonNew,\n/* harmony export */   \"mdiMoonWaningCrescent\": () => /* binding */ mdiMoonWaningCrescent,\n/* harmony export */   \"mdiMoonWaningGibbous\": () => /* binding */ mdiMoonWaningGibbous,\n/* harmony export */   \"mdiMoonWaxingCrescent\": () => /* binding */ mdiMoonWaxingCrescent,\n/* harmony export */   \"mdiMoonWaxingGibbous\": () => /* binding */ mdiMoonWaxingGibbous,\n/* harmony export */   \"mdiMoped\": () => /* binding */ mdiMoped,\n/* harmony export */   \"mdiMopedElectric\": () => /* binding */ mdiMopedElectric,\n/* harmony export */   \"mdiMopedElectricOutline\": () => /* binding */ mdiMopedElectricOutline,\n/* harmony export */   \"mdiMopedOutline\": () => /* binding */ mdiMopedOutline,\n/* harmony export */   \"mdiMore\": () => /* binding */ mdiMore,\n/* harmony export */   \"mdiMotherHeart\": () => /* binding */ mdiMotherHeart,\n/* harmony export */   \"mdiMotherNurse\": () => /* binding */ mdiMotherNurse,\n/* harmony export */   \"mdiMotion\": () => /* binding */ mdiMotion,\n/* harmony export */   \"mdiMotionOutline\": () => /* binding */ mdiMotionOutline,\n/* harmony export */   \"mdiMotionPause\": () => /* binding */ mdiMotionPause,\n/* harmony export */   \"mdiMotionPauseOutline\": () => /* binding */ mdiMotionPauseOutline,\n/* harmony export */   \"mdiMotionPlay\": () => /* binding */ mdiMotionPlay,\n/* harmony export */   \"mdiMotionPlayOutline\": () => /* binding */ mdiMotionPlayOutline,\n/* harmony export */   \"mdiMotionSensor\": () => /* binding */ mdiMotionSensor,\n/* harmony export */   \"mdiMotionSensorOff\": () => /* binding */ mdiMotionSensorOff,\n/* harmony export */   \"mdiMotorbike\": () => /* binding */ mdiMotorbike,\n/* harmony export */   \"mdiMotorbikeElectric\": () => /* binding */ mdiMotorbikeElectric,\n/* harmony export */   \"mdiMouse\": () => /* binding */ mdiMouse,\n/* harmony export */   \"mdiMouseBluetooth\": () => /* binding */ mdiMouseBluetooth,\n/* harmony export */   \"mdiMouseMoveDown\": () => /* binding */ mdiMouseMoveDown,\n/* harmony export */   \"mdiMouseMoveUp\": () => /* binding */ mdiMouseMoveUp,\n/* harmony export */   \"mdiMouseMoveVertical\": () => /* binding */ mdiMouseMoveVertical,\n/* harmony export */   \"mdiMouseOff\": () => /* binding */ mdiMouseOff,\n/* harmony export */   \"mdiMouseVariant\": () => /* binding */ mdiMouseVariant,\n/* harmony export */   \"mdiMouseVariantOff\": () => /* binding */ mdiMouseVariantOff,\n/* harmony export */   \"mdiMoveResize\": () => /* binding */ mdiMoveResize,\n/* harmony export */   \"mdiMoveResizeVariant\": () => /* binding */ mdiMoveResizeVariant,\n/* harmony export */   \"mdiMovie\": () => /* binding */ mdiMovie,\n/* harmony export */   \"mdiMovieEdit\": () => /* binding */ mdiMovieEdit,\n/* harmony export */   \"mdiMovieEditOutline\": () => /* binding */ mdiMovieEditOutline,\n/* harmony export */   \"mdiMovieFilter\": () => /* binding */ mdiMovieFilter,\n/* harmony export */   \"mdiMovieFilterOutline\": () => /* binding */ mdiMovieFilterOutline,\n/* harmony export */   \"mdiMovieOpen\": () => /* binding */ mdiMovieOpen,\n/* harmony export */   \"mdiMovieOpenOutline\": () => /* binding */ mdiMovieOpenOutline,\n/* harmony export */   \"mdiMovieOutline\": () => /* binding */ mdiMovieOutline,\n/* harmony export */   \"mdiMovieRoll\": () => /* binding */ mdiMovieRoll,\n/* harmony export */   \"mdiMovieSearch\": () => /* binding */ mdiMovieSearch,\n/* harmony export */   \"mdiMovieSearchOutline\": () => /* binding */ mdiMovieSearchOutline,\n/* harmony export */   \"mdiMuffin\": () => /* binding */ mdiMuffin,\n/* harmony export */   \"mdiMultiplication\": () => /* binding */ mdiMultiplication,\n/* harmony export */   \"mdiMultiplicationBox\": () => /* binding */ mdiMultiplicationBox,\n/* harmony export */   \"mdiMushroom\": () => /* binding */ mdiMushroom,\n/* harmony export */   \"mdiMushroomOff\": () => /* binding */ mdiMushroomOff,\n/* harmony export */   \"mdiMushroomOffOutline\": () => /* binding */ mdiMushroomOffOutline,\n/* harmony export */   \"mdiMushroomOutline\": () => /* binding */ mdiMushroomOutline,\n/* harmony export */   \"mdiMusic\": () => /* binding */ mdiMusic,\n/* harmony export */   \"mdiMusicAccidentalDoubleFlat\": () => /* binding */ mdiMusicAccidentalDoubleFlat,\n/* harmony export */   \"mdiMusicAccidentalDoubleSharp\": () => /* binding */ mdiMusicAccidentalDoubleSharp,\n/* harmony export */   \"mdiMusicAccidentalFlat\": () => /* binding */ mdiMusicAccidentalFlat,\n/* harmony export */   \"mdiMusicAccidentalNatural\": () => /* binding */ mdiMusicAccidentalNatural,\n/* harmony export */   \"mdiMusicAccidentalSharp\": () => /* binding */ mdiMusicAccidentalSharp,\n/* harmony export */   \"mdiMusicBox\": () => /* binding */ mdiMusicBox,\n/* harmony export */   \"mdiMusicBoxMultiple\": () => /* binding */ mdiMusicBoxMultiple,\n/* harmony export */   \"mdiMusicBoxMultipleOutline\": () => /* binding */ mdiMusicBoxMultipleOutline,\n/* harmony export */   \"mdiMusicBoxOutline\": () => /* binding */ mdiMusicBoxOutline,\n/* harmony export */   \"mdiMusicCircle\": () => /* binding */ mdiMusicCircle,\n/* harmony export */   \"mdiMusicCircleOutline\": () => /* binding */ mdiMusicCircleOutline,\n/* harmony export */   \"mdiMusicClefAlto\": () => /* binding */ mdiMusicClefAlto,\n/* harmony export */   \"mdiMusicClefBass\": () => /* binding */ mdiMusicClefBass,\n/* harmony export */   \"mdiMusicClefTreble\": () => /* binding */ mdiMusicClefTreble,\n/* harmony export */   \"mdiMusicNote\": () => /* binding */ mdiMusicNote,\n/* harmony export */   \"mdiMusicNoteBluetooth\": () => /* binding */ mdiMusicNoteBluetooth,\n/* harmony export */   \"mdiMusicNoteBluetoothOff\": () => /* binding */ mdiMusicNoteBluetoothOff,\n/* harmony export */   \"mdiMusicNoteEighth\": () => /* binding */ mdiMusicNoteEighth,\n/* harmony export */   \"mdiMusicNoteEighthDotted\": () => /* binding */ mdiMusicNoteEighthDotted,\n/* harmony export */   \"mdiMusicNoteHalf\": () => /* binding */ mdiMusicNoteHalf,\n/* harmony export */   \"mdiMusicNoteHalfDotted\": () => /* binding */ mdiMusicNoteHalfDotted,\n/* harmony export */   \"mdiMusicNoteOff\": () => /* binding */ mdiMusicNoteOff,\n/* harmony export */   \"mdiMusicNoteOffOutline\": () => /* binding */ mdiMusicNoteOffOutline,\n/* harmony export */   \"mdiMusicNoteOutline\": () => /* binding */ mdiMusicNoteOutline,\n/* harmony export */   \"mdiMusicNotePlus\": () => /* binding */ mdiMusicNotePlus,\n/* harmony export */   \"mdiMusicNoteQuarter\": () => /* binding */ mdiMusicNoteQuarter,\n/* harmony export */   \"mdiMusicNoteQuarterDotted\": () => /* binding */ mdiMusicNoteQuarterDotted,\n/* harmony export */   \"mdiMusicNoteSixteenth\": () => /* binding */ mdiMusicNoteSixteenth,\n/* harmony export */   \"mdiMusicNoteSixteenthDotted\": () => /* binding */ mdiMusicNoteSixteenthDotted,\n/* harmony export */   \"mdiMusicNoteWhole\": () => /* binding */ mdiMusicNoteWhole,\n/* harmony export */   \"mdiMusicNoteWholeDotted\": () => /* binding */ mdiMusicNoteWholeDotted,\n/* harmony export */   \"mdiMusicOff\": () => /* binding */ mdiMusicOff,\n/* harmony export */   \"mdiMusicRestEighth\": () => /* binding */ mdiMusicRestEighth,\n/* harmony export */   \"mdiMusicRestHalf\": () => /* binding */ mdiMusicRestHalf,\n/* harmony export */   \"mdiMusicRestQuarter\": () => /* binding */ mdiMusicRestQuarter,\n/* harmony export */   \"mdiMusicRestSixteenth\": () => /* binding */ mdiMusicRestSixteenth,\n/* harmony export */   \"mdiMusicRestWhole\": () => /* binding */ mdiMusicRestWhole,\n/* harmony export */   \"mdiMustache\": () => /* binding */ mdiMustache,\n/* harmony export */   \"mdiNail\": () => /* binding */ mdiNail,\n/* harmony export */   \"mdiNas\": () => /* binding */ mdiNas,\n/* harmony export */   \"mdiNativescript\": () => /* binding */ mdiNativescript,\n/* harmony export */   \"mdiNature\": () => /* binding */ mdiNature,\n/* harmony export */   \"mdiNaturePeople\": () => /* binding */ mdiNaturePeople,\n/* harmony export */   \"mdiNavigation\": () => /* binding */ mdiNavigation,\n/* harmony export */   \"mdiNavigationOutline\": () => /* binding */ mdiNavigationOutline,\n/* harmony export */   \"mdiNearMe\": () => /* binding */ mdiNearMe,\n/* harmony export */   \"mdiNecklace\": () => /* binding */ mdiNecklace,\n/* harmony export */   \"mdiNeedle\": () => /* binding */ mdiNeedle,\n/* harmony export */   \"mdiNetflix\": () => /* binding */ mdiNetflix,\n/* harmony export */   \"mdiNetwork\": () => /* binding */ mdiNetwork,\n/* harmony export */   \"mdiNetworkOff\": () => /* binding */ mdiNetworkOff,\n/* harmony export */   \"mdiNetworkOffOutline\": () => /* binding */ mdiNetworkOffOutline,\n/* harmony export */   \"mdiNetworkOutline\": () => /* binding */ mdiNetworkOutline,\n/* harmony export */   \"mdiNetworkStrength1\": () => /* binding */ mdiNetworkStrength1,\n/* harmony export */   \"mdiNetworkStrength1Alert\": () => /* binding */ mdiNetworkStrength1Alert,\n/* harmony export */   \"mdiNetworkStrength2\": () => /* binding */ mdiNetworkStrength2,\n/* harmony export */   \"mdiNetworkStrength2Alert\": () => /* binding */ mdiNetworkStrength2Alert,\n/* harmony export */   \"mdiNetworkStrength3\": () => /* binding */ mdiNetworkStrength3,\n/* harmony export */   \"mdiNetworkStrength3Alert\": () => /* binding */ mdiNetworkStrength3Alert,\n/* harmony export */   \"mdiNetworkStrength4\": () => /* binding */ mdiNetworkStrength4,\n/* harmony export */   \"mdiNetworkStrength4Alert\": () => /* binding */ mdiNetworkStrength4Alert,\n/* harmony export */   \"mdiNetworkStrengthOff\": () => /* binding */ mdiNetworkStrengthOff,\n/* harmony export */   \"mdiNetworkStrengthOffOutline\": () => /* binding */ mdiNetworkStrengthOffOutline,\n/* harmony export */   \"mdiNetworkStrengthOutline\": () => /* binding */ mdiNetworkStrengthOutline,\n/* harmony export */   \"mdiNewBox\": () => /* binding */ mdiNewBox,\n/* harmony export */   \"mdiNewspaper\": () => /* binding */ mdiNewspaper,\n/* harmony export */   \"mdiNewspaperMinus\": () => /* binding */ mdiNewspaperMinus,\n/* harmony export */   \"mdiNewspaperPlus\": () => /* binding */ mdiNewspaperPlus,\n/* harmony export */   \"mdiNewspaperVariant\": () => /* binding */ mdiNewspaperVariant,\n/* harmony export */   \"mdiNewspaperVariantMultiple\": () => /* binding */ mdiNewspaperVariantMultiple,\n/* harmony export */   \"mdiNewspaperVariantMultipleOutline\": () => /* binding */ mdiNewspaperVariantMultipleOutline,\n/* harmony export */   \"mdiNewspaperVariantOutline\": () => /* binding */ mdiNewspaperVariantOutline,\n/* harmony export */   \"mdiNfc\": () => /* binding */ mdiNfc,\n/* harmony export */   \"mdiNfcSearchVariant\": () => /* binding */ mdiNfcSearchVariant,\n/* harmony export */   \"mdiNfcTap\": () => /* binding */ mdiNfcTap,\n/* harmony export */   \"mdiNfcVariant\": () => /* binding */ mdiNfcVariant,\n/* harmony export */   \"mdiNfcVariantOff\": () => /* binding */ mdiNfcVariantOff,\n/* harmony export */   \"mdiNinja\": () => /* binding */ mdiNinja,\n/* harmony export */   \"mdiNintendoGameBoy\": () => /* binding */ mdiNintendoGameBoy,\n/* harmony export */   \"mdiNintendoSwitch\": () => /* binding */ mdiNintendoSwitch,\n/* harmony export */   \"mdiNintendoWii\": () => /* binding */ mdiNintendoWii,\n/* harmony export */   \"mdiNintendoWiiu\": () => /* binding */ mdiNintendoWiiu,\n/* harmony export */   \"mdiNix\": () => /* binding */ mdiNix,\n/* harmony export */   \"mdiNodejs\": () => /* binding */ mdiNodejs,\n/* harmony export */   \"mdiNoodles\": () => /* binding */ mdiNoodles,\n/* harmony export */   \"mdiNotEqual\": () => /* binding */ mdiNotEqual,\n/* harmony export */   \"mdiNotEqualVariant\": () => /* binding */ mdiNotEqualVariant,\n/* harmony export */   \"mdiNote\": () => /* binding */ mdiNote,\n/* harmony export */   \"mdiNoteMultiple\": () => /* binding */ mdiNoteMultiple,\n/* harmony export */   \"mdiNoteMultipleOutline\": () => /* binding */ mdiNoteMultipleOutline,\n/* harmony export */   \"mdiNoteOutline\": () => /* binding */ mdiNoteOutline,\n/* harmony export */   \"mdiNotePlus\": () => /* binding */ mdiNotePlus,\n/* harmony export */   \"mdiNotePlusOutline\": () => /* binding */ mdiNotePlusOutline,\n/* harmony export */   \"mdiNoteText\": () => /* binding */ mdiNoteText,\n/* harmony export */   \"mdiNoteTextOutline\": () => /* binding */ mdiNoteTextOutline,\n/* harmony export */   \"mdiNotebook\": () => /* binding */ mdiNotebook,\n/* harmony export */   \"mdiNotebookCheck\": () => /* binding */ mdiNotebookCheck,\n/* harmony export */   \"mdiNotebookCheckOutline\": () => /* binding */ mdiNotebookCheckOutline,\n/* harmony export */   \"mdiNotebookEdit\": () => /* binding */ mdiNotebookEdit,\n/* harmony export */   \"mdiNotebookEditOutline\": () => /* binding */ mdiNotebookEditOutline,\n/* harmony export */   \"mdiNotebookMinus\": () => /* binding */ mdiNotebookMinus,\n/* harmony export */   \"mdiNotebookMinusOutline\": () => /* binding */ mdiNotebookMinusOutline,\n/* harmony export */   \"mdiNotebookMultiple\": () => /* binding */ mdiNotebookMultiple,\n/* harmony export */   \"mdiNotebookOutline\": () => /* binding */ mdiNotebookOutline,\n/* harmony export */   \"mdiNotebookPlus\": () => /* binding */ mdiNotebookPlus,\n/* harmony export */   \"mdiNotebookPlusOutline\": () => /* binding */ mdiNotebookPlusOutline,\n/* harmony export */   \"mdiNotebookRemove\": () => /* binding */ mdiNotebookRemove,\n/* harmony export */   \"mdiNotebookRemoveOutline\": () => /* binding */ mdiNotebookRemoveOutline,\n/* harmony export */   \"mdiNotificationClearAll\": () => /* binding */ mdiNotificationClearAll,\n/* harmony export */   \"mdiNpm\": () => /* binding */ mdiNpm,\n/* harmony export */   \"mdiNuke\": () => /* binding */ mdiNuke,\n/* harmony export */   \"mdiNull\": () => /* binding */ mdiNull,\n/* harmony export */   \"mdiNumeric\": () => /* binding */ mdiNumeric,\n/* harmony export */   \"mdiNumeric0\": () => /* binding */ mdiNumeric0,\n/* harmony export */   \"mdiNumeric0Box\": () => /* binding */ mdiNumeric0Box,\n/* harmony export */   \"mdiNumeric0BoxMultiple\": () => /* binding */ mdiNumeric0BoxMultiple,\n/* harmony export */   \"mdiNumeric0BoxMultipleOutline\": () => /* binding */ mdiNumeric0BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric0BoxOutline\": () => /* binding */ mdiNumeric0BoxOutline,\n/* harmony export */   \"mdiNumeric0Circle\": () => /* binding */ mdiNumeric0Circle,\n/* harmony export */   \"mdiNumeric0CircleOutline\": () => /* binding */ mdiNumeric0CircleOutline,\n/* harmony export */   \"mdiNumeric1\": () => /* binding */ mdiNumeric1,\n/* harmony export */   \"mdiNumeric1Box\": () => /* binding */ mdiNumeric1Box,\n/* harmony export */   \"mdiNumeric1BoxMultiple\": () => /* binding */ mdiNumeric1BoxMultiple,\n/* harmony export */   \"mdiNumeric1BoxMultipleOutline\": () => /* binding */ mdiNumeric1BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric1BoxOutline\": () => /* binding */ mdiNumeric1BoxOutline,\n/* harmony export */   \"mdiNumeric1Circle\": () => /* binding */ mdiNumeric1Circle,\n/* harmony export */   \"mdiNumeric1CircleOutline\": () => /* binding */ mdiNumeric1CircleOutline,\n/* harmony export */   \"mdiNumeric10\": () => /* binding */ mdiNumeric10,\n/* harmony export */   \"mdiNumeric10Box\": () => /* binding */ mdiNumeric10Box,\n/* harmony export */   \"mdiNumeric10BoxMultiple\": () => /* binding */ mdiNumeric10BoxMultiple,\n/* harmony export */   \"mdiNumeric10BoxMultipleOutline\": () => /* binding */ mdiNumeric10BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric10BoxOutline\": () => /* binding */ mdiNumeric10BoxOutline,\n/* harmony export */   \"mdiNumeric10Circle\": () => /* binding */ mdiNumeric10Circle,\n/* harmony export */   \"mdiNumeric10CircleOutline\": () => /* binding */ mdiNumeric10CircleOutline,\n/* harmony export */   \"mdiNumeric2\": () => /* binding */ mdiNumeric2,\n/* harmony export */   \"mdiNumeric2Box\": () => /* binding */ mdiNumeric2Box,\n/* harmony export */   \"mdiNumeric2BoxMultiple\": () => /* binding */ mdiNumeric2BoxMultiple,\n/* harmony export */   \"mdiNumeric2BoxMultipleOutline\": () => /* binding */ mdiNumeric2BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric2BoxOutline\": () => /* binding */ mdiNumeric2BoxOutline,\n/* harmony export */   \"mdiNumeric2Circle\": () => /* binding */ mdiNumeric2Circle,\n/* harmony export */   \"mdiNumeric2CircleOutline\": () => /* binding */ mdiNumeric2CircleOutline,\n/* harmony export */   \"mdiNumeric3\": () => /* binding */ mdiNumeric3,\n/* harmony export */   \"mdiNumeric3Box\": () => /* binding */ mdiNumeric3Box,\n/* harmony export */   \"mdiNumeric3BoxMultiple\": () => /* binding */ mdiNumeric3BoxMultiple,\n/* harmony export */   \"mdiNumeric3BoxMultipleOutline\": () => /* binding */ mdiNumeric3BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric3BoxOutline\": () => /* binding */ mdiNumeric3BoxOutline,\n/* harmony export */   \"mdiNumeric3Circle\": () => /* binding */ mdiNumeric3Circle,\n/* harmony export */   \"mdiNumeric3CircleOutline\": () => /* binding */ mdiNumeric3CircleOutline,\n/* harmony export */   \"mdiNumeric4\": () => /* binding */ mdiNumeric4,\n/* harmony export */   \"mdiNumeric4Box\": () => /* binding */ mdiNumeric4Box,\n/* harmony export */   \"mdiNumeric4BoxMultiple\": () => /* binding */ mdiNumeric4BoxMultiple,\n/* harmony export */   \"mdiNumeric4BoxMultipleOutline\": () => /* binding */ mdiNumeric4BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric4BoxOutline\": () => /* binding */ mdiNumeric4BoxOutline,\n/* harmony export */   \"mdiNumeric4Circle\": () => /* binding */ mdiNumeric4Circle,\n/* harmony export */   \"mdiNumeric4CircleOutline\": () => /* binding */ mdiNumeric4CircleOutline,\n/* harmony export */   \"mdiNumeric5\": () => /* binding */ mdiNumeric5,\n/* harmony export */   \"mdiNumeric5Box\": () => /* binding */ mdiNumeric5Box,\n/* harmony export */   \"mdiNumeric5BoxMultiple\": () => /* binding */ mdiNumeric5BoxMultiple,\n/* harmony export */   \"mdiNumeric5BoxMultipleOutline\": () => /* binding */ mdiNumeric5BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric5BoxOutline\": () => /* binding */ mdiNumeric5BoxOutline,\n/* harmony export */   \"mdiNumeric5Circle\": () => /* binding */ mdiNumeric5Circle,\n/* harmony export */   \"mdiNumeric5CircleOutline\": () => /* binding */ mdiNumeric5CircleOutline,\n/* harmony export */   \"mdiNumeric6\": () => /* binding */ mdiNumeric6,\n/* harmony export */   \"mdiNumeric6Box\": () => /* binding */ mdiNumeric6Box,\n/* harmony export */   \"mdiNumeric6BoxMultiple\": () => /* binding */ mdiNumeric6BoxMultiple,\n/* harmony export */   \"mdiNumeric6BoxMultipleOutline\": () => /* binding */ mdiNumeric6BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric6BoxOutline\": () => /* binding */ mdiNumeric6BoxOutline,\n/* harmony export */   \"mdiNumeric6Circle\": () => /* binding */ mdiNumeric6Circle,\n/* harmony export */   \"mdiNumeric6CircleOutline\": () => /* binding */ mdiNumeric6CircleOutline,\n/* harmony export */   \"mdiNumeric7\": () => /* binding */ mdiNumeric7,\n/* harmony export */   \"mdiNumeric7Box\": () => /* binding */ mdiNumeric7Box,\n/* harmony export */   \"mdiNumeric7BoxMultiple\": () => /* binding */ mdiNumeric7BoxMultiple,\n/* harmony export */   \"mdiNumeric7BoxMultipleOutline\": () => /* binding */ mdiNumeric7BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric7BoxOutline\": () => /* binding */ mdiNumeric7BoxOutline,\n/* harmony export */   \"mdiNumeric7Circle\": () => /* binding */ mdiNumeric7Circle,\n/* harmony export */   \"mdiNumeric7CircleOutline\": () => /* binding */ mdiNumeric7CircleOutline,\n/* harmony export */   \"mdiNumeric8\": () => /* binding */ mdiNumeric8,\n/* harmony export */   \"mdiNumeric8Box\": () => /* binding */ mdiNumeric8Box,\n/* harmony export */   \"mdiNumeric8BoxMultiple\": () => /* binding */ mdiNumeric8BoxMultiple,\n/* harmony export */   \"mdiNumeric8BoxMultipleOutline\": () => /* binding */ mdiNumeric8BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric8BoxOutline\": () => /* binding */ mdiNumeric8BoxOutline,\n/* harmony export */   \"mdiNumeric8Circle\": () => /* binding */ mdiNumeric8Circle,\n/* harmony export */   \"mdiNumeric8CircleOutline\": () => /* binding */ mdiNumeric8CircleOutline,\n/* harmony export */   \"mdiNumeric9\": () => /* binding */ mdiNumeric9,\n/* harmony export */   \"mdiNumeric9Box\": () => /* binding */ mdiNumeric9Box,\n/* harmony export */   \"mdiNumeric9BoxMultiple\": () => /* binding */ mdiNumeric9BoxMultiple,\n/* harmony export */   \"mdiNumeric9BoxMultipleOutline\": () => /* binding */ mdiNumeric9BoxMultipleOutline,\n/* harmony export */   \"mdiNumeric9BoxOutline\": () => /* binding */ mdiNumeric9BoxOutline,\n/* harmony export */   \"mdiNumeric9Circle\": () => /* binding */ mdiNumeric9Circle,\n/* harmony export */   \"mdiNumeric9CircleOutline\": () => /* binding */ mdiNumeric9CircleOutline,\n/* harmony export */   \"mdiNumeric9Plus\": () => /* binding */ mdiNumeric9Plus,\n/* harmony export */   \"mdiNumeric9PlusBox\": () => /* binding */ mdiNumeric9PlusBox,\n/* harmony export */   \"mdiNumeric9PlusBoxMultiple\": () => /* binding */ mdiNumeric9PlusBoxMultiple,\n/* harmony export */   \"mdiNumeric9PlusBoxMultipleOutline\": () => /* binding */ mdiNumeric9PlusBoxMultipleOutline,\n/* harmony export */   \"mdiNumeric9PlusBoxOutline\": () => /* binding */ mdiNumeric9PlusBoxOutline,\n/* harmony export */   \"mdiNumeric9PlusCircle\": () => /* binding */ mdiNumeric9PlusCircle,\n/* harmony export */   \"mdiNumeric9PlusCircleOutline\": () => /* binding */ mdiNumeric9PlusCircleOutline,\n/* harmony export */   \"mdiNumericNegative1\": () => /* binding */ mdiNumericNegative1,\n/* harmony export */   \"mdiNumericPositive1\": () => /* binding */ mdiNumericPositive1,\n/* harmony export */   \"mdiNut\": () => /* binding */ mdiNut,\n/* harmony export */   \"mdiNutrition\": () => /* binding */ mdiNutrition,\n/* harmony export */   \"mdiNuxt\": () => /* binding */ mdiNuxt,\n/* harmony export */   \"mdiOar\": () => /* binding */ mdiOar,\n/* harmony export */   \"mdiOcarina\": () => /* binding */ mdiOcarina,\n/* harmony export */   \"mdiOci\": () => /* binding */ mdiOci,\n/* harmony export */   \"mdiOcr\": () => /* binding */ mdiOcr,\n/* harmony export */   \"mdiOctagon\": () => /* binding */ mdiOctagon,\n/* harmony export */   \"mdiOctagonOutline\": () => /* binding */ mdiOctagonOutline,\n/* harmony export */   \"mdiOctagram\": () => /* binding */ mdiOctagram,\n/* harmony export */   \"mdiOctagramOutline\": () => /* binding */ mdiOctagramOutline,\n/* harmony export */   \"mdiOdnoklassniki\": () => /* binding */ mdiOdnoklassniki,\n/* harmony export */   \"mdiOffer\": () => /* binding */ mdiOffer,\n/* harmony export */   \"mdiOfficeBuilding\": () => /* binding */ mdiOfficeBuilding,\n/* harmony export */   \"mdiOfficeBuildingMarker\": () => /* binding */ mdiOfficeBuildingMarker,\n/* harmony export */   \"mdiOfficeBuildingMarkerOutline\": () => /* binding */ mdiOfficeBuildingMarkerOutline,\n/* harmony export */   \"mdiOfficeBuildingOutline\": () => /* binding */ mdiOfficeBuildingOutline,\n/* harmony export */   \"mdiOil\": () => /* binding */ mdiOil,\n/* harmony export */   \"mdiOilLamp\": () => /* binding */ mdiOilLamp,\n/* harmony export */   \"mdiOilLevel\": () => /* binding */ mdiOilLevel,\n/* harmony export */   \"mdiOilTemperature\": () => /* binding */ mdiOilTemperature,\n/* harmony export */   \"mdiOmega\": () => /* binding */ mdiOmega,\n/* harmony export */   \"mdiOneUp\": () => /* binding */ mdiOneUp,\n/* harmony export */   \"mdiOnepassword\": () => /* binding */ mdiOnepassword,\n/* harmony export */   \"mdiOpacity\": () => /* binding */ mdiOpacity,\n/* harmony export */   \"mdiOpenInApp\": () => /* binding */ mdiOpenInApp,\n/* harmony export */   \"mdiOpenInNew\": () => /* binding */ mdiOpenInNew,\n/* harmony export */   \"mdiOpenSourceInitiative\": () => /* binding */ mdiOpenSourceInitiative,\n/* harmony export */   \"mdiOpenid\": () => /* binding */ mdiOpenid,\n/* harmony export */   \"mdiOpera\": () => /* binding */ mdiOpera,\n/* harmony export */   \"mdiOrbit\": () => /* binding */ mdiOrbit,\n/* harmony export */   \"mdiOrbitVariant\": () => /* binding */ mdiOrbitVariant,\n/* harmony export */   \"mdiOrderAlphabeticalAscending\": () => /* binding */ mdiOrderAlphabeticalAscending,\n/* harmony export */   \"mdiOrderAlphabeticalDescending\": () => /* binding */ mdiOrderAlphabeticalDescending,\n/* harmony export */   \"mdiOrderBoolAscending\": () => /* binding */ mdiOrderBoolAscending,\n/* harmony export */   \"mdiOrderBoolAscendingVariant\": () => /* binding */ mdiOrderBoolAscendingVariant,\n/* harmony export */   \"mdiOrderBoolDescending\": () => /* binding */ mdiOrderBoolDescending,\n/* harmony export */   \"mdiOrderBoolDescendingVariant\": () => /* binding */ mdiOrderBoolDescendingVariant,\n/* harmony export */   \"mdiOrderNumericAscending\": () => /* binding */ mdiOrderNumericAscending,\n/* harmony export */   \"mdiOrderNumericDescending\": () => /* binding */ mdiOrderNumericDescending,\n/* harmony export */   \"mdiOrigin\": () => /* binding */ mdiOrigin,\n/* harmony export */   \"mdiOrnament\": () => /* binding */ mdiOrnament,\n/* harmony export */   \"mdiOrnamentVariant\": () => /* binding */ mdiOrnamentVariant,\n/* harmony export */   \"mdiOutdoorLamp\": () => /* binding */ mdiOutdoorLamp,\n/* harmony export */   \"mdiOverscan\": () => /* binding */ mdiOverscan,\n/* harmony export */   \"mdiOwl\": () => /* binding */ mdiOwl,\n/* harmony export */   \"mdiPacMan\": () => /* binding */ mdiPacMan,\n/* harmony export */   \"mdiPackage\": () => /* binding */ mdiPackage,\n/* harmony export */   \"mdiPackageDown\": () => /* binding */ mdiPackageDown,\n/* harmony export */   \"mdiPackageUp\": () => /* binding */ mdiPackageUp,\n/* harmony export */   \"mdiPackageVariant\": () => /* binding */ mdiPackageVariant,\n/* harmony export */   \"mdiPackageVariantClosed\": () => /* binding */ mdiPackageVariantClosed,\n/* harmony export */   \"mdiPageFirst\": () => /* binding */ mdiPageFirst,\n/* harmony export */   \"mdiPageLast\": () => /* binding */ mdiPageLast,\n/* harmony export */   \"mdiPageLayoutBody\": () => /* binding */ mdiPageLayoutBody,\n/* harmony export */   \"mdiPageLayoutFooter\": () => /* binding */ mdiPageLayoutFooter,\n/* harmony export */   \"mdiPageLayoutHeader\": () => /* binding */ mdiPageLayoutHeader,\n/* harmony export */   \"mdiPageLayoutHeaderFooter\": () => /* binding */ mdiPageLayoutHeaderFooter,\n/* harmony export */   \"mdiPageLayoutSidebarLeft\": () => /* binding */ mdiPageLayoutSidebarLeft,\n/* harmony export */   \"mdiPageLayoutSidebarRight\": () => /* binding */ mdiPageLayoutSidebarRight,\n/* harmony export */   \"mdiPageNext\": () => /* binding */ mdiPageNext,\n/* harmony export */   \"mdiPageNextOutline\": () => /* binding */ mdiPageNextOutline,\n/* harmony export */   \"mdiPagePrevious\": () => /* binding */ mdiPagePrevious,\n/* harmony export */   \"mdiPagePreviousOutline\": () => /* binding */ mdiPagePreviousOutline,\n/* harmony export */   \"mdiPail\": () => /* binding */ mdiPail,\n/* harmony export */   \"mdiPailMinus\": () => /* binding */ mdiPailMinus,\n/* harmony export */   \"mdiPailMinusOutline\": () => /* binding */ mdiPailMinusOutline,\n/* harmony export */   \"mdiPailOff\": () => /* binding */ mdiPailOff,\n/* harmony export */   \"mdiPailOffOutline\": () => /* binding */ mdiPailOffOutline,\n/* harmony export */   \"mdiPailOutline\": () => /* binding */ mdiPailOutline,\n/* harmony export */   \"mdiPailPlus\": () => /* binding */ mdiPailPlus,\n/* harmony export */   \"mdiPailPlusOutline\": () => /* binding */ mdiPailPlusOutline,\n/* harmony export */   \"mdiPailRemove\": () => /* binding */ mdiPailRemove,\n/* harmony export */   \"mdiPailRemoveOutline\": () => /* binding */ mdiPailRemoveOutline,\n/* harmony export */   \"mdiPalette\": () => /* binding */ mdiPalette,\n/* harmony export */   \"mdiPaletteAdvanced\": () => /* binding */ mdiPaletteAdvanced,\n/* harmony export */   \"mdiPaletteOutline\": () => /* binding */ mdiPaletteOutline,\n/* harmony export */   \"mdiPaletteSwatch\": () => /* binding */ mdiPaletteSwatch,\n/* harmony export */   \"mdiPaletteSwatchOutline\": () => /* binding */ mdiPaletteSwatchOutline,\n/* harmony export */   \"mdiPalmTree\": () => /* binding */ mdiPalmTree,\n/* harmony export */   \"mdiPan\": () => /* binding */ mdiPan,\n/* harmony export */   \"mdiPanBottomLeft\": () => /* binding */ mdiPanBottomLeft,\n/* harmony export */   \"mdiPanBottomRight\": () => /* binding */ mdiPanBottomRight,\n/* harmony export */   \"mdiPanDown\": () => /* binding */ mdiPanDown,\n/* harmony export */   \"mdiPanHorizontal\": () => /* binding */ mdiPanHorizontal,\n/* harmony export */   \"mdiPanLeft\": () => /* binding */ mdiPanLeft,\n/* harmony export */   \"mdiPanRight\": () => /* binding */ mdiPanRight,\n/* harmony export */   \"mdiPanTopLeft\": () => /* binding */ mdiPanTopLeft,\n/* harmony export */   \"mdiPanTopRight\": () => /* binding */ mdiPanTopRight,\n/* harmony export */   \"mdiPanUp\": () => /* binding */ mdiPanUp,\n/* harmony export */   \"mdiPanVertical\": () => /* binding */ mdiPanVertical,\n/* harmony export */   \"mdiPanda\": () => /* binding */ mdiPanda,\n/* harmony export */   \"mdiPandora\": () => /* binding */ mdiPandora,\n/* harmony export */   \"mdiPanorama\": () => /* binding */ mdiPanorama,\n/* harmony export */   \"mdiPanoramaFisheye\": () => /* binding */ mdiPanoramaFisheye,\n/* harmony export */   \"mdiPanoramaHorizontal\": () => /* binding */ mdiPanoramaHorizontal,\n/* harmony export */   \"mdiPanoramaVertical\": () => /* binding */ mdiPanoramaVertical,\n/* harmony export */   \"mdiPanoramaWideAngle\": () => /* binding */ mdiPanoramaWideAngle,\n/* harmony export */   \"mdiPaperCutVertical\": () => /* binding */ mdiPaperCutVertical,\n/* harmony export */   \"mdiPaperRoll\": () => /* binding */ mdiPaperRoll,\n/* harmony export */   \"mdiPaperRollOutline\": () => /* binding */ mdiPaperRollOutline,\n/* harmony export */   \"mdiPaperclip\": () => /* binding */ mdiPaperclip,\n/* harmony export */   \"mdiParachute\": () => /* binding */ mdiParachute,\n/* harmony export */   \"mdiParachuteOutline\": () => /* binding */ mdiParachuteOutline,\n/* harmony export */   \"mdiParking\": () => /* binding */ mdiParking,\n/* harmony export */   \"mdiPartyPopper\": () => /* binding */ mdiPartyPopper,\n/* harmony export */   \"mdiPassport\": () => /* binding */ mdiPassport,\n/* harmony export */   \"mdiPassportBiometric\": () => /* binding */ mdiPassportBiometric,\n/* harmony export */   \"mdiPasta\": () => /* binding */ mdiPasta,\n/* harmony export */   \"mdiPatioHeater\": () => /* binding */ mdiPatioHeater,\n/* harmony export */   \"mdiPatreon\": () => /* binding */ mdiPatreon,\n/* harmony export */   \"mdiPause\": () => /* binding */ mdiPause,\n/* harmony export */   \"mdiPauseCircle\": () => /* binding */ mdiPauseCircle,\n/* harmony export */   \"mdiPauseCircleOutline\": () => /* binding */ mdiPauseCircleOutline,\n/* harmony export */   \"mdiPauseOctagon\": () => /* binding */ mdiPauseOctagon,\n/* harmony export */   \"mdiPauseOctagonOutline\": () => /* binding */ mdiPauseOctagonOutline,\n/* harmony export */   \"mdiPaw\": () => /* binding */ mdiPaw,\n/* harmony export */   \"mdiPawOff\": () => /* binding */ mdiPawOff,\n/* harmony export */   \"mdiPdfBox\": () => /* binding */ mdiPdfBox,\n/* harmony export */   \"mdiPeace\": () => /* binding */ mdiPeace,\n/* harmony export */   \"mdiPeanut\": () => /* binding */ mdiPeanut,\n/* harmony export */   \"mdiPeanutOff\": () => /* binding */ mdiPeanutOff,\n/* harmony export */   \"mdiPeanutOffOutline\": () => /* binding */ mdiPeanutOffOutline,\n/* harmony export */   \"mdiPeanutOutline\": () => /* binding */ mdiPeanutOutline,\n/* harmony export */   \"mdiPen\": () => /* binding */ mdiPen,\n/* harmony export */   \"mdiPenLock\": () => /* binding */ mdiPenLock,\n/* harmony export */   \"mdiPenMinus\": () => /* binding */ mdiPenMinus,\n/* harmony export */   \"mdiPenOff\": () => /* binding */ mdiPenOff,\n/* harmony export */   \"mdiPenPlus\": () => /* binding */ mdiPenPlus,\n/* harmony export */   \"mdiPenRemove\": () => /* binding */ mdiPenRemove,\n/* harmony export */   \"mdiPencil\": () => /* binding */ mdiPencil,\n/* harmony export */   \"mdiPencilBox\": () => /* binding */ mdiPencilBox,\n/* harmony export */   \"mdiPencilBoxMultiple\": () => /* binding */ mdiPencilBoxMultiple,\n/* harmony export */   \"mdiPencilBoxMultipleOutline\": () => /* binding */ mdiPencilBoxMultipleOutline,\n/* harmony export */   \"mdiPencilBoxOutline\": () => /* binding */ mdiPencilBoxOutline,\n/* harmony export */   \"mdiPencilCircle\": () => /* binding */ mdiPencilCircle,\n/* harmony export */   \"mdiPencilCircleOutline\": () => /* binding */ mdiPencilCircleOutline,\n/* harmony export */   \"mdiPencilLock\": () => /* binding */ mdiPencilLock,\n/* harmony export */   \"mdiPencilLockOutline\": () => /* binding */ mdiPencilLockOutline,\n/* harmony export */   \"mdiPencilMinus\": () => /* binding */ mdiPencilMinus,\n/* harmony export */   \"mdiPencilMinusOutline\": () => /* binding */ mdiPencilMinusOutline,\n/* harmony export */   \"mdiPencilOff\": () => /* binding */ mdiPencilOff,\n/* harmony export */   \"mdiPencilOffOutline\": () => /* binding */ mdiPencilOffOutline,\n/* harmony export */   \"mdiPencilOutline\": () => /* binding */ mdiPencilOutline,\n/* harmony export */   \"mdiPencilPlus\": () => /* binding */ mdiPencilPlus,\n/* harmony export */   \"mdiPencilPlusOutline\": () => /* binding */ mdiPencilPlusOutline,\n/* harmony export */   \"mdiPencilRemove\": () => /* binding */ mdiPencilRemove,\n/* harmony export */   \"mdiPencilRemoveOutline\": () => /* binding */ mdiPencilRemoveOutline,\n/* harmony export */   \"mdiPencilRuler\": () => /* binding */ mdiPencilRuler,\n/* harmony export */   \"mdiPenguin\": () => /* binding */ mdiPenguin,\n/* harmony export */   \"mdiPentagon\": () => /* binding */ mdiPentagon,\n/* harmony export */   \"mdiPentagonOutline\": () => /* binding */ mdiPentagonOutline,\n/* harmony export */   \"mdiPercent\": () => /* binding */ mdiPercent,\n/* harmony export */   \"mdiPercentOutline\": () => /* binding */ mdiPercentOutline,\n/* harmony export */   \"mdiPeriodicTable\": () => /* binding */ mdiPeriodicTable,\n/* harmony export */   \"mdiPerspectiveLess\": () => /* binding */ mdiPerspectiveLess,\n/* harmony export */   \"mdiPerspectiveMore\": () => /* binding */ mdiPerspectiveMore,\n/* harmony export */   \"mdiPharmacy\": () => /* binding */ mdiPharmacy,\n/* harmony export */   \"mdiPhone\": () => /* binding */ mdiPhone,\n/* harmony export */   \"mdiPhoneAlert\": () => /* binding */ mdiPhoneAlert,\n/* harmony export */   \"mdiPhoneAlertOutline\": () => /* binding */ mdiPhoneAlertOutline,\n/* harmony export */   \"mdiPhoneBluetooth\": () => /* binding */ mdiPhoneBluetooth,\n/* harmony export */   \"mdiPhoneBluetoothOutline\": () => /* binding */ mdiPhoneBluetoothOutline,\n/* harmony export */   \"mdiPhoneCancel\": () => /* binding */ mdiPhoneCancel,\n/* harmony export */   \"mdiPhoneCancelOutline\": () => /* binding */ mdiPhoneCancelOutline,\n/* harmony export */   \"mdiPhoneCheck\": () => /* binding */ mdiPhoneCheck,\n/* harmony export */   \"mdiPhoneCheckOutline\": () => /* binding */ mdiPhoneCheckOutline,\n/* harmony export */   \"mdiPhoneClassic\": () => /* binding */ mdiPhoneClassic,\n/* harmony export */   \"mdiPhoneClassicOff\": () => /* binding */ mdiPhoneClassicOff,\n/* harmony export */   \"mdiPhoneDial\": () => /* binding */ mdiPhoneDial,\n/* harmony export */   \"mdiPhoneDialOutline\": () => /* binding */ mdiPhoneDialOutline,\n/* harmony export */   \"mdiPhoneForward\": () => /* binding */ mdiPhoneForward,\n/* harmony export */   \"mdiPhoneForwardOutline\": () => /* binding */ mdiPhoneForwardOutline,\n/* harmony export */   \"mdiPhoneHangup\": () => /* binding */ mdiPhoneHangup,\n/* harmony export */   \"mdiPhoneHangupOutline\": () => /* binding */ mdiPhoneHangupOutline,\n/* harmony export */   \"mdiPhoneInTalk\": () => /* binding */ mdiPhoneInTalk,\n/* harmony export */   \"mdiPhoneInTalkOutline\": () => /* binding */ mdiPhoneInTalkOutline,\n/* harmony export */   \"mdiPhoneIncoming\": () => /* binding */ mdiPhoneIncoming,\n/* harmony export */   \"mdiPhoneIncomingOutline\": () => /* binding */ mdiPhoneIncomingOutline,\n/* harmony export */   \"mdiPhoneLock\": () => /* binding */ mdiPhoneLock,\n/* harmony export */   \"mdiPhoneLockOutline\": () => /* binding */ mdiPhoneLockOutline,\n/* harmony export */   \"mdiPhoneLog\": () => /* binding */ mdiPhoneLog,\n/* harmony export */   \"mdiPhoneLogOutline\": () => /* binding */ mdiPhoneLogOutline,\n/* harmony export */   \"mdiPhoneMessage\": () => /* binding */ mdiPhoneMessage,\n/* harmony export */   \"mdiPhoneMessageOutline\": () => /* binding */ mdiPhoneMessageOutline,\n/* harmony export */   \"mdiPhoneMinus\": () => /* binding */ mdiPhoneMinus,\n/* harmony export */   \"mdiPhoneMinusOutline\": () => /* binding */ mdiPhoneMinusOutline,\n/* harmony export */   \"mdiPhoneMissed\": () => /* binding */ mdiPhoneMissed,\n/* harmony export */   \"mdiPhoneMissedOutline\": () => /* binding */ mdiPhoneMissedOutline,\n/* harmony export */   \"mdiPhoneOff\": () => /* binding */ mdiPhoneOff,\n/* harmony export */   \"mdiPhoneOffOutline\": () => /* binding */ mdiPhoneOffOutline,\n/* harmony export */   \"mdiPhoneOutgoing\": () => /* binding */ mdiPhoneOutgoing,\n/* harmony export */   \"mdiPhoneOutgoingOutline\": () => /* binding */ mdiPhoneOutgoingOutline,\n/* harmony export */   \"mdiPhoneOutline\": () => /* binding */ mdiPhoneOutline,\n/* harmony export */   \"mdiPhonePaused\": () => /* binding */ mdiPhonePaused,\n/* harmony export */   \"mdiPhonePausedOutline\": () => /* binding */ mdiPhonePausedOutline,\n/* harmony export */   \"mdiPhonePlus\": () => /* binding */ mdiPhonePlus,\n/* harmony export */   \"mdiPhonePlusOutline\": () => /* binding */ mdiPhonePlusOutline,\n/* harmony export */   \"mdiPhoneRemove\": () => /* binding */ mdiPhoneRemove,\n/* harmony export */   \"mdiPhoneRemoveOutline\": () => /* binding */ mdiPhoneRemoveOutline,\n/* harmony export */   \"mdiPhoneReturn\": () => /* binding */ mdiPhoneReturn,\n/* harmony export */   \"mdiPhoneReturnOutline\": () => /* binding */ mdiPhoneReturnOutline,\n/* harmony export */   \"mdiPhoneRing\": () => /* binding */ mdiPhoneRing,\n/* harmony export */   \"mdiPhoneRingOutline\": () => /* binding */ mdiPhoneRingOutline,\n/* harmony export */   \"mdiPhoneRotateLandscape\": () => /* binding */ mdiPhoneRotateLandscape,\n/* harmony export */   \"mdiPhoneRotatePortrait\": () => /* binding */ mdiPhoneRotatePortrait,\n/* harmony export */   \"mdiPhoneSettings\": () => /* binding */ mdiPhoneSettings,\n/* harmony export */   \"mdiPhoneSettingsOutline\": () => /* binding */ mdiPhoneSettingsOutline,\n/* harmony export */   \"mdiPhoneVoip\": () => /* binding */ mdiPhoneVoip,\n/* harmony export */   \"mdiPi\": () => /* binding */ mdiPi,\n/* harmony export */   \"mdiPiBox\": () => /* binding */ mdiPiBox,\n/* harmony export */   \"mdiPiHole\": () => /* binding */ mdiPiHole,\n/* harmony export */   \"mdiPiano\": () => /* binding */ mdiPiano,\n/* harmony export */   \"mdiPickaxe\": () => /* binding */ mdiPickaxe,\n/* harmony export */   \"mdiPictureInPictureBottomRight\": () => /* binding */ mdiPictureInPictureBottomRight,\n/* harmony export */   \"mdiPictureInPictureBottomRightOutline\": () => /* binding */ mdiPictureInPictureBottomRightOutline,\n/* harmony export */   \"mdiPictureInPictureTopRight\": () => /* binding */ mdiPictureInPictureTopRight,\n/* harmony export */   \"mdiPictureInPictureTopRightOutline\": () => /* binding */ mdiPictureInPictureTopRightOutline,\n/* harmony export */   \"mdiPier\": () => /* binding */ mdiPier,\n/* harmony export */   \"mdiPierCrane\": () => /* binding */ mdiPierCrane,\n/* harmony export */   \"mdiPig\": () => /* binding */ mdiPig,\n/* harmony export */   \"mdiPigVariant\": () => /* binding */ mdiPigVariant,\n/* harmony export */   \"mdiPiggyBank\": () => /* binding */ mdiPiggyBank,\n/* harmony export */   \"mdiPill\": () => /* binding */ mdiPill,\n/* harmony export */   \"mdiPillar\": () => /* binding */ mdiPillar,\n/* harmony export */   \"mdiPin\": () => /* binding */ mdiPin,\n/* harmony export */   \"mdiPinOff\": () => /* binding */ mdiPinOff,\n/* harmony export */   \"mdiPinOffOutline\": () => /* binding */ mdiPinOffOutline,\n/* harmony export */   \"mdiPinOutline\": () => /* binding */ mdiPinOutline,\n/* harmony export */   \"mdiPineTree\": () => /* binding */ mdiPineTree,\n/* harmony export */   \"mdiPineTreeBox\": () => /* binding */ mdiPineTreeBox,\n/* harmony export */   \"mdiPineTreeFire\": () => /* binding */ mdiPineTreeFire,\n/* harmony export */   \"mdiPinterest\": () => /* binding */ mdiPinterest,\n/* harmony export */   \"mdiPinwheel\": () => /* binding */ mdiPinwheel,\n/* harmony export */   \"mdiPinwheelOutline\": () => /* binding */ mdiPinwheelOutline,\n/* harmony export */   \"mdiPipe\": () => /* binding */ mdiPipe,\n/* harmony export */   \"mdiPipeDisconnected\": () => /* binding */ mdiPipeDisconnected,\n/* harmony export */   \"mdiPipeLeak\": () => /* binding */ mdiPipeLeak,\n/* harmony export */   \"mdiPipeWrench\": () => /* binding */ mdiPipeWrench,\n/* harmony export */   \"mdiPirate\": () => /* binding */ mdiPirate,\n/* harmony export */   \"mdiPistol\": () => /* binding */ mdiPistol,\n/* harmony export */   \"mdiPiston\": () => /* binding */ mdiPiston,\n/* harmony export */   \"mdiPitchfork\": () => /* binding */ mdiPitchfork,\n/* harmony export */   \"mdiPizza\": () => /* binding */ mdiPizza,\n/* harmony export */   \"mdiPlay\": () => /* binding */ mdiPlay,\n/* harmony export */   \"mdiPlayBox\": () => /* binding */ mdiPlayBox,\n/* harmony export */   \"mdiPlayBoxMultiple\": () => /* binding */ mdiPlayBoxMultiple,\n/* harmony export */   \"mdiPlayBoxMultipleOutline\": () => /* binding */ mdiPlayBoxMultipleOutline,\n/* harmony export */   \"mdiPlayBoxOutline\": () => /* binding */ mdiPlayBoxOutline,\n/* harmony export */   \"mdiPlayCircle\": () => /* binding */ mdiPlayCircle,\n/* harmony export */   \"mdiPlayCircleOutline\": () => /* binding */ mdiPlayCircleOutline,\n/* harmony export */   \"mdiPlayNetwork\": () => /* binding */ mdiPlayNetwork,\n/* harmony export */   \"mdiPlayNetworkOutline\": () => /* binding */ mdiPlayNetworkOutline,\n/* harmony export */   \"mdiPlayOutline\": () => /* binding */ mdiPlayOutline,\n/* harmony export */   \"mdiPlayPause\": () => /* binding */ mdiPlayPause,\n/* harmony export */   \"mdiPlayProtectedContent\": () => /* binding */ mdiPlayProtectedContent,\n/* harmony export */   \"mdiPlaySpeed\": () => /* binding */ mdiPlaySpeed,\n/* harmony export */   \"mdiPlaylistCheck\": () => /* binding */ mdiPlaylistCheck,\n/* harmony export */   \"mdiPlaylistEdit\": () => /* binding */ mdiPlaylistEdit,\n/* harmony export */   \"mdiPlaylistMinus\": () => /* binding */ mdiPlaylistMinus,\n/* harmony export */   \"mdiPlaylistMusic\": () => /* binding */ mdiPlaylistMusic,\n/* harmony export */   \"mdiPlaylistMusicOutline\": () => /* binding */ mdiPlaylistMusicOutline,\n/* harmony export */   \"mdiPlaylistPlay\": () => /* binding */ mdiPlaylistPlay,\n/* harmony export */   \"mdiPlaylistPlus\": () => /* binding */ mdiPlaylistPlus,\n/* harmony export */   \"mdiPlaylistRemove\": () => /* binding */ mdiPlaylistRemove,\n/* harmony export */   \"mdiPlaylistStar\": () => /* binding */ mdiPlaylistStar,\n/* harmony export */   \"mdiPlex\": () => /* binding */ mdiPlex,\n/* harmony export */   \"mdiPlus\": () => /* binding */ mdiPlus,\n/* harmony export */   \"mdiPlusBox\": () => /* binding */ mdiPlusBox,\n/* harmony export */   \"mdiPlusBoxMultiple\": () => /* binding */ mdiPlusBoxMultiple,\n/* harmony export */   \"mdiPlusBoxMultipleOutline\": () => /* binding */ mdiPlusBoxMultipleOutline,\n/* harmony export */   \"mdiPlusBoxOutline\": () => /* binding */ mdiPlusBoxOutline,\n/* harmony export */   \"mdiPlusCircle\": () => /* binding */ mdiPlusCircle,\n/* harmony export */   \"mdiPlusCircleMultiple\": () => /* binding */ mdiPlusCircleMultiple,\n/* harmony export */   \"mdiPlusCircleMultipleOutline\": () => /* binding */ mdiPlusCircleMultipleOutline,\n/* harmony export */   \"mdiPlusCircleOutline\": () => /* binding */ mdiPlusCircleOutline,\n/* harmony export */   \"mdiPlusMinus\": () => /* binding */ mdiPlusMinus,\n/* harmony export */   \"mdiPlusMinusBox\": () => /* binding */ mdiPlusMinusBox,\n/* harmony export */   \"mdiPlusMinusVariant\": () => /* binding */ mdiPlusMinusVariant,\n/* harmony export */   \"mdiPlusNetwork\": () => /* binding */ mdiPlusNetwork,\n/* harmony export */   \"mdiPlusNetworkOutline\": () => /* binding */ mdiPlusNetworkOutline,\n/* harmony export */   \"mdiPlusOne\": () => /* binding */ mdiPlusOne,\n/* harmony export */   \"mdiPlusOutline\": () => /* binding */ mdiPlusOutline,\n/* harmony export */   \"mdiPlusThick\": () => /* binding */ mdiPlusThick,\n/* harmony export */   \"mdiPodcast\": () => /* binding */ mdiPodcast,\n/* harmony export */   \"mdiPodium\": () => /* binding */ mdiPodium,\n/* harmony export */   \"mdiPodiumBronze\": () => /* binding */ mdiPodiumBronze,\n/* harmony export */   \"mdiPodiumGold\": () => /* binding */ mdiPodiumGold,\n/* harmony export */   \"mdiPodiumSilver\": () => /* binding */ mdiPodiumSilver,\n/* harmony export */   \"mdiPointOfSale\": () => /* binding */ mdiPointOfSale,\n/* harmony export */   \"mdiPokeball\": () => /* binding */ mdiPokeball,\n/* harmony export */   \"mdiPokemonGo\": () => /* binding */ mdiPokemonGo,\n/* harmony export */   \"mdiPokerChip\": () => /* binding */ mdiPokerChip,\n/* harmony export */   \"mdiPolaroid\": () => /* binding */ mdiPolaroid,\n/* harmony export */   \"mdiPoliceBadge\": () => /* binding */ mdiPoliceBadge,\n/* harmony export */   \"mdiPoliceBadgeOutline\": () => /* binding */ mdiPoliceBadgeOutline,\n/* harmony export */   \"mdiPoll\": () => /* binding */ mdiPoll,\n/* harmony export */   \"mdiPollBox\": () => /* binding */ mdiPollBox,\n/* harmony export */   \"mdiPollBoxOutline\": () => /* binding */ mdiPollBoxOutline,\n/* harmony export */   \"mdiPolo\": () => /* binding */ mdiPolo,\n/* harmony export */   \"mdiPolymer\": () => /* binding */ mdiPolymer,\n/* harmony export */   \"mdiPool\": () => /* binding */ mdiPool,\n/* harmony export */   \"mdiPopcorn\": () => /* binding */ mdiPopcorn,\n/* harmony export */   \"mdiPost\": () => /* binding */ mdiPost,\n/* harmony export */   \"mdiPostOutline\": () => /* binding */ mdiPostOutline,\n/* harmony export */   \"mdiPostageStamp\": () => /* binding */ mdiPostageStamp,\n/* harmony export */   \"mdiPot\": () => /* binding */ mdiPot,\n/* harmony export */   \"mdiPotMix\": () => /* binding */ mdiPotMix,\n/* harmony export */   \"mdiPotMixOutline\": () => /* binding */ mdiPotMixOutline,\n/* harmony export */   \"mdiPotOutline\": () => /* binding */ mdiPotOutline,\n/* harmony export */   \"mdiPotSteam\": () => /* binding */ mdiPotSteam,\n/* harmony export */   \"mdiPotSteamOutline\": () => /* binding */ mdiPotSteamOutline,\n/* harmony export */   \"mdiPound\": () => /* binding */ mdiPound,\n/* harmony export */   \"mdiPoundBox\": () => /* binding */ mdiPoundBox,\n/* harmony export */   \"mdiPoundBoxOutline\": () => /* binding */ mdiPoundBoxOutline,\n/* harmony export */   \"mdiPower\": () => /* binding */ mdiPower,\n/* harmony export */   \"mdiPowerCycle\": () => /* binding */ mdiPowerCycle,\n/* harmony export */   \"mdiPowerOff\": () => /* binding */ mdiPowerOff,\n/* harmony export */   \"mdiPowerOn\": () => /* binding */ mdiPowerOn,\n/* harmony export */   \"mdiPowerPlug\": () => /* binding */ mdiPowerPlug,\n/* harmony export */   \"mdiPowerPlugOff\": () => /* binding */ mdiPowerPlugOff,\n/* harmony export */   \"mdiPowerPlugOffOutline\": () => /* binding */ mdiPowerPlugOffOutline,\n/* harmony export */   \"mdiPowerPlugOutline\": () => /* binding */ mdiPowerPlugOutline,\n/* harmony export */   \"mdiPowerSettings\": () => /* binding */ mdiPowerSettings,\n/* harmony export */   \"mdiPowerSleep\": () => /* binding */ mdiPowerSleep,\n/* harmony export */   \"mdiPowerSocket\": () => /* binding */ mdiPowerSocket,\n/* harmony export */   \"mdiPowerSocketAu\": () => /* binding */ mdiPowerSocketAu,\n/* harmony export */   \"mdiPowerSocketDe\": () => /* binding */ mdiPowerSocketDe,\n/* harmony export */   \"mdiPowerSocketEu\": () => /* binding */ mdiPowerSocketEu,\n/* harmony export */   \"mdiPowerSocketFr\": () => /* binding */ mdiPowerSocketFr,\n/* harmony export */   \"mdiPowerSocketIt\": () => /* binding */ mdiPowerSocketIt,\n/* harmony export */   \"mdiPowerSocketJp\": () => /* binding */ mdiPowerSocketJp,\n/* harmony export */   \"mdiPowerSocketUk\": () => /* binding */ mdiPowerSocketUk,\n/* harmony export */   \"mdiPowerSocketUs\": () => /* binding */ mdiPowerSocketUs,\n/* harmony export */   \"mdiPowerStandby\": () => /* binding */ mdiPowerStandby,\n/* harmony export */   \"mdiPowershell\": () => /* binding */ mdiPowershell,\n/* harmony export */   \"mdiPrescription\": () => /* binding */ mdiPrescription,\n/* harmony export */   \"mdiPresentation\": () => /* binding */ mdiPresentation,\n/* harmony export */   \"mdiPresentationPlay\": () => /* binding */ mdiPresentationPlay,\n/* harmony export */   \"mdiPretzel\": () => /* binding */ mdiPretzel,\n/* harmony export */   \"mdiPrinter\": () => /* binding */ mdiPrinter,\n/* harmony export */   \"mdiPrinter3d\": () => /* binding */ mdiPrinter3d,\n/* harmony export */   \"mdiPrinter3dNozzle\": () => /* binding */ mdiPrinter3dNozzle,\n/* harmony export */   \"mdiPrinter3dNozzleAlert\": () => /* binding */ mdiPrinter3dNozzleAlert,\n/* harmony export */   \"mdiPrinter3dNozzleAlertOutline\": () => /* binding */ mdiPrinter3dNozzleAlertOutline,\n/* harmony export */   \"mdiPrinter3dNozzleOutline\": () => /* binding */ mdiPrinter3dNozzleOutline,\n/* harmony export */   \"mdiPrinterAlert\": () => /* binding */ mdiPrinterAlert,\n/* harmony export */   \"mdiPrinterCheck\": () => /* binding */ mdiPrinterCheck,\n/* harmony export */   \"mdiPrinterEye\": () => /* binding */ mdiPrinterEye,\n/* harmony export */   \"mdiPrinterOff\": () => /* binding */ mdiPrinterOff,\n/* harmony export */   \"mdiPrinterPos\": () => /* binding */ mdiPrinterPos,\n/* harmony export */   \"mdiPrinterSearch\": () => /* binding */ mdiPrinterSearch,\n/* harmony export */   \"mdiPrinterSettings\": () => /* binding */ mdiPrinterSettings,\n/* harmony export */   \"mdiPrinterWireless\": () => /* binding */ mdiPrinterWireless,\n/* harmony export */   \"mdiPriorityHigh\": () => /* binding */ mdiPriorityHigh,\n/* harmony export */   \"mdiPriorityLow\": () => /* binding */ mdiPriorityLow,\n/* harmony export */   \"mdiProfessionalHexagon\": () => /* binding */ mdiProfessionalHexagon,\n/* harmony export */   \"mdiProgressAlert\": () => /* binding */ mdiProgressAlert,\n/* harmony export */   \"mdiProgressCheck\": () => /* binding */ mdiProgressCheck,\n/* harmony export */   \"mdiProgressClock\": () => /* binding */ mdiProgressClock,\n/* harmony export */   \"mdiProgressClose\": () => /* binding */ mdiProgressClose,\n/* harmony export */   \"mdiProgressDownload\": () => /* binding */ mdiProgressDownload,\n/* harmony export */   \"mdiProgressQuestion\": () => /* binding */ mdiProgressQuestion,\n/* harmony export */   \"mdiProgressUpload\": () => /* binding */ mdiProgressUpload,\n/* harmony export */   \"mdiProgressWrench\": () => /* binding */ mdiProgressWrench,\n/* harmony export */   \"mdiProjector\": () => /* binding */ mdiProjector,\n/* harmony export */   \"mdiProjectorScreen\": () => /* binding */ mdiProjectorScreen,\n/* harmony export */   \"mdiPropaneTank\": () => /* binding */ mdiPropaneTank,\n/* harmony export */   \"mdiPropaneTankOutline\": () => /* binding */ mdiPropaneTankOutline,\n/* harmony export */   \"mdiProtocol\": () => /* binding */ mdiProtocol,\n/* harmony export */   \"mdiPublish\": () => /* binding */ mdiPublish,\n/* harmony export */   \"mdiPulse\": () => /* binding */ mdiPulse,\n/* harmony export */   \"mdiPump\": () => /* binding */ mdiPump,\n/* harmony export */   \"mdiPumpkin\": () => /* binding */ mdiPumpkin,\n/* harmony export */   \"mdiPurse\": () => /* binding */ mdiPurse,\n/* harmony export */   \"mdiPurseOutline\": () => /* binding */ mdiPurseOutline,\n/* harmony export */   \"mdiPuzzle\": () => /* binding */ mdiPuzzle,\n/* harmony export */   \"mdiPuzzleCheck\": () => /* binding */ mdiPuzzleCheck,\n/* harmony export */   \"mdiPuzzleCheckOutline\": () => /* binding */ mdiPuzzleCheckOutline,\n/* harmony export */   \"mdiPuzzleEdit\": () => /* binding */ mdiPuzzleEdit,\n/* harmony export */   \"mdiPuzzleEditOutline\": () => /* binding */ mdiPuzzleEditOutline,\n/* harmony export */   \"mdiPuzzleHeart\": () => /* binding */ mdiPuzzleHeart,\n/* harmony export */   \"mdiPuzzleHeartOutline\": () => /* binding */ mdiPuzzleHeartOutline,\n/* harmony export */   \"mdiPuzzleMinus\": () => /* binding */ mdiPuzzleMinus,\n/* harmony export */   \"mdiPuzzleMinusOutline\": () => /* binding */ mdiPuzzleMinusOutline,\n/* harmony export */   \"mdiPuzzleOutline\": () => /* binding */ mdiPuzzleOutline,\n/* harmony export */   \"mdiPuzzlePlus\": () => /* binding */ mdiPuzzlePlus,\n/* harmony export */   \"mdiPuzzlePlusOutline\": () => /* binding */ mdiPuzzlePlusOutline,\n/* harmony export */   \"mdiPuzzleRemove\": () => /* binding */ mdiPuzzleRemove,\n/* harmony export */   \"mdiPuzzleRemoveOutline\": () => /* binding */ mdiPuzzleRemoveOutline,\n/* harmony export */   \"mdiPuzzleStar\": () => /* binding */ mdiPuzzleStar,\n/* harmony export */   \"mdiPuzzleStarOutline\": () => /* binding */ mdiPuzzleStarOutline,\n/* harmony export */   \"mdiQi\": () => /* binding */ mdiQi,\n/* harmony export */   \"mdiQqchat\": () => /* binding */ mdiQqchat,\n/* harmony export */   \"mdiQrcode\": () => /* binding */ mdiQrcode,\n/* harmony export */   \"mdiQrcodeEdit\": () => /* binding */ mdiQrcodeEdit,\n/* harmony export */   \"mdiQrcodeMinus\": () => /* binding */ mdiQrcodeMinus,\n/* harmony export */   \"mdiQrcodePlus\": () => /* binding */ mdiQrcodePlus,\n/* harmony export */   \"mdiQrcodeRemove\": () => /* binding */ mdiQrcodeRemove,\n/* harmony export */   \"mdiQrcodeScan\": () => /* binding */ mdiQrcodeScan,\n/* harmony export */   \"mdiQuadcopter\": () => /* binding */ mdiQuadcopter,\n/* harmony export */   \"mdiQualityHigh\": () => /* binding */ mdiQualityHigh,\n/* harmony export */   \"mdiQualityLow\": () => /* binding */ mdiQualityLow,\n/* harmony export */   \"mdiQualityMedium\": () => /* binding */ mdiQualityMedium,\n/* harmony export */   \"mdiQuora\": () => /* binding */ mdiQuora,\n/* harmony export */   \"mdiRabbit\": () => /* binding */ mdiRabbit,\n/* harmony export */   \"mdiRacingHelmet\": () => /* binding */ mdiRacingHelmet,\n/* harmony export */   \"mdiRacquetball\": () => /* binding */ mdiRacquetball,\n/* harmony export */   \"mdiRadar\": () => /* binding */ mdiRadar,\n/* harmony export */   \"mdiRadiator\": () => /* binding */ mdiRadiator,\n/* harmony export */   \"mdiRadiatorDisabled\": () => /* binding */ mdiRadiatorDisabled,\n/* harmony export */   \"mdiRadiatorOff\": () => /* binding */ mdiRadiatorOff,\n/* harmony export */   \"mdiRadio\": () => /* binding */ mdiRadio,\n/* harmony export */   \"mdiRadioAm\": () => /* binding */ mdiRadioAm,\n/* harmony export */   \"mdiRadioFm\": () => /* binding */ mdiRadioFm,\n/* harmony export */   \"mdiRadioHandheld\": () => /* binding */ mdiRadioHandheld,\n/* harmony export */   \"mdiRadioOff\": () => /* binding */ mdiRadioOff,\n/* harmony export */   \"mdiRadioTower\": () => /* binding */ mdiRadioTower,\n/* harmony export */   \"mdiRadioactive\": () => /* binding */ mdiRadioactive,\n/* harmony export */   \"mdiRadioactiveOff\": () => /* binding */ mdiRadioactiveOff,\n/* harmony export */   \"mdiRadioboxBlank\": () => /* binding */ mdiRadioboxBlank,\n/* harmony export */   \"mdiRadioboxMarked\": () => /* binding */ mdiRadioboxMarked,\n/* harmony export */   \"mdiRadiologyBox\": () => /* binding */ mdiRadiologyBox,\n/* harmony export */   \"mdiRadiologyBoxOutline\": () => /* binding */ mdiRadiologyBoxOutline,\n/* harmony export */   \"mdiRadius\": () => /* binding */ mdiRadius,\n/* harmony export */   \"mdiRadiusOutline\": () => /* binding */ mdiRadiusOutline,\n/* harmony export */   \"mdiRailroadLight\": () => /* binding */ mdiRailroadLight,\n/* harmony export */   \"mdiRake\": () => /* binding */ mdiRake,\n/* harmony export */   \"mdiRaspberryPi\": () => /* binding */ mdiRaspberryPi,\n/* harmony export */   \"mdiRayEnd\": () => /* binding */ mdiRayEnd,\n/* harmony export */   \"mdiRayEndArrow\": () => /* binding */ mdiRayEndArrow,\n/* harmony export */   \"mdiRayStart\": () => /* binding */ mdiRayStart,\n/* harmony export */   \"mdiRayStartArrow\": () => /* binding */ mdiRayStartArrow,\n/* harmony export */   \"mdiRayStartEnd\": () => /* binding */ mdiRayStartEnd,\n/* harmony export */   \"mdiRayStartVertexEnd\": () => /* binding */ mdiRayStartVertexEnd,\n/* harmony export */   \"mdiRayVertex\": () => /* binding */ mdiRayVertex,\n/* harmony export */   \"mdiReact\": () => /* binding */ mdiReact,\n/* harmony export */   \"mdiRead\": () => /* binding */ mdiRead,\n/* harmony export */   \"mdiReceipt\": () => /* binding */ mdiReceipt,\n/* harmony export */   \"mdiRecord\": () => /* binding */ mdiRecord,\n/* harmony export */   \"mdiRecordCircle\": () => /* binding */ mdiRecordCircle,\n/* harmony export */   \"mdiRecordCircleOutline\": () => /* binding */ mdiRecordCircleOutline,\n/* harmony export */   \"mdiRecordPlayer\": () => /* binding */ mdiRecordPlayer,\n/* harmony export */   \"mdiRecordRec\": () => /* binding */ mdiRecordRec,\n/* harmony export */   \"mdiRectangle\": () => /* binding */ mdiRectangle,\n/* harmony export */   \"mdiRectangleOutline\": () => /* binding */ mdiRectangleOutline,\n/* harmony export */   \"mdiRecycle\": () => /* binding */ mdiRecycle,\n/* harmony export */   \"mdiRecycleVariant\": () => /* binding */ mdiRecycleVariant,\n/* harmony export */   \"mdiReddit\": () => /* binding */ mdiReddit,\n/* harmony export */   \"mdiRedhat\": () => /* binding */ mdiRedhat,\n/* harmony export */   \"mdiRedo\": () => /* binding */ mdiRedo,\n/* harmony export */   \"mdiRedoVariant\": () => /* binding */ mdiRedoVariant,\n/* harmony export */   \"mdiReflectHorizontal\": () => /* binding */ mdiReflectHorizontal,\n/* harmony export */   \"mdiReflectVertical\": () => /* binding */ mdiReflectVertical,\n/* harmony export */   \"mdiRefresh\": () => /* binding */ mdiRefresh,\n/* harmony export */   \"mdiRefreshCircle\": () => /* binding */ mdiRefreshCircle,\n/* harmony export */   \"mdiRegex\": () => /* binding */ mdiRegex,\n/* harmony export */   \"mdiRegisteredTrademark\": () => /* binding */ mdiRegisteredTrademark,\n/* harmony export */   \"mdiReiterate\": () => /* binding */ mdiReiterate,\n/* harmony export */   \"mdiRelationManyToMany\": () => /* binding */ mdiRelationManyToMany,\n/* harmony export */   \"mdiRelationManyToOne\": () => /* binding */ mdiRelationManyToOne,\n/* harmony export */   \"mdiRelationManyToOneOrMany\": () => /* binding */ mdiRelationManyToOneOrMany,\n/* harmony export */   \"mdiRelationManyToOnlyOne\": () => /* binding */ mdiRelationManyToOnlyOne,\n/* harmony export */   \"mdiRelationManyToZeroOrMany\": () => /* binding */ mdiRelationManyToZeroOrMany,\n/* harmony export */   \"mdiRelationManyToZeroOrOne\": () => /* binding */ mdiRelationManyToZeroOrOne,\n/* harmony export */   \"mdiRelationOneOrManyToMany\": () => /* binding */ mdiRelationOneOrManyToMany,\n/* harmony export */   \"mdiRelationOneOrManyToOne\": () => /* binding */ mdiRelationOneOrManyToOne,\n/* harmony export */   \"mdiRelationOneOrManyToOneOrMany\": () => /* binding */ mdiRelationOneOrManyToOneOrMany,\n/* harmony export */   \"mdiRelationOneOrManyToOnlyOne\": () => /* binding */ mdiRelationOneOrManyToOnlyOne,\n/* harmony export */   \"mdiRelationOneOrManyToZeroOrMany\": () => /* binding */ mdiRelationOneOrManyToZeroOrMany,\n/* harmony export */   \"mdiRelationOneOrManyToZeroOrOne\": () => /* binding */ mdiRelationOneOrManyToZeroOrOne,\n/* harmony export */   \"mdiRelationOneToMany\": () => /* binding */ mdiRelationOneToMany,\n/* harmony export */   \"mdiRelationOneToOne\": () => /* binding */ mdiRelationOneToOne,\n/* harmony export */   \"mdiRelationOneToOneOrMany\": () => /* binding */ mdiRelationOneToOneOrMany,\n/* harmony export */   \"mdiRelationOneToOnlyOne\": () => /* binding */ mdiRelationOneToOnlyOne,\n/* harmony export */   \"mdiRelationOneToZeroOrMany\": () => /* binding */ mdiRelationOneToZeroOrMany,\n/* harmony export */   \"mdiRelationOneToZeroOrOne\": () => /* binding */ mdiRelationOneToZeroOrOne,\n/* harmony export */   \"mdiRelationOnlyOneToMany\": () => /* binding */ mdiRelationOnlyOneToMany,\n/* harmony export */   \"mdiRelationOnlyOneToOne\": () => /* binding */ mdiRelationOnlyOneToOne,\n/* harmony export */   \"mdiRelationOnlyOneToOneOrMany\": () => /* binding */ mdiRelationOnlyOneToOneOrMany,\n/* harmony export */   \"mdiRelationOnlyOneToOnlyOne\": () => /* binding */ mdiRelationOnlyOneToOnlyOne,\n/* harmony export */   \"mdiRelationOnlyOneToZeroOrMany\": () => /* binding */ mdiRelationOnlyOneToZeroOrMany,\n/* harmony export */   \"mdiRelationOnlyOneToZeroOrOne\": () => /* binding */ mdiRelationOnlyOneToZeroOrOne,\n/* harmony export */   \"mdiRelationZeroOrManyToMany\": () => /* binding */ mdiRelationZeroOrManyToMany,\n/* harmony export */   \"mdiRelationZeroOrManyToOne\": () => /* binding */ mdiRelationZeroOrManyToOne,\n/* harmony export */   \"mdiRelationZeroOrManyToOneOrMany\": () => /* binding */ mdiRelationZeroOrManyToOneOrMany,\n/* harmony export */   \"mdiRelationZeroOrManyToOnlyOne\": () => /* binding */ mdiRelationZeroOrManyToOnlyOne,\n/* harmony export */   \"mdiRelationZeroOrManyToZeroOrMany\": () => /* binding */ mdiRelationZeroOrManyToZeroOrMany,\n/* harmony export */   \"mdiRelationZeroOrManyToZeroOrOne\": () => /* binding */ mdiRelationZeroOrManyToZeroOrOne,\n/* harmony export */   \"mdiRelationZeroOrOneToMany\": () => /* binding */ mdiRelationZeroOrOneToMany,\n/* harmony export */   \"mdiRelationZeroOrOneToOne\": () => /* binding */ mdiRelationZeroOrOneToOne,\n/* harmony export */   \"mdiRelationZeroOrOneToOneOrMany\": () => /* binding */ mdiRelationZeroOrOneToOneOrMany,\n/* harmony export */   \"mdiRelationZeroOrOneToOnlyOne\": () => /* binding */ mdiRelationZeroOrOneToOnlyOne,\n/* harmony export */   \"mdiRelationZeroOrOneToZeroOrMany\": () => /* binding */ mdiRelationZeroOrOneToZeroOrMany,\n/* harmony export */   \"mdiRelationZeroOrOneToZeroOrOne\": () => /* binding */ mdiRelationZeroOrOneToZeroOrOne,\n/* harmony export */   \"mdiRelativeScale\": () => /* binding */ mdiRelativeScale,\n/* harmony export */   \"mdiReload\": () => /* binding */ mdiReload,\n/* harmony export */   \"mdiReloadAlert\": () => /* binding */ mdiReloadAlert,\n/* harmony export */   \"mdiReminder\": () => /* binding */ mdiReminder,\n/* harmony export */   \"mdiRemote\": () => /* binding */ mdiRemote,\n/* harmony export */   \"mdiRemoteDesktop\": () => /* binding */ mdiRemoteDesktop,\n/* harmony export */   \"mdiRemoteOff\": () => /* binding */ mdiRemoteOff,\n/* harmony export */   \"mdiRemoteTv\": () => /* binding */ mdiRemoteTv,\n/* harmony export */   \"mdiRemoteTvOff\": () => /* binding */ mdiRemoteTvOff,\n/* harmony export */   \"mdiRenameBox\": () => /* binding */ mdiRenameBox,\n/* harmony export */   \"mdiReorderHorizontal\": () => /* binding */ mdiReorderHorizontal,\n/* harmony export */   \"mdiReorderVertical\": () => /* binding */ mdiReorderVertical,\n/* harmony export */   \"mdiRepeat\": () => /* binding */ mdiRepeat,\n/* harmony export */   \"mdiRepeatOff\": () => /* binding */ mdiRepeatOff,\n/* harmony export */   \"mdiRepeatOnce\": () => /* binding */ mdiRepeatOnce,\n/* harmony export */   \"mdiReplay\": () => /* binding */ mdiReplay,\n/* harmony export */   \"mdiReply\": () => /* binding */ mdiReply,\n/* harmony export */   \"mdiReplyAll\": () => /* binding */ mdiReplyAll,\n/* harmony export */   \"mdiReplyAllOutline\": () => /* binding */ mdiReplyAllOutline,\n/* harmony export */   \"mdiReplyCircle\": () => /* binding */ mdiReplyCircle,\n/* harmony export */   \"mdiReplyOutline\": () => /* binding */ mdiReplyOutline,\n/* harmony export */   \"mdiReproduction\": () => /* binding */ mdiReproduction,\n/* harmony export */   \"mdiResistor\": () => /* binding */ mdiResistor,\n/* harmony export */   \"mdiResistorNodes\": () => /* binding */ mdiResistorNodes,\n/* harmony export */   \"mdiResize\": () => /* binding */ mdiResize,\n/* harmony export */   \"mdiResizeBottomRight\": () => /* binding */ mdiResizeBottomRight,\n/* harmony export */   \"mdiResponsive\": () => /* binding */ mdiResponsive,\n/* harmony export */   \"mdiRestart\": () => /* binding */ mdiRestart,\n/* harmony export */   \"mdiRestartAlert\": () => /* binding */ mdiRestartAlert,\n/* harmony export */   \"mdiRestartOff\": () => /* binding */ mdiRestartOff,\n/* harmony export */   \"mdiRestore\": () => /* binding */ mdiRestore,\n/* harmony export */   \"mdiRestoreAlert\": () => /* binding */ mdiRestoreAlert,\n/* harmony export */   \"mdiRewind\": () => /* binding */ mdiRewind,\n/* harmony export */   \"mdiRewind10\": () => /* binding */ mdiRewind10,\n/* harmony export */   \"mdiRewind30\": () => /* binding */ mdiRewind30,\n/* harmony export */   \"mdiRewind5\": () => /* binding */ mdiRewind5,\n/* harmony export */   \"mdiRewind60\": () => /* binding */ mdiRewind60,\n/* harmony export */   \"mdiRewindOutline\": () => /* binding */ mdiRewindOutline,\n/* harmony export */   \"mdiRhombus\": () => /* binding */ mdiRhombus,\n/* harmony export */   \"mdiRhombusMedium\": () => /* binding */ mdiRhombusMedium,\n/* harmony export */   \"mdiRhombusMediumOutline\": () => /* binding */ mdiRhombusMediumOutline,\n/* harmony export */   \"mdiRhombusOutline\": () => /* binding */ mdiRhombusOutline,\n/* harmony export */   \"mdiRhombusSplit\": () => /* binding */ mdiRhombusSplit,\n/* harmony export */   \"mdiRhombusSplitOutline\": () => /* binding */ mdiRhombusSplitOutline,\n/* harmony export */   \"mdiRibbon\": () => /* binding */ mdiRibbon,\n/* harmony export */   \"mdiRice\": () => /* binding */ mdiRice,\n/* harmony export */   \"mdiRickshaw\": () => /* binding */ mdiRickshaw,\n/* harmony export */   \"mdiRickshawElectric\": () => /* binding */ mdiRickshawElectric,\n/* harmony export */   \"mdiRing\": () => /* binding */ mdiRing,\n/* harmony export */   \"mdiRivet\": () => /* binding */ mdiRivet,\n/* harmony export */   \"mdiRoad\": () => /* binding */ mdiRoad,\n/* harmony export */   \"mdiRoadVariant\": () => /* binding */ mdiRoadVariant,\n/* harmony export */   \"mdiRobber\": () => /* binding */ mdiRobber,\n/* harmony export */   \"mdiRobot\": () => /* binding */ mdiRobot,\n/* harmony export */   \"mdiRobotIndustrial\": () => /* binding */ mdiRobotIndustrial,\n/* harmony export */   \"mdiRobotMower\": () => /* binding */ mdiRobotMower,\n/* harmony export */   \"mdiRobotMowerOutline\": () => /* binding */ mdiRobotMowerOutline,\n/* harmony export */   \"mdiRobotVacuum\": () => /* binding */ mdiRobotVacuum,\n/* harmony export */   \"mdiRobotVacuumVariant\": () => /* binding */ mdiRobotVacuumVariant,\n/* harmony export */   \"mdiRocket\": () => /* binding */ mdiRocket,\n/* harmony export */   \"mdiRocketLaunch\": () => /* binding */ mdiRocketLaunch,\n/* harmony export */   \"mdiRocketLaunchOutline\": () => /* binding */ mdiRocketLaunchOutline,\n/* harmony export */   \"mdiRocketOutline\": () => /* binding */ mdiRocketOutline,\n/* harmony export */   \"mdiRodent\": () => /* binding */ mdiRodent,\n/* harmony export */   \"mdiRollerSkate\": () => /* binding */ mdiRollerSkate,\n/* harmony export */   \"mdiRollerSkateOff\": () => /* binding */ mdiRollerSkateOff,\n/* harmony export */   \"mdiRollerblade\": () => /* binding */ mdiRollerblade,\n/* harmony export */   \"mdiRollerbladeOff\": () => /* binding */ mdiRollerbladeOff,\n/* harmony export */   \"mdiRollupjs\": () => /* binding */ mdiRollupjs,\n/* harmony export */   \"mdiRomanNumeral1\": () => /* binding */ mdiRomanNumeral1,\n/* harmony export */   \"mdiRomanNumeral10\": () => /* binding */ mdiRomanNumeral10,\n/* harmony export */   \"mdiRomanNumeral2\": () => /* binding */ mdiRomanNumeral2,\n/* harmony export */   \"mdiRomanNumeral3\": () => /* binding */ mdiRomanNumeral3,\n/* harmony export */   \"mdiRomanNumeral4\": () => /* binding */ mdiRomanNumeral4,\n/* harmony export */   \"mdiRomanNumeral5\": () => /* binding */ mdiRomanNumeral5,\n/* harmony export */   \"mdiRomanNumeral6\": () => /* binding */ mdiRomanNumeral6,\n/* harmony export */   \"mdiRomanNumeral7\": () => /* binding */ mdiRomanNumeral7,\n/* harmony export */   \"mdiRomanNumeral8\": () => /* binding */ mdiRomanNumeral8,\n/* harmony export */   \"mdiRomanNumeral9\": () => /* binding */ mdiRomanNumeral9,\n/* harmony export */   \"mdiRoomService\": () => /* binding */ mdiRoomService,\n/* harmony export */   \"mdiRoomServiceOutline\": () => /* binding */ mdiRoomServiceOutline,\n/* harmony export */   \"mdiRotate3d\": () => /* binding */ mdiRotate3d,\n/* harmony export */   \"mdiRotate3dVariant\": () => /* binding */ mdiRotate3dVariant,\n/* harmony export */   \"mdiRotateLeft\": () => /* binding */ mdiRotateLeft,\n/* harmony export */   \"mdiRotateLeftVariant\": () => /* binding */ mdiRotateLeftVariant,\n/* harmony export */   \"mdiRotateOrbit\": () => /* binding */ mdiRotateOrbit,\n/* harmony export */   \"mdiRotateRight\": () => /* binding */ mdiRotateRight,\n/* harmony export */   \"mdiRotateRightVariant\": () => /* binding */ mdiRotateRightVariant,\n/* harmony export */   \"mdiRoundedCorner\": () => /* binding */ mdiRoundedCorner,\n/* harmony export */   \"mdiRouter\": () => /* binding */ mdiRouter,\n/* harmony export */   \"mdiRouterNetwork\": () => /* binding */ mdiRouterNetwork,\n/* harmony export */   \"mdiRouterWireless\": () => /* binding */ mdiRouterWireless,\n/* harmony export */   \"mdiRouterWirelessOff\": () => /* binding */ mdiRouterWirelessOff,\n/* harmony export */   \"mdiRouterWirelessSettings\": () => /* binding */ mdiRouterWirelessSettings,\n/* harmony export */   \"mdiRoutes\": () => /* binding */ mdiRoutes,\n/* harmony export */   \"mdiRoutesClock\": () => /* binding */ mdiRoutesClock,\n/* harmony export */   \"mdiRowing\": () => /* binding */ mdiRowing,\n/* harmony export */   \"mdiRss\": () => /* binding */ mdiRss,\n/* harmony export */   \"mdiRssBox\": () => /* binding */ mdiRssBox,\n/* harmony export */   \"mdiRssOff\": () => /* binding */ mdiRssOff,\n/* harmony export */   \"mdiRug\": () => /* binding */ mdiRug,\n/* harmony export */   \"mdiRugby\": () => /* binding */ mdiRugby,\n/* harmony export */   \"mdiRuler\": () => /* binding */ mdiRuler,\n/* harmony export */   \"mdiRulerSquare\": () => /* binding */ mdiRulerSquare,\n/* harmony export */   \"mdiRulerSquareCompass\": () => /* binding */ mdiRulerSquareCompass,\n/* harmony export */   \"mdiRun\": () => /* binding */ mdiRun,\n/* harmony export */   \"mdiRunFast\": () => /* binding */ mdiRunFast,\n/* harmony export */   \"mdiRvTruck\": () => /* binding */ mdiRvTruck,\n/* harmony export */   \"mdiSack\": () => /* binding */ mdiSack,\n/* harmony export */   \"mdiSackPercent\": () => /* binding */ mdiSackPercent,\n/* harmony export */   \"mdiSafe\": () => /* binding */ mdiSafe,\n/* harmony export */   \"mdiSafeSquare\": () => /* binding */ mdiSafeSquare,\n/* harmony export */   \"mdiSafeSquareOutline\": () => /* binding */ mdiSafeSquareOutline,\n/* harmony export */   \"mdiSafetyGoggles\": () => /* binding */ mdiSafetyGoggles,\n/* harmony export */   \"mdiSailBoat\": () => /* binding */ mdiSailBoat,\n/* harmony export */   \"mdiSale\": () => /* binding */ mdiSale,\n/* harmony export */   \"mdiSalesforce\": () => /* binding */ mdiSalesforce,\n/* harmony export */   \"mdiSass\": () => /* binding */ mdiSass,\n/* harmony export */   \"mdiSatellite\": () => /* binding */ mdiSatellite,\n/* harmony export */   \"mdiSatelliteUplink\": () => /* binding */ mdiSatelliteUplink,\n/* harmony export */   \"mdiSatelliteVariant\": () => /* binding */ mdiSatelliteVariant,\n/* harmony export */   \"mdiSausage\": () => /* binding */ mdiSausage,\n/* harmony export */   \"mdiSawBlade\": () => /* binding */ mdiSawBlade,\n/* harmony export */   \"mdiSawtoothWave\": () => /* binding */ mdiSawtoothWave,\n/* harmony export */   \"mdiSaxophone\": () => /* binding */ mdiSaxophone,\n/* harmony export */   \"mdiScale\": () => /* binding */ mdiScale,\n/* harmony export */   \"mdiScaleBalance\": () => /* binding */ mdiScaleBalance,\n/* harmony export */   \"mdiScaleBathroom\": () => /* binding */ mdiScaleBathroom,\n/* harmony export */   \"mdiScaleOff\": () => /* binding */ mdiScaleOff,\n/* harmony export */   \"mdiScanHelper\": () => /* binding */ mdiScanHelper,\n/* harmony export */   \"mdiScanner\": () => /* binding */ mdiScanner,\n/* harmony export */   \"mdiScannerOff\": () => /* binding */ mdiScannerOff,\n/* harmony export */   \"mdiScatterPlot\": () => /* binding */ mdiScatterPlot,\n/* harmony export */   \"mdiScatterPlotOutline\": () => /* binding */ mdiScatterPlotOutline,\n/* harmony export */   \"mdiSchool\": () => /* binding */ mdiSchool,\n/* harmony export */   \"mdiSchoolOutline\": () => /* binding */ mdiSchoolOutline,\n/* harmony export */   \"mdiScissorsCutting\": () => /* binding */ mdiScissorsCutting,\n/* harmony export */   \"mdiScooter\": () => /* binding */ mdiScooter,\n/* harmony export */   \"mdiScooterElectric\": () => /* binding */ mdiScooterElectric,\n/* harmony export */   \"mdiScoreboard\": () => /* binding */ mdiScoreboard,\n/* harmony export */   \"mdiScoreboardOutline\": () => /* binding */ mdiScoreboardOutline,\n/* harmony export */   \"mdiScreenRotation\": () => /* binding */ mdiScreenRotation,\n/* harmony export */   \"mdiScreenRotationLock\": () => /* binding */ mdiScreenRotationLock,\n/* harmony export */   \"mdiScrewFlatTop\": () => /* binding */ mdiScrewFlatTop,\n/* harmony export */   \"mdiScrewLag\": () => /* binding */ mdiScrewLag,\n/* harmony export */   \"mdiScrewMachineFlatTop\": () => /* binding */ mdiScrewMachineFlatTop,\n/* harmony export */   \"mdiScrewMachineRoundTop\": () => /* binding */ mdiScrewMachineRoundTop,\n/* harmony export */   \"mdiScrewRoundTop\": () => /* binding */ mdiScrewRoundTop,\n/* harmony export */   \"mdiScrewdriver\": () => /* binding */ mdiScrewdriver,\n/* harmony export */   \"mdiScript\": () => /* binding */ mdiScript,\n/* harmony export */   \"mdiScriptOutline\": () => /* binding */ mdiScriptOutline,\n/* harmony export */   \"mdiScriptText\": () => /* binding */ mdiScriptText,\n/* harmony export */   \"mdiScriptTextOutline\": () => /* binding */ mdiScriptTextOutline,\n/* harmony export */   \"mdiSd\": () => /* binding */ mdiSd,\n/* harmony export */   \"mdiSeal\": () => /* binding */ mdiSeal,\n/* harmony export */   \"mdiSealVariant\": () => /* binding */ mdiSealVariant,\n/* harmony export */   \"mdiSearchWeb\": () => /* binding */ mdiSearchWeb,\n/* harmony export */   \"mdiSeat\": () => /* binding */ mdiSeat,\n/* harmony export */   \"mdiSeatFlat\": () => /* binding */ mdiSeatFlat,\n/* harmony export */   \"mdiSeatFlatAngled\": () => /* binding */ mdiSeatFlatAngled,\n/* harmony export */   \"mdiSeatIndividualSuite\": () => /* binding */ mdiSeatIndividualSuite,\n/* harmony export */   \"mdiSeatLegroomExtra\": () => /* binding */ mdiSeatLegroomExtra,\n/* harmony export */   \"mdiSeatLegroomNormal\": () => /* binding */ mdiSeatLegroomNormal,\n/* harmony export */   \"mdiSeatLegroomReduced\": () => /* binding */ mdiSeatLegroomReduced,\n/* harmony export */   \"mdiSeatOutline\": () => /* binding */ mdiSeatOutline,\n/* harmony export */   \"mdiSeatPassenger\": () => /* binding */ mdiSeatPassenger,\n/* harmony export */   \"mdiSeatReclineExtra\": () => /* binding */ mdiSeatReclineExtra,\n/* harmony export */   \"mdiSeatReclineNormal\": () => /* binding */ mdiSeatReclineNormal,\n/* harmony export */   \"mdiSeatbelt\": () => /* binding */ mdiSeatbelt,\n/* harmony export */   \"mdiSecurity\": () => /* binding */ mdiSecurity,\n/* harmony export */   \"mdiSecurityNetwork\": () => /* binding */ mdiSecurityNetwork,\n/* harmony export */   \"mdiSeed\": () => /* binding */ mdiSeed,\n/* harmony export */   \"mdiSeedOff\": () => /* binding */ mdiSeedOff,\n/* harmony export */   \"mdiSeedOffOutline\": () => /* binding */ mdiSeedOffOutline,\n/* harmony export */   \"mdiSeedOutline\": () => /* binding */ mdiSeedOutline,\n/* harmony export */   \"mdiSeesaw\": () => /* binding */ mdiSeesaw,\n/* harmony export */   \"mdiSegment\": () => /* binding */ mdiSegment,\n/* harmony export */   \"mdiSelect\": () => /* binding */ mdiSelect,\n/* harmony export */   \"mdiSelectAll\": () => /* binding */ mdiSelectAll,\n/* harmony export */   \"mdiSelectColor\": () => /* binding */ mdiSelectColor,\n/* harmony export */   \"mdiSelectCompare\": () => /* binding */ mdiSelectCompare,\n/* harmony export */   \"mdiSelectDrag\": () => /* binding */ mdiSelectDrag,\n/* harmony export */   \"mdiSelectGroup\": () => /* binding */ mdiSelectGroup,\n/* harmony export */   \"mdiSelectInverse\": () => /* binding */ mdiSelectInverse,\n/* harmony export */   \"mdiSelectMarker\": () => /* binding */ mdiSelectMarker,\n/* harmony export */   \"mdiSelectMultiple\": () => /* binding */ mdiSelectMultiple,\n/* harmony export */   \"mdiSelectMultipleMarker\": () => /* binding */ mdiSelectMultipleMarker,\n/* harmony export */   \"mdiSelectOff\": () => /* binding */ mdiSelectOff,\n/* harmony export */   \"mdiSelectPlace\": () => /* binding */ mdiSelectPlace,\n/* harmony export */   \"mdiSelectSearch\": () => /* binding */ mdiSelectSearch,\n/* harmony export */   \"mdiSelection\": () => /* binding */ mdiSelection,\n/* harmony export */   \"mdiSelectionDrag\": () => /* binding */ mdiSelectionDrag,\n/* harmony export */   \"mdiSelectionEllipse\": () => /* binding */ mdiSelectionEllipse,\n/* harmony export */   \"mdiSelectionEllipseArrowInside\": () => /* binding */ mdiSelectionEllipseArrowInside,\n/* harmony export */   \"mdiSelectionMarker\": () => /* binding */ mdiSelectionMarker,\n/* harmony export */   \"mdiSelectionMultiple\": () => /* binding */ mdiSelectionMultiple,\n/* harmony export */   \"mdiSelectionMultipleMarker\": () => /* binding */ mdiSelectionMultipleMarker,\n/* harmony export */   \"mdiSelectionOff\": () => /* binding */ mdiSelectionOff,\n/* harmony export */   \"mdiSelectionSearch\": () => /* binding */ mdiSelectionSearch,\n/* harmony export */   \"mdiSemanticWeb\": () => /* binding */ mdiSemanticWeb,\n/* harmony export */   \"mdiSend\": () => /* binding */ mdiSend,\n/* harmony export */   \"mdiSendCheck\": () => /* binding */ mdiSendCheck,\n/* harmony export */   \"mdiSendCheckOutline\": () => /* binding */ mdiSendCheckOutline,\n/* harmony export */   \"mdiSendCircle\": () => /* binding */ mdiSendCircle,\n/* harmony export */   \"mdiSendCircleOutline\": () => /* binding */ mdiSendCircleOutline,\n/* harmony export */   \"mdiSendClock\": () => /* binding */ mdiSendClock,\n/* harmony export */   \"mdiSendClockOutline\": () => /* binding */ mdiSendClockOutline,\n/* harmony export */   \"mdiSendLock\": () => /* binding */ mdiSendLock,\n/* harmony export */   \"mdiSendLockOutline\": () => /* binding */ mdiSendLockOutline,\n/* harmony export */   \"mdiSendOutline\": () => /* binding */ mdiSendOutline,\n/* harmony export */   \"mdiSerialPort\": () => /* binding */ mdiSerialPort,\n/* harmony export */   \"mdiServer\": () => /* binding */ mdiServer,\n/* harmony export */   \"mdiServerMinus\": () => /* binding */ mdiServerMinus,\n/* harmony export */   \"mdiServerNetwork\": () => /* binding */ mdiServerNetwork,\n/* harmony export */   \"mdiServerNetworkOff\": () => /* binding */ mdiServerNetworkOff,\n/* harmony export */   \"mdiServerOff\": () => /* binding */ mdiServerOff,\n/* harmony export */   \"mdiServerPlus\": () => /* binding */ mdiServerPlus,\n/* harmony export */   \"mdiServerRemove\": () => /* binding */ mdiServerRemove,\n/* harmony export */   \"mdiServerSecurity\": () => /* binding */ mdiServerSecurity,\n/* harmony export */   \"mdiSetAll\": () => /* binding */ mdiSetAll,\n/* harmony export */   \"mdiSetCenter\": () => /* binding */ mdiSetCenter,\n/* harmony export */   \"mdiSetCenterRight\": () => /* binding */ mdiSetCenterRight,\n/* harmony export */   \"mdiSetLeft\": () => /* binding */ mdiSetLeft,\n/* harmony export */   \"mdiSetLeftCenter\": () => /* binding */ mdiSetLeftCenter,\n/* harmony export */   \"mdiSetLeftRight\": () => /* binding */ mdiSetLeftRight,\n/* harmony export */   \"mdiSetMerge\": () => /* binding */ mdiSetMerge,\n/* harmony export */   \"mdiSetNone\": () => /* binding */ mdiSetNone,\n/* harmony export */   \"mdiSetRight\": () => /* binding */ mdiSetRight,\n/* harmony export */   \"mdiSetSplit\": () => /* binding */ mdiSetSplit,\n/* harmony export */   \"mdiSetSquare\": () => /* binding */ mdiSetSquare,\n/* harmony export */   \"mdiSetTopBox\": () => /* binding */ mdiSetTopBox,\n/* harmony export */   \"mdiSettingsHelper\": () => /* binding */ mdiSettingsHelper,\n/* harmony export */   \"mdiShaker\": () => /* binding */ mdiShaker,\n/* harmony export */   \"mdiShakerOutline\": () => /* binding */ mdiShakerOutline,\n/* harmony export */   \"mdiShape\": () => /* binding */ mdiShape,\n/* harmony export */   \"mdiShapeCirclePlus\": () => /* binding */ mdiShapeCirclePlus,\n/* harmony export */   \"mdiShapeOutline\": () => /* binding */ mdiShapeOutline,\n/* harmony export */   \"mdiShapeOvalPlus\": () => /* binding */ mdiShapeOvalPlus,\n/* harmony export */   \"mdiShapePlus\": () => /* binding */ mdiShapePlus,\n/* harmony export */   \"mdiShapePolygonPlus\": () => /* binding */ mdiShapePolygonPlus,\n/* harmony export */   \"mdiShapeRectanglePlus\": () => /* binding */ mdiShapeRectanglePlus,\n/* harmony export */   \"mdiShapeSquarePlus\": () => /* binding */ mdiShapeSquarePlus,\n/* harmony export */   \"mdiShapeSquareRoundedPlus\": () => /* binding */ mdiShapeSquareRoundedPlus,\n/* harmony export */   \"mdiShare\": () => /* binding */ mdiShare,\n/* harmony export */   \"mdiShareAll\": () => /* binding */ mdiShareAll,\n/* harmony export */   \"mdiShareAllOutline\": () => /* binding */ mdiShareAllOutline,\n/* harmony export */   \"mdiShareCircle\": () => /* binding */ mdiShareCircle,\n/* harmony export */   \"mdiShareOff\": () => /* binding */ mdiShareOff,\n/* harmony export */   \"mdiShareOffOutline\": () => /* binding */ mdiShareOffOutline,\n/* harmony export */   \"mdiShareOutline\": () => /* binding */ mdiShareOutline,\n/* harmony export */   \"mdiShareVariant\": () => /* binding */ mdiShareVariant,\n/* harmony export */   \"mdiShareVariantOutline\": () => /* binding */ mdiShareVariantOutline,\n/* harmony export */   \"mdiSheep\": () => /* binding */ mdiSheep,\n/* harmony export */   \"mdiShield\": () => /* binding */ mdiShield,\n/* harmony export */   \"mdiShieldAccount\": () => /* binding */ mdiShieldAccount,\n/* harmony export */   \"mdiShieldAccountOutline\": () => /* binding */ mdiShieldAccountOutline,\n/* harmony export */   \"mdiShieldAccountVariant\": () => /* binding */ mdiShieldAccountVariant,\n/* harmony export */   \"mdiShieldAccountVariantOutline\": () => /* binding */ mdiShieldAccountVariantOutline,\n/* harmony export */   \"mdiShieldAirplane\": () => /* binding */ mdiShieldAirplane,\n/* harmony export */   \"mdiShieldAirplaneOutline\": () => /* binding */ mdiShieldAirplaneOutline,\n/* harmony export */   \"mdiShieldAlert\": () => /* binding */ mdiShieldAlert,\n/* harmony export */   \"mdiShieldAlertOutline\": () => /* binding */ mdiShieldAlertOutline,\n/* harmony export */   \"mdiShieldBug\": () => /* binding */ mdiShieldBug,\n/* harmony export */   \"mdiShieldBugOutline\": () => /* binding */ mdiShieldBugOutline,\n/* harmony export */   \"mdiShieldCar\": () => /* binding */ mdiShieldCar,\n/* harmony export */   \"mdiShieldCheck\": () => /* binding */ mdiShieldCheck,\n/* harmony export */   \"mdiShieldCheckOutline\": () => /* binding */ mdiShieldCheckOutline,\n/* harmony export */   \"mdiShieldCross\": () => /* binding */ mdiShieldCross,\n/* harmony export */   \"mdiShieldCrossOutline\": () => /* binding */ mdiShieldCrossOutline,\n/* harmony export */   \"mdiShieldEdit\": () => /* binding */ mdiShieldEdit,\n/* harmony export */   \"mdiShieldEditOutline\": () => /* binding */ mdiShieldEditOutline,\n/* harmony export */   \"mdiShieldHalf\": () => /* binding */ mdiShieldHalf,\n/* harmony export */   \"mdiShieldHalfFull\": () => /* binding */ mdiShieldHalfFull,\n/* harmony export */   \"mdiShieldHome\": () => /* binding */ mdiShieldHome,\n/* harmony export */   \"mdiShieldHomeOutline\": () => /* binding */ mdiShieldHomeOutline,\n/* harmony export */   \"mdiShieldKey\": () => /* binding */ mdiShieldKey,\n/* harmony export */   \"mdiShieldKeyOutline\": () => /* binding */ mdiShieldKeyOutline,\n/* harmony export */   \"mdiShieldLinkVariant\": () => /* binding */ mdiShieldLinkVariant,\n/* harmony export */   \"mdiShieldLinkVariantOutline\": () => /* binding */ mdiShieldLinkVariantOutline,\n/* harmony export */   \"mdiShieldLock\": () => /* binding */ mdiShieldLock,\n/* harmony export */   \"mdiShieldLockOutline\": () => /* binding */ mdiShieldLockOutline,\n/* harmony export */   \"mdiShieldOff\": () => /* binding */ mdiShieldOff,\n/* harmony export */   \"mdiShieldOffOutline\": () => /* binding */ mdiShieldOffOutline,\n/* harmony export */   \"mdiShieldOutline\": () => /* binding */ mdiShieldOutline,\n/* harmony export */   \"mdiShieldPlus\": () => /* binding */ mdiShieldPlus,\n/* harmony export */   \"mdiShieldPlusOutline\": () => /* binding */ mdiShieldPlusOutline,\n/* harmony export */   \"mdiShieldRefresh\": () => /* binding */ mdiShieldRefresh,\n/* harmony export */   \"mdiShieldRefreshOutline\": () => /* binding */ mdiShieldRefreshOutline,\n/* harmony export */   \"mdiShieldRemove\": () => /* binding */ mdiShieldRemove,\n/* harmony export */   \"mdiShieldRemoveOutline\": () => /* binding */ mdiShieldRemoveOutline,\n/* harmony export */   \"mdiShieldSearch\": () => /* binding */ mdiShieldSearch,\n/* harmony export */   \"mdiShieldStar\": () => /* binding */ mdiShieldStar,\n/* harmony export */   \"mdiShieldStarOutline\": () => /* binding */ mdiShieldStarOutline,\n/* harmony export */   \"mdiShieldSun\": () => /* binding */ mdiShieldSun,\n/* harmony export */   \"mdiShieldSunOutline\": () => /* binding */ mdiShieldSunOutline,\n/* harmony export */   \"mdiShieldSync\": () => /* binding */ mdiShieldSync,\n/* harmony export */   \"mdiShieldSyncOutline\": () => /* binding */ mdiShieldSyncOutline,\n/* harmony export */   \"mdiShipWheel\": () => /* binding */ mdiShipWheel,\n/* harmony export */   \"mdiShoeBallet\": () => /* binding */ mdiShoeBallet,\n/* harmony export */   \"mdiShoeCleat\": () => /* binding */ mdiShoeCleat,\n/* harmony export */   \"mdiShoeFormal\": () => /* binding */ mdiShoeFormal,\n/* harmony export */   \"mdiShoeHeel\": () => /* binding */ mdiShoeHeel,\n/* harmony export */   \"mdiShoePrint\": () => /* binding */ mdiShoePrint,\n/* harmony export */   \"mdiShoeSneaker\": () => /* binding */ mdiShoeSneaker,\n/* harmony export */   \"mdiShopping\": () => /* binding */ mdiShopping,\n/* harmony export */   \"mdiShoppingMusic\": () => /* binding */ mdiShoppingMusic,\n/* harmony export */   \"mdiShoppingOutline\": () => /* binding */ mdiShoppingOutline,\n/* harmony export */   \"mdiShoppingSearch\": () => /* binding */ mdiShoppingSearch,\n/* harmony export */   \"mdiShore\": () => /* binding */ mdiShore,\n/* harmony export */   \"mdiShovel\": () => /* binding */ mdiShovel,\n/* harmony export */   \"mdiShovelOff\": () => /* binding */ mdiShovelOff,\n/* harmony export */   \"mdiShower\": () => /* binding */ mdiShower,\n/* harmony export */   \"mdiShowerHead\": () => /* binding */ mdiShowerHead,\n/* harmony export */   \"mdiShredder\": () => /* binding */ mdiShredder,\n/* harmony export */   \"mdiShuffle\": () => /* binding */ mdiShuffle,\n/* harmony export */   \"mdiShuffleDisabled\": () => /* binding */ mdiShuffleDisabled,\n/* harmony export */   \"mdiShuffleVariant\": () => /* binding */ mdiShuffleVariant,\n/* harmony export */   \"mdiShuriken\": () => /* binding */ mdiShuriken,\n/* harmony export */   \"mdiSigma\": () => /* binding */ mdiSigma,\n/* harmony export */   \"mdiSigmaLower\": () => /* binding */ mdiSigmaLower,\n/* harmony export */   \"mdiSignCaution\": () => /* binding */ mdiSignCaution,\n/* harmony export */   \"mdiSignDirection\": () => /* binding */ mdiSignDirection,\n/* harmony export */   \"mdiSignDirectionMinus\": () => /* binding */ mdiSignDirectionMinus,\n/* harmony export */   \"mdiSignDirectionPlus\": () => /* binding */ mdiSignDirectionPlus,\n/* harmony export */   \"mdiSignDirectionRemove\": () => /* binding */ mdiSignDirectionRemove,\n/* harmony export */   \"mdiSignPole\": () => /* binding */ mdiSignPole,\n/* harmony export */   \"mdiSignRealEstate\": () => /* binding */ mdiSignRealEstate,\n/* harmony export */   \"mdiSignText\": () => /* binding */ mdiSignText,\n/* harmony export */   \"mdiSignal\": () => /* binding */ mdiSignal,\n/* harmony export */   \"mdiSignal2g\": () => /* binding */ mdiSignal2g,\n/* harmony export */   \"mdiSignal3g\": () => /* binding */ mdiSignal3g,\n/* harmony export */   \"mdiSignal4g\": () => /* binding */ mdiSignal4g,\n/* harmony export */   \"mdiSignal5g\": () => /* binding */ mdiSignal5g,\n/* harmony export */   \"mdiSignalCellular1\": () => /* binding */ mdiSignalCellular1,\n/* harmony export */   \"mdiSignalCellular2\": () => /* binding */ mdiSignalCellular2,\n/* harmony export */   \"mdiSignalCellular3\": () => /* binding */ mdiSignalCellular3,\n/* harmony export */   \"mdiSignalCellularOutline\": () => /* binding */ mdiSignalCellularOutline,\n/* harmony export */   \"mdiSignalDistanceVariant\": () => /* binding */ mdiSignalDistanceVariant,\n/* harmony export */   \"mdiSignalHspa\": () => /* binding */ mdiSignalHspa,\n/* harmony export */   \"mdiSignalHspaPlus\": () => /* binding */ mdiSignalHspaPlus,\n/* harmony export */   \"mdiSignalOff\": () => /* binding */ mdiSignalOff,\n/* harmony export */   \"mdiSignalVariant\": () => /* binding */ mdiSignalVariant,\n/* harmony export */   \"mdiSignature\": () => /* binding */ mdiSignature,\n/* harmony export */   \"mdiSignatureFreehand\": () => /* binding */ mdiSignatureFreehand,\n/* harmony export */   \"mdiSignatureImage\": () => /* binding */ mdiSignatureImage,\n/* harmony export */   \"mdiSignatureText\": () => /* binding */ mdiSignatureText,\n/* harmony export */   \"mdiSilo\": () => /* binding */ mdiSilo,\n/* harmony export */   \"mdiSilverware\": () => /* binding */ mdiSilverware,\n/* harmony export */   \"mdiSilverwareClean\": () => /* binding */ mdiSilverwareClean,\n/* harmony export */   \"mdiSilverwareFork\": () => /* binding */ mdiSilverwareFork,\n/* harmony export */   \"mdiSilverwareForkKnife\": () => /* binding */ mdiSilverwareForkKnife,\n/* harmony export */   \"mdiSilverwareSpoon\": () => /* binding */ mdiSilverwareSpoon,\n/* harmony export */   \"mdiSilverwareVariant\": () => /* binding */ mdiSilverwareVariant,\n/* harmony export */   \"mdiSim\": () => /* binding */ mdiSim,\n/* harmony export */   \"mdiSimAlert\": () => /* binding */ mdiSimAlert,\n/* harmony export */   \"mdiSimAlertOutline\": () => /* binding */ mdiSimAlertOutline,\n/* harmony export */   \"mdiSimOff\": () => /* binding */ mdiSimOff,\n/* harmony export */   \"mdiSimOffOutline\": () => /* binding */ mdiSimOffOutline,\n/* harmony export */   \"mdiSimOutline\": () => /* binding */ mdiSimOutline,\n/* harmony export */   \"mdiSimpleIcons\": () => /* binding */ mdiSimpleIcons,\n/* harmony export */   \"mdiSinaWeibo\": () => /* binding */ mdiSinaWeibo,\n/* harmony export */   \"mdiSineWave\": () => /* binding */ mdiSineWave,\n/* harmony export */   \"mdiSitemap\": () => /* binding */ mdiSitemap,\n/* harmony export */   \"mdiSizeL\": () => /* binding */ mdiSizeL,\n/* harmony export */   \"mdiSizeM\": () => /* binding */ mdiSizeM,\n/* harmony export */   \"mdiSizeS\": () => /* binding */ mdiSizeS,\n/* harmony export */   \"mdiSizeXl\": () => /* binding */ mdiSizeXl,\n/* harmony export */   \"mdiSizeXs\": () => /* binding */ mdiSizeXs,\n/* harmony export */   \"mdiSizeXxl\": () => /* binding */ mdiSizeXxl,\n/* harmony export */   \"mdiSizeXxs\": () => /* binding */ mdiSizeXxs,\n/* harmony export */   \"mdiSizeXxxl\": () => /* binding */ mdiSizeXxxl,\n/* harmony export */   \"mdiSkate\": () => /* binding */ mdiSkate,\n/* harmony export */   \"mdiSkateboard\": () => /* binding */ mdiSkateboard,\n/* harmony export */   \"mdiSkewLess\": () => /* binding */ mdiSkewLess,\n/* harmony export */   \"mdiSkewMore\": () => /* binding */ mdiSkewMore,\n/* harmony export */   \"mdiSki\": () => /* binding */ mdiSki,\n/* harmony export */   \"mdiSkiCrossCountry\": () => /* binding */ mdiSkiCrossCountry,\n/* harmony export */   \"mdiSkiWater\": () => /* binding */ mdiSkiWater,\n/* harmony export */   \"mdiSkipBackward\": () => /* binding */ mdiSkipBackward,\n/* harmony export */   \"mdiSkipBackwardOutline\": () => /* binding */ mdiSkipBackwardOutline,\n/* harmony export */   \"mdiSkipForward\": () => /* binding */ mdiSkipForward,\n/* harmony export */   \"mdiSkipForwardOutline\": () => /* binding */ mdiSkipForwardOutline,\n/* harmony export */   \"mdiSkipNext\": () => /* binding */ mdiSkipNext,\n/* harmony export */   \"mdiSkipNextCircle\": () => /* binding */ mdiSkipNextCircle,\n/* harmony export */   \"mdiSkipNextCircleOutline\": () => /* binding */ mdiSkipNextCircleOutline,\n/* harmony export */   \"mdiSkipNextOutline\": () => /* binding */ mdiSkipNextOutline,\n/* harmony export */   \"mdiSkipPrevious\": () => /* binding */ mdiSkipPrevious,\n/* harmony export */   \"mdiSkipPreviousCircle\": () => /* binding */ mdiSkipPreviousCircle,\n/* harmony export */   \"mdiSkipPreviousCircleOutline\": () => /* binding */ mdiSkipPreviousCircleOutline,\n/* harmony export */   \"mdiSkipPreviousOutline\": () => /* binding */ mdiSkipPreviousOutline,\n/* harmony export */   \"mdiSkull\": () => /* binding */ mdiSkull,\n/* harmony export */   \"mdiSkullCrossbones\": () => /* binding */ mdiSkullCrossbones,\n/* harmony export */   \"mdiSkullCrossbonesOutline\": () => /* binding */ mdiSkullCrossbonesOutline,\n/* harmony export */   \"mdiSkullOutline\": () => /* binding */ mdiSkullOutline,\n/* harmony export */   \"mdiSkullScan\": () => /* binding */ mdiSkullScan,\n/* harmony export */   \"mdiSkullScanOutline\": () => /* binding */ mdiSkullScanOutline,\n/* harmony export */   \"mdiSkype\": () => /* binding */ mdiSkype,\n/* harmony export */   \"mdiSkypeBusiness\": () => /* binding */ mdiSkypeBusiness,\n/* harmony export */   \"mdiSlack\": () => /* binding */ mdiSlack,\n/* harmony export */   \"mdiSlashForward\": () => /* binding */ mdiSlashForward,\n/* harmony export */   \"mdiSlashForwardBox\": () => /* binding */ mdiSlashForwardBox,\n/* harmony export */   \"mdiSleep\": () => /* binding */ mdiSleep,\n/* harmony export */   \"mdiSleepOff\": () => /* binding */ mdiSleepOff,\n/* harmony export */   \"mdiSlide\": () => /* binding */ mdiSlide,\n/* harmony export */   \"mdiSlopeDownhill\": () => /* binding */ mdiSlopeDownhill,\n/* harmony export */   \"mdiSlopeUphill\": () => /* binding */ mdiSlopeUphill,\n/* harmony export */   \"mdiSlotMachine\": () => /* binding */ mdiSlotMachine,\n/* harmony export */   \"mdiSlotMachineOutline\": () => /* binding */ mdiSlotMachineOutline,\n/* harmony export */   \"mdiSmartCard\": () => /* binding */ mdiSmartCard,\n/* harmony export */   \"mdiSmartCardOutline\": () => /* binding */ mdiSmartCardOutline,\n/* harmony export */   \"mdiSmartCardReader\": () => /* binding */ mdiSmartCardReader,\n/* harmony export */   \"mdiSmartCardReaderOutline\": () => /* binding */ mdiSmartCardReaderOutline,\n/* harmony export */   \"mdiSmog\": () => /* binding */ mdiSmog,\n/* harmony export */   \"mdiSmokeDetector\": () => /* binding */ mdiSmokeDetector,\n/* harmony export */   \"mdiSmoking\": () => /* binding */ mdiSmoking,\n/* harmony export */   \"mdiSmokingOff\": () => /* binding */ mdiSmokingOff,\n/* harmony export */   \"mdiSmokingPipe\": () => /* binding */ mdiSmokingPipe,\n/* harmony export */   \"mdiSmokingPipeOff\": () => /* binding */ mdiSmokingPipeOff,\n/* harmony export */   \"mdiSnake\": () => /* binding */ mdiSnake,\n/* harmony export */   \"mdiSnapchat\": () => /* binding */ mdiSnapchat,\n/* harmony export */   \"mdiSnowboard\": () => /* binding */ mdiSnowboard,\n/* harmony export */   \"mdiSnowflake\": () => /* binding */ mdiSnowflake,\n/* harmony export */   \"mdiSnowflakeAlert\": () => /* binding */ mdiSnowflakeAlert,\n/* harmony export */   \"mdiSnowflakeMelt\": () => /* binding */ mdiSnowflakeMelt,\n/* harmony export */   \"mdiSnowflakeOff\": () => /* binding */ mdiSnowflakeOff,\n/* harmony export */   \"mdiSnowflakeVariant\": () => /* binding */ mdiSnowflakeVariant,\n/* harmony export */   \"mdiSnowman\": () => /* binding */ mdiSnowman,\n/* harmony export */   \"mdiSoccer\": () => /* binding */ mdiSoccer,\n/* harmony export */   \"mdiSoccerField\": () => /* binding */ mdiSoccerField,\n/* harmony export */   \"mdiSocialDistance2Meters\": () => /* binding */ mdiSocialDistance2Meters,\n/* harmony export */   \"mdiSocialDistance6Feet\": () => /* binding */ mdiSocialDistance6Feet,\n/* harmony export */   \"mdiSofa\": () => /* binding */ mdiSofa,\n/* harmony export */   \"mdiSofaOutline\": () => /* binding */ mdiSofaOutline,\n/* harmony export */   \"mdiSofaSingle\": () => /* binding */ mdiSofaSingle,\n/* harmony export */   \"mdiSofaSingleOutline\": () => /* binding */ mdiSofaSingleOutline,\n/* harmony export */   \"mdiSolarPanel\": () => /* binding */ mdiSolarPanel,\n/* harmony export */   \"mdiSolarPanelLarge\": () => /* binding */ mdiSolarPanelLarge,\n/* harmony export */   \"mdiSolarPower\": () => /* binding */ mdiSolarPower,\n/* harmony export */   \"mdiSolderingIron\": () => /* binding */ mdiSolderingIron,\n/* harmony export */   \"mdiSolid\": () => /* binding */ mdiSolid,\n/* harmony export */   \"mdiSonyPlaystation\": () => /* binding */ mdiSonyPlaystation,\n/* harmony export */   \"mdiSort\": () => /* binding */ mdiSort,\n/* harmony export */   \"mdiSortAlphabeticalAscending\": () => /* binding */ mdiSortAlphabeticalAscending,\n/* harmony export */   \"mdiSortAlphabeticalAscendingVariant\": () => /* binding */ mdiSortAlphabeticalAscendingVariant,\n/* harmony export */   \"mdiSortAlphabeticalDescending\": () => /* binding */ mdiSortAlphabeticalDescending,\n/* harmony export */   \"mdiSortAlphabeticalDescendingVariant\": () => /* binding */ mdiSortAlphabeticalDescendingVariant,\n/* harmony export */   \"mdiSortAlphabeticalVariant\": () => /* binding */ mdiSortAlphabeticalVariant,\n/* harmony export */   \"mdiSortAscending\": () => /* binding */ mdiSortAscending,\n/* harmony export */   \"mdiSortBoolAscending\": () => /* binding */ mdiSortBoolAscending,\n/* harmony export */   \"mdiSortBoolAscendingVariant\": () => /* binding */ mdiSortBoolAscendingVariant,\n/* harmony export */   \"mdiSortBoolDescending\": () => /* binding */ mdiSortBoolDescending,\n/* harmony export */   \"mdiSortBoolDescendingVariant\": () => /* binding */ mdiSortBoolDescendingVariant,\n/* harmony export */   \"mdiSortCalendarAscending\": () => /* binding */ mdiSortCalendarAscending,\n/* harmony export */   \"mdiSortCalendarDescending\": () => /* binding */ mdiSortCalendarDescending,\n/* harmony export */   \"mdiSortClockAscending\": () => /* binding */ mdiSortClockAscending,\n/* harmony export */   \"mdiSortClockAscendingOutline\": () => /* binding */ mdiSortClockAscendingOutline,\n/* harmony export */   \"mdiSortClockDescending\": () => /* binding */ mdiSortClockDescending,\n/* harmony export */   \"mdiSortClockDescendingOutline\": () => /* binding */ mdiSortClockDescendingOutline,\n/* harmony export */   \"mdiSortDescending\": () => /* binding */ mdiSortDescending,\n/* harmony export */   \"mdiSortNumericAscending\": () => /* binding */ mdiSortNumericAscending,\n/* harmony export */   \"mdiSortNumericAscendingVariant\": () => /* binding */ mdiSortNumericAscendingVariant,\n/* harmony export */   \"mdiSortNumericDescending\": () => /* binding */ mdiSortNumericDescending,\n/* harmony export */   \"mdiSortNumericDescendingVariant\": () => /* binding */ mdiSortNumericDescendingVariant,\n/* harmony export */   \"mdiSortNumericVariant\": () => /* binding */ mdiSortNumericVariant,\n/* harmony export */   \"mdiSortReverseVariant\": () => /* binding */ mdiSortReverseVariant,\n/* harmony export */   \"mdiSortVariant\": () => /* binding */ mdiSortVariant,\n/* harmony export */   \"mdiSortVariantLock\": () => /* binding */ mdiSortVariantLock,\n/* harmony export */   \"mdiSortVariantLockOpen\": () => /* binding */ mdiSortVariantLockOpen,\n/* harmony export */   \"mdiSortVariantRemove\": () => /* binding */ mdiSortVariantRemove,\n/* harmony export */   \"mdiSoundcloud\": () => /* binding */ mdiSoundcloud,\n/* harmony export */   \"mdiSourceBranch\": () => /* binding */ mdiSourceBranch,\n/* harmony export */   \"mdiSourceBranchCheck\": () => /* binding */ mdiSourceBranchCheck,\n/* harmony export */   \"mdiSourceBranchMinus\": () => /* binding */ mdiSourceBranchMinus,\n/* harmony export */   \"mdiSourceBranchPlus\": () => /* binding */ mdiSourceBranchPlus,\n/* harmony export */   \"mdiSourceBranchRefresh\": () => /* binding */ mdiSourceBranchRefresh,\n/* harmony export */   \"mdiSourceBranchRemove\": () => /* binding */ mdiSourceBranchRemove,\n/* harmony export */   \"mdiSourceBranchSync\": () => /* binding */ mdiSourceBranchSync,\n/* harmony export */   \"mdiSourceCommit\": () => /* binding */ mdiSourceCommit,\n/* harmony export */   \"mdiSourceCommitEnd\": () => /* binding */ mdiSourceCommitEnd,\n/* harmony export */   \"mdiSourceCommitEndLocal\": () => /* binding */ mdiSourceCommitEndLocal,\n/* harmony export */   \"mdiSourceCommitLocal\": () => /* binding */ mdiSourceCommitLocal,\n/* harmony export */   \"mdiSourceCommitNextLocal\": () => /* binding */ mdiSourceCommitNextLocal,\n/* harmony export */   \"mdiSourceCommitStart\": () => /* binding */ mdiSourceCommitStart,\n/* harmony export */   \"mdiSourceCommitStartNextLocal\": () => /* binding */ mdiSourceCommitStartNextLocal,\n/* harmony export */   \"mdiSourceFork\": () => /* binding */ mdiSourceFork,\n/* harmony export */   \"mdiSourceMerge\": () => /* binding */ mdiSourceMerge,\n/* harmony export */   \"mdiSourcePull\": () => /* binding */ mdiSourcePull,\n/* harmony export */   \"mdiSourceRepository\": () => /* binding */ mdiSourceRepository,\n/* harmony export */   \"mdiSourceRepositoryMultiple\": () => /* binding */ mdiSourceRepositoryMultiple,\n/* harmony export */   \"mdiSoySauce\": () => /* binding */ mdiSoySauce,\n/* harmony export */   \"mdiSoySauceOff\": () => /* binding */ mdiSoySauceOff,\n/* harmony export */   \"mdiSpa\": () => /* binding */ mdiSpa,\n/* harmony export */   \"mdiSpaOutline\": () => /* binding */ mdiSpaOutline,\n/* harmony export */   \"mdiSpaceInvaders\": () => /* binding */ mdiSpaceInvaders,\n/* harmony export */   \"mdiSpaceStation\": () => /* binding */ mdiSpaceStation,\n/* harmony export */   \"mdiSpade\": () => /* binding */ mdiSpade,\n/* harmony export */   \"mdiSparkles\": () => /* binding */ mdiSparkles,\n/* harmony export */   \"mdiSpeaker\": () => /* binding */ mdiSpeaker,\n/* harmony export */   \"mdiSpeakerBluetooth\": () => /* binding */ mdiSpeakerBluetooth,\n/* harmony export */   \"mdiSpeakerMultiple\": () => /* binding */ mdiSpeakerMultiple,\n/* harmony export */   \"mdiSpeakerOff\": () => /* binding */ mdiSpeakerOff,\n/* harmony export */   \"mdiSpeakerWireless\": () => /* binding */ mdiSpeakerWireless,\n/* harmony export */   \"mdiSpeedometer\": () => /* binding */ mdiSpeedometer,\n/* harmony export */   \"mdiSpeedometerMedium\": () => /* binding */ mdiSpeedometerMedium,\n/* harmony export */   \"mdiSpeedometerSlow\": () => /* binding */ mdiSpeedometerSlow,\n/* harmony export */   \"mdiSpellcheck\": () => /* binding */ mdiSpellcheck,\n/* harmony export */   \"mdiSpider\": () => /* binding */ mdiSpider,\n/* harmony export */   \"mdiSpiderThread\": () => /* binding */ mdiSpiderThread,\n/* harmony export */   \"mdiSpiderWeb\": () => /* binding */ mdiSpiderWeb,\n/* harmony export */   \"mdiSpiritLevel\": () => /* binding */ mdiSpiritLevel,\n/* harmony export */   \"mdiSpoonSugar\": () => /* binding */ mdiSpoonSugar,\n/* harmony export */   \"mdiSpotify\": () => /* binding */ mdiSpotify,\n/* harmony export */   \"mdiSpotlight\": () => /* binding */ mdiSpotlight,\n/* harmony export */   \"mdiSpotlightBeam\": () => /* binding */ mdiSpotlightBeam,\n/* harmony export */   \"mdiSpray\": () => /* binding */ mdiSpray,\n/* harmony export */   \"mdiSprayBottle\": () => /* binding */ mdiSprayBottle,\n/* harmony export */   \"mdiSprinkler\": () => /* binding */ mdiSprinkler,\n/* harmony export */   \"mdiSprinklerVariant\": () => /* binding */ mdiSprinklerVariant,\n/* harmony export */   \"mdiSprout\": () => /* binding */ mdiSprout,\n/* harmony export */   \"mdiSproutOutline\": () => /* binding */ mdiSproutOutline,\n/* harmony export */   \"mdiSquare\": () => /* binding */ mdiSquare,\n/* harmony export */   \"mdiSquareCircle\": () => /* binding */ mdiSquareCircle,\n/* harmony export */   \"mdiSquareEditOutline\": () => /* binding */ mdiSquareEditOutline,\n/* harmony export */   \"mdiSquareMedium\": () => /* binding */ mdiSquareMedium,\n/* harmony export */   \"mdiSquareMediumOutline\": () => /* binding */ mdiSquareMediumOutline,\n/* harmony export */   \"mdiSquareOff\": () => /* binding */ mdiSquareOff,\n/* harmony export */   \"mdiSquareOffOutline\": () => /* binding */ mdiSquareOffOutline,\n/* harmony export */   \"mdiSquareOutline\": () => /* binding */ mdiSquareOutline,\n/* harmony export */   \"mdiSquareRoot\": () => /* binding */ mdiSquareRoot,\n/* harmony export */   \"mdiSquareRootBox\": () => /* binding */ mdiSquareRootBox,\n/* harmony export */   \"mdiSquareRounded\": () => /* binding */ mdiSquareRounded,\n/* harmony export */   \"mdiSquareRoundedOutline\": () => /* binding */ mdiSquareRoundedOutline,\n/* harmony export */   \"mdiSquareSmall\": () => /* binding */ mdiSquareSmall,\n/* harmony export */   \"mdiSquareWave\": () => /* binding */ mdiSquareWave,\n/* harmony export */   \"mdiSqueegee\": () => /* binding */ mdiSqueegee,\n/* harmony export */   \"mdiSsh\": () => /* binding */ mdiSsh,\n/* harmony export */   \"mdiStackExchange\": () => /* binding */ mdiStackExchange,\n/* harmony export */   \"mdiStackOverflow\": () => /* binding */ mdiStackOverflow,\n/* harmony export */   \"mdiStackpath\": () => /* binding */ mdiStackpath,\n/* harmony export */   \"mdiStadium\": () => /* binding */ mdiStadium,\n/* harmony export */   \"mdiStadiumVariant\": () => /* binding */ mdiStadiumVariant,\n/* harmony export */   \"mdiStairs\": () => /* binding */ mdiStairs,\n/* harmony export */   \"mdiStairsBox\": () => /* binding */ mdiStairsBox,\n/* harmony export */   \"mdiStairsDown\": () => /* binding */ mdiStairsDown,\n/* harmony export */   \"mdiStairsUp\": () => /* binding */ mdiStairsUp,\n/* harmony export */   \"mdiStamper\": () => /* binding */ mdiStamper,\n/* harmony export */   \"mdiStandardDefinition\": () => /* binding */ mdiStandardDefinition,\n/* harmony export */   \"mdiStar\": () => /* binding */ mdiStar,\n/* harmony export */   \"mdiStarBox\": () => /* binding */ mdiStarBox,\n/* harmony export */   \"mdiStarBoxMultiple\": () => /* binding */ mdiStarBoxMultiple,\n/* harmony export */   \"mdiStarBoxMultipleOutline\": () => /* binding */ mdiStarBoxMultipleOutline,\n/* harmony export */   \"mdiStarBoxOutline\": () => /* binding */ mdiStarBoxOutline,\n/* harmony export */   \"mdiStarCheck\": () => /* binding */ mdiStarCheck,\n/* harmony export */   \"mdiStarCheckOutline\": () => /* binding */ mdiStarCheckOutline,\n/* harmony export */   \"mdiStarCircle\": () => /* binding */ mdiStarCircle,\n/* harmony export */   \"mdiStarCircleOutline\": () => /* binding */ mdiStarCircleOutline,\n/* harmony export */   \"mdiStarFace\": () => /* binding */ mdiStarFace,\n/* harmony export */   \"mdiStarFourPoints\": () => /* binding */ mdiStarFourPoints,\n/* harmony export */   \"mdiStarFourPointsOutline\": () => /* binding */ mdiStarFourPointsOutline,\n/* harmony export */   \"mdiStarHalf\": () => /* binding */ mdiStarHalf,\n/* harmony export */   \"mdiStarHalfFull\": () => /* binding */ mdiStarHalfFull,\n/* harmony export */   \"mdiStarMinus\": () => /* binding */ mdiStarMinus,\n/* harmony export */   \"mdiStarMinusOutline\": () => /* binding */ mdiStarMinusOutline,\n/* harmony export */   \"mdiStarOff\": () => /* binding */ mdiStarOff,\n/* harmony export */   \"mdiStarOffOutline\": () => /* binding */ mdiStarOffOutline,\n/* harmony export */   \"mdiStarOutline\": () => /* binding */ mdiStarOutline,\n/* harmony export */   \"mdiStarPlus\": () => /* binding */ mdiStarPlus,\n/* harmony export */   \"mdiStarPlusOutline\": () => /* binding */ mdiStarPlusOutline,\n/* harmony export */   \"mdiStarRemove\": () => /* binding */ mdiStarRemove,\n/* harmony export */   \"mdiStarRemoveOutline\": () => /* binding */ mdiStarRemoveOutline,\n/* harmony export */   \"mdiStarThreePoints\": () => /* binding */ mdiStarThreePoints,\n/* harmony export */   \"mdiStarThreePointsOutline\": () => /* binding */ mdiStarThreePointsOutline,\n/* harmony export */   \"mdiStateMachine\": () => /* binding */ mdiStateMachine,\n/* harmony export */   \"mdiSteam\": () => /* binding */ mdiSteam,\n/* harmony export */   \"mdiSteering\": () => /* binding */ mdiSteering,\n/* harmony export */   \"mdiSteeringOff\": () => /* binding */ mdiSteeringOff,\n/* harmony export */   \"mdiStepBackward\": () => /* binding */ mdiStepBackward,\n/* harmony export */   \"mdiStepBackward2\": () => /* binding */ mdiStepBackward2,\n/* harmony export */   \"mdiStepForward\": () => /* binding */ mdiStepForward,\n/* harmony export */   \"mdiStepForward2\": () => /* binding */ mdiStepForward2,\n/* harmony export */   \"mdiStethoscope\": () => /* binding */ mdiStethoscope,\n/* harmony export */   \"mdiSticker\": () => /* binding */ mdiSticker,\n/* harmony export */   \"mdiStickerAlert\": () => /* binding */ mdiStickerAlert,\n/* harmony export */   \"mdiStickerAlertOutline\": () => /* binding */ mdiStickerAlertOutline,\n/* harmony export */   \"mdiStickerCheck\": () => /* binding */ mdiStickerCheck,\n/* harmony export */   \"mdiStickerCheckOutline\": () => /* binding */ mdiStickerCheckOutline,\n/* harmony export */   \"mdiStickerCircleOutline\": () => /* binding */ mdiStickerCircleOutline,\n/* harmony export */   \"mdiStickerEmoji\": () => /* binding */ mdiStickerEmoji,\n/* harmony export */   \"mdiStickerMinus\": () => /* binding */ mdiStickerMinus,\n/* harmony export */   \"mdiStickerMinusOutline\": () => /* binding */ mdiStickerMinusOutline,\n/* harmony export */   \"mdiStickerOutline\": () => /* binding */ mdiStickerOutline,\n/* harmony export */   \"mdiStickerPlus\": () => /* binding */ mdiStickerPlus,\n/* harmony export */   \"mdiStickerPlusOutline\": () => /* binding */ mdiStickerPlusOutline,\n/* harmony export */   \"mdiStickerRemove\": () => /* binding */ mdiStickerRemove,\n/* harmony export */   \"mdiStickerRemoveOutline\": () => /* binding */ mdiStickerRemoveOutline,\n/* harmony export */   \"mdiStocking\": () => /* binding */ mdiStocking,\n/* harmony export */   \"mdiStomach\": () => /* binding */ mdiStomach,\n/* harmony export */   \"mdiStop\": () => /* binding */ mdiStop,\n/* harmony export */   \"mdiStopCircle\": () => /* binding */ mdiStopCircle,\n/* harmony export */   \"mdiStopCircleOutline\": () => /* binding */ mdiStopCircleOutline,\n/* harmony export */   \"mdiStore\": () => /* binding */ mdiStore,\n/* harmony export */   \"mdiStore24Hour\": () => /* binding */ mdiStore24Hour,\n/* harmony export */   \"mdiStoreOutline\": () => /* binding */ mdiStoreOutline,\n/* harmony export */   \"mdiStorefront\": () => /* binding */ mdiStorefront,\n/* harmony export */   \"mdiStorefrontOutline\": () => /* binding */ mdiStorefrontOutline,\n/* harmony export */   \"mdiStove\": () => /* binding */ mdiStove,\n/* harmony export */   \"mdiStrategy\": () => /* binding */ mdiStrategy,\n/* harmony export */   \"mdiStretchToPage\": () => /* binding */ mdiStretchToPage,\n/* harmony export */   \"mdiStretchToPageOutline\": () => /* binding */ mdiStretchToPageOutline,\n/* harmony export */   \"mdiStringLights\": () => /* binding */ mdiStringLights,\n/* harmony export */   \"mdiStringLightsOff\": () => /* binding */ mdiStringLightsOff,\n/* harmony export */   \"mdiSubdirectoryArrowLeft\": () => /* binding */ mdiSubdirectoryArrowLeft,\n/* harmony export */   \"mdiSubdirectoryArrowRight\": () => /* binding */ mdiSubdirectoryArrowRight,\n/* harmony export */   \"mdiSubmarine\": () => /* binding */ mdiSubmarine,\n/* harmony export */   \"mdiSubtitles\": () => /* binding */ mdiSubtitles,\n/* harmony export */   \"mdiSubtitlesOutline\": () => /* binding */ mdiSubtitlesOutline,\n/* harmony export */   \"mdiSubway\": () => /* binding */ mdiSubway,\n/* harmony export */   \"mdiSubwayAlertVariant\": () => /* binding */ mdiSubwayAlertVariant,\n/* harmony export */   \"mdiSubwayVariant\": () => /* binding */ mdiSubwayVariant,\n/* harmony export */   \"mdiSummit\": () => /* binding */ mdiSummit,\n/* harmony export */   \"mdiSunglasses\": () => /* binding */ mdiSunglasses,\n/* harmony export */   \"mdiSurroundSound\": () => /* binding */ mdiSurroundSound,\n/* harmony export */   \"mdiSurroundSound20\": () => /* binding */ mdiSurroundSound20,\n/* harmony export */   \"mdiSurroundSound31\": () => /* binding */ mdiSurroundSound31,\n/* harmony export */   \"mdiSurroundSound51\": () => /* binding */ mdiSurroundSound51,\n/* harmony export */   \"mdiSurroundSound71\": () => /* binding */ mdiSurroundSound71,\n/* harmony export */   \"mdiSvg\": () => /* binding */ mdiSvg,\n/* harmony export */   \"mdiSwapHorizontal\": () => /* binding */ mdiSwapHorizontal,\n/* harmony export */   \"mdiSwapHorizontalBold\": () => /* binding */ mdiSwapHorizontalBold,\n/* harmony export */   \"mdiSwapHorizontalCircle\": () => /* binding */ mdiSwapHorizontalCircle,\n/* harmony export */   \"mdiSwapHorizontalCircleOutline\": () => /* binding */ mdiSwapHorizontalCircleOutline,\n/* harmony export */   \"mdiSwapHorizontalVariant\": () => /* binding */ mdiSwapHorizontalVariant,\n/* harmony export */   \"mdiSwapVertical\": () => /* binding */ mdiSwapVertical,\n/* harmony export */   \"mdiSwapVerticalBold\": () => /* binding */ mdiSwapVerticalBold,\n/* harmony export */   \"mdiSwapVerticalCircle\": () => /* binding */ mdiSwapVerticalCircle,\n/* harmony export */   \"mdiSwapVerticalCircleOutline\": () => /* binding */ mdiSwapVerticalCircleOutline,\n/* harmony export */   \"mdiSwapVerticalVariant\": () => /* binding */ mdiSwapVerticalVariant,\n/* harmony export */   \"mdiSwim\": () => /* binding */ mdiSwim,\n/* harmony export */   \"mdiSwitch\": () => /* binding */ mdiSwitch,\n/* harmony export */   \"mdiSword\": () => /* binding */ mdiSword,\n/* harmony export */   \"mdiSwordCross\": () => /* binding */ mdiSwordCross,\n/* harmony export */   \"mdiSyllabaryHangul\": () => /* binding */ mdiSyllabaryHangul,\n/* harmony export */   \"mdiSyllabaryHiragana\": () => /* binding */ mdiSyllabaryHiragana,\n/* harmony export */   \"mdiSyllabaryKatakana\": () => /* binding */ mdiSyllabaryKatakana,\n/* harmony export */   \"mdiSyllabaryKatakanaHalfwidth\": () => /* binding */ mdiSyllabaryKatakanaHalfwidth,\n/* harmony export */   \"mdiSymbol\": () => /* binding */ mdiSymbol,\n/* harmony export */   \"mdiSymfony\": () => /* binding */ mdiSymfony,\n/* harmony export */   \"mdiSync\": () => /* binding */ mdiSync,\n/* harmony export */   \"mdiSyncAlert\": () => /* binding */ mdiSyncAlert,\n/* harmony export */   \"mdiSyncCircle\": () => /* binding */ mdiSyncCircle,\n/* harmony export */   \"mdiSyncOff\": () => /* binding */ mdiSyncOff,\n/* harmony export */   \"mdiTab\": () => /* binding */ mdiTab,\n/* harmony export */   \"mdiTabMinus\": () => /* binding */ mdiTabMinus,\n/* harmony export */   \"mdiTabPlus\": () => /* binding */ mdiTabPlus,\n/* harmony export */   \"mdiTabRemove\": () => /* binding */ mdiTabRemove,\n/* harmony export */   \"mdiTabUnselected\": () => /* binding */ mdiTabUnselected,\n/* harmony export */   \"mdiTable\": () => /* binding */ mdiTable,\n/* harmony export */   \"mdiTableAccount\": () => /* binding */ mdiTableAccount,\n/* harmony export */   \"mdiTableAlert\": () => /* binding */ mdiTableAlert,\n/* harmony export */   \"mdiTableArrowDown\": () => /* binding */ mdiTableArrowDown,\n/* harmony export */   \"mdiTableArrowLeft\": () => /* binding */ mdiTableArrowLeft,\n/* harmony export */   \"mdiTableArrowRight\": () => /* binding */ mdiTableArrowRight,\n/* harmony export */   \"mdiTableArrowUp\": () => /* binding */ mdiTableArrowUp,\n/* harmony export */   \"mdiTableBorder\": () => /* binding */ mdiTableBorder,\n/* harmony export */   \"mdiTableCancel\": () => /* binding */ mdiTableCancel,\n/* harmony export */   \"mdiTableChair\": () => /* binding */ mdiTableChair,\n/* harmony export */   \"mdiTableCheck\": () => /* binding */ mdiTableCheck,\n/* harmony export */   \"mdiTableClock\": () => /* binding */ mdiTableClock,\n/* harmony export */   \"mdiTableCog\": () => /* binding */ mdiTableCog,\n/* harmony export */   \"mdiTableColumn\": () => /* binding */ mdiTableColumn,\n/* harmony export */   \"mdiTableColumnPlusAfter\": () => /* binding */ mdiTableColumnPlusAfter,\n/* harmony export */   \"mdiTableColumnPlusBefore\": () => /* binding */ mdiTableColumnPlusBefore,\n/* harmony export */   \"mdiTableColumnRemove\": () => /* binding */ mdiTableColumnRemove,\n/* harmony export */   \"mdiTableColumnWidth\": () => /* binding */ mdiTableColumnWidth,\n/* harmony export */   \"mdiTableEdit\": () => /* binding */ mdiTableEdit,\n/* harmony export */   \"mdiTableEye\": () => /* binding */ mdiTableEye,\n/* harmony export */   \"mdiTableEyeOff\": () => /* binding */ mdiTableEyeOff,\n/* harmony export */   \"mdiTableFurniture\": () => /* binding */ mdiTableFurniture,\n/* harmony export */   \"mdiTableHeadersEye\": () => /* binding */ mdiTableHeadersEye,\n/* harmony export */   \"mdiTableHeadersEyeOff\": () => /* binding */ mdiTableHeadersEyeOff,\n/* harmony export */   \"mdiTableHeart\": () => /* binding */ mdiTableHeart,\n/* harmony export */   \"mdiTableKey\": () => /* binding */ mdiTableKey,\n/* harmony export */   \"mdiTableLarge\": () => /* binding */ mdiTableLarge,\n/* harmony export */   \"mdiTableLargePlus\": () => /* binding */ mdiTableLargePlus,\n/* harmony export */   \"mdiTableLargeRemove\": () => /* binding */ mdiTableLargeRemove,\n/* harmony export */   \"mdiTableLock\": () => /* binding */ mdiTableLock,\n/* harmony export */   \"mdiTableMergeCells\": () => /* binding */ mdiTableMergeCells,\n/* harmony export */   \"mdiTableMinus\": () => /* binding */ mdiTableMinus,\n/* harmony export */   \"mdiTableMultiple\": () => /* binding */ mdiTableMultiple,\n/* harmony export */   \"mdiTableNetwork\": () => /* binding */ mdiTableNetwork,\n/* harmony export */   \"mdiTableOfContents\": () => /* binding */ mdiTableOfContents,\n/* harmony export */   \"mdiTableOff\": () => /* binding */ mdiTableOff,\n/* harmony export */   \"mdiTablePlus\": () => /* binding */ mdiTablePlus,\n/* harmony export */   \"mdiTableRefresh\": () => /* binding */ mdiTableRefresh,\n/* harmony export */   \"mdiTableRemove\": () => /* binding */ mdiTableRemove,\n/* harmony export */   \"mdiTableRow\": () => /* binding */ mdiTableRow,\n/* harmony export */   \"mdiTableRowHeight\": () => /* binding */ mdiTableRowHeight,\n/* harmony export */   \"mdiTableRowPlusAfter\": () => /* binding */ mdiTableRowPlusAfter,\n/* harmony export */   \"mdiTableRowPlusBefore\": () => /* binding */ mdiTableRowPlusBefore,\n/* harmony export */   \"mdiTableRowRemove\": () => /* binding */ mdiTableRowRemove,\n/* harmony export */   \"mdiTableSearch\": () => /* binding */ mdiTableSearch,\n/* harmony export */   \"mdiTableSettings\": () => /* binding */ mdiTableSettings,\n/* harmony export */   \"mdiTableSplitCell\": () => /* binding */ mdiTableSplitCell,\n/* harmony export */   \"mdiTableStar\": () => /* binding */ mdiTableStar,\n/* harmony export */   \"mdiTableSync\": () => /* binding */ mdiTableSync,\n/* harmony export */   \"mdiTableTennis\": () => /* binding */ mdiTableTennis,\n/* harmony export */   \"mdiTablet\": () => /* binding */ mdiTablet,\n/* harmony export */   \"mdiTabletAndroid\": () => /* binding */ mdiTabletAndroid,\n/* harmony export */   \"mdiTabletCellphone\": () => /* binding */ mdiTabletCellphone,\n/* harmony export */   \"mdiTabletDashboard\": () => /* binding */ mdiTabletDashboard,\n/* harmony export */   \"mdiTabletIpad\": () => /* binding */ mdiTabletIpad,\n/* harmony export */   \"mdiTaco\": () => /* binding */ mdiTaco,\n/* harmony export */   \"mdiTag\": () => /* binding */ mdiTag,\n/* harmony export */   \"mdiTagFaces\": () => /* binding */ mdiTagFaces,\n/* harmony export */   \"mdiTagHeart\": () => /* binding */ mdiTagHeart,\n/* harmony export */   \"mdiTagHeartOutline\": () => /* binding */ mdiTagHeartOutline,\n/* harmony export */   \"mdiTagMinus\": () => /* binding */ mdiTagMinus,\n/* harmony export */   \"mdiTagMinusOutline\": () => /* binding */ mdiTagMinusOutline,\n/* harmony export */   \"mdiTagMultiple\": () => /* binding */ mdiTagMultiple,\n/* harmony export */   \"mdiTagMultipleOutline\": () => /* binding */ mdiTagMultipleOutline,\n/* harmony export */   \"mdiTagOff\": () => /* binding */ mdiTagOff,\n/* harmony export */   \"mdiTagOffOutline\": () => /* binding */ mdiTagOffOutline,\n/* harmony export */   \"mdiTagOutline\": () => /* binding */ mdiTagOutline,\n/* harmony export */   \"mdiTagPlus\": () => /* binding */ mdiTagPlus,\n/* harmony export */   \"mdiTagPlusOutline\": () => /* binding */ mdiTagPlusOutline,\n/* harmony export */   \"mdiTagRemove\": () => /* binding */ mdiTagRemove,\n/* harmony export */   \"mdiTagRemoveOutline\": () => /* binding */ mdiTagRemoveOutline,\n/* harmony export */   \"mdiTagText\": () => /* binding */ mdiTagText,\n/* harmony export */   \"mdiTagTextOutline\": () => /* binding */ mdiTagTextOutline,\n/* harmony export */   \"mdiTailwind\": () => /* binding */ mdiTailwind,\n/* harmony export */   \"mdiTank\": () => /* binding */ mdiTank,\n/* harmony export */   \"mdiTankerTruck\": () => /* binding */ mdiTankerTruck,\n/* harmony export */   \"mdiTapeMeasure\": () => /* binding */ mdiTapeMeasure,\n/* harmony export */   \"mdiTarget\": () => /* binding */ mdiTarget,\n/* harmony export */   \"mdiTargetAccount\": () => /* binding */ mdiTargetAccount,\n/* harmony export */   \"mdiTargetVariant\": () => /* binding */ mdiTargetVariant,\n/* harmony export */   \"mdiTaxi\": () => /* binding */ mdiTaxi,\n/* harmony export */   \"mdiTea\": () => /* binding */ mdiTea,\n/* harmony export */   \"mdiTeaOutline\": () => /* binding */ mdiTeaOutline,\n/* harmony export */   \"mdiTeach\": () => /* binding */ mdiTeach,\n/* harmony export */   \"mdiTeamviewer\": () => /* binding */ mdiTeamviewer,\n/* harmony export */   \"mdiTelegram\": () => /* binding */ mdiTelegram,\n/* harmony export */   \"mdiTelescope\": () => /* binding */ mdiTelescope,\n/* harmony export */   \"mdiTelevision\": () => /* binding */ mdiTelevision,\n/* harmony export */   \"mdiTelevisionAmbientLight\": () => /* binding */ mdiTelevisionAmbientLight,\n/* harmony export */   \"mdiTelevisionBox\": () => /* binding */ mdiTelevisionBox,\n/* harmony export */   \"mdiTelevisionClassic\": () => /* binding */ mdiTelevisionClassic,\n/* harmony export */   \"mdiTelevisionClassicOff\": () => /* binding */ mdiTelevisionClassicOff,\n/* harmony export */   \"mdiTelevisionClean\": () => /* binding */ mdiTelevisionClean,\n/* harmony export */   \"mdiTelevisionGuide\": () => /* binding */ mdiTelevisionGuide,\n/* harmony export */   \"mdiTelevisionOff\": () => /* binding */ mdiTelevisionOff,\n/* harmony export */   \"mdiTelevisionPause\": () => /* binding */ mdiTelevisionPause,\n/* harmony export */   \"mdiTelevisionPlay\": () => /* binding */ mdiTelevisionPlay,\n/* harmony export */   \"mdiTelevisionStop\": () => /* binding */ mdiTelevisionStop,\n/* harmony export */   \"mdiTemperatureCelsius\": () => /* binding */ mdiTemperatureCelsius,\n/* harmony export */   \"mdiTemperatureFahrenheit\": () => /* binding */ mdiTemperatureFahrenheit,\n/* harmony export */   \"mdiTemperatureKelvin\": () => /* binding */ mdiTemperatureKelvin,\n/* harmony export */   \"mdiTennis\": () => /* binding */ mdiTennis,\n/* harmony export */   \"mdiTennisBall\": () => /* binding */ mdiTennisBall,\n/* harmony export */   \"mdiTent\": () => /* binding */ mdiTent,\n/* harmony export */   \"mdiTerraform\": () => /* binding */ mdiTerraform,\n/* harmony export */   \"mdiTerrain\": () => /* binding */ mdiTerrain,\n/* harmony export */   \"mdiTestTube\": () => /* binding */ mdiTestTube,\n/* harmony export */   \"mdiTestTubeEmpty\": () => /* binding */ mdiTestTubeEmpty,\n/* harmony export */   \"mdiTestTubeOff\": () => /* binding */ mdiTestTubeOff,\n/* harmony export */   \"mdiText\": () => /* binding */ mdiText,\n/* harmony export */   \"mdiTextAccount\": () => /* binding */ mdiTextAccount,\n/* harmony export */   \"mdiTextBox\": () => /* binding */ mdiTextBox,\n/* harmony export */   \"mdiTextBoxCheck\": () => /* binding */ mdiTextBoxCheck,\n/* harmony export */   \"mdiTextBoxCheckOutline\": () => /* binding */ mdiTextBoxCheckOutline,\n/* harmony export */   \"mdiTextBoxMinus\": () => /* binding */ mdiTextBoxMinus,\n/* harmony export */   \"mdiTextBoxMinusOutline\": () => /* binding */ mdiTextBoxMinusOutline,\n/* harmony export */   \"mdiTextBoxMultiple\": () => /* binding */ mdiTextBoxMultiple,\n/* harmony export */   \"mdiTextBoxMultipleOutline\": () => /* binding */ mdiTextBoxMultipleOutline,\n/* harmony export */   \"mdiTextBoxOutline\": () => /* binding */ mdiTextBoxOutline,\n/* harmony export */   \"mdiTextBoxPlus\": () => /* binding */ mdiTextBoxPlus,\n/* harmony export */   \"mdiTextBoxPlusOutline\": () => /* binding */ mdiTextBoxPlusOutline,\n/* harmony export */   \"mdiTextBoxRemove\": () => /* binding */ mdiTextBoxRemove,\n/* harmony export */   \"mdiTextBoxRemoveOutline\": () => /* binding */ mdiTextBoxRemoveOutline,\n/* harmony export */   \"mdiTextBoxSearch\": () => /* binding */ mdiTextBoxSearch,\n/* harmony export */   \"mdiTextBoxSearchOutline\": () => /* binding */ mdiTextBoxSearchOutline,\n/* harmony export */   \"mdiTextRecognition\": () => /* binding */ mdiTextRecognition,\n/* harmony export */   \"mdiTextSearch\": () => /* binding */ mdiTextSearch,\n/* harmony export */   \"mdiTextShadow\": () => /* binding */ mdiTextShadow,\n/* harmony export */   \"mdiTextShort\": () => /* binding */ mdiTextShort,\n/* harmony export */   \"mdiTextSubject\": () => /* binding */ mdiTextSubject,\n/* harmony export */   \"mdiTextToSpeech\": () => /* binding */ mdiTextToSpeech,\n/* harmony export */   \"mdiTextToSpeechOff\": () => /* binding */ mdiTextToSpeechOff,\n/* harmony export */   \"mdiTexture\": () => /* binding */ mdiTexture,\n/* harmony export */   \"mdiTextureBox\": () => /* binding */ mdiTextureBox,\n/* harmony export */   \"mdiTheater\": () => /* binding */ mdiTheater,\n/* harmony export */   \"mdiThemeLightDark\": () => /* binding */ mdiThemeLightDark,\n/* harmony export */   \"mdiThermometer\": () => /* binding */ mdiThermometer,\n/* harmony export */   \"mdiThermometerAlert\": () => /* binding */ mdiThermometerAlert,\n/* harmony export */   \"mdiThermometerChevronDown\": () => /* binding */ mdiThermometerChevronDown,\n/* harmony export */   \"mdiThermometerChevronUp\": () => /* binding */ mdiThermometerChevronUp,\n/* harmony export */   \"mdiThermometerHigh\": () => /* binding */ mdiThermometerHigh,\n/* harmony export */   \"mdiThermometerLines\": () => /* binding */ mdiThermometerLines,\n/* harmony export */   \"mdiThermometerLow\": () => /* binding */ mdiThermometerLow,\n/* harmony export */   \"mdiThermometerMinus\": () => /* binding */ mdiThermometerMinus,\n/* harmony export */   \"mdiThermometerOff\": () => /* binding */ mdiThermometerOff,\n/* harmony export */   \"mdiThermometerPlus\": () => /* binding */ mdiThermometerPlus,\n/* harmony export */   \"mdiThermostat\": () => /* binding */ mdiThermostat,\n/* harmony export */   \"mdiThermostatBox\": () => /* binding */ mdiThermostatBox,\n/* harmony export */   \"mdiThoughtBubble\": () => /* binding */ mdiThoughtBubble,\n/* harmony export */   \"mdiThoughtBubbleOutline\": () => /* binding */ mdiThoughtBubbleOutline,\n/* harmony export */   \"mdiThumbDown\": () => /* binding */ mdiThumbDown,\n/* harmony export */   \"mdiThumbDownOutline\": () => /* binding */ mdiThumbDownOutline,\n/* harmony export */   \"mdiThumbUp\": () => /* binding */ mdiThumbUp,\n/* harmony export */   \"mdiThumbUpOutline\": () => /* binding */ mdiThumbUpOutline,\n/* harmony export */   \"mdiThumbsUpDown\": () => /* binding */ mdiThumbsUpDown,\n/* harmony export */   \"mdiTicket\": () => /* binding */ mdiTicket,\n/* harmony export */   \"mdiTicketAccount\": () => /* binding */ mdiTicketAccount,\n/* harmony export */   \"mdiTicketConfirmation\": () => /* binding */ mdiTicketConfirmation,\n/* harmony export */   \"mdiTicketConfirmationOutline\": () => /* binding */ mdiTicketConfirmationOutline,\n/* harmony export */   \"mdiTicketOutline\": () => /* binding */ mdiTicketOutline,\n/* harmony export */   \"mdiTicketPercent\": () => /* binding */ mdiTicketPercent,\n/* harmony export */   \"mdiTicketPercentOutline\": () => /* binding */ mdiTicketPercentOutline,\n/* harmony export */   \"mdiTie\": () => /* binding */ mdiTie,\n/* harmony export */   \"mdiTilde\": () => /* binding */ mdiTilde,\n/* harmony export */   \"mdiTimelapse\": () => /* binding */ mdiTimelapse,\n/* harmony export */   \"mdiTimeline\": () => /* binding */ mdiTimeline,\n/* harmony export */   \"mdiTimelineAlert\": () => /* binding */ mdiTimelineAlert,\n/* harmony export */   \"mdiTimelineAlertOutline\": () => /* binding */ mdiTimelineAlertOutline,\n/* harmony export */   \"mdiTimelineCheck\": () => /* binding */ mdiTimelineCheck,\n/* harmony export */   \"mdiTimelineCheckOutline\": () => /* binding */ mdiTimelineCheckOutline,\n/* harmony export */   \"mdiTimelineClock\": () => /* binding */ mdiTimelineClock,\n/* harmony export */   \"mdiTimelineClockOutline\": () => /* binding */ mdiTimelineClockOutline,\n/* harmony export */   \"mdiTimelineHelp\": () => /* binding */ mdiTimelineHelp,\n/* harmony export */   \"mdiTimelineHelpOutline\": () => /* binding */ mdiTimelineHelpOutline,\n/* harmony export */   \"mdiTimelineMinus\": () => /* binding */ mdiTimelineMinus,\n/* harmony export */   \"mdiTimelineMinusOutline\": () => /* binding */ mdiTimelineMinusOutline,\n/* harmony export */   \"mdiTimelineOutline\": () => /* binding */ mdiTimelineOutline,\n/* harmony export */   \"mdiTimelinePlus\": () => /* binding */ mdiTimelinePlus,\n/* harmony export */   \"mdiTimelinePlusOutline\": () => /* binding */ mdiTimelinePlusOutline,\n/* harmony export */   \"mdiTimelineRemove\": () => /* binding */ mdiTimelineRemove,\n/* harmony export */   \"mdiTimelineRemoveOutline\": () => /* binding */ mdiTimelineRemoveOutline,\n/* harmony export */   \"mdiTimelineText\": () => /* binding */ mdiTimelineText,\n/* harmony export */   \"mdiTimelineTextOutline\": () => /* binding */ mdiTimelineTextOutline,\n/* harmony export */   \"mdiTimer\": () => /* binding */ mdiTimer,\n/* harmony export */   \"mdiTimer10\": () => /* binding */ mdiTimer10,\n/* harmony export */   \"mdiTimer3\": () => /* binding */ mdiTimer3,\n/* harmony export */   \"mdiTimerOff\": () => /* binding */ mdiTimerOff,\n/* harmony export */   \"mdiTimerOffOutline\": () => /* binding */ mdiTimerOffOutline,\n/* harmony export */   \"mdiTimerOutline\": () => /* binding */ mdiTimerOutline,\n/* harmony export */   \"mdiTimerSand\": () => /* binding */ mdiTimerSand,\n/* harmony export */   \"mdiTimerSandEmpty\": () => /* binding */ mdiTimerSandEmpty,\n/* harmony export */   \"mdiTimerSandFull\": () => /* binding */ mdiTimerSandFull,\n/* harmony export */   \"mdiTimetable\": () => /* binding */ mdiTimetable,\n/* harmony export */   \"mdiToaster\": () => /* binding */ mdiToaster,\n/* harmony export */   \"mdiToasterOff\": () => /* binding */ mdiToasterOff,\n/* harmony export */   \"mdiToasterOven\": () => /* binding */ mdiToasterOven,\n/* harmony export */   \"mdiToggleSwitch\": () => /* binding */ mdiToggleSwitch,\n/* harmony export */   \"mdiToggleSwitchOff\": () => /* binding */ mdiToggleSwitchOff,\n/* harmony export */   \"mdiToggleSwitchOffOutline\": () => /* binding */ mdiToggleSwitchOffOutline,\n/* harmony export */   \"mdiToggleSwitchOutline\": () => /* binding */ mdiToggleSwitchOutline,\n/* harmony export */   \"mdiToilet\": () => /* binding */ mdiToilet,\n/* harmony export */   \"mdiToolbox\": () => /* binding */ mdiToolbox,\n/* harmony export */   \"mdiToolboxOutline\": () => /* binding */ mdiToolboxOutline,\n/* harmony export */   \"mdiTools\": () => /* binding */ mdiTools,\n/* harmony export */   \"mdiTooltip\": () => /* binding */ mdiTooltip,\n/* harmony export */   \"mdiTooltipAccount\": () => /* binding */ mdiTooltipAccount,\n/* harmony export */   \"mdiTooltipCheck\": () => /* binding */ mdiTooltipCheck,\n/* harmony export */   \"mdiTooltipCheckOutline\": () => /* binding */ mdiTooltipCheckOutline,\n/* harmony export */   \"mdiTooltipEdit\": () => /* binding */ mdiTooltipEdit,\n/* harmony export */   \"mdiTooltipEditOutline\": () => /* binding */ mdiTooltipEditOutline,\n/* harmony export */   \"mdiTooltipImage\": () => /* binding */ mdiTooltipImage,\n/* harmony export */   \"mdiTooltipImageOutline\": () => /* binding */ mdiTooltipImageOutline,\n/* harmony export */   \"mdiTooltipMinus\": () => /* binding */ mdiTooltipMinus,\n/* harmony export */   \"mdiTooltipMinusOutline\": () => /* binding */ mdiTooltipMinusOutline,\n/* harmony export */   \"mdiTooltipOutline\": () => /* binding */ mdiTooltipOutline,\n/* harmony export */   \"mdiTooltipPlus\": () => /* binding */ mdiTooltipPlus,\n/* harmony export */   \"mdiTooltipPlusOutline\": () => /* binding */ mdiTooltipPlusOutline,\n/* harmony export */   \"mdiTooltipRemove\": () => /* binding */ mdiTooltipRemove,\n/* harmony export */   \"mdiTooltipRemoveOutline\": () => /* binding */ mdiTooltipRemoveOutline,\n/* harmony export */   \"mdiTooltipText\": () => /* binding */ mdiTooltipText,\n/* harmony export */   \"mdiTooltipTextOutline\": () => /* binding */ mdiTooltipTextOutline,\n/* harmony export */   \"mdiTooth\": () => /* binding */ mdiTooth,\n/* harmony export */   \"mdiToothOutline\": () => /* binding */ mdiToothOutline,\n/* harmony export */   \"mdiToothbrush\": () => /* binding */ mdiToothbrush,\n/* harmony export */   \"mdiToothbrushElectric\": () => /* binding */ mdiToothbrushElectric,\n/* harmony export */   \"mdiToothbrushPaste\": () => /* binding */ mdiToothbrushPaste,\n/* harmony export */   \"mdiTorch\": () => /* binding */ mdiTorch,\n/* harmony export */   \"mdiTortoise\": () => /* binding */ mdiTortoise,\n/* harmony export */   \"mdiToslink\": () => /* binding */ mdiToslink,\n/* harmony export */   \"mdiTournament\": () => /* binding */ mdiTournament,\n/* harmony export */   \"mdiTowTruck\": () => /* binding */ mdiTowTruck,\n/* harmony export */   \"mdiTowerBeach\": () => /* binding */ mdiTowerBeach,\n/* harmony export */   \"mdiTowerFire\": () => /* binding */ mdiTowerFire,\n/* harmony export */   \"mdiToyBrick\": () => /* binding */ mdiToyBrick,\n/* harmony export */   \"mdiToyBrickMarker\": () => /* binding */ mdiToyBrickMarker,\n/* harmony export */   \"mdiToyBrickMarkerOutline\": () => /* binding */ mdiToyBrickMarkerOutline,\n/* harmony export */   \"mdiToyBrickMinus\": () => /* binding */ mdiToyBrickMinus,\n/* harmony export */   \"mdiToyBrickMinusOutline\": () => /* binding */ mdiToyBrickMinusOutline,\n/* harmony export */   \"mdiToyBrickOutline\": () => /* binding */ mdiToyBrickOutline,\n/* harmony export */   \"mdiToyBrickPlus\": () => /* binding */ mdiToyBrickPlus,\n/* harmony export */   \"mdiToyBrickPlusOutline\": () => /* binding */ mdiToyBrickPlusOutline,\n/* harmony export */   \"mdiToyBrickRemove\": () => /* binding */ mdiToyBrickRemove,\n/* harmony export */   \"mdiToyBrickRemoveOutline\": () => /* binding */ mdiToyBrickRemoveOutline,\n/* harmony export */   \"mdiToyBrickSearch\": () => /* binding */ mdiToyBrickSearch,\n/* harmony export */   \"mdiToyBrickSearchOutline\": () => /* binding */ mdiToyBrickSearchOutline,\n/* harmony export */   \"mdiTrackLight\": () => /* binding */ mdiTrackLight,\n/* harmony export */   \"mdiTrackpad\": () => /* binding */ mdiTrackpad,\n/* harmony export */   \"mdiTrackpadLock\": () => /* binding */ mdiTrackpadLock,\n/* harmony export */   \"mdiTractor\": () => /* binding */ mdiTractor,\n/* harmony export */   \"mdiTractorVariant\": () => /* binding */ mdiTractorVariant,\n/* harmony export */   \"mdiTrademark\": () => /* binding */ mdiTrademark,\n/* harmony export */   \"mdiTrafficCone\": () => /* binding */ mdiTrafficCone,\n/* harmony export */   \"mdiTrafficLight\": () => /* binding */ mdiTrafficLight,\n/* harmony export */   \"mdiTrain\": () => /* binding */ mdiTrain,\n/* harmony export */   \"mdiTrainCar\": () => /* binding */ mdiTrainCar,\n/* harmony export */   \"mdiTrainVariant\": () => /* binding */ mdiTrainVariant,\n/* harmony export */   \"mdiTram\": () => /* binding */ mdiTram,\n/* harmony export */   \"mdiTramSide\": () => /* binding */ mdiTramSide,\n/* harmony export */   \"mdiTranscribe\": () => /* binding */ mdiTranscribe,\n/* harmony export */   \"mdiTranscribeClose\": () => /* binding */ mdiTranscribeClose,\n/* harmony export */   \"mdiTransfer\": () => /* binding */ mdiTransfer,\n/* harmony export */   \"mdiTransferDown\": () => /* binding */ mdiTransferDown,\n/* harmony export */   \"mdiTransferLeft\": () => /* binding */ mdiTransferLeft,\n/* harmony export */   \"mdiTransferRight\": () => /* binding */ mdiTransferRight,\n/* harmony export */   \"mdiTransferUp\": () => /* binding */ mdiTransferUp,\n/* harmony export */   \"mdiTransitConnection\": () => /* binding */ mdiTransitConnection,\n/* harmony export */   \"mdiTransitConnectionHorizontal\": () => /* binding */ mdiTransitConnectionHorizontal,\n/* harmony export */   \"mdiTransitConnectionVariant\": () => /* binding */ mdiTransitConnectionVariant,\n/* harmony export */   \"mdiTransitDetour\": () => /* binding */ mdiTransitDetour,\n/* harmony export */   \"mdiTransitSkip\": () => /* binding */ mdiTransitSkip,\n/* harmony export */   \"mdiTransitTransfer\": () => /* binding */ mdiTransitTransfer,\n/* harmony export */   \"mdiTransition\": () => /* binding */ mdiTransition,\n/* harmony export */   \"mdiTransitionMasked\": () => /* binding */ mdiTransitionMasked,\n/* harmony export */   \"mdiTranslate\": () => /* binding */ mdiTranslate,\n/* harmony export */   \"mdiTranslateOff\": () => /* binding */ mdiTranslateOff,\n/* harmony export */   \"mdiTransmissionTower\": () => /* binding */ mdiTransmissionTower,\n/* harmony export */   \"mdiTrashCan\": () => /* binding */ mdiTrashCan,\n/* harmony export */   \"mdiTrashCanOutline\": () => /* binding */ mdiTrashCanOutline,\n/* harmony export */   \"mdiTray\": () => /* binding */ mdiTray,\n/* harmony export */   \"mdiTrayAlert\": () => /* binding */ mdiTrayAlert,\n/* harmony export */   \"mdiTrayFull\": () => /* binding */ mdiTrayFull,\n/* harmony export */   \"mdiTrayMinus\": () => /* binding */ mdiTrayMinus,\n/* harmony export */   \"mdiTrayPlus\": () => /* binding */ mdiTrayPlus,\n/* harmony export */   \"mdiTrayRemove\": () => /* binding */ mdiTrayRemove,\n/* harmony export */   \"mdiTreasureChest\": () => /* binding */ mdiTreasureChest,\n/* harmony export */   \"mdiTree\": () => /* binding */ mdiTree,\n/* harmony export */   \"mdiTreeOutline\": () => /* binding */ mdiTreeOutline,\n/* harmony export */   \"mdiTrello\": () => /* binding */ mdiTrello,\n/* harmony export */   \"mdiTrendingDown\": () => /* binding */ mdiTrendingDown,\n/* harmony export */   \"mdiTrendingNeutral\": () => /* binding */ mdiTrendingNeutral,\n/* harmony export */   \"mdiTrendingUp\": () => /* binding */ mdiTrendingUp,\n/* harmony export */   \"mdiTriangle\": () => /* binding */ mdiTriangle,\n/* harmony export */   \"mdiTriangleOutline\": () => /* binding */ mdiTriangleOutline,\n/* harmony export */   \"mdiTriangleWave\": () => /* binding */ mdiTriangleWave,\n/* harmony export */   \"mdiTriforce\": () => /* binding */ mdiTriforce,\n/* harmony export */   \"mdiTrophy\": () => /* binding */ mdiTrophy,\n/* harmony export */   \"mdiTrophyAward\": () => /* binding */ mdiTrophyAward,\n/* harmony export */   \"mdiTrophyBroken\": () => /* binding */ mdiTrophyBroken,\n/* harmony export */   \"mdiTrophyOutline\": () => /* binding */ mdiTrophyOutline,\n/* harmony export */   \"mdiTrophyVariant\": () => /* binding */ mdiTrophyVariant,\n/* harmony export */   \"mdiTrophyVariantOutline\": () => /* binding */ mdiTrophyVariantOutline,\n/* harmony export */   \"mdiTruck\": () => /* binding */ mdiTruck,\n/* harmony export */   \"mdiTruckCheck\": () => /* binding */ mdiTruckCheck,\n/* harmony export */   \"mdiTruckCheckOutline\": () => /* binding */ mdiTruckCheckOutline,\n/* harmony export */   \"mdiTruckDelivery\": () => /* binding */ mdiTruckDelivery,\n/* harmony export */   \"mdiTruckDeliveryOutline\": () => /* binding */ mdiTruckDeliveryOutline,\n/* harmony export */   \"mdiTruckFast\": () => /* binding */ mdiTruckFast,\n/* harmony export */   \"mdiTruckFastOutline\": () => /* binding */ mdiTruckFastOutline,\n/* harmony export */   \"mdiTruckOutline\": () => /* binding */ mdiTruckOutline,\n/* harmony export */   \"mdiTruckTrailer\": () => /* binding */ mdiTruckTrailer,\n/* harmony export */   \"mdiTrumpet\": () => /* binding */ mdiTrumpet,\n/* harmony export */   \"mdiTshirtCrew\": () => /* binding */ mdiTshirtCrew,\n/* harmony export */   \"mdiTshirtCrewOutline\": () => /* binding */ mdiTshirtCrewOutline,\n/* harmony export */   \"mdiTshirtV\": () => /* binding */ mdiTshirtV,\n/* harmony export */   \"mdiTshirtVOutline\": () => /* binding */ mdiTshirtVOutline,\n/* harmony export */   \"mdiTumbleDryer\": () => /* binding */ mdiTumbleDryer,\n/* harmony export */   \"mdiTumbleDryerAlert\": () => /* binding */ mdiTumbleDryerAlert,\n/* harmony export */   \"mdiTumbleDryerOff\": () => /* binding */ mdiTumbleDryerOff,\n/* harmony export */   \"mdiTune\": () => /* binding */ mdiTune,\n/* harmony export */   \"mdiTuneVariant\": () => /* binding */ mdiTuneVariant,\n/* harmony export */   \"mdiTuneVertical\": () => /* binding */ mdiTuneVertical,\n/* harmony export */   \"mdiTuneVerticalVariant\": () => /* binding */ mdiTuneVerticalVariant,\n/* harmony export */   \"mdiTurnstile\": () => /* binding */ mdiTurnstile,\n/* harmony export */   \"mdiTurnstileOutline\": () => /* binding */ mdiTurnstileOutline,\n/* harmony export */   \"mdiTurtle\": () => /* binding */ mdiTurtle,\n/* harmony export */   \"mdiTwitch\": () => /* binding */ mdiTwitch,\n/* harmony export */   \"mdiTwitter\": () => /* binding */ mdiTwitter,\n/* harmony export */   \"mdiTwitterRetweet\": () => /* binding */ mdiTwitterRetweet,\n/* harmony export */   \"mdiTwoFactorAuthentication\": () => /* binding */ mdiTwoFactorAuthentication,\n/* harmony export */   \"mdiTypewriter\": () => /* binding */ mdiTypewriter,\n/* harmony export */   \"mdiUbisoft\": () => /* binding */ mdiUbisoft,\n/* harmony export */   \"mdiUbuntu\": () => /* binding */ mdiUbuntu,\n/* harmony export */   \"mdiUfo\": () => /* binding */ mdiUfo,\n/* harmony export */   \"mdiUfoOutline\": () => /* binding */ mdiUfoOutline,\n/* harmony export */   \"mdiUltraHighDefinition\": () => /* binding */ mdiUltraHighDefinition,\n/* harmony export */   \"mdiUmbraco\": () => /* binding */ mdiUmbraco,\n/* harmony export */   \"mdiUmbrella\": () => /* binding */ mdiUmbrella,\n/* harmony export */   \"mdiUmbrellaClosed\": () => /* binding */ mdiUmbrellaClosed,\n/* harmony export */   \"mdiUmbrellaClosedOutline\": () => /* binding */ mdiUmbrellaClosedOutline,\n/* harmony export */   \"mdiUmbrellaClosedVariant\": () => /* binding */ mdiUmbrellaClosedVariant,\n/* harmony export */   \"mdiUmbrellaOutline\": () => /* binding */ mdiUmbrellaOutline,\n/* harmony export */   \"mdiUndo\": () => /* binding */ mdiUndo,\n/* harmony export */   \"mdiUndoVariant\": () => /* binding */ mdiUndoVariant,\n/* harmony export */   \"mdiUnfoldLessHorizontal\": () => /* binding */ mdiUnfoldLessHorizontal,\n/* harmony export */   \"mdiUnfoldLessVertical\": () => /* binding */ mdiUnfoldLessVertical,\n/* harmony export */   \"mdiUnfoldMoreHorizontal\": () => /* binding */ mdiUnfoldMoreHorizontal,\n/* harmony export */   \"mdiUnfoldMoreVertical\": () => /* binding */ mdiUnfoldMoreVertical,\n/* harmony export */   \"mdiUngroup\": () => /* binding */ mdiUngroup,\n/* harmony export */   \"mdiUnicode\": () => /* binding */ mdiUnicode,\n/* harmony export */   \"mdiUnicorn\": () => /* binding */ mdiUnicorn,\n/* harmony export */   \"mdiUnicornVariant\": () => /* binding */ mdiUnicornVariant,\n/* harmony export */   \"mdiUnicycle\": () => /* binding */ mdiUnicycle,\n/* harmony export */   \"mdiUnity\": () => /* binding */ mdiUnity,\n/* harmony export */   \"mdiUnreal\": () => /* binding */ mdiUnreal,\n/* harmony export */   \"mdiUntappd\": () => /* binding */ mdiUntappd,\n/* harmony export */   \"mdiUpdate\": () => /* binding */ mdiUpdate,\n/* harmony export */   \"mdiUpload\": () => /* binding */ mdiUpload,\n/* harmony export */   \"mdiUploadLock\": () => /* binding */ mdiUploadLock,\n/* harmony export */   \"mdiUploadLockOutline\": () => /* binding */ mdiUploadLockOutline,\n/* harmony export */   \"mdiUploadMultiple\": () => /* binding */ mdiUploadMultiple,\n/* harmony export */   \"mdiUploadNetwork\": () => /* binding */ mdiUploadNetwork,\n/* harmony export */   \"mdiUploadNetworkOutline\": () => /* binding */ mdiUploadNetworkOutline,\n/* harmony export */   \"mdiUploadOff\": () => /* binding */ mdiUploadOff,\n/* harmony export */   \"mdiUploadOffOutline\": () => /* binding */ mdiUploadOffOutline,\n/* harmony export */   \"mdiUploadOutline\": () => /* binding */ mdiUploadOutline,\n/* harmony export */   \"mdiUsb\": () => /* binding */ mdiUsb,\n/* harmony export */   \"mdiUsbFlashDrive\": () => /* binding */ mdiUsbFlashDrive,\n/* harmony export */   \"mdiUsbFlashDriveOutline\": () => /* binding */ mdiUsbFlashDriveOutline,\n/* harmony export */   \"mdiUsbPort\": () => /* binding */ mdiUsbPort,\n/* harmony export */   \"mdiValve\": () => /* binding */ mdiValve,\n/* harmony export */   \"mdiValveClosed\": () => /* binding */ mdiValveClosed,\n/* harmony export */   \"mdiValveOpen\": () => /* binding */ mdiValveOpen,\n/* harmony export */   \"mdiVanPassenger\": () => /* binding */ mdiVanPassenger,\n/* harmony export */   \"mdiVanUtility\": () => /* binding */ mdiVanUtility,\n/* harmony export */   \"mdiVanish\": () => /* binding */ mdiVanish,\n/* harmony export */   \"mdiVanishQuarter\": () => /* binding */ mdiVanishQuarter,\n/* harmony export */   \"mdiVanityLight\": () => /* binding */ mdiVanityLight,\n/* harmony export */   \"mdiVariable\": () => /* binding */ mdiVariable,\n/* harmony export */   \"mdiVariableBox\": () => /* binding */ mdiVariableBox,\n/* harmony export */   \"mdiVectorArrangeAbove\": () => /* binding */ mdiVectorArrangeAbove,\n/* harmony export */   \"mdiVectorArrangeBelow\": () => /* binding */ mdiVectorArrangeBelow,\n/* harmony export */   \"mdiVectorBezier\": () => /* binding */ mdiVectorBezier,\n/* harmony export */   \"mdiVectorCircle\": () => /* binding */ mdiVectorCircle,\n/* harmony export */   \"mdiVectorCircleVariant\": () => /* binding */ mdiVectorCircleVariant,\n/* harmony export */   \"mdiVectorCombine\": () => /* binding */ mdiVectorCombine,\n/* harmony export */   \"mdiVectorCurve\": () => /* binding */ mdiVectorCurve,\n/* harmony export */   \"mdiVectorDifference\": () => /* binding */ mdiVectorDifference,\n/* harmony export */   \"mdiVectorDifferenceAb\": () => /* binding */ mdiVectorDifferenceAb,\n/* harmony export */   \"mdiVectorDifferenceBa\": () => /* binding */ mdiVectorDifferenceBa,\n/* harmony export */   \"mdiVectorEllipse\": () => /* binding */ mdiVectorEllipse,\n/* harmony export */   \"mdiVectorIntersection\": () => /* binding */ mdiVectorIntersection,\n/* harmony export */   \"mdiVectorLine\": () => /* binding */ mdiVectorLine,\n/* harmony export */   \"mdiVectorLink\": () => /* binding */ mdiVectorLink,\n/* harmony export */   \"mdiVectorPoint\": () => /* binding */ mdiVectorPoint,\n/* harmony export */   \"mdiVectorPolygon\": () => /* binding */ mdiVectorPolygon,\n/* harmony export */   \"mdiVectorPolyline\": () => /* binding */ mdiVectorPolyline,\n/* harmony export */   \"mdiVectorPolylineEdit\": () => /* binding */ mdiVectorPolylineEdit,\n/* harmony export */   \"mdiVectorPolylineMinus\": () => /* binding */ mdiVectorPolylineMinus,\n/* harmony export */   \"mdiVectorPolylinePlus\": () => /* binding */ mdiVectorPolylinePlus,\n/* harmony export */   \"mdiVectorPolylineRemove\": () => /* binding */ mdiVectorPolylineRemove,\n/* harmony export */   \"mdiVectorRadius\": () => /* binding */ mdiVectorRadius,\n/* harmony export */   \"mdiVectorRectangle\": () => /* binding */ mdiVectorRectangle,\n/* harmony export */   \"mdiVectorSelection\": () => /* binding */ mdiVectorSelection,\n/* harmony export */   \"mdiVectorSquare\": () => /* binding */ mdiVectorSquare,\n/* harmony export */   \"mdiVectorTriangle\": () => /* binding */ mdiVectorTriangle,\n/* harmony export */   \"mdiVectorUnion\": () => /* binding */ mdiVectorUnion,\n/* harmony export */   \"mdiVhs\": () => /* binding */ mdiVhs,\n/* harmony export */   \"mdiVibrate\": () => /* binding */ mdiVibrate,\n/* harmony export */   \"mdiVibrateOff\": () => /* binding */ mdiVibrateOff,\n/* harmony export */   \"mdiVideo\": () => /* binding */ mdiVideo,\n/* harmony export */   \"mdiVideo3d\": () => /* binding */ mdiVideo3d,\n/* harmony export */   \"mdiVideo3dOff\": () => /* binding */ mdiVideo3dOff,\n/* harmony export */   \"mdiVideo3dVariant\": () => /* binding */ mdiVideo3dVariant,\n/* harmony export */   \"mdiVideo4kBox\": () => /* binding */ mdiVideo4kBox,\n/* harmony export */   \"mdiVideoAccount\": () => /* binding */ mdiVideoAccount,\n/* harmony export */   \"mdiVideoBox\": () => /* binding */ mdiVideoBox,\n/* harmony export */   \"mdiVideoBoxOff\": () => /* binding */ mdiVideoBoxOff,\n/* harmony export */   \"mdiVideoCheck\": () => /* binding */ mdiVideoCheck,\n/* harmony export */   \"mdiVideoCheckOutline\": () => /* binding */ mdiVideoCheckOutline,\n/* harmony export */   \"mdiVideoHighDefinition\": () => /* binding */ mdiVideoHighDefinition,\n/* harmony export */   \"mdiVideoImage\": () => /* binding */ mdiVideoImage,\n/* harmony export */   \"mdiVideoInputAntenna\": () => /* binding */ mdiVideoInputAntenna,\n/* harmony export */   \"mdiVideoInputComponent\": () => /* binding */ mdiVideoInputComponent,\n/* harmony export */   \"mdiVideoInputHdmi\": () => /* binding */ mdiVideoInputHdmi,\n/* harmony export */   \"mdiVideoInputScart\": () => /* binding */ mdiVideoInputScart,\n/* harmony export */   \"mdiVideoInputSvideo\": () => /* binding */ mdiVideoInputSvideo,\n/* harmony export */   \"mdiVideoMinus\": () => /* binding */ mdiVideoMinus,\n/* harmony export */   \"mdiVideoMinusOutline\": () => /* binding */ mdiVideoMinusOutline,\n/* harmony export */   \"mdiVideoOff\": () => /* binding */ mdiVideoOff,\n/* harmony export */   \"mdiVideoOffOutline\": () => /* binding */ mdiVideoOffOutline,\n/* harmony export */   \"mdiVideoOutline\": () => /* binding */ mdiVideoOutline,\n/* harmony export */   \"mdiVideoPlus\": () => /* binding */ mdiVideoPlus,\n/* harmony export */   \"mdiVideoPlusOutline\": () => /* binding */ mdiVideoPlusOutline,\n/* harmony export */   \"mdiVideoStabilization\": () => /* binding */ mdiVideoStabilization,\n/* harmony export */   \"mdiVideoSwitch\": () => /* binding */ mdiVideoSwitch,\n/* harmony export */   \"mdiVideoSwitchOutline\": () => /* binding */ mdiVideoSwitchOutline,\n/* harmony export */   \"mdiVideoVintage\": () => /* binding */ mdiVideoVintage,\n/* harmony export */   \"mdiVideoWireless\": () => /* binding */ mdiVideoWireless,\n/* harmony export */   \"mdiVideoWirelessOutline\": () => /* binding */ mdiVideoWirelessOutline,\n/* harmony export */   \"mdiViewAgenda\": () => /* binding */ mdiViewAgenda,\n/* harmony export */   \"mdiViewAgendaOutline\": () => /* binding */ mdiViewAgendaOutline,\n/* harmony export */   \"mdiViewArray\": () => /* binding */ mdiViewArray,\n/* harmony export */   \"mdiViewArrayOutline\": () => /* binding */ mdiViewArrayOutline,\n/* harmony export */   \"mdiViewCarousel\": () => /* binding */ mdiViewCarousel,\n/* harmony export */   \"mdiViewCarouselOutline\": () => /* binding */ mdiViewCarouselOutline,\n/* harmony export */   \"mdiViewColumn\": () => /* binding */ mdiViewColumn,\n/* harmony export */   \"mdiViewColumnOutline\": () => /* binding */ mdiViewColumnOutline,\n/* harmony export */   \"mdiViewComfy\": () => /* binding */ mdiViewComfy,\n/* harmony export */   \"mdiViewComfyOutline\": () => /* binding */ mdiViewComfyOutline,\n/* harmony export */   \"mdiViewCompact\": () => /* binding */ mdiViewCompact,\n/* harmony export */   \"mdiViewCompactOutline\": () => /* binding */ mdiViewCompactOutline,\n/* harmony export */   \"mdiViewDashboard\": () => /* binding */ mdiViewDashboard,\n/* harmony export */   \"mdiViewDashboardOutline\": () => /* binding */ mdiViewDashboardOutline,\n/* harmony export */   \"mdiViewDashboardVariant\": () => /* binding */ mdiViewDashboardVariant,\n/* harmony export */   \"mdiViewDashboardVariantOutline\": () => /* binding */ mdiViewDashboardVariantOutline,\n/* harmony export */   \"mdiViewDay\": () => /* binding */ mdiViewDay,\n/* harmony export */   \"mdiViewDayOutline\": () => /* binding */ mdiViewDayOutline,\n/* harmony export */   \"mdiViewGrid\": () => /* binding */ mdiViewGrid,\n/* harmony export */   \"mdiViewGridOutline\": () => /* binding */ mdiViewGridOutline,\n/* harmony export */   \"mdiViewGridPlus\": () => /* binding */ mdiViewGridPlus,\n/* harmony export */   \"mdiViewGridPlusOutline\": () => /* binding */ mdiViewGridPlusOutline,\n/* harmony export */   \"mdiViewHeadline\": () => /* binding */ mdiViewHeadline,\n/* harmony export */   \"mdiViewList\": () => /* binding */ mdiViewList,\n/* harmony export */   \"mdiViewListOutline\": () => /* binding */ mdiViewListOutline,\n/* harmony export */   \"mdiViewModule\": () => /* binding */ mdiViewModule,\n/* harmony export */   \"mdiViewModuleOutline\": () => /* binding */ mdiViewModuleOutline,\n/* harmony export */   \"mdiViewParallel\": () => /* binding */ mdiViewParallel,\n/* harmony export */   \"mdiViewParallelOutline\": () => /* binding */ mdiViewParallelOutline,\n/* harmony export */   \"mdiViewQuilt\": () => /* binding */ mdiViewQuilt,\n/* harmony export */   \"mdiViewQuiltOutline\": () => /* binding */ mdiViewQuiltOutline,\n/* harmony export */   \"mdiViewSequential\": () => /* binding */ mdiViewSequential,\n/* harmony export */   \"mdiViewSequentialOutline\": () => /* binding */ mdiViewSequentialOutline,\n/* harmony export */   \"mdiViewSplitHorizontal\": () => /* binding */ mdiViewSplitHorizontal,\n/* harmony export */   \"mdiViewSplitVertical\": () => /* binding */ mdiViewSplitVertical,\n/* harmony export */   \"mdiViewStream\": () => /* binding */ mdiViewStream,\n/* harmony export */   \"mdiViewStreamOutline\": () => /* binding */ mdiViewStreamOutline,\n/* harmony export */   \"mdiViewWeek\": () => /* binding */ mdiViewWeek,\n/* harmony export */   \"mdiViewWeekOutline\": () => /* binding */ mdiViewWeekOutline,\n/* harmony export */   \"mdiVimeo\": () => /* binding */ mdiVimeo,\n/* harmony export */   \"mdiViolin\": () => /* binding */ mdiViolin,\n/* harmony export */   \"mdiVirtualReality\": () => /* binding */ mdiVirtualReality,\n/* harmony export */   \"mdiVirus\": () => /* binding */ mdiVirus,\n/* harmony export */   \"mdiVirusOutline\": () => /* binding */ mdiVirusOutline,\n/* harmony export */   \"mdiVk\": () => /* binding */ mdiVk,\n/* harmony export */   \"mdiVlc\": () => /* binding */ mdiVlc,\n/* harmony export */   \"mdiVoiceOff\": () => /* binding */ mdiVoiceOff,\n/* harmony export */   \"mdiVoicemail\": () => /* binding */ mdiVoicemail,\n/* harmony export */   \"mdiVolleyball\": () => /* binding */ mdiVolleyball,\n/* harmony export */   \"mdiVolumeHigh\": () => /* binding */ mdiVolumeHigh,\n/* harmony export */   \"mdiVolumeLow\": () => /* binding */ mdiVolumeLow,\n/* harmony export */   \"mdiVolumeMedium\": () => /* binding */ mdiVolumeMedium,\n/* harmony export */   \"mdiVolumeMinus\": () => /* binding */ mdiVolumeMinus,\n/* harmony export */   \"mdiVolumeMute\": () => /* binding */ mdiVolumeMute,\n/* harmony export */   \"mdiVolumeOff\": () => /* binding */ mdiVolumeOff,\n/* harmony export */   \"mdiVolumePlus\": () => /* binding */ mdiVolumePlus,\n/* harmony export */   \"mdiVolumeSource\": () => /* binding */ mdiVolumeSource,\n/* harmony export */   \"mdiVolumeVariantOff\": () => /* binding */ mdiVolumeVariantOff,\n/* harmony export */   \"mdiVolumeVibrate\": () => /* binding */ mdiVolumeVibrate,\n/* harmony export */   \"mdiVote\": () => /* binding */ mdiVote,\n/* harmony export */   \"mdiVoteOutline\": () => /* binding */ mdiVoteOutline,\n/* harmony export */   \"mdiVpn\": () => /* binding */ mdiVpn,\n/* harmony export */   \"mdiVuejs\": () => /* binding */ mdiVuejs,\n/* harmony export */   \"mdiVuetify\": () => /* binding */ mdiVuetify,\n/* harmony export */   \"mdiWalk\": () => /* binding */ mdiWalk,\n/* harmony export */   \"mdiWall\": () => /* binding */ mdiWall,\n/* harmony export */   \"mdiWallSconce\": () => /* binding */ mdiWallSconce,\n/* harmony export */   \"mdiWallSconceFlat\": () => /* binding */ mdiWallSconceFlat,\n/* harmony export */   \"mdiWallSconceFlatVariant\": () => /* binding */ mdiWallSconceFlatVariant,\n/* harmony export */   \"mdiWallSconceRound\": () => /* binding */ mdiWallSconceRound,\n/* harmony export */   \"mdiWallSconceRoundVariant\": () => /* binding */ mdiWallSconceRoundVariant,\n/* harmony export */   \"mdiWallet\": () => /* binding */ mdiWallet,\n/* harmony export */   \"mdiWalletGiftcard\": () => /* binding */ mdiWalletGiftcard,\n/* harmony export */   \"mdiWalletMembership\": () => /* binding */ mdiWalletMembership,\n/* harmony export */   \"mdiWalletOutline\": () => /* binding */ mdiWalletOutline,\n/* harmony export */   \"mdiWalletPlus\": () => /* binding */ mdiWalletPlus,\n/* harmony export */   \"mdiWalletPlusOutline\": () => /* binding */ mdiWalletPlusOutline,\n/* harmony export */   \"mdiWalletTravel\": () => /* binding */ mdiWalletTravel,\n/* harmony export */   \"mdiWallpaper\": () => /* binding */ mdiWallpaper,\n/* harmony export */   \"mdiWan\": () => /* binding */ mdiWan,\n/* harmony export */   \"mdiWardrobe\": () => /* binding */ mdiWardrobe,\n/* harmony export */   \"mdiWardrobeOutline\": () => /* binding */ mdiWardrobeOutline,\n/* harmony export */   \"mdiWarehouse\": () => /* binding */ mdiWarehouse,\n/* harmony export */   \"mdiWashingMachine\": () => /* binding */ mdiWashingMachine,\n/* harmony export */   \"mdiWashingMachineAlert\": () => /* binding */ mdiWashingMachineAlert,\n/* harmony export */   \"mdiWashingMachineOff\": () => /* binding */ mdiWashingMachineOff,\n/* harmony export */   \"mdiWatch\": () => /* binding */ mdiWatch,\n/* harmony export */   \"mdiWatchExport\": () => /* binding */ mdiWatchExport,\n/* harmony export */   \"mdiWatchExportVariant\": () => /* binding */ mdiWatchExportVariant,\n/* harmony export */   \"mdiWatchImport\": () => /* binding */ mdiWatchImport,\n/* harmony export */   \"mdiWatchImportVariant\": () => /* binding */ mdiWatchImportVariant,\n/* harmony export */   \"mdiWatchVariant\": () => /* binding */ mdiWatchVariant,\n/* harmony export */   \"mdiWatchVibrate\": () => /* binding */ mdiWatchVibrate,\n/* harmony export */   \"mdiWatchVibrateOff\": () => /* binding */ mdiWatchVibrateOff,\n/* harmony export */   \"mdiWater\": () => /* binding */ mdiWater,\n/* harmony export */   \"mdiWaterAlert\": () => /* binding */ mdiWaterAlert,\n/* harmony export */   \"mdiWaterAlertOutline\": () => /* binding */ mdiWaterAlertOutline,\n/* harmony export */   \"mdiWaterBoiler\": () => /* binding */ mdiWaterBoiler,\n/* harmony export */   \"mdiWaterBoilerAlert\": () => /* binding */ mdiWaterBoilerAlert,\n/* harmony export */   \"mdiWaterBoilerOff\": () => /* binding */ mdiWaterBoilerOff,\n/* harmony export */   \"mdiWaterCheck\": () => /* binding */ mdiWaterCheck,\n/* harmony export */   \"mdiWaterCheckOutline\": () => /* binding */ mdiWaterCheckOutline,\n/* harmony export */   \"mdiWaterMinus\": () => /* binding */ mdiWaterMinus,\n/* harmony export */   \"mdiWaterMinusOutline\": () => /* binding */ mdiWaterMinusOutline,\n/* harmony export */   \"mdiWaterOff\": () => /* binding */ mdiWaterOff,\n/* harmony export */   \"mdiWaterOffOutline\": () => /* binding */ mdiWaterOffOutline,\n/* harmony export */   \"mdiWaterOutline\": () => /* binding */ mdiWaterOutline,\n/* harmony export */   \"mdiWaterPercent\": () => /* binding */ mdiWaterPercent,\n/* harmony export */   \"mdiWaterPercentAlert\": () => /* binding */ mdiWaterPercentAlert,\n/* harmony export */   \"mdiWaterPlus\": () => /* binding */ mdiWaterPlus,\n/* harmony export */   \"mdiWaterPlusOutline\": () => /* binding */ mdiWaterPlusOutline,\n/* harmony export */   \"mdiWaterPolo\": () => /* binding */ mdiWaterPolo,\n/* harmony export */   \"mdiWaterPump\": () => /* binding */ mdiWaterPump,\n/* harmony export */   \"mdiWaterPumpOff\": () => /* binding */ mdiWaterPumpOff,\n/* harmony export */   \"mdiWaterRemove\": () => /* binding */ mdiWaterRemove,\n/* harmony export */   \"mdiWaterRemoveOutline\": () => /* binding */ mdiWaterRemoveOutline,\n/* harmony export */   \"mdiWaterWell\": () => /* binding */ mdiWaterWell,\n/* harmony export */   \"mdiWaterWellOutline\": () => /* binding */ mdiWaterWellOutline,\n/* harmony export */   \"mdiWateringCan\": () => /* binding */ mdiWateringCan,\n/* harmony export */   \"mdiWateringCanOutline\": () => /* binding */ mdiWateringCanOutline,\n/* harmony export */   \"mdiWatermark\": () => /* binding */ mdiWatermark,\n/* harmony export */   \"mdiWave\": () => /* binding */ mdiWave,\n/* harmony export */   \"mdiWaveform\": () => /* binding */ mdiWaveform,\n/* harmony export */   \"mdiWaves\": () => /* binding */ mdiWaves,\n/* harmony export */   \"mdiWaze\": () => /* binding */ mdiWaze,\n/* harmony export */   \"mdiWeatherCloudy\": () => /* binding */ mdiWeatherCloudy,\n/* harmony export */   \"mdiWeatherCloudyAlert\": () => /* binding */ mdiWeatherCloudyAlert,\n/* harmony export */   \"mdiWeatherCloudyArrowRight\": () => /* binding */ mdiWeatherCloudyArrowRight,\n/* harmony export */   \"mdiWeatherFog\": () => /* binding */ mdiWeatherFog,\n/* harmony export */   \"mdiWeatherHail\": () => /* binding */ mdiWeatherHail,\n/* harmony export */   \"mdiWeatherHazy\": () => /* binding */ mdiWeatherHazy,\n/* harmony export */   \"mdiWeatherHurricane\": () => /* binding */ mdiWeatherHurricane,\n/* harmony export */   \"mdiWeatherLightning\": () => /* binding */ mdiWeatherLightning,\n/* harmony export */   \"mdiWeatherLightningRainy\": () => /* binding */ mdiWeatherLightningRainy,\n/* harmony export */   \"mdiWeatherNight\": () => /* binding */ mdiWeatherNight,\n/* harmony export */   \"mdiWeatherNightPartlyCloudy\": () => /* binding */ mdiWeatherNightPartlyCloudy,\n/* harmony export */   \"mdiWeatherPartlyCloudy\": () => /* binding */ mdiWeatherPartlyCloudy,\n/* harmony export */   \"mdiWeatherPartlyLightning\": () => /* binding */ mdiWeatherPartlyLightning,\n/* harmony export */   \"mdiWeatherPartlyRainy\": () => /* binding */ mdiWeatherPartlyRainy,\n/* harmony export */   \"mdiWeatherPartlySnowy\": () => /* binding */ mdiWeatherPartlySnowy,\n/* harmony export */   \"mdiWeatherPartlySnowyRainy\": () => /* binding */ mdiWeatherPartlySnowyRainy,\n/* harmony export */   \"mdiWeatherPouring\": () => /* binding */ mdiWeatherPouring,\n/* harmony export */   \"mdiWeatherRainy\": () => /* binding */ mdiWeatherRainy,\n/* harmony export */   \"mdiWeatherSnowy\": () => /* binding */ mdiWeatherSnowy,\n/* harmony export */   \"mdiWeatherSnowyHeavy\": () => /* binding */ mdiWeatherSnowyHeavy,\n/* harmony export */   \"mdiWeatherSnowyRainy\": () => /* binding */ mdiWeatherSnowyRainy,\n/* harmony export */   \"mdiWeatherSunny\": () => /* binding */ mdiWeatherSunny,\n/* harmony export */   \"mdiWeatherSunnyAlert\": () => /* binding */ mdiWeatherSunnyAlert,\n/* harmony export */   \"mdiWeatherSunnyOff\": () => /* binding */ mdiWeatherSunnyOff,\n/* harmony export */   \"mdiWeatherSunset\": () => /* binding */ mdiWeatherSunset,\n/* harmony export */   \"mdiWeatherSunsetDown\": () => /* binding */ mdiWeatherSunsetDown,\n/* harmony export */   \"mdiWeatherSunsetUp\": () => /* binding */ mdiWeatherSunsetUp,\n/* harmony export */   \"mdiWeatherTornado\": () => /* binding */ mdiWeatherTornado,\n/* harmony export */   \"mdiWeatherWindy\": () => /* binding */ mdiWeatherWindy,\n/* harmony export */   \"mdiWeatherWindyVariant\": () => /* binding */ mdiWeatherWindyVariant,\n/* harmony export */   \"mdiWeb\": () => /* binding */ mdiWeb,\n/* harmony export */   \"mdiWebBox\": () => /* binding */ mdiWebBox,\n/* harmony export */   \"mdiWebClock\": () => /* binding */ mdiWebClock,\n/* harmony export */   \"mdiWebcam\": () => /* binding */ mdiWebcam,\n/* harmony export */   \"mdiWebhook\": () => /* binding */ mdiWebhook,\n/* harmony export */   \"mdiWebpack\": () => /* binding */ mdiWebpack,\n/* harmony export */   \"mdiWebrtc\": () => /* binding */ mdiWebrtc,\n/* harmony export */   \"mdiWechat\": () => /* binding */ mdiWechat,\n/* harmony export */   \"mdiWeight\": () => /* binding */ mdiWeight,\n/* harmony export */   \"mdiWeightGram\": () => /* binding */ mdiWeightGram,\n/* harmony export */   \"mdiWeightKilogram\": () => /* binding */ mdiWeightKilogram,\n/* harmony export */   \"mdiWeightLifter\": () => /* binding */ mdiWeightLifter,\n/* harmony export */   \"mdiWeightPound\": () => /* binding */ mdiWeightPound,\n/* harmony export */   \"mdiWhatsapp\": () => /* binding */ mdiWhatsapp,\n/* harmony export */   \"mdiWheelBarrow\": () => /* binding */ mdiWheelBarrow,\n/* harmony export */   \"mdiWheelchairAccessibility\": () => /* binding */ mdiWheelchairAccessibility,\n/* harmony export */   \"mdiWhistle\": () => /* binding */ mdiWhistle,\n/* harmony export */   \"mdiWhistleOutline\": () => /* binding */ mdiWhistleOutline,\n/* harmony export */   \"mdiWhiteBalanceAuto\": () => /* binding */ mdiWhiteBalanceAuto,\n/* harmony export */   \"mdiWhiteBalanceIncandescent\": () => /* binding */ mdiWhiteBalanceIncandescent,\n/* harmony export */   \"mdiWhiteBalanceIridescent\": () => /* binding */ mdiWhiteBalanceIridescent,\n/* harmony export */   \"mdiWhiteBalanceSunny\": () => /* binding */ mdiWhiteBalanceSunny,\n/* harmony export */   \"mdiWidgets\": () => /* binding */ mdiWidgets,\n/* harmony export */   \"mdiWidgetsOutline\": () => /* binding */ mdiWidgetsOutline,\n/* harmony export */   \"mdiWifi\": () => /* binding */ mdiWifi,\n/* harmony export */   \"mdiWifiOff\": () => /* binding */ mdiWifiOff,\n/* harmony export */   \"mdiWifiStar\": () => /* binding */ mdiWifiStar,\n/* harmony export */   \"mdiWifiStrength1\": () => /* binding */ mdiWifiStrength1,\n/* harmony export */   \"mdiWifiStrength1Alert\": () => /* binding */ mdiWifiStrength1Alert,\n/* harmony export */   \"mdiWifiStrength1Lock\": () => /* binding */ mdiWifiStrength1Lock,\n/* harmony export */   \"mdiWifiStrength2\": () => /* binding */ mdiWifiStrength2,\n/* harmony export */   \"mdiWifiStrength2Alert\": () => /* binding */ mdiWifiStrength2Alert,\n/* harmony export */   \"mdiWifiStrength2Lock\": () => /* binding */ mdiWifiStrength2Lock,\n/* harmony export */   \"mdiWifiStrength3\": () => /* binding */ mdiWifiStrength3,\n/* harmony export */   \"mdiWifiStrength3Alert\": () => /* binding */ mdiWifiStrength3Alert,\n/* harmony export */   \"mdiWifiStrength3Lock\": () => /* binding */ mdiWifiStrength3Lock,\n/* harmony export */   \"mdiWifiStrength4\": () => /* binding */ mdiWifiStrength4,\n/* harmony export */   \"mdiWifiStrength4Alert\": () => /* binding */ mdiWifiStrength4Alert,\n/* harmony export */   \"mdiWifiStrength4Lock\": () => /* binding */ mdiWifiStrength4Lock,\n/* harmony export */   \"mdiWifiStrengthAlertOutline\": () => /* binding */ mdiWifiStrengthAlertOutline,\n/* harmony export */   \"mdiWifiStrengthLockOutline\": () => /* binding */ mdiWifiStrengthLockOutline,\n/* harmony export */   \"mdiWifiStrengthOff\": () => /* binding */ mdiWifiStrengthOff,\n/* harmony export */   \"mdiWifiStrengthOffOutline\": () => /* binding */ mdiWifiStrengthOffOutline,\n/* harmony export */   \"mdiWifiStrengthOutline\": () => /* binding */ mdiWifiStrengthOutline,\n/* harmony export */   \"mdiWikipedia\": () => /* binding */ mdiWikipedia,\n/* harmony export */   \"mdiWindTurbine\": () => /* binding */ mdiWindTurbine,\n/* harmony export */   \"mdiWindowClose\": () => /* binding */ mdiWindowClose,\n/* harmony export */   \"mdiWindowClosed\": () => /* binding */ mdiWindowClosed,\n/* harmony export */   \"mdiWindowClosedVariant\": () => /* binding */ mdiWindowClosedVariant,\n/* harmony export */   \"mdiWindowMaximize\": () => /* binding */ mdiWindowMaximize,\n/* harmony export */   \"mdiWindowMinimize\": () => /* binding */ mdiWindowMinimize,\n/* harmony export */   \"mdiWindowOpen\": () => /* binding */ mdiWindowOpen,\n/* harmony export */   \"mdiWindowOpenVariant\": () => /* binding */ mdiWindowOpenVariant,\n/* harmony export */   \"mdiWindowRestore\": () => /* binding */ mdiWindowRestore,\n/* harmony export */   \"mdiWindowShutter\": () => /* binding */ mdiWindowShutter,\n/* harmony export */   \"mdiWindowShutterAlert\": () => /* binding */ mdiWindowShutterAlert,\n/* harmony export */   \"mdiWindowShutterOpen\": () => /* binding */ mdiWindowShutterOpen,\n/* harmony export */   \"mdiWindsock\": () => /* binding */ mdiWindsock,\n/* harmony export */   \"mdiWiper\": () => /* binding */ mdiWiper,\n/* harmony export */   \"mdiWiperWash\": () => /* binding */ mdiWiperWash,\n/* harmony export */   \"mdiWizardHat\": () => /* binding */ mdiWizardHat,\n/* harmony export */   \"mdiWordpress\": () => /* binding */ mdiWordpress,\n/* harmony export */   \"mdiWrap\": () => /* binding */ mdiWrap,\n/* harmony export */   \"mdiWrapDisabled\": () => /* binding */ mdiWrapDisabled,\n/* harmony export */   \"mdiWrench\": () => /* binding */ mdiWrench,\n/* harmony export */   \"mdiWrenchOutline\": () => /* binding */ mdiWrenchOutline,\n/* harmony export */   \"mdiXamarin\": () => /* binding */ mdiXamarin,\n/* harmony export */   \"mdiXamarinOutline\": () => /* binding */ mdiXamarinOutline,\n/* harmony export */   \"mdiXing\": () => /* binding */ mdiXing,\n/* harmony export */   \"mdiXml\": () => /* binding */ mdiXml,\n/* harmony export */   \"mdiXmpp\": () => /* binding */ mdiXmpp,\n/* harmony export */   \"mdiYCombinator\": () => /* binding */ mdiYCombinator,\n/* harmony export */   \"mdiYahoo\": () => /* binding */ mdiYahoo,\n/* harmony export */   \"mdiYeast\": () => /* binding */ mdiYeast,\n/* harmony export */   \"mdiYinYang\": () => /* binding */ mdiYinYang,\n/* harmony export */   \"mdiYoga\": () => /* binding */ mdiYoga,\n/* harmony export */   \"mdiYoutube\": () => /* binding */ mdiYoutube,\n/* harmony export */   \"mdiYoutubeGaming\": () => /* binding */ mdiYoutubeGaming,\n/* harmony export */   \"mdiYoutubeStudio\": () => /* binding */ mdiYoutubeStudio,\n/* harmony export */   \"mdiYoutubeSubscription\": () => /* binding */ mdiYoutubeSubscription,\n/* harmony export */   \"mdiYoutubeTv\": () => /* binding */ mdiYoutubeTv,\n/* harmony export */   \"mdiYurt\": () => /* binding */ mdiYurt,\n/* harmony export */   \"mdiZWave\": () => /* binding */ mdiZWave,\n/* harmony export */   \"mdiZend\": () => /* binding */ mdiZend,\n/* harmony export */   \"mdiZigbee\": () => /* binding */ mdiZigbee,\n/* harmony export */   \"mdiZipBox\": () => /* binding */ mdiZipBox,\n/* harmony export */   \"mdiZipBoxOutline\": () => /* binding */ mdiZipBoxOutline,\n/* harmony export */   \"mdiZipDisk\": () => /* binding */ mdiZipDisk,\n/* harmony export */   \"mdiZodiacAquarius\": () => /* binding */ mdiZodiacAquarius,\n/* harmony export */   \"mdiZodiacAries\": () => /* binding */ mdiZodiacAries,\n/* harmony export */   \"mdiZodiacCancer\": () => /* binding */ mdiZodiacCancer,\n/* harmony export */   \"mdiZodiacCapricorn\": () => /* binding */ mdiZodiacCapricorn,\n/* harmony export */   \"mdiZodiacGemini\": () => /* binding */ mdiZodiacGemini,\n/* harmony export */   \"mdiZodiacLeo\": () => /* binding */ mdiZodiacLeo,\n/* harmony export */   \"mdiZodiacLibra\": () => /* binding */ mdiZodiacLibra,\n/* harmony export */   \"mdiZodiacPisces\": () => /* binding */ mdiZodiacPisces,\n/* harmony export */   \"mdiZodiacSagittarius\": () => /* binding */ mdiZodiacSagittarius,\n/* harmony export */   \"mdiZodiacScorpio\": () => /* binding */ mdiZodiacScorpio,\n/* harmony export */   \"mdiZodiacTaurus\": () => /* binding */ mdiZodiacTaurus,\n/* harmony export */   \"mdiZodiacVirgo\": () => /* binding */ mdiZodiacVirgo\n/* harmony export */ });\n// Material Design Icons v5.6.55\r\nvar mdiAbTesting = \"M4 2A2 2 0 0 0 2 4V12H4V8H6V12H8V4A2 2 0 0 0 6 2H4M4 4H6V6H4M22 15.5V14A2 2 0 0 0 20 12H16V22H20A2 2 0 0 0 22 20V18.5A1.54 1.54 0 0 0 20.5 17A1.54 1.54 0 0 0 22 15.5M20 20H18V18H20V20M20 16H18V14H20M5.79 21.61L4.21 20.39L18.21 2.39L19.79 3.61Z\";\r\nvar mdiAbjadArabic = \"M12 4C10.08 4 8.5 5.58 8.5 7.5C8.5 8.43 8.88 9.28 9.5 9.91C7.97 10.91 7 12.62 7 14.5C7 17.53 9.47 20 12.5 20C14.26 20 16 19.54 17.5 18.66L16.5 16.93C15.28 17.63 13.9 18 12.5 18C10.56 18 9 16.45 9 14.5C9 12.91 10.06 11.53 11.59 11.12L16.8 9.72L16.28 7.79L11.83 9C11.08 8.9 10.5 8.28 10.5 7.5C10.5 6.66 11.16 6 12 6C12.26 6 12.5 6.07 12.75 6.2L13.75 4.47C13.22 4.16 12.61 4 12 4Z\";\r\nvar mdiAbjadHebrew = \"M3.9 4L9 10.03C7.58 10.17 6.36 11.18 6 12.59L4 20H6.07L7.92 13.11C8.09 12.46 8.69 12 9.36 12H10.69L17.47 20H20.1L15 13.97C16.42 13.83 17.64 12.82 18 11.41L20 4H17.93L16.08 10.89C15.91 11.54 15.31 12 14.64 12H13.31L6.53 4Z\";\r\nvar mdiAbugidaDevanagari = \"M8 3V5H11C12.32 5 13.41 5.83 13.82 7H6V9H14V10H12C9.25 10 7 12.25 7 15C7 17.75 9.25 20 12 20C12.77 20 13.45 19.73 14 19.3V21H16V17H14C13.55 17.62 12.83 18 12 18C10.33 18 9 16.67 9 15C9 13.33 10.33 12 12 12H16V9H18V7H15.9C15.43 4.72 13.41 3 11 3H8Z\";\r\nvar mdiAbugidaThai = \"M9 20C9 17.44 10.87 12.42 13.86 7.25C14.29 6.5 15.08 6 16 6C17.12 6 18 6.88 18 8V20H20V8C20 5.8 18.2 4 16 4C14.34 4 12.9 4.92 12.13 6.25C10.56 8.96 9.61 11.15 9 13.03V6.5C9 5.13 7.87 4 6.5 4C5.13 4 4 5.13 4 6.5C4 7.87 5.13 9 6.5 9C6.67 9 6.84 9 7 8.95V20M6.5 6C6.79 6 7 6.21 7 6.5C7 6.79 6.79 7 6.5 7C6.21 7 6 6.79 6 6.5C6 6.21 6.21 6 6.5 6Z\";\r\nvar mdiAccessPoint = \"M4.93,4.93C3.12,6.74 2,9.24 2,12C2,14.76 3.12,17.26 4.93,19.07L6.34,17.66C4.89,16.22 4,14.22 4,12C4,9.79 4.89,7.78 6.34,6.34L4.93,4.93M19.07,4.93L17.66,6.34C19.11,7.78 20,9.79 20,12C20,14.22 19.11,16.22 17.66,17.66L19.07,19.07C20.88,17.26 22,14.76 22,12C22,9.24 20.88,6.74 19.07,4.93M7.76,7.76C6.67,8.85 6,10.35 6,12C6,13.65 6.67,15.15 7.76,16.24L9.17,14.83C8.45,14.11 8,13.11 8,12C8,10.89 8.45,9.89 9.17,9.17L7.76,7.76M16.24,7.76L14.83,9.17C15.55,9.89 16,10.89 16,12C16,13.11 15.55,14.11 14.83,14.83L16.24,16.24C17.33,15.15 18,13.65 18,12C18,10.35 17.33,8.85 16.24,7.76M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiAccessPointCheck = \"M20.59 14.84L21.75 16.25L17 21L14.25 18L15.41 16.84L17 18.43L20.59 14.84M19.07 4.93L17.66 6.34C19.11 7.78 20 9.79 20 12V12.34C20.68 12.59 21.33 12.96 21.88 13.43C21.95 12.96 22 12.5 22 12C22 9.24 20.88 6.74 19.07 4.93M15.96 12.36C16.6 12.13 17.28 12 18 12C18 10.35 17.33 8.85 16.24 7.76L14.83 9.17C15.55 9.89 16 10.89 16 12C16 12.12 15.97 12.24 15.96 12.36M12 10C10.9 10 10 10.9 10 12S10.9 14 12 14 14 13.1 14 12 13.1 10 12 10M6.34 6.34L4.93 4.93C3.12 6.74 2 9.24 2 12S3.12 17.26 4.93 19.07L6.34 17.66C4.89 16.22 4 14.22 4 12C4 9.79 4.89 7.78 6.34 6.34M7.76 7.76C6.67 8.85 6 10.35 6 12S6.67 15.15 7.76 16.24L9.17 14.83C8.45 14.11 8 13.11 8 12S8.45 9.89 9.17 9.17L7.76 7.76Z\";\r\nvar mdiAccessPointMinus = \"M16 12C16 10.89 15.55 9.89 14.83 9.17L16.24 7.76C17.33 8.85 18 10.35 18 12C17.28 12 16.6 12.13 15.96 12.36C15.97 12.24 16 12.12 16 12M20 12.34C20.68 12.59 21.33 12.96 21.88 13.43C21.95 12.96 22 12.5 22 12C22 9.24 20.88 6.74 19.07 4.93L17.66 6.34C19.11 7.78 20 9.79 20 12C20 12.12 20 12.23 20 12.34M12 10C10.9 10 10 10.9 10 12S10.9 14 12 14 14 13.1 14 12 13.1 10 12 10M7.76 7.76C6.67 8.85 6 10.35 6 12S6.67 15.15 7.76 16.24L9.17 14.83C8.45 14.11 8 13.11 8 12S8.45 9.89 9.17 9.17L7.76 7.76M6.34 6.34L4.93 4.93C3.12 6.74 2 9.24 2 12S3.12 17.26 4.93 19.07L6.34 17.66C4.89 16.22 4 14.22 4 12C4 9.79 4.89 7.78 6.34 6.34M14 19H22V17H14V19Z\";\r\nvar mdiAccessPointNetwork = \"M4.93,3.93C3.12,5.74 2,8.24 2,11C2,13.76 3.12,16.26 4.93,18.07L6.34,16.66C4.89,15.22 4,13.22 4,11C4,8.79 4.89,6.78 6.34,5.34L4.93,3.93M19.07,3.93L17.66,5.34C19.11,6.78 20,8.79 20,11C20,13.22 19.11,15.22 17.66,16.66L19.07,18.07C20.88,16.26 22,13.76 22,11C22,8.24 20.88,5.74 19.07,3.93M7.76,6.76C6.67,7.85 6,9.35 6,11C6,12.65 6.67,14.15 7.76,15.24L9.17,13.83C8.45,13.11 8,12.11 8,11C8,9.89 8.45,8.89 9.17,8.17L7.76,6.76M16.24,6.76L14.83,8.17C15.55,8.89 16,9.89 16,11C16,12.11 15.55,13.11 14.83,13.83L16.24,15.24C17.33,14.15 18,12.65 18,11C18,9.35 17.33,7.85 16.24,6.76M12,9A2,2 0 0,0 10,11A2,2 0 0,0 12,13A2,2 0 0,0 14,11A2,2 0 0,0 12,9M11,15V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15A1,1 0 0,0 14,19H13V15H11Z\";\r\nvar mdiAccessPointNetworkOff = \"M14.83,13.83C15.55,13.11 16,12.11 16,11C16,9.89 15.55,8.89 14.83,8.17L16.24,6.76C17.33,7.85 18,9.35 18,11C18,12.65 17.33,14.15 16.24,15.24L14.83,13.83M14,11A2,2 0 0,0 12,9C11.4,9 10.87,9.27 10.5,9.68L13.32,12.5C13.73,12.13 14,11.6 14,11M17.66,16.66L19.07,18.07C20.88,16.26 22,13.76 22,11C22,8.24 20.88,5.74 19.07,3.93L17.66,5.34C19.11,6.78 20,8.79 20,11C20,13.22 19.11,15.22 17.66,16.66M22,21.18V20H20.82L22,21.18M20.27,22L21,22.73L19.73,24L17.73,22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V15.27L8.34,12.61C8.54,13.07 8.82,13.5 9.17,13.83L7.76,15.24C6.67,14.15 6,12.65 6,11C6,10.77 6,10.54 6.04,10.31L4.37,8.64C4.14,9.39 4,10.18 4,11C4,13.22 4.89,15.22 6.34,16.66L4.93,18.07C3.12,16.26 2,13.76 2,11C2,9.61 2.29,8.28 2.81,7.08L1,5.27L2.28,4L3.7,5.42L5.15,6.87L6.63,8.35V8.35L8.17,9.9L10.28,12L11,12.71L18.27,20H18.28L20.28,22H20.27M15.73,20L13,17.27V19H14A1,1 0 0,1 15,20H15.73Z\";\r\nvar mdiAccessPointOff = \"M20.84 22.73L12.1 14C12.06 14 12.03 14 12 14C10.9 14 10 13.11 10 12C10 11.97 10 11.94 10 11.9L8.4 10.29C8.15 10.81 8 11.38 8 12C8 13.11 8.45 14.11 9.17 14.83L7.76 16.24C6.67 15.15 6 13.65 6 12C6 10.83 6.34 9.74 6.93 8.82L5.5 7.37C4.55 8.67 4 10.27 4 12C4 14.22 4.89 16.22 6.34 17.66L4.93 19.07C3.12 17.26 2 14.76 2 12C2 9.72 2.77 7.63 4.06 5.95L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M15.93 12.73L17.53 14.33C17.83 13.61 18 12.83 18 12C18 10.35 17.33 8.85 16.24 7.76L14.83 9.17C15.55 9.89 16 10.89 16 12C16 12.25 15.97 12.5 15.93 12.73M19.03 15.83L20.5 17.28C21.44 15.75 22 13.94 22 12C22 9.24 20.88 6.74 19.07 4.93L17.66 6.34C19.11 7.78 20 9.79 20 12C20 13.39 19.65 14.7 19.03 15.83Z\";\r\nvar mdiAccessPointPlus = \"M16 12C16 10.89 15.55 9.89 14.83 9.17L16.24 7.76C17.33 8.85 18 10.35 18 12C17.28 12 16.6 12.13 15.96 12.36C15.97 12.24 16 12.12 16 12M20 12.34C20.68 12.59 21.33 12.96 21.88 13.43C21.95 12.96 22 12.5 22 12C22 9.24 20.88 6.74 19.07 4.93L17.66 6.34C19.11 7.78 20 9.79 20 12C20 12.12 20 12.23 20 12.34M12 10C10.9 10 10 10.9 10 12S10.9 14 12 14 14 13.1 14 12 13.1 10 12 10M6.34 6.34L4.93 4.93C3.12 6.74 2 9.24 2 12S3.12 17.26 4.93 19.07L6.34 17.66C4.89 16.22 4 14.22 4 12C4 9.79 4.89 7.78 6.34 6.34M7.76 7.76C6.67 8.85 6 10.35 6 12S6.67 15.15 7.76 16.24L9.17 14.83C8.45 14.11 8 13.11 8 12S8.45 9.89 9.17 9.17L7.76 7.76M19 14H17V17H14V19H17V22H19V19H22V17H19V14Z\";\r\nvar mdiAccessPointRemove = \"M16 12C16 10.89 15.55 9.89 14.83 9.17L16.24 7.76C17.33 8.85 18 10.35 18 12C17.28 12 16.6 12.13 15.96 12.36C15.97 12.24 16 12.12 16 12M6.34 6.34L4.93 4.93C3.12 6.74 2 9.24 2 12S3.12 17.26 4.93 19.07L6.34 17.66C4.89 16.22 4 14.22 4 12C4 9.79 4.89 7.78 6.34 6.34M19.07 4.93L17.66 6.34C19.11 7.78 20 9.79 20 12C20 12.12 20 12.23 20 12.34C20.68 12.59 21.33 12.96 21.88 13.43C21.95 12.96 22 12.5 22 12C22 9.24 20.88 6.74 19.07 4.93M12 10C10.9 10 10 10.9 10 12S10.9 14 12 14 14 13.1 14 12 13.1 10 12 10M7.76 7.76C6.67 8.85 6 10.35 6 12S6.67 15.15 7.76 16.24L9.17 14.83C8.45 14.11 8 13.11 8 12S8.45 9.89 9.17 9.17L7.76 7.76M20.12 14.46L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.53L18 19.41L20.12 21.53L21.53 20.12L19.41 18L21.53 15.88L20.12 14.46Z\";\r\nvar mdiAccount = \"M12,4A4,4 0 0,1 16,8A4,4 0 0,1 12,12A4,4 0 0,1 8,8A4,4 0 0,1 12,4M12,14C16.42,14 20,15.79 20,18V20H4V18C4,15.79 7.58,14 12,14Z\";\r\nvar mdiAccountAlert = \"M10 4A4 4 0 0 1 14 8A4 4 0 0 1 10 12A4 4 0 0 1 6 8A4 4 0 0 1 10 4M10 14C14.42 14 18 15.79 18 18V20H2V18C2 15.79 5.58 14 10 14M20 12V7H22V13H20M20 17V15H22V17H20Z\";\r\nvar mdiAccountAlertOutline = \"M20 12V7H22V13H20M20 17H22V15H20M10 13C12.67 13 18 14.34 18 17V20H2V17C2 14.34 7.33 13 10 13M10 4A4 4 0 0 1 14 8A4 4 0 0 1 10 12A4 4 0 0 1 6 8A4 4 0 0 1 10 4M10 14.9C7.03 14.9 3.9 16.36 3.9 17V18.1H16.1V17C16.1 16.36 12.97 14.9 10 14.9M10 5.9A2.1 2.1 0 0 0 7.9 8A2.1 2.1 0 0 0 10 10.1A2.1 2.1 0 0 0 12.1 8A2.1 2.1 0 0 0 10 5.9Z\";\r\nvar mdiAccountArrowLeft = \"M18,21L15,18L18,15V17H22V19H18V21M10,4A4,4 0 0,1 14,8A4,4 0 0,1 10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M10,14C11.15,14 12.25,14.12 13.24,14.34C12.46,15.35 12,16.62 12,18C12,18.7 12.12,19.37 12.34,20H2V18C2,15.79 5.58,14 10,14Z\";\r\nvar mdiAccountArrowLeftOutline = \"M18,21L15,18L18,15V17H22V19H18V21M13,18C13,18.71 13.15,19.39 13.42,20H2V17C2,14.79 5.58,13 10,13C11,13 11.96,13.09 12.85,13.26C13.68,13.42 14.44,13.64 15.11,13.92C13.83,14.83 13,16.32 13,18M4,17V18H11C11,16.96 11.23,15.97 11.64,15.08L10,15C6.69,15 4,15.9 4,17M10,4A4,4 0 0,1 14,8A4,4 0 0,1 10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M10,6A2,2 0 0,0 8,8A2,2 0 0,0 10,10A2,2 0 0,0 12,8A2,2 0 0,0 10,6Z\";\r\nvar mdiAccountArrowRight = \"M19,21V19H15V17H19V15L22,18L19,21M10,4A4,4 0 0,1 14,8A4,4 0 0,1 10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M10,14C11.15,14 12.25,14.12 13.24,14.34C12.46,15.35 12,16.62 12,18C12,18.7 12.12,19.37 12.34,20H2V18C2,15.79 5.58,14 10,14Z\";\r\nvar mdiAccountArrowRightOutline = \"M19,21V19H15V17H19V15L22,18L19,21M13,18C13,18.71 13.15,19.39 13.42,20H2V17C2,14.79 5.58,13 10,13C11,13 11.96,13.09 12.85,13.26C13.68,13.42 14.44,13.64 15.11,13.92C13.83,14.83 13,16.32 13,18M4,17V18H11C11,16.96 11.23,15.97 11.64,15.08L10,15C6.69,15 4,15.9 4,17M10,4A4,4 0 0,1 14,8A4,4 0 0,1 10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M10,6A2,2 0 0,0 8,8A2,2 0 0,0 10,10A2,2 0 0,0 12,8A2,2 0 0,0 10,6Z\";\r\nvar mdiAccountBox = \"M6,17C6,15 10,13.9 12,13.9C14,13.9 18,15 18,17V18H6M15,9A3,3 0 0,1 12,12A3,3 0 0,1 9,9A3,3 0 0,1 12,6A3,3 0 0,1 15,9M3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5C3.89,3 3,3.9 3,5Z\";\r\nvar mdiAccountBoxMultiple = \"M4,6H2V20A2,2 0 0,0 4,22H18V20H4V6M20,2A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H8A2,2 0 0,1 6,16V4A2,2 0 0,1 8,2H20M17,7A3,3 0 0,0 14,4A3,3 0 0,0 11,7A3,3 0 0,0 14,10A3,3 0 0,0 17,7M8,15V16H20V15C20,13 16,11.9 14,11.9C12,11.9 8,13 8,15Z\";\r\nvar mdiAccountBoxMultipleOutline = \"M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6M18.5 14.25C18.5 12.75 15.5 12 14 12S9.5 12.75 9.5 14.25V15H18.5M14 10.25C15.24 10.25 16.25 9.24 16.25 8S15.24 5.75 14 5.75 11.75 6.76 11.75 8 12.76 10.25 14 10.25M20 2H8C6.9 2 6 2.9 6 4V16C6 17.11 6.9 18 8 18H20C21.11 18 22 17.11 22 16V4C22 2.89 21.1 2 20 2M20 16H8V4H20V16Z\";\r\nvar mdiAccountBoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M16.5,16.25C16.5,14.75 13.5,14 12,14C10.5,14 7.5,14.75 7.5,16.25V17H16.5M12,12.25A2.25,2.25 0 0,0 14.25,10A2.25,2.25 0 0,0 12,7.75A2.25,2.25 0 0,0 9.75,10A2.25,2.25 0 0,0 12,12.25Z\";\r\nvar mdiAccountCancel = \"M10 4A4 4 0 0 0 6 8A4 4 0 0 0 10 12A4 4 0 0 0 14 8A4 4 0 0 0 10 4M17.5 13C15 13 13 15 13 17.5C13 20 15 22 17.5 22C20 22 22 20 22 17.5C22 15 20 13 17.5 13M10 14C5.58 14 2 15.79 2 18V20H11.5A6.5 6.5 0 0 1 11 17.5A6.5 6.5 0 0 1 11.95 14.14C11.32 14.06 10.68 14 10 14M17.5 14.5C19.16 14.5 20.5 15.84 20.5 17.5C20.5 18.06 20.35 18.58 20.08 19L16 14.92C16.42 14.65 16.94 14.5 17.5 14.5M14.92 16L19 20.08C18.58 20.35 18.06 20.5 17.5 20.5C15.84 20.5 14.5 19.16 14.5 17.5C14.5 16.94 14.65 16.42 14.92 16Z\";\r\nvar mdiAccountCancelOutline = \"M10 4A4 4 0 0 0 6 8A4 4 0 0 0 10 12A4 4 0 0 0 14 8A4 4 0 0 0 10 4M10 6A2 2 0 0 1 12 8A2 2 0 0 1 10 10A2 2 0 0 1 8 8A2 2 0 0 1 10 6M10 13C7.33 13 2 14.33 2 17V20H11.5A6.5 6.5 0 0 1 11.03 18.1H3.9V17C3.9 16.36 7.03 14.9 10 14.9C10.5 14.9 11 14.95 11.5 15.03A6.5 6.5 0 0 1 12.55 13.29C11.61 13.1 10.71 13 10 13M17.5 13C15 13 13 15 13 17.5C13 20 15 22 17.5 22C20 22 22 20 22 17.5C22 15 20 13 17.5 13M17.5 14.5C19.16 14.5 20.5 15.84 20.5 17.5C20.5 18.06 20.35 18.58 20.08 19L16 14.92C16.42 14.65 16.94 14.5 17.5 14.5M14.92 16L19 20.08C18.58 20.35 18.06 20.5 17.5 20.5C15.84 20.5 14.5 19.16 14.5 17.5C14.5 16.94 14.65 16.42 14.92 16Z\";\r\nvar mdiAccountCash = \"M11 8C11 10.21 9.21 12 7 12C4.79 12 3 10.21 3 8C3 5.79 4.79 4 7 4C9.21 4 11 5.79 11 8M11 14.72V20H0V18C0 15.79 3.13 14 7 14C8.5 14 9.87 14.27 11 14.72M24 20H13V3H24V20M16 11.5C16 10.12 17.12 9 18.5 9C19.88 9 21 10.12 21 11.5C21 12.88 19.88 14 18.5 14C17.12 14 16 12.88 16 11.5M22 7C20.9 7 20 6.11 20 5H17C17 6.11 16.11 7 15 7V16C16.11 16 17 16.9 17 18H20C20 16.9 20.9 16 22 16V7Z\";\r\nvar mdiAccountCashOutline = \"M16 11.5C16 10.12 17.12 9 18.5 9S21 10.12 21 11.5 19.88 14 18.5 14 16 12.88 16 11.5M13 3V20H24V3H13M22 16C20.9 16 20 16.9 20 18H17C17 16.9 16.11 16 15 16V7C16.11 7 17 6.11 17 5H20C20 6.11 20.9 7 22 7V16M7 6C8.1 6 9 6.9 9 8S8.1 10 7 10 5 9.1 5 8 5.9 6 7 6M7 4C4.79 4 3 5.79 3 8S4.79 12 7 12 11 10.21 11 8 9.21 4 7 4M7 14C3.13 14 0 15.79 0 18V20H11V18H2C2 17.42 3.75 16 7 16C8.83 16 10.17 16.45 11 16.95V14.72C9.87 14.27 8.5 14 7 14Z\";\r\nvar mdiAccountCheck = \"M21.1,12.5L22.5,13.91L15.97,20.5L12.5,17L13.9,15.59L15.97,17.67L21.1,12.5M10,17L13,20H3V18C3,15.79 6.58,14 11,14L12.89,14.11L10,17M11,4A4,4 0 0,1 15,8A4,4 0 0,1 11,12A4,4 0 0,1 7,8A4,4 0 0,1 11,4Z\";\r\nvar mdiAccountCheckOutline = \"M21.1,12.5L22.5,13.91L15.97,20.5L12.5,17L13.9,15.59L15.97,17.67L21.1,12.5M11,4A4,4 0 0,1 15,8A4,4 0 0,1 11,12A4,4 0 0,1 7,8A4,4 0 0,1 11,4M11,6A2,2 0 0,0 9,8A2,2 0 0,0 11,10A2,2 0 0,0 13,8A2,2 0 0,0 11,6M11,13C11.68,13 12.5,13.09 13.41,13.26L11.74,14.93L11,14.9C8.03,14.9 4.9,16.36 4.9,17V18.1H11.1L13,20H3V17C3,14.34 8.33,13 11,13Z\";\r\nvar mdiAccountChild = \"M12,2A3,3 0 0,1 15,5A3,3 0 0,1 12,8A3,3 0 0,1 9,5A3,3 0 0,1 12,2M12,9C13.63,9 15.12,9.35 16.5,10.05C17.84,10.76 18.5,11.61 18.5,12.61V18.38C18.5,19.5 17.64,20.44 15.89,21.19V19C15.89,18.05 15.03,17.38 13.31,16.97C12.75,16.84 12.31,16.78 12,16.78C11.13,16.78 10.3,16.95 9.54,17.3C8.77,17.64 8.31,18.08 8.16,18.61C9.5,19.14 10.78,19.41 12,19.41L13,19.31V21.94L12,22C10.63,22 9.33,21.72 8.11,21.19C6.36,20.44 5.5,19.5 5.5,18.38V12.61C5.5,11.61 6.16,10.76 7.5,10.05C8.88,9.35 10.38,9 12,9M12,11A2,2 0 0,0 10,13A2,2 0 0,0 12,15A2,2 0 0,0 14,13A2,2 0 0,0 12,11Z\";\r\nvar mdiAccountChildCircle = \"M12,12A1.5,1.5 0 0,1 13.5,13.5A1.5,1.5 0 0,1 12,15A1.5,1.5 0 0,1 10.5,13.5A1.5,1.5 0 0,1 12,12M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,16C12.72,16 13.4,16.15 14.04,16.5C14.68,16.8 15,17.2 15,17.67V19.41C16.34,18.81 17,18.08 17,17.2V12.8C17,12 16.5,11.35 15.45,10.8C14.4,10.26 13.25,10 12,10C10.75,10 9.6,10.26 8.55,10.8C7.5,11.35 7,12 7,12.8V17.2C7,18 7.53,18.69 8.63,19.22C9.72,19.75 10.84,20 12,20L13,19.92V17.91L12,18C11,18 10,17.8 9.05,17.39C9.17,17 9.53,16.69 10.13,16.41C10.72,16.13 11.34,16 12,16M12,4A2.5,2.5 0 0,0 9.5,6.5A2.5,2.5 0 0,0 12,9A2.5,2.5 0 0,0 14.5,6.5A2.5,2.5 0 0,0 12,4Z\";\r\nvar mdiAccountChildOutline = \"M12 17C10.9 17 10 16.1 10 15C10 13.9 10.9 13 12 13C13.1 13 14 13.9 14 15C14 16.1 13.1 17 12 17M12 10C14.34 10 19 11.16 19 13.5V18.63C19 19.5 18.31 20.24 17.34 20.79V13.38C17.34 12.82 14.6 11.54 12 11.54C9.4 11.54 6.66 12.82 6.66 13.38V18.75C6.66 19 7.31 19.46 8.28 19.85C9 19 10.93 18.56 12 18.56C13.33 18.56 16 19.22 16 20.56V21.39C14.63 21.88 13.07 22.13 12 22.13C10.93 22.13 9.38 21.88 8 21.39H8C6.37 20.81 5 19.89 5 18.63V13.5C5 11.16 9.66 10 12 10M12 3.75C11.03 3.75 10.25 4.53 10.25 5.5C10.25 6.47 11.03 7.25 12 7.25C12.97 7.25 13.75 6.47 13.75 5.5C13.75 4.53 12.97 3.75 12 3.75M12 9C10.07 9 8.5 7.43 8.5 5.5C8.5 3.57 10.07 2 12 2C13.93 2 15.5 3.57 15.5 5.5C15.5 7.43 13.93 9 12 9Z\";\r\nvar mdiAccountCircle = \"M12,19.2C9.5,19.2 7.29,17.92 6,16C6.03,14 10,12.9 12,12.9C14,12.9 17.97,14 18,16C16.71,17.92 14.5,19.2 12,19.2M12,5A3,3 0 0,1 15,8A3,3 0 0,1 12,11A3,3 0 0,1 9,8A3,3 0 0,1 12,5M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2Z\";\r\nvar mdiAccountCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7.07,18.28C7.5,17.38 10.12,16.5 12,16.5C13.88,16.5 16.5,17.38 16.93,18.28C15.57,19.36 13.86,20 12,20C10.14,20 8.43,19.36 7.07,18.28M18.36,16.83C16.93,15.09 13.46,14.5 12,14.5C10.54,14.5 7.07,15.09 5.64,16.83C4.62,15.5 4,13.82 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,13.82 19.38,15.5 18.36,16.83M12,6C10.06,6 8.5,7.56 8.5,9.5C8.5,11.44 10.06,13 12,13C13.94,13 15.5,11.44 15.5,9.5C15.5,7.56 13.94,6 12,6M12,11A1.5,1.5 0 0,1 10.5,9.5A1.5,1.5 0 0,1 12,8A1.5,1.5 0 0,1 13.5,9.5A1.5,1.5 0 0,1 12,11Z\";\r\nvar mdiAccountClock = \"M10.63,14.1C12.23,10.58 16.38,9.03 19.9,10.63C23.42,12.23 24.97,16.38 23.37,19.9C22.24,22.4 19.75,24 17,24C14.3,24 11.83,22.44 10.67,20H1V18C1.06,16.86 1.84,15.93 3.34,15.18C4.84,14.43 6.72,14.04 9,14C9.57,14 10.11,14.05 10.63,14.1V14.1M9,4C10.12,4.03 11.06,4.42 11.81,5.17C12.56,5.92 12.93,6.86 12.93,8C12.93,9.14 12.56,10.08 11.81,10.83C11.06,11.58 10.12,11.95 9,11.95C7.88,11.95 6.94,11.58 6.19,10.83C5.44,10.08 5.07,9.14 5.07,8C5.07,6.86 5.44,5.92 6.19,5.17C6.94,4.42 7.88,4.03 9,4M17,22A5,5 0 0,0 22,17A5,5 0 0,0 17,12A5,5 0 0,0 12,17A5,5 0 0,0 17,22M16,14H17.5V16.82L19.94,18.23L19.19,19.53L16,17.69V14Z\";\r\nvar mdiAccountClockOutline = \"M16,14H17.5V16.82L19.94,18.23L19.19,19.53L16,17.69V14M17,12A5,5 0 0,0 12,17A5,5 0 0,0 17,22A5,5 0 0,0 22,17A5,5 0 0,0 17,12M17,10A7,7 0 0,1 24,17A7,7 0 0,1 17,24C14.21,24 11.8,22.36 10.67,20H1V17C1,14.34 6.33,13 9,13C9.6,13 10.34,13.07 11.12,13.2C12.36,11.28 14.53,10 17,10M10,17C10,16.3 10.1,15.62 10.29,15C9.87,14.93 9.43,14.9 9,14.9C6.03,14.9 2.9,16.36 2.9,17V18.1H10.09C10.03,17.74 10,17.37 10,17M9,4A4,4 0 0,1 13,8A4,4 0 0,1 9,12A4,4 0 0,1 5,8A4,4 0 0,1 9,4M9,5.9A2.1,2.1 0 0,0 6.9,8A2.1,2.1 0 0,0 9,10.1A2.1,2.1 0 0,0 11.1,8A2.1,2.1 0 0,0 9,5.9Z\";\r\nvar mdiAccountCog = \"M10 4A4 4 0 0 0 6 8A4 4 0 0 0 10 12A4 4 0 0 0 14 8A4 4 0 0 0 10 4M17 12C16.87 12 16.76 12.09 16.74 12.21L16.55 13.53C16.25 13.66 15.96 13.82 15.7 14L14.46 13.5C14.35 13.5 14.22 13.5 14.15 13.63L13.15 15.36C13.09 15.47 13.11 15.6 13.21 15.68L14.27 16.5C14.25 16.67 14.24 16.83 14.24 17C14.24 17.17 14.25 17.33 14.27 17.5L13.21 18.32C13.12 18.4 13.09 18.53 13.15 18.64L14.15 20.37C14.21 20.5 14.34 20.5 14.46 20.5L15.7 20C15.96 20.18 16.24 20.35 16.55 20.47L16.74 21.79C16.76 21.91 16.86 22 17 22H19C19.11 22 19.22 21.91 19.24 21.79L19.43 20.47C19.73 20.34 20 20.18 20.27 20L21.5 20.5C21.63 20.5 21.76 20.5 21.83 20.37L22.83 18.64C22.89 18.53 22.86 18.4 22.77 18.32L21.7 17.5C21.72 17.33 21.74 17.17 21.74 17C21.74 16.83 21.73 16.67 21.7 16.5L22.76 15.68C22.85 15.6 22.88 15.47 22.82 15.36L21.82 13.63C21.76 13.5 21.63 13.5 21.5 13.5L20.27 14C20 13.82 19.73 13.65 19.42 13.53L19.23 12.21C19.22 12.09 19.11 12 19 12H17M10 14C5.58 14 2 15.79 2 18V20H11.68A7 7 0 0 1 11 17A7 7 0 0 1 11.64 14.09C11.11 14.03 10.56 14 10 14M18 15.5C18.83 15.5 19.5 16.17 19.5 17C19.5 17.83 18.83 18.5 18 18.5C17.16 18.5 16.5 17.83 16.5 17C16.5 16.17 17.17 15.5 18 15.5Z\";\r\nvar mdiAccountCogOutline = \"M10 4A4 4 0 0 0 6 8A4 4 0 0 0 10 12A4 4 0 0 0 14 8A4 4 0 0 0 10 4M10 6A2 2 0 0 1 12 8A2 2 0 0 1 10 10A2 2 0 0 1 8 8A2 2 0 0 1 10 6M17 12C16.84 12 16.76 12.08 16.76 12.24L16.5 13.5C16.28 13.68 15.96 13.84 15.72 14L14.44 13.5C14.36 13.5 14.2 13.5 14.12 13.6L13.16 15.36C13.08 15.44 13.08 15.6 13.24 15.68L14.28 16.5V17.5L13.24 18.32C13.16 18.4 13.08 18.56 13.16 18.64L14.12 20.4C14.2 20.5 14.36 20.5 14.44 20.5L15.72 20C15.96 20.16 16.28 20.32 16.5 20.5L16.76 21.76C16.76 21.92 16.84 22 17 22H19C19.08 22 19.24 21.92 19.24 21.76L19.4 20.5C19.72 20.32 20.04 20.16 20.28 20L21.5 20.5C21.64 20.5 21.8 20.5 21.8 20.4L22.84 18.64C22.92 18.56 22.84 18.4 22.76 18.32L21.72 17.5V16.5L22.76 15.68C22.84 15.6 22.92 15.44 22.84 15.36L21.8 13.6C21.8 13.5 21.64 13.5 21.5 13.5L20.28 14C20.04 13.84 19.72 13.68 19.4 13.5L19.24 12.24C19.24 12.08 19.08 12 19 12H17M10 13C7.33 13 2 14.33 2 17V20H11.67C11.39 19.41 11.19 18.77 11.09 18.1H3.9V17C3.9 16.36 7.03 14.9 10 14.9C10.43 14.9 10.87 14.94 11.3 15C11.5 14.36 11.77 13.76 12.12 13.21C11.34 13.08 10.6 13 10 13M18.04 15.5C18.84 15.5 19.5 16.16 19.5 17.04C19.5 17.84 18.84 18.5 18.04 18.5C17.16 18.5 16.5 17.84 16.5 17.04C16.5 16.16 17.16 15.5 18.04 15.5Z\";\r\nvar mdiAccountConvert = \"M12 0L11.34 .03L15.15 3.84L16.5 2.5C19.75 4.07 22.09 7.24 22.45 11H23.95C23.44 4.84 18.29 0 12 0M12 4C10.07 4 8.5 5.57 8.5 7.5C8.5 9.43 10.07 11 12 11C13.93 11 15.5 9.43 15.5 7.5C15.5 5.57 13.93 4 12 4M.05 13C.56 19.16 5.71 24 12 24L12.66 23.97L8.85 20.16L7.5 21.5C4.25 19.94 1.91 16.76 1.55 13H.05M12 13C8.13 13 5 14.57 5 16.5V18H19V16.5C19 14.57 15.87 13 12 13Z\";\r\nvar mdiAccountConvertOutline = \"M12 0L11.34 .03L15.15 3.84L16.5 2.5C19.75 4.07 22.09 7.24 22.45 11H23.95C23.44 4.84 18.29 0 12 0M12 4C10.07 4 8.5 5.57 8.5 7.5C8.5 9.43 10.07 11 12 11C13.93 11 15.5 9.43 15.5 7.5C15.5 5.57 13.93 4 12 4M12 6C12.83 6 13.5 6.67 13.5 7.5C13.5 8.33 12.83 9 12 9C11.17 9 10.5 8.33 10.5 7.5C10.5 6.67 11.17 6 12 6M.05 13C.56 19.16 5.71 24 12 24L12.66 23.97L8.85 20.16L7.5 21.5C4.25 19.94 1.91 16.76 1.55 13H.05M12 13C8.13 13 5 14.57 5 16.5V18H19V16.5C19 14.57 15.87 13 12 13M12 15C14.11 15 15.61 15.53 16.39 16H7.61C8.39 15.53 9.89 15 12 15Z\";\r\nvar mdiAccountCowboyHat = \"M20 22H4V20C4 17.8 7.6 16 12 16S20 17.8 20 20M8 9H16V10C16 12.2 14.2 14 12 14S8 12.2 8 10M19 4C18.4 4 18 4.4 18 5V6H16.5L15.1 3C15 2.8 14.9 2.6 14.7 2.5C14.2 2 13.4 1.9 12.7 2.2L12 2.4L11.3 2.1C10.6 1.8 9.8 1.9 9.3 2.4C9.1 2.6 9 2.8 8.9 3L7.5 6H6V5C6 4.4 5.6 4 5 4S4 4.4 4 5V6C4 7.1 4.9 8 6 8H18C19.1 8 20 7.1 20 6V5C20 4.5 19.6 4 19 4Z\";\r\nvar mdiAccountDetails = \"M11 9C11 10.66 9.66 12 8 12C6.34 12 5 10.66 5 9C5 7.34 6.34 6 8 6C9.66 6 11 7.34 11 9M14 20H2V18C2 15.79 4.69 14 8 14C11.31 14 14 15.79 14 18M22 12V14H13V12M22 8V10H13V8M22 4V6H13V4Z\";\r\nvar mdiAccountDetailsOutline = \"M11 9C11 10.66 9.66 12 8 12C6.34 12 5 10.66 5 9C5 7.34 6.34 6 8 6C9.66 6 11 7.34 11 9M14 20H2V18C2 15.79 4.69 14 8 14C11.31 14 14 15.79 14 18M7 9C7 9.55 7.45 10 8 10C8.55 10 9 9.55 9 9C9 8.45 8.55 8 8 8C7.45 8 7 8.45 7 9M4 18H12C12 16.9 10.21 16 8 16C5.79 16 4 16.9 4 18M22 12V14H13V12M22 8V10H13V8M22 4V6H13V4Z\";\r\nvar mdiAccountEdit = \"M21.7,13.35L20.7,14.35L18.65,12.3L19.65,11.3C19.86,11.09 20.21,11.09 20.42,11.3L21.7,12.58C21.91,12.79 21.91,13.14 21.7,13.35M12,18.94L18.06,12.88L20.11,14.93L14.06,21H12V18.94M12,14C7.58,14 4,15.79 4,18V20H10V18.11L14,14.11C13.34,14.03 12.67,14 12,14M12,4A4,4 0 0,0 8,8A4,4 0 0,0 12,12A4,4 0 0,0 16,8A4,4 0 0,0 12,4Z\";\r\nvar mdiAccountEditOutline = \"M2 17V20H10V18.11H3.9V17C3.9 16.36 7.03 14.9 10 14.9C10.96 14.91 11.91 15.04 12.83 15.28L14.35 13.76C12.95 13.29 11.5 13.03 10 13C7.33 13 2 14.33 2 17M10 4C7.79 4 6 5.79 6 8S7.79 12 10 12 14 10.21 14 8 12.21 4 10 4M10 10C8.9 10 8 9.11 8 8S8.9 6 10 6 12 6.9 12 8 11.11 10 10 10M21.7 13.35L20.7 14.35L18.65 12.35L19.65 11.35C19.86 11.14 20.21 11.14 20.42 11.35L21.7 12.63C21.91 12.84 21.91 13.19 21.7 13.4M12 18.94L18.06 12.88L20.11 14.88L14.11 20.95H12V18.94\";\r\nvar mdiAccountGroup = \"M12,5.5A3.5,3.5 0 0,1 15.5,9A3.5,3.5 0 0,1 12,12.5A3.5,3.5 0 0,1 8.5,9A3.5,3.5 0 0,1 12,5.5M5,8C5.56,8 6.08,8.15 6.53,8.42C6.38,9.85 6.8,11.27 7.66,12.38C7.16,13.34 6.16,14 5,14A3,3 0 0,1 2,11A3,3 0 0,1 5,8M19,8A3,3 0 0,1 22,11A3,3 0 0,1 19,14C17.84,14 16.84,13.34 16.34,12.38C17.2,11.27 17.62,9.85 17.47,8.42C17.92,8.15 18.44,8 19,8M5.5,18.25C5.5,16.18 8.41,14.5 12,14.5C15.59,14.5 18.5,16.18 18.5,18.25V20H5.5V18.25M0,20V18.5C0,17.11 1.89,15.94 4.45,15.6C3.86,16.28 3.5,17.22 3.5,18.25V20H0M24,20H20.5V18.25C20.5,17.22 20.14,16.28 19.55,15.6C22.11,15.94 24,17.11 24,18.5V20Z\";\r\nvar mdiAccountGroupOutline = \"M12,5A3.5,3.5 0 0,0 8.5,8.5A3.5,3.5 0 0,0 12,12A3.5,3.5 0 0,0 15.5,8.5A3.5,3.5 0 0,0 12,5M12,7A1.5,1.5 0 0,1 13.5,8.5A1.5,1.5 0 0,1 12,10A1.5,1.5 0 0,1 10.5,8.5A1.5,1.5 0 0,1 12,7M5.5,8A2.5,2.5 0 0,0 3,10.5C3,11.44 3.53,12.25 4.29,12.68C4.65,12.88 5.06,13 5.5,13C5.94,13 6.35,12.88 6.71,12.68C7.08,12.47 7.39,12.17 7.62,11.81C6.89,10.86 6.5,9.7 6.5,8.5C6.5,8.41 6.5,8.31 6.5,8.22C6.2,8.08 5.86,8 5.5,8M18.5,8C18.14,8 17.8,8.08 17.5,8.22C17.5,8.31 17.5,8.41 17.5,8.5C17.5,9.7 17.11,10.86 16.38,11.81C16.5,12 16.63,12.15 16.78,12.3C16.94,12.45 17.1,12.58 17.29,12.68C17.65,12.88 18.06,13 18.5,13C18.94,13 19.35,12.88 19.71,12.68C20.47,12.25 21,11.44 21,10.5A2.5,2.5 0 0,0 18.5,8M12,14C9.66,14 5,15.17 5,17.5V19H19V17.5C19,15.17 14.34,14 12,14M4.71,14.55C2.78,14.78 0,15.76 0,17.5V19H3V17.07C3,16.06 3.69,15.22 4.71,14.55M19.29,14.55C20.31,15.22 21,16.06 21,17.07V19H24V17.5C24,15.76 21.22,14.78 19.29,14.55M12,16C13.53,16 15.24,16.5 16.23,17H7.77C8.76,16.5 10.47,16 12,16Z\";\r\nvar mdiAccountHardHat = \"M12,15C7.58,15 4,16.79 4,19V21H20V19C20,16.79 16.42,15 12,15M8,9A4,4 0 0,0 12,13A4,4 0 0,0 16,9M11.5,2C11.2,2 11,2.21 11,2.5V5.5H10V3C10,3 7.75,3.86 7.75,6.75C7.75,6.75 7,6.89 7,8H17C16.95,6.89 16.25,6.75 16.25,6.75C16.25,3.86 14,3 14,3V5.5H13V2.5C13,2.21 12.81,2 12.5,2H11.5Z\";\r\nvar mdiAccountHeart = \"M15,14C12.3,14 7,15.3 7,18V20H23V18C23,15.3 17.7,14 15,14M15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12M5,15L4.4,14.5C2.4,12.6 1,11.4 1,9.9C1,8.7 2,7.7 3.2,7.7C3.9,7.7 4.6,8 5,8.5C5.4,8 6.1,7.7 6.8,7.7C8,7.7 9,8.6 9,9.9C9,11.4 7.6,12.6 5.6,14.5L5,15Z\";\r\nvar mdiAccountHeartOutline = \"M5,15L4.4,14.5C2.4,12.6 1,11.4 1,9.9C1,8.7 2,7.7 3.2,7.7C3.9,7.7 4.6,8 5,8.5C5.4,8 6.1,7.7 6.8,7.7C8,7.7 9,8.6 9,9.9C9,11.4 7.6,12.6 5.6,14.5L5,15M15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4M15,10.1A2.1,2.1 0 0,1 12.9,8A2.1,2.1 0 0,1 15,5.9C16.16,5.9 17.1,6.84 17.1,8C17.1,9.16 16.16,10.1 15,10.1M15,13C12.33,13 7,14.33 7,17V20H23V17C23,14.33 17.67,13 15,13M21.1,18.1H8.9V17C8.9,16.36 12,14.9 15,14.9C17.97,14.9 21.1,16.36 21.1,17V18.1Z\";\r\nvar mdiAccountKey = \"M11,10V12H10V14H8V12H5.83C5.42,13.17 4.31,14 3,14A3,3 0 0,1 0,11A3,3 0 0,1 3,8C4.31,8 5.42,8.83 5.83,10H11M3,10A1,1 0 0,0 2,11A1,1 0 0,0 3,12A1,1 0 0,0 4,11A1,1 0 0,0 3,10M16,14C18.67,14 24,15.34 24,18V20H8V18C8,15.34 13.33,14 16,14M16,12A4,4 0 0,1 12,8A4,4 0 0,1 16,4A4,4 0 0,1 20,8A4,4 0 0,1 16,12Z\";\r\nvar mdiAccountKeyOutline = \"M5.83,10C5.42,8.83 4.31,8 3,8A3,3 0 0,0 0,11A3,3 0 0,0 3,14C4.31,14 5.42,13.17 5.83,12H8V14H10V12H11V10H5.83M3,12A1,1 0 0,1 2,11A1,1 0 0,1 3,10A1,1 0 0,1 4,11A1,1 0 0,1 3,12M16,4A4,4 0 0,0 12,8A4,4 0 0,0 16,12A4,4 0 0,0 20,8A4,4 0 0,0 16,4M16,10.1A2.1,2.1 0 0,1 13.9,8A2.1,2.1 0 0,1 16,5.9C17.16,5.9 18.1,6.84 18.1,8C18.1,9.16 17.16,10.1 16,10.1M16,13C13.33,13 8,14.33 8,17V20H24V17C24,14.33 18.67,13 16,13M22.1,18.1H9.9V17C9.9,16.36 13,14.9 16,14.9C18.97,14.9 22.1,16.36 22.1,17V18.1Z\";\r\nvar mdiAccountLock = \"M22 17V16.5C22 15.12 20.88 14 19.5 14S17 15.12 17 16.5V17C16.45 17 16 17.45 16 18V22C16 22.55 16.45 23 17 23H22C22.55 23 23 22.55 23 22V18C23 17.45 22.55 17 22 17M21 17H18V16.5C18 15.67 18.67 15 19.5 15S21 15.67 21 16.5V17M8 8C8 5.79 9.79 4 12 4S16 5.79 16 8 14.21 12 12 12 8 10.21 8 8M14 20H4V18C4 15.79 7.58 14 12 14C13.27 14 14.46 14.15 15.53 14.41C15.32 14.82 15.15 15.25 15.07 15.71C14.42 16.26 14 17.08 14 18V20Z\";\r\nvar mdiAccountLockOutline = \"M22 17V16.5C22 15.12 20.88 14 19.5 14S17 15.12 17 16.5V17C16.45 17 16 17.45 16 18V22C16 22.55 16.45 23 17 23H22C22.55 23 23 22.55 23 22V18C23 17.45 22.55 17 22 17M21 17H18V16.5C18 15.67 18.67 15 19.5 15S21 15.67 21 16.5V17M14 20H4V17C4 14.33 9.33 13 12 13C13.08 13 14.6 13.22 16 13.66C15.61 14.15 15.33 14.74 15.16 15.38C14.19 15.1 13.09 14.9 12 14.9C9.03 14.9 5.9 16.36 5.9 17V18.1H14V20M12 12C14.21 12 16 10.21 16 8S14.21 4 12 4 8 5.79 8 8 9.79 12 12 12M12 6C13.11 6 14 6.9 14 8S13.11 10 12 10 10 9.11 10 8 10.9 6 12 6Z\";\r\nvar mdiAccountMinus = \"M15,14C12.33,14 7,15.33 7,18V20H23V18C23,15.33 17.67,14 15,14M1,10V12H9V10M15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12Z\";\r\nvar mdiAccountMinusOutline = \"M15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4M15,5.9C16.16,5.9 17.1,6.84 17.1,8C17.1,9.16 16.16,10.1 15,10.1A2.1,2.1 0 0,1 12.9,8A2.1,2.1 0 0,1 15,5.9M1,10V12H9V10H1M15,13C12.33,13 7,14.33 7,17V20H23V17C23,14.33 17.67,13 15,13M15,14.9C17.97,14.9 21.1,16.36 21.1,17V18.1H8.9V17C8.9,16.36 12,14.9 15,14.9Z\";\r\nvar mdiAccountMultiple = \"M16 17V19H2V17S2 13 9 13 16 17 16 17M12.5 7.5A3.5 3.5 0 1 0 9 11A3.5 3.5 0 0 0 12.5 7.5M15.94 13A5.32 5.32 0 0 1 18 17V19H22V17S22 13.37 15.94 13M15 4A3.39 3.39 0 0 0 13.07 4.59A5 5 0 0 1 13.07 10.41A3.39 3.39 0 0 0 15 11A3.5 3.5 0 0 0 15 4Z\";\r\nvar mdiAccountMultipleCheck = \"M19 17V19H7V17S7 13 13 13 19 17 19 17M16 8A3 3 0 1 0 13 11A3 3 0 0 0 16 8M19.2 13.06A5.6 5.6 0 0 1 21 17V19H24V17S24 13.55 19.2 13.06M18 5A2.91 2.91 0 0 0 17.11 5.14A5 5 0 0 1 17.11 10.86A2.91 2.91 0 0 0 18 11A3 3 0 0 0 18 5M7.34 8.92L8.5 10.33L3.75 15.08L1 12.08L2.16 10.92L3.75 12.5L7.34 8.92\";\r\nvar mdiAccountMultipleCheckOutline = \"M13 11A3 3 0 1 0 10 8A3 3 0 0 0 13 11M13 7A1 1 0 1 1 12 8A1 1 0 0 1 13 7M17.11 10.86A5 5 0 0 0 17.11 5.14A2.91 2.91 0 0 1 18 5A3 3 0 0 1 18 11A2.91 2.91 0 0 1 17.11 10.86M13 13C7 13 7 17 7 17V19H19V17S19 13 13 13M9 17C9 16.71 9.32 15 13 15C16.5 15 16.94 16.56 17 17M24 17V19H21V17A5.6 5.6 0 0 0 19.2 13.06C24 13.55 24 17 24 17M7.34 8.92L8.5 10.33L3.75 15.08L1 12.08L2.16 10.92L3.75 12.5L7.34 8.92\";\r\nvar mdiAccountMultipleMinus = \"M19 17V19H7V17S7 13 13 13 19 17 19 17M16 8A3 3 0 1 0 13 11A3 3 0 0 0 16 8M19.2 13.06A5.6 5.6 0 0 1 21 17V19H24V17S24 13.55 19.2 13.06M18 5A2.91 2.91 0 0 0 17.11 5.14A5 5 0 0 1 17.11 10.86A2.91 2.91 0 0 0 18 11A3 3 0 0 0 18 5M8 10H0V12H8Z\";\r\nvar mdiAccountMultipleMinusOutline = \"M13 11A3 3 0 1 0 10 8A3 3 0 0 0 13 11M13 7A1 1 0 1 1 12 8A1 1 0 0 1 13 7M17.11 10.86A5 5 0 0 0 17.11 5.14A2.91 2.91 0 0 1 18 5A3 3 0 0 1 18 11A2.91 2.91 0 0 1 17.11 10.86M13 13C7 13 7 17 7 17V19H19V17S19 13 13 13M9 17C9 16.71 9.32 15 13 15C16.5 15 16.94 16.56 17 17M24 17V19H21V17A5.6 5.6 0 0 0 19.2 13.06C24 13.55 24 17 24 17M8 12H0V10H8Z\";\r\nvar mdiAccountMultipleOutline = \"M13.07 10.41A5 5 0 0 0 13.07 4.59A3.39 3.39 0 0 1 15 4A3.5 3.5 0 0 1 15 11A3.39 3.39 0 0 1 13.07 10.41M5.5 7.5A3.5 3.5 0 1 1 9 11A3.5 3.5 0 0 1 5.5 7.5M7.5 7.5A1.5 1.5 0 1 0 9 6A1.5 1.5 0 0 0 7.5 7.5M16 17V19H2V17S2 13 9 13 16 17 16 17M14 17C13.86 16.22 12.67 15 9 15S4.07 16.31 4 17M15.95 13A5.32 5.32 0 0 1 18 17V19H22V17S22 13.37 15.94 13Z\";\r\nvar mdiAccountMultiplePlus = \"M19 17V19H7V17S7 13 13 13 19 17 19 17M16 8A3 3 0 1 0 13 11A3 3 0 0 0 16 8M19.2 13.06A5.6 5.6 0 0 1 21 17V19H24V17S24 13.55 19.2 13.06M18 5A2.91 2.91 0 0 0 17.11 5.14A5 5 0 0 1 17.11 10.86A2.91 2.91 0 0 0 18 11A3 3 0 0 0 18 5M8 10H5V7H3V10H0V12H3V15H5V12H8Z\";\r\nvar mdiAccountMultiplePlusOutline = \"M13 11A3 3 0 1 0 10 8A3 3 0 0 0 13 11M13 7A1 1 0 1 1 12 8A1 1 0 0 1 13 7M17.11 10.86A5 5 0 0 0 17.11 5.14A2.91 2.91 0 0 1 18 5A3 3 0 0 1 18 11A2.91 2.91 0 0 1 17.11 10.86M13 13C7 13 7 17 7 17V19H19V17S19 13 13 13M9 17C9 16.71 9.32 15 13 15C16.5 15 16.94 16.56 17 17M24 17V19H21V17A5.6 5.6 0 0 0 19.2 13.06C24 13.55 24 17 24 17M8 12H5V15H3V12H0V10H3V7H5V10H8Z\";\r\nvar mdiAccountMultipleRemove = \"M24 17V19H21V17C21 15.45 20.3 14.06 19.18 13.06C24 13.55 24 17 24 17M18 5C19.66 5 21 6.34 21 8C21 9.66 19.66 11 18 11C17.69 11 17.38 10.95 17.1 10.86C17.67 10.05 18 9.07 18 8C18 6.94 17.67 5.95 17.1 5.14C17.38 5.05 17.69 5 18 5M13 5C14.66 5 16 6.34 16 8C16 9.66 14.66 11 13 11C11.34 11 10 9.66 10 8C10 6.34 11.34 5 13 5M19 17V19H7V17C7 14.79 9.69 13 13 13C16.31 13 19 14.79 19 17M.464 13.12L2.59 11L.464 8.88L1.88 7.46L4 9.59L6.12 7.46L7.54 8.88L5.41 11L7.54 13.12L6.12 14.54L4 12.41L1.88 14.54Z\";\r\nvar mdiAccountMultipleRemoveOutline = \"M24 17V19H21V17C21 15.45 20.3 14.06 19.18 13.06C24 13.55 24 17 24 17M18 5C19.66 5 21 6.34 21 8C21 9.66 19.66 11 18 11C17.69 11 17.38 10.95 17.1 10.86C17.67 10.05 18 9.07 18 8C18 6.94 17.67 5.95 17.1 5.14C17.38 5.05 17.69 5 18 5M13 5C14.66 5 16 6.34 16 8C16 9.66 14.66 11 13 11C11.34 11 10 9.66 10 8C10 6.34 11.34 5 13 5M19 17V19H7V17C7 14.79 9.69 13 13 13C16.31 13 19 14.79 19 17M13 7C12.45 7 12 7.45 12 8C12 8.55 12.45 9 13 9C13.55 9 14 8.55 14 8C14 7.45 13.55 7 13 7M13 15C10.79 15 9 15.9 9 17H17C17 15.9 15.21 15 13 15M.464 13.12L2.59 11L.464 8.88L1.88 7.46L4 9.59L6.12 7.46L7.54 8.88L5.41 11L7.54 13.12L6.12 14.54L4 12.41L1.88 14.54Z\";\r\nvar mdiAccountMusic = \"M11,14C12,14 13.05,14.16 14.2,14.44C13.39,15.31 13,16.33 13,17.5C13,18.39 13.25,19.23 13.78,20H3V18C3,16.81 3.91,15.85 5.74,15.12C7.57,14.38 9.33,14 11,14M11,12C9.92,12 9,11.61 8.18,10.83C7.38,10.05 7,9.11 7,8C7,6.92 7.38,6 8.18,5.18C9,4.38 9.92,4 11,4C12.11,4 13.05,4.38 13.83,5.18C14.61,6 15,6.92 15,8C15,9.11 14.61,10.05 13.83,10.83C13.05,11.61 12.11,12 11,12M18.5,10H20L22,10V12H20V17.5A2.5,2.5 0 0,1 17.5,20A2.5,2.5 0 0,1 15,17.5A2.5,2.5 0 0,1 17.5,15C17.86,15 18.19,15.07 18.5,15.21V10Z\";\r\nvar mdiAccountMusicOutline = \"M11,4A4,4 0 0,1 15,8A4,4 0 0,1 11,12A4,4 0 0,1 7,8A4,4 0 0,1 11,4M11,6A2,2 0 0,0 9,8A2,2 0 0,0 11,10A2,2 0 0,0 13,8A2,2 0 0,0 11,6M11,13C12.1,13 13.66,13.23 15.11,13.69C14.5,14.07 14,14.6 13.61,15.23C12.79,15.03 11.89,14.9 11,14.9C8.03,14.9 4.9,16.36 4.9,17V18.1H13.04C13.13,18.8 13.38,19.44 13.76,20H3V17C3,14.34 8.33,13 11,13M18.5,10H20L22,10V12H20V17.5A2.5,2.5 0 0,1 17.5,20A2.5,2.5 0 0,1 15,17.5A2.5,2.5 0 0,1 17.5,15C17.86,15 18.19,15.07 18.5,15.21V10Z\";\r\nvar mdiAccountNetwork = \"M13,17V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H5V15.5C5,13.57 8.13,12 12,12C15.87,12 19,13.57 19,15.5V17H13M12,3A3.5,3.5 0 0,1 15.5,6.5A3.5,3.5 0 0,1 12,10A3.5,3.5 0 0,1 8.5,6.5A3.5,3.5 0 0,1 12,3Z\";\r\nvar mdiAccountNetworkOutline = \"M12,10A3.5,3.5 0 0,0 15.5,6.5A3.5,3.5 0 0,0 12,3A3.5,3.5 0 0,0 8.5,6.5A3.5,3.5 0 0,0 12,10M12,5A1.5,1.5 0 0,1 13.5,6.5A1.5,1.5 0 0,1 12,8A1.5,1.5 0 0,1 10.5,6.5A1.5,1.5 0 0,1 12,5M15,20A1,1 0 0,0 14,19H13V17H19V15.5C19,13.57 15.87,12 12,12C8.13,12 5,13.57 5,15.5V17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7.61,15C8.39,14.53 9.89,14 12,14C14.11,14 15.61,14.53 16.39,15H7.61Z\";\r\nvar mdiAccountOff = \"M12,4A4,4 0 0,1 16,8C16,9.95 14.6,11.58 12.75,11.93L8.07,7.25C8.42,5.4 10.05,4 12,4M12.28,14L18.28,20L20,21.72L18.73,23L15.73,20H4V18C4,16.16 6.5,14.61 9.87,14.14L2.78,7.05L4.05,5.78L12.28,14M20,18V19.18L15.14,14.32C18,14.93 20,16.35 20,18Z\";\r\nvar mdiAccountOffOutline = \"M2.75,7L4.03,5.75L13.26,15L20,21.72L18.73,23L15.73,20H4V17C4,15.14 6.61,13.92 9.09,13.36L2.75,7M20,17V19.18L18.1,17.28V17C18.1,16.74 17.6,16.35 16.8,16L14,13.18C16.71,13.63 20,14.91 20,17M5.9,17V18.1H13.83L10.72,15C8.19,15.3 5.9,16.45 5.9,17M12,4A4,4 0 0,1 16,8C16,9.95 14.6,11.58 12.75,11.93L8.07,7.25C8.42,5.4 10.05,4 12,4M12,6A2,2 0 0,0 10,8A2,2 0 0,0 12,10A2,2 0 0,0 14,8A2,2 0 0,0 12,6Z\";\r\nvar mdiAccountOutline = \"M12,4A4,4 0 0,1 16,8A4,4 0 0,1 12,12A4,4 0 0,1 8,8A4,4 0 0,1 12,4M12,6A2,2 0 0,0 10,8A2,2 0 0,0 12,10A2,2 0 0,0 14,8A2,2 0 0,0 12,6M12,13C14.67,13 20,14.33 20,17V20H4V17C4,14.33 9.33,13 12,13M12,14.9C9.03,14.9 5.9,16.36 5.9,17V18.1H18.1V17C18.1,16.36 14.97,14.9 12,14.9Z\";\r\nvar mdiAccountPlus = \"M15,14C12.33,14 7,15.33 7,18V20H23V18C23,15.33 17.67,14 15,14M6,10V7H4V10H1V12H4V15H6V12H9V10M15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12Z\";\r\nvar mdiAccountPlusOutline = \"M15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4M15,5.9C16.16,5.9 17.1,6.84 17.1,8C17.1,9.16 16.16,10.1 15,10.1A2.1,2.1 0 0,1 12.9,8A2.1,2.1 0 0,1 15,5.9M4,7V10H1V12H4V15H6V12H9V10H6V7H4M15,13C12.33,13 7,14.33 7,17V20H23V17C23,14.33 17.67,13 15,13M15,14.9C17.97,14.9 21.1,16.36 21.1,17V18.1H8.9V17C8.9,16.36 12,14.9 15,14.9Z\";\r\nvar mdiAccountQuestion = \"M13,8A4,4 0 0,1 9,12A4,4 0 0,1 5,8A4,4 0 0,1 9,4A4,4 0 0,1 13,8M17,18V20H1V18C1,15.79 4.58,14 9,14C13.42,14 17,15.79 17,18M20.5,14.5V16H19V14.5H20.5M18.5,9.5H17V9A3,3 0 0,1 20,6A3,3 0 0,1 23,9C23,9.97 22.5,10.88 21.71,11.41L21.41,11.6C20.84,12 20.5,12.61 20.5,13.3V13.5H19V13.3C19,12.11 19.6,11 20.59,10.35L20.88,10.16C21.27,9.9 21.5,9.47 21.5,9A1.5,1.5 0 0,0 20,7.5A1.5,1.5 0 0,0 18.5,9V9.5Z\";\r\nvar mdiAccountQuestionOutline = \"M20.5,14.5V16H19V14.5H20.5M18.5,9.5H17V9A3,3 0 0,1 20,6A3,3 0 0,1 23,9C23,9.97 22.5,10.88 21.71,11.41L21.41,11.6C20.84,12 20.5,12.61 20.5,13.3V13.5H19V13.3C19,12.11 19.6,11 20.59,10.35L20.88,10.16C21.27,9.9 21.5,9.47 21.5,9A1.5,1.5 0 0,0 20,7.5A1.5,1.5 0 0,0 18.5,9V9.5M9,13C11.67,13 17,14.34 17,17V20H1V17C1,14.34 6.33,13 9,13M9,4A4,4 0 0,1 13,8A4,4 0 0,1 9,12A4,4 0 0,1 5,8A4,4 0 0,1 9,4M9,14.9C6.03,14.9 2.9,16.36 2.9,17V18.1H15.1V17C15.1,16.36 11.97,14.9 9,14.9M9,5.9A2.1,2.1 0 0,0 6.9,8A2.1,2.1 0 0,0 9,10.1A2.1,2.1 0 0,0 11.1,8A2.1,2.1 0 0,0 9,5.9Z\";\r\nvar mdiAccountReactivate = \"M21.5 9H16.5L18.36 7.14C16.9 5.23 14.59 4 12 4C7.58 4 4 7.58 4 12C4 13.83 4.61 15.5 5.64 16.85C6.86 15.45 9.15 14.5 12 14.5C14.85 14.5 17.15 15.45 18.36 16.85C19.39 15.5 20 13.83 20 12H22C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C15.14 2 17.95 3.45 19.78 5.72L21.5 4V9M12 7C13.66 7 15 8.34 15 10C15 11.66 13.66 13 12 13C10.34 13 9 11.66 9 10C9 8.34 10.34 7 12 7Z\";\r\nvar mdiAccountReactivateOutline = \"M21.5 9H16.5L18.36 7.14C16.9 5.23 14.59 4 12 4C7.58 4 4 7.58 4 12C4 13.83 4.61 15.5 5.64 16.85C6.86 15.45 9.15 14.5 12 14.5C14.85 14.5 17.15 15.45 18.36 16.85C19.39 15.5 20 13.83 20 12H22C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C15.14 2 17.95 3.45 19.78 5.72L21.5 4V9M12 20C13.9 20 15.64 19.34 17 18.24C16.36 17.23 14.45 16.5 12 16.5C9.55 16.5 7.64 17.23 7 18.24C8.36 19.34 10.1 20 12 20M12 6C13.93 6 15.5 7.57 15.5 9.5C15.5 11.43 13.93 13 12 13C10.07 13 8.5 11.43 8.5 9.5C8.5 7.57 10.07 6 12 6M12 8C11.17 8 10.5 8.67 10.5 9.5C10.5 10.33 11.17 11 12 11C12.83 11 13.5 10.33 13.5 9.5C13.5 8.67 12.83 8 12 8Z\";\r\nvar mdiAccountRemove = \"M15,14C17.67,14 23,15.33 23,18V20H7V18C7,15.33 12.33,14 15,14M15,12A4,4 0 0,1 11,8A4,4 0 0,1 15,4A4,4 0 0,1 19,8A4,4 0 0,1 15,12M5,9.59L7.12,7.46L8.54,8.88L6.41,11L8.54,13.12L7.12,14.54L5,12.41L2.88,14.54L1.46,13.12L3.59,11L1.46,8.88L2.88,7.46L5,9.59Z\";\r\nvar mdiAccountRemoveOutline = \"M1.46,8.88L2.88,7.46L5,9.59L7.12,7.46L8.54,8.88L6.41,11L8.54,13.12L7.12,14.54L5,12.41L2.88,14.54L1.46,13.12L3.59,11L1.46,8.88M15,4A4,4 0 0,1 19,8A4,4 0 0,1 15,12A4,4 0 0,1 11,8A4,4 0 0,1 15,4M15,5.9A2.1,2.1 0 0,0 12.9,8A2.1,2.1 0 0,0 15,10.1C16.16,10.1 17.1,9.16 17.1,8C17.1,6.84 16.16,5.9 15,5.9M15,13C17.67,13 23,14.33 23,17V20H7V17C7,14.33 12.33,13 15,13M15,14.9C12,14.9 8.9,16.36 8.9,17V18.1H21.1V17C21.1,16.36 17.97,14.9 15,14.9Z\";\r\nvar mdiAccountSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M10,4A4,4 0 0,1 14,8C14,8.91 13.69,9.75 13.18,10.43C12.32,10.75 11.55,11.26 10.91,11.9L10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M2,20V18C2,15.88 5.31,14.14 9.5,14C9.18,14.78 9,15.62 9,16.5C9,17.79 9.38,19 10,20H2Z\";\r\nvar mdiAccountSearchOutline = \"M10,13C9.65,13.59 9.36,14.24 9.19,14.93C6.5,15.16 3.9,16.42 3.9,17V18.1H9.2C9.37,18.78 9.65,19.42 10,20H2V17C2,14.34 7.33,13 10,13M10,4A4,4 0 0,1 14,8C14,8.91 13.69,9.75 13.18,10.43C12.32,10.75 11.55,11.26 10.91,11.9L10,12A4,4 0 0,1 6,8A4,4 0 0,1 10,4M10,5.9A2.1,2.1 0 0,0 7.9,8A2.1,2.1 0 0,0 10,10.1A2.1,2.1 0 0,0 12.1,8A2.1,2.1 0 0,0 10,5.9M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14Z\";\r\nvar mdiAccountSettings = \"M12,4A4,4 0 0,1 16,8A4,4 0 0,1 12,12A4,4 0 0,1 8,8A4,4 0 0,1 12,4M12,14C16.42,14 20,15.79 20,18V20H4V18C4,15.79 7.58,14 12,14M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiAccountSettingsOutline = \"M12 4C14.21 4 16 5.79 16 8S14.21 12 12 12 8 10.21 8 8 9.79 4 12 4M12 6C10.9 6 10 6.9 10 8S10.9 10 12 10 14 9.11 14 8 13.11 6 12 6M12 13C14.67 13 20 14.33 20 17V20H4V17C4 14.33 9.33 13 12 13M12 14.9C9.03 14.9 5.9 16.36 5.9 17V18.1H18.1V17C18.1 16.36 14.97 14.9 12 14.9M13 22H11V24H13V22M17 22H15V24H17V22M9 22H7V24H9V22Z\";\r\nvar mdiAccountStar = \"M15,14C12.33,14 7,15.33 7,18V20H23V18C23,15.33 17.67,14 15,14M15,12A4,4 0 0,0 19,8A4,4 0 0,0 15,4A4,4 0 0,0 11,8A4,4 0 0,0 15,12M5,13.28L7.45,14.77L6.8,11.96L9,10.08L6.11,9.83L5,7.19L3.87,9.83L1,10.08L3.18,11.96L2.5,14.77L5,13.28Z\";\r\nvar mdiAccountStarOutline = \"M15,4A4,4 0 0,1 19,8A4,4 0 0,1 15,12A4,4 0 0,1 11,8A4,4 0 0,1 15,4M15,5.9A2.1,2.1 0 0,0 12.9,8A2.1,2.1 0 0,0 15,10.1C16.16,10.1 17.1,9.16 17.1,8C17.1,6.84 16.16,5.9 15,5.9M15,13C17.67,13 23,14.33 23,17V20H7V17C7,14.33 12.33,13 15,13M15,14.9C12,14.9 8.9,16.36 8.9,17V18.1H21.1V17C21.1,16.36 17.97,14.9 15,14.9M5,13.28L2.5,14.77L3.18,11.96L1,10.08L3.87,9.83L5,7.19L6.11,9.83L9,10.08L6.8,11.96L7.45,14.77L5,13.28Z\";\r\nvar mdiAccountSupervisor = \"M16.5,12A2.5,2.5 0 0,0 19,9.5A2.5,2.5 0 0,0 16.5,7A2.5,2.5 0 0,0 14,9.5A2.5,2.5 0 0,0 16.5,12M9,11A3,3 0 0,0 12,8A3,3 0 0,0 9,5A3,3 0 0,0 6,8A3,3 0 0,0 9,11M16.5,14C14.67,14 11,14.92 11,16.75V19H22V16.75C22,14.92 18.33,14 16.5,14M9,13C6.67,13 2,14.17 2,16.5V19H9V16.75C9,15.9 9.33,14.41 11.37,13.28C10.5,13.1 9.66,13 9,13Z\";\r\nvar mdiAccountSupervisorCircle = \"M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M15.6,8.34C16.67,8.34 17.53,9.2 17.53,10.27C17.53,11.34 16.67,12.2 15.6,12.2A1.93,1.93 0 0,1 13.67,10.27C13.66,9.2 14.53,8.34 15.6,8.34M9.6,6.76C10.9,6.76 11.96,7.82 11.96,9.12C11.96,10.42 10.9,11.5 9.6,11.5C8.3,11.5 7.24,10.42 7.24,9.12C7.24,7.81 8.29,6.76 9.6,6.76M9.6,15.89V19.64C7.2,18.89 5.3,17.04 4.46,14.68C5.5,13.56 8.13,13 9.6,13C10.13,13 10.8,13.07 11.5,13.21C9.86,14.08 9.6,15.23 9.6,15.89M12,20C11.72,20 11.46,20 11.2,19.96V15.89C11.2,14.47 14.14,13.76 15.6,13.76C16.67,13.76 18.5,14.15 19.44,14.91C18.27,17.88 15.38,20 12,20Z\";\r\nvar mdiAccountSupervisorCircleOutline = \"M12.5 10C12.5 8.34 11.16 7 9.5 7C7.86 7 6.5 8.34 6.5 10C6.5 11.64 7.86 13 9.5 13C11.16 13 12.5 11.64 12.5 10M9.5 11C8.96 11 8.5 10.54 8.5 10C8.5 9.44 8.96 9 9.5 9C10.06 9 10.5 9.44 10.5 10C10.5 10.54 10.06 11 9.5 11M16 13C17.12 13 18 12.1 18 11C18 9.88 17.12 9 16 9C14.9 9 14 9.88 14 11C14 12.1 14.9 13 16 13M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 6.5 17.5 2 12 2M5.85 17.11C6.53 16.57 8.12 16 9.5 16C9.58 16 9.66 16 9.74 16C10 15.37 10.41 14.72 11.04 14.15C10.5 14.05 9.95 14 9.5 14C8.21 14 6.12 14.44 4.78 15.42C4.28 14.38 4 13.22 4 12C4 7.58 7.59 4 12 4C16.41 4 20 7.58 20 12C20 13.19 19.73 14.33 19.25 15.36C18.25 14.77 16.89 14.5 16 14.5C14.5 14.5 11.5 15.3 11.5 17.19V19.97C9.24 19.84 7.22 18.76 5.85 17.11Z\";\r\nvar mdiAccountSupervisorOutline = \"M16.5 15.5C18.22 15.5 20.25 16.3 20.5 16.78V17.5H12.5V16.78C12.75 16.3 14.78 15.5 16.5 15.5M16.5 14C14.67 14 11 14.92 11 16.75V19H22V16.75C22 14.92 18.33 14 16.5 14M9 13C6.67 13 2 14.17 2 16.5V19H9V17.5H3.5V16.5C3.5 15.87 6.29 14.34 9.82 14.5A5.12 5.12 0 0 1 11.37 13.25A12.28 12.28 0 0 0 9 13M9 6.5A1.5 1.5 0 1 1 7.5 8A1.5 1.5 0 0 1 9 6.5M9 5A3 3 0 1 0 12 8A3 3 0 0 0 9 5M16.5 8.5A1 1 0 1 1 15.5 9.5A1 1 0 0 1 16.5 8.5M16.5 7A2.5 2.5 0 1 0 19 9.5A2.5 2.5 0 0 0 16.5 7Z\";\r\nvar mdiAccountSwitch = \"M16 9C22 9 22 13 22 13V15H16V13C16 13 16 11.31 14.85 9.8C14.68 9.57 14.47 9.35 14.25 9.14C14.77 9.06 15.34 9 16 9M2 13C2 13 2 9 8 9S14 13 14 13V15H2V13M9 17V19H15V17L18 20L15 23V21H9V23L6 20L9 17M8 1C6.34 1 5 2.34 5 4S6.34 7 8 7 11 5.66 11 4 9.66 1 8 1M16 1C14.34 1 13 2.34 13 4S14.34 7 16 7 19 5.66 19 4 17.66 1 16 1Z\";\r\nvar mdiAccountSwitchOutline = \"M16 9C22 9 22 13 22 13V15H16V13C16 13 16 11.31 14.85 9.8C14.68 9.57 14.47 9.35 14.25 9.14C14.77 9.06 15.34 9 16 9M8 11C11.5 11 11.94 12.56 12 13H4C4.06 12.56 4.5 11 8 11M8 9C2 9 2 13 2 13V15H14V13C14 13 14 9 8 9M9 17V19H15V17L18 20L15 23V21H9V23L6 20L9 17M8 3C8.55 3 9 3.45 9 4S8.55 5 8 5 7 4.55 7 4 7.45 3 8 3M8 1C6.34 1 5 2.34 5 4S6.34 7 8 7 11 5.66 11 4 9.66 1 8 1M16 1C14.34 1 13 2.34 13 4S14.34 7 16 7 19 5.66 19 4 17.66 1 16 1Z\";\r\nvar mdiAccountTie = \"M12 3C14.21 3 16 4.79 16 7S14.21 11 12 11 8 9.21 8 7 9.79 3 12 3M16 13.54C16 14.6 15.72 17.07 13.81 19.83L13 15L13.94 13.12C13.32 13.05 12.67 13 12 13S10.68 13.05 10.06 13.12L11 15L10.19 19.83C8.28 17.07 8 14.6 8 13.54C5.61 14.24 4 15.5 4 17V21H20V17C20 15.5 18.4 14.24 16 13.54Z\";\r\nvar mdiAccountTieOutline = \"M16.36 12.76C18.31 13.42 20 14.5 20 16V21H4V16C4 14.5 5.69 13.42 7.65 12.76L8.27 14L8.5 14.5C7 14.96 5.9 15.62 5.9 16V19.1H10.12L11 14.03L10.06 12.15C10.68 12.08 11.33 12.03 12 12.03C12.67 12.03 13.32 12.08 13.94 12.15L13 14.03L13.88 19.1H18.1V16C18.1 15.62 17 14.96 15.5 14.5L15.73 14L16.36 12.76M12 5C10.9 5 10 5.9 10 7C10 8.1 10.9 9 12 9C13.1 9 14 8.1 14 7C14 5.9 13.1 5 12 5M12 11C9.79 11 8 9.21 8 7C8 4.79 9.79 3 12 3C14.21 3 16 4.79 16 7C16 9.21 14.21 11 12 11Z\";\r\nvar mdiAccountTieVoice = \"M16.75 4.36C18.77 6.56 18.77 9.61 16.75 11.63L15.07 9.94C15.91 8.76 15.91 7.23 15.07 6.05L16.75 4.36M20.06 1C24 5.05 23.96 11.11 20.06 15L18.43 13.37C21.2 10.19 21.2 5.65 18.43 2.63L20.06 1M9 4C11.2 4 13 5.79 13 8S11.2 12 9 12 5 10.21 5 8 6.79 4 9 4M13 14.54C13 15.6 12.71 18.07 10.8 20.83L10 16L10.93 14.12C10.31 14.05 9.66 14 9 14S7.67 14.05 7.05 14.12L8 16L7.18 20.83C5.27 18.07 5 15.6 5 14.54C2.6 15.24 .994 16.5 .994 18V22H17V18C17 16.5 15.39 15.24 13 14.54Z\";\r\nvar mdiAccountTieVoiceOff = \"M12.7 9.5L7.5 4.3C7.96 4.11 8.46 4 9 4C11.2 4 13 5.79 13 8C13 8.53 12.89 9.04 12.7 9.5M16.75 11.63C18.77 9.61 18.77 6.56 16.75 4.36L15.07 6.05C15.91 7.23 15.91 8.76 15.07 9.94L16.75 11.63M20.06 15C23.96 11.11 24 5.05 20.06 1L18.43 2.63C21.2 5.65 21.2 10.19 18.43 13.37L20.06 15M2.39 1.73L1.11 3L5.13 7C5.05 7.34 5 7.66 5 8C5 10.21 6.79 12 9 12C9.33 12 9.66 11.94 9.97 11.86L13 14.87C12.93 16.06 12.54 18.32 10.8 20.83L10 16L10.93 14.12C10.31 14.05 9.66 14 9 14C8.32 14 7.67 14.05 7.05 14.12L8 16L7.18 20.83C5.27 18.07 5 15.6 5 14.54C2.6 15.24 .994 16.5 .994 18V22H17V18.88L20.84 22.73L22.11 21.46L2.39 1.73Z\";\r\nvar mdiAccountTieVoiceOffOutline = \"M9.22 6L7.5 4.3C7.96 4.11 8.47 4 9 4C11.21 4 13 5.79 13 8C13 8.53 12.89 9.04 12.7 9.5L11 7.78C10.87 6.86 10.14 6.13 9.22 6M20.06 15C23.96 11.11 24 5.05 20.06 1L18.43 2.63C21.2 5.65 21.2 10.19 18.43 13.37L20.06 15M16.75 11.63C18.77 9.61 18.77 6.56 16.75 4.36L15.07 6.05C15.91 7.23 15.91 8.76 15.07 9.94L16.75 11.63M2.39 1.73L1.11 3L5.14 7.03C5.06 7.34 5 7.66 5 8C5 10.21 6.79 12 9 12C9.34 12 9.66 11.94 9.97 11.86L12.86 14.75L12.73 15L12.5 15.5C13.3 15.74 13.97 16.05 14.44 16.33L15.1 17V20.1H10.88L10 15.03L10.94 13.15C10.32 13.08 9.67 13.03 9 13.03S7.68 13.08 7.06 13.15L8 15.03L7.12 20.1H2.9V17C2.9 16.62 4 15.96 5.5 15.5L5.27 15L4.65 13.76C2.69 14.42 1 15.5 1 17V22H17V18.89L20.84 22.73L22.11 21.46L2.39 1.73Z\";\r\nvar mdiAccountTieVoiceOutline = \"M16.75 4.36C18.77 6.56 18.77 9.61 16.75 11.63L15.07 9.94C15.91 8.76 15.91 7.23 15.07 6.05L16.75 4.36M20.06 1C24 5.05 23.96 11.11 20.06 15L18.43 13.37C21.2 10.19 21.2 5.65 18.43 2.63L20.06 1M13.36 13.76C15.31 14.42 17 15.5 17 17V22H1V17C1 15.5 2.69 14.42 4.65 13.76L5.27 15L5.5 15.5C4 15.96 2.9 16.62 2.9 17V20.1H7.12L8 15.03L7.06 13.15C7.68 13.08 8.33 13.03 9 13.03S10.32 13.08 10.94 13.15L10 15.03L10.88 20.1H15.1V17C15.1 16.62 14 15.96 12.5 15.5L12.73 15L13.36 13.76M9 6C7.9 6 7 6.9 7 8S7.9 10 9 10 11 9.1 11 8 10.1 6 9 6M9 12C6.79 12 5 10.21 5 8S6.79 4 9 4 13 5.79 13 8 11.21 12 9 12Z\";\r\nvar mdiAccountVoice = \"M9,5A4,4 0 0,1 13,9A4,4 0 0,1 9,13A4,4 0 0,1 5,9A4,4 0 0,1 9,5M9,15C11.67,15 17,16.34 17,19V21H1V19C1,16.34 6.33,15 9,15M16.76,5.36C18.78,7.56 18.78,10.61 16.76,12.63L15.08,10.94C15.92,9.76 15.92,8.23 15.08,7.05L16.76,5.36M20.07,2C24,6.05 23.97,12.11 20.07,16L18.44,14.37C21.21,11.19 21.21,6.65 18.44,3.63L20.07,2Z\";\r\nvar mdiAdjust = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9A3,3 0 0,1 15,12Z\";\r\nvar mdiAdobe = \"M14.58,3H22V19.67L14.58,3M9.42,3H2V19.67L9.42,3M12,9.17L16.67,19.67H13.5L12.17,16.33H8.75L12,9.17Z\";\r\nvar mdiAdobeAcrobat = \"M21.8 14.5C21.3 13.7 20.1 13.4 18.1 13.4C17.4 13.4 16.7 13.4 16 13.5C15.5 13.2 15 12.9 14.6 12.6C13.6 11.8 12.7 10.3 12 8.5C12 8.5 12 8.4 12.1 8.3C12.6 6.2 13.1 3.6 12.1 2.5C11.8 2.2 11.5 2.1 11.1 2.1H10.7C10.1 2.1 9.6 2.7 9.4 3.3C8.8 5.4 9.2 6.6 9.8 8.5C9.4 10 8.9 11.6 8 13.3C7.5 14.4 6.9 15.4 6.5 16.2C5.9 16.5 5.4 16.8 5.1 17C3.2 18.2 2.2 19.6 2.1 20.4C2 20.7 2 21 2.1 21.2V21.3L2.9 21.8C3.1 21.9 3.4 22 3.6 22C4.9 22 6.4 20.5 8.4 17C8.5 17 8.6 16.9 8.7 16.9C10.4 16.4 12.4 16 15.2 15.7C16.8 16.5 18.8 16.9 20 16.9C20.7 16.9 21.2 16.7 21.5 16.4C21.8 16.1 21.9 15.7 22 15.3C22 15 22 14.7 21.8 14.5M3.4 20.9C3.5 20.3 4.2 19.2 5.4 18.2C5.6 18.1 5.8 17.9 6.2 17.7C5 19.6 4.1 20.6 3.4 20.9M10.8 3.2C10.9 3.1 10.9 3 11 3L11.2 3.1C11.5 3.5 11.5 4 11.3 4.9V5.2C11.2 5.6 11.2 6 11 6.5C10.6 5 10.6 3.9 10.8 3.2M8.8 15.8L8.6 15.9C8.7 15.4 9.1 14.8 9.4 14.2C10.1 12.8 10.7 11.5 11 10.3C11.7 11.8 12.5 12.9 13.5 13.8C13.7 14 13.9 14.2 14.2 14.3C12.8 14.5 10.9 15 8.8 15.8M20.9 15.7H20.5C19.8 15.7 18.6 15.4 17.4 14.9C17.5 14.7 17.7 14.7 17.8 14.7C20.1 14.7 20.7 15.1 20.9 15.3C21 15.4 21 15.4 21 15.5C21 15.6 21 15.6 20.9 15.7Z\";\r\nvar mdiAirConditioner = \"M6.59,0.66C8.93,-1.15 11.47,1.06 12.04,4.5C12.47,4.5 12.89,4.62 13.27,4.84C13.79,4.24 14.25,3.42 14.07,2.5C13.65,0.35 16.06,-1.39 18.35,1.58C20.16,3.92 17.95,6.46 14.5,7.03C14.5,7.46 14.39,7.89 14.16,8.27C14.76,8.78 15.58,9.24 16.5,9.06C18.63,8.64 20.38,11.04 17.41,13.34C15.07,15.15 12.53,12.94 11.96,9.5C11.53,9.5 11.11,9.37 10.74,9.15C10.22,9.75 9.75,10.58 9.93,11.5C10.35,13.64 7.94,15.39 5.65,12.42C3.83,10.07 6.05,7.53 9.5,6.97C9.5,6.54 9.63,6.12 9.85,5.74C9.25,5.23 8.43,4.76 7.5,4.94C5.37,5.36 3.62,2.96 6.59,0.66M5,16H7A2,2 0 0,1 9,18V24H7V22H5V24H3V18A2,2 0 0,1 5,16M5,18V20H7V18H5M12.93,16H15L12.07,24H10L12.93,16M18,16H21V18H18V22H21V24H18A2,2 0 0,1 16,22V18A2,2 0 0,1 18,16Z\";\r\nvar mdiAirFilter = \"M19,18.31V20A2,2 0 0,1 17,22H7A2,2 0 0,1 5,20V16.3C4.54,16.12 3.95,16 3,16A1,1 0 0,1 2,15A1,1 0 0,1 3,14C3.82,14 4.47,14.08 5,14.21V12.3C4.54,12.12 3.95,12 3,12A1,1 0 0,1 2,11A1,1 0 0,1 3,10C3.82,10 4.47,10.08 5,10.21V8.3C4.54,8.12 3.95,8 3,8A1,1 0 0,1 2,7A1,1 0 0,1 3,6C3.82,6 4.47,6.08 5,6.21V4A2,2 0 0,1 7,2H17A2,2 0 0,1 19,4V6.16C20.78,6.47 21.54,7.13 21.71,7.29C22.1,7.68 22.1,8.32 21.71,8.71C21.32,9.1 20.8,9.09 20.29,8.71V8.71C20.29,8.71 19.25,8 17,8C15.74,8 14.91,8.41 13.95,8.9C12.91,9.41 11.74,10 10,10C9.64,10 9.31,10 9,9.96V7.95C9.3,8 9.63,8 10,8C11.26,8 12.09,7.59 13.05,7.11C14.09,6.59 15.27,6 17,6V4H7V20H17V18C18.5,18 18.97,18.29 19,18.31M17,10C15.27,10 14.09,10.59 13.05,11.11C12.09,11.59 11.26,12 10,12C9.63,12 9.3,12 9,11.95V13.96C9.31,14 9.64,14 10,14C11.74,14 12.91,13.41 13.95,12.9C14.91,12.42 15.74,12 17,12C19.25,12 20.29,12.71 20.29,12.71V12.71C20.8,13.1 21.32,13.1 21.71,12.71C22.1,12.32 22.1,11.69 21.71,11.29C21.5,11.08 20.25,10 17,10M17,14C15.27,14 14.09,14.59 13.05,15.11C12.09,15.59 11.26,16 10,16C9.63,16 9.3,16 9,15.95V17.96C9.31,18 9.64,18 10,18C11.74,18 12.91,17.41 13.95,16.9C14.91,16.42 15.74,16 17,16C19.25,16 20.29,16.71 20.29,16.71V16.71C20.8,17.1 21.32,17.1 21.71,16.71C22.1,16.32 22.1,15.69 21.71,15.29C21.5,15.08 20.25,14 17,14Z\";\r\nvar mdiAirHorn = \"M19,2.8V6L19,9.2C19,9.5 18.7,9.8 18.4,9.7C18.4,9.7 14.5,7.1 10,7.1V9.5H10.2C10.7,9.5 11.2,9.7 11.4,10.1L12.7,11.9C12.9,12.1 13,12.4 13,12.6V20.6C13,21.3 12.3,22 11.5,22H6.5C5.7,22 5,21.4 5,20.6V12.6C5,12.3 5.1,12.1 5.3,11.9L6.6,10.1C6.9,9.7 7.3,9.5 7.8,9.5H8V8C7.6,8.5 7,8.8 6.4,8.8C5.1,8.8 4,7.5 4,6C4,4.5 5.1,3.2 6.4,3.2C7,3.3 7.6,3.6 8,4V2.6H10V5C14.5,5 18.4,2.4 18.4,2.4C18.7,2.3 19,2.5 19,2.8Z\";\r\nvar mdiAirHumidifier = \"M11 9C8.79 9 7 10.79 7 13S8.79 17 11 17 15 15.21 15 13 13.21 9 11 9M11 15C9.9 15 9 14.11 9 13S9.9 11 11 11 13 11.9 13 13 12.11 15 11 15M7 4H14C16.21 4 18 5.79 18 8V9H16V8C16 6.9 15.11 6 14 6H7C5.9 6 5 6.9 5 8V20H16V18H18V22H3V8C3 5.79 4.79 4 7 4M19 10.5C19 10.5 21 12.67 21 14C21 15.1 20.1 16 19 16S17 15.1 17 14C17 12.67 19 10.5 19 10.5\";\r\nvar mdiAirHumidifierOff = \"M22.1 21.5L2.4 1.7L1.1 3L3.8 5.7C3.3 6.3 3 7.1 3 8V22H18V19.9L20.8 22.7L22.1 21.5M9.6 11.5L12.4 14.3C12.1 14.7 11.6 15 11 15C9.9 15 9 14.1 9 13C9 12.4 9.3 11.9 9.6 11.5M16 17.9V20H5V8C5 7.7 5.1 7.4 5.2 7.1L8.2 10.1C7.5 10.8 7 11.9 7 13C7 15.2 8.8 17 11 17C12.1 17 13.2 16.5 13.9 15.8L16 17.9M17 13.8C17.1 12.5 19 10.5 19 10.5S21 12.7 21 14C21 15 20.2 15.9 19.2 16L17 13.8M9.2 6L7.2 4H14C16.2 4 18 5.8 18 8V9H16V8C16 6.9 15.1 6 14 6H9.2Z\";\r\nvar mdiAirPurifier = \"M11,9A4,4 0 0,1 15,13A4,4 0 0,1 11,17A4,4 0 0,1 7,13A4,4 0 0,1 11,9M11,11A2,2 0 0,0 9,13A2,2 0 0,0 11,15A2,2 0 0,0 13,13A2,2 0 0,0 11,11M7,4H14A4,4 0 0,1 18,8V9H16V8A2,2 0 0,0 14,6H7A2,2 0 0,0 5,8V20H16V18H18V22H3V8A4,4 0 0,1 7,4M16,11C18.5,11 18.5,9 21,9V11C18.5,11 18.5,13 16,13V11M16,15C18.5,15 18.5,13 21,13V15C18.5,15 18.5,17 16,17V15Z\";\r\nvar mdiAirbag = \"M14,8A5,5 0 0,1 9,13A5,5 0 0,1 4,8A5,5 0 0,1 9,3A5,5 0 0,1 14,8M10.46,15.55L13,18.03L11,18.05L7.5,21.58L6,20.09L10.46,15.55M17,2C18.08,2 19,2.88 19,4C19,5.08 18.12,6 17,6C15.92,6 15,5.12 15,4C15,2.92 15.89,2 17,2M14.41,15H11.59L17.29,20.71L18.71,19.29L14.41,15M15.12,14.29L19.41,18.59L19.63,18.8C19.86,18.42 20,18 20,17.5V9.5A2.5,2.5 0 0,0 17.5,7A2.5,2.5 0 0,0 15,9.5V14.17L15.12,14.29Z\";\r\nvar mdiAirballoon = \"M11,23A2,2 0 0,1 9,21V19H15V21A2,2 0 0,1 13,23H11M12,1C12.71,1 13.39,1.09 14.05,1.26C15.22,2.83 16,5.71 16,9C16,11.28 15.62,13.37 15,16A2,2 0 0,1 13,18H11A2,2 0 0,1 9,16C8.38,13.37 8,11.28 8,9C8,5.71 8.78,2.83 9.95,1.26C10.61,1.09 11.29,1 12,1M20,8C20,11.18 18.15,15.92 15.46,17.21C16.41,15.39 17,11.83 17,9C17,6.17 16.41,3.61 15.46,1.79C18.15,3.08 20,4.82 20,8M4,8C4,4.82 5.85,3.08 8.54,1.79C7.59,3.61 7,6.17 7,9C7,11.83 7.59,15.39 8.54,17.21C5.85,15.92 4,11.18 4,8Z\";\r\nvar mdiAirballoonOutline = \"M11 23C9.9 23 9 22.1 9 21V19H15V21C15 22.1 14.1 23 13 23H11M12 3C12.28 3 12.55 3 12.81 3.05C13.42 4.22 14 6.26 14 9C14 11.1 13 16 13 16H11C11 16 10 11.1 10 9C10 6.26 10.58 4.22 11.19 3.05C11.45 3 11.72 3 12 3M12 1C11.29 1 10.61 1.09 9.95 1.26C8.78 2.83 8 5.71 8 9C8 11.28 8.38 13.37 9 16C9 17.1 9.9 18 11 18H13C14.1 18 15 17.1 15 16C15.62 13.37 16 11.28 16 9C16 5.71 15.22 2.83 14.05 1.26C13.39 1.09 12.71 1 12 1M4 8C4 11.18 5.85 15.92 8.54 17.21C8 16.21 7.61 14.67 7.34 13C6.55 11.53 6 9.62 6 8C6 6.66 6.44 5.67 7.47 4.8C7.73 3.67 8.09 2.65 8.54 1.79C5.85 3.08 4 4.82 4 8M15.46 1.79C15.91 2.65 16.27 3.67 16.53 4.8C17.56 5.67 18 6.66 18 8C18 9.62 17.45 11.53 16.66 13C16.39 14.67 16 16.21 15.46 17.21C18.15 15.92 20 11.18 20 8S18.15 3.08 15.46 1.79Z\";\r\nvar mdiAirplane = \"M21,16V14L13,9V3.5A1.5,1.5 0 0,0 11.5,2A1.5,1.5 0 0,0 10,3.5V9L2,14V16L10,13.5V19L8,20.5V22L11.5,21L15,22V20.5L13,19V13.5L21,16Z\";\r\nvar mdiAirplaneLanding = \"M2.5,19H21.5V21H2.5V19M9.68,13.27L14.03,14.43L19.34,15.85C20.14,16.06 20.96,15.59 21.18,14.79C21.39,14 20.92,13.17 20.12,12.95L14.81,11.53L12.05,2.5L10.12,2V10.28L5.15,8.95L4.22,6.63L2.77,6.24V11.41L4.37,11.84L9.68,13.27Z\";\r\nvar mdiAirplaneOff = \"M3.15,5.27L8.13,10.26L2.15,14V16L10.15,13.5V19L8.15,20.5V22L11.65,21L15.15,22V20.5L13.15,19V15.27L18.87,21L20.15,19.73L4.42,4M13.15,9V3.5A1.5,1.5 0 0,0 11.65,2A1.5,1.5 0 0,0 10.15,3.5V7.18L17.97,15L21.15,16V14L13.15,9Z\";\r\nvar mdiAirplaneTakeoff = \"M2.5,19H21.5V21H2.5V19M22.07,9.64C21.86,8.84 21.03,8.36 20.23,8.58L14.92,10L8,3.57L6.09,4.08L10.23,11.25L5.26,12.58L3.29,11.04L1.84,11.43L3.66,14.59L4.43,15.92L6.03,15.5L11.34,14.07L15.69,12.91L21,11.5C21.81,11.26 22.28,10.44 22.07,9.64Z\";\r\nvar mdiAirport = \"M14.97,5.92C14.83,5.41 14.3,5.1 13.79,5.24L10.39,6.15L5.95,2.03L4.72,2.36L7.38,6.95L4.19,7.8L2.93,6.82L2,7.07L3.66,9.95L14.28,7.11C14.8,6.96 15.1,6.43 14.97,5.92M21,10L20,12H15L14,10L15,9H17V7H18V9H20L21,10M22,20V22H2V20H15V13H20V20H22Z\";\r\nvar mdiAlarm = \"M12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6A7,7 0 0,1 19,13A7,7 0 0,1 12,20M12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,4M12.5,8H11V14L15.75,16.85L16.5,15.62L12.5,13.25V8M7.88,3.39L6.6,1.86L2,5.71L3.29,7.24L7.88,3.39M22,5.72L17.4,1.86L16.11,3.39L20.71,7.25L22,5.72Z\";\r\nvar mdiAlarmBell = \"M15,18.66V22H5V18.66C8.09,20.45 11.91,20.45 15,18.66M22,4A2,2 0 0,0 20,2C19.69,2 19.39,2.07 19.12,2.21C18.82,2.36 18.56,2.58 18.36,2.85C17.72,3.75 17.94,5 18.85,5.64C19.18,5.87 19.59,6 20,6C20.08,6 20.16,6 20.24,6C21.97,10.43 20.66,15.46 17,18.5C16.68,18.75 16.35,19 16,19.22V21H17V19.74C20.14,17.5 22,13.86 22,10C22,8.5 21.72,7 21.17,5.62C21.69,5.24 22,4.64 22,4M18,10A8,8 0 0,1 10,18A8,8 0 0,1 2,10A8,8 0 0,1 10,2A8,8 0 0,1 18,10Z\";\r\nvar mdiAlarmCheck = \"M10.54,14.53L8.41,12.4L7.35,13.46L10.53,16.64L16.53,10.64L15.47,9.58L10.54,14.53M12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6A7,7 0 0,1 19,13A7,7 0 0,1 12,20M12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,4M7.88,3.39L6.6,1.86L2,5.71L3.29,7.24L7.88,3.39M22,5.72L17.4,1.86L16.11,3.39L20.71,7.25L22,5.72Z\";\r\nvar mdiAlarmLight = \"M6,6.9L3.87,4.78L5.28,3.37L7.4,5.5L6,6.9M13,1V4H11V1H13M20.13,4.78L18,6.9L16.6,5.5L18.72,3.37L20.13,4.78M4.5,10.5V12.5H1.5V10.5H4.5M19.5,10.5H22.5V12.5H19.5V10.5M6,20H18A2,2 0 0,1 20,22H4A2,2 0 0,1 6,20M12,5A6,6 0 0,1 18,11V19H6V11A6,6 0 0,1 12,5Z\";\r\nvar mdiAlarmLightOutline = \"M6,6.9L3.87,4.78L5.28,3.37L7.4,5.5L6,6.9M13,1V4H11V1H13M20.13,4.78L18,6.9L16.6,5.5L18.72,3.37L20.13,4.78M4.5,10.5V12.5H1.5V10.5H4.5M19.5,10.5H22.5V12.5H19.5V10.5M6,20H18A2,2 0 0,1 20,22H4A2,2 0 0,1 6,20M12,5A6,6 0 0,1 18,11V19H6V11A6,6 0 0,1 12,5M12,7A4,4 0 0,0 8,11V17H16V11A4,4 0 0,0 12,7Z\";\r\nvar mdiAlarmMultiple = \"M9.29,3.25L5.16,6.72L4,5.34L8.14,1.87L9.29,3.25M22,5.35L20.84,6.73L16.7,3.25L17.86,1.87L22,5.35M13,4A8,8 0 0,1 21,12A8,8 0 0,1 13,20A8,8 0 0,1 5,12A8,8 0 0,1 13,4M13,6A6,6 0 0,0 7,12A6,6 0 0,0 13,18A6,6 0 0,0 19,12A6,6 0 0,0 13,6M12,7.5H13.5V12.03L16.72,13.5L16.1,14.86L12,13V7.5M1,14C1,11.5 2.13,9.3 3.91,7.83C3.33,9.1 3,10.5 3,12L3.06,13.13L3,14C3,16.28 4.27,18.26 6.14,19.28C7.44,20.5 9.07,21.39 10.89,21.78C10.28,21.92 9.65,22 9,22A8,8 0 0,1 1,14Z\";\r\nvar mdiAlarmNote = \"M17.4,1.86L16.11,3.39L20.71,7.25L22,5.72L17.4,1.86M6.6,1.86L2,5.71L3.29,7.24L7.88,3.39L6.6,1.86M12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22C12.33,22 12.67,22 13,21.94V19.94C12.67,20 12.33,20 12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6C15.1,6 17.83,8.03 18.71,11H20.78C19.85,6.9 16.2,4 12,4M23,15H20V20.5A2.5,2.5 0 0,1 17.5,23A2.5,2.5 0 0,1 15,20.5A2.5,2.5 0 0,1 17.5,18C18.04,18 18.57,18.18 19,18.5V13H23V15M11.5,8V13.25L7.5,15.62L8.25,16.85L13,14V8H11.5Z\";\r\nvar mdiAlarmNoteOff = \"M19,13V15.8L20,16.8V15H23V13H19M2.38,1.73L1.11,3L3,4.88L2,5.71L3.29,7.24L4.41,6.3L5.21,7.1C1.95,10.85 2.35,16.54 6.11,19.8C7.74,21.22 9.83,22 12,22C12.33,22 12.67,22 13,21.94V19.94C12.67,20 12.33,20 12,20A7,7 0 0,1 5,13C5,11.36 5.57,9.77 6.63,8.5L11.41,13.3L7.5,15.62L8.25,16.85L12.44,14.33L16.38,18.27C15.14,18.88 14.64,20.38 15.25,21.62C15.86,22.86 17.36,23.36 18.6,22.75C19.09,22.5 19.5,22.11 19.73,21.62L20.84,22.73L22.11,21.46L2.38,1.73M12,6C15.1,6 17.83,8.03 18.71,11H20.78C19.85,6.9 16.2,4 12,4C10.65,4 9.31,4.3 8.1,4.9L9.62,6.42C10.38,6.14 11.19,6 12,6M11.5,8.3L13,9.8V8H11.5V8.3M7.88,3.39L6.6,1.86L5.76,2.56L7.18,4L7.88,3.39M17.4,1.86L16.11,3.39L20.71,7.25L22,5.72L17.4,1.86Z\";\r\nvar mdiAlarmOff = \"M8,3.28L6.6,1.86L5.74,2.57L7.16,4M16.47,18.39C15.26,19.39 13.7,20 12,20A7,7 0 0,1 5,13C5,11.3 5.61,9.74 6.61,8.53M2.92,2.29L1.65,3.57L3,4.9L1.87,5.83L3.29,7.25L4.4,6.31L5.2,7.11C3.83,8.69 3,10.75 3,13A9,9 0 0,0 12,22C14.25,22 16.31,21.17 17.89,19.8L20.09,22L21.36,20.73L3.89,3.27L2.92,2.29M22,5.72L17.4,1.86L16.11,3.39L20.71,7.25L22,5.72M12,6A7,7 0 0,1 19,13C19,13.84 18.84,14.65 18.57,15.4L20.09,16.92C20.67,15.73 21,14.41 21,13A9,9 0 0,0 12,4C10.59,4 9.27,4.33 8.08,4.91L9.6,6.43C10.35,6.16 11.16,6 12,6Z\";\r\nvar mdiAlarmPanel = \"M20 3H4C2.9 3 2 3.9 2 5V19C2 20.1 2.9 21 4 21H20C21.1 21 22 20.1 22 19V5C22 3.9 21.1 3 20 3M8 19H5V17H8V19M8 16H5V14H8V16M8 13H5V11H8V13M13.5 19H10.5V17H13.5V19M13.5 16H10.5V14H13.5V16M13.5 13H10.5V11H13.5V13M19 19H16V17H19V19M19 16H16V14H19V16M19 13H16V11H19V13M19 9H5V5H19V9Z\";\r\nvar mdiAlarmPanelOutline = \"M9 12H6V10H9V12M13.5 10H10.5V12H13.5V10M18 10H15V12H18V10M18 6H6V9H18V6M20 5H4L4 19L20 19L20 5L20 5M20 3C21.1 3 22 3.9 22 5V19C22 20.1 21.1 21 20 21H4C2.9 21 2 20.1 2 19V5C2 3.9 2.9 3 4 3H20M9 13H6V15H9V13M13.5 13H10.5V15H13.5V13M18 13H15V15H18V13M9 16H6V18H9V16M13.5 16H10.5V18H13.5V16M18 16H15V18H18V16Z\";\r\nvar mdiAlarmPlus = \"M13,9H11V12H8V14H11V17H13V14H16V12H13M12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6A7,7 0 0,1 19,13A7,7 0 0,1 12,20M12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,4M22,5.72L17.4,1.86L16.11,3.39L20.71,7.25M7.88,3.39L6.6,1.86L2,5.71L3.29,7.24L7.88,3.39Z\";\r\nvar mdiAlarmSnooze = \"M7.88,3.39L6.6,1.86L2,5.71L3.29,7.24L7.88,3.39M22,5.72L17.4,1.86L16.11,3.39L20.71,7.25L22,5.72M12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,4M12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6A7,7 0 0,1 19,13A7,7 0 0,1 12,20M9,11H12.63L9,15.2V17H15V15H11.37L15,10.8V9H9V11Z\";\r\nvar mdiAlbum = \"M12,11A1,1 0 0,0 11,12A1,1 0 0,0 12,13A1,1 0 0,0 13,12A1,1 0 0,0 12,11M12,16.5C9.5,16.5 7.5,14.5 7.5,12C7.5,9.5 9.5,7.5 12,7.5C14.5,7.5 16.5,9.5 16.5,12C16.5,14.5 14.5,16.5 12,16.5M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiAlert = \"M13 14H11V9H13M13 18H11V16H13M1 21H23L12 2L1 21Z\";\r\nvar mdiAlertBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M13,13V7H11V13H13M13,17V15H11V17H13Z\";\r\nvar mdiAlertBoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M11,15H13V17H11V15M11,7H13V13H11V7\";\r\nvar mdiAlertCircle = \"M13,13H11V7H13M13,17H11V15H13M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiAlertCircleCheck = \"M18.75 22.16L16 19.16L17.16 18L18.75 19.59L22.34 16L23.5 17.41L18.75 22.16M13 13V7H11V13H13M13 17V15H11V17H13M12 2C17.5 2 22 6.5 22 12L21.91 13.31C21.31 13.11 20.67 13 20 13C16.69 13 14 15.69 14 19C14 19.95 14.22 20.85 14.62 21.65C13.78 21.88 12.91 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2Z\";\r\nvar mdiAlertCircleCheckOutline = \"M18.75 22.16L16 19.16L17.16 18L18.75 19.59L22.34 16L23.5 17.41L18.75 22.16M11 15H13V17H11V15M11 7H13V13H11V7M12 2C17.5 2 22 6.5 22 12L21.92 13.31C21.31 13.11 20.67 13 19.94 13L20 12C20 7.58 16.42 4 12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C12.71 20 13.39 19.91 14.05 19.74C14.13 20.42 14.33 21.06 14.62 21.65C13.78 21.88 12.9 22 12 22C6.47 22 2 17.5 2 12C2 6.5 6.47 2 12 2Z\";\r\nvar mdiAlertCircleOutline = \"M11,15H13V17H11V15M11,7H13V13H11V7M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20Z\";\r\nvar mdiAlertDecagram = \"M23,12L20.56,9.22L20.9,5.54L17.29,4.72L15.4,1.54L12,3L8.6,1.54L6.71,4.72L3.1,5.53L3.44,9.21L1,12L3.44,14.78L3.1,18.47L6.71,19.29L8.6,22.47L12,21L15.4,22.46L17.29,19.28L20.9,18.46L20.56,14.78L23,12M13,17H11V15H13V17M13,13H11V7H13V13Z\";\r\nvar mdiAlertDecagramOutline = \"M23,12L20.56,14.78L20.9,18.46L17.29,19.28L15.4,22.46L12,21L8.6,22.47L6.71,19.29L3.1,18.47L3.44,14.78L1,12L3.44,9.21L3.1,5.53L6.71,4.72L8.6,1.54L12,3L15.4,1.54L17.29,4.72L20.9,5.54L20.56,9.22L23,12M20.33,12L18.5,9.89L18.74,7.1L16,6.5L14.58,4.07L12,5.18L9.42,4.07L8,6.5L5.26,7.09L5.5,9.88L3.67,12L5.5,14.1L5.26,16.9L8,17.5L9.42,19.93L12,18.81L14.58,19.92L16,17.5L18.74,16.89L18.5,14.1L20.33,12M11,15H13V17H11V15M11,7H13V13H11V7\";\r\nvar mdiAlertMinus = \"M14 19C14 16.21 15.91 13.87 18.5 13.2L12 2L1 21H14.35C14.13 20.37 14 19.7 14 19M13 18H11V16H13V18M13 14H11V10H13V14M24 18V20H16V18H24Z\";\r\nvar mdiAlertMinusOutline = \"M11 15.5H13V17.5H11V15.5M14 19C14 18.86 14 18.73 14 18.6H5.4L12 7.3L16.11 14.44C16.62 14 17.2 13.65 17.84 13.41L12 3.3L2 20.6H14.22C14.08 20.09 14 19.56 14 19M13 10.5H11V14.5H13V10.5M16 18V20H24V18H16Z\";\r\nvar mdiAlertOctagon = \"M13 13H11V7H13M11 15H13V17H11M15.73 3H8.27L3 8.27V15.73L8.27 21H15.73L21 15.73V8.27L15.73 3Z\";\r\nvar mdiAlertOctagonOutline = \"M8.27,3L3,8.27V15.73L8.27,21H15.73C17.5,19.24 21,15.73 21,15.73V8.27L15.73,3M9.1,5H14.9L19,9.1V14.9L14.9,19H9.1L5,14.9V9.1M11,15H13V17H11V15M11,7H13V13H11V7\";\r\nvar mdiAlertOctagram = \"M2.2,16.06L3.88,12L2.2,7.94L6.26,6.26L7.94,2.2L12,3.88L16.06,2.2L17.74,6.26L21.8,7.94L20.12,12L21.8,16.06L17.74,17.74L16.06,21.8L12,20.12L7.94,21.8L6.26,17.74L2.2,16.06M13,17V15H11V17H13M13,13V7H11V13H13Z\";\r\nvar mdiAlertOctagramOutline = \"M2.2,16.06L3.88,12L2.2,7.94L6.26,6.26L7.94,2.2L12,3.88L16.06,2.2L17.74,6.26L21.8,7.94L20.12,12L21.8,16.06L17.74,17.74L16.06,21.8L12,20.12L7.94,21.8L6.26,17.74L2.2,16.06M4.81,9L6.05,12L4.81,15L7.79,16.21L9,19.19L12,17.95L15,19.19L16.21,16.21L19.19,15L17.95,12L19.19,9L16.21,7.79L15,4.81L12,6.05L9,4.81L7.79,7.79L4.81,9M11,15H13V17H11V15M11,7H13V13H11V7\";\r\nvar mdiAlertOutline = \"M12,2L1,21H23M12,6L19.53,19H4.47M11,10V14H13V10M11,16V18H13V16\";\r\nvar mdiAlertPlus = \"M14 19C14 16.21 15.91 13.87 18.5 13.2L12 2L1 21H14.35C14.13 20.37 14 19.7 14 19M13 18H11V16H13V18M13 14H11V10H13V14M21 15V18H24V20H21V23H19V20H16V18H19V15H21Z\";\r\nvar mdiAlertPlusOutline = \"M11 15.5H13V17.5H11V15.5M14 19C14 18.86 14 18.73 14 18.6H5.4L12 7.3L16.11 14.44C16.62 14 17.2 13.65 17.84 13.41L12 3.3L2 20.6H14.22C14.08 20.09 14 19.56 14 19M13 10.5H11V14.5H13V10.5M19 15V18H16V20H19V23H21V20H24V18H21V15H19Z\";\r\nvar mdiAlertRemove = \"M14 19C14 16.21 15.91 13.87 18.5 13.2L12 2L1 21H14.35C14.13 20.37 14 19.7 14 19M13 18H11V16H13V18M13 14H11V10H13V14M23.54 16.88L21.41 19L23.54 21.12L22.12 22.54L20 20.41L17.88 22.54L16.47 21.12L18.59 19L16.47 16.88L17.88 15.47L20 17.59L22.12 15.46L23.54 16.88Z\";\r\nvar mdiAlertRemoveOutline = \"M11 15.5H13V17.5H11V15.5M14 19C14 18.86 14 18.73 14 18.6H5.4L12 7.3L16.11 14.44C16.62 14 17.2 13.65 17.84 13.41L12 3.3L2 20.6H14.22C14.08 20.09 14 19.56 14 19M13 10.5H11V14.5H13V10.5M22.12 15.46L20 17.59L17.88 15.46L16.47 16.88L18.59 19L16.47 21.12L17.88 22.54L20 20.41L22.12 22.54L23.54 21.12L21.41 19L23.54 16.88L22.12 15.46Z\";\r\nvar mdiAlertRhombus = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M11 7H13V13H11V7M11 15H13V17H11V15Z\";\r\nvar mdiAlertRhombusOutline = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L20 12L12 20L4 12M11 7V13H13V7M11 15V17H13V15Z\";\r\nvar mdiAlien = \"M12,3C16.97,3 21,6.58 21,11C21,15.42 15,21 12,21C9,21 3,15.42 3,11C3,6.58 7.03,3 12,3M10.31,10.93C9.29,9.29 7.47,8.58 6.25,9.34C5.03,10.1 4.87,12.05 5.89,13.69C6.92,15.33 8.74,16.04 9.96,15.28C11.18,14.5 11.33,12.57 10.31,10.93M13.69,10.93C12.67,12.57 12.82,14.5 14.04,15.28C15.26,16.04 17.08,15.33 18.11,13.69C19.13,12.05 18.97,10.1 17.75,9.34C16.53,8.58 14.71,9.29 13.69,10.93M12,17.75C10,17.75 9.5,17 9.5,17C9.5,17.03 10,19 12,19C14,19 14.5,17 14.5,17C14.5,17 14,17.75 12,17.75Z\";\r\nvar mdiAlienOutline = \"M10.31 10.93C11.33 12.57 11.18 14.5 9.96 15.28C8.74 16.04 6.92 15.33 5.89 13.69C4.87 12.05 5.03 10.1 6.25 9.34C7.47 8.58 9.29 9.29 10.31 10.93M12 17.75C14 17.75 14.5 17 14.5 17C14.5 17 14 19 12 19C10 19 9.5 17.03 9.5 17C9.5 17 10 17.75 12 17.75M17.75 9.34C18.97 10.1 19.13 12.05 18.11 13.69C17.08 15.33 15.26 16.04 14.04 15.28C12.82 14.5 12.67 12.57 13.69 10.93C14.71 9.29 16.53 8.58 17.75 9.34M12 20C14.5 20 20 14.86 20 11C20 7.14 16.41 4 12 4C7.59 4 4 7.14 4 11C4 14.86 9.5 20 12 20M12 2C17.5 2 22 6.04 22 11C22 15.08 16.32 22 12 22C7.68 22 2 15.08 2 11C2 6.04 6.5 2 12 2Z\";\r\nvar mdiAlignHorizontalCenter = \"M20 19H13V22H11V19H4V13H11V11H7V5H11V2H13V5H17V11H13V13H20V19Z\";\r\nvar mdiAlignHorizontalLeft = \"M22 13V19H6V13H22M6 5V11H16V5H6M2 2V22H4V2H2\";\r\nvar mdiAlignHorizontalRight = \"M18 13V19H2V13H18M8 5V11H18V5H8M20 2V22H22V2H20Z\";\r\nvar mdiAlignVerticalBottom = \"M11 18H5V2H11V18M19 8H13V18H19V8M22 20H2V22H22V20Z\";\r\nvar mdiAlignVerticalCenter = \"M5 20V13H2V11H5V4H11V11H13V7H19V11H22V13H19V17H13V13H11V20H5Z\";\r\nvar mdiAlignVerticalTop = \"M11 22H5V6H11V22M19 6H13V16H19V6M22 2H2V4H22V2Z\";\r\nvar mdiAllInclusive = \"M18.6,6.62C17.16,6.62 15.8,7.18 14.83,8.15L7.8,14.39C7.16,15.03 6.31,15.38 5.4,15.38C3.53,15.38 2,13.87 2,12C2,10.13 3.53,8.62 5.4,8.62C6.31,8.62 7.16,8.97 7.84,9.65L8.97,10.65L10.5,9.31L9.22,8.2C8.2,7.18 6.84,6.62 5.4,6.62C2.42,6.62 0,9.04 0,12C0,14.96 2.42,17.38 5.4,17.38C6.84,17.38 8.2,16.82 9.17,15.85L16.2,9.61C16.84,8.97 17.69,8.62 18.6,8.62C20.47,8.62 22,10.13 22,12C22,13.87 20.47,15.38 18.6,15.38C17.7,15.38 16.84,15.03 16.16,14.35L15,13.34L13.5,14.68L14.78,15.8C15.8,16.81 17.15,17.37 18.6,17.37C21.58,17.37 24,14.96 24,12C24,9 21.58,6.62 18.6,6.62Z\";\r\nvar mdiAllergy = \"M19.75 5.33A1.25 1.25 0 0 0 18.5 6.58V11.17H17.67V4.08A1.25 1.25 0 0 0 15.17 4.08V11.17H14.33V3.25A1.25 1.25 0 1 0 11.83 3.25V11.17H11V5.33A1.25 1.25 0 0 0 8.5 5.33V15.26L4.91 13.26A1 1 0 0 0 4.41 13.12A1 1 0 0 0 3.75 13.37L2.67 14.37L9.21 21A3.29 3.29 0 0 0 11.58 22H17.67A3.33 3.33 0 0 0 21 18.67V6.58A1.25 1.25 0 0 0 19.75 5.33M11 15A1 1 0 1 1 12 14A1 1 0 0 1 11 15M13 18A1 1 0 1 1 14 17A1 1 0 0 1 13 18M18 16A1 1 0 1 1 19 15A1 1 0 0 1 18 16M17 19A1 1 0 1 1 18 18A1 1 0 0 1 17 19M15 15A1 1 0 1 1 16 14A1 1 0 0 1 15 15Z\";\r\nvar mdiAlpha = \"M18.08,17.8C17.62,17.93 17.21,18 16.85,18C15.65,18 14.84,17.12 14.43,15.35H14.38C13.39,17.26 12,18.21 10.25,18.21C8.94,18.21 7.89,17.72 7.1,16.73C6.31,15.74 5.92,14.5 5.92,13C5.92,11.25 6.37,9.85 7.26,8.76C8.15,7.67 9.36,7.12 10.89,7.12C11.71,7.12 12.45,7.35 13.09,7.8C13.73,8.26 14.22,8.9 14.56,9.73H14.6L15.31,7.33H17.87L15.73,12.65C15.97,13.89 16.22,14.74 16.5,15.19C16.74,15.64 17.08,15.87 17.5,15.87C17.74,15.87 17.93,15.83 18.1,15.76L18.08,17.8M13.82,12.56C13.61,11.43 13.27,10.55 12.81,9.95C12.36,9.34 11.81,9.04 11.18,9.04C10.36,9.04 9.7,9.41 9.21,10.14C8.72,10.88 8.5,11.79 8.5,12.86C8.5,13.84 8.69,14.65 9.12,15.31C9.54,15.97 10.11,16.29 10.82,16.29C11.42,16.29 11.97,16 12.46,15.45C12.96,14.88 13.37,14.05 13.7,12.96L13.82,12.56Z\";\r\nvar mdiAlphaA = \"M11,7A2,2 0 0,0 9,9V17H11V13H13V17H15V9A2,2 0 0,0 13,7H11M11,9H13V11H11V9Z\";\r\nvar mdiAlphaABox = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M11,7A2,2 0 0,0 9,9V17H11V13H13V17H15V9A2,2 0 0,0 13,7H11M11,9H13V11H11V9Z\";\r\nvar mdiAlphaABoxOutline = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5M11,7H13A2,2 0 0,1 15,9V17H13V13H11V17H9V9A2,2 0 0,1 11,7M11,9V11H13V9H11Z\";\r\nvar mdiAlphaACircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M11,7A2,2 0 0,0 9,9V17H11V13H13V17H15V9A2,2 0 0,0 13,7H11M11,9H13V11H11V9Z\";\r\nvar mdiAlphaACircleOutline = \"M11,7H13A2,2 0 0,1 15,9V17H13V13H11V17H9V9A2,2 0 0,1 11,7M11,9V11H13V9H11M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaB = \"M15,10.5V9A2,2 0 0,0 13,7H9V17H13A2,2 0 0,0 15,15V13.5C15,12.7 14.3,12 13.5,12C14.3,12 15,11.3 15,10.5M13,15H11V13H13V15M13,11H11V9H13V11Z\";\r\nvar mdiAlphaBBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M15,10.5V9A2,2 0 0,0 13,7H9V17H13A2,2 0 0,0 15,15V13.5C15,12.7 14.3,12 13.5,12C14.3,12 15,11.3 15,10.5M13,15H11V13H13V15M13,11H11V9H13V11Z\";\r\nvar mdiAlphaBBoxOutline = \"M15,10.5C15,11.3 14.3,12 13.5,12C14.3,12 15,12.7 15,13.5V15A2,2 0 0,1 13,17H9V7H13A2,2 0 0,1 15,9V10.5M13,15V13H11V15H13M13,11V9H11V11H13M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaBCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M15,10.5V9A2,2 0 0,0 13,7H9V17H13A2,2 0 0,0 15,15V13.5C15,12.7 14.3,12 13.5,12C14.3,12 15,11.3 15,10.5M13,15H11V13H13V15M13,11H11V9H13V11Z\";\r\nvar mdiAlphaBCircleOutline = \"M15,10.5C15,11.3 14.3,12 13.5,12C14.3,12 15,12.7 15,13.5V15A2,2 0 0,1 13,17H9V7H13A2,2 0 0,1 15,9V10.5M13,15V13H11V15H13M13,11V9H11V11H13M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaC = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V14H13V15H11V9H13V10H15V9A2,2 0 0,0 13,7H11Z\";\r\nvar mdiAlphaCBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V14H13V15H11V9H13V10H15V9A2,2 0 0,0 13,7H11Z\";\r\nvar mdiAlphaCBoxOutline = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5M11,7H13A2,2 0 0,1 15,9V10H13V9H11V15H13V14H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7Z\";\r\nvar mdiAlphaCCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V14H13V15H11V9H13V10H15V9A2,2 0 0,0 13,7H11Z\";\r\nvar mdiAlphaCCircleOutline = \"M11,7H13A2,2 0 0,1 15,9V10H13V9H11V15H13V14H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaD = \"M9,7V17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H9M11,9H13V15H11V9Z\";\r\nvar mdiAlphaDBox = \"M9,7V17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H9M11,9H13V15H11V9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaDBoxOutline = \"M9,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H9V7M11,9V15H13V9H11M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaDCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M9,7V17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H9M11,9H13V15H11V9Z\";\r\nvar mdiAlphaDCircleOutline = \"M9,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H9V7M11,9V15H13V9H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaE = \"M9,7V17H15V15H11V13H15V11H11V9H15V7H9Z\";\r\nvar mdiAlphaEBox = \"M9,7V17H15V15H11V13H15V11H11V9H15V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaEBoxOutline = \"M9,7H15V9H11V11H15V13H11V15H15V17H9V7M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaECircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M9,7V17H15V15H11V13H15V11H11V9H15V7H9Z\";\r\nvar mdiAlphaECircleOutline = \"M9,7H15V9H11V11H15V13H11V15H15V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaF = \"M9,7V17H11V13H14V11H11V9H15V7H9Z\";\r\nvar mdiAlphaFBox = \"M9,7V17H11V13H14V11H11V9H15V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaFBoxOutline = \"M9,7H15V9H11V11H14V13H11V17H9V7M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaFCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M9,7V17H11V13H14V11H11V9H15V7H9Z\";\r\nvar mdiAlphaFCircleOutline = \"M9,7H15V9H11V11H14V13H11V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaG = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V11H13V15H11V9H15V7H11Z\";\r\nvar mdiAlphaGBox = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V11H13V15H11V9H15V7H11M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaGBoxOutline = \"M11,7H15V9H11V15H13V11H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaGCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V11H13V15H11V9H15V7H11Z\";\r\nvar mdiAlphaGCircleOutline = \"M11,7H15V9H11V15H13V11H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaH = \"M9,7V17H11V13H13V17H15V7H13V11H11V7H9Z\";\r\nvar mdiAlphaHBox = \"M9,7V17H11V13H13V17H15V7H13V11H11V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaHBoxOutline = \"M9,7H11V11H13V7H15V17H13V13H11V17H9V7M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M5,5V19H19V5H5Z\";\r\nvar mdiAlphaHCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M9,7V17H11V13H13V17H15V7H13V11H11V7H9Z\";\r\nvar mdiAlphaHCircleOutline = \"M9,7H11V11H13V7H15V17H13V13H11V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaI = \"M14,7V9H13V15H14V17H10V15H11V9H10V7H14Z\";\r\nvar mdiAlphaIBox = \"M14,7H10V9H11V15H10V17H14V15H13V9H14V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaIBoxOutline = \"M14,7V9H13V15H14V17H10V15H11V9H10V7H14M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaICircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M14,7H10V9H11V15H10V17H14V15H13V9H14V7Z\";\r\nvar mdiAlphaICircleOutline = \"M14,7V9H13V15H14V17H10V15H11V9H10V7H14M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaJ = \"M13,7V15H11V14H9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13Z\";\r\nvar mdiAlphaJBox = \"M13,7V15H11V14H9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaJBoxOutline = \"M13,7H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V14H11V15H13V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaJCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M13,7V15H11V14H9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13Z\";\r\nvar mdiAlphaJCircleOutline = \"M13,7H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V14H11V15H13V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaK = \"M9,7V17H11V13.67L13,17H15L12,12L15,7H13L11,10.33V7H9Z\";\r\nvar mdiAlphaKBox = \"M9,7V17H11V13.67L13,17H15L12,12L15,7H13L11,10.33V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaKBoxOutline = \"M9,7H11V10.33L13,7H15L12,12L15,17H13L11,13.67V17H9V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaKCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M9,7V17H11V13.67L13,17H15L12,12L15,7H13L11,10.33V7H9Z\";\r\nvar mdiAlphaKCircleOutline = \"M9,7H11V10.33L13,7H15L12,12L15,17H13L11,13.67V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaL = \"M9,7V17H15V15H11V7H9Z\";\r\nvar mdiAlphaLBox = \"M9,7V17H15V15H11V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaLBoxOutline = \"M9,7H11V15H15V17H9V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaLCircle = \"M9,7V17H15V15H11V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaLCircleOutline = \"M9,7H11V15H15V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaM = \"M9,7A2,2 0 0,0 7,9V17H9V9H11V16H13V9H15V17H17V9A2,2 0 0,0 15,7H9Z\";\r\nvar mdiAlphaMBox = \"M9,7A2,2 0 0,0 7,9V17H9V9H11V16H13V9H15V17H17V9A2,2 0 0,0 15,7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaMBoxOutline = \"M9,7H15A2,2 0 0,1 17,9V17H15V9H13V16H11V9H9V17H7V9A2,2 0 0,1 9,7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaMCircle = \"M9,7A2,2 0 0,0 7,9V17H9V9H11V16H13V9H15V17H17V9A2,2 0 0,0 15,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaMCircleOutline = \"M9,7H15A2,2 0 0,1 17,9V17H15V9H13V16H11V9H9V17H7V9A2,2 0 0,1 9,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaN = \"M9,7V17H11V12L13,17H15V7H13V12L11,7H9Z\";\r\nvar mdiAlphaNBox = \"M9,7V17H11V12L13,17H15V7H13V12L11,7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaNBoxOutline = \"M9,7H11L13,12V7H15V17H13L11,12V17H9V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaNCircle = \"M9,7V17H11V12L13,17H15V7H13V12L11,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaNCircleOutline = \"M9,7H11L13,12V7H15V17H13L11,12V17H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaO = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9Z\";\r\nvar mdiAlphaOBox = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaOBoxOutline = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11Z\";\r\nvar mdiAlphaOCircle = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaOCircleOutline = \"M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaP = \"M9,7V17H11V13H13A2,2 0 0,0 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9Z\";\r\nvar mdiAlphaPBox = \"M9,7V17H11V13H13A2,2 0 0,0 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaPBoxOutline = \"M9,7H13A2,2 0 0,1 15,9V11A2,2 0 0,1 13,13H11V17H9V7M11,9V11H13V9H11M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaPCircle = \"M9,7V17H11V13H13A2,2 0 0,0 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaPCircleOutline = \"M9,7H13A2,2 0 0,1 15,9V11A2,2 0 0,1 13,13H11V17H9V7M11,9V11H13V9H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaQ = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17V19H13V17A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9Z\";\r\nvar mdiAlphaQBox = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17V19H13V17A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M5,4H19A2,2 0 0,1 21,6V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V6A2,2 0 0,1 5,4Z\";\r\nvar mdiAlphaQBoxOutline = \"M5,4H19A2,2 0 0,1 21,6V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V6A2,2 0 0,1 5,4M5,6V20H19V6H5M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17V19H11V17A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11Z\";\r\nvar mdiAlphaQCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17V19H13V17A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9Z\";\r\nvar mdiAlphaQCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17V19H11V17A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11Z\";\r\nvar mdiAlphaR = \"M9,7V17H11V13H11.8L13,17H15L13.76,12.85C14.5,12.55 15,11.84 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9Z\";\r\nvar mdiAlphaRBox = \"M9,7V17H11V13H11.8L13,17H15L13.76,12.85C14.5,12.55 15,11.84 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaRBoxOutline = \"M9,7H13A2,2 0 0,1 15,9V11C15,11.84 14.5,12.55 13.76,12.85L15,17H13L11.8,13H11V17H9V7M11,9V11H13V9H11M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaRCircle = \"M9,7V17H11V13H11.8L13,17H15L13.76,12.85C14.5,12.55 15,11.84 15,11V9A2,2 0 0,0 13,7H9M11,9H13V11H11V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaRCircleOutline = \"M9,7H13A2,2 0 0,1 15,9V11C15,11.84 14.5,12.55 13.76,12.85L15,17H13L11.8,13H11V17H9V7M11,9V11H13V9H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12C4,16.41 7.58,20 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaS = \"M11,7A2,2 0 0,0 9,9V11A2,2 0 0,0 11,13H13V15H9V17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H11Z\";\r\nvar mdiAlphaSBox = \"M11,7A2,2 0 0,0 9,9V11A2,2 0 0,0 11,13H13V15H9V17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H11M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaSBoxOutline = \"M11,7H15V9H11V11H13A2,2 0 0,1 15,13V15A2,2 0 0,1 13,17H9V15H13V13H11A2,2 0 0,1 9,11V9A2,2 0 0,1 11,7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaSCircle = \"M11,7A2,2 0 0,0 9,9V11A2,2 0 0,0 11,13H13V15H9V17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaSCircleOutline = \"M11,7H15V9H11V11H13A2,2 0 0,1 15,13V15A2,2 0 0,1 13,17H9V15H13V13H11A2,2 0 0,1 9,11V9A2,2 0 0,1 11,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaT = \"M9,7V9H11V17H13V9H15V7H9Z\";\r\nvar mdiAlphaTBox = \"M9,7V9H11V17H13V9H15V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaTBoxOutline = \"M9,7H15V9H13V17H11V9H9V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaTCircle = \"M9,7V9H11V17H13V9H15V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaTCircleOutline = \"M9,7H15V9H13V17H11V9H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaU = \"M9,7V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13V15H11V7H9Z\";\r\nvar mdiAlphaUBox = \"M9,7V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13V15H11V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaUBoxOutline = \"M9,7H11V15H13V7H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaUCircle = \"M9,7V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V7H13V15H11V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaUCircleOutline = \"M9,7H11V15H13V7H15V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaV = \"M9,7L11,17H13L15,7H13L12,12L11,7H9Z\";\r\nvar mdiAlphaVBox = \"M9,7L11,17H13L15,7H13L12,12L11,7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaVBoxOutline = \"M9,7H11L12,12L13,7H15L13,17H11L9,7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaVCircle = \"M9,7L11,17H13L15,7H13L12,12L11,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaVCircleOutline = \"M9,7H11L12,12L13,7H15L13,17H11L9,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaW = \"M9,17A2,2 0 0,1 7,15V7H9V15H11V8H13V15H15V7H17V15A2,2 0 0,1 15,17H9Z\";\r\nvar mdiAlphaWBox = \"M9,17H15A2,2 0 0,0 17,15V7H15V15H13V8H11V15H9V7H7V15A2,2 0 0,0 9,17M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaWBoxOutline = \"M9,17A2,2 0 0,1 7,15V7H9V15H11V8H13V15H15V7H17V15A2,2 0 0,1 15,17H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaWCircle = \"M9,17H15A2,2 0 0,0 17,15V7H15V15H13V8H11V15H9V7H7V15A2,2 0 0,0 9,17M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaWCircleOutline = \"M9,17A2,2 0 0,1 7,15V7H9V15H11V8H13V15H15V7H17V15A2,2 0 0,1 15,17H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaX = \"M9,7L11,12L9,17H11L12,14.5L13,17H15L13,12L15,7H13L12,9.5L11,7H9Z\";\r\nvar mdiAlphaXBox = \"M9,7L11,12L9,17H11L12,14.5L13,17H15L13,12L15,7H13L12,9.5L11,7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaXBoxOutline = \"M9,7H11L12,9.5L13,7H15L13,12L15,17H13L12,14.5L11,17H9L11,12L9,7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaXCircle = \"M9,7L11,12L9,17H11L12,14.5L13,17H15L13,12L15,7H13L12,9.5L11,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaXCircleOutline = \"M9,7H11L12,9.5L13,7H15L13,12L15,17H13L12,14.5L11,17H9L11,12L9,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaY = \"M9,7L11,13V17H13V13L15,7H13L12,10L11,7H9Z\";\r\nvar mdiAlphaYBox = \"M9,7L11,13V17H13V13L15,7H13L12,10L11,7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaYBoxOutline = \"M9,7H11L12,10L13,7H15L13,13V17H11V13L9,7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaYCircle = \"M9,7L11,13V17H13V13L15,7H13L12,10L11,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaYCircleOutline = \"M9,7H11L12,10L13,7H15L13,13V17H11V13L9,7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphaZ = \"M9,7V9H13L9,15V17H15V15H11L15,9V7H9Z\";\r\nvar mdiAlphaZBox = \"M9,7V9H13L9,15V17H15V15H11L15,9V7H9M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiAlphaZBoxOutline = \"M9,7H15V9L11,15H15V17H9V15L13,9H9V7M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiAlphaZCircle = \"M9,7V9H13L9,15V17H15V15H11L15,9V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiAlphaZCircleOutline = \"M9,7H15V9L11,15H15V17H9V15L13,9H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiAlphabetAurebesh = \"M3 4V11H14.23L22 4H19L13.46 9H5V4H3M3 13V20H5V15H13.46L19 20H22L14.23 13H3Z\";\r\nvar mdiAlphabetCyrillic = \"M16 6C14.36 6 13 7.36 13 9V15C13 16.65 14.36 18 16 18H17C18.65 18 20 16.65 20 15V12C20 10.36 18.65 9 17 9H15C15 8.44 15.44 8 16 8H18C19.09 8 20 7.09 20 6M5 9V11H8C8.57 11 9 11.43 9 12H7C5.36 12 4 13.36 4 15C4 16.65 5.36 18 7 18H11V12C11 10.36 9.65 9 8 9M15 11H17C17.57 11 18 11.43 18 12V15C18 15.57 17.57 16 17 16H16C15.43 16 15 15.57 15 15M7 14H9V16H7C6.43 16 6 15.57 6 15C6 14.43 6.43 14 7 14Z\";\r\nvar mdiAlphabetGreek = \"M16 6C14.36 6 13 7.36 13 9V21H15V9C15 8.43 15.43 8 16 8H17C17.57 8 18 8.43 18 9V10C18 10.57 17.57 11 17 11H16V13H17C17.57 13 18 13.43 18 14V15C18 15.57 17.57 16 17 16H16V18H17C18.65 18 20 16.65 20 15V14C20 13.18 19.59 12.46 19 12C19.59 11.54 20 10.82 20 10V9C20 7.36 18.65 6 17 6M7 9C5.36 9 4 10.36 4 12V15C4 16.65 5.36 18 7 18H7.7C8.2 18 8.65 17.81 9 17.5V18H11V9H9V9.5C8.65 9.19 8.2 9 7.7 9M7 11H8C8.57 11 9 11.43 9 12V15C9 15.57 8.57 16 8 16H7C6.43 16 6 15.57 6 15V12C6 11.43 6.43 11 7 11Z\";\r\nvar mdiAlphabetLatin = \"M13 6V18H15V17.31C15.37 17.73 15.9 18 16.5 18H17C18.65 18 20 16.65 20 15V12C20 10.36 18.65 9 17 9H16.5C15.9 9 15.37 9.27 15 9.7V6M5 9V11H8C8.57 11 9 11.43 9 12H7C5.36 12 4 13.36 4 15C4 16.65 5.36 18 7 18H11V12C11 10.36 9.65 9 8 9M16 11H17C17.57 11 18 11.43 18 12V15C18 15.57 17.57 16 17 16H16C15.43 16 15 15.57 15 15V12C15 11.43 15.43 11 16 11M7 14H9V16H7C6.43 16 6 15.57 6 15C6 14.43 6.43 14 7 14Z\";\r\nvar mdiAlphabetPiqad = \"M13.04 4L6.54 17.85C6.21 18.55 5.5 19 4.73 19H4V20H16C17.2 20 18.27 20.54 19 21.39H20C19.05 19.32 17 18 14.7 18H12C11.29 18 10.62 17.63 10.24 17.03C9.85 16.43 9.8 15.68 10.1 15.03L10.58 14H19V13H17.5C15.29 13 13.5 11.21 13.5 9C13.5 6.79 15.29 5 17.5 5H20V4Z\";\r\nvar mdiAlphabetTengwar = \"M10 7L12.5 3H15L11 7H10M12.5 9C11.96 9 11.46 9.13 11 9.35V9H8V11H9V21H11V12.5C11 11.67 11.67 11 12.5 11C13.33 11 14 11.67 14 12.5V14.5C14 15.33 13.33 16 12.5 16H12V18H12.5C14.43 18 16 16.43 16 14.5V12.5C16 10.57 14.43 9 12.5 9Z\";\r\nvar mdiAlphabetical = \"M6,11A2,2 0 0,1 8,13V17H4A2,2 0 0,1 2,15V13A2,2 0 0,1 4,11H6M4,13V15H6V13H4M20,13V15H22V17H20A2,2 0 0,1 18,15V13A2,2 0 0,1 20,11H22V13H20M12,7V11H14A2,2 0 0,1 16,13V15A2,2 0 0,1 14,17H12A2,2 0 0,1 10,15V7H12M12,15H14V13H12V15Z\";\r\nvar mdiAlphabeticalOff = \"M22.11 21.46L16 15.31L14 13.31L13.65 13L10 9.34L2.39 1.73L1.11 3L10 11.89V15A2 2 0 0 0 12 17H14A1.92 1.92 0 0 0 14.89 16.78L20.84 22.73M12 15V13.89L13.11 15M16 12.78L14.22 11A2 2 0 0 1 16 12.78M20.2 17L18 14.8V13A2 2 0 0 1 20 11H22V13H20V15H22V17M6 11H4A2 2 0 0 0 2 13V15A2 2 0 0 0 4 17H8V13A2 2 0 0 0 6 11M6 15H4V13H6M12 8.8L10.2 7H12Z\";\r\nvar mdiAlphabeticalVariant = \"M3 7A2 2 0 0 0 1 9V17H3V13H5V17H7V9A2 2 0 0 0 5 7H3M3 9H5V11H3M15 10.5V9A2 2 0 0 0 13 7H9V17H13A2 2 0 0 0 15 15V13.5A1.54 1.54 0 0 0 13.5 12A1.54 1.54 0 0 0 15 10.5M13 15H11V13H13V15M13 11H11V9H13M19 7A2 2 0 0 0 17 9V15A2 2 0 0 0 19 17H21A2 2 0 0 0 23 15V14H21V15H19V9H21V10H23V9A2 2 0 0 0 21 7Z\";\r\nvar mdiAlphabeticalVariantOff = \"M12.2 9L10.2 7H13A2 2 0 0 1 15 9V10.5A1.47 1.47 0 0 1 14.64 11.44L13 9.8V9M23 10V9A2 2 0 0 0 21 7H19A2 2 0 0 0 17 9V13.8L20.2 17H21A2 2 0 0 0 23 15V14H21V15H19V9H21V10M15 14.35L22.11 21.46L20.84 22.73L14.46 16.35A2 2 0 0 1 13 17H9V10.89L7 8.89V17H5V13H3V17H1V9A2 2 0 0 1 3 7H5.12L1.12 3L2.39 1.73L9 8.34L11 10.34L11.66 11L15 14.34M5 9H3V11H5M13 14.89L11.11 13H11V15H13Z\";\r\nvar mdiAltimeter = \"M7,3V5H17V3H7M9,7V9H15V7H9M2,7.96V16.04L6.03,12L2,7.96M22.03,7.96L18,12L22.03,16.04V7.96M7,11V13H17V11H7M9,15V17H15V15H9M7,19V21H17V19H7Z\";\r\nvar mdiAmazon = \"M15.93,17.09C15.75,17.25 15.5,17.26 15.3,17.15C14.41,16.41 14.25,16.07 13.76,15.36C12.29,16.86 11.25,17.31 9.34,17.31C7.09,17.31 5.33,15.92 5.33,13.14C5.33,10.96 6.5,9.5 8.19,8.76C9.65,8.12 11.68,8 13.23,7.83V7.5C13.23,6.84 13.28,6.09 12.9,5.54C12.58,5.05 11.95,4.84 11.4,4.84C10.38,4.84 9.47,5.37 9.25,6.45C9.2,6.69 9,6.93 8.78,6.94L6.18,6.66C5.96,6.61 5.72,6.44 5.78,6.1C6.38,2.95 9.23,2 11.78,2C13.08,2 14.78,2.35 15.81,3.33C17.11,4.55 17,6.18 17,7.95V12.12C17,13.37 17.5,13.93 18,14.6C18.17,14.85 18.21,15.14 18,15.31L15.94,17.09H15.93M13.23,10.56V10C11.29,10 9.24,10.39 9.24,12.67C9.24,13.83 9.85,14.62 10.87,14.62C11.63,14.62 12.3,14.15 12.73,13.4C13.25,12.47 13.23,11.6 13.23,10.56M20.16,19.54C18,21.14 14.82,22 12.1,22C8.29,22 4.85,20.59 2.25,18.24C2.05,18.06 2.23,17.81 2.5,17.95C5.28,19.58 8.75,20.56 12.33,20.56C14.74,20.56 17.4,20.06 19.84,19.03C20.21,18.87 20.5,19.27 20.16,19.54M21.07,18.5C20.79,18.14 19.22,18.33 18.5,18.42C18.31,18.44 18.28,18.26 18.47,18.12C19.71,17.24 21.76,17.5 22,17.79C22.24,18.09 21.93,20.14 20.76,21.11C20.58,21.27 20.41,21.18 20.5,21C20.76,20.33 21.35,18.86 21.07,18.5Z\";\r\nvar mdiAmazonAlexa = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M10.43,21.87V19.91C10.43,19.22 10,18.57 9.35,18.3C6.91,17.26 5.17,14.83 5.17,12C5.17,8.26 8.22,5.17 12,5.17C15.78,5.17 18.83,8.26 18.83,12C18.83,16.43 15.39,20.61 10.43,21.87Z\";\r\nvar mdiAmbulance = \"M18,18.5A1.5,1.5 0 0,0 19.5,17A1.5,1.5 0 0,0 18,15.5A1.5,1.5 0 0,0 16.5,17A1.5,1.5 0 0,0 18,18.5M19.5,9.5H17V12H21.46L19.5,9.5M6,18.5A1.5,1.5 0 0,0 7.5,17A1.5,1.5 0 0,0 6,15.5A1.5,1.5 0 0,0 4.5,17A1.5,1.5 0 0,0 6,18.5M20,8L23,12V17H21A3,3 0 0,1 18,20A3,3 0 0,1 15,17H9A3,3 0 0,1 6,20A3,3 0 0,1 3,17H1V6C1,4.89 1.89,4 3,4H17V8H20M8,6V9H5V11H8V14H10V11H13V9H10V6H8Z\";\r\nvar mdiAmmunition = \"M14,22H10V21H14V22M13,10V7H11V10L10,11.5V20H14V11.5L13,10M12,2C12,2 11,3 11,5V6H13V5C13,5 13,3 12,2M8,22H4V21H8V22M7,10V7H5V10L4,11.5V20H8V11.5L7,10M6,2C6,2 5,3 5,5V6H7V5C7,5 7,3 6,2M20,22H16V21H20V22M19,10V7H17V10L16,11.5V20H20V11.5L19,10M18,2C18,2 17,3 17,5V6H19V5C19,5 19,3 18,2Z\";\r\nvar mdiAmpersand = \"M4.4,16.5C4.4,15.6 4.7,14.7 5.2,13.9C5.7,13.1 6.7,12.2 8.2,11.2C7.3,10.1 6.8,9.3 6.5,8.7C6.1,8 6,7.4 6,6.7C6,5.2 6.4,4.1 7.3,3.2C8.2,2.3 9.4,2 10.9,2C12.2,2 13.3,2.4 14.2,3.2C15.1,4 15.5,5 15.5,6.1C15.5,6.9 15.3,7.6 14.9,8.3C14.5,9 13.8,9.7 12.8,10.4L11.4,11.5L15.7,16.7C16.3,15.5 16.6,14.3 16.6,12.8H18.8C18.8,15.1 18.3,17 17.2,18.5L20,21.8H17L15.7,20.3C15,20.9 14.3,21.3 13.4,21.6C12.5,21.9 11.6,22.1 10.7,22.1C8.8,22.1 7.3,21.6 6.1,20.6C5,19.5 4.4,18.2 4.4,16.5M10.7,20C12,20 13.2,19.5 14.3,18.5L9.6,12.8L9.2,13.1C7.7,14.2 7,15.3 7,16.5C7,17.6 7.3,18.4 8,19C8.7,19.6 9.5,20 10.7,20M8.5,6.7C8.5,7.6 9,8.6 10.1,9.9L11.7,8.8C12.3,8.4 12.7,8 12.9,7.6C13.1,7.2 13.2,6.7 13.2,6.2C13.2,5.6 13,5.1 12.5,4.7C12.1,4.3 11.5,4.1 10.8,4.1C10.1,4.1 9.5,4.3 9.1,4.8C8.7,5.3 8.5,5.9 8.5,6.7Z\";\r\nvar mdiAmplifier = \"M10,2H14A1,1 0 0,1 15,3H21V21H19A1,1 0 0,1 18,22A1,1 0 0,1 17,21H7A1,1 0 0,1 6,22A1,1 0 0,1 5,21H3V3H9A1,1 0 0,1 10,2M5,5V9H19V5H5M7,6A1,1 0 0,1 8,7A1,1 0 0,1 7,8A1,1 0 0,1 6,7A1,1 0 0,1 7,6M12,6H14V7H12V6M15,6H16V8H15V6M17,6H18V8H17V6M12,11A4,4 0 0,0 8,15A4,4 0 0,0 12,19A4,4 0 0,0 16,15A4,4 0 0,0 12,11M10,6A1,1 0 0,1 11,7A1,1 0 0,1 10,8A1,1 0 0,1 9,7A1,1 0 0,1 10,6Z\";\r\nvar mdiAmplifierOff = \"M22.1 21.5L2.4 1.7L1.1 3L3 4.9V21H5C5 21.6 5.4 22 6 22S7 21.6 7 21H17C17 21.6 17.4 22 18 22S19 21.6 19 21H19.1L20.8 22.7L22.1 21.5M5 9V6.9L7.1 9H5M12 19C9.8 19 8 17.2 8 15C8 13.6 8.7 12.4 9.8 11.7L15.3 17.2C14.6 18.3 13.4 19 12 19M14 6V7H12V6H14M10 6C10.6 6 11 6.4 11 7C11 7.2 10.9 7.4 10.8 7.6L9.4 6.2C9.6 6.1 9.8 6 10 6M8.2 5L6.2 3H9C9 2.4 9.4 2 10 2H14C14.6 2 15 2.4 15 3H21V17.8L12.2 9H19V5H8.2M16 6V8H15V6H16M18 6V8H17V6H18Z\";\r\nvar mdiAnchor = \"M12 2A3 3 0 0 0 9 5A3 3 0 0 0 11 7.83V9H8V11H11V19.92C10.26 19.79 9.5 19.58 8.79 19.27C8.05 18.95 7.4 18.56 6.82 18.09C6.24 17.62 5.78 17.11 5.44 16.55L7 15L3 12V15C3 15.97 3.27 16.88 3.82 17.72C4.37 18.56 5.09 19.31 6 19.95C6.87 20.59 7.84 21.09 8.88 21.45C9.93 21.81 10.97 22 12 22C13.03 22 14.07 21.8 15.12 21.44C16.16 21.08 17.13 20.58 18 19.95C18.92 19.31 19.63 18.57 20.18 17.72C20.73 16.88 21 15.97 21 15V12L17 15L18.56 16.55C18.22 17.11 17.76 17.62 17.18 18.09C16.6 18.56 15.95 18.95 15.21 19.27C14.5 19.58 13.74 19.79 13 19.92V11H16V9H13V7.82A3 3 0 0 0 15 5A3 3 0 0 0 12 2M12 4A1 1 0 0 1 13 5A1 1 0 0 1 12 6A1 1 0 0 1 11 5A1 1 0 0 1 12 4Z\";\r\nvar mdiAndroid = \"M16.61 15.15C16.15 15.15 15.77 14.78 15.77 14.32S16.15 13.5 16.61 13.5H16.61C17.07 13.5 17.45 13.86 17.45 14.32C17.45 14.78 17.07 15.15 16.61 15.15M7.41 15.15C6.95 15.15 6.57 14.78 6.57 14.32C6.57 13.86 6.95 13.5 7.41 13.5H7.41C7.87 13.5 8.24 13.86 8.24 14.32C8.24 14.78 7.87 15.15 7.41 15.15M16.91 10.14L18.58 7.26C18.67 7.09 18.61 6.88 18.45 6.79C18.28 6.69 18.07 6.75 18 6.92L16.29 9.83C14.95 9.22 13.5 8.9 12 8.91C10.47 8.91 9 9.24 7.73 9.82L6.04 6.91C5.95 6.74 5.74 6.68 5.57 6.78C5.4 6.87 5.35 7.08 5.44 7.25L7.1 10.13C4.25 11.69 2.29 14.58 2 18H22C21.72 14.59 19.77 11.7 16.91 10.14H16.91Z\";\r\nvar mdiAndroidAuto = \"M22.78,17.91C22.94,18.16 23,18.42 23,18.7C23,19.08 22.87,19.39 22.57,19.64C22.27,19.89 21.94,20 21.56,20H19.08L12.42,8H11.58L4.92,20H2.39C1.92,20 1.53,19.8 1.22,19.38C0.91,18.96 0.89,18.5 1.17,18L10.78,1.69C11.09,1.22 11.5,1 12,1C12.53,1 12.92,1.22 13.17,1.69L22.78,17.91M4.78,22.31L12,9.38L19.22,22.31L18.5,23L12,20.34L5.44,23L4.78,22.31Z\";\r\nvar mdiAndroidDebugBridge = \"M15,9A1,1 0 0,1 14,8A1,1 0 0,1 15,7A1,1 0 0,1 16,8A1,1 0 0,1 15,9M9,9A1,1 0 0,1 8,8A1,1 0 0,1 9,7A1,1 0 0,1 10,8A1,1 0 0,1 9,9M16.12,4.37L18.22,2.27L17.4,1.44L15.09,3.75C14.16,3.28 13.11,3 12,3C10.88,3 9.84,3.28 8.91,3.75L6.6,1.44L5.78,2.27L7.88,4.37C6.14,5.64 5,7.68 5,10V11H19V10C19,7.68 17.86,5.64 16.12,4.37M5,16C5,19.86 8.13,23 12,23A7,7 0 0,0 19,16V12H5V16Z\";\r\nvar mdiAndroidMessages = \"M20,20H7A2,2 0 0,1 5,18V8.94L2.23,5.64C2.09,5.47 2,5.24 2,5A1,1 0 0,1 3,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M8.5,7A0.5,0.5 0 0,0 8,7.5V8.5A0.5,0.5 0 0,0 8.5,9H18.5A0.5,0.5 0 0,0 19,8.5V7.5A0.5,0.5 0 0,0 18.5,7H8.5M8.5,11A0.5,0.5 0 0,0 8,11.5V12.5A0.5,0.5 0 0,0 8.5,13H18.5A0.5,0.5 0 0,0 19,12.5V11.5A0.5,0.5 0 0,0 18.5,11H8.5M8.5,15A0.5,0.5 0 0,0 8,15.5V16.5A0.5,0.5 0 0,0 8.5,17H13.5A0.5,0.5 0 0,0 14,16.5V15.5A0.5,0.5 0 0,0 13.5,15H8.5Z\";\r\nvar mdiAndroidStudio = \"M11,2H13V4H13.5A1.5,1.5 0 0,1 15,5.5V9L14.56,9.44L16.2,12.28C17.31,11.19 18,9.68 18,8H20C20,10.42 18.93,12.59 17.23,14.06L20.37,19.5L20.5,21.72L18.63,20.5L15.56,15.17C14.5,15.7 13.28,16 12,16C10.72,16 9.5,15.7 8.44,15.17L5.37,20.5L3.5,21.72L3.63,19.5L9.44,9.44L9,9V5.5A1.5,1.5 0 0,1 10.5,4H11V2M9.44,13.43C10.22,13.8 11.09,14 12,14C12.91,14 13.78,13.8 14.56,13.43L13.1,10.9H13.09C12.47,11.5 11.53,11.5 10.91,10.9H10.9L9.44,13.43M12,6A1,1 0 0,0 11,7A1,1 0 0,0 12,8A1,1 0 0,0 13,7A1,1 0 0,0 12,6Z\";\r\nvar mdiAngleAcute = \"M20,19H4.09L14.18,4.43L15.82,5.57L11.28,12.13C12.89,12.96 14,14.62 14,16.54C14,16.7 14,16.85 13.97,17H20V19M7.91,17H11.96C12,16.85 12,16.7 12,16.54C12,15.28 11.24,14.22 10.14,13.78L7.91,17Z\";\r\nvar mdiAngleObtuse = \"M21,19H9.31L4.07,5.36L5.93,4.64L8.96,12.5C9.5,12.29 10.09,12.17 10.71,12.17V12.17C13.38,12.17 15.56,14.34 15.58,17H21V19M10.69,17H13.58C13.56,15.42 12.3,14.17 10.71,14.17C10.34,14.17 10,14.24 9.67,14.36L10.69,17Z\";\r\nvar mdiAngleRight = \"M5,4H7V11H13V17H20V19H5V4M7,17H11V13H7V17Z\";\r\nvar mdiAngular = \"M12,2.5L20.84,5.65L19.5,17.35L12,21.5L4.5,17.35L3.16,5.65L12,2.5M12,4.6L6.47,17H8.53L9.64,14.22H14.34L15.45,17H17.5L12,4.6M13.62,12.5H10.39L12,8.63L13.62,12.5Z\";\r\nvar mdiAngularjs = \"M12,2.5L20.84,5.65L19.5,17.35L12,21.5L4.5,17.35L3.16,5.65L12,2.5M12,4.5L5,7L6.08,16.22L12,19.5L17.92,16.22L19,7L12,4.5M12,5.72L16.58,16H14.87L13.94,13.72H10.04L9.12,16H7.41L12,5.72M13.34,12.3L12,9.07L10.66,12.3H13.34Z\";\r\nvar mdiAnimation = \"M4,2C2.89,2 2,2.89 2,4V14H4V4H14V2H4M8,6C6.89,6 6,6.89 6,8V18H8V8H18V6H8M12,10C10.89,10 10,10.89 10,12V20C10,21.11 10.89,22 12,22H20C21.11,22 22,21.11 22,20V12C22,10.89 21.11,10 20,10H12Z\";\r\nvar mdiAnimationOutline = \"M4,2A2,2 0 0,0 2,4V14H4V4H14V2H4M8,6A2,2 0 0,0 6,8V18H8V8H18V6H8M20,12V20H12V12H20M20,10H12A2,2 0 0,0 10,12V20A2,2 0 0,0 12,22H20A2,2 0 0,0 22,20V12A2,2 0 0,0 20,10Z\";\r\nvar mdiAnimationPlay = \"M4,2H14V4H4V14H2V4C2,2.89 2.89,2 4,2M8,6H18V8H8V18H6V8C6,6.89 6.89,6 8,6M12,10H20C21.11,10 22,10.89 22,12V20C22,21.11 21.11,22 20,22H12C10.89,22 10,21.11 10,20V12C10,10.89 10.89,10 12,10M14,12V20L20,16L14,12Z\";\r\nvar mdiAnimationPlayOutline = \"M4,2A2,2 0 0,0 2,4V14H4V4H14V2H4M8,6A2,2 0 0,0 6,8V18H8V8H18V6H8M20,12V20H12V12H20M20,10H12A2,2 0 0,0 10,12V20A2,2 0 0,0 12,22H20A2,2 0 0,0 22,20V12A2,2 0 0,0 20,10M14,13V19L18,16L14,13Z\";\r\nvar mdiAnsible = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 6.5 17.5 2 12 2M16.1 17C15.91 17 15.76 16.9 15.55 16.73L10.39 12.56L8.66 16.9H7.17L11.54 6.39C11.65 6.11 11.89 5.97 12.17 5.97C12.45 5.97 12.67 6.11 12.79 6.39L16.77 15.97C16.81 16.08 16.84 16.19 16.84 16.26C16.83 16.68 16.5 17 16.1 17M12.17 8.11L14.76 14.5L10.85 11.42L12.17 8.11Z\";\r\nvar mdiAntenna = \"M12 7.5C12.69 7.5 13.27 7.73 13.76 8.2S14.5 9.27 14.5 10C14.5 11.05 14 11.81 13 12.28V21H11V12.28C10 11.81 9.5 11.05 9.5 10C9.5 9.27 9.76 8.67 10.24 8.2S11.31 7.5 12 7.5M16.69 5.3C17.94 6.55 18.61 8.11 18.7 10C18.7 11.8 18.03 13.38 16.69 14.72L15.5 13.5C16.5 12.59 17 11.42 17 10C17 8.67 16.5 7.5 15.5 6.5L16.69 5.3M6.09 4.08C4.5 5.67 3.7 7.64 3.7 10S4.5 14.3 6.09 15.89L4.92 17.11C3 15.08 2 12.7 2 10C2 7.3 3 4.94 4.92 2.91L6.09 4.08M19.08 2.91C21 4.94 22 7.3 22 10C22 12.8 21 15.17 19.08 17.11L17.91 15.89C19.5 14.3 20.3 12.33 20.3 10S19.5 5.67 17.91 4.08L19.08 2.91M7.31 5.3L8.5 6.5C7.5 7.42 7 8.58 7 10C7 11.33 7.5 12.5 8.5 13.5L7.31 14.72C5.97 13.38 5.3 11.8 5.3 10C5.3 8.2 5.97 6.64 7.31 5.3Z\";\r\nvar mdiAnvil = \"M9,5V10C13.03,12.47 8.44,14.97 6,16V19H21V16C14.59,13.27 17.47,9 22,8V5H9M2,6C2.81,8.13 4.42,9.5 7,10V6H2Z\";\r\nvar mdiApacheKafka = \"M15.54 12.97C14.86 12.97 14.24 13.22 13.76 13.64L12.47 12.89C12.56 12.6 12.6 12.29 12.6 11.97C12.6 11.65 12.56 11.34 12.5 11.05L13.73 10.32C14.21 10.76 14.85 11 15.54 11C17.03 11 18.24 9.81 18.24 8.32S17.03 5.63 15.54 5.63 12.84 6.84 12.84 8.33C12.84 8.5 12.86 8.7 12.89 8.88L11.64 9.6C11.21 9.15 10.64 8.82 10 8.65V7.26C11.09 6.91 11.88 5.89 11.88 4.69C11.88 3.2 10.67 2 9.18 2C7.69 2 6.5 3.2 6.5 4.69C6.5 5.89 7.26 6.9 8.34 7.26V8.66C6.86 9.04 5.76 10.37 5.76 11.97C5.76 13.57 6.86 14.91 8.34 15.28V16.73C7.26 17.09 6.5 18.1 6.5 19.3C6.5 20.79 7.69 22 9.18 22C10.67 22 11.88 20.79 11.88 19.3C11.88 18.1 11.09 17.08 10 16.73V15.29C10.64 15.13 11.2 14.8 11.64 14.35L12.9 15.08C12.86 15.27 12.84 15.46 12.84 15.66C12.84 17.15 14.05 18.36 15.54 18.36S18.24 17.15 18.24 15.66 17.03 12.97 15.54 12.97M15.54 7C16.28 7 16.87 7.59 16.87 8.32S16.28 9.66 15.54 9.66 14.21 9.06 14.21 8.32 14.8 7 15.54 7M7.85 4.69C7.85 3.95 8.44 3.35 9.18 3.35C9.92 3.35 10.5 3.95 10.5 4.69S9.92 6.03 9.18 6.03C8.44 6.03 7.85 5.43 7.85 4.69M10.5 19.3C10.5 20.04 9.92 20.64 9.18 20.64C8.44 20.64 7.85 20.04 7.85 19.3C7.85 18.56 8.44 17.96 9.18 17.96C9.92 17.96 10.5 18.56 10.5 19.3M9.18 13.89C8.12 13.89 7.26 13.03 7.26 11.97C7.26 10.91 8.12 10.05 9.18 10.05S11.1 10.91 11.1 11.97C11.1 13.03 10.24 13.89 9.18 13.89M15.54 17C14.8 17 14.21 16.4 14.21 15.66S14.8 14.33 15.54 14.33 16.87 14.93 16.87 15.66 16.28 17 15.54 17Z\";\r\nvar mdiApi = \"M7 7H5A2 2 0 0 0 3 9V17H5V13H7V17H9V9A2 2 0 0 0 7 7M7 11H5V9H7M14 7H10V17H12V13H14A2 2 0 0 0 16 11V9A2 2 0 0 0 14 7M14 11H12V9H14M20 9V15H21V17H17V15H18V9H17V7H21V9Z\";\r\nvar mdiApiOff = \"M7 11H5V9H7M14 7H11.38L13.29 9H14V9.75L15.87 11.71C15.95 11.5 16 11.25 16 11V9C16 7.9 15.11 7 14 7M4.45 2.62L3 4L5.86 7H5C3.9 7 3 7.9 3 9V17H5V13H7V17H9V10.3L10 11.34V17H12V13.45L19.55 21.38L21 20M20.9 17H21V15H20V9H21V7H17V9H18V13.95Z\";\r\nvar mdiApple = \"M18.71,19.5C17.88,20.74 17,21.95 15.66,21.97C14.32,22 13.89,21.18 12.37,21.18C10.84,21.18 10.37,21.95 9.1,22C7.79,22.05 6.8,20.68 5.96,19.47C4.25,17 2.94,12.45 4.7,9.39C5.57,7.87 7.13,6.91 8.82,6.88C10.1,6.86 11.32,7.75 12.11,7.75C12.89,7.75 14.37,6.68 15.92,6.84C16.57,6.87 18.39,7.1 19.56,8.82C19.47,8.88 17.39,10.1 17.41,12.63C17.44,15.65 20.06,16.66 20.09,16.67C20.06,16.74 19.67,18.11 18.71,19.5M13,3.5C13.73,2.67 14.94,2.04 15.94,2C16.07,3.17 15.6,4.35 14.9,5.19C14.21,6.04 13.07,6.7 11.95,6.61C11.8,5.46 12.36,4.26 13,3.5Z\";\r\nvar mdiAppleAirplay = \"M6,22H18L12,16M21,3H3A2,2 0 0,0 1,5V17A2,2 0 0,0 3,19H7V17H3V5H21V17H17V19H21A2,2 0 0,0 23,17V5A2,2 0 0,0 21,3Z\";\r\nvar mdiAppleFinder = \"M8 11C7.45 11 7 10.55 7 10V8C7 7.45 7.45 7 8 7C8.55 7 9 7.45 9 8V10C9 10.55 8.55 11 8 11M17 10V8C17 7.45 16.55 7 16 7C15.45 7 15 7.45 15 8V10C15 10.55 15.45 11 16 11C16.55 11 17 10.55 17 10M22 5V20C22 21.1 21.1 22 20 22H4C2.9 22 2 21.1 2 20V5C2 3.9 2.9 3 4 3H20C21.1 3 22 3.9 22 5M4 20L13.06 20C12.96 19.35 12.89 18.64 12.83 17.94C12.56 17.96 12.3 18 12 18C8.24 18 6.31 15.73 6.23 15.63C5.88 15.21 5.94 14.58 6.36 14.22C6.78 13.87 7.41 13.93 7.77 14.35C7.83 14.43 9.23 16 12 16C12.27 16 12.5 15.97 12.74 15.95C12.71 14.75 12.73 13.74 12.74 13.26H10.93C10.28 13.26 9.75 12.7 9.75 12C9.77 11.75 10.07 7.82 11 5H4L4 20M20 20L20 5H12.6C11.74 7.19 11.37 10.73 11.27 11.76H13.08C13.72 11.76 14.25 12.32 14.25 13C14.25 13.04 14.21 14.15 14.24 15.6C15.54 15.11 16.22 14.35 16.23 14.34C16.58 13.92 17.21 13.85 17.63 14.2C18.06 14.55 18.12 15.18 17.77 15.61C17.71 15.68 16.55 17.05 14.32 17.68C14.38 18.5 14.46 19.29 14.58 20H20Z\";\r\nvar mdiAppleIcloud = \"M22,15.04C22,17.23 20.24,19 18.07,19H5.93C3.76,19 2,17.23 2,15.04C2,13.07 3.43,11.44 5.31,11.14C5.28,11 5.27,10.86 5.27,10.71C5.27,9.33 6.38,8.2 7.76,8.2C8.37,8.2 8.94,8.43 9.37,8.8C10.14,7.05 11.13,5.44 13.91,5.44C17.28,5.44 18.87,8.06 18.87,10.83C18.87,10.94 18.87,11.06 18.86,11.17C20.65,11.54 22,13.13 22,15.04Z\";\r\nvar mdiAppleIos = \"M2.09 16.8H3.75V9.76H2.09M2.92 8.84C3.44 8.84 3.84 8.44 3.84 7.94C3.84 7.44 3.44 7.04 2.92 7.04C2.4 7.04 2 7.44 2 7.94C2 8.44 2.4 8.84 2.92 8.84M9.25 7.06C6.46 7.06 4.7 8.96 4.7 12C4.7 15.06 6.46 16.96 9.25 16.96C12.04 16.96 13.8 15.06 13.8 12C13.8 8.96 12.04 7.06 9.25 7.06M9.25 8.5C10.96 8.5 12.05 9.87 12.05 12C12.05 14.15 10.96 15.5 9.25 15.5C7.54 15.5 6.46 14.15 6.46 12C6.46 9.87 7.54 8.5 9.25 8.5M14.5 14.11C14.57 15.87 16 16.96 18.22 16.96C20.54 16.96 22 15.82 22 14C22 12.57 21.18 11.77 19.23 11.32L18.13 11.07C16.95 10.79 16.47 10.42 16.47 9.78C16.47 9 17.2 8.45 18.28 8.45C19.38 8.45 20.13 9 20.21 9.89H21.84C21.8 8.2 20.41 7.06 18.29 7.06C16.21 7.06 14.73 8.21 14.73 9.91C14.73 11.28 15.56 12.13 17.33 12.53L18.57 12.82C19.78 13.11 20.27 13.5 20.27 14.2C20.27 15 19.47 15.57 18.31 15.57C17.15 15.57 16.26 15 16.16 14.11H14.5Z\";\r\nvar mdiAppleKeyboardCaps = \"M15,14V8H17.17L12,2.83L6.83,8H9V14H15M12,0L22,10H17V16H7V10H2L12,0M7,18H17V24H7V18M15,20H9V22H15V20Z\";\r\nvar mdiAppleKeyboardCommand = \"M6,2A4,4 0 0,1 10,6V8H14V6A4,4 0 0,1 18,2A4,4 0 0,1 22,6A4,4 0 0,1 18,10H16V14H18A4,4 0 0,1 22,18A4,4 0 0,1 18,22A4,4 0 0,1 14,18V16H10V18A4,4 0 0,1 6,22A4,4 0 0,1 2,18A4,4 0 0,1 6,14H8V10H6A4,4 0 0,1 2,6A4,4 0 0,1 6,2M16,18A2,2 0 0,0 18,20A2,2 0 0,0 20,18A2,2 0 0,0 18,16H16V18M14,10H10V14H14V10M6,16A2,2 0 0,0 4,18A2,2 0 0,0 6,20A2,2 0 0,0 8,18V16H6M8,6A2,2 0 0,0 6,4A2,2 0 0,0 4,6A2,2 0 0,0 6,8H8V6M18,8A2,2 0 0,0 20,6A2,2 0 0,0 18,4A2,2 0 0,0 16,6V8H18Z\";\r\nvar mdiAppleKeyboardControl = \"M19.78,11.78L18.36,13.19L12,6.83L5.64,13.19L4.22,11.78L12,4L19.78,11.78Z\";\r\nvar mdiAppleKeyboardOption = \"M3,4H9.11L16.15,18H21V20H14.88L7.84,6H3V4M14,4H21V6H14V4Z\";\r\nvar mdiAppleKeyboardShift = \"M15,18V12H17.17L12,6.83L6.83,12H9V18H15M12,4L22,14H17V20H7V14H2L12,4Z\";\r\nvar mdiAppleSafari = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12C4,14.09 4.8,16 6.11,17.41L9.88,9.88L17.41,6.11C16,4.8 14.09,4 12,4M12,20A8,8 0 0,0 20,12C20,9.91 19.2,8 17.89,6.59L14.12,14.12L6.59,17.89C8,19.2 9.91,20 12,20M12,12L11.23,11.23L9.7,14.3L12.77,12.77L12,12M12,17.5H13V19H12V17.5M15.88,15.89L16.59,15.18L17.65,16.24L16.94,16.95L15.88,15.89M17.5,12V11H19V12H17.5M12,6.5H11V5H12V6.5M8.12,8.11L7.41,8.82L6.35,7.76L7.06,7.05L8.12,8.11M6.5,12V13H5V12H6.5Z\";\r\nvar mdiApplication = \"M19,4C20.11,4 21,4.9 21,6V18A2,2 0 0,1 19,20H5C3.89,20 3,19.1 3,18V6A2,2 0 0,1 5,4H19M19,18V8H5V18H19Z\";\r\nvar mdiApplicationCog = \"M21.7 18.6V17.6L22.8 16.8C22.9 16.7 23 16.6 22.9 16.5L21.9 14.8C21.9 14.7 21.7 14.7 21.6 14.7L20.4 15.2C20.1 15 19.8 14.8 19.5 14.7L19.3 13.4C19.3 13.3 19.2 13.2 19.1 13.2H17.1C16.9 13.2 16.8 13.3 16.8 13.4L16.6 14.7C16.3 14.9 16.1 15 15.8 15.2L14.6 14.7C14.5 14.7 14.4 14.7 14.3 14.8L13.3 16.5C13.3 16.6 13.3 16.7 13.4 16.8L14.5 17.6V18.6L13.4 19.4C13.3 19.5 13.2 19.6 13.3 19.7L14.3 21.4C14.4 21.5 14.5 21.5 14.6 21.5L15.8 21C16 21.2 16.3 21.4 16.6 21.5L16.8 22.8C16.9 22.9 17 23 17.1 23H19.1C19.2 23 19.3 22.9 19.3 22.8L19.5 21.5C19.8 21.3 20 21.2 20.3 21L21.5 21.4C21.6 21.4 21.7 21.4 21.8 21.3L22.8 19.6C22.9 19.5 22.9 19.4 22.8 19.4L21.7 18.6M18 19.5C17.2 19.5 16.5 18.8 16.5 18S17.2 16.5 18 16.5 19.5 17.2 19.5 18 18.8 19.5 18 19.5M11.29 20H5C3.89 20 3 19.1 3 18V6C3 4.89 3.9 4 5 4H19C20.11 4 21 4.9 21 6V11.68C20.38 11.39 19.71 11.18 19 11.08V8H5V18H11C11 18.7 11.11 19.37 11.29 20Z\";\r\nvar mdiApplicationExport = \"M8,12H17.76L15.26,9.5L16.67,8.08L21.59,13L16.67,17.92L15.26,16.5L17.76,14H8V12M19,3C20.11,3 21,3.9 21,5V9.67L19,7.67V7H5V19H19V18.33L21,16.33V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3H19Z\";\r\nvar mdiApplicationImport = \"M1,12H10.76L8.26,9.5L9.67,8.08L14.59,13L9.67,17.92L8.26,16.5L10.76,14H1V12M19,3C20.11,3 21,3.9 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V16H5V19H19V7H5V10H3V5A2,2 0 0,1 5,3H19Z\";\r\nvar mdiApplicationSettings = \"M7 22H9V24H7V22M11 22H13V24H11V22M15 22H17V24H15V22M5 4H19A2 2 0 0 1 21 6V18A2 2 0 0 1 19 20H5A2 2 0 0 1 3 18V6A2 2 0 0 1 5 4M5 8V18H19V8H5\";\r\nvar mdiApproximatelyEqual = \"M18.9 9.2C18.1 10.1 16.6 11 15 11C13.5 11 12.6 10.5 11.8 10.1C11 9.8 10.2 9.3 8.9 9.3C7.7 9.3 6.6 10 6 10.6L5 9.1C5.9 8.2 7.3 7.2 8.9 7.2C10.4 7.2 11.3 7.8 12.1 8.1C12.9 8.4 13.7 9 15 9C16.2 9 17.3 8.2 17.9 7.6L18.9 9.2M19 14.1C18.1 15 16.7 16 15.1 16C13.6 16 12.7 15.5 11.9 15.1C11.1 14.8 10.3 14.2 9 14.2C7.8 14.2 6.7 15 6.1 15.6L5.1 14C6 13.1 7.4 12.1 9 12.1C10.5 12.1 11.4 12.6 12.2 13C13 13.3 13.8 13.8 15.1 13.8C16.3 13.8 17.4 13 18 12.4L19 14.1Z\";\r\nvar mdiApproximatelyEqualBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M9.3 8.2C10.6 8.2 11.4 8.7 12.1 9C12.7 9.3 13.4 9.7 14.5 9.7C15.5 9.7 16.5 9 17 8.5L17.8 9.8C17.1 10.6 15.8 11.4 14.4 11.4C13.1 11.4 12.3 10.9 11.7 10.6C11.1 10.3 10.3 9.9 9.2 9.9C8.2 9.9 7.2 10.6 6.7 11.1L6 9.8C6.7 9 8 8.2 9.3 8.2M14.6 15.8C13.3 15.8 12.5 15.3 11.8 15C11.2 14.7 10.4 14.3 9.3 14.3C8.3 14.3 7.3 15 6.8 15.5L6 14.1C6.7 13.3 8 12.5 9.3 12.5C10.6 12.5 11.4 13 12.1 13.3C12.7 13.6 13.4 14 14.6 14C15.6 14 16.6 13.3 17.1 12.8L17.9 14.1C17.3 15 16 15.8 14.6 15.8Z\";\r\nvar mdiApps = \"M16,20H20V16H16M16,14H20V10H16M10,8H14V4H10M16,8H20V4H16M10,14H14V10H10M4,14H8V10H4M4,20H8V16H4M10,20H14V16H10M4,8H8V4H4V8Z\";\r\nvar mdiAppsBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7,7V9H9V7H7M11,7V9H13V7H11M15,7V9H17V7H15M7,11V13H9V11H7M11,11V13H13V11H11M15,11V13H17V11H15M7,15V17H9V15H7M11,15V17H13V15H11M15,15V17H17V15H15Z\";\r\nvar mdiArch = \"M12,2C11.11,4.18 10.57,5.61 9.58,7.73C10.19,8.37 10.93,9.12 12.14,9.97C10.84,9.43 9.95,8.9 9.29,8.34C8,11 6.03,14.75 2,22C5.17,20.17 7.63,19.04 9.92,18.61C9.82,18.19 9.76,17.73 9.77,17.25V17.15C9.82,15.12 10.88,13.56 12.13,13.67C13.38,13.77 14.35,15.5 14.3,17.54C14.29,17.92 14.25,18.29 14.18,18.63C16.44,19.07 18.87,20.19 22,22C21.38,20.86 20.83,19.84 20.31,18.87C19.5,18.23 18.61,17.39 16.85,16.5C18.06,16.8 18.93,17.16 19.61,17.57C14.26,7.62 13.83,6.3 12,2Z\";\r\nvar mdiArchive = \"M3,3H21V7H3V3M4,8H20V21H4V8M9.5,11A0.5,0.5 0 0,0 9,11.5V13H15V11.5A0.5,0.5 0 0,0 14.5,11H9.5Z\";\r\nvar mdiArchiveAlert = \"M2 4H18V7H2V4M3 8H17V20H3V8M7.5 11C7.22 11 7 11.22 7 11.5V13H13V11.5C13 11.22 12.78 11 12.5 11H7.5M20 13V7H22V13H20M20 17V15H22V17H20Z\";\r\nvar mdiArchiveAlertOutline = \"M2 4H18V7H2V4M7.5 11H12.5C12.78 11 13 11.22 13 11.5V13H7V11.5C7 11.22 7.22 11 7.5 11M20 13V7H22V13H20M20 17V15H22V17H20M3 8H5V18H15V8H17V20H3V8Z\";\r\nvar mdiArchiveArrowDown = \"M3 3H21V7H3V3M4 21V8H20V21H4M14 14V11H10V14H7L12 19L17 14H14Z\";\r\nvar mdiArchiveArrowDownOutline = \"M20 21H4V10H6V19H18V10H20V21M3 3H21V9H3V3M5 5V7H19V5M10.5 11V14H8L12 18L16 14H13.5V11\";\r\nvar mdiArchiveArrowUp = \"M4 21H20V8H4M14 15V18H10V15H7L12 10L17 15M3 3H21V7H3\";\r\nvar mdiArchiveArrowUpOutline = \"M20 21H4V10H6V19H18V10H20V21M3 3H21V9H3V3M5 5V7H19V5M10.5 17V14H8L12 10L16 14H13.5V17\";\r\nvar mdiArchiveOutline = \"M20 21H4V10H6V19H18V10H20V21M3 3H21V9H3V3M9.5 11H14.5C14.78 11 15 11.22 15 11.5V13H9V11.5C9 11.22 9.22 11 9.5 11M5 5V7H19V5H5Z\";\r\nvar mdiArmFlex = \"M3 18.34C3 18.34 4 7.09 7 3L12 4L11 7.09H9V14.25H10C12 11.18 16.14 10.06 18.64 11.18C21.94 12.71 21.64 17.32 18.64 19.36C16.24 21 9 22.43 3 18.34Z\";\r\nvar mdiArmFlexOutline = \"M7 7.76V16.25H11.08L11.68 15.34C12.84 13.55 14.93 12.75 16.47 12.75C17 12.75 17.45 12.84 17.79 13C18.7 13.41 18.95 14.18 19 14.74C19.08 15.87 18.5 17.03 17.5 17.71C16.6 18.33 14.44 19 11.87 19C10.12 19 7.61 18.69 5.12 17.3C5.41 14.85 6 10.88 7 7.76M7 3C4 7.09 3 18.34 3 18.34C5.9 20.31 9.08 21 11.87 21C14.86 21 17.39 20.21 18.64 19.36C21.64 17.32 21.94 12.71 18.64 11.18C18 10.89 17.26 10.75 16.47 10.75C14.17 10.75 11.5 11.96 10 14.25H9V7.09H11L12 4L7 3Z\";\r\nvar mdiArrangeBringForward = \"M2,2H16V16H2V2M22,8V22H8V18H10V20H20V10H18V8H22Z\";\r\nvar mdiArrangeBringToFront = \"M2,2H11V6H9V4H4V9H6V11H2V2M22,13V22H13V18H15V20H20V15H18V13H22M8,8H16V16H8V8Z\";\r\nvar mdiArrangeSendBackward = \"M2,2H16V16H2V2M22,8V22H8V18H18V8H22M4,4V14H14V4H4Z\";\r\nvar mdiArrangeSendToBack = \"M2,2H11V11H2V2M9,4H4V9H9V4M22,13V22H13V13H22M15,20H20V15H15V20M16,8V11H13V8H16M11,16H8V13H11V16Z\";\r\nvar mdiArrowAll = \"M13,11H18L16.5,9.5L17.92,8.08L21.84,12L17.92,15.92L16.5,14.5L18,13H13V18L14.5,16.5L15.92,17.92L12,21.84L8.08,17.92L9.5,16.5L11,18V13H6L7.5,14.5L6.08,15.92L2.16,12L6.08,8.08L7.5,9.5L6,11H11V6L9.5,7.5L8.08,6.08L12,2.16L15.92,6.08L14.5,7.5L13,6V11Z\";\r\nvar mdiArrowBottomLeft = \"M19,6.41L17.59,5L7,15.59V9H5V19H15V17H8.41L19,6.41Z\";\r\nvar mdiArrowBottomLeftBoldOutline = \"M18.36,19.78H4.22V5.64L8.47,9.88L14.12,4.22L19.78,9.88L14.12,15.54L18.36,19.78M6.34,17.66H13.41L11.29,15.54L16.95,9.88L14.12,7.05L8.46,12.71L6.34,10.59V17.66Z\";\r\nvar mdiArrowBottomLeftThick = \"M15.5,5.69L18.31,8.5L11.94,14.89H16.89V18.31H5.69V7.11H9.12V12.06L15.5,5.69Z\";\r\nvar mdiArrowBottomLeftThinCircleOutline = \"M12 20.03C16.41 20.03 20.03 16.41 20.03 12C20.03 7.59 16.41 3.97 12 3.97C7.59 3.97 3.97 7.59 3.97 12C3.97 16.41 7.59 20.03 12 20.03M12 22C6.46 22 2 17.54 2 12C2 6.46 6.46 2 12 2C17.54 2 22 6.46 22 12C22 17.54 17.54 22 12 22M10.12 12.47L8 10.36V16H13.64L11.53 13.88L16.5 8.9L15.1 7.5\";\r\nvar mdiArrowBottomRight = \"M5,6.41L6.41,5L17,15.59V9H19V19H9V17H15.59L5,6.41Z\";\r\nvar mdiArrowBottomRightBoldOutline = \"M9.88,15.54L4.22,9.88L9.88,4.22L15.54,9.88L19.78,5.64V19.78H5.64L9.88,15.54M17.66,10.59L15.54,12.71L9.88,7.05L7.05,9.88L12.71,15.54L10.59,17.66H17.66V10.59Z\";\r\nvar mdiArrowBottomRightThick = \"M14.89,12.06V7.11H18.31V18.31H7.11V14.89H12.06L5.69,8.5L8.5,5.69L14.89,12.06Z\";\r\nvar mdiArrowBottomRightThinCircleOutline = \"M12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 7.59 7.59 3.97 12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03M12 22C17.54 22 22 17.54 22 12C22 6.46 17.54 2 12 2C6.46 2 2 6.46 2 12C2 17.54 6.46 22 12 22M13.88 12.47L16 10.36V16H10.36L12.47 13.88L7.5 8.9L8.9 7.5\";\r\nvar mdiArrowCollapse = \"M19.5,3.09L15,7.59V4H13V11H20V9H16.41L20.91,4.5L19.5,3.09M4,13V15H7.59L3.09,19.5L4.5,20.91L9,16.41V20H11V13H4Z\";\r\nvar mdiArrowCollapseAll = \"M19.5,3.09L20.91,4.5L16.41,9H20V11H13V4H15V7.59L19.5,3.09M20.91,19.5L19.5,20.91L15,16.41V20H13V13H20V15H16.41L20.91,19.5M4.5,3.09L9,7.59V4H11V11H4V9H7.59L3.09,4.5L4.5,3.09M3.09,19.5L7.59,15H4V13H11V20H9V16.41L4.5,20.91L3.09,19.5Z\";\r\nvar mdiArrowCollapseDown = \"M19.92,12.08L12,20L4.08,12.08L5.5,10.67L11,16.17V2H13V16.17L18.5,10.66L19.92,12.08M12,20H2V22H22V20H12Z\";\r\nvar mdiArrowCollapseHorizontal = \"M13,20V4H15.03V20H13M10,20V4H12.03V20H10M5,8L9.03,12L5,16V13H2V11H5V8M20,16L16,12L20,8V11H23V13H20V16Z\";\r\nvar mdiArrowCollapseLeft = \"M11.92,19.92L4,12L11.92,4.08L13.33,5.5L7.83,11H22V13H7.83L13.34,18.5L11.92,19.92M4,12V2H2V22H4V12Z\";\r\nvar mdiArrowCollapseRight = \"M12.08,4.08L20,12L12.08,19.92L10.67,18.5L16.17,13H2V11H16.17L10.67,5.5L12.08,4.08M20,12V22H22V2H20V12Z\";\r\nvar mdiArrowCollapseUp = \"M4.08,11.92L12,4L19.92,11.92L18.5,13.33L13,7.83V22H11V7.83L5.5,13.33L4.08,11.92M12,4H22V2H2V4H12Z\";\r\nvar mdiArrowCollapseVertical = \"M4,12H20V14H4V12M4,9H20V11H4V9M16,4L12,8L8,4H11V1H13V4H16M8,19L12,15L16,19H13V22H11V19H8Z\";\r\nvar mdiArrowDecision = \"M11,5H8L12,1L16,5H13V9.43C12.25,9.89 11.58,10.46 11,11.12V5M22,11L18,7V10C14.39,9.85 11.31,12.57 11,16.17C9.44,16.72 8.62,18.44 9.17,20C9.72,21.56 11.44,22.38 13,21.83C14.56,21.27 15.38,19.56 14.83,18C14.53,17.14 13.85,16.47 13,16.17C13.47,12.17 17.47,11.97 17.95,11.97V14.97L22,11M10.63,11.59C9.3,10.57 7.67,10 6,10V7L2,11L6,15V12C7.34,12.03 8.63,12.5 9.64,13.4C9.89,12.76 10.22,12.15 10.63,11.59Z\";\r\nvar mdiArrowDecisionAuto = \"M12,5H9L13,1L17,5H14V9.43C13.25,9.89 12.58,10.46 12,11.12V5M10.4,15H8.5L7.8,13H4.6L3.9,15H2L5.2,6H7.2L10.4,15M7.35,11.65L6.2,8L5.05,11.65H7.35M23,11L19,7V10C15.39,9.85 12.31,12.57 12,16.17C10.44,16.72 9.62,18.44 10.17,20C10.72,21.56 12.44,22.38 14,21.83C15.56,21.27 16.38,19.56 15.83,18C15.53,17.14 14.85,16.47 14,16.17C14.47,12.17 18.47,11.97 18.95,11.97V14.97L23,11Z\";\r\nvar mdiArrowDecisionAutoOutline = \"M19,15V12C18.5,12 14.5,12.16 14.05,16.2C15.61,16.75 16.43,18.47 15.88,20.03C15.33,21.59 13.61,22.41 12.05,21.86C10.5,21.3 9.67,19.59 10.22,18.03C10.5,17.17 11.2,16.5 12.05,16.2C12.34,12.61 15.4,9.88 19,10V7L23,11L19,15M14,19A1,1 0 0,0 13,18A1,1 0 0,0 12,19A1,1 0 0,0 13,20A1,1 0 0,0 14,19M12,11.12C12.58,10.46 13.25,9.89 14,9.43V5H17L13,1L9,5H12V11.12M7.2,6H5.2L2,15H3.9L4.6,13H7.8L8.5,15H10.4L7.2,6M5.05,11.65L6.2,8L7.35,11.65H5.05Z\";\r\nvar mdiArrowDecisionOutline = \"M9.64,13.4C8.63,12.5 7.34,12.03 6,12V15L2,11L6,7V10C7.67,10 9.3,10.57 10.63,11.59C10.22,12.15 9.89,12.76 9.64,13.4M18,15V12C17.5,12 13.5,12.16 13.05,16.2C14.61,16.75 15.43,18.47 14.88,20.03C14.33,21.59 12.61,22.41 11.05,21.86C9.5,21.3 8.67,19.59 9.22,18.03C9.5,17.17 10.2,16.5 11.05,16.2C11.34,12.61 14.4,9.88 18,10V7L22,11L18,15M13,19A1,1 0 0,0 12,18A1,1 0 0,0 11,19A1,1 0 0,0 12,20A1,1 0 0,0 13,19M11,11.12C11.58,10.46 12.25,9.89 13,9.43V5H16L12,1L8,5H11V11.12Z\";\r\nvar mdiArrowDown = \"M11,4H13V16L18.5,10.5L19.92,11.92L12,19.84L4.08,11.92L5.5,10.5L11,16V4Z\";\r\nvar mdiArrowDownBold = \"M9,4H15V12H19.84L12,19.84L4.16,12H9V4Z\";\r\nvar mdiArrowDownBoldBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M12,17L17,12H14V8H10V12H7L12,17Z\";\r\nvar mdiArrowDownBoldBoxOutline = \"M12,17L7,12H10V8H14V12H17L12,17M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiArrowDownBoldCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,17L17,12H14V8H10V12H7L12,17Z\";\r\nvar mdiArrowDownBoldCircleOutline = \"M12,17L7,12H10V8H14V12H17L12,17M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiArrowDownBoldHexagonOutline = \"M12,17L7,12H10V8H14V12H17L12,17M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiArrowDownBoldOutline = \"M22,11L12,21L2,11H8V3H16V11H22M12,18L17,13H14V5H10V13H7L12,18Z\";\r\nvar mdiArrowDownBox = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M11,6V14.5L7.5,11L6.08,12.42L12,18.34L17.92,12.42L16.5,11L13,14.5V6H11Z\";\r\nvar mdiArrowDownCircle = \"M11,6V14L7.5,10.5L6.08,11.92L12,17.84L17.92,11.92L16.5,10.5L13,14V6H11M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22Z\";\r\nvar mdiArrowDownCircleOutline = \"M11,6H13V14L16.5,10.5L17.92,11.92L12,17.84L6.08,11.92L7.5,10.5L11,14V6M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20Z\";\r\nvar mdiArrowDownDropCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M7,10L12,15L17,10H7Z\";\r\nvar mdiArrowDownDropCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M7,10L12,15L17,10H7Z\";\r\nvar mdiArrowDownThick = \"M10,4H14V13L17.5,9.5L19.92,11.92L12,19.84L4.08,11.92L6.5,9.5L10,13V4Z\";\r\nvar mdiArrowDownThinCircleOutline = \"M12 20.03C16.41 20.03 20.03 16.41 20.03 12C20.03 7.59 16.41 3.97 12 3.97C7.59 3.97 3.97 7.59 3.97 12C3.97 16.41 7.59 20.03 12 20.03M12 22C6.46 22 2 17.54 2 12C2 6.46 6.46 2 12 2C17.54 2 22 6.46 22 12C22 17.54 17.54 22 12 22M11 13.54H8L12 17.5L16 13.54H13V6.5H11\";\r\nvar mdiArrowExpand = \"M10,21V19H6.41L10.91,14.5L9.5,13.09L5,17.59V14H3V21H10M14.5,10.91L19,6.41V10H21V3H14V5H17.59L13.09,9.5L14.5,10.91Z\";\r\nvar mdiArrowExpandAll = \"M9.5,13.09L10.91,14.5L6.41,19H10V21H3V14H5V17.59L9.5,13.09M10.91,9.5L9.5,10.91L5,6.41V10H3V3H10V5H6.41L10.91,9.5M14.5,13.09L19,17.59V14H21V21H14V19H17.59L13.09,14.5L14.5,13.09M13.09,9.5L17.59,5H14V3H21V10H19V6.41L14.5,10.91L13.09,9.5Z\";\r\nvar mdiArrowExpandDown = \"M22,4V2H2V4H11V18.17L5.5,12.67L4.08,14.08L12,22L19.92,14.08L18.5,12.67L13,18.17V4H22Z\";\r\nvar mdiArrowExpandHorizontal = \"M9,11H15V8L19,12L15,16V13H9V16L5,12L9,8V11M2,20V4H4V20H2M20,20V4H22V20H20Z\";\r\nvar mdiArrowExpandLeft = \"M20,22H22V2H20V11H5.83L11.33,5.5L9.92,4.08L2,12L9.92,19.92L11.33,18.5L5.83,13H20V22Z\";\r\nvar mdiArrowExpandRight = \"M4,2H2V22H4V13H18.17L12.67,18.5L14.08,19.92L22,12L14.08,4.08L12.67,5.5L18.17,11H4V2Z\";\r\nvar mdiArrowExpandUp = \"M2,20V22H22V20H13V5.83L18.5,11.33L19.92,9.92L12,2L4.08,9.92L5.5,11.33L11,5.83V20H2Z\";\r\nvar mdiArrowExpandVertical = \"M13,9V15H16L12,19L8,15H11V9H8L12,5L16,9H13M4,2H20V4H4V2M4,20H20V22H4V20Z\";\r\nvar mdiArrowHorizontalLock = \"M14.8 7V5.5C14.8 4.1 13.4 3 12 3S9.2 4.1 9.2 5.5V7C8.6 7 8 7.6 8 8.2V11.7C8 12.4 8.6 13 9.2 13H14.7C15.4 13 16 12.4 16 11.8V8.3C16 7.6 15.4 7 14.8 7M13.5 7H10.5V5.5C10.5 4.7 11.2 4.2 12 4.2S13.5 4.7 13.5 5.5V7M6 17V20L2 16L6 12V15H18V12L22 16L18 20V17H6Z\";\r\nvar mdiArrowLeft = \"M20,11V13H8L13.5,18.5L12.08,19.92L4.16,12L12.08,4.08L13.5,5.5L8,11H20Z\";\r\nvar mdiArrowLeftBold = \"M20,9V15H12V19.84L4.16,12L12,4.16V9H20Z\";\r\nvar mdiArrowLeftBoldBox = \"M21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5M7,12L12,17V14H16V10H12V7L7,12Z\";\r\nvar mdiArrowLeftBoldBoxOutline = \"M7,12L12,7V10H16V14H12V17L7,12M21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5M19,5H5V19H19V5Z\";\r\nvar mdiArrowLeftBoldCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M7,12L12,17V14H16V10H12V7L7,12Z\";\r\nvar mdiArrowLeftBoldCircleOutline = \"M7,12L12,7V10H16V14H12V17L7,12M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12Z\";\r\nvar mdiArrowLeftBoldHexagonOutline = \"M7,12L12,7V10H16V14H12V17L7,12M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiArrowLeftBoldOutline = \"M13,22L3,12L13,2V8H21V16H13V22M6,12L11,17V14H19V10H11V7L6,12Z\";\r\nvar mdiArrowLeftBox = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5C3,3.89 3.9,3 5,3H19M18,11H9.5L13,7.5L11.58,6.08L5.66,12L11.58,17.92L13,16.5L9.5,13H18V11Z\";\r\nvar mdiArrowLeftCircle = \"M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M18,11H10L13.5,7.5L12.08,6.08L6.16,12L12.08,17.92L13.5,16.5L10,13H18V11Z\";\r\nvar mdiArrowLeftCircleOutline = \"M18,11V13H10L13.5,16.5L12.08,17.92L6.16,12L12.08,6.08L13.5,7.5L10,11H18M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12Z\";\r\nvar mdiArrowLeftDropCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M14,7L9,12L14,17V7Z\";\r\nvar mdiArrowLeftDropCircleOutline = \"M22,12A10,10 0 0,0 12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12M20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12M14,7L9,12L14,17V7Z\";\r\nvar mdiArrowLeftRight = \"M6.45,17.45L1,12L6.45,6.55L7.86,7.96L4.83,11H19.17L16.14,7.96L17.55,6.55L23,12L17.55,17.45L16.14,16.04L19.17,13H4.83L7.86,16.04L6.45,17.45Z\";\r\nvar mdiArrowLeftRightBold = \"M8,14V18L2,12L8,6V10H16V6L22,12L16,18V14H8Z\";\r\nvar mdiArrowLeftRightBoldOutline = \"M14,16V22L24,12L14,2V8H10V2L0,12L10,22V16H14M8,14V17L3,12L8,7V10H16V7L21,12L16,17V14H8Z\";\r\nvar mdiArrowLeftThick = \"M20,10V14H11L14.5,17.5L12.08,19.92L4.16,12L12.08,4.08L14.5,6.5L11,10H20Z\";\r\nvar mdiArrowLeftThinCircleOutline = \"M3.97 12C3.97 16.41 7.59 20.03 12 20.03C16.41 20.03 20.03 16.41 20.03 12C20.03 7.59 16.41 3.97 12 3.97C7.59 3.97 3.97 7.59 3.97 12M2 12C2 6.46 6.46 2 12 2C17.54 2 22 6.46 22 12C22 17.54 17.54 22 12 22C6.46 22 2 17.54 2 12M10.46 11V8L6.5 12L10.46 16V13H17.5V11\";\r\nvar mdiArrowRight = \"M4,11V13H16L10.5,18.5L11.92,19.92L19.84,12L11.92,4.08L10.5,5.5L16,11H4Z\";\r\nvar mdiArrowRightBold = \"M4,15V9H12V4.16L19.84,12L12,19.84V15H4Z\";\r\nvar mdiArrowRightBoldBox = \"M3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19M17,12L12,7V10H8V14H12V17L17,12Z\";\r\nvar mdiArrowRightBoldBoxOutline = \"M17,12L12,17V14H8V10H12V7L17,12M3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19M5,19H19V5H5V19Z\";\r\nvar mdiArrowRightBoldCircle = \"M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M17,12L12,7V10H8V14H12V17L17,12Z\";\r\nvar mdiArrowRightBoldCircleOutline = \"M17,12L12,17V14H8V10H12V7L17,12M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12Z\";\r\nvar mdiArrowRightBoldHexagonOutline = \"M17,12L12,17V14H8V10H12V7L17,12M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiArrowRightBoldOutline = \"M11,16H3V8H11V2L21,12L11,22V16M13,7V10H5V14H13V17L18,12L13,7Z\";\r\nvar mdiArrowRightBox = \"M5,21A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19C21,20.11 20.1,21 19,21H5M6,13H14.5L11,16.5L12.42,17.92L18.34,12L12.42,6.08L11,7.5L14.5,11H6V13Z\";\r\nvar mdiArrowRightCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M6,13H14L10.5,16.5L11.92,17.92L17.84,12L11.92,6.08L10.5,7.5L14,11H6V13Z\";\r\nvar mdiArrowRightCircleOutline = \"M6,13V11H14L10.5,7.5L11.92,6.08L17.84,12L11.92,17.92L10.5,16.5L14,13H6M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12Z\";\r\nvar mdiArrowRightDropCircle = \"M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M10,17L15,12L10,7V17Z\";\r\nvar mdiArrowRightDropCircleOutline = \"M2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2A10,10 0 0,0 2,12M4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12M10,17L15,12L10,7V17Z\";\r\nvar mdiArrowRightThick = \"M4,10V14H13L9.5,17.5L11.92,19.92L19.84,12L11.92,4.08L9.5,6.5L13,10H4Z\";\r\nvar mdiArrowRightThinCircleOutline = \"M20.03 12C20.03 7.59 16.41 3.97 12 3.97C7.59 3.97 3.97 7.59 3.97 12C3.97 16.41 7.59 20.03 12 20.03C16.41 20.03 20.03 16.41 20.03 12M22 12C22 17.54 17.54 22 12 22C6.46 22 2 17.54 2 12C2 6.46 6.46 2 12 2C17.54 2 22 6.46 22 12M13.54 13V16L17.5 12L13.54 8V11H6.5V13\";\r\nvar mdiArrowSplitHorizontal = \"M8,18H11V15H2V13H22V15H13V18H16L12,22L8,18M12,2L8,6H11V9H2V11H22V9H13V6H16L12,2Z\";\r\nvar mdiArrowSplitVertical = \"M18,16V13H15V22H13V2H15V11H18V8L22,12L18,16M2,12L6,16V13H9V22H11V2H9V11H6V8L2,12Z\";\r\nvar mdiArrowTopLeft = \"M19,17.59L17.59,19L7,8.41V15H5V5H15V7H8.41L19,17.59Z\";\r\nvar mdiArrowTopLeftBoldOutline = \"M14.12,8.46L19.78,14.12L14.12,19.78L8.46,14.12L4.22,18.36V4.22H18.36L14.12,8.46M6.34,13.41L8.46,11.29L14.12,16.95L16.95,14.12L11.29,8.47L13.41,6.34H6.34V13.41Z\";\r\nvar mdiArrowTopLeftBottomRight = \"M13,21H21V13H19V17.59L6.41,5H11V3H3V11H5V6.41L17.59,19H13V21Z\";\r\nvar mdiArrowTopLeftBottomRightBold = \"M5.83,8.66L3,11.5V3H11.5L8.66,5.83L18.17,15.34L21,12.5V21H12.5L15.34,18.17L5.83,8.66Z\";\r\nvar mdiArrowTopLeftThick = \"M9.12,11.94V16.89H5.69V5.69H16.89V9.12H11.94L18.31,15.5L15.5,18.31L9.12,11.94Z\";\r\nvar mdiArrowTopLeftThinCircleOutline = \"M12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 7.59 7.59 3.97 12 3.97M12 2C6.46 2 2 6.46 2 12C2 17.54 6.46 22 12 22C17.54 22 22 17.54 22 12C22 6.46 17.54 2 12 2M10.12 11.53L8 13.64V8H13.64L11.53 10.12L16.5 15.1L15.1 16.5\";\r\nvar mdiArrowTopRight = \"M5,17.59L15.59,7H9V5H19V15H17V8.41L6.41,19L5,17.59Z\";\r\nvar mdiArrowTopRightBoldOutline = \"M5.64,4.22H19.78V18.36L15.54,14.12L9.88,19.78L4.22,14.12L9.88,8.46L5.64,4.22M17.66,6.34H10.59L12.71,8.46L7.05,14.12L9.88,16.95L15.54,11.29L17.66,13.41V6.34H17.66Z\";\r\nvar mdiArrowTopRightBottomLeft = \"M11,21H3V13H5V17.59L17.59,5H13V3H21V11H19V6.41L6.41,19H11V21Z\";\r\nvar mdiArrowTopRightBottomLeftBold = \"M18.17,8.66L21,11.5V3H12.5L15.34,5.83L5.83,15.34L3,12.5V21H11.5L8.66,18.17L18.17,8.66Z\";\r\nvar mdiArrowTopRightThick = \"M8.5,18.31L5.69,15.5L12.06,9.12H7.11V5.69H18.31V16.89H14.89V11.94L8.5,18.31Z\";\r\nvar mdiArrowTopRightThinCircleOutline = \"M12 3.97C7.59 3.97 3.97 7.59 3.97 12C3.97 16.41 7.59 20.03 12 20.03C16.41 20.03 20.03 16.41 20.03 12C20.03 7.59 16.41 3.97 12 3.97M12 2C17.54 2 22 6.46 22 12C22 17.54 17.54 22 12 22C6.46 22 2 17.54 2 12C2 6.46 6.46 2 12 2M13.88 11.53L16 13.64V8H10.36L12.47 10.12L7.5 15.1L8.9 16.5\";\r\nvar mdiArrowUp = \"M13,20H11V8L5.5,13.5L4.08,12.08L12,4.16L19.92,12.08L18.5,13.5L13,8V20Z\";\r\nvar mdiArrowUpBold = \"M15,20H9V12H4.16L12,4.16L19.84,12H15V20Z\";\r\nvar mdiArrowUpBoldBox = \"M19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21M12,7L7,12H10V16H14V12H17L12,7Z\";\r\nvar mdiArrowUpBoldBoxOutline = \"M12,7L17,12H14V16H10V12H7L12,7M19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21M19,19V5H5V19H19Z\";\r\nvar mdiArrowUpBoldCircle = \"M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22M12,7L7,12H10V16H14V12H17L12,7Z\";\r\nvar mdiArrowUpBoldCircleOutline = \"M12,7L17,12H14V16H10V12H7L12,7M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20Z\";\r\nvar mdiArrowUpBoldHexagonOutline = \"M12,7L17,12H14V16H10V12H7L12,7M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiArrowUpBoldOutline = \"M16,13V21H8V13H2L12,3L22,13H16M7,11H10V19H14V11H17L12,6L7,11Z\";\r\nvar mdiArrowUpBox = \"M21,19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19C20.11,3 21,3.9 21,5V19M13,18V9.5L16.5,13L17.92,11.58L12,5.66L6.08,11.58L7.5,13L11,9.5V18H13Z\";\r\nvar mdiArrowUpCircle = \"M13,18V10L16.5,13.5L17.92,12.08L12,6.16L6.08,12.08L7.5,13.5L11,10V18H13M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiArrowUpCircleOutline = \"M13,18H11V10L7.5,13.5L6.08,12.08L12,6.16L17.92,12.08L16.5,13.5L13,10V18M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiArrowUpDown = \"M17.45,17.55L12,23L6.55,17.55L7.96,16.14L11,19.17V4.83L7.96,7.86L6.55,6.45L12,1L17.45,6.45L16.04,7.86L13,4.83V19.17L16.04,16.14L17.45,17.55Z\";\r\nvar mdiArrowUpDownBold = \"M10,8H6L12,2L18,8H14V16H18L12,22L6,16H10V8Z\";\r\nvar mdiArrowUpDownBoldOutline = \"M16,10H22L12,0L2,10H8V14H2L12,24L22,14H16V10M14,16H17L12,21L7,16H10V8H7L12,3L17,8H14V16Z\";\r\nvar mdiArrowUpDropCircle = \"M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22M17,14L12,9L7,14H17Z\";\r\nvar mdiArrowUpDropCircleOutline = \"M12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M17,14L12,9L7,14H17Z\";\r\nvar mdiArrowUpThick = \"M14,20H10V11L6.5,14.5L4.08,12.08L12,4.16L19.92,12.08L17.5,14.5L14,11V20Z\";\r\nvar mdiArrowUpThinCircleOutline = \"M12 3.97C7.59 3.97 3.97 7.59 3.97 12C3.97 16.41 7.59 20.03 12 20.03C16.41 20.03 20.03 16.41 20.03 12C20.03 7.59 16.41 3.97 12 3.97M12 2C17.54 2 22 6.46 22 12C22 17.54 17.54 22 12 22C6.46 22 2 17.54 2 12C2 6.46 6.46 2 12 2M13 10.46H16L12 6.5L8 10.46H11V17.5H13\";\r\nvar mdiArrowVerticalLock = \"M18.8 11V9.5C18.8 8.1 17.4 7 16 7S13.2 8.1 13.2 9.5V11C12.6 11 12 11.6 12 12.2V15.7C12 16.4 12.6 17 13.2 17H18.7C19.4 17 20 16.4 20 15.8V12.3C20 11.6 19.4 11 18.8 11M17.5 11H14.5V9.5C14.5 8.7 15.2 8.2 16 8.2C16.8 8.2 17.5 8.7 17.5 9.5V11M9 6H12L8 2L4 6H7V18H4L8 22L12 18H9V6Z\";\r\nvar mdiArtstation = \"M1.77,16.88L3.5,19.86C3.84,20.54 4.54,21 5.33,21H16.79L14.43,16.88H1.77M22.23,16.9C22.23,16.5 22.11,16.11 21.9,15.78L15.17,4.1C14.82,3.44 14.15,3 13.35,3H9.8L20.18,21L21.82,18.14C22.13,17.6 22.23,17.36 22.23,16.9M12.73,13.94L8.1,5.92L3.45,13.94H12.73Z\";\r\nvar mdiAspectRatio = \"M19,12H17V15H14V17H19V12M7,9H10V7H5V12H7V9M21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3M21,19H3V5H21V19Z\";\r\nvar mdiAssistant = \"M19,2H5A2,2 0 0,0 3,4V18A2,2 0 0,0 5,20H9L12,23L15,20H19A2,2 0 0,0 21,18V4A2,2 0 0,0 19,2M13.88,12.88L12,17L10.12,12.88L6,11L10.12,9.12L12,5L13.88,9.12L18,11\";\r\nvar mdiAsterisk = \"M10,2H14L13.21,9.91L19.66,5.27L21.66,8.73L14.42,12L21.66,15.27L19.66,18.73L13.21,14.09L14,22H10L10.79,14.09L4.34,18.73L2.34,15.27L9.58,12L2.34,8.73L4.34,5.27L10.79,9.91L10,2Z\";\r\nvar mdiAt = \"M12,15C12.81,15 13.5,14.7 14.11,14.11C14.7,13.5 15,12.81 15,12C15,11.19 14.7,10.5 14.11,9.89C13.5,9.3 12.81,9 12,9C11.19,9 10.5,9.3 9.89,9.89C9.3,10.5 9,11.19 9,12C9,12.81 9.3,13.5 9.89,14.11C10.5,14.7 11.19,15 12,15M12,2C14.75,2 17.1,3 19.05,4.95C21,6.9 22,9.25 22,12V13.45C22,14.45 21.65,15.3 21,16C20.3,16.67 19.5,17 18.5,17C17.3,17 16.31,16.5 15.56,15.5C14.56,16.5 13.38,17 12,17C10.63,17 9.45,16.5 8.46,15.54C7.5,14.55 7,13.38 7,12C7,10.63 7.5,9.45 8.46,8.46C9.45,7.5 10.63,7 12,7C13.38,7 14.55,7.5 15.54,8.46C16.5,9.45 17,10.63 17,12V13.45C17,13.86 17.16,14.22 17.46,14.53C17.76,14.84 18.11,15 18.5,15C18.92,15 19.27,14.84 19.57,14.53C19.87,14.22 20,13.86 20,13.45V12C20,9.81 19.23,7.93 17.65,6.35C16.07,4.77 14.19,4 12,4C9.81,4 7.93,4.77 6.35,6.35C4.77,7.93 4,9.81 4,12C4,14.19 4.77,16.07 6.35,17.65C7.93,19.23 9.81,20 12,20H17V22H12C9.25,22 6.9,21 4.95,19.05C3,17.1 2,14.75 2,12C2,9.25 3,6.9 4.95,4.95C6.9,3 9.25,2 12,2Z\";\r\nvar mdiAtlassian = \"M7.93,11.24C7.74,11 7.38,10.94 7.13,11.13C7.06,11.19 7,11.26 6.96,11.34L2.06,21.15C1.91,21.44 2.03,21.79 2.32,21.94C2.4,22 2.5,22 2.59,22H9.41C9.63,22 9.84,21.88 9.94,21.68C11.41,18.63 10.5,14 7.93,11.24M11.53,2.31C9.05,6.14 8.76,11 10.77,15.09L14.06,21.68C14.17,21.88 14.37,22 14.59,22H21.41A0.59,0.59 0 0,0 22,21.41C22,21.32 22,21.23 21.94,21.15C21.94,21.15 12.76,2.77 12.5,2.31C12.39,2.04 12.06,1.92 11.78,2.06C11.67,2.11 11.58,2.2 11.53,2.31Z\";\r\nvar mdiAtm = \"M8,9V10.5H10.25V15H11.75V10.5H14V9H8M6,9H3A1,1 0 0,0 2,10V15H3.5V13.5H5.5V15H7V10A1,1 0 0,0 6,9M5.5,12H3.5V10.5H5.5V12M21,9H16.5A1,1 0 0,0 15.5,10V15H17V10.5H18V14H19.5V10.5H20.5V15H22V10A1,1 0 0,0 21,9Z\";\r\nvar mdiAtom = \"M12,11A1,1 0 0,1 13,12A1,1 0 0,1 12,13A1,1 0 0,1 11,12A1,1 0 0,1 12,11M4.22,4.22C5.65,2.79 8.75,3.43 12,5.56C15.25,3.43 18.35,2.79 19.78,4.22C21.21,5.65 20.57,8.75 18.44,12C20.57,15.25 21.21,18.35 19.78,19.78C18.35,21.21 15.25,20.57 12,18.44C8.75,20.57 5.65,21.21 4.22,19.78C2.79,18.35 3.43,15.25 5.56,12C3.43,8.75 2.79,5.65 4.22,4.22M15.54,8.46C16.15,9.08 16.71,9.71 17.23,10.34C18.61,8.21 19.11,6.38 18.36,5.64C17.62,4.89 15.79,5.39 13.66,6.77C14.29,7.29 14.92,7.85 15.54,8.46M8.46,15.54C7.85,14.92 7.29,14.29 6.77,13.66C5.39,15.79 4.89,17.62 5.64,18.36C6.38,19.11 8.21,18.61 10.34,17.23C9.71,16.71 9.08,16.15 8.46,15.54M5.64,5.64C4.89,6.38 5.39,8.21 6.77,10.34C7.29,9.71 7.85,9.08 8.46,8.46C9.08,7.85 9.71,7.29 10.34,6.77C8.21,5.39 6.38,4.89 5.64,5.64M9.88,14.12C10.58,14.82 11.3,15.46 12,16.03C12.7,15.46 13.42,14.82 14.12,14.12C14.82,13.42 15.46,12.7 16.03,12C15.46,11.3 14.82,10.58 14.12,9.88C13.42,9.18 12.7,8.54 12,7.97C11.3,8.54 10.58,9.18 9.88,9.88C9.18,10.58 8.54,11.3 7.97,12C8.54,12.7 9.18,13.42 9.88,14.12M18.36,18.36C19.11,17.62 18.61,15.79 17.23,13.66C16.71,14.29 16.15,14.92 15.54,15.54C14.92,16.15 14.29,16.71 13.66,17.23C15.79,18.61 17.62,19.11 18.36,18.36Z\";\r\nvar mdiAtomVariant = \"M18.36,2.64C20,2.64 21.36,4 21.36,5.64C21.36,7.29 20,8.64 18.36,8.64C16.71,8.64 15.36,7.29 15.36,5.64C15.36,5.34 15.41,5.06 15.5,4.8C14.43,4.29 13.25,4 12,4A8,8 0 0,0 4,12L4.04,12.84L2.05,13.05L2,12A10,10 0 0,1 12,2C13.69,2 15.28,2.42 16.67,3.16C17.16,2.83 17.74,2.64 18.36,2.64M18.36,4.64A1,1 0 0,0 17.36,5.64A1,1 0 0,0 18.36,6.64C18.92,6.64 19.36,6.19 19.36,5.64C19.36,5.08 18.92,4.64 18.36,4.64M5.64,15.36C7.29,15.36 8.64,16.71 8.64,18.36C8.64,18.66 8.59,18.94 8.5,19.2C9.57,19.71 10.75,20 12,20A8,8 0 0,0 20,12L19.96,11.16L21.95,10.95L22,12A10,10 0 0,1 12,22C10.31,22 8.72,21.58 7.33,20.84C6.84,21.17 6.26,21.36 5.64,21.36C4,21.36 2.64,20 2.64,18.36C2.64,16.71 4,15.36 5.64,15.36M5.64,17.36C5.08,17.36 4.64,17.81 4.64,18.36C4.64,18.92 5.08,19.36 5.64,19.36A1,1 0 0,0 6.64,18.36A1,1 0 0,0 5.64,17.36M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8Z\";\r\nvar mdiAttachment = \"M7.5,18A5.5,5.5 0 0,1 2,12.5A5.5,5.5 0 0,1 7.5,7H18A4,4 0 0,1 22,11A4,4 0 0,1 18,15H9.5A2.5,2.5 0 0,1 7,12.5A2.5,2.5 0 0,1 9.5,10H17V11.5H9.5A1,1 0 0,0 8.5,12.5A1,1 0 0,0 9.5,13.5H18A2.5,2.5 0 0,0 20.5,11A2.5,2.5 0 0,0 18,8.5H7.5A4,4 0 0,0 3.5,12.5A4,4 0 0,0 7.5,16.5H17V18H7.5Z\";\r\nvar mdiAudioVideo = \"M20,7H4A2,2 0 0,0 2,9V15A2,2 0 0,0 4,17H5V18C5,18.6 5.4,19 6,19H8C8.6,19 9,18.6 9,18V17H15V18C15,18.6 15.4,19 16,19H18C18.6,19 19,18.6 19,18V17H20A2,2 0 0,0 22,15V9A2,2 0 0,0 20,7M14,12H4V10H14V12M18,13A2,2 0 0,1 16,11A2,2 0 0,1 18,9A2,2 0 0,1 20,11A2,2 0 0,1 18,13M6,15H4V14H6V15M10,15H8V14H10V15M14,15H12V14H14V15Z\";\r\nvar mdiAudioVideoOff = \"M22.1 21.5L2.4 1.7L1.1 3L5.1 7H4C2.9 7 2 7.9 2 9V15C2 16.1 2.9 17 4 17H5V18C5 18.6 5.4 19 6 19H8C8.6 19 9 18.6 9 18V17H15V18C15 18.6 15.4 19 16 19H17.1L20.8 22.7L22.1 21.5M6 15H4V14H6V15M4 12V10H8.1L10.1 12H4M10 15H8V14H10V15M12 15V14H12.1L13.1 15H12M14 10V10.8L20.2 17C21.2 16.9 22 16.1 22 15V9C22 7.9 21.1 7 20 7H10.2L13.2 10H14M18 9C19.1 9 20 9.9 20 11S19.1 13 18 13 16 12.1 16 11 16.9 9 18 9Z\";\r\nvar mdiAugmentedReality = \"M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M7,9H10C10.6,9 11,9.5 11,10V15H9.5V13.5H7.5V15H6V10C6,9.5 6.4,9 7,9M13,9H16.5C17.35,9 18,9.65 18,10.5V11.5C18,12.1 17.6,12.65 17.1,12.9L18,15H16.5L15.65,13H14.5V15H13V9M7.5,10.5V12H9.5V10.5H7.5M14.5,10.5V11.5H16.5V10.5H14.5\";\r\nvar mdiAutoDownload = \"M22 17V19H11V17H22M19 4.5V9.5H22L16.5 15L11 9.5H14V4.5H19M10.7 15H8.8L8.1 13H4.9L4.2 15H2.3L5.5 6H7.5L10.7 15M7.65 11.65L6.5 8L5.35 11.65H7.65Z\";\r\nvar mdiAutoFix = \"M7.5,5.6L5,7L6.4,4.5L5,2L7.5,3.4L10,2L8.6,4.5L10,7L7.5,5.6M19.5,15.4L22,14L20.6,16.5L22,19L19.5,17.6L17,19L18.4,16.5L17,14L19.5,15.4M22,2L20.6,4.5L22,7L19.5,5.6L17,7L18.4,4.5L17,2L19.5,3.4L22,2M13.34,12.78L15.78,10.34L13.66,8.22L11.22,10.66L13.34,12.78M14.37,7.29L16.71,9.63C17.1,10 17.1,10.65 16.71,11.04L5.04,22.71C4.65,23.1 4,23.1 3.63,22.71L1.29,20.37C0.9,20 0.9,19.35 1.29,18.96L12.96,7.29C13.35,6.9 14,6.9 14.37,7.29Z\";\r\nvar mdiAutoUpload = \"M5.35,12.65L6.5,9L7.65,12.65M5.5,7L2.3,16H4.2L4.9,14H8.1L8.8,16H10.7L7.5,7M11,20H22V18H11M14,16H19V11H22L16.5,5.5L11,11H14V16Z\";\r\nvar mdiAutorenew = \"M12,6V9L16,5L12,1V4A8,8 0 0,0 4,12C4,13.57 4.46,15.03 5.24,16.26L6.7,14.8C6.25,13.97 6,13 6,12A6,6 0 0,1 12,6M18.76,7.74L17.3,9.2C17.74,10.04 18,11 18,12A6,6 0 0,1 12,18V15L8,19L12,23V20A8,8 0 0,0 20,12C20,10.43 19.54,8.97 18.76,7.74Z\";\r\nvar mdiAvTimer = \"M11,17A1,1 0 0,0 12,18A1,1 0 0,0 13,17A1,1 0 0,0 12,16A1,1 0 0,0 11,17M11,3V7H13V5.08C16.39,5.57 19,8.47 19,12A7,7 0 0,1 12,19A7,7 0 0,1 5,12C5,10.32 5.59,8.78 6.58,7.58L12,13L13.41,11.59L6.61,4.79V4.81C4.42,6.45 3,9.05 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3M18,12A1,1 0 0,0 17,11A1,1 0 0,0 16,12A1,1 0 0,0 17,13A1,1 0 0,0 18,12M6,12A1,1 0 0,0 7,13A1,1 0 0,0 8,12A1,1 0 0,0 7,11A1,1 0 0,0 6,12Z\";\r\nvar mdiAws = \"M7.64,10.38C7.64,10.63 7.66,10.83 7.71,11C7.76,11.12 7.83,11.28 7.92,11.46C7.96,11.5 7.97,11.56 7.97,11.61C7.97,11.68 7.93,11.74 7.84,11.81L7.42,12.09C7.36,12.13 7.3,12.15 7.25,12.15C7.18,12.15 7.12,12.11 7.05,12.05C6.96,11.95 6.88,11.85 6.81,11.74C6.75,11.63 6.68,11.5 6.61,11.35C6.09,11.96 5.44,12.27 4.65,12.27C4.09,12.27 3.65,12.11 3.32,11.79C3,11.47 2.83,11.04 2.83,10.5C2.83,9.95 3.03,9.5 3.43,9.14C3.84,8.8 4.38,8.62 5.06,8.62C5.29,8.62 5.5,8.64 5.77,8.68C6,8.71 6.27,8.76 6.53,8.82V8.34C6.53,7.83 6.43,7.5 6.22,7.27C6,7.06 5.65,6.97 5.14,6.97C4.9,6.97 4.66,7 4.42,7.05C4.17,7.11 3.93,7.18 3.7,7.28C3.59,7.32 3.5,7.35 3.47,7.36C3.42,7.38 3.39,7.38 3.36,7.38C3.27,7.38 3.22,7.32 3.22,7.18V6.85C3.22,6.75 3.23,6.67 3.27,6.62C3.3,6.57 3.36,6.53 3.45,6.5C3.69,6.36 3.96,6.26 4.29,6.18C4.62,6.09 4.96,6.05 5.33,6.05C6.12,6.05 6.7,6.23 7.07,6.59C7.44,6.95 7.62,7.5 7.62,8.23V10.38H7.64M4.94,11.4C5.16,11.4 5.38,11.36 5.62,11.28C5.86,11.2 6.07,11.05 6.25,10.85C6.36,10.72 6.44,10.58 6.5,10.42C6.5,10.26 6.55,10.07 6.55,9.84V9.57C6.35,9.5 6.15,9.5 5.93,9.45C5.72,9.43 5.5,9.41 5.31,9.41C4.86,9.41 4.54,9.5 4.32,9.68C4.1,9.86 4,10.11 4,10.44C4,10.76 4.07,11 4.24,11.15C4.4,11.32 4.63,11.4 4.94,11.4M10.28,12.11C10.16,12.11 10.08,12.09 10,12.05C9.97,12 9.92,11.91 9.88,11.79L8.32,6.65C8.28,6.5 8.26,6.43 8.26,6.38C8.26,6.27 8.31,6.21 8.42,6.21H9.07C9.2,6.21 9.29,6.23 9.33,6.28C9.39,6.32 9.43,6.41 9.47,6.54L10.58,10.94L11.62,6.54C11.65,6.41 11.69,6.32 11.75,6.28C11.8,6.24 11.89,6.21 12,6.21H12.55C12.67,6.21 12.76,6.23 12.81,6.28C12.86,6.32 12.91,6.41 12.94,6.54L14,11L15.14,6.54C15.18,6.41 15.23,6.32 15.27,6.28C15.33,6.24 15.41,6.21 15.53,6.21H16.15C16.26,6.21 16.32,6.27 16.32,6.38C16.32,6.41 16.31,6.45 16.3,6.5C16.3,6.5 16.28,6.58 16.26,6.65L14.65,11.79C14.61,11.93 14.57,12 14.5,12.05C14.46,12.09 14.37,12.12 14.26,12.12H13.69C13.56,12.12 13.5,12.1 13.42,12.05C13.37,12 13.32,11.92 13.3,11.79L12.27,7.5L11.24,11.78C11.21,11.91 11.17,12 11.12,12.05C11.06,12.09 10.97,12.11 10.85,12.11H10.28M18.83,12.29C18.5,12.29 18.13,12.25 17.8,12.17C17.47,12.09 17.21,12 17.04,11.91C16.93,11.85 16.86,11.78 16.83,11.72C16.8,11.66 16.79,11.6 16.79,11.54V11.2C16.79,11.06 16.84,11 16.94,11C17,11 17,11 17.06,11C17.1,11 17.16,11.05 17.23,11.08C17.45,11.18 17.7,11.26 17.96,11.31C18.23,11.36 18.5,11.39 18.75,11.39C19.17,11.39 19.5,11.32 19.72,11.17C19.95,11 20.07,10.81 20.07,10.54C20.07,10.35 20,10.2 19.89,10.07C19.77,9.95 19.54,9.83 19.22,9.73L18.25,9.43C17.77,9.27 17.41,9.05 17.19,8.75C16.97,8.46 16.86,8.13 16.86,7.78C16.86,7.5 16.92,7.26 17.04,7.05C17.16,6.83 17.32,6.65 17.5,6.5C17.72,6.35 17.94,6.24 18.21,6.16C18.47,6.08 18.75,6.04 19.05,6.04C19.19,6.04 19.34,6.05 19.5,6.07C19.64,6.09 19.78,6.12 19.92,6.14C20.06,6.18 20.18,6.21 20.3,6.25C20.42,6.29 20.5,6.33 20.58,6.37C20.67,6.42 20.74,6.47 20.78,6.53C20.82,6.59 20.84,6.66 20.84,6.75V7.07C20.84,7.21 20.79,7.28 20.69,7.28C20.64,7.28 20.55,7.25 20.43,7.2C20.06,7.03 19.63,6.94 19.16,6.94C18.78,6.94 18.5,7 18.27,7.13C18.07,7.25 17.96,7.45 17.96,7.72C17.96,7.91 18.03,8.07 18.16,8.19C18.29,8.32 18.54,8.44 18.89,8.56L19.84,8.86C20.32,9 20.66,9.22 20.87,9.5C21.07,9.77 21.17,10.08 21.17,10.43C21.17,10.71 21.11,10.97 21,11.2C20.88,11.42 20.72,11.62 20.5,11.78C20.31,11.95 20.06,12.07 19.78,12.16C19.5,12.25 19.16,12.29 18.83,12.29M20.08,15.53C17.89,17.14 14.71,18 12,18C8.15,18 4.7,16.58 2.09,14.23C1.88,14.04 2.07,13.79 2.32,13.94C5.14,15.57 8.61,16.56 12.21,16.56C14.64,16.56 17.31,16.06 19.76,15C20.13,14.85 20.44,15.26 20.08,15.53M21,14.5C20.71,14.13 19.14,14.32 18.43,14.4C18.22,14.43 18.19,14.24 18.38,14.1C19.63,13.23 21.69,13.5 21.92,13.77C22.16,14.07 21.86,16.13 20.69,17.11C20.5,17.26 20.33,17.18 20.41,17C20.68,16.32 21.27,14.84 21,14.5Z\";\r\nvar mdiAxe = \"M12,2L22,8C22,12 20,14 16,15L13,10L9,6L12,2M4.11,19.84L2.12,18.33L9.19,9L11,10.81L4.11,19.84Z\";\r\nvar mdiAxis = \"M2.61,21L1.61,19.27L11,13.85V3H13V13.85L22.39,19.27L21.39,21L12,15.58L2.61,21Z\";\r\nvar mdiAxisArrow = \"M12,2L16,6H13V13.85L19.53,17.61L21,15.03L22.5,20.5L17,21.96L18.53,19.35L12,15.58L5.47,19.35L7,21.96L1.5,20.5L3,15.03L4.47,17.61L11,13.85V6H8L12,2Z\";\r\nvar mdiAxisArrowInfo = \"M12 2L16 6H13V13.85L19.53 17.61L21 15.03L22.5 20.5L17 21.96L18.53 19.35L12 15.58L5.47 19.35L7 21.96L1.5 20.5L3 15.03L4.47 17.61L11 13.85V6H8L12 2M21 5H19V3H21V5M22 10V12H18V10H19V8H18V6H21V10H22Z\";\r\nvar mdiAxisArrowLock = \"M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.2,2.2 17.5,2.7 17.5,3.5V5H20.5M1.74,19.25L3.21,13.79L4.68,16.34L9,13.85V6H6L10,2L14,6H11V13.85L18.03,17.86L19.5,15.28L21,20.74L15.5,22.21L17.03,19.6L10,15.58L5.68,18.07L7.21,20.71L1.74,19.25Z\";\r\nvar mdiAxisLock = \"M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.2,2.2 17.5,2.7 17.5,3.5V5H20.5M11,13.82L20.39,19.25L19.39,21L10,15.56L3.17,19.5L2.17,17.77L9,13.82V3H11V13.82Z\";\r\nvar mdiAxisXArrow = \"M1.5,20.5L3,15.03L4.46,17.6L11,13.82V3H13V13.82L22.39,19.25L21.39,21L12,15.56L5.46,19.33L7,21.96L1.5,20.5Z\";\r\nvar mdiAxisXArrowLock = \"M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.31,2.2 17.69,2.58 17.54,3.2C17.5,3.29 17.5,3.39 17.5,3.5V5H20.5M1.74,19.25L3.21,13.79L4.67,16.32L9,13.82V3H11V13.82L20.39,19.25L19.39,21L10,15.56L5.67,18.06L7.21,20.71L1.74,19.25Z\";\r\nvar mdiAxisXRotateClockwise = \"M12,10H14.91C14.57,6.55 13.4,4 12,4C10.42,4 9.12,7.27 9,11.42L7,12.57V12C7,6.5 9.24,2 12,2C14.42,2 16.44,5.44 16.9,10H20L16,14L12,10M12,22C10.12,22 8.47,19.92 7.62,16.84L9.37,15.83C9.87,18.31 10.86,20 12,20C13.27,20 14.36,17.89 14.79,14.92L16,16.12L16.7,15.42C16,19.26 14.16,22 12,22M2.11,18.87L1.11,17.13L1.06,17.06L11.12,11.25L12.72,12.84L2.15,18.94L2.11,18.87M21.89,5.13L22.89,6.87L19.2,9H17.77L17.5,7.66L21.89,5.13Z\";\r\nvar mdiAxisXRotateCounterclockwise = \"M12,14L16,10L20,14H16.9C16.44,18.56 14.42,22 12,22C10.12,22 8.47,19.92 7.62,16.84L9.37,15.83C9.87,18.31 10.86,20 12,20C13.4,20 14.57,17.45 14.91,14H12M1.11,17.13L13.89,9.75L13.96,10.54L10.5,14H10.54L2.11,18.87L1.11,17.13M21.89,5.13L22.89,6.87L17.88,9.76C17.79,9.03 17.67,8.33 17.5,7.66L21.89,5.13M12,2C14.3,2 16.23,5.1 16.82,9.32L16,8.5L14.87,9.63C14.5,6.37 13.35,4 12,4C10.42,4 9.12,7.27 9,11.42L7,12.57V12C7,6.5 9.24,2 12,2Z\";\r\nvar mdiAxisXYArrowLock = \"M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.2,2.2 17.5,2.7 17.5,3.5V5H20.5M1.74,19.25L3.21,13.79L4.68,16.34L9,13.85V3H11V13.85L17.53,17.61L19,15.03L20.5,20.5L15,21.96L16.53,19.35L10,15.58L5.68,18.07L7.21,20.71L1.74,19.25Z\";\r\nvar mdiAxisYArrow = \"M22.5,20.5L17,21.96L18.53,19.35L12,15.58L2.61,21L1.61,19.27L11,13.85V3H13V13.85L19.53,17.61L21,15.03L22.5,20.5Z\";\r\nvar mdiAxisYArrowLock = \"M11,13.82L18,17.88L19.5,15.28L21,20.74L15.5,22.21L17,19.61L10,15.56L3.17,19.5L2.17,17.77L9,13.82V3H11V13.82M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.2,2.2 17.5,2.7 17.5,3.5V5H20.5Z\";\r\nvar mdiAxisYRotateClockwise = \"M12,10L16,14L20,10H16.9C16.44,5.44 14.42,2 12,2C10.12,2 8.47,4.08 7.62,7.16L9.37,8.17C9.87,5.69 10.86,4 12,4C13.4,4 14.57,6.55 14.91,10H12M1.11,6.87L13.89,14.25L13.96,13.46L10.5,10H10.54L2.11,5.13L1.11,6.87M21.89,18.87L22.89,17.13L17.88,14.24C17.79,14.97 17.67,15.67 17.5,16.34L21.89,18.87M12,22C14.3,22 16.23,18.9 16.82,14.68L16,15.5L14.87,14.37C14.5,17.63 13.35,20 12,20C10.42,20 9.12,16.73 9,12.58L7,11.43V12C7,17.5 9.24,22 12,22Z\";\r\nvar mdiAxisYRotateCounterclockwise = \"M12,14H14.91C14.57,17.45 13.4,20 12,20C10.42,20 9.12,16.73 9,12.58L7,11.43V12C7,17.5 9.24,22 12,22C14.42,22 16.44,18.56 16.9,14H20L16,10L12,14M12,2C10.12,2 8.47,4.08 7.62,7.16L9.37,8.17C9.87,5.69 10.86,4 12,4C13.27,4 14.36,6.11 14.79,9.08L16,7.88L16.7,8.58C16,4.74 14.16,2 12,2M2.11,5.13L1.11,6.87L1.06,6.94L11.12,12.75L12.72,11.16L2.15,5.06L2.11,5.13M21.89,18.87L22.89,17.13L19.2,15H17.77L17.5,16.34L21.89,18.87Z\";\r\nvar mdiAxisZArrow = \"M12,2L16,6H13V13.82L22.39,19.25L21.39,21L12,15.56L2.61,21L1.61,19.25L11,13.82V6H8L12,2Z\";\r\nvar mdiAxisZArrowLock = \"M21.8,5C22.4,5 23,5.6 23,6.3V9.8C23,10.4 22.4,11 21.7,11H16.2C15.6,11 15,10.4 15,9.7V6.2C15,5.6 15.6,5 16.2,5V3.5C16.2,2.1 17.6,1 19,1C20.4,1 21.8,2.1 21.8,3.5V5M20.5,5V3.5C20.5,2.7 19.8,2.2 19,2.2C18.2,2.2 17.5,2.7 17.5,3.5V5H20.5M10,2L14,6H11V13.82L20.39,19.25L19.39,21L10,15.56L3.17,19.5L2.17,17.77L9,13.82V6H6L10,2Z\";\r\nvar mdiAxisZRotateClockwise = \"M14,12L10,16L14,20V16.9C18.56,16.44 22,14.42 22,12C22,9.58 18.56,7.56 14,7.1V9.09C17.45,9.43 20,10.6 20,12C20,13.4 17.45,14.57 14,14.91V12M4,12C4,10.6 6.55,9.43 10,9.09V7.1C5.44,7.56 2,9.58 2,12C2,14.16 4.74,16 8.58,16.7L7.88,16L9.08,14.79C6.11,14.36 4,13.27 4,12M13,2H11V13L13,11V2M13,22V21L11,19V22H13Z\";\r\nvar mdiAxisZRotateCounterclockwise = \"M10,12L14,16L10,20V16.9C5.44,16.44 2,14.42 2,12C2,9.58 5.44,7.56 10,7.1V9.09C6.55,9.43 4,10.6 4,12C4,13.4 6.55,14.57 10,14.91V12M20,12C20,10.6 17.45,9.43 14,9.09V7.1C18.56,7.56 22,9.58 22,12C22,14.16 19.26,16 15.42,16.7L16.12,16L14.92,14.79C17.89,14.36 20,13.27 20,12M11,2H13V13L11,11V2M11,22V21L13,19V22H11Z\";\r\nvar mdiBabel = \"M15.14 2C13.8 2.12 12.04 2.59 9.87 3.43C9.28 3.87 8.6 4.3 7.84 4.72V4.85C7.9 4.85 7.96 4.81 8.04 4.77C8.13 4.76 8.19 4.79 8.19 4.88L8.32 4.8L8.39 4.79L8.4 4.86C8.41 4.92 7.93 5.29 7 5.96L7.06 6.09H7L6.84 6.04C6.84 6.09 6.78 6.11 6.64 6.12L6.65 6.19L6.81 6.37C6.75 6.37 6.68 6.36 6.6 6.32C6.29 6.35 6 6.58 5.69 7L5.77 7.12C6.03 6.88 6.18 6.76 6.22 6.76L6.24 6.95C6.2 6.95 6.12 7 6.04 7.03L6.2 7.27C6.5 6.93 6.86 6.64 7.24 6.41C7.43 6.46 7.53 6.5 7.53 6.58L7.67 6.57C8.69 5.81 9.71 5.27 10.71 4.93L10.72 5.06C10.53 5.34 10.4 5.5 10.33 5.5C10.34 5.59 10.38 5.67 10.43 5.74C10.45 5.92 10 7.06 9.07 9.19C6.95 14.13 5.19 17.78 3.77 20.16C3.77 20.2 3.8 20.27 3.85 20.35C4.2 20.26 4.42 20.18 4.5 20.1L4.6 20.09L4.61 20.22L4.74 20.21L4.88 20.13C4.88 20.18 4.93 20.19 5 20.18L5.03 20.31C5.03 20.45 4.96 20.65 4.8 20.92C4.65 21.08 4.5 21.42 4.34 21.94V22H4.47C5.04 21.35 5.5 20.72 5.78 20.11C7.44 19.62 8.71 19.15 9.59 18.67C10.47 18.6 11.15 18.37 11.61 18L11.6 17.91L11.27 18H11.19L11.18 17.95C11.83 17.85 12.28 17.7 12.5 17.5C13.79 16.54 14.74 15.85 15.39 15.44C17.39 13.97 18.33 12.55 18.22 11.21C18.21 11.07 17.76 10.5 16.9 9.56C16.88 9.38 17.19 9.12 17.8 8.77L19.53 7.24C19.92 6.74 20.15 5.94 20.23 4.83L20.2 4.57C20.14 3.79 19.58 3.16 18.5 2.68C17.88 2.25 16.76 2.03 15.14 2M17.24 2.87C18.53 2.92 19.19 3.14 19.23 3.55L19.18 3.68L17.24 2.87M16 3.96C16.89 3.95 17.35 4.18 17.4 4.68L17.5 4.67V4.34L17.64 4.33C18 4.5 18.16 4.74 18.18 5C18.2 5.2 18.1 5.42 17.89 5.69C17.8 5.7 17.75 5.64 17.74 5.5H17.6L17.56 5.91C17 6.78 16.56 7.23 16.3 7.26C16.06 7.58 15.91 7.75 15.85 7.75C15.67 7.97 15.17 8.35 14.35 8.87C14.08 8.9 13.07 9.28 11.34 10.04C11.25 10 11.16 10 11.06 10L11.05 9.88C11.03 9.62 11.14 9.31 11.39 8.92C11.5 8.21 11.67 7.8 11.83 7.7L13.28 4.44C13.27 4.24 13.57 4.09 14.21 4L14.42 3.96L14.44 4.15C15.06 4.05 15.45 4 15.6 4C15.74 3.97 15.88 3.96 16 3.96M19 4.29H19.04C19.16 4.3 19.28 4.5 19.41 4.91L19.42 5.03C19.35 5.04 19.22 4.83 19.03 4.41L19 4.29M10.82 6.36H10.88L10.9 6.55C10.84 6.56 10.75 6.65 10.65 6.83L10.64 6.7C10.76 6.55 10.82 6.43 10.82 6.36M6.67 6.46L6.68 6.5C6.63 6.5 6.56 6.56 6.5 6.6L6.41 6.61L6.39 6.5L6.67 6.46M10.24 7.72L10.26 8H10.19L10.16 7.73L10.24 7.72M10.07 8.19C10.05 8.41 10 8.5 9.89 8.53L9.82 8.54C9.9 8.39 9.94 8.29 9.93 8.21L10.07 8.19M9.78 8.87L9.79 8.93L9.67 9.14L9.54 9.15L9.53 9.09C9.66 9.08 9.72 9 9.71 8.88L9.78 8.87M9.5 9.5L9.45 9.81H9.38L9.36 9.5H9.5M16.57 9.72L16.85 9.89C16.86 10 16.82 10.03 16.73 10.04C16.61 9.96 16.5 9.93 16.44 9.93L16.43 9.73L16.57 9.72M11 10.46L11.03 10.58L10.76 10.61L10.75 10.5L11 10.46M15.5 10.91C15.68 11 15.78 11.09 15.79 11.16L15.8 11.22C15.61 11.24 15.45 11.14 15.29 10.93L15.5 10.91M17.66 11.12C17.81 11.18 17.88 11.25 17.89 11.31L17.93 11.82C17.87 11.96 17.81 12.03 17.74 12.03L17.66 11.12M14.16 11.18C14.86 11.17 15.4 11.33 15.76 11.68L15.79 11.94C15.5 12.85 15.13 13.38 14.75 13.54L13 14.93C11.7 15.79 11 16.21 10.9 16.22C8.83 17.36 7.54 17.95 7.04 18H6.96C7.03 17.76 7.95 15.87 9.73 12.33C10.5 12.26 11.76 11.89 13.44 11.23L13.85 11.19C13.96 11.19 14.06 11.18 14.16 11.18M11.62 11.59L11.63 11.65L11.35 11.67L11.34 11.61L11.62 11.59M7.26 15.81C7.17 16.26 7.08 16.5 7 16.5L6.97 16.43C6.95 16.2 7.05 16 7.26 15.81M13.18 16.09L13.19 16.21C13.2 16.27 13 16.43 12.6 16.72C11.44 17.29 10.76 17.68 10.56 17.88C9.3 18.32 8.68 18.59 8.69 18.69C7.57 19.14 6.84 19.46 6.5 19.66C6.41 19.67 6.29 19.63 6.13 19.56C6.12 19.34 6.21 19.15 6.44 19C6.63 19 6.82 19 7 19.09C7.21 19 7.57 18.87 8.08 18.74L8.07 18.61L7.66 18.65C7.71 18.58 8.11 18.4 8.86 18.09L9.07 18.07L9.08 18.13C8.73 18.16 8.53 18.27 8.5 18.46C8.5 18.53 8.53 18.58 8.62 18.57C8.87 18.39 9 18.3 9 18.27C9.5 18.18 10.9 17.44 13.18 16.09M6.86 16.69L6.87 16.75C6.88 16.84 6.83 16.89 6.74 16.9V16.84C6.73 16.76 6.77 16.71 6.86 16.69M10 17.5C10.07 17.47 10.12 17.5 10.12 17.58C9.96 17.6 9.65 17.73 9.19 18H9.12L9.11 17.87C9.44 17.84 9.73 17.71 9.97 17.5H10M6.95 18.5L6.96 18.58C6.9 18.58 6.84 18.61 6.75 18.66L6.62 18.67C6.61 18.61 6.65 18.55 6.74 18.53L6.95 18.5M5.35 19.3L5.5 19.36C5.44 19.76 5.33 19.96 5.13 20C4.97 19.91 4.83 19.88 4.7 19.89L4.68 19.7C4.67 19.62 4.72 19.57 4.82 19.55C4.9 19.54 4.95 19.6 4.96 19.73C5.2 19.44 5.33 19.3 5.35 19.3Z\";\r\nvar mdiBaby = \"M18.5,4A2.5,2.5 0 0,1 21,6.5A2.5,2.5 0 0,1 18.5,9A2.5,2.5 0 0,1 16,6.5A2.5,2.5 0 0,1 18.5,4M4.5,20A1.5,1.5 0 0,1 3,18.5A1.5,1.5 0 0,1 4.5,17H11.5A1.5,1.5 0 0,1 13,18.5A1.5,1.5 0 0,1 11.5,20H4.5M16.09,19L14.69,15H11L6.75,10.75C6.75,10.75 9,8.25 12.5,8.25C15.5,8.25 15.85,9.25 16.06,9.87L18.92,18C19.2,18.78 18.78,19.64 18,19.92C17.22,20.19 16.36,19.78 16.09,19Z\";\r\nvar mdiBabyBottle = \"M11.28 2.8L10.78 3.3A5.5 5.5 0 0 0 6.41 2.87L6.33 2.8A2.5 2.5 0 0 0 2.8 6.33L2.87 6.41A5.5 5.5 0 0 0 3.3 10.78L2.8 11.28A1.5 1.5 0 0 0 2.8 13.4L4.21 14.82A1.5 1.5 0 0 0 6.33 14.82L6.68 14.46L13.76 21.53A1.5 1.5 0 0 0 15.88 21.53L21.53 15.88A1.5 1.5 0 0 0 21.53 13.76L14.46 6.68L14.82 6.33A1.5 1.5 0 0 0 14.82 4.21L13.4 2.8A1.5 1.5 0 0 0 11.28 2.8M13.76 5.27L5.27 13.76L3.86 12.34L12.34 3.86M14.82 11.63L11.63 14.82L10.57 13.76L13.76 10.57M16.94 13.76L13.76 16.94L12.69 15.88L15.88 12.69Z\";\r\nvar mdiBabyBottleOutline = \"M11.28 2.8L10.78 3.3C9.44 2.55 7.84 2.4 6.41 2.87L6.33 2.8C5.36 1.82 3.77 1.82 2.8 2.8S1.82 5.36 2.8 6.33L2.87 6.41C2.4 7.84 2.55 9.44 3.3 10.78L2.8 11.28C2.21 11.87 2.21 12.81 2.8 13.4L4.21 14.82C4.8 15.4 5.74 15.4 6.33 14.82L6.68 14.46L13.76 21.53C14.34 22.12 15.29 22.12 15.88 21.53L21.53 15.88C22.12 15.29 22.12 14.34 21.53 13.75L14.46 6.68L14.82 6.33C15.4 5.74 15.4 4.8 14.82 4.21L13.4 2.79C12.82 2.21 11.87 2.21 11.28 2.8M4.25 7.05C4.33 6.71 4.47 6.38 4.66 6.07L3.86 5.27C3.75 5.16 3.67 5.04 3.63 4.9C3.5 4.56 3.57 4.14 3.86 3.86S4.56 3.5 4.9 3.63C5.04 3.67 5.16 3.75 5.27 3.86L6.07 4.66C6.38 4.47 6.71 4.33 7.05 4.25C7.91 4 8.83 4.06 9.65 4.42L4.42 9.65C4.06 8.83 4 7.91 4.25 7.05M20.47 14.82L14.82 20.47L7.75 13.4L13.4 7.75L20.47 14.82M13.76 5.27L5.27 13.76L3.86 12.34L12.34 3.86L13.76 5.27M14.82 11.63L11.63 14.82L10.57 13.76L13.76 10.57L14.82 11.63M16.94 13.76L13.76 16.94L12.69 15.88L15.88 12.69L16.94 13.76Z\";\r\nvar mdiBabyBuggy = \"M17 20A2 2 0 0 1 15 22A2 2 0 0 1 13 20A2 2 0 0 1 15 18A2 2 0 0 1 17 20M7 20A2 2 0 0 1 5 22A2 2 0 0 1 3 20A2 2 0 0 1 5 18A2 2 0 0 1 7 20M17.61 3C16.95 3 16.44 3.2 16 3.5C15.32 3.91 14.88 4.59 14.47 5.07L5.71 15.35C5.16 16 5.62 17 6.47 17H14C15.11 17 16 16.1 16 15V6.38C16.58 5.7 16.93 5 17.61 5C18.38 5 19 5.66 19 6.5V7H21V6.5C21 4.56 19.5 3 17.61 3M8.86 3.09C7.04 3.16 5.23 3.76 3.68 4.9L8.44 9.66L12.32 5.1C12.59 4.78 12.91 4.38 13.3 4C12.14 3.45 10.9 3.15 9.65 3.09C9.39 3.08 9.12 3.08 8.86 3.09Z\";\r\nvar mdiBabyCarriage = \"M13,2V10H21A8,8 0 0,0 13,2M19.32,15.89C20.37,14.54 21,12.84 21,11H6.44L5.5,9H2V11H4.22C4.22,11 6.11,15.07 6.34,15.42C5.24,16 4.5,17.17 4.5,18.5A3.5,3.5 0 0,0 8,22C9.76,22 11.22,20.7 11.46,19H13.54C13.78,20.7 15.24,22 17,22A3.5,3.5 0 0,0 20.5,18.5C20.5,17.46 20.04,16.53 19.32,15.89M8,20A1.5,1.5 0 0,1 6.5,18.5A1.5,1.5 0 0,1 8,17A1.5,1.5 0 0,1 9.5,18.5A1.5,1.5 0 0,1 8,20M17,20A1.5,1.5 0 0,1 15.5,18.5A1.5,1.5 0 0,1 17,17A1.5,1.5 0 0,1 18.5,18.5A1.5,1.5 0 0,1 17,20Z\";\r\nvar mdiBabyCarriageOff = \"M22 10C22 5.6 18.4 2 14 2V10H22M14.2 11H22C22 12.8 21.4 14.5 20.3 15.9C21 16.5 21.4 17.4 21.5 18.3L14.2 11M20.8 22.7L22.1 21.4L2.4 1.7L1.1 3L9.1 11H7.4L6.5 9H3V11H5.2C5.2 11 7.1 15.1 7.3 15.4C6.3 15.9 5.6 16.9 5.5 18C5.2 19.9 6.6 21.7 8.5 22C10.4 22.3 12.2 20.9 12.5 19H14.6C14.7 19.4 14.8 19.8 15 20.2C15.9 21.9 18.1 22.5 19.7 21.6L20.8 22.7M10.5 18.5C10.5 19.3 9.8 20 9 20S7.5 19.3 7.5 18.5 8.2 17 9 17 10.5 17.7 10.5 18.5M18.1 20C17.2 20 16.5 19.3 16.5 18.5V18.4L18.1 20Z\";\r\nvar mdiBabyFace = \"M1,12C1,10.19 2.2,8.66 3.86,8.17C5.29,5.11 8.4,3 12,3C15.6,3 18.71,5.11 20.15,8.17C21.8,8.66 23,10.19 23,12C23,13.81 21.8,15.34 20.15,15.83C18.71,18.89 15.6,21 12,21C8.4,21 5.29,18.89 3.86,15.83C2.2,15.34 1,13.81 1,12M14.5,9.25A1.25,1.25 0 0,0 13.25,10.5A1.25,1.25 0 0,0 14.5,11.75A1.25,1.25 0 0,0 15.75,10.5A1.25,1.25 0 0,0 14.5,9.25M9.5,9.25A1.25,1.25 0 0,0 8.25,10.5A1.25,1.25 0 0,0 9.5,11.75A1.25,1.25 0 0,0 10.75,10.5A1.25,1.25 0 0,0 9.5,9.25M7.5,14C8.26,15.77 10,17 12,17C14,17 15.74,15.77 16.5,14H7.5M3,12C3,12.82 3.5,13.53 4.21,13.84C4.07,13.25 4,12.63 4,12C4,11.37 4.07,10.75 4.21,10.16C3.5,10.47 3,11.18 3,12M21,12C21,11.18 20.5,10.47 19.79,10.16C19.93,10.75 20,11.37 20,12C20,12.63 19.93,13.25 19.79,13.84C20.5,13.53 21,12.82 21,12Z\";\r\nvar mdiBabyFaceOutline = \"M14.5,9.25A1.25,1.25 0 0,1 15.75,10.5A1.25,1.25 0 0,1 14.5,11.75A1.25,1.25 0 0,1 13.25,10.5A1.25,1.25 0 0,1 14.5,9.25M9.5,9.25A1.25,1.25 0 0,1 10.75,10.5A1.25,1.25 0 0,1 9.5,11.75A1.25,1.25 0 0,1 8.25,10.5A1.25,1.25 0 0,1 9.5,9.25M7.5,14H16.5C15.74,15.77 14,17 12,17C10,17 8.26,15.77 7.5,14M1,12C1,10.19 2.2,8.66 3.86,8.17C5.29,5.11 8.4,3 12,3C15.6,3 18.71,5.11 20.15,8.17C21.8,8.66 23,10.19 23,12C23,13.81 21.8,15.34 20.15,15.83C18.71,18.89 15.6,21 12,21C8.4,21 5.29,18.89 3.86,15.83C2.2,15.34 1,13.81 1,12M12,5C8.82,5 6.14,7.12 5.28,10H5A2,2 0 0,0 3,12A2,2 0 0,0 5,14H5.28C6.14,16.88 8.82,19 12,19C15.18,19 17.86,16.88 18.72,14H19A2,2 0 0,0 21,12A2,2 0 0,0 19,10H18.72C17.86,7.12 15.18,5 12,5Z\";\r\nvar mdiBackburger = \"M5,13L9,17L7.6,18.42L1.18,12L7.6,5.58L9,7L5,11H21V13H5M21,6V8H11V6H21M21,16V18H11V16H21Z\";\r\nvar mdiBackspace = \"M22,3H7C6.31,3 5.77,3.35 5.41,3.88L0,12L5.41,20.11C5.77,20.64 6.31,21 7,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M19,15.59L17.59,17L14,13.41L10.41,17L9,15.59L12.59,12L9,8.41L10.41,7L14,10.59L17.59,7L19,8.41L15.41,12\";\r\nvar mdiBackspaceOutline = \"M19,15.59L17.59,17L14,13.41L10.41,17L9,15.59L12.59,12L9,8.41L10.41,7L14,10.59L17.59,7L19,8.41L15.41,12L19,15.59M22,3A2,2 0 0,1 24,5V19A2,2 0 0,1 22,21H7C6.31,21 5.77,20.64 5.41,20.11L0,12L5.41,3.88C5.77,3.35 6.31,3 7,3H22M22,5H7L2.28,12L7,19H22V5Z\";\r\nvar mdiBackspaceReverse = \"M2,21H17C17.7,21 18.2,20.6 18.6,20.1L24,12L18.6,3.9C18.2,3.4 17.7,3 17,3H2A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21M5,8.4L6.4,7L10,10.6L13.6,7L15,8.4L11.4,12L15,15.6L13.6,17L10,13.4L6.4,17L5,15.6L8.6,12\";\r\nvar mdiBackspaceReverseOutline = \"M5,15.59L6.41,17L10,13.41L13.59,17L15,15.59L11.41,12L15,8.41L13.59,7L10,10.59L6.41,7L5,8.41L8.59,12L5,15.59M2,3A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21H17C17.69,21 18.23,20.64 18.59,20.11L24,12L18.59,3.88C18.23,3.35 17.69,3 17,3H2M2,5H17L21.72,12L17,19H2V5Z\";\r\nvar mdiBackupRestore = \"M12,3A9,9 0 0,0 3,12H0L4,16L8,12H5A7,7 0 0,1 12,5A7,7 0 0,1 19,12A7,7 0 0,1 12,19C10.5,19 9.09,18.5 7.94,17.7L6.5,19.14C8.04,20.3 9.94,21 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3M14,12A2,2 0 0,0 12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12Z\";\r\nvar mdiBacteria = \"M21,16C21,15.5 20.95,15.08 20.88,14.68L22.45,13.9L21.55,12.1L20.18,12.79C19.63,11.96 18.91,11.5 18.29,11.28L18.95,9.32L17.05,8.68L16.29,10.96C14.96,10.83 14.17,10.32 13.7,9.77L15.45,8.9L14.55,7.1L13,7.89C12.97,7.59 12.86,6.72 12.28,5.87L13.83,3.55L12.17,2.44L10.76,4.56C10.28,4.33 9.7,4.15 9,4.06V2H7V4.1C6.29,4.25 5.73,4.54 5.32,4.91L2.7,2.29L1.29,3.71L4.24,6.65C4,7.39 4,8 4,8H2V10H4.04C4.1,10.63 4.21,11.36 4.4,12.15L1.68,13.05L2.31,14.95L5,14.05C5.24,14.56 5.5,15.08 5.82,15.58L3.44,17.17L4.55,18.83L7.07,17.15C7.63,17.71 8.29,18.21 9.06,18.64L8.1,20.55L9.89,21.45L10.89,19.45L10.73,19.36C11.68,19.68 12.76,19.9 14,19.97V22H16V19.93C16.76,19.84 17.81,19.64 18.77,19.19L20.29,20.71L21.7,19.29L20.37,17.95C20.75,17.44 21,16.8 21,16M8.5,11A1.5,1.5 0 0,1 7,9.5A1.5,1.5 0 0,1 8.5,8A1.5,1.5 0 0,1 10,9.5A1.5,1.5 0 0,1 8.5,11M11,14A1,1 0 0,1 10,13A1,1 0 0,1 11,12A1,1 0 0,1 12,13A1,1 0 0,1 11,14M15.5,17A1.5,1.5 0 0,1 14,15.5A1.5,1.5 0 0,1 15.5,14A1.5,1.5 0 0,1 17,15.5A1.5,1.5 0 0,1 15.5,17Z\";\r\nvar mdiBacteriaOutline = \"M9,2H7V4.1C6.29,4.25 5.73,4.54 5.32,4.91L2.7,2.29L1.29,3.71L4.24,6.65C4,7.39 4,8 4,8H2V10H4.04C4.1,10.63 4.21,11.36 4.4,12.15L1.68,13.05L2.31,14.95L5,14.05C5.24,14.56 5.5,15.08 5.82,15.58L3.44,17.17L4.55,18.83L7.07,17.15C7.63,17.71 8.29,18.21 9.06,18.64L8.1,20.55L9.89,21.45L10.89,19.45L10.73,19.36C11.68,19.68 12.76,19.9 14,19.97V22H16V19.93C16.76,19.84 17.81,19.64 18.77,19.19L20.29,20.71L21.7,19.29L20.37,17.95C20.75,17.44 21,16.8 21,16C21,15.5 20.95,15.08 20.88,14.68L22.45,13.9L21.55,12.1L20.18,12.79C19.63,11.96 18.91,11.5 18.29,11.28L18.95,9.32L17.05,8.68L16.29,10.96C14.96,10.83 14.17,10.32 13.7,9.77L15.45,8.9L14.55,7.1L13,7.89C12.97,7.59 12.86,6.72 12.28,5.87L13.83,3.55L12.17,2.44L10.76,4.56C10.28,4.33 9.7,4.15 9,4.06M15,18C12.06,18 9.81,17.18 8.31,15.56C5.68,12.72 6,8.2 6,8.17V8.11L6,8.03C6,7.1 6.39,6 8,6C10.63,6 10.97,7.43 11,8C11,10 12.6,13 17,13C17.33,13 19,13.15 19,16C19,17.89 15.03,18 15,18M8.5,8A1.5,1.5 0 0,0 7,9.5A1.5,1.5 0 0,0 8.5,11A1.5,1.5 0 0,0 10,9.5A1.5,1.5 0 0,0 8.5,8M11,12A1,1 0 0,0 10,13A1,1 0 0,0 11,14A1,1 0 0,0 12,13A1,1 0 0,0 11,12M15.5,14A1.5,1.5 0 0,0 14,15.5A1.5,1.5 0 0,0 15.5,17A1.5,1.5 0 0,0 17,15.5A1.5,1.5 0 0,0 15.5,14Z\";\r\nvar mdiBadgeAccount = \"M17,3H14V6H10V3H7A2,2 0 0,0 5,5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V5A2,2 0 0,0 17,3M12,8A2,2 0 0,1 14,10A2,2 0 0,1 12,12A2,2 0 0,1 10,10A2,2 0 0,1 12,8M16,16H8V15C8,13.67 10.67,13 12,13C13.33,13 16,13.67 16,15V16M13,5H11V1H13V5M16,19H8V18H16V19M12,21H8V20H12V21Z\";\r\nvar mdiBadgeAccountAlert = \"M15,3H12V6H8V3H5A2,2 0 0,0 3,5V21A2,2 0 0,0 5,23H15A2,2 0 0,0 17,21V5A2,2 0 0,0 15,3M10,8A2,2 0 0,1 12,10A2,2 0 0,1 10,12A2,2 0 0,1 8,10A2,2 0 0,1 10,8M14,16H6V15C6,13.67 8.67,13 10,13C11.33,13 14,13.67 14,15V16M11,5H9V1H11V5M14,19H6V18H14V19M10,21H6V20H10V21M19,13V7H21V13H19M19,17V15H21V17H19Z\";\r\nvar mdiBadgeAccountAlertOutline = \"M15,3H12V5H15V21H5V5H8V3H5A2,2 0 0,0 3,5V21A2,2 0 0,0 5,23H15A2,2 0 0,0 17,21V5A2,2 0 0,0 15,3M10,7A2,2 0 0,1 12,9A2,2 0 0,1 10,11A2,2 0 0,1 8,9A2,2 0 0,1 10,7M14,15H6V14C6,12.67 8.67,12 10,12C11.33,12 14,12.67 14,14V15M14,18H6V17H14V18M10,20H6V19H10V20M11,5H9V1H11V5M19,13V7H21V13H19M19,17V15H21V17H19Z\";\r\nvar mdiBadgeAccountHorizontal = \"M22,4H14V7H10V4H2A2,2 0 0,0 0,6V20A2,2 0 0,0 2,22H22A2,2 0 0,0 24,20V6A2,2 0 0,0 22,4M8,9A2,2 0 0,1 10,11A2,2 0 0,1 8,13A2,2 0 0,1 6,11A2,2 0 0,1 8,9M12,17H4V16C4,14.67 6.67,14 8,14C9.33,14 12,14.67 12,16V17M20,18H14V16H20V18M20,14H14V12H20V14M20,10H14V8H20V10M13,6H11V2H13V6Z\";\r\nvar mdiBadgeAccountHorizontalOutline = \"M8,9A2,2 0 0,1 10,11A2,2 0 0,1 8,13A2,2 0 0,1 6,11A2,2 0 0,1 8,9M12,17H4V16C4,14.67 6.67,14 8,14C9.33,14 12,14.67 12,16V17M20,8H14V10H20V8M20,12H14V14H20V12M20,16H14V18H20V16M22,4H14V6H22V20H2V6H10V4H2A2,2 0 0,0 0,6V20A2,2 0 0,0 2,22H22A2,2 0 0,0 24,20V6A2,2 0 0,0 22,4M13,6H11V2H13V6Z\";\r\nvar mdiBadgeAccountOutline = \"M17,3H14V5H17V21H7V5H10V3H7A2,2 0 0,0 5,5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V5A2,2 0 0,0 17,3M12,7A2,2 0 0,1 14,9A2,2 0 0,1 12,11A2,2 0 0,1 10,9A2,2 0 0,1 12,7M16,15H8V14C8,12.67 10.67,12 12,12C13.33,12 16,12.67 16,14V15M16,18H8V17H16V18M12,20H8V19H12V20M13,5H11V1H13V5Z\";\r\nvar mdiBadminton = \"M12.3,2C11.33,2.03 10.58,2.84 10.61,3.8C10.62,4.04 10.67,4.27 10.77,4.5L11.06,5.14V5.14C11.1,5.27 11.03,5.41 10.89,5.45C10.8,5.5 10.7,5.45 10.63,5.37L10.21,4.82C9.88,4.4 9.38,4.14 8.85,4.13C7.88,4.11 7.08,4.88 7.06,5.84C7.05,6.26 7.19,6.66 7.45,7L7.87,7.5H7.88C7.96,7.63 7.93,7.79 7.82,7.87C7.73,7.94 7.61,7.94 7.53,7.87L7,7.45C6.66,7.19 6.25,7.05 5.84,7.06C4.88,7.08 4.11,7.88 4.13,8.85C4.14,9.38 4.4,9.88 4.82,10.21L5.39,10.65C5.5,10.75 5.5,10.91 5.38,11C5.31,11.07 5.21,11.09 5.12,11.05H5.11L4.5,10.77C4.27,10.68 4.04,10.62 3.8,10.61C2.84,10.58 2.03,11.34 2,12.31C2,13.03 2.4,13.69 3.06,13.97L14.45,19.04L19.04,14.45L13.97,3.06C13.69,2.39 13,1.97 12.3,2M13.13,6.1C13.55,6.09 13.93,6.33 14.09,6.71L17.14,13.55L13.19,9.61L12.26,7.5C11.96,6.87 12.42,6.12 13.13,6.1M9.85,8.85C10.12,8.85 10.37,8.95 10.56,9.15L15.37,13.96C15.77,14.34 15.78,14.97 15.4,15.37C15,15.77 14.38,15.78 13.96,15.37L9.15,10.56C8.75,10.18 8.74,9.54 9.13,9.15C9.32,8.95 9.58,8.85 9.85,8.85M7.13,12.17C7.26,12.17 7.4,12.21 7.5,12.26L9.63,13.2L13.57,17.14L6.71,14.09C5.69,13.65 6.03,12.14 7.13,12.17M20.28,16.04L16.04,20.28L16.89,21.13C17.65,21.88 18.75,22.17 19.78,21.9C20.81,21.62 21.62,20.81 21.9,19.78C22.17,18.75 21.88,17.65 21.13,16.89L20.28,16.04Z\";\r\nvar mdiBagCarryOn = \"M14.6 21.4C15 21.8 15.4 22 16 22S17 21.8 17.4 21.4 18 20.6 18 20 17.8 19 17.4 18.6 16.5 18 16 18 15 18.2 14.6 18.6 14 19.4 14 20 14.2 21 14.6 21.4M6 19C6 19.5 6.2 20 6.6 20.4C7 20.8 7.5 21 8 21V7C7.5 7 7 7.2 6.6 7.6C6.2 8 6 8.5 6 9V19M16 2H12C12 2.5 12.2 3 12.6 3.4C13 3.8 13.5 4 14 4V7H9V21H13.2C13 20.5 13 20.2 13 20C13 19.2 13.3 18.5 13.9 17.9C14.5 17.3 15.2 17 16 17V2Z\";\r\nvar mdiBagCarryOnCheck = \"M15.28,16.69L18.14,13.88L18.84,14.58L15.28,18.14L13.17,16L13.88,15.28L15.28,16.69M8,21A2,2 0 0,1 6,19V9A2,2 0 0,1 8,7V21M9,7H14V4A2,2 0 0,1 12,2H16V10A6,6 0 0,1 22,16A6,6 0 0,1 16,22C14.77,22 13.63,21.63 12.68,21H9V7M16,12A4,4 0 0,0 12,16A4,4 0 0,0 16,20A4,4 0 0,0 20,16A4,4 0 0,0 16,12Z\";\r\nvar mdiBagCarryOnOff = \"M2.1 4.9L6 8.9V19C6 19.5 6.2 20 6.6 20.4C7 20.8 7.5 21 8 21V10.8L9 11.8V21H13.2C13.1 20.6 13 20.2 13 20C13 18.8 13.5 18 14.6 17.4L15.4 18.2C14.5 18.5 14.1 19.2 14.1 20.1C14.1 20.6 14.3 21.1 14.7 21.5C15 21.8 15.5 22 16 22C16.9 22 17.6 21.6 17.9 20.7L19.1 21.9L20.5 20.5L3.5 3.5L2.1 4.9M12 2C12 2.5 12.2 3 12.6 3.4S13.5 4 14 4V7H9.8L16 13.2V2H12Z\";\r\nvar mdiBagChecked = \"M22 19H2V21H22V19M4 15C4 15.5 4.2 16 4.6 16.4C5 16.8 5.5 17 6 17V6C5.5 6 5 6.2 4.6 6.6C4.2 7 4 7.5 4 8V15M13.5 6H10.5C10.5 5.6 10.6 5.2 10.9 4.9C11.2 4.6 11.5 4.5 12 4.5C12.4 4.5 12.8 4.6 13.1 4.9C13.3 5.2 13.5 5.6 13.5 6M7 6V17H17V6H15C15 5.2 14.7 4.5 14.1 3.9S12.8 3 12 3C11.2 3 10.5 3.3 9.9 3.9C9.3 4.5 9 5.2 9 6H7M18 17C18.5 17 19 16.8 19.4 16.4C19.8 16 20 15.5 20 15V8C20 7.5 19.8 7 19.4 6.6C19 6.2 18.5 6 18 6V17Z\";\r\nvar mdiBagPersonal = \"M16,5V4A2,2 0 0,0 14,2H10A2,2 0 0,0 8,4V5A4,4 0 0,0 4,9V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V9A4,4 0 0,0 16,5M10,4H14V5H10V4M12,9L14,11L12,13L10,11L12,9M18,16H9V18H8V16H6V15H18V16Z\";\r\nvar mdiBagPersonalOff = \"M20,19.35L2.38,1.73L1.11,3L4.77,6.66C4.27,7.34 4,8.16 4,9V20A2,2 0 0,0 6,22H18C18.56,22 19.08,21.76 19.46,21.35L20.84,22.73L22.11,21.46L20,19.35M9,16V18H8V16H6V15H13.11L14.11,16H9M20,9A4,4 0 0,0 16,5V4A2,2 0 0,0 14,2H10A2,2 0 0,0 8,4V4.8L20,16.8V9M14,5H10V4H14V5Z\";\r\nvar mdiBagPersonalOffOutline = \"M20,19.35L2.38,1.73L1.11,3L4.77,6.66C4.27,7.34 4,8.16 4,9V20A2,2 0 0,0 6,22H18C18.56,22 19.08,21.76 19.46,21.35L20.84,22.73L22.11,21.46L20,19.35M6,9C6,8.69 6.08,8.38 6.22,8.11L13.11,15H6V9M18,20H6V16H8V18H9V16H14.11L18,19.89V20M16,7A2,2 0 0,1 18,9V14.8L20,16.8V9A4,4 0 0,0 16,5V4A2,2 0 0,0 14,2H10A2,2 0 0,0 8,4V4.8L10.2,7H16M10,4H14V5H10V4Z\";\r\nvar mdiBagPersonalOutline = \"M16,5V4A2,2 0 0,0 14,2H10A2,2 0 0,0 8,4V5A4,4 0 0,0 4,9V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V9A4,4 0 0,0 16,5M10,4H14V5H10V4M12,9L14,11L12,13L10,11L12,9M18,20H6V16H8V18H9V16H18V20M18,15H6V9A2,2 0 0,1 8,7H16A2,2 0 0,1 18,9V15Z\";\r\nvar mdiBagSuitcase = \"M17.03 6C18.11 6 19 6.88 19 8V19C19 20.13 18.11 21 17.03 21C17.03 21.58 16.56 22 16 22C15.5 22 15 21.58 15 21H9C9 21.58 8.5 22 8 22C7.44 22 6.97 21.58 6.97 21C5.89 21 5 20.13 5 19V8C5 6.88 5.89 6 6.97 6H9V3C9 2.42 9.46 2 10 2H14C14.54 2 15 2.42 15 3V6H17.03M13.5 6V3.5H10.5V6H13.5M8 9V18H9.5V9H8M14.5 9V18H16V9H14.5M11.25 9V18H12.75V9H11.25Z\";\r\nvar mdiBagSuitcaseOff = \"M2 4.77L3.28 3.5L21 21.22L19.73 22.5L18 20.76C17.71 20.93 17.38 21 17.03 21C17.03 21.58 16.56 22 16 22C15.5 22 15 21.58 15 21H9C9 21.58 8.5 22 8 22C7.44 22 6.97 21.58 6.97 21C5.89 21 5 20.13 5 19V7.77L2 4.77M17.03 6C18.11 6 19 6.88 19 8V16.68L16 13.68V9H14.5V12.18L12.75 10.43V9H11.32L8.31 6H9V3C9 2.42 9.46 2 10 2H14C14.54 2 15 2.42 15 3V6H17.03M8 18H9.5V12.27L8 10.77V18M11.25 18H12.75V15.5L11.25 14V18M14.5 18H15.23L14.5 17.27V18M13.5 6V3.5H10.5V6H13.5Z\";\r\nvar mdiBagSuitcaseOffOutline = \"M2 4.77L3.28 3.5L21 21.22L19.73 22.5L18 20.76C17.71 20.93 17.38 21 17.03 21C17.03 21.58 16.56 22 16 22C15.5 22 15 21.58 15 21H9C9 21.58 8.5 22 8 22C7.44 22 6.97 21.58 6.97 21C5.89 21 5 20.13 5 19L5 7.78L2 4.77M9.5 18H8V10.78L6.97 9.74V19H16.23L15.25 18H14.5V17.26L12.75 15.5V18H11.25V14L9.5 12.28V18M12.75 9V10.43L11.32 9H12.75M14.5 9H16V13.67L14.5 12.17V9M17.03 6C18.11 6 19 6.88 19 8V16.68L17.03 14.7V8H10.33L8.31 6H9V3C9 2.42 9.46 2 10 2H14C14.54 2 15 2.42 15 3V6H17.03M10.5 3.5V6H13.5V3.5H10.5Z\";\r\nvar mdiBagSuitcaseOutline = \"M9.5 18V9H8V18M12.75 18V9H11.25V18M16 18V9H14.5V18M17.03 6C18.11 6 19 6.88 19 8V19C19 20.13 18.11 21 17.03 21C17.03 21.58 16.56 22 16 22C15.5 22 15 21.58 15 21H9C9 21.58 8.5 22 8 22C7.44 22 6.97 21.58 6.97 21C5.89 21 5 20.13 5 19V8C5 6.88 5.89 6 6.97 6H9V3C9 2.42 9.46 2 10 2H14C14.54 2 15 2.42 15 3V6M10.5 3.5V6H13.5V3.5M17.03 19V8H6.97V19\";\r\nvar mdiBaguette = \"M5 22C3.68 22 3.15 19.64 3.04 18.7A5.56 5.56 0 0 1 3.36 16A2.5 2.5 0 0 1 5.23 14.38C6.4 14.18 7.23 14.88 8.29 15.12A1.21 1.21 0 0 0 9.85 13.75C9.41 12.03 6.28 12 5 12C5 10.14 7.04 9.9 8.5 10.04A10.8 10.8 0 0 1 11.04 10.6C11.54 10.77 12.12 11.2 12.67 11.16C13.5 11.09 13.67 10.23 13.31 9.6C12.44 8.12 9.97 8 8.5 8C8.5 6 10.23 5.62 11.89 5.92A11.58 11.58 0 0 1 14.38 6.71C14.89 6.93 15.5 7.35 16.06 7.16C17.5 6.72 16 5.18 15.36 4.81A6.6 6.6 0 0 0 13.94 4.23C13.4 4.07 12.74 4.13 13.23 3.5A5.13 5.13 0 0 1 15.96 2.26C17.85 1.82 20.46 1.74 20.92 4.12A5.3 5.3 0 0 1 20.07 7.7A38.96 38.96 0 0 1 13.22 16.33A36.6 36.6 0 0 1 8.62 20.32C7.62 21.04 6.3 22 5 22Z\";\r\nvar mdiBalloon = \"M13.16,12.74L14,14H12.5C12.35,16.71 12,19.41 11.5,22.08L10.5,21.92C11,19.3 11.34,16.66 11.5,14H10L10.84,12.74C8.64,11.79 7,8.36 7,6A5,5 0 0,1 12,1A5,5 0 0,1 17,6C17,8.36 15.36,11.79 13.16,12.74Z\";\r\nvar mdiBallot = \"M13,9.5H18V7.5H13V9.5M13,16.5H18V14.5H13V16.5M19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21M6,11H11V6H6V11M7,7H10V10H7V7M6,18H11V13H6V18M7,14H10V17H7V14Z\";\r\nvar mdiBallotOutline = \"M13,7.5H18V9.5H13V7.5M13,14.5H18V16.5H13V14.5M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M19,19V5H5V19H19M11,6V11H6V6H11M10,10V7H7V10H10M11,13V18H6V13H11M10,17V14H7V17H10Z\";\r\nvar mdiBallotRecount = \"M19,12V13.5A4,4 0 0,1 23,17.5C23,18.32 22.75,19.08 22.33,19.71L21.24,18.62C21.41,18.28 21.5,17.9 21.5,17.5A2.5,2.5 0 0,0 19,15V16.5L16.75,14.25L19,12M19,23V21.5A4,4 0 0,1 15,17.5C15,16.68 15.25,15.92 15.67,15.29L16.76,16.38C16.59,16.72 16.5,17.1 16.5,17.5A2.5,2.5 0 0,0 19,20V18.5L21.25,20.75L19,23M10,17H7V14H10V17M10,7V10H7V7H10M5,21A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V11.17C20.5,11.06 20,11 19.5,11A6.5,6.5 0 0,0 13,17.5C13,18.79 13.38,20 14,21H5M13,9.5H18V7.5H13V9.5M11,13H6V18H11V13M11,6H6V11H11V6Z\";\r\nvar mdiBallotRecountOutline = \"M6,18V13H11V18H6M7,14V17H10V14H7M13,7.5H18V9.5H13V7.5M5,21A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V11.17C20.5,11.06 20,11 19.5,11H19V5H5V19H13.17C13.34,19.72 13.63,20.39 14,21H5M11,6V11H6V6H11M10,10V7H7V10H10M19,12V13.5A4,4 0 0,1 23,17.5C23,18.32 22.75,19.08 22.33,19.71L21.24,18.62C21.41,18.28 21.5,17.9 21.5,17.5A2.5,2.5 0 0,0 19,15V16.5L16.75,14.25L19,12M19,23V21.5A4,4 0 0,1 15,17.5C15,16.68 15.25,15.92 15.67,15.29L16.76,16.38C16.59,16.72 16.5,17.1 16.5,17.5A2.5,2.5 0 0,0 19,20V18.5L21.25,20.75L19,23Z\";\r\nvar mdiBandage = \"M17.73,12L21.71,8.04C22.1,7.65 22.1,7 21.71,6.63L17.37,2.29C17,1.9 16.35,1.9 15.96,2.29L12,6.27L8,2.29C7.8,2.1 7.55,2 7.29,2C7.04,2 6.78,2.1 6.59,2.29L2.25,6.63C1.86,7 1.86,7.65 2.25,8.04L6.23,12L2.25,16C1.86,16.39 1.86,17 2.25,17.41L6.59,21.75C7,22.14 7.61,22.14 8,21.75L12,17.77L15.96,21.75C16.16,21.95 16.41,22.04 16.67,22.04C16.93,22.04 17.18,21.94 17.38,21.75L21.72,17.41C22.11,17 22.11,16.39 21.72,16L17.73,12M12,9A1,1 0 0,1 13,10A1,1 0 0,1 12,11A1,1 0 0,1 11,10A1,1 0 0,1 12,9M7.29,10.96L3.66,7.34L7.29,3.71L10.91,7.33L7.29,10.96M10,13A1,1 0 0,1 9,12A1,1 0 0,1 10,11A1,1 0 0,1 11,12A1,1 0 0,1 10,13M12,15A1,1 0 0,1 11,14A1,1 0 0,1 12,13A1,1 0 0,1 13,14A1,1 0 0,1 12,15M14,11A1,1 0 0,1 15,12A1,1 0 0,1 14,13A1,1 0 0,1 13,12A1,1 0 0,1 14,11M16.66,20.34L13.03,16.72L16.66,13.09L20.28,16.71L16.66,20.34Z\";\r\nvar mdiBandcamp = \"M22,6L15.5,18H2L8.5,6H22Z\";\r\nvar mdiBank = \"M11.5,1L2,6V8H21V6M16,10V17H19V10M2,22H21V19H2M10,10V17H13V10M4,10V17H7V10H4Z\";\r\nvar mdiBankMinus = \"M14,17H22V19H14V17M11.5,1L21,6V8H2V6L11.5,1M16,10H19V12.08L18,12C17.3,12 16.63,12.12 16,12.34V10M2,22V19H12.08C12.27,20.14 12.79,21.17 13.53,22H2M10,10H13V14.68C12.54,15.37 12.22,16.15 12.08,17H10V10M4,10H7V17H4V10Z\";\r\nvar mdiBankOutline = \"M6.5,10H4.5V17H6.5V10M12.5,10H10.5V17H12.5V10M21,19H2V21H21V19M18.5,10H16.5V17H18.5V10M11.5,3.26L16.71,6H6.29L11.5,3.26M11.5,1L2,6V8H21V6L11.5,1Z\";\r\nvar mdiBankPlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M11.5,1L21,6V8H2V6L11.5,1M16,10H19V12.08L18,12C17.3,12 16.63,12.12 16,12.34V10M2,22V19H12.08C12.27,20.14 12.79,21.17 13.53,22H2M10,10H13V14.68C12.54,15.37 12.22,16.15 12.08,17H10V10M4,10H7V17H4V10Z\";\r\nvar mdiBankRemove = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M11.5,1L21,6V8H2V6L11.5,1M16,10H19V12.08L18,12C17.3,12 16.63,12.12 16,12.34V10M2,22V19H12.08C12.27,20.14 12.79,21.17 13.53,22H2M10,10H13V14.68C12.54,15.37 12.22,16.15 12.08,17H10V10M4,10H7V17H4V10Z\";\r\nvar mdiBankTransfer = \"M15,14V11H18V9L22,12.5L18,16V14H15M14,7.7V9H2V7.7L8,4L14,7.7M7,10H9V15H7V10M3,10H5V15H3V10M13,10V12.5L11,14.3V10H13M9.1,16L8.5,16.5L10.2,18H2V16H9.1M17,15V18H14V20L10,16.5L14,13V15H17Z\";\r\nvar mdiBankTransferIn = \"M2,15V12H5V10L9,13.5L5,17V15H2M22,8.7V10H10V8.7L16,5L22,8.7M10,17H22V19H10V17M15,11H17V16H15V11M11,11H13V16H11V11M19,11H21V16H19V11Z\";\r\nvar mdiBankTransferOut = \"M15,15V12H18V10L22,13.5L18,17V15H15M14,8.7V10H2V8.7L8,5L14,8.7M2,17H14V19H2V17M7,11H9V16H7V11M3,11H5V16H3V11M11,11H13V16H11V11Z\";\r\nvar mdiBarcode = \"M2,6H4V18H2V6M5,6H6V18H5V6M7,6H10V18H7V6M11,6H12V18H11V6M14,6H16V18H14V6M17,6H20V18H17V6M21,6H22V18H21V6Z\";\r\nvar mdiBarcodeOff = \"M20.84 22.73L16 17.89V18H14V15.89L12 13.89V18H11V12.89L10 11.89V18H7V8.89L6 7.89V18H5V6.89L1.11 3L2.39 1.73L7 6.34L10 9.34L11 10.34L12 11.34L14 13.35V13.34L16 15.34V15.35L17 16.35V16.34L18.66 18H18.65L22.11 21.46L20.84 22.73M16 6H14V10.8L16 12.8V6M12 6H11V7.8L12 8.8V6M20 6H17V13.8L20 16.8V6M22 18V6H21V17.8L21.2 18H22M10 6H9.2L10 6.8V6M2 18H4V6H2V18Z\";\r\nvar mdiBarcodeScan = \"M4,6H6V18H4V6M7,6H8V18H7V6M9,6H12V18H9V6M13,6H14V18H13V6M16,6H18V18H16V6M19,6H20V18H19V6M2,4V8H0V4A2,2 0 0,1 2,2H6V4H2M22,2A2,2 0 0,1 24,4V8H22V4H18V2H22M2,16V20H6V22H2A2,2 0 0,1 0,20V16H2M22,20V16H24V20A2,2 0 0,1 22,22H18V20H22Z\";\r\nvar mdiBarley = \"M7.33,18.33C6.5,17.17 6.5,15.83 6.5,14.5C8.17,15.5 9.83,16.5 10.67,17.67L11,18.23V15.95C9.5,15.05 8.08,14.13 7.33,13.08C6.5,11.92 6.5,10.58 6.5,9.25C8.17,10.25 9.83,11.25 10.67,12.42L11,13V10.7C9.5,9.8 8.08,8.88 7.33,7.83C6.5,6.67 6.5,5.33 6.5,4C8.17,5 9.83,6 10.67,7.17C10.77,7.31 10.86,7.46 10.94,7.62C10.77,7 10.66,6.42 10.65,5.82C10.64,4.31 11.3,2.76 11.96,1.21C12.65,2.69 13.34,4.18 13.35,5.69C13.36,6.32 13.25,6.96 13.07,7.59C13.15,7.45 13.23,7.31 13.33,7.17C14.17,6 15.83,5 17.5,4C17.5,5.33 17.5,6.67 16.67,7.83C15.92,8.88 14.5,9.8 13,10.7V13L13.33,12.42C14.17,11.25 15.83,10.25 17.5,9.25C17.5,10.58 17.5,11.92 16.67,13.08C15.92,14.13 14.5,15.05 13,15.95V18.23L13.33,17.67C14.17,16.5 15.83,15.5 17.5,14.5C17.5,15.83 17.5,17.17 16.67,18.33C15.92,19.38 14.5,20.3 13,21.2V23H11V21.2C9.5,20.3 8.08,19.38 7.33,18.33Z\";\r\nvar mdiBarleyOff = \"M11.96,1.21C11.3,2.76 10.64,4.31 10.65,5.82C10.66,6.42 10.77,7 10.94,7.62C10.86,7.46 10.77,7.31 10.67,7.17C9.83,6 8.17,5 6.5,4C6.5,4.8 6.5,5.59 6.68,6.36L13,12.68V10.7C14.5,9.8 15.92,8.88 16.67,7.83C17.5,6.67 17.5,5.33 17.5,4C15.83,5 14.17,6 13.33,7.17C13.23,7.31 13.15,7.45 13.07,7.59C13.25,6.96 13.36,6.32 13.35,5.69C13.34,4.18 12.65,2.69 11.96,1.21M3.28,5.5L2,6.77L6.64,11.41C6.75,12 6.95,12.55 7.33,13.08C8.08,14.13 9.5,15.05 11,15.95V18.23L10.67,17.67C9.83,16.5 8.17,15.5 6.5,14.5C6.5,15.83 6.5,17.17 7.33,18.33C8.08,19.38 9.5,20.3 11,21.2V23H13V21.2C13.74,20.76 14.45,20.31 15.07,19.84L18.73,23.5L20,22.22C14,16.23 9.1,11.32 3.28,5.5M17.5,9.25C15.83,10.25 14.17,11.25 13.33,12.42L13.12,12.79L15,14.66C15.67,14.16 16.27,13.64 16.67,13.08C17.5,11.92 17.5,10.58 17.5,9.25M17.5,14.5C16.93,14.84 16.38,15.18 15.85,15.53L17.29,16.97C17.5,16.17 17.5,15.33 17.5,14.5Z\";\r\nvar mdiBarn = \"M12,3L3,8.2V21H9L11.9,18L15,21H21V8.2L12,3M7.9,20V14L10.9,17L7.9,20M8.9,13H14.9L11.9,16L8.9,13M15.9,20L12.9,17L15.9,14V20M15,11H8.8V9H15V11Z\";\r\nvar mdiBarrel = \"M18,19H19V21H5V19H6V13H5V11H6V5H5V3H19V5H18V11H19V13H18V19M9,13A3,3 0 0,0 12,16A3,3 0 0,0 15,13C15,11 12,7.63 12,7.63C12,7.63 9,11 9,13Z\";\r\nvar mdiBaseball = \"M12,2C9.5,2 7.25,2.9 5.5,4.4C6,4.81 6.41,5.27 6.8,5.76L7.89,5.13L8.89,6.87L7.89,7.44C8.45,8.53 8.82,9.73 8.95,11H10V12L10,13H8.95C8.82,14.27 8.45,15.47 7.89,16.56L8.89,17.13L7.89,18.87L6.8,18.24C6.41,18.73 6,19.19 5.5,19.6C7.25,21.1 9.5,22 12,22C14.5,22 16.75,21.1 18.5,19.6C18,19.19 17.59,18.73 17.19,18.24L16.11,18.87L15.11,17.13L16.11,16.55C15.55,15.47 15.18,14.27 15.05,13H14V11H15.05C15.18,9.73 15.55,8.53 16.11,7.45L15.11,6.87L16.11,5.13L17.19,5.76C17.59,5.27 18,4.81 18.5,4.4C16.75,2.9 14.5,2 12,2M4.12,5.85C2.79,7.55 2,9.68 2,12C2,14.32 2.79,16.45 4.12,18.15C4.46,17.87 4.76,17.55 5.05,17.22L4.43,16.87L5.43,15.13L6.16,15.56C6.55,14.77 6.82,13.91 6.93,13H6V12L6,11H6.93C6.82,10.09 6.55,9.23 6.16,8.44L5.43,8.87L4.43,7.13L5.05,6.78C4.76,6.45 4.46,6.13 4.12,5.85M19.88,5.85C19.54,6.13 19.24,6.45 18.95,6.78L19.57,7.13L18.57,8.87L17.84,8.44C17.45,9.23 17.18,10.09 17.07,11H18V13H17.07C17.18,13.91 17.45,14.77 17.84,15.56L18.57,15.13L19.57,16.87L18.95,17.22C19.24,17.55 19.54,17.87 19.88,18.15C21.21,16.45 22,14.32 22,12C22,9.68 21.21,7.55 19.88,5.85Z\";\r\nvar mdiBaseballBat = \"M20,2C19.72,2 19.5,2.11 19.29,2.29L9.79,11.79C9.75,11.83 9.72,11.87 7.23,15.35L4,18.59L3.71,18.29C3.5,18.1 3.26,18 3,18C2.44,18 2,18.44 2,19C2,19.26 2.1,19.5 2.29,19.71L4.29,21.71C4.68,22.11 5.31,22.12 5.71,21.74C6.11,21.35 6.12,20.72 5.71,20.29L5.41,20L8.64,16.77L12.21,14.21L21.71,4.71C22.1,4.32 22.1,3.68 21.71,3.29L20.71,2.29C20.5,2.1 20.26,2 20,2M18.5,13A2.5,2.5 0 0,0 16,15.5A2.5,2.5 0 0,0 18.5,18A2.5,2.5 0 0,0 21,15.5A2.5,2.5 0 0,0 18.5,13Z\";\r\nvar mdiBaseballDiamond = \"M5.79 12.79L2 9C2 9 6 3 12 3S22 9 22 9L18.21 12.79L12 6.59L5.79 12.79M13.5 18H10.5V20L12 21L13.5 20V18M16.79 14.21L14.2 16.8C13.6 16.31 12.84 16 12 16S10.4 16.31 9.8 16.8L7.21 14.21L12 9.41L16.79 14.21M13 14C13 13.45 12.55 13 12 13S11 13.45 11 14 11.45 15 12 15 13 14.55 13 14Z\";\r\nvar mdiBaseballDiamondOutline = \"M12 2C5 2 1 9 1 9L9.3 17.3C9.74 16.77 10.32 16.37 11 16.17L7.83 13L12 8.83L16.17 13L13 16.17C13.68 16.37 14.27 16.77 14.7 17.3L23 9C23 9 19 2 12 2M17.59 11.59L12 6L6.41 11.59L3.59 8.76C4.95 7 7.89 4 12 4C16.08 4 19.03 7 20.4 8.77L17.59 11.59M13 13C13 13.55 12.55 14 12 14S11 13.55 11 13 11.45 12 12 12 13 12.45 13 13M13.5 20L12 21L10.5 20V18H13.5V20Z\";\r\nvar mdiBash = \"M5 9H7.31L7.63 6H9.63L9.31 9H11.31L11.63 6H13.63L13.31 9H15V11H13.1L12.9 13H15V15H12.69L12.37 18H10.37L10.69 15H8.69L8.37 18H6.37L6.69 15H5V13H6.9L7.1 11H5V9M9.1 11L8.9 13H10.9L11.1 11M19 6H17V14H19M19 16H17V18H19Z\";\r\nvar mdiBasket = \"M5.5,21C4.72,21 4.04,20.55 3.71,19.9V19.9L1.1,10.44L1,10A1,1 0 0,1 2,9H6.58L11.18,2.43C11.36,2.17 11.66,2 12,2C12.34,2 12.65,2.17 12.83,2.44L17.42,9H22A1,1 0 0,1 23,10L22.96,10.29L20.29,19.9C19.96,20.55 19.28,21 18.5,21H5.5M12,4.74L9,9H15L12,4.74M12,13A2,2 0 0,0 10,15A2,2 0 0,0 12,17A2,2 0 0,0 14,15A2,2 0 0,0 12,13Z\";\r\nvar mdiBasketFill = \"M3,2H6V5H3V2M6,7H9V10H6V7M8,2H11V5H8V2M17,11L12,6H15V2H19V6H22L17,11M7.5,22C6.72,22 6.04,21.55 5.71,20.9V20.9L3.1,13.44L3,13A1,1 0 0,1 4,12H20A1,1 0 0,1 21,13L20.96,13.29L18.29,20.9C17.96,21.55 17.28,22 16.5,22H7.5M7.61,20H16.39L18.57,14H5.42L7.61,20Z\";\r\nvar mdiBasketMinus = \"M23 18V20H15V18H23M23 10L22.96 10.29L22 13.8C21.11 13.29 20.09 13 19 13C15.69 13 13 15.69 13 19C13 19.7 13.13 20.37 13.35 21H5.5C4.72 21 4.04 20.55 3.71 19.9L1.1 10.44L1 10C1 9.45 1.45 9 2 9H6.58L11.18 2.43C11.36 2.17 11.66 2 12 2S12.65 2.17 12.83 2.44L17.42 9H22C22.55 9 23 9.45 23 10M14 15C14 13.9 13.11 13 12 13S10 13.9 10 15 10.9 17 12 17 14 16.11 14 15M15 9L12 4.74L9 9H15Z\";\r\nvar mdiBasketMinusOutline = \"M23 18V20H15V18H23M12 13C10.9 13 10 13.9 10 15S10.9 17 12 17 14 16.1 14 15 13.1 13 12 13M13.35 21H5.5C4.58 21 3.81 20.38 3.58 19.54L1.04 10.27C1 10.18 1 10.09 1 10C1 9.45 1.45 9 2 9H6.79L11.17 2.45C11.36 2.16 11.68 2 12 2S12.64 2.16 12.83 2.44L17.21 9H22C22.55 9 23 9.45 23 10L22.97 10.27L22 13.81C21.43 13.5 20.79 13.24 20.12 13.11L20.7 11H3.31L5.5 19H13C13 19.7 13.13 20.37 13.35 21M9.2 9H14.8L12 4.8L9.2 9Z\";\r\nvar mdiBasketOff = \"M23 10L22.96 10.29L20.9 17.7L12.2 9H15L12 4.74L10.32 7.12L8.89 5.69L11.18 2.43C11.36 2.17 11.66 2 12 2S12.65 2.17 12.83 2.44L17.42 9H22C22.55 9 23 9.45 23 10M22.11 21.46L20.84 22.73L19.03 20.92C18.86 20.97 18.68 21 18.5 21H5.5C4.72 21 4.04 20.55 3.71 19.9L1.1 10.44L1 10C1 9.45 1.45 9 2 9H6.58L6.8 8.69L1.11 3L2.39 1.73L22.11 21.46M13.85 15.74L11.26 13.15C10.5 13.44 10 14.16 10 15C10 16.11 10.9 17 12 17C12.84 17 13.56 16.5 13.85 15.74Z\";\r\nvar mdiBasketOffOutline = \"M2.39 1.73L1.11 3L6.92 8.81L6.79 9H2C1.45 9 1 9.45 1 10C1 10.09 1 10.18 1.04 10.27L3.58 19.54C3.81 20.38 4.58 21 5.5 21H18.5C18.68 21 18.86 20.96 19.03 20.92L20.84 22.73L22.11 21.46L2.39 1.73M5.5 19L3.31 11H9.11L11.26 13.15C10.5 13.44 10 14.16 10 15C10 16.1 10.9 17 12 17C12.84 17 13.56 16.5 13.85 15.74L17.11 19H5.5M23 10L22.97 10.27L20.93 17.73L19.3 16.1L20.7 11H14.2L12.2 9H14.8L12 4.8L10.4 7.2L8.96 5.76L11.17 2.45C11.36 2.16 11.68 2 12 2S12.64 2.16 12.83 2.44L17.21 9H22C22.55 9 23 9.45 23 10Z\";\r\nvar mdiBasketOutline = \"M22 9H17.21L12.83 2.44C12.64 2.16 12.32 2 12 2S11.36 2.16 11.17 2.45L6.79 9H2C1.45 9 1 9.45 1 10C1 10.09 1 10.18 1.04 10.27L3.58 19.54C3.81 20.38 4.58 21 5.5 21H18.5C19.42 21 20.19 20.38 20.43 19.54L22.97 10.27L23 10C23 9.45 22.55 9 22 9M12 4.8L14.8 9H9.2L12 4.8M18.5 19L5.5 19L3.31 11H20.7L18.5 19M12 13C10.9 13 10 13.9 10 15S10.9 17 12 17 14 16.1 14 15 13.1 13 12 13Z\";\r\nvar mdiBasketPlus = \"M20 15V18H23V20H20V23H18V20H15V18H18V15H20M23 10L22.96 10.29L22 13.8C21.11 13.29 20.09 13 19 13C15.69 13 13 15.69 13 19C13 19.7 13.13 20.37 13.35 21H5.5C4.72 21 4.04 20.55 3.71 19.9L1.1 10.44L1 10C1 9.45 1.45 9 2 9H6.58L11.18 2.43C11.36 2.17 11.66 2 12 2S12.65 2.17 12.83 2.44L17.42 9H22C22.55 9 23 9.45 23 10M14 15C14 13.9 13.11 13 12 13S10 13.9 10 15 10.9 17 12 17 14 16.11 14 15M15 9L12 4.74L9 9H15Z\";\r\nvar mdiBasketPlusOutline = \"M20 15V18H23V20H20V23H18V20H15V18H18V15H20M12 13C10.9 13 10 13.9 10 15S10.9 17 12 17 14 16.1 14 15 13.1 13 12 13M13.35 21H5.5C4.58 21 3.81 20.38 3.58 19.54L1.04 10.27C1 10.18 1 10.09 1 10C1 9.45 1.45 9 2 9H6.79L11.17 2.45C11.36 2.16 11.68 2 12 2S12.64 2.16 12.83 2.44L17.21 9H22C22.55 9 23 9.45 23 10L22.97 10.27L22 13.81C21.43 13.5 20.79 13.24 20.12 13.11L20.7 11H3.31L5.5 19H13C13 19.7 13.13 20.37 13.35 21M9.2 9H14.8L12 4.8L9.2 9Z\";\r\nvar mdiBasketRemove = \"M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.46L22.54 16.88M23 10L22.96 10.29L22 13.8C21.11 13.29 20.09 13 19 13C15.69 13 13 15.69 13 19C13 19.7 13.13 20.37 13.35 21H5.5C4.72 21 4.04 20.55 3.71 19.9L1.1 10.44L1 10C1 9.45 1.45 9 2 9H6.58L11.18 2.43C11.36 2.17 11.66 2 12 2S12.65 2.17 12.83 2.44L17.42 9H22C22.55 9 23 9.45 23 10M14 15C14 13.9 13.11 13 12 13S10 13.9 10 15 10.9 17 12 17 14 16.11 14 15M15 9L12 4.74L9 9H15Z\";\r\nvar mdiBasketRemoveOutline = \"M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.46L22.54 16.88M12 13C10.9 13 10 13.9 10 15S10.9 17 12 17 14 16.1 14 15 13.1 13 12 13M13.35 21H5.5C4.58 21 3.81 20.38 3.58 19.54L1.04 10.27C1 10.18 1 10.09 1 10C1 9.45 1.45 9 2 9H6.79L11.17 2.45C11.36 2.16 11.68 2 12 2S12.64 2.16 12.83 2.44L17.21 9H22C22.55 9 23 9.45 23 10L22.97 10.27L22 13.81C21.43 13.5 20.79 13.24 20.12 13.11L20.7 11H3.31L5.5 19H13C13 19.7 13.13 20.37 13.35 21M9.2 9H14.8L12 4.8L9.2 9Z\";\r\nvar mdiBasketUnfill = \"M3,10H6V7H3V10M5,5H8V2H5V5M8,10H11V7H8V10M17,1L12,6H15V10H19V6H22L17,1M7.5,22C6.72,22 6.04,21.55 5.71,20.9V20.9L3.1,13.44L3,13A1,1 0 0,1 4,12H20A1,1 0 0,1 21,13L20.96,13.29L18.29,20.9C17.96,21.55 17.28,22 16.5,22H7.5M7.61,20H16.39L18.57,14H5.42L7.61,20Z\";\r\nvar mdiBasketball = \"M2.34,14.63C2.94,14.41 3.56,14.3 4.22,14.3C5.56,14.3 6.73,14.72 7.73,15.56L4.59,18.7C3.53,17.5 2.78,16.13 2.34,14.63M15.56,9.8C17.53,11.27 19.66,11.63 21.94,10.88C21.97,11.09 22,11.47 22,12C22,13.03 21.75,14.18 21.28,15.45C20.81,16.71 20.23,17.73 19.55,18.5L13.22,12.19L15.56,9.8M8.77,16.64C9.83,18.17 10.05,19.84 9.42,21.66C8,21.25 6.73,20.61 5.67,19.73L8.77,16.64M12.19,13.22L18.5,19.55C16.33,21.45 13.78,22.25 10.88,21.94C11.09,21.28 11.2,20.56 11.2,19.78C11.2,19.16 11.06,18.43 10.78,17.6C10.5,16.77 10.17,16.09 9.8,15.56L12.19,13.22M8.81,14.5C7.88,13.67 6.8,13.15 5.58,12.91C4.36,12.68 3.19,12.75 2.06,13.13C2.03,12.91 2,12.53 2,12C2,10.97 2.25,9.82 2.72,8.55C3.19,7.29 3.77,6.27 4.45,5.5L11.11,12.19L8.81,14.5M15.56,7.73C14.22,6.08 13.91,4.28 14.63,2.34C15.25,2.5 15.96,2.8 16.76,3.26C17.55,3.71 18.2,4.16 18.7,4.59L15.56,7.73M21.66,9.38C21.06,9.59 20.44,9.7 19.78,9.7C18.69,9.7 17.64,9.38 16.64,8.72L19.73,5.67C20.61,6.77 21.25,8 21.66,9.38M12.19,11.11L5.5,4.45C7.67,2.55 10.22,1.75 13.13,2.06C12.91,2.72 12.8,3.44 12.8,4.22C12.8,4.94 12.96,5.75 13.29,6.66C13.62,7.56 14,8.28 14.5,8.81L12.19,11.11Z\";\r\nvar mdiBasketballHoop = \"M21,2H3A2,2 0 0,0 1,4V16A2,2 0 0,0 3,18H5V14H19V18H21A2,2 0 0,0 23,16V4A2,2 0 0,0 21,2M17,12H15V9H9V12H7V9A2,2 0 0,1 9,7H15A2,2 0 0,1 17,9V12M7,16V19.5L8,23L10,21L12,23L14,21L16,23L17,19.5V16H7Z\";\r\nvar mdiBasketballHoopOutline = \"M21,2H3A2,2 0 0,0 1,4V16A2,2 0 0,0 3,18H6.57L8,23L10,21L12,23L14,21L16,23L17.43,18H21A2,2 0 0,0 23,16V4A2,2 0 0,0 21,2M21,16H18V14H17V9A2,2 0 0,0 15,7H9A2,2 0 0,0 7,9V14H6V16H3V4H21V16M9,14V9H15V14H9Z\";\r\nvar mdiBat = \"M0.75,8C0.75,8 5,7 8,9C8,9 8.5,12.75 10.5,12.75V11C10.5,11 11,12 12,12C13,12 13.5,11 13.5,11V12.75C15.5,12.75 16,9 16,9C19,7 23.25,8 23.25,8C21.25,9 21,12.5 21,12.5C17,12.5 17,15.75 17,15.75C12,14.75 12,18.5 12,18.5C12,18.5 12,14.75 7,15.75C7,15.75 7,12.5 3,12.5C3,12.5 2.75,9 0.75,8Z\";\r\nvar mdiBattery = \"M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery10 = \"M16,18H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery10Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V18H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery20 = \"M16,17H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery20Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V17H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery30 = \"M16,15H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery30Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V15H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery40 = \"M16,14H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery40Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V14H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery50 = \"M16,13H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery50Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V13H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery60 = \"M16,12H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery60Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V12H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery70 = \"M16,10H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery70Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V10H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery80 = \"M16,9H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery80Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V9H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBattery90 = \"M16,8H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBattery90Bluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M4,6H12V8H4V6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBatteryAlert = \"M13 14H11V8H13M13 18H11V16H13M16.7 4H15V2H9V4H7.3C6.6 4 6 4.6 6 5.3V20.6C6 21.4 6.6 22 7.3 22H16.6C17.3 22 17.9 21.4 17.9 20.7V5.3C18 4.6 17.4 4 16.7 4Z\";\r\nvar mdiBatteryAlertBluetooth = \"M5 2V4H3.3C2.6 4 2 4.6 2 5.3V20.6C2 21.4 2.6 22 3.3 22H12.6C13.3 22 13.9 21.4 13.9 20.7V5.3C14 4.6 13.4 4 12.7 4H11V2H5M19 8V11.8L16.7 9.5L16 10.2L18.8 13L16 15.8L16.7 16.5L19 14.2V18H19.5L22.4 15.1L20.2 13L22.3 10.9L19.5 8H19M7 8H9V14H7M20 9.9L20.9 10.8L20 11.8V9.9M20 14.2L20.9 15.1L20 16.1V14.2M7 16H9V18H7V16Z\";\r\nvar mdiBatteryAlertVariant = \"M14.67 4H13V2H7V4H5.33C4.6 4 4 4.6 4 5.33V20.67C4 21.4 4.6 22 5.33 22H14.67C15.4 22 16 21.4 16 20.67V5.33C16 4.6 15.4 4 14.67 4M21 13H19V7H21V13M21 17H19V15H21V17Z\";\r\nvar mdiBatteryAlertVariantOutline = \"M14 20H6V6H14M14.67 4H13V2H7V4H5.33C4.6 4 4 4.6 4 5.33V20.67C4 21.4 4.6 22 5.33 22H14.67C15.4 22 16 21.4 16 20.67V5.33C16 4.6 15.4 4 14.67 4M21 7H19V13H21V8M21 15H19V17H21V15Z\";\r\nvar mdiBatteryBluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4H11V2H5M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21Z\";\r\nvar mdiBatteryBluetoothVariant = \"M9,2V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4H15V2H9M11.83,8H12.33L15.18,10.85L13.04,13L15.17,15.14L12.33,18H11.83V14.21L9.54,16.5L8.83,15.79L11.62,13L8.83,10.21L9.54,9.5L11.83,11.79V8M12.83,9.91V11.79L13.77,10.85L12.83,9.91M12.83,14.21V16.08L13.77,15.14L12.83,14.21Z\";\r\nvar mdiBatteryCharging = \"M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.66C6,21.4 6.6,22 7.33,22H16.66C17.4,22 18,21.4 18,20.67V5.33C18,4.6 17.4,4 16.67,4M11,20V14.5H9L13,7V12.5H15\";\r\nvar mdiBatteryCharging10 = \"M23.05,11H20.05V4L15.05,14H18.05V22M12,18H4L4.05,6H12.05M12.72,4H11.05V2H5.05V4H3.38A1.33,1.33 0 0,0 2.05,5.33V20.67C2.05,21.4 2.65,22 3.38,22H12.72C13.45,22 14.05,21.4 14.05,20.67V5.33A1.33,1.33 0 0,0 12.72,4Z\";\r\nvar mdiBatteryCharging100 = \"M23,11H20V4L15,14H18V22M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4Z\";\r\nvar mdiBatteryCharging20 = \"M23.05,11H20.05V4L15.05,14H18.05V22M12.05,17H4.05V6H12.05M12.72,4H11.05V2H5.05V4H3.38A1.33,1.33 0 0,0 2.05,5.33V20.67C2.05,21.4 2.65,22 3.38,22H12.72C13.45,22 14.05,21.4 14.05,20.67V5.33A1.33,1.33 0 0,0 12.72,4Z\";\r\nvar mdiBatteryCharging30 = \"M12,15H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4M23,11H20V4L15,14H18V22L23,11Z\";\r\nvar mdiBatteryCharging40 = \"M23,11H20V4L15,14H18V22M12,13H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4Z\";\r\nvar mdiBatteryCharging50 = \"M23,11H20V4L15,14H18V22M12,13H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4Z\";\r\nvar mdiBatteryCharging60 = \"M12,11H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4M23,11H20V4L15,14H18V22L23,11Z\";\r\nvar mdiBatteryCharging70 = \"M12,10H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4M23,11H20V4L15,14H18V22L23,11Z\";\r\nvar mdiBatteryCharging80 = \"M23,11H20V4L15,14H18V22M12,9H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4Z\";\r\nvar mdiBatteryCharging90 = \"M23,11H20V4L15,14H18V22M12,8H4V6H12M12.67,4H11V2H5V4H3.33A1.33,1.33 0 0,0 2,5.33V20.67C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.67V5.33A1.33,1.33 0 0,0 12.67,4Z\";\r\nvar mdiBatteryChargingHigh = \"M12 20H4V6H12M12.67 4H11V2H5V4H3.33C2.6 4 2 4.6 2 5.33V20.67C2 21.4 2.6 22 3.33 22H12.67C13.41 22 14 21.41 14 20.67V5.33C14 4.6 13.4 4 12.67 4M11 16H5V19H11V16M11 7H5V10H11V7M11 11.5H5V14.5H11V11.5M23 10H20V3L15 13H18V21\";\r\nvar mdiBatteryChargingLow = \"M12 20H4V6H12M12.67 4H11V2H5V4H3.33C2.6 4 2 4.6 2 5.33V20.67C2 21.4 2.6 22 3.33 22H12.67C13.41 22 14 21.41 14 20.67V5.33C14 4.6 13.4 4 12.67 4M11 16H5V19H11V16M23 10H20V3L15 13H18V21\";\r\nvar mdiBatteryChargingMedium = \"M12 20H4V6H12M12.67 4H11V2H5V4H3.33C2.6 4 2 4.6 2 5.33V20.67C2 21.4 2.6 22 3.33 22H12.67C13.41 22 14 21.41 14 20.67V5.33C14 4.6 13.4 4 12.67 4M11 16H5V19H11V16M11 11.5H5V14.5H11V11.5M23 10H20V3L15 13H18V21\";\r\nvar mdiBatteryChargingOutline = \"M23.05,11H20.05V4L15.05,14H18.05V22M12,20H4L4.05,6H12.05M12.72,4H11.05V2H5.05V4H3.38A1.33,1.33 0 0,0 2.05,5.33V20.67C2.05,21.4 2.65,22 3.38,22H12.72C13.45,22 14.05,21.4 14.05,20.67V5.33A1.33,1.33 0 0,0 12.72,4Z\";\r\nvar mdiBatteryChargingWireless = \"M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76Z\";\r\nvar mdiBatteryChargingWireless10 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,18.5H4V6H12V18.5Z\";\r\nvar mdiBatteryChargingWireless20 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,17H4V6H12V17Z\";\r\nvar mdiBatteryChargingWireless30 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,16H4V6H12V16Z\";\r\nvar mdiBatteryChargingWireless40 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,14.5H4V6H12V14.5Z\";\r\nvar mdiBatteryChargingWireless50 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,13H4V6H12V13Z\";\r\nvar mdiBatteryChargingWireless60 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,11.6H4V6H12V11.6Z\";\r\nvar mdiBatteryChargingWireless70 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,10H4V6H12V10Z\";\r\nvar mdiBatteryChargingWireless80 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,9H4V6H12V9Z\";\r\nvar mdiBatteryChargingWireless90 = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,7.5H4V6H12V7.5Z\";\r\nvar mdiBatteryChargingWirelessAlert = \"M13 4H11V2H5V4H3C2.4 4 2 4.4 2 5V21C2 21.6 2.4 22 3 22H13C13.6 22 14 21.6 14 21V5C14 4.4 13.6 4 13 4M9 18H7V16H9V18M9 14H7V8H9V14M20.1 4.9L18.7 6.3C21.8 9.4 21.8 14.5 18.7 17.6L20.1 19C24 15.2 24 8.8 20.1 4.9M17.2 7.8L15.8 9.2C17.4 10.8 17.4 13.3 15.8 14.9L17.2 16.3C19.6 13.9 19.6 10.1 17.2 7.8Z\";\r\nvar mdiBatteryChargingWirelessOutline = \"M20.07,4.93L18.66,6.34C21.79,9.46 21.79,14.53 18.66,17.66L20.07,19.07C23.97,15.17 23.97,8.84 20.07,4.93M17.24,7.76L15.83,9.17C17.39,10.73 17.39,13.26 15.83,14.83L17.24,16.24C19.58,13.9 19.58,10.1 17.24,7.76M13,4H11V2H5V4H3A1,1 0 0,0 2,5V21A1,1 0 0,0 3,22H13A1,1 0 0,0 14,21V5A1,1 0 0,0 13,4M12,20H4V6H12V20Z\";\r\nvar mdiBatteryHeart = \"M12.67 4H11V2H5V4H3.33A1.34 1.34 0 0 0 2 5.33V20.67A1.34 1.34 0 0 0 3.33 22H12.67A1.34 1.34 0 0 0 14 20.67V5.33A1.34 1.34 0 0 0 12.67 4M19 16.17L18.42 15.64C16.36 13.77 15 12.54 15 11A2.18 2.18 0 0 1 17.2 8.8A2.4 2.4 0 0 1 19 9.63A2.4 2.4 0 0 1 20.8 8.8A2.18 2.18 0 0 1 23 11C23 12.5 21.64 13.74 19.58 15.61Z\";\r\nvar mdiBatteryHeartOutline = \"M19 16.2L18.4 15.7C16.4 13.8 15 12.5 15 11C15 9.8 16 8.8 17.2 8.8C17.9 8.8 18.5 9.1 19 9.6C19.5 9.1 20.1 8.8 20.8 8.8C22 8.8 23 9.8 23 11C23 12.5 21.6 13.7 19.6 15.6L19 16.2M12.7 4H11V2H5V4H3.3C2.6 4 2 4.6 2 5.3V20.6C2 21.4 2.6 22 3.3 22H12.6C13.3 22 13.9 21.4 13.9 20.7V5.3C14 4.6 13.4 4 12.7 4M12 20H4V6H12V20Z\";\r\nvar mdiBatteryHeartVariant = \"M16.67 4H15V2H9V4H7.33A1.34 1.34 0 0 0 6 5.33V20.67A1.34 1.34 0 0 0 7.33 22H16.67A1.34 1.34 0 0 0 18 20.67V5.33A1.34 1.34 0 0 0 16.67 4M12.58 15.64L12 16.17L11.42 15.64C9.36 13.77 8 12.54 8 11A2.18 2.18 0 0 1 10.2 8.8A2.4 2.4 0 0 1 12 9.63A2.4 2.4 0 0 1 13.8 8.8A2.18 2.18 0 0 1 16 11C16 12.54 14.64 13.77 12.58 15.64Z\";\r\nvar mdiBatteryHigh = \"M16 20H8V6H16M16.67 4H15V2H9V4H7.33C6.6 4 6 4.6 6 5.33V20.67C6 21.4 6.6 22 7.33 22H16.67C17.41 22 18 21.41 18 20.67V5.33C18 4.6 17.4 4 16.67 4M15 16H9V19H15V16M15 7H9V10H15V7M15 11.5H9V14.5H15V11.5Z\";\r\nvar mdiBatteryLow = \"M16 20H8V6H16M16.67 4H15V2H9V4H7.33C6.6 4 6 4.6 6 5.33V20.67C6 21.4 6.6 22 7.33 22H16.67C17.41 22 18 21.41 18 20.67V5.33C18 4.6 17.4 4 16.67 4M15 16H9V19H15V16\";\r\nvar mdiBatteryMedium = \"M16 20H8V6H16M16.67 4H15V2H9V4H7.33C6.6 4 6 4.6 6 5.33V20.67C6 21.4 6.6 22 7.33 22H16.67C17.41 22 18 21.41 18 20.67V5.33C18 4.6 17.4 4 16.67 4M15 16H9V19H15V16M15 11.5H9V14.5H15V11.5Z\";\r\nvar mdiBatteryMinus = \"M16.67,4C17.4,4 18,4.6 18,5.33V20.67A1.33,1.33 0 0,1 16.67,22H7.33C6.6,22 6,21.4 6,20.67V5.33A1.33,1.33 0 0,1 7.33,4H9V2H15V4H16.67M8,12V14H16V12\";\r\nvar mdiBatteryNegative = \"M11.67,4A1.33,1.33 0 0,1 13,5.33V20.67C13,21.4 12.4,22 11.67,22H2.33C1.6,22 1,21.4 1,20.67V5.33A1.33,1.33 0 0,1 2.33,4H4V2H10V4H11.67M15,12H23V14H15V12M3,13H11V6H3V13Z\";\r\nvar mdiBatteryOff = \"M18 14.8L7.21 4H9V2H15V4H16.67A1.34 1.34 0 0 1 18 5.33M18 17.35L3.38 2.73L2.11 4L6 7.89V20.67A1.34 1.34 0 0 0 7.33 22H16.67A1.34 1.34 0 0 0 18 20.67V19.89L20.84 22.73L22.11 21.46Z\";\r\nvar mdiBatteryOffOutline = \"M18 17.35L3.38 2.73L2.11 4L6 7.89V20.67A1.34 1.34 0 0 0 7.33 22H16.67A1.34 1.34 0 0 0 18 20.67V19.89L20.84 22.73L22.11 21.46M16 20H8V9.89L16 17.89M16 6V12.8L18 14.8V5.33A1.34 1.34 0 0 0 16.67 4H15V2H9V4H7.21L9.21 6Z\";\r\nvar mdiBatteryOutline = \"M16,20H8V6H16M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.67C6,21.4 6.6,22 7.33,22H16.67A1.33,1.33 0 0,0 18,20.67V5.33C18,4.6 17.4,4 16.67,4Z\";\r\nvar mdiBatteryPlus = \"M16.67,4C17.4,4 18,4.6 18,5.33V20.67A1.33,1.33 0 0,1 16.67,22H7.33C6.6,22 6,21.4 6,20.67V5.33A1.33,1.33 0 0,1 7.33,4H9V2H15V4H16.67M16,14V12H13V9H11V12H8V14H11V17H13V14H16Z\";\r\nvar mdiBatteryPositive = \"M11.67,4A1.33,1.33 0 0,1 13,5.33V20.67C13,21.4 12.4,22 11.67,22H2.33C1.6,22 1,21.4 1,20.67V5.33A1.33,1.33 0 0,1 2.33,4H4V2H10V4H11.67M23,14H20V17H18V14H15V12H18V9H20V12H23V14M3,13H11V6H3V13Z\";\r\nvar mdiBatteryUnknown = \"M15.07,12.25L14.17,13.17C13.63,13.71 13.25,14.18 13.09,15H11.05C11.16,14.1 11.56,13.28 12.17,12.67L13.41,11.41C13.78,11.05 14,10.55 14,10C14,8.89 13.1,8 12,8A2,2 0 0,0 10,10H8A4,4 0 0,1 12,6A4,4 0 0,1 16,10C16,10.88 15.64,11.68 15.07,12.25M13,19H11V17H13M16.67,4H15V2H9V4H7.33A1.33,1.33 0 0,0 6,5.33V20.66C6,21.4 6.6,22 7.33,22H16.67C17.4,22 18,21.4 18,20.66V5.33C18,4.59 17.4,4 16.67,4Z\";\r\nvar mdiBatteryUnknownBluetooth = \"M5,2V4H3.33A1.33,1.33 0 0,0 2,5.33V20.66C2,21.4 2.6,22 3.33,22H12.67C13.4,22 14,21.4 14,20.66V5.33C14,4.59 13.4,4 12.67,4H11V2H5M8,6A4,4 0 0,1 12,10C12,10.88 11.64,11.68 11.07,12.25L10.17,13.17C9.63,13.71 9.25,14.18 9.09,15H7.05C7.16,14.1 7.56,13.28 8.17,12.67L9.41,11.41C9.78,11.05 10,10.55 10,10C10,8.89 9.1,8 8,8A2,2 0 0,0 6,10H4A4,4 0 0,1 8,6M19,8V11.79L16.71,9.5L16,10.21L18.79,13L16,15.79L16.71,16.5L19,14.21V18H19.5L22.35,15.14L20.21,13L22.35,10.85L19.5,8H19M20,9.91L20.94,10.85L20,11.79V9.91M20,14.21L20.94,15.14L20,16.08V14.21M7,17H9V19H7V17Z\";\r\nvar mdiBattlenet = \"M19.92,10.76C19.92,10.76 22.5,12.24 22.5,13.89C22.5,15.5 19.5,16.06 16.18,15.9C16.18,15.9 14.77,17.87 13.42,18.7C14.88,21.44 16,22.5 15.97,22.5C15.97,22.5 15.23,22.69 13,19.04C11.66,19.89 10.17,20.23 9.56,19.7C8.94,19.17 9.42,18.28 9.68,17.85C9.41,18 8,18.83 6.75,18.83C5.26,18.83 5.05,17.72 5.05,17.15C5.05,15 7.12,12 7.12,12C7.12,12 6.16,9.88 6.05,8.22C4.17,8.06 2,8.39 1.53,8.54C1.4,8.54 1.84,8.22 2,8.18C2.15,8.13 3.91,7.67 6,7.67C6,5.93 6.35,4.33 7.41,4.33C8.13,4.33 8.71,5.45 8.71,5.45C8.71,5.45 8.7,1.5 10.74,1.5C12.8,1.5 15,6.11 15,6.11C15,6.11 17.22,6.32 18.85,7.09C19.5,5.73 20.09,5.11 20.81,3C21,3.7 20.2,5.5 19.35,7.3V7.3H19.35C19.35,7.3 21.65,8.5 21.65,9.83C21.65,10.84 19.92,10.76 19.92,10.76M10.68,18.58C11.36,18.69 12.41,18.1 12.4,18.1L11.58,16.57L10.4,17.4C10.39,17.41 9.64,18.38 10.68,18.58M20.15,9.76C20.15,9.1 18.95,8.35 18.81,8.27L17.89,9.75L19.17,10.37C19.59,10.34 20.15,10.35 20.15,9.76M8,5.63C7.7,5.63 7.09,6.07 7.09,7.64L8.83,7.7L8.72,6.3C8.6,6 8.3,5.63 8,5.63M10.18,15.78C8.92,15.13 8.16,14.06 7.54,12.9C7.54,12.9 5.96,15.55 6.97,16.22C8,16.89 9.64,16.16 10.18,15.78M12.97,17.76C14.11,16.89 17.19,14.73 17.45,11.08C14.57,9.44 10.62,8.71 10.62,8.71C10.62,8.71 10.61,8.21 10.7,7.86C11.64,7.97 14.59,8.47 17.03,9.43C16.35,8.28 15.84,7.85 15.37,7.5C16.53,7.76 17.36,9.26 17.36,9.26L18.28,7.96C18.28,7.96 13.91,5.61 10.19,7.42C10.11,10.3 11.59,14.56 11.59,14.56L10.82,14.89C10.3,13.84 9.63,12.09 9,8.67C8.7,9.08 8.17,9.55 8.16,11.09C7.7,9.8 8.66,8.43 8.67,8.42L7.07,8.26C7.17,9.92 8.05,14.2 10.68,15.53C13,14.21 15.5,11.54 16.13,10.77L16.82,11.28L12.35,15.97C13.59,16 14.32,15.72 14.82,15.5C14.1,16.25 12.86,16.32 12.27,16.32C12.28,16.34 12.57,17.07 12.97,17.76M14.03,6.05C14,5.97 12.66,3.69 11.47,3.86C10.69,4.11 10.24,5.43 10.23,6.87C10.76,6.56 12,6 14.03,6.05M16.71,15.07C16.71,15.07 20,15 19.9,13.76C19.9,12.56 17.92,11.33 17.92,11.35C17.93,13.47 16.71,15.07 16.71,15.07Z\";\r\nvar mdiBeach = \"M15,18.54C17.13,18.21 19.5,18 22,18V22H5C5,21.35 8.2,19.86 13,18.9V12.4C12.16,12.65 11.45,13.21 11,13.95C10.39,12.93 9.27,12.25 8,12.25C6.73,12.25 5.61,12.93 5,13.95C5.03,10.37 8.5,7.43 13,7.04V7A1,1 0 0,1 14,6A1,1 0 0,1 15,7V7.04C19.5,7.43 22.96,10.37 23,13.95C22.39,12.93 21.27,12.25 20,12.25C18.73,12.25 17.61,12.93 17,13.95C16.55,13.21 15.84,12.65 15,12.39V18.54M7,2A5,5 0 0,1 2,7V2H7Z\";\r\nvar mdiBeaker = \"M3,3V5A2,2 0 0,1 5,7V19A2,2 0 0,0 7,21H17A2,2 0 0,0 19,19V7A2,2 0 0,1 21,5V3H3M7,9H10V10H7V9M7,11H10V12H7V11M10,16H7V15H10V16M12,14H7V13H12V14M12,8H7V7H12V8Z\";\r\nvar mdiBeakerAlert = \"M3 3H21V5C19.9 5 19 5.9 19 7V19C19 20.1 18.1 21 17 21H7C5.9 21 5 20.1 5 19V7C5 5.9 4.1 5 3 5V3M7 9V10H10V9H7M7 11V12H10V11H7M10 16V15H7V16H10M12 14V13H7V14H12M12 8V7H7V8H12M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiBeakerAlertOutline = \"M3 3H21V5C19.9 5 19 5.9 19 7V19C19 20.11 18.11 21 17 21H7C5.9 21 5 20.11 5 19V7C5 5.9 4.11 5 3 5V3M7 5V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H17V5H7M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiBeakerCheck = \"M17.75 21.16L15 18.16L16.16 17L17.75 18.59L21.34 15L22.5 16.41L17.75 21.16M3 3H21V5C19.9 5 19 5.9 19 7V12C15.69 12 13 14.69 13 18C13 19.09 13.29 20.12 13.8 21H7C5.9 21 5 20.1 5 19V7C5 5.9 4.1 5 3 5V3M7 9V10H10V9H7M7 11V12H10V11H7M10 16V15H7V16H10M12 14V13H7V14H12M12 8V7H7V8H12Z\";\r\nvar mdiBeakerCheckOutline = \"M17.75 21.16L15 18.16L16.16 17L17.75 18.59L21.34 15L22.5 16.41L17.75 21.16M3 3H21V5C19.9 5 19 5.9 19 7V12C18.3 12 17.63 12.12 17 12.34V5H7V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H13.08C13.2 19.72 13.45 20.39 13.8 21H7C5.9 21 5 20.11 5 19V7C5 5.9 4.11 5 3 5V3Z\";\r\nvar mdiBeakerMinus = \"M23 17V19H15V17H23M3 3H21V5C19.9 5 19 5.9 19 7V12C15.69 12 13 14.69 13 18C13 19.09 13.29 20.12 13.8 21H7C5.9 21 5 20.1 5 19V7C5 5.9 4.1 5 3 5V3M7 9V10H10V9H7M7 11V12H10V11H7M10 16V15H7V16H10M12 14V13H7V14H12M12 8V7H7V8H12Z\";\r\nvar mdiBeakerMinusOutline = \"M23 17V19H15V17M3 3H21V5C19.9 5 19 5.9 19 7V12C18.3 12 17.63 12.12 17 12.34V5H7V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H13.08C13.2 19.72 13.45 20.39 13.8 21H7C5.9 21 5 20.11 5 19V7C5 5.9 4.11 5 3 5V3Z\";\r\nvar mdiBeakerOutline = \"M3,3H21V5A2,2 0 0,0 19,7V19A2,2 0 0,1 17,21H7A2,2 0 0,1 5,19V7A2,2 0 0,0 3,5V3M7,5V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H17V5H7Z\";\r\nvar mdiBeakerPlus = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M3 3H21V5C19.9 5 19 5.9 19 7V12C15.69 12 13 14.69 13 18C13 19.09 13.29 20.12 13.8 21H7C5.9 21 5 20.1 5 19V7C5 5.9 4.1 5 3 5V3M7 9V10H10V9H7M7 11V12H10V11H7M10 16V15H7V16H10M12 14V13H7V14H12M12 8V7H7V8H12Z\";\r\nvar mdiBeakerPlusOutline = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M3 3H21V5C19.9 5 19 5.9 19 7V12C18.3 12 17.63 12.12 17 12.34V5H7V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H13.08C13.2 19.72 13.45 20.39 13.8 21H7C5.9 21 5 20.11 5 19V7C5 5.9 4.11 5 3 5V3Z\";\r\nvar mdiBeakerQuestion = \"M0 3H18V5C16.9 5 16 5.9 16 7V19C16 20.1 15.1 21 14 21H4C2.9 21 2 20.1 2 19V7C2 5.9 1.1 5 0 5V3M4 9V10H7V9H4M4 11V12H7V11H4M7 16V15H4V16H7M9 14V13H4V14H9M9 8V7H4V8H9M21.5 15.5V17H20V15.5H21.5M19.5 10.5H18V10C18 8.34 19.34 7 21 7C22.66 7 24 8.34 24 10C24 10.97 23.5 11.88 22.71 12.41L22.41 12.6C21.84 13 21.5 13.62 21.5 14.3V14.5H20V14.3C20 13.11 20.6 12 21.59 11.35L21.88 11.16C22.27 10.9 22.5 10.47 22.5 10C22.5 9.18 21.83 8.5 21 8.5C20.17 8.5 19.5 9.17 19.5 10V10.5Z\";\r\nvar mdiBeakerQuestionOutline = \"M0 3H18V5C16.9 5 16 5.9 16 7V19C16 20.11 15.11 21 14 21H4C2.9 21 2 20.11 2 19V7C2 5.9 1.11 5 0 5V3M4 5V7H9V8H4V9H7V10H4V11H7V12H4V13H9V14H4V15H7V16H4V19H14V5H4M21.5 15.5V17H20V15.5H21.5M19.5 10.5H18V10C18 8.34 19.34 7 21 7C22.66 7 24 8.34 24 10C24 10.97 23.5 11.88 22.71 12.41L22.41 12.6C21.84 13 21.5 13.62 21.5 14.3V14.5H20V14.3C20 13.11 20.6 12 21.59 11.35L21.88 11.16C22.27 10.9 22.5 10.47 22.5 10C22.5 9.18 21.83 8.5 21 8.5C20.17 8.5 19.5 9.17 19.5 10V10.5Z\";\r\nvar mdiBeakerRemove = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M3 3H21V5C19.9 5 19 5.9 19 7V12C15.69 12 13 14.69 13 18C13 19.09 13.29 20.12 13.8 21H7C5.9 21 5 20.1 5 19V7C5 5.9 4.1 5 3 5V3M7 9V10H10V9H7M7 11V12H10V11H7M10 16V15H7V16H10M12 14V13H7V14H12M12 8V7H7V8H12Z\";\r\nvar mdiBeakerRemoveOutline = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M3 3H21V5C19.9 5 19 5.9 19 7V12C18.3 12 17.63 12.12 17 12.34V5H7V7H12V8H7V9H10V10H7V11H10V12H7V13H12V14H7V15H10V16H7V19H13.08C13.2 19.72 13.45 20.39 13.8 21H7C5.9 21 5 20.11 5 19V7C5 5.9 4.11 5 3 5V3Z\";\r\nvar mdiBed = \"M19,7H11V14H3V5H1V20H3V17H21V20H23V11A4,4 0 0,0 19,7M7,13A3,3 0 0,0 10,10A3,3 0 0,0 7,7A3,3 0 0,0 4,10A3,3 0 0,0 7,13Z\";\r\nvar mdiBedDouble = \"M18 10V7A2 2 0 0 0 16 5H8A2 2 0 0 0 6 7V10A2 2 0 0 0 4 12V17H5.33L6 19H7L7.67 17H16.33L17 19H18L18.67 17H20V12A2 2 0 0 0 18 10M11 10H8V7H11M16 10H13V7H16Z\";\r\nvar mdiBedDoubleOutline = \"M8 5C7.5 5 7 5.21 6.61 5.6S6 6.45 6 7V10C5.47 10 5 10.19 4.59 10.59S4 11.47 4 12V17H5.34L6 19H7L7.69 17H16.36L17 19H18L18.66 17H20V12C20 11.47 19.81 11 19.41 10.59S18.53 10 18 10V7C18 6.45 17.8 6 17.39 5.6S16.5 5 16 5M8 7H11V10H8M13 7H16V10H13M6 12H18V15H6Z\";\r\nvar mdiBedEmpty = \"M19,7H5V14H3V5H1V20H3V17H21V20H23V11A4,4 0 0,0 19,7\";\r\nvar mdiBedKing = \"M6 5C5.47 5 5 5.21 4.59 5.6S4 6.45 4 7V10C3.45 10 3 10.19 2.6 10.59S2 11.47 2 12V17H3.33L4 19H5L5.67 17H18.33L19 19H20L20.67 17H22V12C22 11.47 21.79 11 21.4 10.59C21 10.19 20.55 10 20 10V7C20 6.45 19.81 6 19.41 5.6S18.53 5 18 5M6 7H11V10H6M13 7H18V10H13Z\";\r\nvar mdiBedKingOutline = \"M20 10V7A2 2 0 0 0 18 5H6A2 2 0 0 0 4 7V10A2 2 0 0 0 2 12V17H3.33L4 19H5L5.67 17H18.33L19 19H20L20.67 17H22V12A2 2 0 0 0 20 10M13 7H18V10H13M6 7H11V10H6M20 15H4V12H20Z\";\r\nvar mdiBedOutline = \"M7 14C8.66 14 10 12.66 10 11C10 9.34 8.66 8 7 8C5.34 8 4 9.34 4 11C4 12.66 5.34 14 7 14M7 10C7.55 10 8 10.45 8 11C8 11.55 7.55 12 7 12C6.45 12 6 11.55 6 11C6 10.45 6.45 10 7 10M19 7H11V15H3V5H1V20H3V17H21V20H23V11C23 8.79 21.21 7 19 7M21 15H13V9H19C20.1 9 21 9.9 21 11Z\";\r\nvar mdiBedQueen = \"M19 10V7A2 2 0 0 0 17 5H7A2 2 0 0 0 5 7V10A2 2 0 0 0 3 12V17H4.33L5 19H6L6.67 17H17.33L18 19H19L19.67 17H21V12A2 2 0 0 0 19 10M17 10H7V7H17Z\";\r\nvar mdiBedQueenOutline = \"M19 10V7A2 2 0 0 0 17 5H7A2 2 0 0 0 5 7V10A2 2 0 0 0 3 12V17H4.33L5 19H6L6.67 17H17.33L18 19H19L19.67 17H21V12A2 2 0 0 0 19 10M7 7H17V10H7M19 15H5V12H19Z\";\r\nvar mdiBedSingle = \"M17 10V7C17 5.9 16.11 5 15 5H9C7.9 5 7 5.9 7 7V10C5.9 10 4.89 10.9 5 12V17H6.33L7 19H8L8.67 17H15.33L16 19H17L17.67 17H19V12C19 10.9 18.11 10 17 10M15 10H9V7H15Z\";\r\nvar mdiBedSingleOutline = \"M17 10V7C17 5.9 16.11 5 15 5H9C7.9 5 7 5.9 7 7V10C5.9 10 5 10.9 5 12V17H6.33L7 19H8L8.67 17H15.33L16 19H17L17.67 17H19V12C19 10.9 18.11 10 17 10M9 7H15V10H9M17 15H7V12H17Z\";\r\nvar mdiBee = \"M17.4 9C17 7.8 16.2 7 15 6.5V5H14V6.4H13.6C12.5 6.4 11.6 6.8 10.8 7.6L10.4 8L9 7.5C8.7 7.4 8.4 7.3 8 7.3C7.4 7.3 6.8 7.5 6.3 7.9C5.7 8.3 5.4 8.8 5.2 9.3C5 10 5 10.6 5.2 11.3C5.5 12 5.8 12.5 6.3 12.8C5.9 14.3 6.2 15.6 7.3 16.7C8.1 17.5 9 17.9 10.1 17.9C10.6 17.9 10.9 17.9 11.2 17.8C11.8 18.6 12.6 19.1 13.6 19.1C13.9 19.1 14.3 19.1 14.6 19C15.2 18.8 15.6 18.4 16 17.9C16.4 17.3 16.6 16.8 16.6 16.2C16.6 15.8 16.6 15.5 16.5 15.2L16 13.6L16.6 13.2C17.4 12.4 17.8 11.3 17.7 10.1H19V9H17.4M7.7 11.3C7.1 11 6.9 10.6 7.1 10C7.3 9.4 7.7 9.2 8.3 9.4L11.5 10.6C9.9 11.4 8.7 11.6 7.7 11.3M14 16.9C13.4 17.1 13 16.9 12.7 16.3C12.4 15.3 12.6 14.1 13.4 12.5L14.6 15.6C14.8 16.3 14.6 16.7 14 16.9M15.2 11.6L14.6 10V9.9L14.3 9.6H14.2L12.6 9C13 8.7 13.4 8.5 13.9 8.5C14.4 8.5 14.9 8.7 15.3 9.1C15.7 9.5 15.9 9.9 15.9 10.4C15.7 10.7 15.5 11.2 15.2 11.6Z\";\r\nvar mdiBeeFlower = \"M11.6 13V12.9L11.3 12.6H11.2L9.6 12C10 11.7 10.4 11.5 10.9 11.5C11.4 11.5 11.9 11.7 12.3 12.1C12.7 12.5 12.9 12.9 12.9 13.4C12.9 13.9 12.8 14.3 12.4 14.7L11.6 13M9.7 19.3C9.4 18.3 9.6 17.1 10.4 15.5L11.6 18.6C11.8 19.2 11.6 19.6 11 19.9C10.4 20.2 10 20 9.7 19.3M4.1 13.1C4.3 12.5 4.7 12.3 5.3 12.5L8.5 13.7C6.9 14.5 5.7 14.7 4.7 14.4C4.1 14.1 3.9 13.7 4.1 13.1M12 8.1H11V9.5H10.6C9.5 9.5 8.6 9.9 7.8 10.7L7.4 11.3L6 10.5C5.7 10.4 5.4 10.4 5 10.4C4.4 10.4 3.8 10.6 3.3 11S2.4 11.8 2.2 12.4C2 13.1 2 13.7 2.2 14.4C2.5 15.1 2.8 15.6 3.3 15.9C2.9 17.4 3.2 18.7 4.3 19.8C5.1 20.6 6 21 7.1 21C7.6 21 7.9 21 8.2 20.9C8.8 21.7 9.6 22.2 10.6 22.2C10.9 22.2 11.3 22.2 11.6 22.1C12.2 21.9 12.6 21.5 13 21C13.4 20.4 13.6 19.9 13.6 19.3C13.6 18.9 13.6 18.6 13.5 18.3L12.9 16.9L13.5 16.5C14.3 15.7 14.7 14.6 14.6 13.4H16V12.4H14.4C14 11.2 13.2 10.4 12 10V8.1M17.3 6.8C17.1 6.6 17 6.3 17 6.1C17 5.8 17.1 5.6 17.3 5.4C17.5 5.2 17.7 5.1 18 5.1S18.5 5.2 18.7 5.4C18.9 5.5 19 5.8 19 6.1C19 6.4 18.9 6.6 18.7 6.8C18.5 7 18.3 7 18 7S17.5 7 17.3 6.8M20.7 4.1H19.6L19.3 3.2C19.1 2.5 18.7 2.2 18 2.2C17.3 2.2 16.8 2.5 16.7 3.2L16.4 4.1H15.3C14.7 4.1 14.3 4.4 14 5C13.8 5.6 14 6.1 14.6 6.5L15.5 7L15.1 8.2C14.9 8.6 15 9 15.2 9.4C15.5 9.8 15.8 10 16.3 10C16.7 10 17 9.9 17.2 9.7L18 9.1L18.8 9.8C19 9.9 19.3 10 19.7 10C20.2 10 20.5 9.8 20.8 9.4C21 9 21.1 8.6 20.9 8.2L20.5 7L21.3 6.5C21.9 6.1 22.1 5.6 21.9 5C21.7 4.3 21.3 4.1 20.7 4.1Z\";\r\nvar mdiBeehiveOffOutline = \"M1.1 3L4.7 6.5C3.7 7.2 3 8.2 3 9.5C3 10.1 3.2 10.7 3.5 11.2C2 11.6 1 12.9 1 14.5C1 15.8 1.7 16.8 2.7 17.5C2.2 18 2 18.7 2 19.5C2 21.4 3.6 23 5.5 23H18.5C19.3 23 20 22.7 20.6 22.3L21.3 23L22.6 21.7L2.4 1.7L1.1 3M9.2 11H6.5C5.7 11 5 10.3 5 9.5C5 8.8 5.5 8.2 6.2 8L9.2 11M9 21H5.5C4.7 21 4 20.3 4 19.5S4.7 18 5.5 18H9V21M9.2 16H4.5C3.7 16 3 15.3 3 14.5S3.7 13 4.5 13H11.2L12.2 14H12C10.7 14 9.6 14.8 9.2 16M18.5 21H15V18H16.2L19.1 20.9C18.9 21 18.7 21 18.5 21M7.1 3.9L5.7 2.5C6.3 1.6 7.3 1 8.5 1H15.5C17.4 1 19 2.6 19 4.5C19 5.1 18.8 5.7 18.5 6.2C20 6.6 21 7.9 21 9.5C21 10.1 20.8 10.7 20.5 11.2C21.9 11.7 23 13 23 14.5C23 15.8 22.3 16.8 21.3 17.5C21.6 17.9 21.8 18.3 21.9 18.7L19.2 16H19.5C20.3 16 21 15.3 21 14.5S20.3 13 19.5 13H16.2L14.2 11H17.5C18.3 11 19 10.3 19 9.5S18.3 8 17.5 8H11.2L9.2 6H15.5C16.3 6 17 5.3 17 4.5S16.3 3 15.5 3H8.5C7.9 3 7.3 3.4 7.1 3.9Z\";\r\nvar mdiBeehiveOutline = \"M23 14.5C23 12.94 21.97 11.63 20.55 11.18C20.83 10.68 21 10.11 21 9.5C21 7.94 19.97 6.63 18.55 6.18C18.83 5.68 19 5.11 19 4.5C19 2.57 17.43 1 15.5 1H8.5C6.57 1 5 2.57 5 4.5C5 5.11 5.17 5.68 5.45 6.18C4.04 6.63 3 7.94 3 9.5C3 10.11 3.17 10.68 3.45 11.18C2.04 11.63 1 12.94 1 14.5C1 15.76 1.67 16.84 2.67 17.46C2.25 18.03 2 18.74 2 19.5C2 21.43 3.57 23 5.5 23H18.5C20.43 23 22 21.43 22 19.5C22 18.74 21.75 18.03 21.33 17.46C22.33 16.84 23 15.76 23 14.5M8.5 3H15.5C16.33 3 17 3.67 17 4.5S16.33 6 15.5 6H8.5C7.67 6 7 5.33 7 4.5S7.67 3 8.5 3M6.5 8H17.5C18.33 8 19 8.67 19 9.5S18.33 11 17.5 11H6.5C5.67 11 5 10.33 5 9.5S5.67 8 6.5 8M4 19.5C4 18.67 4.67 18 5.5 18H9V21H5.5C4.67 21 4 20.33 4 19.5M18.5 21H15V18H18.5C19.33 18 20 18.67 20 19.5S19.33 21 18.5 21M19.5 16H14.82C14.4 14.84 13.3 14 12 14S9.6 14.84 9.18 16H4.5C3.67 16 3 15.33 3 14.5S3.67 13 4.5 13H19.5C20.33 13 21 13.67 21 14.5S20.33 16 19.5 16Z\";\r\nvar mdiBeekeeper = \"M19 5H16C16 3.34 14.21 2 12 2C9.79 2 8 3.34 8 5H5C4.45 5 4 5.45 4 6S4.45 7 5 7V14C5 15.11 5.9 16 7 16H17C18.11 16 19 15.11 19 14V7C19.55 7 20 6.55 20 6S19.55 5 19 5M17 14H7V7H17V14M15.86 8C15.94 8.32 16 8.65 16 9C16 11.21 14.21 13 12 13S8 11.21 8 9C8 8.65 8.06 8.32 8.14 8H10.28C10.11 8.3 10 8.63 10 9C10 10.1 10.9 11 12 11S14 10.1 14 9C14 8.63 13.89 8.3 13.72 8H15.86M20 19V22H4V19C4 18.22 4.47 17.55 5.18 17H12C9.28 17 6.19 18.29 6 19V20H18V19C17.81 18.29 14.72 17 12 17H18.82C19.53 17.55 20 18.22 20 19Z\";\r\nvar mdiBeer = \"M4,2H19L17,22H6L4,2M6.2,4L7.8,20H8.8L7.43,6.34C8.5,6 9.89,5.89 11,7C12.56,8.56 15.33,7.69 16.5,7.23L16.8,4H6.2Z\";\r\nvar mdiBeerOutline = \"M4 2L6 22H17L19 2H4M6.2 4H16.8L16.5 7.23C13.18 8.5 11.85 7.67 11.38 7.31C11.13 7.12 10.77 6.69 10.11 6.39C9.45 6.08 8.55 6 7.5 6.32C7.09 6.43 6.77 6.61 6.5 6.79L6.2 4M8.86 8.11C9.05 8.11 9.16 8.15 9.27 8.2C9.5 8.3 9.71 8.55 10.17 8.9C11.03 9.56 13.03 10.36 16.26 9.41L15.2 20H7.8L6.71 9.06C6.76 9 6.91 8.89 7.17 8.71C7.5 8.5 7.91 8.28 8 8.25L8 8.25H8.03C8.41 8.14 8.67 8.1 8.86 8.11Z\";\r\nvar mdiBell = \"M21,19V20H3V19L5,17V11C5,7.9 7.03,5.17 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V17L21,19M14,21A2,2 0 0,1 12,23A2,2 0 0,1 10,21\";\r\nvar mdiBellAlert = \"M23 7V13H21V7M21 15H23V17H21M12 2A2 2 0 0 0 10 4A2 2 0 0 0 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H21V19L19 17V11C19 7.82 16.88 5.14 14 4.29A2 2 0 0 0 14 4A2 2 0 0 0 12 2M10 21A2 2 0 0 0 12 23A2 2 0 0 0 14 21Z\";\r\nvar mdiBellAlertOutline = \"M12 2A2 2 0 0 0 10 4A2 2 0 0 0 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H21V19L19 17V11C19 7.82 16.88 5.14 14 4.29A2 2 0 0 0 14 4A2 2 0 0 0 12 2M12 6A5 5 0 0 1 17 11V18H7V11A5 5 0 0 1 12 6M21 7V13H23V7H21M21 15V17H23V15H21M10 21A2 2 0 0 0 12 23A2 2 0 0 0 14 21H10Z\";\r\nvar mdiBellCancel = \"M17.5 13A4.5 4.5 0 0 0 13 17.5A4.5 4.5 0 0 0 17.5 22A4.5 4.5 0 0 0 22 17.5A4.5 4.5 0 0 0 17.5 13M17.5 14.5A3 3 0 0 1 20.5 17.5A3 3 0 0 1 20.08 19L16 14.92A3 3 0 0 1 17.5 14.5M14.92 16L19 20.08A3 3 0 0 1 17.5 20.5A3 3 0 0 1 14.5 17.5A3 3 0 0 1 14.92 16M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H11.5A6.5 6.5 0 0 1 11 17.5A6.5 6.5 0 0 1 17.5 11A6.5 6.5 0 0 1 19 11.18V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M10 21C10 22.11 10.9 23 12 23C12.5 23 12.97 22.81 13.33 22.5A6.5 6.5 0 0 1 12.03 21Z\";\r\nvar mdiBellCancelOutline = \"M17.5 13A4.5 4.5 0 0 0 13 17.5A4.5 4.5 0 0 0 17.5 22A4.5 4.5 0 0 0 22 17.5A4.5 4.5 0 0 0 17.5 13M17.5 14.5A3 3 0 0 1 20.5 17.5A3 3 0 0 1 20.08 19L16 14.92A3 3 0 0 1 17.5 14.5M14.92 16L19 20.08A3 3 0 0 1 17.5 20.5A3 3 0 0 1 14.5 17.5A3 3 0 0 1 14.92 16M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H11.5A6.5 6.5 0 0 1 11.03 18H7V11A5 5 0 0 1 12 6A5 5 0 0 1 17 11V11A6.5 6.5 0 0 1 17.5 11A6.5 6.5 0 0 1 19 11.18V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M10 21C10 22.11 10.9 23 12 23C12.5 23 12.97 22.81 13.33 22.5A6.5 6.5 0 0 1 12.03 21Z\";\r\nvar mdiBellCheck = \"M17.75 21.16L15 18.16L16.16 17L17.75 18.59L21.34 15L22.5 16.41L17.75 21.16M3 20V19L5 17V11C5 7.9 7.03 5.18 10 4.29V4C10 2.9 10.9 2 12 2C13.11 2 14 2.9 14 4V4.29C16.97 5.18 19 7.9 19 11V12.08L18 12C14.69 12 12 14.69 12 18C12 18.7 12.12 19.37 12.34 20H3M12 23C10.9 23 10 22.11 10 21H12.8C13.04 21.41 13.33 21.79 13.65 22.13C13.29 22.66 12.69 23 12 23Z\";\r\nvar mdiBellCheckOutline = \"M17.75 21.16L15 18.16L16.16 17L17.75 18.59L21.34 15L22.5 16.41L17.75 21.16M10 21H12.8C13.04 21.41 13.33 21.79 13.65 22.13C13.29 22.66 12.69 23 12 23C10.9 23 10 22.11 10 21M3 20V19L5 17V11C5 7.9 7.03 5.18 10 4.29V4C10 2.9 10.9 2 12 2C13.11 2 14 2.9 14 4V4.29C16.97 5.18 19 7.9 19 11V12.08L18 12L17 12.08V11C17 8.24 14.76 6 12 6C9.24 6 7 8.24 7 11V18H12C12 18.7 12.12 19.37 12.34 20H3Z\";\r\nvar mdiBellCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M17,16V15L16,14V11.39C16,10.3 15.73,9.34 15.21,8.53C14.7,7.72 13.96,7.21 13,7V6.5A1,1 0 0,0 12,5.5A1,1 0 0,0 11,6.5V7C10.04,7.21 9.3,7.72 8.79,8.53C8.27,9.34 8,10.3 8,11.39V14L7,15V16H17M13.5,17H10.5A1.5,1.5 0 0,0 12,18.5A1.5,1.5 0 0,0 13.5,17Z\";\r\nvar mdiBellCircleOutline = \"M17,16H7V15L8,14V11.39C8,10.3 8.27,9.34 8.79,8.53C9.3,7.72 10.04,7.21 11,7V6.5A1,1 0 0,1 12,5.5A1,1 0 0,1 13,6.5V7C13.96,7.21 14.7,7.72 15.21,8.53C15.73,9.34 16,10.3 16,11.39V14L17,15V16M13.5,17A1.5,1.5 0 0,1 12,18.5A1.5,1.5 0 0,1 10.5,17H13.5M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiBellMinus = \"M22 19V17H14V19H22M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35C12.12 19.36 12 18.68 12 18C12 14.69 14.69 12 18 12C18.34 12 18.67 12.03 19 12.09V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M10 21C10 22.11 10.9 23 12 23C12.66 23 13.28 22.67 13.65 22.13C13.33 21.79 13.05 21.41 12.81 21H10Z\";\r\nvar mdiBellMinusOutline = \"M12 2C10.9 2 10 2.9 10 4V4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35C12.12 19.36 12 18.68 12 18H7V11C7 8.24 9.24 6 12 6S17 8.24 17 11V12.09C17.33 12.03 17.67 12 18 12C18.34 12 18.67 12.03 19 12.09V11C19 7.82 16.88 5.14 14 4.29V4C14 2.9 13.11 2 12 2M14 17V19H22V17M10 21C10 22.11 10.9 23 12 23C12.66 23 13.28 22.67 13.65 22.13C13.33 21.79 13.05 21.41 12.81 21H10Z\";\r\nvar mdiBellOff = \"M20.84,22.73L18.11,20H3V19L5,17V11C5,9.86 5.29,8.73 5.83,7.72L1.11,3L2.39,1.73L22.11,21.46L20.84,22.73M19,15.8V11C19,7.9 16.97,5.17 14,4.29C14,4.19 14,4.1 14,4A2,2 0 0,0 12,2A2,2 0 0,0 10,4C10,4.1 10,4.19 10,4.29C9.39,4.47 8.8,4.74 8.26,5.09L19,15.8M12,23A2,2 0 0,0 14,21H10A2,2 0 0,0 12,23Z\";\r\nvar mdiBellOffOutline = \"M22.11,21.46L2.39,1.73L1.11,3L5.83,7.72C5.29,8.73 5,9.86 5,11V17L3,19V20H18.11L20.84,22.73L22.11,21.46M7,18V11C7,10.39 7.11,9.79 7.34,9.23L16.11,18H7M10,21H14A2,2 0 0,1 12,23A2,2 0 0,1 10,21M8.29,5.09C8.82,4.75 9.4,4.5 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V15.8L17,13.8V11A5,5 0 0,0 12,6C11.22,6 10.45,6.2 9.76,6.56L8.29,5.09Z\";\r\nvar mdiBellOutline = \"M16,17H7V10.5C7,8 9,6 11.5,6C14,6 16,8 16,10.5M18,16V10.5C18,7.43 15.86,4.86 13,4.18V3.5A1.5,1.5 0 0,0 11.5,2A1.5,1.5 0 0,0 10,3.5V4.18C7.13,4.86 5,7.43 5,10.5V16L3,18V19H20V18M11.5,22A2,2 0 0,0 13.5,20H9.5A2,2 0 0,0 11.5,22Z\";\r\nvar mdiBellPlus = \"M17 14V17H14V19H17V22H19V19H22V17H19V14M12 2A2 2 0 0 0 10 4A2 2 0 0 0 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35A6 6 0 0 1 12 18A6 6 0 0 1 18 12A6 6 0 0 1 19 12.09V11C19 7.82 16.88 5.14 14 4.29A2 2 0 0 0 14 4A2 2 0 0 0 12 2M10 21A2 2 0 0 0 12 23A2 2 0 0 0 13.65 22.13A6 6 0 0 1 12.81 21Z\";\r\nvar mdiBellPlusOutline = \"M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35C12.12 19.36 12 18.68 12 18H7V11C7 8.24 9.24 6 12 6C14.76 6 17 8.24 17 11V12.09C17.33 12.03 17.67 12 18 12C18.34 12 18.67 12.03 19 12.09V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M17 14V17H14V19H17V22H19V19H22V17H19V14M10 21C10 22.11 10.9 23 12 23C12.66 23 13.28 22.67 13.65 22.13C13.33 21.79 13.05 21.41 12.81 21Z\";\r\nvar mdiBellRemove = \"M20.12 14.46L18 16.59L15.88 14.46L14.46 15.88L16.59 18L14.46 20.12L15.88 21.54L18 19.41L20.12 21.54L21.54 20.12L19.41 18L21.54 15.88M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35C12.12 19.36 12 18.68 12 18C12 14.69 14.69 12 18 12C18.34 12 18.67 12.03 19 12.09V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M10 21C10 22.11 10.9 23 12 23C12.66 23 13.28 22.67 13.65 22.13C13.33 21.79 13.05 21.41 12.81 21Z\";\r\nvar mdiBellRemoveOutline = \"M20.12 14.46L18 16.59L15.88 14.46L14.46 15.88L16.59 18L14.46 20.12L15.88 21.54L18 19.41L20.12 21.54L21.54 20.12L19.41 18L21.54 15.88M12 2C10.9 2 10 2.9 10 4C10 4.1 10 4.19 10 4.29C7.12 5.14 5 7.82 5 11V17L3 19V20H12.35C12.12 19.36 12 18.68 12 18H7V11A5 5 0 0 1 12 6A5 5 0 0 1 17 11V12.09C17.33 12.04 17.66 12 18 12C18.34 12 18.67 12.03 19 12.09V11C19 7.82 16.88 5.14 14 4.29C14 4.19 14 4.1 14 4C14 2.9 13.11 2 12 2M10 21C10 22.11 10.9 23 12 23C12.66 23 13.28 22.67 13.65 22.13C13.33 21.79 13.05 21.41 12.81 21Z\";\r\nvar mdiBellRing = \"M21,19V20H3V19L5,17V11C5,7.9 7.03,5.17 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V17L21,19M14,21A2,2 0 0,1 12,23A2,2 0 0,1 10,21M19.75,3.19L18.33,4.61C20.04,6.3 21,8.6 21,11H23C23,8.07 21.84,5.25 19.75,3.19M1,11H3C3,8.6 3.96,6.3 5.67,4.61L4.25,3.19C2.16,5.25 1,8.07 1,11Z\";\r\nvar mdiBellRingOutline = \"M10,21H14A2,2 0 0,1 12,23A2,2 0 0,1 10,21M21,19V20H3V19L5,17V11C5,7.9 7.03,5.17 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V17L21,19M17,11A5,5 0 0,0 12,6A5,5 0 0,0 7,11V18H17V11M19.75,3.19L18.33,4.61C20.04,6.3 21,8.6 21,11H23C23,8.07 21.84,5.25 19.75,3.19M1,11H3C3,8.6 3.96,6.3 5.67,4.61L4.25,3.19C2.16,5.25 1,8.07 1,11Z\";\r\nvar mdiBellSleep = \"M10,21H14A2,2 0 0,1 12,23A2,2 0 0,1 10,21M21,19V20H3V19L5,17V11C5,7.9 7.03,5.17 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V17L21,19M15,9H9V11H12.24L9,13.7V16H15V14H11.76L15,11.3V9Z\";\r\nvar mdiBellSleepOutline = \"M10,21H14A2,2 0 0,1 12,23A2,2 0 0,1 10,21M21,19V20H3V19L5,17V11C5,7.9 7.03,5.17 10,4.29C10,4.19 10,4.1 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.1 14,4.19 14,4.29C16.97,5.17 19,7.9 19,11V17L21,19M17,11A5,5 0 0,0 12,6A5,5 0 0,0 7,11V18H17V11M9,9V11H12.24L9,13.7V16H15V14H11.76L15,11.3V9H9Z\";\r\nvar mdiBeta = \"M9.23,17.59V23.12H6.88V6.72C6.88,5.27 7.31,4.13 8.16,3.28C9,2.43 10.17,2 11.61,2C13,2 14.07,2.34 14.87,3C15.66,3.68 16.05,4.62 16.05,5.81C16.05,6.63 15.79,7.4 15.27,8.11C14.75,8.82 14.08,9.31 13.25,9.58V9.62C14.5,9.82 15.47,10.27 16.13,11C16.79,11.71 17.12,12.62 17.12,13.74C17.12,15.06 16.66,16.14 15.75,16.97C14.83,17.8 13.63,18.21 12.13,18.21C11.07,18.21 10.1,18 9.23,17.59M10.72,10.75V8.83C11.59,8.72 12.3,8.4 12.87,7.86C13.43,7.31 13.71,6.7 13.71,6C13.71,4.62 13,3.92 11.6,3.92C10.84,3.92 10.25,4.16 9.84,4.65C9.43,5.14 9.23,5.82 9.23,6.71V15.5C10.14,16.03 11.03,16.29 11.89,16.29C12.73,16.29 13.39,16.07 13.86,15.64C14.33,15.2 14.56,14.58 14.56,13.79C14.56,12 13.28,11 10.72,10.75Z\";\r\nvar mdiBetamax = \"M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M8,9A4,4 0 0,1 12,13A4,4 0 0,1 8,17A4,4 0 0,1 4,13A4,4 0 0,1 8,9M13,9H20V17H13V9M8,11A2,2 0 0,0 6,13A2,2 0 0,0 8,15A2,2 0 0,0 10,13A2,2 0 0,0 8,11Z\";\r\nvar mdiBiathlon = \"M12.88,3.64C13.65,3.64 14.28,4.27 14.28,5.04C14.28,5.81 13.65,6.44 12.88,6.44C12.11,6.44 11.5,5.81 11.5,5.04C11.5,4.27 12.11,3.64 12.88,3.64M15,13H16.5V19H15V13M15,8.5H16.5V10H15V8.5M10.04,2.6L8,2.04L6.06,8.58L3.9,11.42L7.17,12.37L10.04,2.6M19.67,18.55C19.31,18.93 18.88,19.5 18.4,19.7C17.91,19.92 17.54,20 17,20H13.5L13.43,17C13.42,16.83 13.37,16.67 13.28,16.5L10.88,12.24L11.76,9.5C12.34,10.55 13,11.73 13.06,11.83C13.21,12 13.45,12.13 13.69,12.13H15.9A0.81,0.81 0 0,0 16.71,11.32C16.71,10.9 16.38,10.56 15.96,10.53L14.29,10.4L12.4,7C12.4,7 12,6.42 11.14,6.42C10.27,6.42 10,6.84 9.83,7.42L6,20H3V22H17C18.37,22 19.53,21.34 20.5,20.37L19.67,18.55M9.75,14.39L11.62,17.39L11.75,20H7.75L9.75,14.39Z\";\r\nvar mdiBicycle = \"M19 10C18.44 10 17.91 10.11 17.41 10.28L14.46 4.5H11V6H13.54L14.42 7.72L12 13.13L10.23 8.95C10.5 8.85 10.74 8.58 10.74 8.25C10.74 7.84 10.41 7.5 10 7.5H8C7.58 7.5 7.24 7.84 7.24 8.25S7.58 9 8 9H8.61L10.86 14.25H9.92C9.56 11.85 7.5 10 5 10C2.24 10 0 12.24 0 15S2.24 20 5 20C7.5 20 9.56 18.15 9.92 15.75H12.5L15.29 9.43L16.08 10.96C14.82 11.87 14 13.34 14 15C14 17.76 16.24 20 19 20S24 17.76 24 15 21.76 10 19 10M5 18.5C3.07 18.5 1.5 16.93 1.5 15S3.07 11.5 5 11.5C6.67 11.5 8.07 12.68 8.41 14.25H4V15.75H8.41C8.07 17.32 6.67 18.5 5 18.5M19 18.5C17.07 18.5 15.5 16.93 15.5 15C15.5 13.92 16 12.97 16.77 12.33L18.57 15.85L19.89 15.13L18.1 11.63C18.39 11.56 18.69 11.5 19 11.5C20.93 11.5 22.5 13.07 22.5 15S20.93 18.5 19 18.5Z\";\r\nvar mdiBicycleBasket = \"M11.74 13.36L14.14 7.71L13.06 5.5H10.5V4H14L14.73 5.5H21.75L20.75 9H16.44L17.11 10.37C17.69 10.13 18.33 10 19 10C21.76 10 24 12.24 24 15C24 17.76 21.76 20 19 20C16.24 20 14 17.76 14 15C14 13.45 14.71 12.06 15.82 11.15L15 9.5L12.25 16H9.9C9.44 18.28 7.42 20 5 20C2.24 20 0 17.76 0 15C0 12.24 2.24 10 5 10C7.59 10 9.72 11.97 10 14.5H10.58L8.3 9H7.5C7.09 9 6.75 8.66 6.75 8.25C6.75 7.84 7.09 7.5 7.5 7.5H10.25C10.66 7.5 11 7.84 11 8.25C11 8.66 10.66 9 10.25 9H9.97L11.74 13.36M5 11.5C3.07 11.5 1.5 13.07 1.5 15C1.5 16.93 3.07 18.5 5 18.5C6.59 18.5 7.93 17.45 8.36 16H4V14.5H8.47C8.22 12.8 6.76 11.5 5 11.5M19 11.5C18.57 11.5 18.15 11.58 17.77 11.72L19.7 15.68L18.35 16.34L16.5 12.55C15.88 13.18 15.5 14.05 15.5 15C15.5 16.93 17.07 18.5 19 18.5C20.93 18.5 22.5 16.93 22.5 15C22.5 13.07 20.93 11.5 19 11.5Z\";\r\nvar mdiBicycleElectric = \"M19 7C18.44 7 17.91 7.11 17.41 7.28L14.46 1.5H11V3H13.54L14.42 4.72L12 10.13L10.23 5.95C10.5 5.85 10.74 5.58 10.74 5.25C10.74 4.84 10.41 4.5 10 4.5H8C7.58 4.5 7.24 4.84 7.24 5.25S7.58 6 8 6H8.61L10.86 11.25H9.92C9.56 8.85 7.5 7 5 7C2.24 7 0 9.24 0 12S2.24 17 5 17C7.5 17 9.56 15.15 9.92 12.75H12.5L15.29 6.43L16.08 7.96C14.82 8.87 14 10.34 14 12C14 14.76 16.24 17 19 17S24 14.76 24 12 21.76 7 19 7M5 15.5C3.07 15.5 1.5 13.93 1.5 12S3.07 8.5 5 8.5C6.67 8.5 8.07 9.68 8.41 11.25H4V12.75H8.41C8.07 14.32 6.67 15.5 5 15.5M19 15.5C17.07 15.5 15.5 13.93 15.5 12C15.5 10.92 16 9.97 16.77 9.33L18.57 12.85L19.89 12.13L18.1 8.63C18.39 8.56 18.69 8.5 19 8.5C20.93 8.5 22.5 10.07 22.5 12S20.93 15.5 19 15.5M11 20H7L13 23V21H17L11 18V20Z\";\r\nvar mdiBicyclePennyFarthing = \"M15.5 5.06V2H12V4H13.5V5.04C12.71 5.11 11.94 5.27 11.2 5.5C11.03 5.2 10.72 5 10.36 5H7C6.45 5 6 5.45 6 6S6.45 7 7 7H8.05C5.09 9 3.12 12.36 3 16.18C1.85 16.59 1 17.69 1 19C1 20.66 2.34 22 4 22S7 20.66 7 19C7 17.7 6.17 16.61 5 16.19C5.07 14.67 5.46 13.25 6.14 12C6.05 12.5 6 13 6 13.5C6 18.19 9.81 22 14.5 22C19.19 22 23 18.19 23 13.5C23 9.14 19.72 5.56 15.5 5.06M4 20C3.45 20 3 19.55 3 19S3.45 18 4 18 5 18.45 5 19 4.55 20 4 20M14.5 20C10.92 20 8 17.08 8 13.5C8 10.26 10.39 7.57 13.5 7.09V15H15.5V7.09C18.61 7.57 21 10.26 21 13.5C21 17.08 18.08 20 14.5 20Z\";\r\nvar mdiBike = \"M5,20.5A3.5,3.5 0 0,1 1.5,17A3.5,3.5 0 0,1 5,13.5A3.5,3.5 0 0,1 8.5,17A3.5,3.5 0 0,1 5,20.5M5,12A5,5 0 0,0 0,17A5,5 0 0,0 5,22A5,5 0 0,0 10,17A5,5 0 0,0 5,12M14.8,10H19V8.2H15.8L13.86,4.93C13.57,4.43 13,4.1 12.4,4.1C11.93,4.1 11.5,4.29 11.2,4.6L7.5,8.29C7.19,8.6 7,9 7,9.5C7,10.13 7.33,10.66 7.85,10.97L11.2,13V18H13V11.5L10.75,9.85L13.07,7.5M19,20.5A3.5,3.5 0 0,1 15.5,17A3.5,3.5 0 0,1 19,13.5A3.5,3.5 0 0,1 22.5,17A3.5,3.5 0 0,1 19,20.5M19,12A5,5 0 0,0 14,17A5,5 0 0,0 19,22A5,5 0 0,0 24,17A5,5 0 0,0 19,12M16,4.8C17,4.8 17.8,4 17.8,3C17.8,2 17,1.2 16,1.2C15,1.2 14.2,2 14.2,3C14.2,4 15,4.8 16,4.8Z\";\r\nvar mdiBikeFast = \"M16 1.2C15 1.2 14.2 2 14.2 3S15 4.8 16 4.8 17.8 4 17.8 3 17 1.2 16 1.2M12.4 4.1C11.93 4.1 11.5 4.29 11.2 4.6L7.5 8.29C7.19 8.6 7 9 7 9.5C7 10.13 7.33 10.66 7.85 10.97L11.2 13V18H13V11.5L10.75 9.85L13.07 7.5L14.8 10H19V8.2H15.8L13.86 4.93C13.57 4.43 13 4.1 12.4 4.1M10 3H3C2.45 3 2 2.55 2 2S2.45 1 3 1H12.79C12.58 1.34 12.41 1.71 12.32 2.11C11.46 2.13 10.65 2.45 10 3M5 12C2.24 12 0 14.24 0 17S2.24 22 5 22 10 19.76 10 17 7.76 12 5 12M5 20.5C3.07 20.5 1.5 18.93 1.5 17S3.07 13.5 5 13.5 8.5 15.07 8.5 17 6.93 20.5 5 20.5M19 12C16.24 12 14 14.24 14 17S16.24 22 19 22 24 19.76 24 17 21.76 12 19 12M19 20.5C17.07 20.5 15.5 18.93 15.5 17S17.07 13.5 19 13.5 22.5 15.07 22.5 17 20.93 20.5 19 20.5M5.32 11H1C.448 11 0 10.55 0 10S.448 9 1 9H5.05C5.03 9.16 5 9.33 5 9.5C5 10.03 5.12 10.54 5.32 11M6 7H2C1.45 7 1 6.55 1 6S1.45 5 2 5H7.97L6.09 6.87C6.05 6.91 6 6.96 6 7Z\";\r\nvar mdiBillboard = \"M20 22H18V17H20M6 22H4V17H6M23 4V13A2 2 0 0 1 21 15H3A2 2 0 0 1 1 13V4A2 2 0 0 1 3 2H21A2 2 0 0 1 23 4M21 4H3V13H21M20 6H15V8H20M18 9H15V11H18M14 11H4L6.73 7.36L8.73 10.09L9.46 9.55L8.2 7.82L9.91 5.55Z\";\r\nvar mdiBilliards = \"M11,13H13V15H11M11,9H13V11H11M11,17H13A2,2 0 0,0 15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9A2,2 0 0,0 13,7H11A2,2 0 0,0 9,9V10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 9,13.5V15A2,2 0 0,0 11,17M12,1C5.92,1 1,5.92 1,12C1,18.08 5.92,23 12,23C18.08,23 23,18.08 23,12C23,5.92 18.08,1 12,1M12,19A7,7 0 0,1 5,12A7,7 0 0,1 12,5A7,7 0 0,1 19,12A7,7 0 0,1 12,19Z\";\r\nvar mdiBilliardsRack = \"M20.31,16.44L14.54,6.47C13.72,5.04 11.89,4.55 10.46,5.38C10,5.64 9.63,6 9.36,6.47L3.6,16.44C2.77,17.87 3.26,19.69 4.69,20.5C5.14,20.78 5.65,20.92 6.18,20.92H17.73C19.38,20.91 20.72,19.57 20.71,17.92C20.71,17.4 20.57,16.89 20.31,16.44M5.37,17.43L11.11,7.47C11.38,7 12,6.82 12.46,7.1C12.62,7.18 12.75,7.31 12.84,7.47L18.58,17.43C18.85,17.91 18.69,18.5 18.21,18.79C18.06,18.88 17.89,18.93 17.72,18.93H6.21C5.66,18.92 5.21,18.47 5.22,17.92C5.22,17.75 5.26,17.58 5.35,17.43H5.37M11.97,13.45C10.87,13.45 10,12.56 10,11.46C10,10.35 10.87,9.46 11.97,9.46A2,2 0 0,1 13.97,11.46C13.97,12.56 13.07,13.45 11.95,13.45H11.97M9.46,17.93C8.36,17.93 7.47,17.04 7.47,15.94C7.47,14.84 8.36,13.95 9.46,13.95C10.56,13.95 11.46,14.84 11.46,15.94C11.46,17.04 10.56,17.93 9.46,17.93M14.44,17.93A2,2 0 0,1 12.45,15.94A2,2 0 0,1 14.44,13.95C15.54,13.95 16.44,14.84 16.44,15.94C16.44,17.04 15.54,17.93 14.44,17.93Z\";\r\nvar mdiBinoculars = \"M11,6H13V13H11V6M9,20A1,1 0 0,1 8,21H5A1,1 0 0,1 4,20V15L6,6H10V13A1,1 0 0,1 9,14V20M10,5H7V3H10V5M15,20V14A1,1 0 0,1 14,13V6H18L20,15V20A1,1 0 0,1 19,21H16A1,1 0 0,1 15,20M14,5V3H17V5H14Z\";\r\nvar mdiBio = \"M17,12H20A2,2 0 0,1 22,14V17A2,2 0 0,1 20,19H17A2,2 0 0,1 15,17V14A2,2 0 0,1 17,12M17,14V17H20V14H17M2,7H7A2,2 0 0,1 9,9V11A2,2 0 0,1 7,13A2,2 0 0,1 9,15V17A2,2 0 0,1 7,19H2V13L2,7M4,9V12H7V9H4M4,17H7V14H4V17M11,13H13V19H11V13M11,9H13V11H11V9Z\";\r\nvar mdiBiohazard = \"M23,16.06C23,16.29 23,16.5 22.96,16.7C22.78,14.14 20.64,12.11 18,12.11C17.63,12.11 17.27,12.16 16.92,12.23C16.96,12.5 17,12.73 17,13C17,15.35 15.31,17.32 13.07,17.81C13.42,20.05 15.31,21.79 17.65,21.96C17.43,22 17.22,22 17,22C14.92,22 13.07,20.94 12,19.34C10.93,20.94 9.09,22 7,22C6.78,22 6.57,22 6.35,21.96C8.69,21.79 10.57,20.06 10.93,17.81C8.68,17.32 7,15.35 7,13C7,12.73 7.04,12.5 7.07,12.23C6.73,12.16 6.37,12.11 6,12.11C3.36,12.11 1.22,14.14 1.03,16.7C1,16.5 1,16.29 1,16.06C1,12.85 3.59,10.24 6.81,10.14C6.3,9.27 6,8.25 6,7.17C6,4.94 7.23,3 9.06,2C7.81,2.9 7,4.34 7,6C7,7.35 7.56,8.59 8.47,9.5C9.38,8.59 10.62,8.04 12,8.04C13.37,8.04 14.62,8.59 15.5,9.5C16.43,8.59 17,7.35 17,6C17,4.34 16.18,2.9 14.94,2C16.77,3 18,4.94 18,7.17C18,8.25 17.7,9.27 17.19,10.14C20.42,10.24 23,12.85 23,16.06M9.27,10.11C10.05,10.62 11,10.92 12,10.92C13,10.92 13.95,10.62 14.73,10.11C14,9.45 13.06,9.03 12,9.03C10.94,9.03 10,9.45 9.27,10.11M12,14.47C12.82,14.47 13.5,13.8 13.5,13A1.5,1.5 0 0,0 12,11.5A1.5,1.5 0 0,0 10.5,13C10.5,13.8 11.17,14.47 12,14.47M10.97,16.79C10.87,14.9 9.71,13.29 8.05,12.55C8.03,12.7 8,12.84 8,13C8,14.82 9.27,16.34 10.97,16.79M15.96,12.55C14.29,13.29 13.12,14.9 13,16.79C14.73,16.34 16,14.82 16,13C16,12.84 15.97,12.7 15.96,12.55Z\";\r\nvar mdiBird = \"M23 11.5L19.95 10.37C19.69 9.22 19.04 8.56 19.04 8.56C17.4 6.92 14.75 6.92 13.11 8.56L11.63 10.04L5 3C4 7 5 11 7.45 14.22L2 19.5C2 19.5 10.89 21.5 16.07 17.45C18.83 15.29 19.45 14.03 19.84 12.7L23 11.5M17.71 11.72C17.32 12.11 16.68 12.11 16.29 11.72C15.9 11.33 15.9 10.7 16.29 10.31C16.68 9.92 17.32 9.92 17.71 10.31C18.1 10.7 18.1 11.33 17.71 11.72Z\";\r\nvar mdiBitbucket = \"M2.65 3C2.3 3 2 3.3 2 3.65C2 3.69 2 3.73 2 3.77L4.73 20.27C4.8 20.69 5.16 21 5.58 21H18.63C18.94 21 19.22 20.78 19.27 20.46L22 3.77C22.05 3.42 21.81 3.09 21.46 3.04C21.43 3.03 21.39 3.03 21.35 3.03L2.65 3M14.1 14.95H9.94L8.81 9.07H15.11L14.1 14.95Z\";\r\nvar mdiBitcoin = \"M14.24 10.56C13.93 11.8 12 11.17 11.4 11L11.95 8.82C12.57 9 14.56 9.26 14.24 10.56M11.13 12.12L10.53 14.53C11.27 14.72 13.56 15.45 13.9 14.09C14.26 12.67 11.87 12.3 11.13 12.12M21.7 14.42C20.36 19.78 14.94 23.04 9.58 21.7C4.22 20.36 .963 14.94 2.3 9.58C3.64 4.22 9.06 .964 14.42 2.3C19.77 3.64 23.03 9.06 21.7 14.42M14.21 8.05L14.66 6.25L13.56 6L13.12 7.73C12.83 7.66 12.54 7.59 12.24 7.53L12.68 5.76L11.59 5.5L11.14 7.29C10.9 7.23 10.66 7.18 10.44 7.12L10.44 7.12L8.93 6.74L8.63 7.91C8.63 7.91 9.45 8.1 9.43 8.11C9.88 8.22 9.96 8.5 9.94 8.75L8.71 13.68C8.66 13.82 8.5 14 8.21 13.95C8.22 13.96 7.41 13.75 7.41 13.75L6.87 15L8.29 15.36C8.56 15.43 8.82 15.5 9.08 15.56L8.62 17.38L9.72 17.66L10.17 15.85C10.47 15.93 10.76 16 11.04 16.08L10.59 17.87L11.69 18.15L12.15 16.33C14 16.68 15.42 16.54 16 14.85C16.5 13.5 16 12.7 15 12.19C15.72 12 16.26 11.55 16.41 10.57C16.61 9.24 15.59 8.53 14.21 8.05Z\";\r\nvar mdiBlackMesa = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12C4,14.39 5.05,16.53 6.71,18H9V12H17L19.15,15.59C19.69,14.5 20,13.29 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiBlender = \"M19,5H17.8L18,2H4L5,4H6L6.94,16.19L5,22H19L17.06,16.17L17.2,14H19C20.3,14 21,12.97 21,12V7C21,5.7 19.97,5 19,5M12,20A1.5,1.5 0 0,1 10.5,18.5A1.5,1.5 0 0,1 12,17A1.5,1.5 0 0,1 13.5,18.5A1.5,1.5 0 0,1 12,20M15.13,15H8.85L8.7,13H13V12H8.62L8.47,10H13V9H8.39L8.24,7H13V6H8.16L8,4H15.86L15.13,15M19,12H17.33L17.67,7H19V12Z\";\r\nvar mdiBlenderSoftware = \"M12.58,3.12V3.13C12.27,3.13 11.96,3.22 11.71,3.39C11.21,3.74 11.15,4.32 11.6,4.69L14.46,7L5.73,7.03H5.72C5,7.03 4.3,7.5 4.16,8.1C4,8.71 4.5,9.22 5.26,9.22L9.69,9.21L1.76,15.3C1,15.87 0.77,16.82 1.24,17.42C1.72,18.03 2.73,18.03 3.5,17.42L7.8,13.89C7.8,13.89 7.73,14.37 7.74,14.65C7.74,14.94 7.84,15.5 7.97,15.93C8.26,16.86 8.75,17.71 9.43,18.46C10.13,19.23 11,19.85 12,20.29C13.03,20.76 14.17,21 15.34,21C16.5,21 17.65,20.75 18.69,20.28C19.69,19.84 20.55,19.21 21.25,18.44C21.93,17.69 22.42,16.83 22.71,15.91C22.85,15.44 22.94,14.97 23,14.5C23,14.03 23,13.56 22.94,13.09C22.81,12.18 22.5,11.32 22,10.54C21.56,9.83 21,9.2 20.31,8.67V8.67L13.42,3.38C13.19,3.21 12.89,3.12 12.58,3.12M15.34,9.21C16.5,9.21 17.59,9.59 18.46,10.29C18.9,10.65 19.25,11.07 19.5,11.54C19.77,12 19.94,12.55 20,13.11C20.04,13.67 19.96,14.23 19.77,14.77C19.57,15.31 19.25,15.81 18.82,16.26C17.93,17.16 16.69,17.68 15.34,17.68C14,17.68 12.75,17.17 11.86,16.27C11.43,15.83 11.11,15.32 10.91,14.78C10.72,14.25 10.64,13.69 10.69,13.12C10.74,12.56 10.91,12.03 11.17,11.55C11.43,11.08 11.79,10.66 12.23,10.3C13.09,9.59 14.19,9.21 15.34,9.21M15.44,10.61C14.66,10.61 13.94,10.89 13.41,11.34C12.87,11.8 12.5,12.44 12.47,13.18C12.43,13.93 12.73,14.63 13.26,15.15C13.8,15.68 14.58,16 15.44,16C16.3,16 17.07,15.68 17.62,15.15C18.15,14.63 18.45,13.93 18.41,13.18C18.37,12.44 18,11.8 17.47,11.34C16.94,10.89 16.22,10.61 15.44,10.61Z\";\r\nvar mdiBlinds = \"M3,2H21A1,1 0 0,1 22,3V5A1,1 0 0,1 21,6H20V13A1,1 0 0,1 19,14H13V16.17C14.17,16.58 15,17.69 15,19A3,3 0 0,1 12,22A3,3 0 0,1 9,19C9,17.69 9.83,16.58 11,16.17V14H5A1,1 0 0,1 4,13V6H3A1,1 0 0,1 2,5V3A1,1 0 0,1 3,2M12,18A1,1 0 0,0 11,19A1,1 0 0,0 12,20A1,1 0 0,0 13,19A1,1 0 0,0 12,18Z\";\r\nvar mdiBlindsOpen = \"M3 2H21C21.55 2 22 2.45 22 3V5C22 5.55 21.55 6 21 6H20V7C20 7.55 19.55 8 19 8H13V10.17C14.17 10.58 15 11.7 15 13C15 14.66 13.66 16 12 16C10.34 16 9 14.66 9 13C9 11.69 9.84 10.58 11 10.17V8H5C4.45 8 4 7.55 4 7V6H3C2.45 6 2 5.55 2 5V3C2 2.45 2.45 2 3 2M12 12C11.45 12 11 12.45 11 13C11 13.55 11.45 14 12 14C12.55 14 13 13.55 13 13C13 12.45 12.55 12 12 12Z\";\r\nvar mdiBlockHelper = \"M12,0A12,12 0 0,1 24,12A12,12 0 0,1 12,24A12,12 0 0,1 0,12A12,12 0 0,1 12,0M12,2A10,10 0 0,0 2,12C2,14.4 2.85,16.6 4.26,18.33L18.33,4.26C16.6,2.85 14.4,2 12,2M12,22A10,10 0 0,0 22,12C22,9.6 21.15,7.4 19.74,5.67L5.67,19.74C7.4,21.15 9.6,22 12,22Z\";\r\nvar mdiBlogger = \"M12.5 10H10C9.45 10 9 9.55 9 9C9 8.45 9.45 8 10 8H12.5C13.05 8 13.5 8.45 13.5 9C13.5 9.55 13.05 10 12.5 10M15 14C15 13.45 14.55 13 14 13H10C9.45 13 9 13.45 9 14C9 14.55 9.45 15 10 15H14C14.55 15 15 14.55 15 14M22 4V20C22 21.11 21.11 22 20 22H4C2.89 22 2 21.11 2 20V4C2 2.89 2.89 2 4 2H20C21.11 2 22 2.89 22 4M18 12C18 12 18 11 17 11C16.05 11.03 16 10 16 10L16 8C16 6.34 14.66 5 13 5H9C7.34 5 6 6.34 6 8V15C6 16.66 7.34 18 9 18H15C16.66 18 18 16.66 18 15L18 12Z\";\r\nvar mdiBloodBag = \"M21,7C20,7 20,6 20,6V5H18V7H16V6C16,4.27 14.75,1 10,1C5.25,1 4,4.27 4,6V19C4,19.33 3.9,21 2,21V23C4.93,23 6,20.61 6,19V6C6,5.88 6.05,3 10,3C13.83,3 14,5.7 14,6V7H12V5H10V6C10,6 10,7 9,7C8,7 8,8 8,8V20C8,20 8,22 13,22C13.24,22 14.13,22 17,22C22,22 22,20 22,20V8C22,8 22,7 21,7M15,19.4A3,3 0 0,1 12,16.4C12,14.4 15,11 15,11C15,11 18,14.4 18,16.4A3,3 0 0,1 15,19.4Z\";\r\nvar mdiBluetooth = \"M14.88,16.29L13,18.17V14.41M13,5.83L14.88,7.71L13,9.58M17.71,7.71L12,2H11V9.58L6.41,5L5,6.41L10.59,12L5,17.58L6.41,19L11,14.41V22H12L17.71,16.29L13.41,12L17.71,7.71Z\";\r\nvar mdiBluetoothAudio = \"M12.88,16.29L11,18.17V14.41M11,5.83L12.88,7.71L11,9.58M15.71,7.71L10,2H9V9.58L4.41,5L3,6.41L8.59,12L3,17.58L4.41,19L9,14.41V22H10L15.71,16.29L11.41,12M19.53,6.71L18.26,8C18.89,9.18 19.25,10.55 19.25,12C19.25,13.45 18.89,14.82 18.26,16L19.46,17.22C20.43,15.68 21,13.87 21,11.91C21,10 20.46,8.23 19.53,6.71M14.24,12L16.56,14.33C16.84,13.6 17,12.82 17,12C17,11.18 16.84,10.4 16.57,9.68L14.24,12Z\";\r\nvar mdiBluetoothConnect = \"M19,10L17,12L19,14L21,12M14.88,16.29L13,18.17V14.41M13,5.83L14.88,7.71L13,9.58M17.71,7.71L12,2H11V9.58L6.41,5L5,6.41L10.59,12L5,17.58L6.41,19L11,14.41V22H12L17.71,16.29L13.41,12M7,12L5,10L3,12L5,14L7,12Z\";\r\nvar mdiBluetoothOff = \"M13,5.83L14.88,7.71L13.28,9.31L14.69,10.72L17.71,7.7L12,2H11V7.03L13,9.03M5.41,4L4,5.41L10.59,12L5,17.59L6.41,19L11,14.41V22H12L16.29,17.71L18.59,20L20,18.59M13,18.17V14.41L14.88,16.29\";\r\nvar mdiBluetoothSettings = \"M14.88,14.29L13,16.17V12.41L14.88,14.29M13,3.83L14.88,5.71L13,7.59M17.71,5.71L12,0H11V7.59L6.41,3L5,4.41L10.59,10L5,15.59L6.41,17L11,12.41V20H12L17.71,14.29L13.41,10L17.71,5.71M15,24H17V22H15M7,24H9V22H7M11,24H13V22H11V24Z\";\r\nvar mdiBluetoothTransfer = \"M14.71,7.71L10.41,12L14.71,16.29L9,22H8V14.41L3.41,19L2,17.59L7.59,12L2,6.41L3.41,5L8,9.59V2H9L14.71,7.71M10,5.83V9.59L11.88,7.71L10,5.83M11.88,16.29L10,14.41V18.17L11.88,16.29M22,8H20V11H18V8H16L19,4L22,8M22,16L19,20L16,16H18V13H20V16H22Z\";\r\nvar mdiBlur = \"M14,8.5A1.5,1.5 0 0,0 12.5,10A1.5,1.5 0 0,0 14,11.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 14,8.5M14,12.5A1.5,1.5 0 0,0 12.5,14A1.5,1.5 0 0,0 14,15.5A1.5,1.5 0 0,0 15.5,14A1.5,1.5 0 0,0 14,12.5M10,17A1,1 0 0,0 9,18A1,1 0 0,0 10,19A1,1 0 0,0 11,18A1,1 0 0,0 10,17M10,8.5A1.5,1.5 0 0,0 8.5,10A1.5,1.5 0 0,0 10,11.5A1.5,1.5 0 0,0 11.5,10A1.5,1.5 0 0,0 10,8.5M14,20.5A0.5,0.5 0 0,0 13.5,21A0.5,0.5 0 0,0 14,21.5A0.5,0.5 0 0,0 14.5,21A0.5,0.5 0 0,0 14,20.5M14,17A1,1 0 0,0 13,18A1,1 0 0,0 14,19A1,1 0 0,0 15,18A1,1 0 0,0 14,17M21,13.5A0.5,0.5 0 0,0 20.5,14A0.5,0.5 0 0,0 21,14.5A0.5,0.5 0 0,0 21.5,14A0.5,0.5 0 0,0 21,13.5M18,5A1,1 0 0,0 17,6A1,1 0 0,0 18,7A1,1 0 0,0 19,6A1,1 0 0,0 18,5M18,9A1,1 0 0,0 17,10A1,1 0 0,0 18,11A1,1 0 0,0 19,10A1,1 0 0,0 18,9M18,17A1,1 0 0,0 17,18A1,1 0 0,0 18,19A1,1 0 0,0 19,18A1,1 0 0,0 18,17M18,13A1,1 0 0,0 17,14A1,1 0 0,0 18,15A1,1 0 0,0 19,14A1,1 0 0,0 18,13M10,12.5A1.5,1.5 0 0,0 8.5,14A1.5,1.5 0 0,0 10,15.5A1.5,1.5 0 0,0 11.5,14A1.5,1.5 0 0,0 10,12.5M10,7A1,1 0 0,0 11,6A1,1 0 0,0 10,5A1,1 0 0,0 9,6A1,1 0 0,0 10,7M10,3.5A0.5,0.5 0 0,0 10.5,3A0.5,0.5 0 0,0 10,2.5A0.5,0.5 0 0,0 9.5,3A0.5,0.5 0 0,0 10,3.5M10,20.5A0.5,0.5 0 0,0 9.5,21A0.5,0.5 0 0,0 10,21.5A0.5,0.5 0 0,0 10.5,21A0.5,0.5 0 0,0 10,20.5M3,13.5A0.5,0.5 0 0,0 2.5,14A0.5,0.5 0 0,0 3,14.5A0.5,0.5 0 0,0 3.5,14A0.5,0.5 0 0,0 3,13.5M14,3.5A0.5,0.5 0 0,0 14.5,3A0.5,0.5 0 0,0 14,2.5A0.5,0.5 0 0,0 13.5,3A0.5,0.5 0 0,0 14,3.5M14,7A1,1 0 0,0 15,6A1,1 0 0,0 14,5A1,1 0 0,0 13,6A1,1 0 0,0 14,7M21,10.5A0.5,0.5 0 0,0 21.5,10A0.5,0.5 0 0,0 21,9.5A0.5,0.5 0 0,0 20.5,10A0.5,0.5 0 0,0 21,10.5M6,5A1,1 0 0,0 5,6A1,1 0 0,0 6,7A1,1 0 0,0 7,6A1,1 0 0,0 6,5M3,9.5A0.5,0.5 0 0,0 2.5,10A0.5,0.5 0 0,0 3,10.5A0.5,0.5 0 0,0 3.5,10A0.5,0.5 0 0,0 3,9.5M6,9A1,1 0 0,0 5,10A1,1 0 0,0 6,11A1,1 0 0,0 7,10A1,1 0 0,0 6,9M6,17A1,1 0 0,0 5,18A1,1 0 0,0 6,19A1,1 0 0,0 7,18A1,1 0 0,0 6,17M6,13A1,1 0 0,0 5,14A1,1 0 0,0 6,15A1,1 0 0,0 7,14A1,1 0 0,0 6,13Z\";\r\nvar mdiBlurLinear = \"M13,17A1,1 0 0,0 14,16A1,1 0 0,0 13,15A1,1 0 0,0 12,16A1,1 0 0,0 13,17M13,13A1,1 0 0,0 14,12A1,1 0 0,0 13,11A1,1 0 0,0 12,12A1,1 0 0,0 13,13M13,9A1,1 0 0,0 14,8A1,1 0 0,0 13,7A1,1 0 0,0 12,8A1,1 0 0,0 13,9M17,12.5A0.5,0.5 0 0,0 17.5,12A0.5,0.5 0 0,0 17,11.5A0.5,0.5 0 0,0 16.5,12A0.5,0.5 0 0,0 17,12.5M17,8.5A0.5,0.5 0 0,0 17.5,8A0.5,0.5 0 0,0 17,7.5A0.5,0.5 0 0,0 16.5,8A0.5,0.5 0 0,0 17,8.5M3,3V5H21V3M17,16.5A0.5,0.5 0 0,0 17.5,16A0.5,0.5 0 0,0 17,15.5A0.5,0.5 0 0,0 16.5,16A0.5,0.5 0 0,0 17,16.5M9,17A1,1 0 0,0 10,16A1,1 0 0,0 9,15A1,1 0 0,0 8,16A1,1 0 0,0 9,17M5,13.5A1.5,1.5 0 0,0 6.5,12A1.5,1.5 0 0,0 5,10.5A1.5,1.5 0 0,0 3.5,12A1.5,1.5 0 0,0 5,13.5M5,9.5A1.5,1.5 0 0,0 6.5,8A1.5,1.5 0 0,0 5,6.5A1.5,1.5 0 0,0 3.5,8A1.5,1.5 0 0,0 5,9.5M3,21H21V19H3M9,9A1,1 0 0,0 10,8A1,1 0 0,0 9,7A1,1 0 0,0 8,8A1,1 0 0,0 9,9M9,13A1,1 0 0,0 10,12A1,1 0 0,0 9,11A1,1 0 0,0 8,12A1,1 0 0,0 9,13M5,17.5A1.5,1.5 0 0,0 6.5,16A1.5,1.5 0 0,0 5,14.5A1.5,1.5 0 0,0 3.5,16A1.5,1.5 0 0,0 5,17.5Z\";\r\nvar mdiBlurOff = \"M3,13.5A0.5,0.5 0 0,0 2.5,14A0.5,0.5 0 0,0 3,14.5A0.5,0.5 0 0,0 3.5,14A0.5,0.5 0 0,0 3,13.5M6,17A1,1 0 0,0 5,18A1,1 0 0,0 6,19A1,1 0 0,0 7,18A1,1 0 0,0 6,17M10,20.5A0.5,0.5 0 0,0 9.5,21A0.5,0.5 0 0,0 10,21.5A0.5,0.5 0 0,0 10.5,21A0.5,0.5 0 0,0 10,20.5M3,9.5A0.5,0.5 0 0,0 2.5,10A0.5,0.5 0 0,0 3,10.5A0.5,0.5 0 0,0 3.5,10A0.5,0.5 0 0,0 3,9.5M6,13A1,1 0 0,0 5,14A1,1 0 0,0 6,15A1,1 0 0,0 7,14A1,1 0 0,0 6,13M21,13.5A0.5,0.5 0 0,0 20.5,14A0.5,0.5 0 0,0 21,14.5A0.5,0.5 0 0,0 21.5,14A0.5,0.5 0 0,0 21,13.5M10,17A1,1 0 0,0 9,18A1,1 0 0,0 10,19A1,1 0 0,0 11,18A1,1 0 0,0 10,17M2.5,5.27L6.28,9.05L6,9A1,1 0 0,0 5,10A1,1 0 0,0 6,11A1,1 0 0,0 7,10C7,9.9 6.97,9.81 6.94,9.72L9.75,12.53C9.04,12.64 8.5,13.26 8.5,14A1.5,1.5 0 0,0 10,15.5C10.74,15.5 11.36,14.96 11.47,14.25L14.28,17.06C14.19,17.03 14.1,17 14,17A1,1 0 0,0 13,18A1,1 0 0,0 14,19A1,1 0 0,0 15,18C15,17.9 14.97,17.81 14.94,17.72L18.72,21.5L20,20.23L3.77,4L2.5,5.27M14,20.5A0.5,0.5 0 0,0 13.5,21A0.5,0.5 0 0,0 14,21.5A0.5,0.5 0 0,0 14.5,21A0.5,0.5 0 0,0 14,20.5M18,7A1,1 0 0,0 19,6A1,1 0 0,0 18,5A1,1 0 0,0 17,6A1,1 0 0,0 18,7M18,11A1,1 0 0,0 19,10A1,1 0 0,0 18,9A1,1 0 0,0 17,10A1,1 0 0,0 18,11M18,15A1,1 0 0,0 19,14A1,1 0 0,0 18,13A1,1 0 0,0 17,14A1,1 0 0,0 18,15M10,7A1,1 0 0,0 11,6A1,1 0 0,0 10,5A1,1 0 0,0 9,6A1,1 0 0,0 10,7M21,10.5A0.5,0.5 0 0,0 21.5,10A0.5,0.5 0 0,0 21,9.5A0.5,0.5 0 0,0 20.5,10A0.5,0.5 0 0,0 21,10.5M10,3.5A0.5,0.5 0 0,0 10.5,3A0.5,0.5 0 0,0 10,2.5A0.5,0.5 0 0,0 9.5,3A0.5,0.5 0 0,0 10,3.5M14,3.5A0.5,0.5 0 0,0 14.5,3A0.5,0.5 0 0,0 14,2.5A0.5,0.5 0 0,0 13.5,3A0.5,0.5 0 0,0 14,3.5M13.8,11.5H14A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 14,8.5A1.5,1.5 0 0,0 12.5,10V10.2C12.61,10.87 13.13,11.39 13.8,11.5M14,7A1,1 0 0,0 15,6A1,1 0 0,0 14,5A1,1 0 0,0 13,6A1,1 0 0,0 14,7Z\";\r\nvar mdiBlurRadial = \"M14,13A1,1 0 0,0 13,14A1,1 0 0,0 14,15A1,1 0 0,0 15,14A1,1 0 0,0 14,13M14,16.5A0.5,0.5 0 0,0 13.5,17A0.5,0.5 0 0,0 14,17.5A0.5,0.5 0 0,0 14.5,17A0.5,0.5 0 0,0 14,16.5M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M17,9.5A0.5,0.5 0 0,0 16.5,10A0.5,0.5 0 0,0 17,10.5A0.5,0.5 0 0,0 17.5,10A0.5,0.5 0 0,0 17,9.5M17,13.5A0.5,0.5 0 0,0 16.5,14A0.5,0.5 0 0,0 17,14.5A0.5,0.5 0 0,0 17.5,14A0.5,0.5 0 0,0 17,13.5M14,7.5A0.5,0.5 0 0,0 14.5,7A0.5,0.5 0 0,0 14,6.5A0.5,0.5 0 0,0 13.5,7A0.5,0.5 0 0,0 14,7.5M14,9A1,1 0 0,0 13,10A1,1 0 0,0 14,11A1,1 0 0,0 15,10A1,1 0 0,0 14,9M10,7.5A0.5,0.5 0 0,0 10.5,7A0.5,0.5 0 0,0 10,6.5A0.5,0.5 0 0,0 9.5,7A0.5,0.5 0 0,0 10,7.5M7,13.5A0.5,0.5 0 0,0 6.5,14A0.5,0.5 0 0,0 7,14.5A0.5,0.5 0 0,0 7.5,14A0.5,0.5 0 0,0 7,13.5M10,16.5A0.5,0.5 0 0,0 9.5,17A0.5,0.5 0 0,0 10,17.5A0.5,0.5 0 0,0 10.5,17A0.5,0.5 0 0,0 10,16.5M7,9.5A0.5,0.5 0 0,0 6.5,10A0.5,0.5 0 0,0 7,10.5A0.5,0.5 0 0,0 7.5,10A0.5,0.5 0 0,0 7,9.5M10,13A1,1 0 0,0 9,14A1,1 0 0,0 10,15A1,1 0 0,0 11,14A1,1 0 0,0 10,13M10,9A1,1 0 0,0 9,10A1,1 0 0,0 10,11A1,1 0 0,0 11,10A1,1 0 0,0 10,9Z\";\r\nvar mdiBolnisiCross = \"M22,7L21.5,6.5C19.93,8 18.47,9.4 16.93,10.18C15.5,10.91 14.44,10.91 13,11C13.09,9.56 13.09,8.5 13.82,7.07C14.6,5.53 16,4.07 17.5,2.5L17,2C15.32,3.23 13.64,3.83 12,3.83C10.36,3.83 8.68,3.23 7,2L6.5,2.5C8,4.07 9.4,5.53 10.18,7.07C10.91,8.5 10.91,9.56 11,11C9.56,10.91 8.5,10.91 7.07,10.18C5.53,9.4 4.06,8 2.5,6.5L2,7C3.23,8.68 3.83,10.36 3.83,12C3.83,13.64 3.23,15.32 2,17L2.5,17.5C4.07,16 5.53,14.6 7.07,13.82C8.5,13.09 9.56,13.09 11,13C10.91,14.44 10.91,15.5 10.18,16.93C9.4,18.47 8,19.93 6.5,21.5L7,22C8.68,20.77 10.36,20.17 12,20.17C13.64,20.17 15.32,20.77 17,22L17.5,21.5C16,19.93 14.6,18.47 13.82,16.93C13.09,15.5 13.09,14.44 13,13C14.44,13.09 15.5,13.09 16.93,13.82C18.47,14.6 19.93,16 21.5,17.5L22,17C20.77,15.32 20.17,13.64 20.17,12C20.17,10.36 20.77,8.68 22,7Z\";\r\nvar mdiBolt = \"M14,17.7V21H10V20.3L14,17.7M17,3H7V6H17V3M15,7L14,7.7V7H10V10.3L9,11V12L15,8.1V7M15,11L14,11.7V9.7L10,12.4V14.4L9,15V16L15,12.1V11M15,15L14,15.7V13.7L10,16.4V18.4L9,19V20L15,16.1V15Z\";\r\nvar mdiBomb = \"M11.25,6A3.25,3.25 0 0,1 14.5,2.75A3.25,3.25 0 0,1 17.75,6C17.75,6.42 18.08,6.75 18.5,6.75C18.92,6.75 19.25,6.42 19.25,6V5.25H20.75V6A2.25,2.25 0 0,1 18.5,8.25A2.25,2.25 0 0,1 16.25,6A1.75,1.75 0 0,0 14.5,4.25A1.75,1.75 0 0,0 12.75,6H14V7.29C16.89,8.15 19,10.83 19,14A7,7 0 0,1 12,21A7,7 0 0,1 5,14C5,10.83 7.11,8.15 10,7.29V6H11.25M22,6H24V7H22V6M19,4V2H20V4H19M20.91,4.38L22.33,2.96L23.04,3.67L21.62,5.09L20.91,4.38Z\";\r\nvar mdiBombOff = \"M14.5,2.75C12.7,2.75 11.25,4.2 11.25,6H10V7.29C9.31,7.5 8.67,7.81 8.08,8.2L17.79,17.91C18.58,16.76 19,15.39 19,14C19,10.83 16.89,8.15 14,7.29V6H12.75A1.75,1.75 0 0,1 14.5,4.25A1.75,1.75 0 0,1 16.25,6A2.25,2.25 0 0,0 18.5,8.25C19.74,8.25 20.74,7.24 20.74,6V5.25H19.25V6C19.25,6.42 18.91,6.75 18.5,6.75C18.08,6.75 17.75,6.42 17.75,6C17.75,4.2 16.29,2.75 14.5,2.75M3.41,6.36L2,7.77L5.55,11.32C5.2,12.14 5,13.04 5,14C5,17.86 8.13,21 12,21C12.92,21 13.83,20.81 14.68,20.45L18.23,24L19.64,22.59L3.41,6.36Z\";\r\nvar mdiBone = \"M8,14A3,3 0 0,1 5,17A3,3 0 0,1 2,14C2,13.23 2.29,12.53 2.76,12C2.29,11.47 2,10.77 2,10A3,3 0 0,1 5,7A3,3 0 0,1 8,10C9.33,10.08 10.67,10.17 12,10.17C13.33,10.17 14.67,10.08 16,10A3,3 0 0,1 19,7A3,3 0 0,1 22,10C22,10.77 21.71,11.47 21.24,12C21.71,12.53 22,13.23 22,14A3,3 0 0,1 19,17A3,3 0 0,1 16,14C14.67,13.92 13.33,13.83 12,13.83C10.67,13.83 9.33,13.92 8,14Z\";\r\nvar mdiBook = \"M18,22A2,2 0 0,0 20,20V4C20,2.89 19.1,2 18,2H12V9L9.5,7.5L7,9V2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18Z\";\r\nvar mdiBookAccount = \"M18 2H12V9L9.5 7.5L7 9V2H6A2 2 0 0 0 4 4V20A2 2 0 0 0 6 22H18A2 2 0 0 0 20 20V4A2 2 0 0 0 18 2M14 12A2 2 0 1 1 12 14A2 2 0 0 1 14 12M18 20H10V19C10 17.67 12.67 17 14 17S18 17.67 18 19Z\";\r\nvar mdiBookAccountOutline = \"M18 2A2 2 0 0 1 20 4V20A2 2 0 0 1 18 22H6A2 2 0 0 1 4 20V4A2 2 0 0 1 6 2H18M18 4H13V9L10.5 6.7L8 9V4H6V20H18M13 11A2 2 0 1 1 11 13A2 2 0 0 1 13 11M17 19H9V18C9 16.67 11.67 16 13 16S17 16.67 17 18V19\";\r\nvar mdiBookAlphabet = \"M5.81,2C4.83,2.09 4,3 4,4V20C4,21.05 4.95,22 6,22H18C19.05,22 20,21.05 20,20V4C20,2.89 19.1,2 18,2H12V9L9.5,7.5L7,9V2H6C5.94,2 5.87,2 5.81,2M12,13H13A1,1 0 0,1 14,14V18H13V16H12V18H11V14A1,1 0 0,1 12,13M12,14V15H13V14H12M15,15H18V16L16,19H18V20H15V19L17,16H15V15Z\";\r\nvar mdiBookCheck = \"M16.75 22.16L14 19.16L15.16 18L16.75 19.59L20.34 16L21.5 17.41L16.75 22.16M6 22C4.89 22 4 21.1 4 20V4C4 2.89 4.89 2 6 2H7V9L9.5 7.5L12 9V2H18C19.1 2 20 2.89 20 4V13.34C19.37 13.12 18.7 13 18 13C14.69 13 12 15.69 12 19C12 20.09 12.29 21.12 12.8 22H6Z\";\r\nvar mdiBookCheckOutline = \"M16.75 22.16L14 19.16L15.16 18L16.75 19.59L20.34 16L21.5 17.41L16.75 22.16M18 2C19.1 2 20 2.9 20 4V13.34C19.37 13.12 18.7 13 18 13V4H13V12L10.5 9.75L8 12V4H6V20H12.08C12.2 20.72 12.45 21.39 12.8 22H6C4.9 22 4 21.1 4 20V4C4 2.9 4.9 2 6 2H18Z\";\r\nvar mdiBookCross = \"M5.81,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V20C20,21.05 19.05,22 18,22H6C4.95,22 4,21.05 4,20V4C4,3 4.83,2.09 5.81,2M13,10V13H10V15H13V20H15V15H18V13H15V10H13Z\";\r\nvar mdiBookInformationVariant = \"M18 2H12V9L9.5 7.5L7 9V2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V4C20 2.89 19.1 2 18 2M17.68 18.41C17.57 18.5 16.47 19.25 16.05 19.5C15.63 19.79 14 20.72 14.26 18.92C14.89 15.28 16.11 13.12 14.65 14.06C14.27 14.29 14.05 14.43 13.91 14.5C13.78 14.61 13.79 14.6 13.68 14.41S13.53 14.23 13.67 14.13C13.67 14.13 15.9 12.34 16.72 12.28C17.5 12.21 17.31 13.17 17.24 13.61C16.78 15.46 15.94 18.15 16.07 18.54C16.18 18.93 17 18.31 17.44 18C17.44 18 17.5 17.93 17.61 18.05C17.72 18.22 17.83 18.3 17.68 18.41M16.97 11.06C16.4 11.06 15.94 10.6 15.94 10.03C15.94 9.46 16.4 9 16.97 9C17.54 9 18 9.46 18 10.03C18 10.6 17.54 11.06 16.97 11.06Z\";\r\nvar mdiBookLock = \"M18,2H12V9L9.5,7.5L7,9V2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2M18,20H10V16H11V15A3,3 0 0,1 14,12A3,3 0 0,1 17,15V16H18V20M15,15V16H13V15A1,1 0 0,1 14,14A1,1 0 0,1 15,15Z\";\r\nvar mdiBookLockOpen = \"M18,2H12V9L9.5,7.5L7,9V2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2M18,20H10V16H11V14A3,3 0 0,1 14,11A3,3 0 0,1 17,14H15A1,1 0 0,0 14,13A1,1 0 0,0 13,14V16H18V20Z\";\r\nvar mdiBookMinus = \"M18,22H6A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22M18,18V16H12V18H18Z\";\r\nvar mdiBookMinusMultiple = \"M13.09 20H5V6H3V20C3 21.11 3.9 22 5 22H13.81C13.44 21.39 13.2 20.71 13.09 20M19 2H14V7L12 5.5L10 7V2H9C7.9 2 7 2.9 7 4V16C7 17.11 7.9 18 9 18H13.09C13.64 14.73 16.74 12.53 20 13.08C20.34 13.14 20.68 13.23 21 13.34V4C21 2.9 20.11 2 19 2M23 18V20H15V18H23Z\";\r\nvar mdiBookMinusMultipleOutline = \"M13.09 20H5V6H3V20C3 21.11 3.9 22 5 22H13.81C13.44 21.39 13.2 20.71 13.09 20M19 2H9C7.9 2 7 2.9 7 4V16C7 17.11 7.9 18 9 18H13.09C13.2 17.29 13.44 16.61 13.81 16H9V4H11V10L13.5 7.75L16 10V4H19V13C19.68 13 20.36 13.11 21 13.34V4C21 2.9 20.11 2 19 2M23 18V20H15V18H23Z\";\r\nvar mdiBookMultiple = \"M19,18H9A2,2 0 0,1 7,16V4A2,2 0 0,1 9,2H10V7L12,5.5L14,7V2H19A2,2 0 0,1 21,4V16A2,2 0 0,1 19,18M17,20V22H5A2,2 0 0,1 3,20V6H5V20H17Z\";\r\nvar mdiBookMultipleOutline = \"M19 2A2 2 0 0 1 21 4V16A2 2 0 0 1 19 18H9A2 2 0 0 1 7 16V4A2 2 0 0 1 9 2H19M19 4H16V10L13.5 7.75L11 10V4H9V16H19M3 20A2 2 0 0 0 5 22H17V20H5V6H3Z\";\r\nvar mdiBookMusic = \"M18,22H6A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22M13,15A2,2 0 0,0 11,17A2,2 0 0,0 13,19A2,2 0 0,0 15,17V12H18V10H14V15.27C13.71,15.1 13.36,15 13,15Z\";\r\nvar mdiBookOpen = \"M13,12H20V13.5H13M13,9.5H20V11H13M13,14.5H20V16H13M21,4H3A2,2 0 0,0 1,6V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V6A2,2 0 0,0 21,4M21,19H12V6H21\";\r\nvar mdiBookOpenBlankVariant = \"M21,5C19.89,4.65 18.67,4.5 17.5,4.5C15.55,4.5 13.45,4.9 12,6C10.55,4.9 8.45,4.5 6.5,4.5C4.55,4.5 2.45,4.9 1,6V20.65C1,20.9 1.25,21.15 1.5,21.15C1.6,21.15 1.65,21.1 1.75,21.1C3.1,20.45 5.05,20 6.5,20C8.45,20 10.55,20.4 12,21.5C13.35,20.65 15.8,20 17.5,20C19.15,20 20.85,20.3 22.25,21.05C22.35,21.1 22.4,21.1 22.5,21.1C22.75,21.1 23,20.85 23,20.6V6C22.4,5.55 21.75,5.25 21,5M21,18.5C19.9,18.15 18.7,18 17.5,18C15.8,18 13.35,18.65 12,19.5V8C13.35,7.15 15.8,6.5 17.5,6.5C18.7,6.5 19.9,6.65 21,7V18.5Z\";\r\nvar mdiBookOpenOutline = \"M21,4H3A2,2 0 0,0 1,6V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V6A2,2 0 0,0 21,4M3,19V6H11V19H3M21,19H13V6H21V19M14,9.5H20V11H14V9.5M14,12H20V13.5H14V12M14,14.5H20V16H14V14.5Z\";\r\nvar mdiBookOpenPageVariant = \"M19 2L14 6.5V17.5L19 13V2M6.5 5C4.55 5 2.45 5.4 1 6.5V21.16C1 21.41 1.25 21.66 1.5 21.66C1.6 21.66 1.65 21.59 1.75 21.59C3.1 20.94 5.05 20.5 6.5 20.5C8.45 20.5 10.55 20.9 12 22C13.35 21.15 15.8 20.5 17.5 20.5C19.15 20.5 20.85 20.81 22.25 21.56C22.35 21.61 22.4 21.59 22.5 21.59C22.75 21.59 23 21.34 23 21.09V6.5C22.4 6.05 21.75 5.75 21 5.5V19C19.9 18.65 18.7 18.5 17.5 18.5C15.8 18.5 13.35 19.15 12 20V6.5C10.55 5.4 8.45 5 6.5 5Z\";\r\nvar mdiBookOpenPageVariantOutline = \"M19 1L14 6V17L19 12.5V1M21 5V18.5C19.9 18.15 18.7 18 17.5 18C15.8 18 13.35 18.65 12 19.5V6C10.55 4.9 8.45 4.5 6.5 4.5C4.55 4.5 2.45 4.9 1 6V20.65C1 20.9 1.25 21.15 1.5 21.15C1.6 21.15 1.65 21.1 1.75 21.1C3.1 20.45 5.05 20 6.5 20C8.45 20 10.55 20.4 12 21.5C13.35 20.65 15.8 20 17.5 20C19.15 20 20.85 20.3 22.25 21.05C22.35 21.1 22.4 21.1 22.5 21.1C22.75 21.1 23 20.85 23 20.6V6C22.4 5.55 21.75 5.25 21 5M10 18.41C8.75 18.09 7.5 18 6.5 18C5.44 18 4.18 18.19 3 18.5V7.13C3.91 6.73 5.14 6.5 6.5 6.5C7.86 6.5 9.09 6.73 10 7.13V18.41Z\";\r\nvar mdiBookOpenVariant = \"M17.5 14.33C18.29 14.33 19.13 14.41 20 14.57V16.07C19.38 15.91 18.54 15.83 17.5 15.83C15.6 15.83 14.11 16.16 13 16.82V15.13C14.17 14.6 15.67 14.33 17.5 14.33M13 12.46C14.29 11.93 15.79 11.67 17.5 11.67C18.29 11.67 19.13 11.74 20 11.9V13.4C19.38 13.24 18.54 13.16 17.5 13.16C15.6 13.16 14.11 13.5 13 14.15M17.5 10.5C15.6 10.5 14.11 10.82 13 11.5V9.84C14.23 9.28 15.73 9 17.5 9C18.29 9 19.13 9.08 20 9.23V10.78C19.26 10.59 18.41 10.5 17.5 10.5M21 18.5V7C19.96 6.67 18.79 6.5 17.5 6.5C15.45 6.5 13.62 7 12 8V19.5C13.62 18.5 15.45 18 17.5 18C18.69 18 19.86 18.16 21 18.5M17.5 4.5C19.85 4.5 21.69 5 23 6V20.56C23 20.68 22.95 20.8 22.84 20.91C22.73 21 22.61 21.08 22.5 21.08C22.39 21.08 22.31 21.06 22.25 21.03C20.97 20.34 19.38 20 17.5 20C15.45 20 13.62 20.5 12 21.5C10.66 20.5 8.83 20 6.5 20C4.84 20 3.25 20.36 1.75 21.07C1.72 21.08 1.68 21.08 1.63 21.1C1.59 21.11 1.55 21.12 1.5 21.12C1.39 21.12 1.27 21.08 1.16 21C1.05 20.89 1 20.78 1 20.65V6C2.34 5 4.18 4.5 6.5 4.5C8.83 4.5 10.66 5 12 6C13.34 5 15.17 4.5 17.5 4.5Z\";\r\nvar mdiBookOutline = \"M18,2A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H18M18,4H13V12L10.5,9.75L8,12V4H6V20H18V4Z\";\r\nvar mdiBookPlay = \"M6,22A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V11.5C19.23,11.18 18.39,11 17.5,11A6.5,6.5 0 0,0 11,17.5C11,19.25 11.69,20.83 12.81,22H6M17.5,13C20,13 22,15 22,17.5C22,20 20,22 17.5,22C15,22 13,20 13,17.5C13,15 15,13 17.5,13M16.07,15V20L20,17.5L16.07,15Z\";\r\nvar mdiBookPlayOutline = \"M17,16L22,19L17,22V16M18,2A2,2 0 0,1 20,4V15.42L18,14.27V4H13V12L10.5,9.75L8,12V4H6V20H15V22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H18Z\";\r\nvar mdiBookPlus = \"M18,22H6A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22M14,20H16V18H18V16H16V14H14V16H12V18H14V20Z\";\r\nvar mdiBookPlusMultiple = \"M13.09 20H5V6H3V20A2 2 0 0 0 5 22H13.81A5.5 5.5 0 0 1 13.09 20M19 2H14V7L12 5.5L10 7V2H9A2 2 0 0 0 7 4V16A2 2 0 0 0 9 18H13.09A6 6 0 0 1 21 13.34V4A2 2 0 0 0 19 2M20 15V18H23V20H20V23H18V20H15V18H18V15Z\";\r\nvar mdiBookPlusMultipleOutline = \"M13.09 20H5V6H3V20A2 2 0 0 0 5 22H13.81A5.5 5.5 0 0 1 13.09 20M19 2H9A2 2 0 0 0 7 4V16A2 2 0 0 0 9 18H13.09A5.5 5.5 0 0 1 13.81 16H9V4H11V10L13.5 7.75L16 10V4H19V13A6 6 0 0 1 21 13.34V4A2 2 0 0 0 19 2M20 15V18H23V20H20V23H18V20H15V18H18V15Z\";\r\nvar mdiBookRemove = \"M18,22H6A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22M16.41,19.83L17.83,18.41L16.41,17L17.83,15.59L16.41,14.17L15,15.59L13.59,14.17L12.17,15.59L13.59,17L12.17,18.41L13.59,19.83L15,18.41L16.41,19.83Z\";\r\nvar mdiBookRemoveMultiple = \"M13.09 20H5V6H3V20A2 2 0 0 0 5 22H13.81A5.5 5.5 0 0 1 13.09 20M19 2H14V7L12 5.5L10 7V2H9A2 2 0 0 0 7 4V16A2 2 0 0 0 9 18H13.09A6 6 0 0 1 21 13.34V4A2 2 0 0 0 19 2M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.46 21.12L17.59 19L15.46 16.88L16.88 15.46L19 17.59L21.12 15.46Z\";\r\nvar mdiBookRemoveMultipleOutline = \"M13.09 20H5V6H3V20A2 2 0 0 0 5 22H13.81A5.5 5.5 0 0 1 13.09 20M19 2H9A2 2 0 0 0 7 4V16A2 2 0 0 0 9 18H13.09A5.5 5.5 0 0 1 13.81 16H9V4H11V10L13.5 7.75L16 10V4H19V13A6 6 0 0 1 21 13.34V4A2 2 0 0 0 19 2M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.46 21.12L17.59 19L15.46 16.88L16.88 15.46L19 17.59L21.12 15.46Z\";\r\nvar mdiBookSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M6,22A2,2 0 0,1 4,20V4C4,2.89 4.9,2 6,2H7V9L9.5,7.5L12,9V2H18A2,2 0 0,1 20,4V11.81C18.83,10.69 17.25,10 15.5,10A6.5,6.5 0 0,0 9,16.5C9,18.81 10.21,20.85 12.03,22H6Z\";\r\nvar mdiBookSearchOutline = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M13,4V12L10.5,9.75L8,12V4H6V20H10C10.54,20.81 11.23,21.5 12.03,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H18A2,2 0 0,1 20,4V11.81C19.42,11.26 18.75,10.81 18,10.5V4H13Z\";\r\nvar mdiBookVariant = \"M6,4H11V12L8.5,10.5L6,12M18,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2Z\";\r\nvar mdiBookVariantMultiple = \"M4,6H2V20A2,2 0 0,0 4,22H18V20H4V6M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M20,12L17.5,10.5L15,12V4H20V12Z\";\r\nvar mdiBookmark = \"M17,3H7A2,2 0 0,0 5,5V21L12,18L19,21V5C19,3.89 18.1,3 17,3Z\";\r\nvar mdiBookmarkCheck = \"M17,3A2,2 0 0,1 19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17M11,14L17.25,7.76L15.84,6.34L11,11.18L8.41,8.59L7,10L11,14Z\";\r\nvar mdiBookmarkCheckOutline = \"M9.47 9.65L8.06 11.07L11 14L16.19 8.82L14.78 7.4L11 11.18M17 3H7C5.9 3 5 3.9 5 5L5 21L12 18L19 21V5C19 3.9 18.1 3 17 3M17 18L12 15.82L7 18V5H17Z\";\r\nvar mdiBookmarkMinus = \"M17,3H7A2,2 0 0,0 5,5V21L12,18L19,21V5A2,2 0 0,0 17,3M15,11H9V9H15V11Z\";\r\nvar mdiBookmarkMinusOutline = \"M9,11V9H15V11H9M19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17C18.11,3 19,3.9 19,5M17,5H7V18L12,15.82L17,18V5Z\";\r\nvar mdiBookmarkMultiple = \"M15,5A2,2 0 0,1 17,7V23L10,20L3,23V7C3,5.89 3.9,5 5,5H15M9,1H19A2,2 0 0,1 21,3V19L19,18.13V3H7A2,2 0 0,1 9,1Z\";\r\nvar mdiBookmarkMultipleOutline = \"M9,1H19A2,2 0 0,1 21,3V19L19,18.13V3H7A2,2 0 0,1 9,1M15,20V7H5V20L10,17.82L15,20M15,5C16.11,5 17,5.9 17,7V23L10,20L3,23V7A2,2 0 0,1 5,5H15Z\";\r\nvar mdiBookmarkMusic = \"M17,3A2,2 0 0,1 19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17M11,11A2,2 0 0,0 9,13A2,2 0 0,0 11,15A2,2 0 0,0 13,13V8H16V6H12V11.27C11.71,11.1 11.36,11 11,11Z\";\r\nvar mdiBookmarkMusicOutline = \"M7 3C5.9 3 5 3.9 5 5V21L12 18L19 21V5C19 3.89 18.1 3 17 3H7M7 5H17V18L12 15.82L7 18V5M12 6V11.3C11.7 11.1 11.4 11 11 11C9.9 11 9 11.9 9 13C9 14.11 9.9 15 11 15C12.11 15 13 14.11 13 13V8H15V6H12Z\";\r\nvar mdiBookmarkOff = \"M20,20.72L18.73,22L16.78,20.05L12,18L5,21V8.27L2,5.27L3.28,4L20,20.72M19,17.16V5C19,3.89 18.1,3 17,3H7C6.41,3 5.89,3.27 5.5,3.68L19,17.16Z\";\r\nvar mdiBookmarkOffOutline = \"M3.28,4L2,5.27L5,8.27V21L12,18L16.78,20.05L18.73,22L20,20.72L3.28,4M7,18V10.27L13,16.25L12,15.82L7,18M7,5.16L5.5,3.67C5.88,3.26 6.41,3 7,3H17A2,2 0 0,1 19,5V17.16L17,15.16V5H7V5.16Z\";\r\nvar mdiBookmarkOutline = \"M17,18L12,15.82L7,18V5H17M17,3H7A2,2 0 0,0 5,5V21L12,18L19,21V5C19,3.89 18.1,3 17,3Z\";\r\nvar mdiBookmarkPlus = \"M17,3A2,2 0 0,1 19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17M11,7V9H9V11H11V13H13V11H15V9H13V7H11Z\";\r\nvar mdiBookmarkPlusOutline = \"M17,18V5H7V18L12,15.82L17,18M17,3A2,2 0 0,1 19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17M11,7H13V9H15V11H13V13H11V11H9V9H11V7Z\";\r\nvar mdiBookmarkRemove = \"M17,3A2,2 0 0,1 19,5V21L12,18L5,21V5C5,3.89 5.9,3 7,3H17M8.17,8.58L10.59,11L8.17,13.41L9.59,14.83L12,12.41L14.41,14.83L15.83,13.41L13.41,11L15.83,8.58L14.41,7.17L12,9.58L9.59,7.17L8.17,8.58Z\";\r\nvar mdiBookmarkRemoveOutline = \"M7 3C5.9 3 5 3.9 5 5V21L12 18L19 21V5C19 3.89 18.1 3 17 3H7M7 5H17V18L12 15.82L7 18V5M9.88 7.47L8.47 8.88L10.59 11L8.47 13.12L9.88 14.54L12 12.42L14.12 14.53L15.54 13.12L13.42 11L15.53 8.88L14.12 7.47L12 9.59L9.88 7.47Z\";\r\nvar mdiBookshelf = \"M9 3V18H12V3H9M12 5L16 18L19 17L15 4L12 5M5 5V18H8V5H5M3 19V21H21V19H3Z\";\r\nvar mdiBoomGate = \"M20,9H8.22C7.11,7.77 5.21,7.68 4,8.8C3.36,9.36 3,10.16 3,11V20A1,1 0 0,0 2,21V22H10V21A1,1 0 0,0 9,20V13H20A2,2 0 0,0 22,11A2,2 0 0,0 20,9M6,12.5A1.5,1.5 0 0,1 4.5,11A1.5,1.5 0 0,1 6,9.5A1.5,1.5 0 0,1 7.5,11A1.5,1.5 0 0,1 6,12.5M10.5,12L9,10H10.5L12,12H10.5M14.5,12L13,10H14.5L16,12H14.5M18.5,12L17,10H18.5L20,12H18.5Z\";\r\nvar mdiBoomGateAlert = \"M19.9 3C19.3 2 18.1 1.7 17.2 2.3L6.9 8.2C6.6 8.1 6.3 8 6 8C4.3 8 3 9.3 3 11V20C2.4 20 2 20.4 2 21V22H10V21C10 20.4 9.6 20 9 20V11.6L19.1 5.8C20.1 5.2 20.4 4 19.9 3M6 12.5C5.2 12.5 4.5 11.8 4.5 11S5.2 9.5 6 9.5 7.5 10.2 7.5 11 6.8 12.5 6 12.5M10.4 9.6L8.1 8.6L9.4 7.8L11.7 8.8L10.4 9.6M13.9 7.6L11.6 6.6L12.9 5.8L15.2 6.8L13.9 7.6M17.3 5.6L15 4.6L16.3 3.8L18.6 4.8L17.3 5.6M20 18H18V20H20V18M20 10H18V16H20V10Z\";\r\nvar mdiBoomGateAlertOutline = \"M19.9 3C19.3 2 18.1 1.7 17.2 2.3L6.9 8.2C6.6 8.1 6.3 8 6 8C4.3 8 3 9.3 3 11V20C2.4 20 2 20.4 2 21V22H10V21C10 20.4 9.6 20 9 20V11.6L19.1 5.8C20.1 5.2 20.4 4 19.9 3M7.5 20H4.5V13.6C5.4 14.1 6.6 14.1 7.5 13.6V20M6 12.5C5.2 12.5 4.5 11.8 4.5 11S5.2 9.5 6 9.5 7.5 10.2 7.5 11 6.8 12.5 6 12.5M10.4 9.6L8.1 8.6L9.4 7.8L11.7 8.8L10.4 9.6M13.9 7.6L11.6 6.6L12.9 5.8L15.2 6.8L13.9 7.6M17.3 5.6L15 4.6L16.3 3.8L18.6 4.8L17.3 5.6M20 16H18V10H20V16M20 20H18V18H20V20Z\";\r\nvar mdiBoomGateDown = \"M19.86,3C19.31,2.04 18.09,1.71 17.12,2.27L6.92,8.16C6.62,8.06 6.31,8 6,8A3,3 0 0,0 3,11V20A1,1 0 0,0 2,21V22H10V21A1,1 0 0,0 9,20V11.58L19.12,5.73C20.08,5.18 20.41,3.96 19.86,3M6,12.5A1.5,1.5 0 0,1 4.5,11A1.5,1.5 0 0,1 6,9.5A1.5,1.5 0 0,1 7.5,11A1.5,1.5 0 0,1 6,12.5M10.4,9.62L8.1,8.62L9.4,7.87L11.7,8.87L10.4,9.62M13.86,7.62L11.56,6.62L12.86,5.87L15.16,6.87L13.86,7.62M17.33,5.62L15.03,4.62L16.33,3.87L18.62,4.87L17.33,5.62M17,20L12,15H15V11H19V15H22L17,20\";\r\nvar mdiBoomGateDownOutline = \"M19.86,3C20.41,3.96 20.08,5.18 19.12,5.73L9,11.58V20A1,1 0 0,1 10,21V22H2V21A1,1 0 0,1 3,20V11A3,3 0 0,1 6,8C6.31,8 6.62,8.06 6.92,8.16L17.12,2.27C18.09,1.71 19.31,2.04 19.86,3M7.5,20V13.6C6.57,14.14 5.43,14.14 4.5,13.6V20H7.5M6,12.5A1.5,1.5 0 0,0 7.5,11A1.5,1.5 0 0,0 6,9.5A1.5,1.5 0 0,0 4.5,11A1.5,1.5 0 0,0 6,12.5M10.4,9.62L11.7,8.87L9.4,7.87L8.1,8.62L10.4,9.62M13.86,7.62L15.16,6.87L12.86,5.87L11.56,6.62L13.86,7.62M17.33,5.62L18.62,4.87L16.33,3.87L15.03,4.62L17.33,5.62M16,11.16H18V16.17L21,16.16L17,20L13,16.16L16,16.17V11.16Z\";\r\nvar mdiBoomGateOutline = \"M20,9H8.22C7.11,7.77 5.21,7.68 4,8.8C3.36,9.36 3,10.16 3,11V20A1,1 0 0,0 2,21V22H10V21A1,1 0 0,0 9,20V13H20A2,2 0 0,0 22,11A2,2 0 0,0 20,9M7.5,20H4.5V13.6C5.43,14.14 6.57,14.14 7.5,13.6V20M6,12.5A1.5,1.5 0 0,1 4.5,11A1.5,1.5 0 0,1 6,9.5A1.5,1.5 0 0,1 7.5,11A1.5,1.5 0 0,1 6,12.5M10.5,12L9,10H10.5L12,12H10.5M14.5,12L13,10H14.5L16,12H14.5M18.5,12L17,10H18.5L20,12H18.5Z\";\r\nvar mdiBoomGateUp = \"M19.86,3C19.31,2.04 18.09,1.71 17.12,2.27L6.92,8.16C6.62,8.06 6.31,8 6,8A3,3 0 0,0 3,11V20A1,1 0 0,0 2,21V22H10V21A1,1 0 0,0 9,20V11.58L19.12,5.73C20.08,5.18 20.41,3.96 19.86,3M6,12.5A1.5,1.5 0 0,1 4.5,11A1.5,1.5 0 0,1 6,9.5A1.5,1.5 0 0,1 7.5,11A1.5,1.5 0 0,1 6,12.5M10.4,9.62L8.1,8.62L9.4,7.87L11.7,8.87L10.4,9.62M13.86,7.62L11.56,6.62L12.86,5.87L15.16,6.87L13.86,7.62M17.33,5.62L15.03,4.62L16.33,3.87L18.62,4.87L17.33,5.62M17,11L22,16H19V20H15V16H12L17,11\";\r\nvar mdiBoomGateUpOutline = \"M19.86,3C20.41,3.96 20.08,5.18 19.12,5.73L9,11.58V20A1,1 0 0,1 10,21V22H2V21A1,1 0 0,1 3,20V11A3,3 0 0,1 6,8C6.31,8 6.62,8.06 6.92,8.16L17.12,2.27C18.09,1.71 19.31,2.04 19.86,3M7.5,20V13.6C6.57,14.14 5.43,14.14 4.5,13.6V20H7.5M6,12.5A1.5,1.5 0 0,0 7.5,11A1.5,1.5 0 0,0 6,9.5A1.5,1.5 0 0,0 4.5,11A1.5,1.5 0 0,0 6,12.5M10.4,9.62L11.7,8.87L9.4,7.87L8.1,8.62L10.4,9.62M13.86,7.62L15.16,6.87L12.86,5.87L11.56,6.62L13.86,7.62M17.33,5.62L18.62,4.87L16.33,3.87L15.03,4.62L17.33,5.62M16,20V15H13L17,11.16L21,15H18V20H16Z\";\r\nvar mdiBoombox = \"M7,5L5,7V8H3A1,1 0 0,0 2,9V17A1,1 0 0,0 3,18H21A1,1 0 0,0 22,17V9A1,1 0 0,0 21,8H19V7L17,5H7M7,7H17V8H7V7M11,9H13A0.5,0.5 0 0,1 13.5,9.5A0.5,0.5 0 0,1 13,10H11A0.5,0.5 0 0,1 10.5,9.5A0.5,0.5 0 0,1 11,9M7.5,10.5A3,3 0 0,1 10.5,13.5A3,3 0 0,1 7.5,16.5A3,3 0 0,1 4.5,13.5A3,3 0 0,1 7.5,10.5M16.5,10.5A3,3 0 0,1 19.5,13.5A3,3 0 0,1 16.5,16.5A3,3 0 0,1 13.5,13.5A3,3 0 0,1 16.5,10.5M7.5,12A1.5,1.5 0 0,0 6,13.5A1.5,1.5 0 0,0 7.5,15A1.5,1.5 0 0,0 9,13.5A1.5,1.5 0 0,0 7.5,12M16.5,12A1.5,1.5 0 0,0 15,13.5A1.5,1.5 0 0,0 16.5,15A1.5,1.5 0 0,0 18,13.5A1.5,1.5 0 0,0 16.5,12Z\";\r\nvar mdiBoomerang = \"M10 2H4C2.9 2 2 2.9 2 4S2.9 6 4 6H8L10 2M18 2C20.2 2 22 3.8 22 6V12L18 14C18 9.6 14.4 6 10 6L12 2H18M18 20V16L22 14V20C22 21.1 21.1 22 20 22S18 21.1 18 20Z\";\r\nvar mdiBootstrap = \"M11.79 11.5H9.72V8.19H12.19C13.45 8.19 14.15 8.75 14.15 9.78C14.15 10.9 13.32 11.5 11.79 11.5M12.16 12.63H9.72V16.27L12.28 16.27C13.84 16.27 14.66 15.64 14.66 14.44S13.81 12.63 12.16 12.63M22 5.31V18.69C22 20.5 20.5 22 18.69 22H5.31C3.5 22 2 20.5 2 18.69V5.31C2 3.5 3.5 2 5.31 2H18.69C20.5 2 22 3.5 22 5.31M16 14.5C16 13.12 15.08 12.13 13.67 11.95V11.89C14.67 11.71 15.46 10.71 15.46 9.63C15.46 8.08 14.26 7.05 12.5 7.05H8.43V17.41H12.47C14.68 17.41 16 16.32 16 14.5Z\";\r\nvar mdiBorderAll = \"M19,11H13V5H19M19,19H13V13H19M11,11H5V5H11M11,19H5V13H11M3,21H21V3H3V21Z\";\r\nvar mdiBorderAllVariant = \"M3,21V3H21V21H3M5,5V19H19V5H5Z\";\r\nvar mdiBorderBottom = \"M5,15H3V17H5M3,21H21V19H3M5,11H3V13H5M19,9H21V7H19M19,5H21V3H19M5,7H3V9H5M19,17H21V15H19M19,13H21V11H19M17,3H15V5H17M13,3H11V5H13M17,11H15V13H17M13,7H11V9H13M5,3H3V5H5M13,11H11V13H13M9,3H7V5H9M13,15H11V17H13M9,11H7V13H9V11Z\";\r\nvar mdiBorderBottomVariant = \"M5,15H3V17H5M3,21H21V19H3M5,11H3V13H5M19,9H21V7H19M19,5H21V3H19M5,7H3V9H5M19,17H21V15H19M19,13H21V11H19M17,3H15V5H17M13,3H11V5H13M5,3H3V5H5M9,3H7V5H9\";\r\nvar mdiBorderColor = \"M20.71,4.04C21.1,3.65 21.1,3 20.71,2.63L18.37,0.29C18,-0.1 17.35,-0.1 16.96,0.29L15,2.25L18.75,6M17.75,7L14,3.25L4,13.25V17H7.75L17.75,7Z\";\r\nvar mdiBorderHorizontal = \"M19,21H21V19H19M15,21H17V19H15M11,17H13V15H11M19,9H21V7H19M19,5H21V3H19M3,13H21V11H3M11,21H13V19H11M19,17H21V15H19M13,3H11V5H13M13,7H11V9H13M17,3H15V5H17M9,3H7V5H9M5,3H3V5H5M7,21H9V19H7M3,17H5V15H3M5,7H3V9H5M3,21H5V19H3V21Z\";\r\nvar mdiBorderInside = \"M19,17H21V15H19M19,21H21V19H19M13,3H11V11H3V13H11V21H13V13H21V11H13M15,21H17V19H15M19,5H21V3H19M19,9H21V7H19M17,3H15V5H17M5,3H3V5H5M9,3H7V5H9M3,17H5V15H3M5,7H3V9H5M7,21H9V19H7M3,21H5V19H3V21Z\";\r\nvar mdiBorderLeft = \"M15,5H17V3H15M15,13H17V11H15M19,21H21V19H19M19,13H21V11H19M19,5H21V3H19M19,17H21V15H19M15,21H17V19H15M19,9H21V7H19M3,21H5V3H3M7,13H9V11H7M7,5H9V3H7M7,21H9V19H7M11,13H13V11H11M11,9H13V7H11M11,5H13V3H11M11,17H13V15H11M11,21H13V19H11V21Z\";\r\nvar mdiBorderLeftVariant = \"M15,5H17V3H15M19,21H21V19H19M19,13H21V11H19M19,5H21V3H19M19,17H21V15H19M15,21H17V19H15M19,9H21V7H19M3,21H5V3H3M7,5H9V3H7M7,21H9V19H7M11,5H13V3H11M11,21H13V19H11V21Z\";\r\nvar mdiBorderNone = \"M15,5H17V3H15M15,13H17V11H15M15,21H17V19H15M11,5H13V3H11M19,5H21V3H19M11,9H13V7H11M19,9H21V7H19M19,21H21V19H19M19,13H21V11H19M19,17H21V15H19M11,13H13V11H11M3,5H5V3H3M3,9H5V7H3M3,13H5V11H3M3,17H5V15H3M3,21H5V19H3M11,21H13V19H11M11,17H13V15H11M7,21H9V19H7M7,13H9V11H7M7,5H9V3H7V5Z\";\r\nvar mdiBorderNoneVariant = \"M15,5H17V3H15M15,21H17V19H15M11,5H13V3H11M19,5H21V3H19M19,9H21V7H19M19,21H21V19H19M19,13H21V11H19M19,17H21V15H19M3,5H5V3H3M3,9H5V7H3M3,13H5V11H3M3,17H5V15H3M3,21H5V19H3M11,21H13V19H11M7,21H9V19H7M7,5H9V3H7V5Z\";\r\nvar mdiBorderOutside = \"M9,11H7V13H9M13,15H11V17H13M19,19H5V5H19M3,21H21V3H3M17,11H15V13H17M13,11H11V13H13M13,7H11V9H13V7Z\";\r\nvar mdiBorderRight = \"M11,9H13V7H11M11,5H13V3H11M11,13H13V11H11M15,5H17V3H15M15,21H17V19H15M19,21H21V3H19M15,13H17V11H15M11,17H13V15H11M3,9H5V7H3M3,17H5V15H3M3,13H5V11H3M11,21H13V19H11M3,21H5V19H3M7,13H9V11H7M7,5H9V3H7M3,5H5V3H3M7,21H9V19H7V21Z\";\r\nvar mdiBorderRightVariant = \"M11,5H13V3H11M15,5H17V3H15M15,21H17V19H15M19,21H21V3H19M3,9H5V7H3M3,17H5V15H3M3,13H5V11H3M11,21H13V19H11M3,21H5V19H3M7,5H9V3H7M3,5H5V3H3M7,21H9V19H7V21Z\";\r\nvar mdiBorderStyle = \"M15,21H17V19H15M19,21H21V19H19M7,21H9V19H7M11,21H13V19H11M19,17H21V15H19M19,13H21V11H19M3,3V21H5V5H21V3M19,9H21V7H19\";\r\nvar mdiBorderTop = \"M15,13H17V11H15M19,21H21V19H19M11,9H13V7H11M15,21H17V19H15M19,17H21V15H19M3,5H21V3H3M19,13H21V11H19M19,9H21V7H19M11,17H13V15H11M3,9H5V7H3M3,13H5V11H3M3,21H5V19H3M3,17H5V15H3M11,21H13V19H11M11,13H13V11H11M7,13H9V11H7M7,21H9V19H7V21Z\";\r\nvar mdiBorderTopVariant = \"M19,21H21V19H19M15,21H17V19H15M19,17H21V15H19M3,5H21V3H3M19,13H21V11H19M19,9H21V7H19M3,9H5V7H3M3,13H5V11H3M3,21H5V19H3M3,17H5V15H3M11,21H13V19H11M7,21H9V19H7V21Z\";\r\nvar mdiBorderVertical = \"M15,13H17V11H15M15,21H17V19H15M15,5H17V3H15M19,9H21V7H19M19,5H21V3H19M19,13H21V11H19M19,21H21V19H19M11,21H13V3H11M19,17H21V15H19M7,5H9V3H7M3,17H5V15H3M3,21H5V19H3M3,13H5V11H3M7,13H9V11H7M7,21H9V19H7M3,5H5V3H3M3,9H5V7H3V9Z\";\r\nvar mdiBottleSoda = \"M15 11V20A2 2 0 0 1 13 22H11A2 2 0 0 1 9 20V11A2 2 0 0 1 9.6 9.58C11.1 7.89 11 4 11 4H10V2H14V4H13S12.9 7.89 14.4 9.58A2 2 0 0 1 15 11Z\";\r\nvar mdiBottleSodaClassic = \"M15 13.77A3 3 0 0 0 15 18.23V20A2 2 0 0 1 13 22H11A2 2 0 0 1 9 20V18.23A3 3 0 0 0 9 13.77V9A12.28 12.28 0 0 0 10.91 4H10V2H14V4H13.09A12.28 12.28 0 0 0 15 9Z\";\r\nvar mdiBottleSodaClassicOutline = \"M10 2V4H10.91C10.65 5.79 9 7.5 8 9V13.77C9.32 14.96 9.32 17.04 8 18.23V20C8 21.11 8.9 22 10 22H14C15.11 22 16 21.11 16 20V18.23C14.68 17.04 14.68 14.96 16 13.77V9C15 7.5 13.35 5.79 13.09 4H14V2M12 6.5C12.24 7 13.54 8.5 13.9 8.91L14 9V13C13.35 13.87 13 14.92 13 16C13 17.08 13.35 18.13 14 19V20H10V19C10.65 18.13 11 17.08 11 16C11 14.92 10.65 13.87 10 13V9L10.1 8.91C10.46 8.5 11.76 7 12 6.5Z\";\r\nvar mdiBottleSodaOutline = \"M14.4 9.58C12.9 7.89 13 4 13 4H14V2H10V4H11S11.1 7.89 9.6 9.58A2 2 0 0 0 9 11V20A2 2 0 0 0 11 22H13A2 2 0 0 0 15 20V11A2 2 0 0 0 14.4 9.58M13 20H11V11L11.1 10.91A6.26 6.26 0 0 0 12 9.5A6.26 6.26 0 0 0 12.9 10.91L13 11Z\";\r\nvar mdiBottleTonic = \"M13 4H11L10 2H14L13 4M19 13V22H5V13C5 10.24 7.24 8 10 8V6H9V5H15V6H14V8C16.76 8 19 10.24 19 13Z\";\r\nvar mdiBottleTonicOutline = \"M13 4H11L10 2H14L13 4M19 13V22H5V13C5 10.24 7.24 8 10 8V6H9V5H15V6H14V8C16.76 8 19 10.24 19 13M17 13C17 11.35 15.65 10 14 10H10C8.35 10 7 11.35 7 13V20H17V13Z\";\r\nvar mdiBottleTonicPlus = \"M13 4H11L10 2H14L13 4M14 8V6H15V5H9V6H10V8C7.24 8 5 10.24 5 13V22H19V13C19 10.24 16.76 8 14 8M16 17H13V20H11V17H8V15H11V12H13V15H16V17Z\";\r\nvar mdiBottleTonicPlusOutline = \"M13 4H11L10 2H14L13 4M19 13V22H5V13C5 10.24 7.24 8 10 8V6H9V5H15V6H14V8C16.76 8 19 10.24 19 13M17 13C17 11.35 15.65 10 14 10H10C8.35 10 7 11.35 7 13V20H17V13M15 16H13V18H11V16H9V14H11V12H13V14H15V16Z\";\r\nvar mdiBottleTonicSkull = \"M19 13V22H5V13C5 10.24 7.24 8 10 8V6H9V5H15V6H14V8C16.76 8 19 10.24 19 13M13 4L14 2H10L11 4H13M12 11C9.79 11 8 12.79 8 15C8 16 8.39 16.9 9 17.59V19H10.25V17.5H11.38V19H12.63V17.5H13.75V19H15V17.59C15.61 16.9 16 16 16 15C16 12.79 14.21 11 12 11M10.5 15C9.95 15 9.5 14.55 9.5 14S9.95 13 10.5 13 11.5 13.45 11.5 14 11.05 15 10.5 15M11.25 16.25L12 15L12.75 16.25H11.25M13.5 15C12.95 15 12.5 14.55 12.5 14S12.95 13 13.5 13 14.5 13.45 14.5 14 14.05 15 13.5 15Z\";\r\nvar mdiBottleTonicSkullOutline = \"M13 4H11L10 2H14L13 4M14 8V6H15V5H9V6H10V8C7.24 8 5 10.24 5 13V22H19V13C19 10.24 16.76 8 14 8M17 20H7V13C7 11.35 8.35 10 10 10H14C15.65 10 17 11.35 17 13V20M12 11C9.79 11 8 12.79 8 15C8 16 8.39 16.9 9 17.59V19H10.25V17.5H11.38V19H12.63V17.5H13.75V19H15V17.59C15.61 16.9 16 16 16 15C16 12.79 14.21 11 12 11M10.5 15C9.95 15 9.5 14.55 9.5 14S9.95 13 10.5 13 11.5 13.45 11.5 14 11.05 15 10.5 15M11.25 16.25L12 15L12.75 16.25H11.25M13.5 15C12.95 15 12.5 14.55 12.5 14S12.95 13 13.5 13 14.5 13.45 14.5 14 14.05 15 13.5 15Z\";\r\nvar mdiBottleWine = \"M10,22A1,1 0 0,1 9,21V11C9,9 10,7.25 11,7V2.5A0.5,0.5 0 0,1 11.5,2H12.5A0.5,0.5 0 0,1 13,2.5V7C14,7.25 15,9 15,11V21A1,1 0 0,1 14,22H10Z\";\r\nvar mdiBottleWineOutline = \"M11.5 2C11.22 2 11 2.22 11 2.5V7C10.93 7 10.85 7 10.78 7.03C9.82 7.27 9.21 8 8.76 8.89C8.3 9.76 8 10.84 8 12C8.05 15 8 18.03 8 21C8 21.55 8.45 22 9 22C11 22 13 22 15 22C15.55 22 16 21.55 16 21C16.04 18 16 15 16 12C16 10.84 15.74 9.76 15.28 8.88C14.83 8 14.22 7.27 13.26 7.04C13.18 7 13.05 7 13 7V2.5C13 2.22 12.78 2 12.5 2M12 8.85C12.32 8.85 12.63 8.9 12.78 9C12.85 9.03 13.2 9.26 13.5 9.81C13.78 10.37 14 11.17 14 12V20H10V12C10 11.17 10.22 10.37 10.5 9.81C10.8 9.26 11.15 9.03 11.22 9C11.36 8.9 11.68 8.85 12 8.85Z\";\r\nvar mdiBowTie = \"M15,14L21,17V7L15,10V14M9,14L3,17V7L9,10V14M10,10H14V14H10V10Z\";\r\nvar mdiBowl = \"M22 15C22 18.9 18.9 22 15 22H9C5.1 22 2 18.9 2 15V12H22V15Z\";\r\nvar mdiBowlMix = \"M16.2 11L20.3 4.5L22 5.5L18.6 11H16.2M15.6 12H2V15C2 18.9 5.1 22 9 22H15C18.9 22 22 18.9 22 15V12H15.6Z\";\r\nvar mdiBowlMixOutline = \"M15.6 12H2V15C2 18.9 5.1 22 9 22H15C18.9 22 22 18.9 22 15V12H15.6M20 15C20 17.8 17.8 20 15 20H9C6.2 20 4 17.8 4 15V14H20V15M16.2 11L20.3 4.4L22 5.5L18.6 11H16.2Z\";\r\nvar mdiBowlOutline = \"M2 12V15C2 18.9 5.1 22 9 22H15C18.9 22 22 18.9 22 15V12H2M4 14H20V15C20 17.8 17.8 20 15 20H9C6.2 20 4 17.8 4 15V14Z\";\r\nvar mdiBowling = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12.5,11A1.5,1.5 0 0,0 11,12.5A1.5,1.5 0 0,0 12.5,14A1.5,1.5 0 0,0 14,12.5A1.5,1.5 0 0,0 12.5,11M12,5A2,2 0 0,0 10,7A2,2 0 0,0 12,9A2,2 0 0,0 14,7A2,2 0 0,0 12,5M5.93,8.5C5.38,9.45 5.71,10.67 6.66,11.22C7.62,11.78 8.84,11.45 9.4,10.5C9.95,9.53 9.62,8.31 8.66,7.76C7.71,7.21 6.5,7.53 5.93,8.5Z\";\r\nvar mdiBox = \"M15.39,14.04V14.04C15.39,12.62 14.24,11.47 12.82,11.47C11.41,11.47 10.26,12.62 10.26,14.04V14.04C10.26,15.45 11.41,16.6 12.82,16.6C14.24,16.6 15.39,15.45 15.39,14.04M17.1,14.04C17.1,16.4 15.18,18.31 12.82,18.31C11.19,18.31 9.77,17.39 9.05,16.04C8.33,17.39 6.91,18.31 5.28,18.31C2.94,18.31 1.04,16.43 1,14.11V14.11H1V7H1V7C1,6.56 1.39,6.18 1.86,6.18C2.33,6.18 2.7,6.56 2.71,7V7H2.71V10.62C3.43,10.08 4.32,9.76 5.28,9.76C6.91,9.76 8.33,10.68 9.05,12.03C9.77,10.68 11.19,9.76 12.82,9.76C15.18,9.76 17.1,11.68 17.1,14.04V14.04M7.84,14.04V14.04C7.84,12.62 6.69,11.47 5.28,11.47C3.86,11.47 2.71,12.62 2.71,14.04V14.04C2.71,15.45 3.86,16.6 5.28,16.6C6.69,16.6 7.84,15.45 7.84,14.04M22.84,16.96V16.96C22.95,17.12 23,17.3 23,17.47C23,17.73 22.88,18 22.66,18.15C22.5,18.26 22.33,18.32 22.15,18.32C21.9,18.32 21.65,18.21 21.5,18L19.59,15.47L17.7,18V18C17.53,18.21 17.28,18.32 17.03,18.32C16.85,18.32 16.67,18.26 16.5,18.15C16.29,18 16.17,17.72 16.17,17.46C16.17,17.29 16.23,17.11 16.33,16.96V16.96H16.33V16.96L18.5,14.04L16.33,11.11V11.11H16.33V11.11C16.22,10.96 16.17,10.79 16.17,10.61C16.17,10.35 16.29,10.1 16.5,9.93C16.89,9.65 17.41,9.72 17.7,10.09V10.09L19.59,12.61L21.5,10.09C21.76,9.72 22.29,9.65 22.66,9.93C22.89,10.1 23,10.36 23,10.63C23,10.8 22.95,10.97 22.84,11.11V11.11H22.84V11.11L20.66,14.04L22.84,16.96V16.96H22.84Z\";\r\nvar mdiBoxCutter = \"M7.22,11.91C6.89,12.24 6.71,12.65 6.66,13.08L12.17,15.44L20.66,6.96C21.44,6.17 21.44,4.91 20.66,4.13L19.24,2.71C18.46,1.93 17.2,1.93 16.41,2.71L7.22,11.91M5,16V21.75L10.81,16.53L5.81,14.53L5,16M17.12,4.83C17.5,4.44 18.15,4.44 18.54,4.83C18.93,5.23 18.93,5.86 18.54,6.25C18.15,6.64 17.5,6.64 17.12,6.25C16.73,5.86 16.73,5.23 17.12,4.83Z\";\r\nvar mdiBoxCutterOff = \"M20.84 22.73L12.86 14.75L12.17 15.44L6.66 13.08C6.71 12.65 6.89 12.24 7.22 11.91L8.62 10.5L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M15.41 12.21L11.16 7.96L16.41 2.71C17.2 1.93 18.46 1.93 19.24 2.71L20.66 4.13C21.44 4.91 21.44 6.17 20.66 6.96L15.41 12.21M17.12 6.25C17.5 6.64 18.15 6.64 18.54 6.25C18.93 5.86 18.93 5.23 18.54 4.83C18.15 4.44 17.5 4.44 17.12 4.83C16.73 5.23 16.73 5.86 17.12 6.25M5 16V21.75L10.81 16.53L5.81 14.53L5 16Z\";\r\nvar mdiBoxShadow = \"M3,3H18V18H3V3M19,19H21V21H19V19M19,16H21V18H19V16M19,13H21V15H19V13M19,10H21V12H19V10M19,7H21V9H19V7M16,19H18V21H16V19M13,19H15V21H13V19M10,19H12V21H10V19M7,19H9V21H7V19Z\";\r\nvar mdiBoxingGlove = \"M19,16V6H22V16H19M12,4C8,4 7,4 7,4C7,4 2,4 2,8V14C2,15.77 3,16.76 4.07,17.31C4.4,15.43 6.03,14 8,14H11V16H8A2,2 0 0,0 6,18C6,19.11 6.9,20 8,20H13C17,20 17,16 17,16V6C17,6 16,4 12,4Z\";\r\nvar mdiBraille = \"M7,8A1,1 0 0,1 8,7A1,1 0 0,1 9,8V12.47L10.21,12.6L15.15,14.79C15.67,15.03 16,15.56 16,16.14V20.5C15.97,21.32 15.32,21.97 14.5,22H8C7.62,22 7.26,21.85 7,21.57L2.1,17.37L2.84,16.6C3.03,16.39 3.3,16.28 3.58,16.28H3.8L7,18V8M19.5,2A1.5,1.5 0 0,0 18,3.5A1.5,1.5 0 0,0 19.5,5A1.5,1.5 0 0,0 21,3.5A1.5,1.5 0 0,0 19.5,2M19.5,7A1.5,1.5 0 0,0 18,8.5A1.5,1.5 0 0,0 19.5,10A1.5,1.5 0 0,0 21,8.5A1.5,1.5 0 0,0 19.5,7M14.5,7A1.5,1.5 0 0,0 13,8.5A1.5,1.5 0 0,0 14.5,10A1.5,1.5 0 0,0 16,8.5A1.5,1.5 0 0,0 14.5,7M19.5,12A1.5,1.5 0 0,0 18,13.5A1.5,1.5 0 0,0 19.5,15A1.5,1.5 0 0,0 21,13.5A1.5,1.5 0 0,0 19.5,12Z\";\r\nvar mdiBrain = \"M21.33,12.91C21.42,14.46 20.71,15.95 19.44,16.86L20.21,18.35C20.44,18.8 20.47,19.33 20.27,19.8C20.08,20.27 19.69,20.64 19.21,20.8L18.42,21.05C18.25,21.11 18.06,21.14 17.88,21.14C17.37,21.14 16.89,20.91 16.56,20.5L14.44,18C13.55,17.85 12.71,17.47 12,16.9C11.5,17.05 11,17.13 10.5,17.13C9.62,17.13 8.74,16.86 8,16.34C7.47,16.5 6.93,16.57 6.38,16.56C5.59,16.57 4.81,16.41 4.08,16.11C2.65,15.47 1.7,14.07 1.65,12.5C1.57,11.78 1.69,11.05 2,10.39C1.71,9.64 1.68,8.82 1.93,8.06C2.3,7.11 3,6.32 3.87,5.82C4.45,4.13 6.08,3 7.87,3.12C9.47,1.62 11.92,1.46 13.7,2.75C14.12,2.64 14.56,2.58 15,2.58C16.36,2.55 17.65,3.15 18.5,4.22C20.54,4.75 22,6.57 22.08,8.69C22.13,9.8 21.83,10.89 21.22,11.82C21.29,12.18 21.33,12.54 21.33,12.91M16.33,11.5C16.9,11.57 17.35,12 17.35,12.57A1,1 0 0,1 16.35,13.57H15.72C15.4,14.47 14.84,15.26 14.1,15.86C14.35,15.95 14.61,16 14.87,16.07C20,16 19.4,12.87 19.4,12.82C19.34,11.39 18.14,10.27 16.71,10.33A1,1 0 0,1 15.71,9.33A1,1 0 0,1 16.71,8.33C17.94,8.36 19.12,8.82 20.04,9.63C20.09,9.34 20.12,9.04 20.12,8.74C20.06,7.5 19.5,6.42 17.25,6.21C16,3.25 12.85,4.89 12.85,5.81V5.81C12.82,6.04 13.06,6.53 13.1,6.56A1,1 0 0,1 14.1,7.56C14.1,8.11 13.65,8.56 13.1,8.56V8.56C12.57,8.54 12.07,8.34 11.67,8C11.19,8.31 10.64,8.5 10.07,8.56V8.56C9.5,8.61 9.03,8.21 9,7.66C8.92,7.1 9.33,6.61 9.88,6.56C10.04,6.54 10.82,6.42 10.82,5.79V5.79C10.82,5.13 11.07,4.5 11.5,4C10.58,3.75 9.59,4.08 8.59,5.29C6.75,5 6,5.25 5.45,7.2C4.5,7.67 4,8 3.78,9C4.86,8.78 5.97,8.87 7,9.25C7.5,9.44 7.78,10 7.59,10.54C7.4,11.06 6.82,11.32 6.3,11.13C5.57,10.81 4.75,10.79 4,11.07C3.68,11.34 3.68,11.9 3.68,12.34C3.68,13.08 4.05,13.77 4.68,14.17C5.21,14.44 5.8,14.58 6.39,14.57C6.24,14.31 6.11,14.04 6,13.76C5.81,13.22 6.1,12.63 6.64,12.44C7.18,12.25 7.77,12.54 7.96,13.08C8.36,14.22 9.38,15 10.58,15.13C11.95,15.06 13.17,14.25 13.77,13C14,11.62 15.11,11.5 16.33,11.5M18.33,18.97L17.71,17.67L17,17.83L18,19.08L18.33,18.97M13.68,10.36C13.7,9.83 13.3,9.38 12.77,9.33C12.06,9.29 11.37,9.53 10.84,10C10.27,10.58 9.97,11.38 10,12.19A1,1 0 0,0 11,13.19C11.57,13.19 12,12.74 12,12.19C12,11.92 12.07,11.65 12.23,11.43C12.35,11.33 12.5,11.28 12.66,11.28C13.21,11.31 13.68,10.9 13.68,10.36Z\";\r\nvar mdiBreadSlice = \"M12,2C17.5,2 22,5.36 22,9.5C22,11.19 21.26,12.75 20,14V22H4V14C2.74,12.75 2,11.19 2,9.5C2,5.36 6.5,2 12,2M8,18H12V14H8V18Z\";\r\nvar mdiBreadSliceOutline = \"M12,2C17.5,2 22,5.36 22,9.5C22,11.19 21.26,12.75 20,14V22H4V14C2.74,12.75 2,11.19 2,9.5C2,5.36 6.5,2 12,2M18,13.14C19.24,12.17 20,10.89 20,9.5C20,6.46 16.42,4 12,4C7.58,4 4,6.46 4,9.5C4,10.89 4.76,12.17 6,13.14V20H18V13.14M8,18V14H12V18H8Z\";\r\nvar mdiBridge = \"M7,14V10.91C6.28,10.58 5.61,10.18 5,9.71V14H7M5,18H3V16H1V14H3V7H5V8.43C6.8,10 9.27,11 12,11C14.73,11 17.2,10 19,8.43V7H21V14H23V16H21V18H19V16H5V18M17,10.91V14H19V9.71C18.39,10.18 17.72,10.58 17,10.91M16,14V11.32C15.36,11.55 14.69,11.72 14,11.84V14H16M13,14V11.96L12,12L11,11.96V14H13M10,14V11.84C9.31,11.72 8.64,11.55 8,11.32V14H10Z\";\r\nvar mdiBriefcase = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcaseAccount = \"M20,6H16V4A2,2 0 0,0 14,2H10C8.89,2 8,2.89 8,4V6H4C2.89,6 2,6.89 2,8V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V8A2,2 0 0,0 20,6M10,4H14V6H10V4M12,9A2.5,2.5 0 0,1 14.5,11.5A2.5,2.5 0 0,1 12,14A2.5,2.5 0 0,1 9.5,11.5A2.5,2.5 0 0,1 12,9M17,19H7V17.75C7,16.37 9.24,15.25 12,15.25C14.76,15.25 17,16.37 17,17.75V19Z\";\r\nvar mdiBriefcaseAccountOutline = \"M20,6C20.58,6 21.05,6.2 21.42,6.59C21.8,7 22,7.45 22,8V19C22,19.55 21.8,20 21.42,20.41C21.05,20.8 20.58,21 20,21H4C3.42,21 2.95,20.8 2.58,20.41C2.2,20 2,19.55 2,19V8C2,7.45 2.2,7 2.58,6.59C2.95,6.2 3.42,6 4,6H8V4C8,3.42 8.2,2.95 8.58,2.58C8.95,2.2 9.42,2 10,2H14C14.58,2 15.05,2.2 15.42,2.58C15.8,2.95 16,3.42 16,4V6H20M4,8V19H20V8H4M14,6V4H10V6H14M12,9A2.25,2.25 0 0,1 14.25,11.25C14.25,12.5 13.24,13.5 12,13.5A2.25,2.25 0 0,1 9.75,11.25C9.75,10 10.76,9 12,9M16.5,18H7.5V16.88C7.5,15.63 9.5,14.63 12,14.63C14.5,14.63 16.5,15.63 16.5,16.88V18Z\";\r\nvar mdiBriefcaseCheck = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V8A2,2 0 0,1 4,6H8V4A2,2 0 0,1 10,2M14,6V4H10V6H14M10.5,17.5L17.09,10.91L15.68,9.5L10.5,14.67L8.41,12.59L7,14L10.5,17.5Z\";\r\nvar mdiBriefcaseCheckOutline = \"M20 6C20.58 6 21.05 6.2 21.42 6.59C21.8 7 22 7.45 22 8V19C22 19.55 21.8 20 21.42 20.41C21.05 20.8 20.58 21 20 21H4C3.42 21 2.95 20.8 2.58 20.41C2.2 20 2 19.55 2 19V8C2 7.45 2.2 7 2.58 6.59C2.95 6.2 3.42 6 4 6H8V4C8 3.42 8.2 2.95 8.58 2.58C8.95 2.2 9.42 2 10 2H14C14.58 2 15.05 2.2 15.42 2.58C15.8 2.95 16 3.42 16 4V6H20M4 8V19H20V8H4M14 6V4H10V6H14M10.46 17.5L17.05 10.91L15.64 9.5L10.46 14.67L8.37 12.59L6.96 14L10.46 17.5Z\";\r\nvar mdiBriefcaseClock = \"M21 11.11V7A2 2 0 0 0 19 5H15V3A2 2 0 0 0 13 1H9A2 2 0 0 0 7 3V5H3A2 2 0 0 0 1 7V18A2 2 0 0 0 3 20H10.26A7 7 0 1 0 21 11.11M9 3H13V5H9M19 20A5 5 0 0 1 13 20A5 5 0 1 1 19 20M15 13H16.5V15.82L18.94 17.23L18.19 18.53L15 16.69V13\";\r\nvar mdiBriefcaseClockOutline = \"M21 11.11V7A2 2 0 0 0 20.42 5.59A1.87 1.87 0 0 0 19 5H15V3A1.9 1.9 0 0 0 14.42 1.58A1.9 1.9 0 0 0 13 1H9A1.9 1.9 0 0 0 7.58 1.58A1.9 1.9 0 0 0 7 3V5H3A1.87 1.87 0 0 0 1.58 5.59A2 2 0 0 0 1 7V18A2 2 0 0 0 1.58 19.41A1.87 1.87 0 0 0 3 20H10.26A7 7 0 1 0 21 11.11M9 3H13V5H9M3 18V7H19V9.68A6.84 6.84 0 0 0 16 9A7 7 0 0 0 9 16A6.91 6.91 0 0 0 9.29 18M19 20A5 5 0 0 1 13 20A4.94 4.94 0 0 1 11 16A5 5 0 0 1 16 11A4.94 4.94 0 0 1 19 12A5 5 0 0 1 19 20M15 13H16.5V15.82L18.94 17.23L18.19 18.53L15 16.69V13\";\r\nvar mdiBriefcaseDownload = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14M12,19L17,14H14V10H10V14H7L12,19Z\";\r\nvar mdiBriefcaseDownloadOutline = \"M12,18L7,13H10V9H14V13H17L12,18M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14M4,8V19H20V8H4Z\";\r\nvar mdiBriefcaseEdit = \"M14,2A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8L10.85,19C10.85,20.1 10.85,19.5 10.85,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2H14M14,6V4H10V6H14M21.04,12.13C20.9,12.13 20.76,12.19 20.65,12.3L19.65,13.3L21.7,15.35L22.7,14.35C22.92,14.14 22.92,13.79 22.7,13.58L21.42,12.3C21.31,12.19 21.18,12.13 21.04,12.13M19.07,13.88L13,19.94V22H15.06L21.12,15.93L19.07,13.88Z\";\r\nvar mdiBriefcaseEditOutline = \"M21.04,12.13C21.18,12.13 21.31,12.19 21.42,12.3L22.7,13.58C22.92,13.79 22.92,14.14 22.7,14.35L21.7,15.35L19.65,13.3L20.65,12.3C20.76,12.19 20.9,12.13 21.04,12.13M19.07,13.88L21.12,15.93L15.06,22H13V19.94L19.07,13.88M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8L20,10V8H4V19H11V21H4A2,2 0 0,1 2,19V8A2,2 0 0,1 4,6H8V4A2,2 0 0,1 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcaseMinus = \"M22,17V19H14V17H22M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C20.94,12.58 19.54,12 18,12A6,6 0 0,0 12,18C12,19.09 12.29,20.12 12.8,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcaseMinusOutline = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C21.42,13 20.75,12.6 20,12.34V8H4V19H12.08C12.2,19.72 12.45,20.39 12.8,21H4A2,2 0 0,1 2,19V8A2,2 0 0,1 4,6H8V4A2,2 0 0,1 10,2M14,6V4H10V6H14M14,17H22V19H14V17Z\";\r\nvar mdiBriefcaseOutline = \"M20,6C20.58,6 21.05,6.2 21.42,6.59C21.8,7 22,7.45 22,8V19C22,19.55 21.8,20 21.42,20.41C21.05,20.8 20.58,21 20,21H4C3.42,21 2.95,20.8 2.58,20.41C2.2,20 2,19.55 2,19V8C2,7.45 2.2,7 2.58,6.59C2.95,6.2 3.42,6 4,6H8V4C8,3.42 8.2,2.95 8.58,2.58C8.95,2.2 9.42,2 10,2H14C14.58,2 15.05,2.2 15.42,2.58C15.8,2.95 16,3.42 16,4V6H20M4,8V19H20V8H4M14,6V4H10V6H14Z\";\r\nvar mdiBriefcasePlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C20.94,12.58 19.54,12 18,12A6,6 0 0,0 12,18C12,19.09 12.29,20.12 12.8,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcasePlusOutline = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C21.42,13 20.75,12.6 20,12.34V8H4V19H12.08C12.2,19.72 12.45,20.39 12.8,21H4A2,2 0 0,1 2,19V8A2,2 0 0,1 4,6H8V4A2,2 0 0,1 10,2M14,6V4H10V6H14M14,17H17V14H19V17H22V19H19V22H17V19H14V17Z\";\r\nvar mdiBriefcaseRemove = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C20.94,12.58 19.54,12 18,12A6,6 0 0,0 12,18C12,19.09 12.29,20.12 12.8,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcaseRemoveOutline = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.53C21.42,13 20.75,12.6 20,12.34V8H4V19H12.08C12.2,19.72 12.45,20.39 12.8,21H4A2,2 0 0,1 2,19V8A2,2 0 0,1 4,6H8V4A2,2 0 0,1 10,2M14,6V4H10V6H14M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88Z\";\r\nvar mdiBriefcaseSearch = \"M16.5,12C19,12 21,14 21,16.5C21,17.38 20.75,18.21 20.31,18.9L23.39,22L22,23.39L18.88,20.32C18.19,20.75 17.37,21 16.5,21C14,21 12,19 12,16.5C12,14 14,12 16.5,12M16.5,14A2.5,2.5 0 0,0 14,16.5A2.5,2.5 0 0,0 16.5,19A2.5,2.5 0 0,0 19,16.5A2.5,2.5 0 0,0 16.5,14M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.03C20.85,11.21 18.82,10 16.5,10A6.5,6.5 0 0,0 10,16.5C10,18.25 10.69,19.83 11.81,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14Z\";\r\nvar mdiBriefcaseSearchOutline = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V13.03C21.5,12.23 20.8,11.54 20,11V8H4V19H10.5C10.81,19.75 11.26,20.42 11.81,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14M20.31,18.9L23.39,22L22,23.39L18.88,20.32C18.19,20.75 17.37,21 16.5,21C14,21 12,19 12,16.5C12,14 14,12 16.5,12C19,12 21,14 21,16.5C21,17.38 20.75,18.21 20.31,18.9M16.5,19A2.5,2.5 0 0,0 19,16.5A2.5,2.5 0 0,0 16.5,14A2.5,2.5 0 0,0 14,16.5A2.5,2.5 0 0,0 16.5,19Z\";\r\nvar mdiBriefcaseUpload = \"M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14M12,9L7,14H10V18H14V14H17L12,9Z\";\r\nvar mdiBriefcaseUploadOutline = \"M12,9L17,14H14V18H10V14H7L12,9M10,2H14A2,2 0 0,1 16,4V6H20A2,2 0 0,1 22,8V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V8C2,6.89 2.89,6 4,6H8V4C8,2.89 8.89,2 10,2M14,6V4H10V6H14M4,8V19H20V8H4Z\";\r\nvar mdiBriefcaseVariant = \"M10 16V15H3L3 19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V15H14V16H10M20 7H16V5L14 3H10L8 5V7H4C2.9 7 2 7.9 2 9V12C2 13.11 2.89 14 4 14H10V12H14V14H20C21.1 14 22 13.1 22 12V9C22 7.9 21.1 7 20 7M14 7H10V5H14V7Z\";\r\nvar mdiBriefcaseVariantOutline = \"M20 7H16V5L14 3H10L8 5V7H4C2.9 7 2 7.9 2 9V14C2 14.75 2.4 15.38 3 15.73V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V15.72C21.59 15.37 22 14.73 22 14V9C22 7.9 21.1 7 20 7M10 5H14V7H10V5M4 9H20V14H15V11H9V14H4V9M13 15H11V13H13V15M19 19H5V16H9V17H15V16H19V19Z\";\r\nvar mdiBrightness1 = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiBrightness2 = \"M10,2C8.18,2 6.47,2.5 5,3.35C8,5.08 10,8.3 10,12C10,15.7 8,18.92 5,20.65C6.47,21.5 8.18,22 10,22A10,10 0 0,0 20,12A10,10 0 0,0 10,2Z\";\r\nvar mdiBrightness3 = \"M9,2C7.95,2 6.95,2.16 6,2.46C10.06,3.73 13,7.5 13,12C13,16.5 10.06,20.27 6,21.54C6.95,21.84 7.95,22 9,22A10,10 0 0,0 19,12A10,10 0 0,0 9,2Z\";\r\nvar mdiBrightness4 = \"M12,18C11.11,18 10.26,17.8 9.5,17.45C11.56,16.5 13,14.42 13,12C13,9.58 11.56,7.5 9.5,6.55C10.26,6.2 11.11,6 12,6A6,6 0 0,1 18,12A6,6 0 0,1 12,18M20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31L23.31,12L20,8.69Z\";\r\nvar mdiBrightness5 = \"M12,18A6,6 0 0,1 6,12A6,6 0 0,1 12,6A6,6 0 0,1 18,12A6,6 0 0,1 12,18M20,15.31L23.31,12L20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31Z\";\r\nvar mdiBrightness6 = \"M12,18V6A6,6 0 0,1 18,12A6,6 0 0,1 12,18M20,15.31L23.31,12L20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31Z\";\r\nvar mdiBrightness7 = \"M12,8A4,4 0 0,0 8,12A4,4 0 0,0 12,16A4,4 0 0,0 16,12A4,4 0 0,0 12,8M12,18A6,6 0 0,1 6,12A6,6 0 0,1 12,6A6,6 0 0,1 18,12A6,6 0 0,1 12,18M20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31L23.31,12L20,8.69Z\";\r\nvar mdiBrightnessAuto = \"M14.3,16L13.6,14H10.4L9.7,16H7.8L11,7H13L16.2,16H14.3M20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31L23.31,12L20,8.69M10.85,12.65H13.15L12,9L10.85,12.65Z\";\r\nvar mdiBrightnessPercent = \"M20.04,8.71V4H15.34L12,0.69L8.71,4H4V8.71L0.69,12L4,15.34V20.04H8.71L12,23.35L15.34,20.04H20.04V15.34L23.35,12L20.04,8.71M8.83,7.05C9.81,7.05 10.6,7.84 10.6,8.83A1.77,1.77 0 0,1 8.83,10.6C7.84,10.6 7.05,9.81 7.05,8.83C7.05,7.84 7.84,7.05 8.83,7.05M15.22,17C14.24,17 13.45,16.2 13.45,15.22A1.77,1.77 0 0,1 15.22,13.45C16.2,13.45 17,14.24 17,15.22A1.78,1.78 0 0,1 15.22,17M8.5,17.03L7,15.53L15.53,7L17.03,8.5L8.5,17.03Z\";\r\nvar mdiBroom = \"M19.36,2.72L20.78,4.14L15.06,9.85C16.13,11.39 16.28,13.24 15.38,14.44L9.06,8.12C10.26,7.22 12.11,7.37 13.65,8.44L19.36,2.72M5.93,17.57C3.92,15.56 2.69,13.16 2.35,10.92L7.23,8.83L14.67,16.27L12.58,21.15C10.34,20.81 7.94,19.58 5.93,17.57Z\";\r\nvar mdiBrush = \"M20.71,4.63L19.37,3.29C19,2.9 18.35,2.9 17.96,3.29L9,12.25L11.75,15L20.71,6.04C21.1,5.65 21.1,5 20.71,4.63M7,14A3,3 0 0,0 4,17C4,18.31 2.84,19 2,19C2.92,20.22 4.5,21 6,21A4,4 0 0,0 10,17A3,3 0 0,0 7,14Z\";\r\nvar mdiBucket = \"M3 4H21V7H20L17.5 21H6.5L4 7H3V4Z\";\r\nvar mdiBucketOutline = \"M3 4H21V7H20L17.5 21H6.5L4 7H3V4M17.97 7H6.03L8.15 19H15.85L17.97 7Z\";\r\nvar mdiBuddhism = \"M11,2V3C9.27,3.2 7.69,3.9 6.4,4.94L5.64,4.18L4.22,5.6L5,6.35C3.9,7.68 3.21,9.3 3,11H2V13H3C3.21,14.68 3.9,16.26 5,17.56L4.22,18.32L5.64,19.74L6.39,19C7.71,20.07 9.3,20.77 11,21V22H13V21C14.69,20.77 16.29,20.07 17.6,19L18.36,19.74L19.78,18.32L19,17.57C20.1,16.27 20.79,14.68 21,13H22V11H21C20.79,9.3 20.1,7.69 19,6.36L19.78,5.6L18.36,4.18L17.61,4.94C16.29,3.87 14.69,3.2 13,3V2H11M11,5V8L10,8.5L7.81,6.35C8.72,5.67 9.81,5.17 11,5M13,5C14.16,5.18 15.26,5.64 16.2,6.35L14,8.5L13,8V5M6.4,7.76L8.5,10L8,11H5C5.16,9.84 5.7,8.7 6.39,7.75L6.4,7.76M17.6,7.76C18.33,8.71 18.81,9.82 19,11H16L15.5,10L17.61,7.76H17.6M12,10C13.12,10 14,10.88 14,12C14,13.12 13.12,14 12,14C10.88,14 10,13.12 10,12C10,10.88 10.88,10 12,10M5,13H8L8.57,14L6.39,16.15C5.67,15.24 5.19,14.16 5,13V13M16,13H19C18.81,14.15 18.33,15.24 17.61,16.16L15.5,14L16,13M10,15.5L11,16V19C9.83,18.8 8.73,18.31 7.8,17.57L10,15.5M14,15.5L16.19,17.57C15.28,18.25 14.19,18.83 13,19V16L14,15.5Z\";\r\nvar mdiBuffer = \"M12.6,2.86C15.27,4.1 18,5.39 20.66,6.63C20.81,6.7 21,6.75 21,6.95C21,7.15 20.81,7.19 20.66,7.26C18,8.5 15.3,9.77 12.62,11C12.21,11.21 11.79,11.21 11.38,11C8.69,9.76 6,8.5 3.32,7.25C3.18,7.19 3,7.14 3,6.94C3,6.76 3.18,6.71 3.31,6.65C6,5.39 8.74,4.1 11.44,2.85C11.73,2.72 12.3,2.73 12.6,2.86M12,21.15C11.8,21.15 11.66,21.07 11.38,20.97C8.69,19.73 6,18.47 3.33,17.22C3.19,17.15 3,17.11 3,16.9C3,16.7 3.19,16.66 3.34,16.59C3.78,16.38 4.23,16.17 4.67,15.96C5.12,15.76 5.56,15.76 6,15.97C7.79,16.8 9.57,17.63 11.35,18.46C11.79,18.67 12.23,18.66 12.67,18.46C14.45,17.62 16.23,16.79 18,15.96C18.44,15.76 18.87,15.75 19.29,15.95C19.77,16.16 20.24,16.39 20.71,16.61C20.78,16.64 20.85,16.68 20.91,16.73C21.04,16.83 21.04,17 20.91,17.08C20.83,17.14 20.74,17.19 20.65,17.23C18,18.5 15.33,19.72 12.66,20.95C12.46,21.05 12.19,21.15 12,21.15M12,16.17C11.9,16.17 11.55,16.07 11.36,16C8.68,14.74 6,13.5 3.34,12.24C3.2,12.18 3,12.13 3,11.93C3,11.72 3.2,11.68 3.35,11.61C3.8,11.39 4.25,11.18 4.7,10.97C5.13,10.78 5.56,10.78 6,11C7.78,11.82 9.58,12.66 11.38,13.5C11.79,13.69 12.21,13.69 12.63,13.5C14.43,12.65 16.23,11.81 18.04,10.97C18.45,10.78 18.87,10.78 19.29,10.97C19.76,11.19 20.24,11.41 20.71,11.63C20.77,11.66 20.84,11.69 20.9,11.74C21.04,11.85 21.04,12 20.89,12.12C20.84,12.16 20.77,12.19 20.71,12.22C18,13.5 15.31,14.75 12.61,16C12.42,16.09 12.08,16.17 12,16.17Z\";\r\nvar mdiBuffet = \"M9 14C9.55 14 10 14.45 10 15C10 15.55 9.55 16 9 16C8.45 16 8 15.55 8 15C8 14.45 8.45 14 9 14M15 14C15.55 14 16 14.45 16 15C16 15.55 15.55 16 15 16C14.45 16 14 15.55 14 15C14 14.45 14.45 14 15 14M3 22L4 19H3C2.45 19 2 18.55 2 18V12C2 11.45 2.45 11 3 11H21C21.55 11 22 11.45 22 12V18C22 18.55 21.55 19 21 19H20L21 22H19L18 19H6L5 22H3M13 13V17H20V13H13M4 13V17H11V13H4Z\";\r\nvar mdiBug = \"M14,12H10V10H14M14,16H10V14H14M20,8H17.19C16.74,7.22 16.12,6.55 15.37,6.04L17,4.41L15.59,3L13.42,5.17C12.96,5.06 12.5,5 12,5C11.5,5 11.04,5.06 10.59,5.17L8.41,3L7,4.41L8.62,6.04C7.88,6.55 7.26,7.22 6.81,8H4V10H6.09C6.04,10.33 6,10.66 6,11V12H4V14H6V15C6,15.34 6.04,15.67 6.09,16H4V18H6.81C7.85,19.79 9.78,21 12,21C14.22,21 16.15,19.79 17.19,18H20V16H17.91C17.96,15.67 18,15.34 18,15V14H20V12H18V11C18,10.66 17.96,10.33 17.91,10H20V8Z\";\r\nvar mdiBugCheck = \"M18,7H15.19C14.74,6.2 14.12,5.5 13.37,5L15,3.41L13.59,2L11.42,4.17C10.96,4.06 10.5,4 10,4C9.5,4 9.05,4.06 8.59,4.17L6.41,2L5,3.41L6.62,5C5.87,5.5 5.26,6.21 4.81,7H2V9H4.09C4.03,9.33 4,9.66 4,10V11H2V13H4V14C4,14.34 4.03,14.67 4.09,15H2V17H4.81C6.26,19.5 9.28,20.61 12,19.65C12,19.43 12,19.22 12,19C12,16.46 13.61,14.2 16,13.35V13H18V11H16V10C16,9.66 15.97,9.33 15.91,9H18V7M12,15H8V13H12V15M12,11H8V9H12V11M17.75,22.16L15,19.16L16.16,18L17.75,19.59L21.34,16L22.5,17.41L17.75,22.16Z\";\r\nvar mdiBugCheckOutline = \"M18,7H15.19C14.74,6.2 14.12,5.5 13.37,5L15,3.41L13.59,2L11.42,4.17C10.96,4.06 10.5,4 10,4C9.5,4 9.05,4.06 8.59,4.17L6.41,2L5,3.41L6.62,5C5.87,5.5 5.26,6.21 4.81,7H2V9H4.09C4.03,9.33 4,9.66 4,10V11H2V13H4V14C4,14.34 4.03,14.67 4.09,15H2V17H4.81C6.26,19.5 9.28,20.61 12,19.65C12,19.43 12,19.22 12,19C12,18.43 12.09,17.86 12.25,17.31C11.59,17.76 10.8,18 10,18A4,4 0 0,1 6,14V10A4,4 0 0,1 10,6A4,4 0 0,1 14,10V14C14,14.19 14,14.39 13.95,14.58C14.54,14.04 15.24,13.62 16,13.35V13H18V11H16V10C16,9.66 15.97,9.33 15.91,9H18V7M21.34,16L17.75,19.59L16.16,18L15,19.16L17.75,22.16L22.5,17.41L21.34,16M12,9V11H8V9H12M12,13V15H8V13H12Z\";\r\nvar mdiBugOutline = \"M20,8H17.19C16.74,7.2 16.12,6.5 15.37,6L17,4.41L15.59,3L13.42,5.17C12.96,5.06 12.5,5 12,5C11.5,5 11.05,5.06 10.59,5.17L8.41,3L7,4.41L8.62,6C7.87,6.5 7.26,7.21 6.81,8H4V10H6.09C6.03,10.33 6,10.66 6,11V12H4V14H6V15C6,15.34 6.03,15.67 6.09,16H4V18H6.81C8.47,20.87 12.14,21.84 15,20.18C15.91,19.66 16.67,18.9 17.19,18H20V16H17.91C17.97,15.67 18,15.34 18,15V14H20V12H18V11C18,10.66 17.97,10.33 17.91,10H20V8M16,15A4,4 0 0,1 12,19A4,4 0 0,1 8,15V11A4,4 0 0,1 12,7A4,4 0 0,1 16,11V15M14,10V12H10V10H14M10,14H14V16H10V14Z\";\r\nvar mdiBugle = \"M21,6C21,11 12,11 12,11C12,11 6,11 5,11C4,11 3,10 3,10H2V14H3C3,14 4,13 5,13C5.2,13 5.7,13 6.3,13C5.5,13.5 5,14.2 5,15C5,16.8 7.3,18 10.5,18C13.7,18 16,16.8 16,15C16,14.4 15.7,13.8 15.2,13.3C17.8,13.8 21,15 21,18H22V6H21M10.5,16.7C8.2,16.7 6.4,15.9 6.4,15C6.4,14.1 8.2,13.3 10.5,13.3C12.8,13.3 14.6,14.1 14.6,15C14.6,15.9 12.8,16.7 10.5,16.7Z\";\r\nvar mdiBulldozer = \"M4,4A1,1 0 0,0 3,5V10C2.54,10 2.14,10.31 2.03,10.76V13.97H2.29C2.65,13.37 3.3,13 4,13H13C13.7,13 14.35,13.37 14.71,13.97H16.03L16,11V11A1,1 0 0,0 15,10H13V8A1,1 0 0,0 12,7A1,1 0 0,0 11,8V10H9V5A1,1 0 0,0 8,4H4M5,6H7V10L7,11H5V6M17,11V19H22V18L19,17L18,11H17M4,15A2,2 0 0,0 2,17A2,2 0 0,0 4,19H13A2,2 0 0,0 15,17A2,2 0 0,0 13,15H4Z\";\r\nvar mdiBullet = \"M14,22H10V21H14V22M13,10V7H11V10L10,11.5V20H14V11.5L13,10M12,2C12,2 11,3 11,5V6H13V5C13,5 13,3 12,2Z\";\r\nvar mdiBulletinBoard = \"M12.04,2.5L9.53,5H14.53L12.04,2.5M4,7V20H20V7H4M12,0L17,5V5H20A2,2 0 0,1 22,7V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V7A2,2 0 0,1 4,5H7V5L12,0M7,18V14H12V18H7M14,17V10H18V17H14M6,12V9H11V12H6Z\";\r\nvar mdiBullhorn = \"M12,8H4A2,2 0 0,0 2,10V14A2,2 0 0,0 4,16H5V20A1,1 0 0,0 6,21H8A1,1 0 0,0 9,20V16H12L17,20V4L12,8M21.5,12C21.5,13.71 20.54,15.26 19,16V8C20.53,8.75 21.5,10.3 21.5,12Z\";\r\nvar mdiBullhornOutline = \"M12,8H4A2,2 0 0,0 2,10V14A2,2 0 0,0 4,16H5V20A1,1 0 0,0 6,21H8A1,1 0 0,0 9,20V16H12L17,20V4L12,8M15,15.6L13,14H4V10H13L15,8.4V15.6M21.5,12C21.5,13.71 20.54,15.26 19,16V8C20.53,8.75 21.5,10.3 21.5,12Z\";\r\nvar mdiBullseye = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M12,6A6,6 0 0,0 6,12A6,6 0 0,0 12,18A6,6 0 0,0 18,12A6,6 0 0,0 12,6M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiBullseyeArrow = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,10.84 21.79,9.69 21.39,8.61L19.79,10.21C19.93,10.8 20,11.4 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4C12.6,4 13.2,4.07 13.79,4.21L15.4,2.6C14.31,2.21 13.16,2 12,2M19,2L15,6V7.5L12.45,10.05C12.3,10 12.15,10 12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12C14,11.85 14,11.7 13.95,11.55L16.5,9H18L22,5H19V2M12,6A6,6 0 0,0 6,12A6,6 0 0,0 12,18A6,6 0 0,0 18,12H16A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8V6Z\";\r\nvar mdiBulma = \"M11.38 2L6.38 7L5.13 15.75L11.38 22L18.88 17L13.88 12L17.63 8.25L11.38 2Z\";\r\nvar mdiBunkBed = \"M1 2V23H3V21H21V23H23V7C23 4.79 21.21 3 19 3H10V8H3V2M6.5 2A2.5 2.5 0 0 0 4 4.5A2.5 2.5 0 0 0 6.5 7A2.5 2.5 0 0 0 9 4.5A2.5 2.5 0 0 0 6.5 2M3 11H21V13.56C20.41 13.21 19.73 13 19 13H10V18H3M6.5 12A2.5 2.5 0 0 0 4 14.5A2.5 2.5 0 0 0 6.5 17A2.5 2.5 0 0 0 9 14.5A2.5 2.5 0 0 0 6.5 12Z\";\r\nvar mdiBunkBedOutline = \"M1 2H3V9H10V3H19C21.2 3 23 4.8 23 7V23H21V21H3V23H1V2M12 5V9H21V7C21 5.9 20.1 5 19 5H12M3 11V19H10V13H19C19.7 13 20.4 13.2 21 13.6V11H3M6.5 13C7.9 13 9 14.1 9 15.5S7.9 18 6.5 18 4 16.9 4 15.5 5.1 13 6.5 13M6.5 14.6C6 14.6 5.6 15 5.6 15.5S6 16.4 6.5 16.4 7.4 16 7.4 15.5 7 14.6 6.5 14.6M12 15V19H21V17C21 15.9 20.1 15 19 15H12M6.5 3C7.9 3 9 4.1 9 5.5S7.9 8 6.5 8 4 6.9 4 5.5 5.1 3 6.5 3M6.5 4.6C6 4.6 5.6 5 5.6 5.5S6 6.4 6.5 6.4 7.4 6 7.4 5.5 7 4.6 6.5 4.6Z\";\r\nvar mdiBus = \"M18,11H6V6H18M16.5,17A1.5,1.5 0 0,1 15,15.5A1.5,1.5 0 0,1 16.5,14A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 16.5,17M7.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,14A1.5,1.5 0 0,1 9,15.5A1.5,1.5 0 0,1 7.5,17M4,16C4,16.88 4.39,17.67 5,18.22V20A1,1 0 0,0 6,21H7A1,1 0 0,0 8,20V19H16V20A1,1 0 0,0 17,21H18A1,1 0 0,0 19,20V18.22C19.61,17.67 20,16.88 20,16V6C20,2.5 16.42,2 12,2C7.58,2 4,2.5 4,6V16Z\";\r\nvar mdiBusAlert = \"M16,1A7,7 0 0,1 23,8C23,11.53 20.39,14.45 17,14.93V18C17,18.84 16.65,19.58 15.96,20.2V22C15.96,22.27 15.87,22.5 15.68,22.71C15.5,22.91 15.26,23 15,23H14C13.71,23 13.47,22.91 13.27,22.71C13.06,22.5 12.96,22.27 12.96,22V21H5.04V22C5.04,22.27 4.94,22.5 4.73,22.71C4.53,22.91 4.29,23 4,23H3C2.74,23 2.5,22.91 2.32,22.71C2.13,22.5 2.04,22.27 2.04,22V20.2C1.35,19.58 1,18.84 1,18V8C1,6.42 1.7,5.35 3.07,4.8C4.44,4.26 6.42,4 9,4L10.23,4.03C11.5,2.2 13.61,1 16,1M16,3A5,5 0 0,0 11,8A5,5 0 0,0 16,13A5,5 0 0,0 21,8A5,5 0 0,0 16,3M15,10H17V12H15V10M15,4H17V9H15V4M3,13H11.09C9.8,11.72 9,9.96 9,8H3V13M4.5,16C3.69,16 3,16.67 3,17.5A1.5,1.5 0 0,0 4.5,19C5.35,19 6,18.33 6,17.5A1.5,1.5 0 0,0 4.5,16M13.5,16C12.65,16 12,16.67 12,17.5A1.5,1.5 0 0,0 13.5,19C14.31,19 15,18.33 15,17.5A1.5,1.5 0 0,0 13.5,16Z\";\r\nvar mdiBusArticulatedEnd = \"M21.5,6L20,7.5L21.5,9L20,10.5L21.5,12L20,13.5L21.5,15H12.5A3,3 0 0,1 9.5,18A3,3 0 0,1 6.5,15H2.5V8C2.5,6.89 3.39,6 4.5,6H21.5M18.5,7.5H15V10H18.5V7.5M13.5,7.5H9.5V10H13.5V7.5M8,7.5H4V10H8V7.5M9.5,13.5A1.5,1.5 0 0,0 8,15A1.5,1.5 0 0,0 9.5,16.5A1.5,1.5 0 0,0 11,15A1.5,1.5 0 0,0 9.5,13.5Z\";\r\nvar mdiBusArticulatedFront = \"M1,6L2.5,7.5L1,9L2.5,10.5L1,12L2.5,13.5L1,15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V8C23,6.89 22.11,6 21,6H1M4,7.5H6.5V10H4V7.5M8,7.5H12V10H8V7.5M13.5,7.5H17.5V10H13.5V7.5M19,7.5H21.5V13L19,11V7.5M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiBusClock = \"M16.5,4V8.25L19.36,9.94L18.61,11.16L15,9V4H16.5M16,13C17.36,13 18.54,12.5 19.5,11.53C20.5,10.56 21,9.39 21,8C21,6.64 20.5,5.46 19.5,4.5C18.54,3.5 17.36,3 16,3C14.61,3 13.44,3.5 12.47,4.5C11.5,5.46 11,6.64 11,8C11,9.39 11.5,10.56 12.47,11.53C13.44,12.5 14.61,13 16,13M13.5,19C13.94,19 14.3,18.84 14.58,18.54C14.86,18.24 15,17.89 15,17.5C15,17.08 14.86,16.73 14.58,16.43C14.3,16.13 13.94,16 13.5,16C13.06,16 12.7,16.13 12.42,16.43C12.14,16.73 12,17.08 12,17.5C12,17.89 12.14,18.24 12.42,18.54C12.7,18.84 13.06,19 13.5,19M3,13H11.11C9.7,11.64 9,10 9,8H3V13M4.5,19C4.94,19 5.3,18.84 5.58,18.54C5.86,18.24 6,17.89 6,17.5C6,17.08 5.86,16.73 5.58,16.43C5.3,16.13 4.94,16 4.5,16C4.06,16 3.7,16.13 3.42,16.43C3.14,16.73 3,17.08 3,17.5C3,17.89 3.14,18.24 3.42,18.54C3.7,18.84 4.06,19 4.5,19M16,1C17.92,1 19.58,1.67 20.95,3.05C22.33,4.42 23,6.08 23,8C23,9.77 22.44,11.29 21.28,12.59C20.13,13.88 18.7,14.66 17,14.91V18C17,18.84 16.67,19.58 16,20.2V22C16,22.27 15.89,22.5 15.7,22.71C15.5,22.91 15.28,23 15,23H14C13.73,23 13.5,22.91 13.29,22.71C13.09,22.5 13,22.27 13,22V21H5V22C5,22.27 4.91,22.5 4.71,22.71C4.5,22.91 4.27,23 4,23H3C2.72,23 2.5,22.91 2.3,22.71C2.11,22.5 2,22.27 2,22V20.2C1.33,19.58 1,18.84 1,18V8C1,6.42 1.67,5.35 3.05,4.8C4.42,4.26 6.41,4 9,4C9.13,4 9.33,4 9.61,4C9.89,4 10.09,4.03 10.22,4.03C11.63,2 13.55,1 16,1Z\";\r\nvar mdiBusDoubleDecker = \"M3,4C1.89,4 1,4.89 1,6V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V14C23,12.89 22.11,12 21,12H19V9.5H23V6C23,4.89 22.11,4 21,4H3M2.5,5.5H6.5V8H2.5V5.5M8,5.5H12V8H8V5.5M13.5,5.5H17.5V8H13.5V5.5M19,5.5H21.5V8H19V5.5M13.5,9.5H17.5V12H13.5V9.5M2.5,9.5H6.5V12H2.5V9.5M8,9.5H12V12H8V9.5M6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5M18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5Z\";\r\nvar mdiBusMarker = \"M12 2C7.58 2 4 2.5 4 6V16A3 3 0 0 0 5 18.22V20A1 1 0 0 0 6 21H7A1 1 0 0 0 8 20V19H14A8 8 0 0 1 13 15.5A5.55 5.55 0 0 1 15.38 11H6V6H18V10A4.07 4.07 0 0 1 18.5 10A5.34 5.34 0 0 1 20 10.22V6C20 2.5 16.42 2 12 2M7.5 14A1.5 1.5 0 1 1 6 15.5A1.5 1.5 0 0 1 7.5 14M18.5 12A3.54 3.54 0 0 0 15 15.5C15 18.1 18.5 22 18.5 22S22 18.1 22 15.5A3.54 3.54 0 0 0 18.5 12M18.5 16.8A1.2 1.2 0 1 1 18.5 14.4A1.29 1.29 0 0 1 19.7 15.6A1.15 1.15 0 0 1 18.5 16.8Z\";\r\nvar mdiBusMultiple = \"M10 5C5.58 5 2 5.5 2 9V19C2 19.85 2.37 20.66 3 21.22V23C3 23.55 3.45 24 4 24H5C5.55 24 6 23.55 6 23V22H14V23C14 23.55 14.45 24 15 24H16C16.55 24 17 23.55 17 23V21.22C17.63 20.66 18 19.85 18 19V9C18 5.5 14.42 5 10 5M5.5 20C4.67 20 4 19.33 4 18.5S4.67 17 5.5 17 7 17.67 7 18.5 6.33 20 5.5 20M14.5 20C13.67 20 13 19.33 13 18.5S13.67 17 14.5 17 16 17.67 16 18.5 15.33 20 14.5 20M16 14H4V9H16V14M22 5V15C22 15.85 21.63 16.66 21 17.22V19C21 19.55 20.55 20 20 20H19.88C19.95 19.68 20 19.35 20 19V9C20 3 13 3 10 3C9.09 3 7.8 3 6.46 3.17C7.55 1.32 10.5 1 14 1C18.42 1 22 1.5 22 5Z\";\r\nvar mdiBusSchool = \"M3,6C1.89,6 1,6.89 1,8V15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V12C23,10.89 22.11,10 21,10H19V8C19,6.89 18.11,6 17,6H3M13.5,7.5H17.5V10H13.5V7.5M2.5,7.5H6.5V10H2.5V7.5M8,7.5H12V10H8V7.5M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiBusSide = \"M3,6C1.89,6 1,6.89 1,8V15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V8C23,6.89 22.11,6 21,6H3M2.5,7.5H6.5V10H2.5V7.5M8,7.5H12V10H8V7.5M13.5,7.5H17.5V10H13.5V7.5M19,7.5H21.5V13L19,11V7.5M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiBusStop = \"M22 7V16C22 16.71 21.62 17.36 21 17.72V19.25C21 19.66 20.66 20 20.25 20H19.75C19.34 20 19 19.66 19 19.25V18H12V19.25C12 19.66 11.66 20 11.25 20H10.75C10.34 20 10 19.66 10 19.25V17.72C9.39 17.36 9 16.71 9 16V7C9 4 12 4 15.5 4S22 4 22 7M13 15C13 14.45 12.55 14 12 14S11 14.45 11 15 11.45 16 12 16 13 15.55 13 15M20 15C20 14.45 19.55 14 19 14S18 14.45 18 15 18.45 16 19 16 20 15.55 20 15M20 7H11V11H20V7M7 9.5C6.97 8.12 5.83 7 4.45 7.05C3.07 7.08 1.97 8.22 2 9.6C2.03 10.77 2.86 11.77 4 12V20H5V12C6.18 11.76 7 10.71 7 9.5Z\";\r\nvar mdiBusStopCovered = \"M20 3H7V2H6A1.78 1.78 0 0 0 4.59 3H2V5H3.73C2 10.58 2 22 2 22H7V5H20M22 8.5A2.5 2.5 0 1 0 19 11V22H20V11A2.5 2.5 0 0 0 22 8.5M15 11.5V16H14V22H12.5V17H11.5V22H10V16H9V11.5A1.5 1.5 0 0 1 10.5 10H13.5A1.5 1.5 0 0 1 15 11.5M12 6.5A1.5 1.5 0 1 0 13.5 8A1.5 1.5 0 0 0 12 6.5Z\";\r\nvar mdiBusStopUncovered = \"M6 22V19H4V22H2V14A1 1 0 0 1 3 13A1 1 0 0 1 4 14V17H7A1 1 0 0 1 8 18V22M20 11V22H19V11A2.5 2.5 0 1 1 20 11M15 11.55V16H14V22H12.5V17H11.5V22H10V16H9V11.5A1.5 1.5 0 0 1 10.5 10H13.5A1.5 1.5 0 0 1 15 11.5M12 6.55A1.5 1.5 0 1 0 13.5 8A1.5 1.5 0 0 0 12 6.5Z\";\r\nvar mdiButterfly = \"M13 21H11V6L9.03 3.97L10 3L12 5L14 3L15 4L13 6V21M7 6C4.24 6 2 8.24 2 11C2 12.64 2.79 14.09 4 15H4V17C4 19.21 5.79 21 8 21C8.72 21 9.39 20.81 9.97 20.5L10 20.46V7C9.16 6.37 8.13 6 7 6M6.5 12.5L5 11L6.5 9.5L8 11L6.5 12.5M22 11C22 8.24 19.76 6 17 6C15.88 6 14.85 6.37 14 7L14 7V20.46C14.59 20.81 15.27 21 16 21C18.21 21 20 19.21 20 17V15H20C21.21 14.09 22 12.64 22 11M17.5 12.5L16 11L17.5 9.5L19 11L17.5 12.5Z\";\r\nvar mdiButterflyOutline = \"M13 21H11V6L9.03 3.97L10 3L12 5L14 3L15 4L13 6V21M14 9H14V7C14.84 6.37 15.88 6 17 6C19.76 6 22 8.24 22 11C22 12.64 21.21 14.09 20 15H20V17C20 19.21 18.21 21 16 21C15.27 21 14.59 20.81 14 20.46V18.46C14.59 18.81 15.27 19 16 19C17.1 19 18 18.1 18 17V13.83C19.17 13.42 20 12.31 20 11C20 9.35 18.67 8 17 8H17C15.88 8 14.84 8.37 14 9M10 9H10C9.16 8.37 8.13 8 7 8H7C5.33 8 4 9.35 4 11C4 12.31 4.84 13.42 6 13.83V17C6 18.1 6.9 19 8 19C8.73 19 9.41 18.81 10 18.46V20.46C9.41 20.81 8.73 21 8 21C5.79 21 4 19.21 4 17V15H4C2.79 14.09 2 12.64 2 11C2 8.24 4.24 6 7 6C8.13 6 9.16 6.37 10 7V9M9 11L7.5 9.5L6 11L7.5 12.5L9 11M18 11L16.5 9.5L15 11L16.5 12.5L18 11Z\";\r\nvar mdiCableData = \"M7.05 3.5C5.68 4.88 5.68 7.1 7.05 8.47L15.54 16.95C16.12 17.54 16.12 18.5 15.54 19.07C14.95 19.66 14 19.66 13.41 19.07L9.17 14.83L10.23 13.77L6.7 10.23L6.34 10.59L4.93 9.17C4.54 8.78 3.91 8.78 3.5 9.17L2.1 10.59C1.71 11 1.71 11.61 2.1 12L3.5 13.41L3.16 13.77L6.7 17.3L7.76 16.24L12 20.5C13.37 21.85 15.58 21.85 16.95 20.5C18.32 19.12 18.32 16.9 16.95 15.54L8.46 7.05C7.88 6.46 7.88 5.5 8.46 4.93C9.05 4.34 10 4.34 10.59 4.93L14.83 9.17L13.77 10.23L17.3 13.77L17.66 13.41L19.07 14.83C19.46 15.22 20.1 15.22 20.5 14.83L21.9 13.41C22.29 13 22.29 12.39 21.9 12L20.5 10.59L20.84 10.23L17.3 6.7L16.24 7.76L12 3.5C10.63 2.15 8.42 2.15 7.05 3.5M2.81 11.29L4.22 9.88L5.64 11.29L4.22 12.71M18.36 12.71L19.78 11.29L21.19 12.71L19.78 14.12Z\";\r\nvar mdiCached = \"M19,8L15,12H18A6,6 0 0,1 12,18C11,18 10.03,17.75 9.2,17.3L7.74,18.76C8.97,19.54 10.43,20 12,20A8,8 0 0,0 20,12H23M6,12A6,6 0 0,1 12,6C13,6 13.97,6.25 14.8,6.7L16.26,5.24C15.03,4.46 13.57,4 12,4A8,8 0 0,0 4,12H1L5,16L9,12\";\r\nvar mdiCactus = \"M14,16V21H10V18H9A3,3 0 0,1 6,15V12A1,1 0 0,1 7,11A1,1 0 0,1 8,12V15C8,15.56 8.45,16 9,16H10V6A2,2 0 0,1 12,4A2,2 0 0,1 14,6V14H15A1,1 0 0,0 16,13V11A1,1 0 0,1 17,10A1,1 0 0,1 18,11V13A3,3 0 0,1 15,16H14Z\";\r\nvar mdiCake = \"M11.5,0.5C12,0.75 13,2.4 13,3.5C13,4.6 12.33,5 11.5,5C10.67,5 10,4.85 10,3.75C10,2.65 11,2 11.5,0.5M18.5,9C21,9 23,11 23,13.5C23,15.06 22.21,16.43 21,17.24V23H12L3,23V17.24C1.79,16.43 1,15.06 1,13.5C1,11 3,9 5.5,9H10V6H13V9H18.5M12,16A2.5,2.5 0 0,0 14.5,13.5H16A2.5,2.5 0 0,0 18.5,16A2.5,2.5 0 0,0 21,13.5A2.5,2.5 0 0,0 18.5,11H5.5A2.5,2.5 0 0,0 3,13.5A2.5,2.5 0 0,0 5.5,16A2.5,2.5 0 0,0 8,13.5H9.5A2.5,2.5 0 0,0 12,16Z\";\r\nvar mdiCakeLayered = \"M21,21V17C21,15.89 20.1,15 19,15H18V12C18,10.89 17.1,10 16,10H13V8H11V10H8C6.89,10 6,10.89 6,12V15H5C3.89,15 3,15.89 3,17V21H1V23H23V21M12,7A2,2 0 0,0 14,5C14,4.62 13.9,4.27 13.71,3.97L12,1L10.28,3.97C10.1,4.27 10,4.62 10,5A2,2 0 0,0 12,7Z\";\r\nvar mdiCakeVariant = \"M12,6C13.11,6 14,5.1 14,4C14,3.62 13.9,3.27 13.71,2.97L12,0L10.29,2.97C10.1,3.27 10,3.62 10,4A2,2 0 0,0 12,6M16.6,16L15.53,14.92L14.45,16C13.15,17.29 10.87,17.3 9.56,16L8.5,14.92L7.4,16C6.75,16.64 5.88,17 4.96,17C4.23,17 3.56,16.77 3,16.39V21A1,1 0 0,0 4,22H20A1,1 0 0,0 21,21V16.39C20.44,16.77 19.77,17 19.04,17C18.12,17 17.25,16.64 16.6,16M18,9H13V7H11V9H6A3,3 0 0,0 3,12V13.54C3,14.62 3.88,15.5 4.96,15.5C5.5,15.5 6,15.3 6.34,14.93L8.5,12.8L10.61,14.93C11.35,15.67 12.64,15.67 13.38,14.93L15.5,12.8L17.65,14.93C18,15.3 18.5,15.5 19.03,15.5C20.11,15.5 21,14.62 21,13.54V12A3,3 0 0,0 18,9Z\";\r\nvar mdiCalculator = \"M7,2H17A2,2 0 0,1 19,4V20A2,2 0 0,1 17,22H7A2,2 0 0,1 5,20V4A2,2 0 0,1 7,2M7,4V8H17V4H7M7,10V12H9V10H7M11,10V12H13V10H11M15,10V12H17V10H15M7,14V16H9V14H7M11,14V16H13V14H11M15,14V16H17V14H15M7,18V20H9V18H7M11,18V20H13V18H11M15,18V20H17V18H15Z\";\r\nvar mdiCalculatorVariant = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M13 7.1L14.1 6L15.5 7.4L16.9 6L18 7.1L16.6 8.5L18 9.9L16.9 11L15.5 9.6L14.1 11L13 9.9L14.4 8.5L13 7.1M6.2 7.7H11.2V9.2H6.2V7.7M11.5 16H9.5V18H8V16H6V14.5H8V12.5H9.5V14.5H11.5V16M18 17.2H13V15.7H18V17.2M18 14.8H13V13.3H18V14.8Z\";\r\nvar mdiCalculatorVariantOutline = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M19 19H5V5H19V19M6.2 7.7H11.2V9.2H6.2V7.7M13 15.8H18V17.3H13V15.8M13 13.2H18V14.7H13V13.2M8 18H9.5V16H11.5V14.5H9.5V12.5H8V14.5H6V16H8V18M14.1 10.9L15.5 9.5L16.9 10.9L18 9.9L16.6 8.5L18 7.1L16.9 6L15.5 7.4L14.1 6L13 7.1L14.4 8.5L13 9.9L14.1 10.9Z\";\r\nvar mdiCalendar = \"M19,19H5V8H19M16,1V3H8V1H6V3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H18V1M17,12H12V17H17V12Z\";\r\nvar mdiCalendarAccount = \"M12,10C14,10 15,12.42 13.59,13.84C12.17,15.26 9.75,14.25 9.75,12.25C9.75,11 10.75,10 12,10M16.5,19H7.5V17.88C7.5,16.63 9.5,15.63 12,15.63C14.5,15.63 16.5,16.63 16.5,17.88M19,20H5V9H19M16,2V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4H18V2H16Z\";\r\nvar mdiCalendarAccountOutline = \"M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M19,8H5V6H19M12,11C14,11 15,13.42 13.59,14.84C12.17,16.26 9.75,15.25 9.75,13.25C9.75,12 10.75,11 12,11M16.5,18.88V19H7.5V18.88C7.5,17.63 9.5,16.63 12,16.63C14.5,16.63 16.5,17.63 16.5,18.88Z\";\r\nvar mdiCalendarAlert = \"M6 1V3H5C3.89 3 3 3.89 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3H18V1H16V3H8V1H6M5 8H19V19H5V7M11 9V14H13V9H11M11 16V18H13V16H11Z\";\r\nvar mdiCalendarArrowLeft = \"M19 3H18V1H16V3H8V1H6V3H5C3.89 3 3 3.89 3 5V19C3 20.1 3.89 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.89 20.1 3 19 3M19 19H5V8H19V19M12 10V12H16V15H12V17L8 13.5L12 10Z\";\r\nvar mdiCalendarArrowRight = \"M19 3H18V1H16V3H8V1H6V3H5C3.89 3 3 3.89 3 5V19C3 20.1 3.89 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.89 20.1 3 19 3M19 19H5V8H19V19M12 17V15H8V12H12V10L16 13.5L12 17Z\";\r\nvar mdiCalendarBlank = \"M19,19H5V8H19M16,1V3H8V1H6V3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H18V1\";\r\nvar mdiCalendarBlankMultiple = \"M21 17V8H7V17H21M21 3C22.1 3 23 3.9 23 5V17C23 18.1 22.1 19 21 19H7C5.89 19 5 18.1 5 17V5C5 3.9 5.9 3 7 3H8V1H10V3H18V1H20V3H21M3 21H17V23H3C1.89 23 1 22.1 1 21V9H3V21Z\";\r\nvar mdiCalendarBlankOutline = \"M19,4H18V2H16V4H8V2H6V4H5C3.89,4 3,4.9 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M19,8H5V6H19V8Z\";\r\nvar mdiCalendarCheck = \"M19,19H5V8H19M19,3H18V1H16V3H8V1H6V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M16.53,11.06L15.47,10L10.59,14.88L8.47,12.76L7.41,13.82L10.59,17L16.53,11.06Z\";\r\nvar mdiCalendarCheckOutline = \"M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M5,8V6H19V8H5M10.56,18.46L16.5,12.53L15.43,11.47L10.56,16.34L8.45,14.23L7.39,15.29L10.56,18.46Z\";\r\nvar mdiCalendarClock = \"M15,13H16.5V15.82L18.94,17.23L18.19,18.53L15,16.69V13M19,8H5V19H9.67C9.24,18.09 9,17.07 9,16A7,7 0 0,1 16,9C17.07,9 18.09,9.24 19,9.67V8M5,21C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H6V1H8V3H16V1H18V3H19A2,2 0 0,1 21,5V11.1C22.24,12.36 23,14.09 23,16A7,7 0 0,1 16,23C14.09,23 12.36,22.24 11.1,21H5M16,11.15A4.85,4.85 0 0,0 11.15,16C11.15,18.68 13.32,20.85 16,20.85A4.85,4.85 0 0,0 20.85,16C20.85,13.32 18.68,11.15 16,11.15Z\";\r\nvar mdiCalendarCursor = \"M21.7 20.26L20.29 21.67L17.06 18.5L16 20.97L14 14L21 16L18.47 17.03L21.7 20.26M19 8H5V19H13.41L13.97 21H5C3.89 21 3 20.1 3 19L3 5C3 3.9 3.89 3 5 3H6V1H8V3H16V1H18V3H19C20.1 3 21 3.9 21 5V13.95L19 13.35V8M12 10V15H7V10H12Z\";\r\nvar mdiCalendarEdit = \"M19,3H18V1H16V3H8V1H6V3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H10V19H5V8H19V9H21V5A2,2 0 0,0 19,3M21.7,13.35L20.7,14.35L18.65,12.35L19.65,11.35C19.85,11.14 20.19,11.13 20.42,11.35L21.7,12.63C21.89,12.83 21.89,13.15 21.7,13.35M12,18.94L18.07,12.88L20.12,14.88L14.06,21H12V18.94Z\";\r\nvar mdiCalendarExport = \"M12,22L16,18H13V12H11V18H8M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H8V20H5V9H19V20H16V22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4Z\";\r\nvar mdiCalendarHeart = \"M19,20V9H5V20H19M16,2H18V4H19A2,2 0 0,1 21,6V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V6A2,2 0 0,1 5,4H6V2H8V4H16V2M12,18.17L11.42,17.64C9.36,15.77 8,14.54 8,13.03C8,11.8 8.97,10.83 10.2,10.83C10.9,10.83 11.56,11.15 12,11.66C12.44,11.15 13.1,10.83 13.8,10.83C15.03,10.83 16,11.8 16,13.03C16,14.54 14.64,15.77 12.58,17.64L12,18.17Z\";\r\nvar mdiCalendarImport = \"M12,12L8,16H11V22H13V16H16M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H9V20H5V9H19V20H15V22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4Z\";\r\nvar mdiCalendarMinus = \"M19 19V8H5V19H19M16 1H18V3H19C20.11 3 21 3.9 21 5V19C21 20.11 20.11 21 19 21H5C3.89 21 3 20.1 3 19V5C3 3.89 3.89 3 5 3H6V1H8V3H16V1M16 12.5V14.5H8V12.5H16Z\";\r\nvar mdiCalendarMonth = \"M9,10V12H7V10H9M13,10V12H11V10H13M17,10V12H15V10H17M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3H6V1H8V3H16V1H18V3H19M19,19V8H5V19H19M9,14V16H7V14H9M13,14V16H11V14H13M17,14V16H15V14H17Z\";\r\nvar mdiCalendarMonthOutline = \"M7,12H9V14H7V12M21,6V20A2,2 0 0,1 19,22H5C3.89,22 3,21.1 3,20V6A2,2 0 0,1 5,4H6V2H8V4H16V2H18V4H19A2,2 0 0,1 21,6M5,8H19V6H5V8M19,20V10H5V20H19M15,14V12H17V14H15M11,14V12H13V14H11M7,16H9V18H7V16M15,18V16H17V18H15M11,18V16H13V18H11Z\";\r\nvar mdiCalendarMultiple = \"M21,17V8H7V17H21M21,3A2,2 0 0,1 23,5V17A2,2 0 0,1 21,19H7C5.89,19 5,18.1 5,17V5A2,2 0 0,1 7,3H8V1H10V3H18V1H20V3H21M3,21H17V23H3C1.89,23 1,22.1 1,21V9H3V21M19,15H15V11H19V15Z\";\r\nvar mdiCalendarMultipleCheck = \"M21,17V8H7V17H21M21,3A2,2 0 0,1 23,5V17A2,2 0 0,1 21,19H7C5.89,19 5,18.1 5,17V5A2,2 0 0,1 7,3H8V1H10V3H18V1H20V3H21M17.53,11.06L13.09,15.5L10.41,12.82L11.47,11.76L13.09,13.38L16.47,10L17.53,11.06M3,21H17V23H3C1.89,23 1,22.1 1,21V9H3V21Z\";\r\nvar mdiCalendarMultiselect = \"M19,19V8H5V19H19M16,1H18V3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H6V1H8V3H16V1M7,10H9V12H7V10M15,10H17V12H15V10M11,14H13V16H11V14M15,14H17V16H15V14Z\";\r\nvar mdiCalendarOutline = \"M19,4H18V2H16V4H8V2H6V4H5C3.89,4 3,4.9 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M19,8H5V6H19V8M12,13H17V18H12V13Z\";\r\nvar mdiCalendarPlus = \"M19 19V8H5V19H19M16 1H18V3H19C20.11 3 21 3.9 21 5V19C21 20.11 20.11 21 19 21H5C3.89 21 3 20.1 3 19V5C3 3.89 3.89 3 5 3H6V1H8V3H16V1M11 9.5H13V12.5H16V14.5H13V17.5H11V14.5H8V12.5H11V9.5Z\";\r\nvar mdiCalendarQuestion = \"M6,1V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H18V1H16V3H8V1H6M5,8H19V19H5V8M12.19,9C11.32,9 10.62,9.2 10.08,9.59C9.56,10 9.3,10.57 9.31,11.36L9.32,11.39H11.25C11.26,11.09 11.35,10.86 11.53,10.7C11.71,10.55 11.93,10.47 12.19,10.47C12.5,10.47 12.76,10.57 12.94,10.75C13.12,10.94 13.2,11.2 13.2,11.5C13.2,11.82 13.13,12.09 12.97,12.32C12.83,12.55 12.62,12.75 12.36,12.91C11.85,13.25 11.5,13.55 11.31,13.82C11.11,14.08 11,14.5 11,15H13C13,14.69 13.04,14.44 13.13,14.26C13.22,14.08 13.39,13.9 13.64,13.74C14.09,13.5 14.46,13.21 14.75,12.81C15.04,12.41 15.19,12 15.19,11.5C15.19,10.74 14.92,10.13 14.38,9.68C13.85,9.23 13.12,9 12.19,9M11,16V18H13V16H11Z\";\r\nvar mdiCalendarRange = \"M9,10H7V12H9V10M13,10H11V12H13V10M17,10H15V12H17V10M19,3H18V1H16V3H8V1H6V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,19H5V8H19V19Z\";\r\nvar mdiCalendarRangeOutline = \"M7,12H9V14H7V12M21,6V20A2,2 0 0,1 19,22H5C3.89,22 3,21.1 3,20V6A2,2 0 0,1 5,4H6V2H8V4H16V2H18V4H19A2,2 0 0,1 21,6M5,8H19V6H5V8M19,20V10H5V20H19M15,14H17V12H15V14M11,14H13V12H11V14Z\";\r\nvar mdiCalendarRefresh = \"M19 3H18V1H16V3H8V1H6V3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H14C13.4 20.5 12.9 19.8 12.5 19H5V8H19V10.6C19.7 10.7 20.4 10.9 21 11.3V5C21 3.9 20.1 3 19 3M18 12.5C19.1 12.5 20.1 12.9 20.8 13.7L22 12.5V16.5H18L19.8 14.7C19.3 14.3 18.7 14 18 14C16.6 14 15.5 15.1 15.5 16.5S16.6 19 18 19C18.8 19 19.5 18.6 20 18H21.7C21.1 19.5 19.7 20.5 18 20.5C15.8 20.5 14 18.7 14 16.5S15.8 12.5 18 12.5Z\";\r\nvar mdiCalendarRefreshOutline = \"M19 3H18V1H16V3H8V1H6V3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H14C13.4 20.5 12.9 19.8 12.5 19H5V9H19V10.6C19.7 10.7 20.4 10.9 21 11.3V5C21 3.9 20.1 3 19 3M19 7H5V5H19M18 12.5C19.1 12.5 20.1 12.9 20.8 13.7L22 12.5V16.5H18L19.8 14.7C19.3 14.3 18.7 14 18 14C16.6 14 15.5 15.1 15.5 16.5S16.6 19 18 19C18.8 19 19.5 18.6 20 18H21.7C21.1 19.5 19.7 20.5 18 20.5C15.8 20.5 14 18.7 14 16.5S15.8 12.5 18 12.5Z\";\r\nvar mdiCalendarRemove = \"M19,19H5V8H19M19,3H18V1H16V3H8V1H6V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M9.31,17L11.75,14.56L14.19,17L15.25,15.94L12.81,13.5L15.25,11.06L14.19,10L11.75,12.44L9.31,10L8.25,11.06L10.69,13.5L8.25,15.94L9.31,17Z\";\r\nvar mdiCalendarRemoveOutline = \"M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M5,8V6H19V8H5M8.23,17.41L9.29,18.47L11.73,16.03L14.17,18.47L15.23,17.41L12.79,14.97L15.23,12.53L14.17,11.47L11.73,13.91L9.29,11.47L8.23,12.53L10.67,14.97L8.23,17.41Z\";\r\nvar mdiCalendarSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M19,8H5V19H9.5C9.81,19.75 10.26,20.42 10.81,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H6V1H8V3H16V1H18V3H19A2,2 0 0,1 21,5V13.03C20.5,12.22 19.8,11.54 19,11V8Z\";\r\nvar mdiCalendarStar = \"M19,20H5V9H19M16,2V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4H18V2M10.88,13H7.27L10.19,15.11L9.08,18.56L12,16.43L14.92,18.56L13.8,15.12L16.72,13H13.12L12,9.56L10.88,13Z\";\r\nvar mdiCalendarSync = \"M18,11V12.5C21.19,12.5 23.09,16.05 21.33,18.71L20.24,17.62C21.06,15.96 19.85,14 18,14V15.5L15.75,13.25L18,11M18,22V20.5C14.81,20.5 12.91,16.95 14.67,14.29L15.76,15.38C14.94,17.04 16.15,19 18,19V17.5L20.25,19.75L18,22M19,3H18V1H16V3H8V1H6V3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H14C13.36,20.45 12.86,19.77 12.5,19H5V8H19V10.59C19.71,10.7 20.39,10.94 21,11.31V5A2,2 0 0,0 19,3Z\";\r\nvar mdiCalendarSyncOutline = \"M18,11V12.5C21.19,12.5 23.09,16.05 21.33,18.71L20.24,17.62C21.06,15.96 19.85,14 18,14V15.5L15.75,13.25L18,11M18,22V20.5C14.81,20.5 12.91,16.95 14.67,14.29L15.76,15.38C14.94,17.04 16.15,19 18,19V17.5L20.25,19.75L18,22M19,3H18V1H16V3H8V1H6V3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H14C13.36,20.45 12.86,19.77 12.5,19H5V9H19V10.59C19.71,10.7 20.39,10.94 21,11.31V5A2,2 0 0,0 19,3M19,7H5V5H19\";\r\nvar mdiCalendarText = \"M14,14H7V16H14M19,19H5V8H19M19,3H18V1H16V3H8V1H6V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M17,10H7V12H17V10Z\";\r\nvar mdiCalendarTextOutline = \"M19,4H18V2H16V4H8V2H6V4H5A2,2 0 0,0 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M5,8V6H19V8H5M7,12H17V14H7V12M7,16H14V18H7V16Z\";\r\nvar mdiCalendarToday = \"M7,10H12V15H7M19,19H5V8H19M19,3H18V1H16V3H8V1H6V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiCalendarWeek = \"M6 1H8V3H16V1H18V3H19C20.11 3 21 3.9 21 5V19C21 20.11 20.11 21 19 21H5C3.89 21 3 20.1 3 19V5C3 3.89 3.89 3 5 3H6V1M5 8V19H19V8H5M7 10H17V12H7V10Z\";\r\nvar mdiCalendarWeekBegin = \"M19,19H5V8H19M16,1V3H8V1H6V3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H18V1M9,10H7V17H9V10Z\";\r\nvar mdiCalendarWeekend = \"M19,20V9H5V20H19M16,2H18V4H19A2,2 0 0,1 21,6V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V6A2,2 0 0,1 5,4H6V2H8V4H16V2M7,18V11H9V18H7M15,11H17V18H15V11Z\";\r\nvar mdiCalendarWeekendOutline = \"M19,4A2,2 0 0,1 21,6V20A2,2 0 0,1 19,22H5C3.89,22 3,21.1 3,20V6A2,2 0 0,1 5,4H6V2H8V4H16V2H18V4H19M19,20V10H5V20H19M19,8V6H5V8H19M7,12H9V18H7V12M15,12H17V18H15V12Z\";\r\nvar mdiCallMade = \"M9,5V7H15.59L4,18.59L5.41,20L17,8.41V15H19V5\";\r\nvar mdiCallMerge = \"M17,20.41L18.41,19L15,15.59L13.59,17M7.5,8H11V13.59L5.59,19L7,20.41L13,14.41V8H16.5L12,3.5\";\r\nvar mdiCallMissed = \"M19.59,7L12,14.59L6.41,9H11V7H3V15H5V10.41L12,17.41L21,8.41\";\r\nvar mdiCallReceived = \"M20,5.41L18.59,4L7,15.59V9H5V19H15V17H8.41\";\r\nvar mdiCallSplit = \"M14,4L16.29,6.29L13.41,9.17L14.83,10.59L17.71,7.71L20,10V4M10,4H4V10L6.29,7.71L11,12.41V20H13V11.59L7.71,6.29\";\r\nvar mdiCamcorder = \"M7 2C4.24 2 2 4.24 2 7V20C2 21.1 2.9 22 4 22H10C11.1 22 12 21.1 12 20V7C12 4.24 9.76 2 7 2M5 20C4.45 20 4 19.55 4 19S4.45 18 5 18 6 18.45 6 19 5.55 20 5 20M7 10C5.34 10 4 8.66 4 7S5.34 4 7 4 10 5.34 10 7 8.66 10 7 10M22 9V14C22 15.1 21.1 16 20 16H13V14H20V9H13V7H20C21.1 7 22 7.9 22 9Z\";\r\nvar mdiCamcorderOff = \"M22.1 21.5L9.4 8.8L2.4 1.8L1.1 3L2.7 4.6C2.2 5.3 2 6.1 2 7V20C2 21.1 2.9 22 4 22H10C11.1 22 12 21.1 12 20V13.9L13 14.9V16H14.1L20.8 22.7L22.1 21.5M5 20C4.5 20 4 19.5 4 19S4.5 18 5 18 6 18.5 6 19 5.5 20 5 20M7 10C5.3 10 4 8.7 4 7C4 6.7 4.1 6.4 4.2 6.1L8 9.9C7.6 9.9 7.3 10 7 10M7.2 4L5.5 2.3C6 2.1 6.5 2 7 2C9.8 2 12 4.2 12 7V8.8L10 6.8C9.9 5.3 8.7 4.1 7.2 4M20 9H13V7H20C21.1 7 22 7.9 22 9V14C22 15.1 21.1 16 20 16H19.2L17.2 14H20V9Z\";\r\nvar mdiCamera = \"M4,4H7L9,2H15L17,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12A5,5 0 0,0 12,7M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9Z\";\r\nvar mdiCameraAccount = \"M4,5H7L9,3H15L17,5H20A2,2 0 0,1 22,7V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V7A2,2 0 0,1 4,5M16,17V16C16,14.67 13.33,14 12,14C10.67,14 8,14.67 8,16V17H16M12,9A2,2 0 0,0 10,11A2,2 0 0,0 12,13A2,2 0 0,0 14,11A2,2 0 0,0 12,9Z\";\r\nvar mdiCameraBurst = \"M1,5H3V19H1V5M5,5H7V19H5V5M22,5H10A1,1 0 0,0 9,6V18A1,1 0 0,0 10,19H22A1,1 0 0,0 23,18V6A1,1 0 0,0 22,5M11,17L13.5,13.85L15.29,16L17.79,12.78L21,17H11Z\";\r\nvar mdiCameraControl = \"M9,12C9,11.19 9.3,10.5 9.89,9.89C10.5,9.3 11.19,9 12,9C12.81,9 13.5,9.3 14.11,9.89C14.7,10.5 15,11.19 15,12C15,12.81 14.7,13.5 14.11,14.11C13.5,14.7 12.81,15 12,15C11.19,15 10.5,14.7 9.89,14.11C9.3,13.5 9,12.81 9,12M5.53,8.44L7.31,10.22L5.53,12L7.31,13.78L5.53,15.56L2,12L5.53,8.44M8.44,18.47L10.22,16.69L12,18.47L13.78,16.69L15.56,18.47L12,22L8.44,18.47M18.47,15.56L16.69,13.78L18.47,12L16.69,10.22L18.47,8.44L22,12L18.47,15.56M15.56,5.53L13.78,7.31L12,5.53L10.22,7.31L8.44,5.53L12,2L15.56,5.53Z\";\r\nvar mdiCameraEnhance = \"M9,3L7.17,5H4A2,2 0 0,0 2,7V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V7A2,2 0 0,0 20,5H16.83L15,3M12,18A5,5 0 0,1 7,13A5,5 0 0,1 12,8A5,5 0 0,1 17,13A5,5 0 0,1 12,18M12,17L13.25,14.25L16,13L13.25,11.75L12,9L10.75,11.75L8,13L10.75,14.25\";\r\nvar mdiCameraEnhanceOutline = \"M12,10L11.06,12.06L9,13L11.06,13.94L12,16L12.94,13.94L15,13L12.94,12.06L12,10M20,5H16.83L15,3H9L7.17,5H4A2,2 0 0,0 2,7V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V7A2,2 0 0,0 20,5M20,19H4V7H8.05L8.64,6.35L9.88,5H14.12L15.36,6.35L15.95,7H20V19M12,8A5,5 0 0,0 7,13A5,5 0 0,0 12,18A5,5 0 0,0 17,13A5,5 0 0,0 12,8M12,16A3,3 0 0,1 9,13A3,3 0 0,1 12,10A3,3 0 0,1 15,13A3,3 0 0,1 12,16Z\";\r\nvar mdiCameraFlip = \"M20 5H17L15 3H9L7 5H4C2.9 5 2 5.9 2 7V19C2 20.11 2.9 21 4 21H20C21.11 21 22 20.11 22 19V7C22 5.9 21.11 5 20 5M5 12H7.1C7.65 9.29 10.29 7.55 13 8.1C13.76 8.25 14.43 8.59 15 9L13.56 10.45C13.11 10.17 12.58 10 12 10C10.74 10 9.6 10.8 9.18 12H11L8 15L5 12M16.91 14C16.36 16.71 13.72 18.45 11 17.9C10.25 17.74 9.58 17.41 9 17L10.44 15.55C10.9 15.83 11.43 16 12 16C13.27 16 14.41 15.2 14.83 14H13L16 11L19 14H16.91Z\";\r\nvar mdiCameraFlipOutline = \"M20 5H16.83L15 3H9L7.17 5H4C2.9 5 2 5.9 2 7V19C2 20.11 2.9 21 4 21H20C21.11 21 22 20.11 22 19V7C22 5.9 21.11 5 20 5M20 19H4V7H8.05L9.88 5H14.12L16 7H20V19M5 12H7.1C7.65 9.29 10.29 7.55 13 8.1C13.76 8.25 14.43 8.59 15 9L13.56 10.45C13.11 10.17 12.58 10 12 10C10.74 10 9.6 10.8 9.18 12H11L8 15L5 12M16.91 14C16.36 16.71 13.72 18.45 11 17.9C10.25 17.74 9.58 17.41 9 17L10.44 15.55C10.9 15.83 11.43 16 12 16C13.27 16 14.41 15.2 14.83 14H13L16 11L19 14H16.91Z\";\r\nvar mdiCameraFront = \"M7,2H17V12.5C17,10.83 13.67,10 12,10C10.33,10 7,10.83 7,12.5M17,0H7A2,2 0 0,0 5,2V16A2,2 0 0,0 7,18H17A2,2 0 0,0 19,16V2A2,2 0 0,0 17,0M12,8A2,2 0 0,0 14,6A2,2 0 0,0 12,4A2,2 0 0,0 10,6A2,2 0 0,0 12,8M14,20V22H19V20M10,20H5V22H10V24L13,21L10,18V20Z\";\r\nvar mdiCameraFrontVariant = \"M6,0H18A2,2 0 0,1 20,2V22A2,2 0 0,1 18,24H6A2,2 0 0,1 4,22V2A2,2 0 0,1 6,0M12,6A3,3 0 0,1 15,9A3,3 0 0,1 12,12A3,3 0 0,1 9,9A3,3 0 0,1 12,6M11,1V3H13V1H11M6,4V16.5C6,15.12 8.69,14 12,14C15.31,14 18,15.12 18,16.5V4H6M13,18H9V20H13V22L16,19L13,16V18Z\";\r\nvar mdiCameraGopro = \"M20,5H15A2,2 0 0,0 13,7V12A2,2 0 0,0 15,14H20A2,2 0 0,0 22,12V7A2,2 0 0,0 20,5M17.5,12.5A3,3 0 0,1 14.5,9.5A3,3 0 0,1 17.5,6.5A3,3 0 0,1 20.5,9.5A3,3 0 0,1 17.5,12.5M17.5,11A1.5,1.5 0 0,1 16,9.5A1.5,1.5 0 0,1 17.5,8A1.5,1.5 0 0,1 19,9.5A1.5,1.5 0 0,1 17.5,11M12,15V5H4A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V15H12M10,12H4V7H10V12Z\";\r\nvar mdiCameraImage = \"M4,5H7L9,3H15L17,5H20A2,2 0 0,1 22,7V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V7A2,2 0 0,1 4,5M13.09,9.45L11.05,12.18L12.6,14.25L11.73,14.91L9.27,11.64L6,16H18L13.09,9.45Z\";\r\nvar mdiCameraIris = \"M13.73,15L9.83,21.76C10.53,21.91 11.25,22 12,22C14.4,22 16.6,21.15 18.32,19.75L14.66,13.4M2.46,15C3.38,17.92 5.61,20.26 8.45,21.34L12.12,15M8.54,12L4.64,5.25C3,7 2,9.39 2,12C2,12.68 2.07,13.35 2.2,14H9.69M21.8,10H14.31L14.6,10.5L19.36,18.75C21,16.97 22,14.6 22,12C22,11.31 21.93,10.64 21.8,10M21.54,9C20.62,6.07 18.39,3.74 15.55,2.66L11.88,9M9.4,10.5L14.17,2.24C13.47,2.09 12.75,2 12,2C9.6,2 7.4,2.84 5.68,4.25L9.34,10.6L9.4,10.5Z\";\r\nvar mdiCameraMeteringCenter = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H20V6H4M12,10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 12,10.5M12,7.5C14.14,7.5 15.93,9 16.39,11H14.83C14.42,9.83 13.31,9 12,9C10.69,9 9.58,9.83 9.17,11H7.61C8.07,9 9.86,7.5 12,7.5M12,16.5C9.86,16.5 8.07,15 7.61,13H9.17C9.58,14.17 10.69,15 12,15C13.31,15 14.42,14.17 14.83,13H16.39C15.93,15 14.14,16.5 12,16.5Z\";\r\nvar mdiCameraMeteringMatrix = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H20V6H4M5.5,7.5H11V9.17C10.15,9.47 9.47,10.15 9.17,11H5.5V7.5M18.5,7.5V11H14.83C14.53,10.15 13.85,9.47 13,9.17V7.5H18.5M18.5,16.5H13V14.83C13.85,14.53 14.53,13.85 14.83,13H18.5V16.5M5.5,16.5V13H9.17C9.47,13.85 10.15,14.53 11,14.83V16.5H5.5M12,10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 12,10.5Z\";\r\nvar mdiCameraMeteringPartial = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H20V6H4M12,7.5C14.14,7.5 15.93,9 16.39,11H14.83C14.42,9.83 13.31,9 12,9C10.69,9 9.58,9.83 9.17,11H7.61C8.07,9 9.86,7.5 12,7.5M12,16.5C9.86,16.5 8.07,15 7.61,13H9.17C9.58,14.17 10.69,15 12,15C13.31,15 14.42,14.17 14.83,13H16.39C15.93,15 14.14,16.5 12,16.5Z\";\r\nvar mdiCameraMeteringSpot = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H20V6H4M12,10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 12,10.5Z\";\r\nvar mdiCameraOff = \"M1.2,4.47L2.5,3.2L20,20.72L18.73,22L16.73,20H4A2,2 0 0,1 2,18V6C2,5.78 2.04,5.57 2.1,5.37L1.2,4.47M7,4L9,2H15L17,4H20A2,2 0 0,1 22,6V18C22,18.6 21.74,19.13 21.32,19.5L16.33,14.5C16.76,13.77 17,12.91 17,12A5,5 0 0,0 12,7C11.09,7 10.23,7.24 9.5,7.67L5.82,4H7M7,12A5,5 0 0,0 12,17C12.5,17 13.03,16.92 13.5,16.77L11.72,15C10.29,14.85 9.15,13.71 9,12.28L7.23,10.5C7.08,10.97 7,11.5 7,12M12,9A3,3 0 0,1 15,12C15,12.35 14.94,12.69 14.83,13L11,9.17C11.31,9.06 11.65,9 12,9Z\";\r\nvar mdiCameraOutline = \"M20,4H16.83L15,2H9L7.17,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6A2,2 0 0,0 20,4M20,18H4V6H8.05L9.88,4H14.12L15.95,6H20V18M12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12A5,5 0 0,0 12,7M12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15Z\";\r\nvar mdiCameraPartyMode = \"M12,17C10.37,17 8.94,16.21 8,15H12A3,3 0 0,0 15,12C15,11.65 14.93,11.31 14.82,11H16.9C16.96,11.32 17,11.66 17,12A5,5 0 0,1 12,17M12,7C13.63,7 15.06,7.79 16,9H12A3,3 0 0,0 9,12C9,12.35 9.07,12.68 9.18,13H7.1C7.03,12.68 7,12.34 7,12A5,5 0 0,1 12,7M20,4H16.83L15,2H9L7.17,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiCameraPlus = \"M3 4V1H5V4H8V6H5V9H3V6H0V4M6 10V7H9V4H16L17.8 6H21C22.1 6 23 6.9 23 8V20C23 21.1 22.1 22 21 22H5C3.9 22 3 21.1 3 20V10M13 19C17.45 19 19.69 13.62 16.54 10.46C13.39 7.31 8 9.55 8 14C8 16.76 10.24 19 13 19M9.8 14C9.8 16.85 13.25 18.28 15.26 16.26C17.28 14.25 15.85 10.8 13 10.8C11.24 10.8 9.8 12.24 9.8 14Z\";\r\nvar mdiCameraPlusOutline = \"M21 6H17.8L16 4H10V6H15.1L17 8H21V20H5V11H3V20C3 21.1 3.9 22 5 22H21C22.1 22 23 21.1 23 20V8C23 6.9 22.1 6 21 6M8 14C8 18.45 13.39 20.69 16.54 17.54C19.69 14.39 17.45 9 13 9C10.24 9 8 11.24 8 14M13 11C14.64 11.05 15.95 12.36 16 14C15.95 15.64 14.64 16.95 13 17C11.36 16.95 10.05 15.64 10 14C10.05 12.36 11.36 11.05 13 11M5 6H8V4H5V1H3V4H0V6H3V9H5\";\r\nvar mdiCameraRear = \"M12,6C10.89,6 10,5.1 10,4A2,2 0 0,1 12,2C13.09,2 14,2.9 14,4A2,2 0 0,1 12,6M17,0H7A2,2 0 0,0 5,2V16A2,2 0 0,0 7,18H17A2,2 0 0,0 19,16V2A2,2 0 0,0 17,0M14,20V22H19V20M10,20H5V22H10V24L13,21L10,18V20Z\";\r\nvar mdiCameraRearVariant = \"M6,0H18A2,2 0 0,1 20,2V22A2,2 0 0,1 18,24H6A2,2 0 0,1 4,22V2A2,2 0 0,1 6,0M12,2A2,2 0 0,0 10,4A2,2 0 0,0 12,6A2,2 0 0,0 14,4A2,2 0 0,0 12,2M13,18H9V20H13V22L16,19L13,16V18Z\";\r\nvar mdiCameraRetake = \"M20,5H17L15,3H9L7,5H4A2,2 0 0,0 2,7V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V7A2,2 0 0,0 20,5M12,18C10.92,18 9.86,17.65 9,17L10.44,15.56C10.91,15.85 11.45,16 12,16A3,3 0 0,0 15,13A3,3 0 0,0 12,10C10.74,10 9.6,10.8 9.18,12H11L8,15L5,12H7.1C7.65,9.29 10.29,7.55 13,8.1C15.7,8.65 17.45,11.29 16.9,14C16.42,16.33 14.38,18 12,18Z\";\r\nvar mdiCameraRetakeOutline = \"M20,5H16.83L15,3H9L7.17,5H4A2,2 0 0,0 2,7V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V7A2,2 0 0,0 20,5M20,19H4V7H8.05L9.88,5H14.12L16,7H20V19M12,18C10.92,18 9.86,17.65 9,17L10.44,15.56C10.91,15.85 11.45,16 12,16A3,3 0 0,0 15,13A3,3 0 0,0 12,10C10.74,10 9.6,10.8 9.18,12H11L8,15L5,12H7.1C7.65,9.29 10.29,7.55 13,8.1C15.7,8.65 17.45,11.29 16.9,14C16.42,16.33 14.38,18 12,18Z\";\r\nvar mdiCameraSwitch = \"M15,15.5V13H9V15.5L5.5,12L9,8.5V11H15V8.5L18.5,12M20,4H16.83L15,2H9L7.17,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiCameraSwitchOutline = \"M20 4H16.8L15 2H9L7.2 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4M9.9 4H14.1L15.9 6H20V18H4V6H8.1M15 11H9V8.5L5.5 12L9 15.5V13H15V15.5L18.5 12L15 8.5V11Z\";\r\nvar mdiCameraTimer = \"M4.94,6.35C4.55,5.96 4.55,5.32 4.94,4.93C5.33,4.54 5.96,4.54 6.35,4.93L13.07,10.31L13.42,10.59C14.2,11.37 14.2,12.64 13.42,13.42C12.64,14.2 11.37,14.2 10.59,13.42L10.31,13.07L4.94,6.35M12,20A8,8 0 0,0 20,12C20,9.79 19.1,7.79 17.66,6.34L19.07,4.93C20.88,6.74 22,9.24 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12H4A8,8 0 0,0 12,20M12,1A2,2 0 0,1 14,3A2,2 0 0,1 12,5A2,2 0 0,1 10,3A2,2 0 0,1 12,1Z\";\r\nvar mdiCameraWireless = \"M12,10.8A3.2,3.2 0 0,1 15.2,14A3.2,3.2 0 0,1 12,17.2A3.2,3.2 0 0,1 8.8,14A3.2,3.2 0 0,1 12,10.8M16,3.33V2A6,6 0 0,1 22,8H20.67C20.67,5.42 18.58,3.33 16,3.33M16,6V4.67C17.84,4.67 19.33,6.16 19.33,8H18C18,6.89 17.11,6 16,6M17,9H22V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V8A2,2 0 0,1 4,6H7.17L9,4H15V7C16.11,7 17,7.89 17,9M12,19A5,5 0 0,0 17,14A5,5 0 0,0 12,9A5,5 0 0,0 7,14A5,5 0 0,0 12,19Z\";\r\nvar mdiCameraWirelessOutline = \"M20,9V20H4V8H8.05L9.88,6H15V4H9L7.17,6H4A2,2 0 0,0 2,8V20A2,2 0 0,0 4,22H20A2,2 0 0,0 22,20V9H20M20.67,8H22C22,4.68 19.31,2 16,2V3.33C18.58,3.33 20.66,5.41 20.67,8M18,8H19.33C19.32,6.15 17.84,4.67 16,4.67V6C17.11,6 18,6.89 18,8M7,14A5,5 0 0,0 12,19A5,5 0 0,0 17,14A5,5 0 0,0 12,9A5,5 0 0,0 7,14M15,14A3,3 0 0,1 12,17A3,3 0 0,1 9,14A3,3 0 0,1 12,11A3,3 0 0,1 15,14Z\";\r\nvar mdiCampfire = \"M15.9,18.5L21.9,20.1L21.5,22L12.1,19.5L2.7,22L2.2,20.1L8.2,18.5L2.1,16.9L2.6,15L12,17.5L21.4,15L21.9,16.9L15.9,18.5M16.07,7.92C15.91,7.7 15.71,7.5 15.5,7.33C15.05,6.9 14.5,6.59 14.06,6.13C13,5.08 12.79,3.34 13.44,2C12.79,2.17 12.18,2.54 11.67,2.95C9.84,4.46 9.11,7.1 10,9.38C10,9.45 10.04,9.53 10.04,9.62C10.04,9.78 9.93,9.92 9.79,10C9.63,10.05 9.46,10 9.33,9.9C9.28,9.86 9.25,9.82 9.22,9.77C8.42,8.74 8.29,7.26 8.84,6.07C7.65,7.06 7,8.72 7.11,10.29C7.13,10.65 7.18,11 7.3,11.36C7.41,11.8 7.59,12.23 7.82,12.61C8.57,13.86 9.9,14.76 11.32,14.94C12.84,15.14 14.46,14.85 15.63,13.79C16.93,12.59 17.4,10.67 16.71,9L16.61,8.83C16.47,8.5 16.28,8.2 16.04,7.93L16.07,7.92M13.83,12.47C13.63,12.65 13.31,12.83 13.05,12.91C12.26,13.19 11.46,12.79 11,12.31C11.84,12.11 12.34,11.47 12.5,10.83C12.61,10.25 12.39,9.78 12.29,9.22C12.21,8.69 12.22,8.23 12.42,7.73C12.55,8 12.69,8.28 12.86,8.5C13.41,9.22 14.27,9.54 14.45,10.5C14.47,10.63 14.5,10.72 14.5,10.83C14.5,11.43 14.26,12.07 13.82,12.47\";\r\nvar mdiCancel = \"M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22 2 17.5 2 12 6.5 2 12 2M12 4C10.1 4 8.4 4.6 7.1 5.7L18.3 16.9C19.3 15.5 20 13.8 20 12C20 7.6 16.4 4 12 4M16.9 18.3L5.7 7.1C4.6 8.4 4 10.1 4 12C4 16.4 7.6 20 12 20C13.9 20 15.6 19.4 16.9 18.3Z\";\r\nvar mdiCandle = \"M12.5,2C10.84,2 9.5,5.34 9.5,7A3,3 0 0,0 12.5,10A3,3 0 0,0 15.5,7C15.5,5.34 14.16,2 12.5,2M12.5,6.5A1,1 0 0,1 13.5,7.5A1,1 0 0,1 12.5,8.5A1,1 0 0,1 11.5,7.5A1,1 0 0,1 12.5,6.5M10,11A1,1 0 0,0 9,12V20H7A1,1 0 0,1 6,19V18A1,1 0 0,0 5,17A1,1 0 0,0 4,18V19A3,3 0 0,0 7,22H19A1,1 0 0,0 20,21A1,1 0 0,0 19,20H16V12A1,1 0 0,0 15,11H10Z\";\r\nvar mdiCandycane = \"M10,10A2,2 0 0,1 8,12A2,2 0 0,1 6,10V8C6,7.37 6.1,6.77 6.27,6.2L10,9.93V10M12,2C12.74,2 13.44,2.13 14.09,2.38L11.97,6C11.14,6 10.44,6.5 10.15,7.25L7.24,4.34C8.34,2.92 10.06,2 12,2M17.76,6.31L14,10.07V8C14,7.62 13.9,7.27 13.72,6.97L15.83,3.38C16.74,4.13 17.42,5.15 17.76,6.31M18,13.09L14,17.09V12.9L18,8.9V13.09M18,20A2,2 0 0,1 16,22A2,2 0 0,1 14,20V19.91L18,15.91V20Z\";\r\nvar mdiCannabis = \"M11.5,22V17.35C11,18.13 10,19.09 8.03,19.81C8.03,19.81 8.53,18.1 9.94,16.95C8.64,17.23 6.68,17.19 4,16C4,16 6.47,14.59 9.28,14.97C7.69,14 5.7,12.08 4.17,8.11C4.17,8.11 8.67,9.34 10.91,13.14C8.88,8.24 12,2 12,2C14.43,7.47 13.91,11.1 13.12,13.1C15.37,9.33 19.83,8.11 19.83,8.11C18.3,12.08 16.31,14 14.72,14.97C17.53,14.59 20,16 20,16C17.32,17.19 15.36,17.23 14.06,16.95C15.47,18.1 15.97,19.81 15.97,19.81C14,19.09 13,18.13 12.5,17.35V22H11.5Z\";\r\nvar mdiCapsLock = \"M9.96,13.71L12,8.29L14.03,13.72M11.14,6L6.43,18H8.36L9.32,15.43H14.68L15.64,18H17.57L12.86,6H11.14M20,2H4C2.89,2 2,2.89 2,4V20C2,21.11 2.9,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.1,2 20,2M20,20H4V4H20V20Z\";\r\nvar mdiCar = \"M5,11L6.5,6.5H17.5L19,11M17.5,16A1.5,1.5 0 0,1 16,14.5A1.5,1.5 0 0,1 17.5,13A1.5,1.5 0 0,1 19,14.5A1.5,1.5 0 0,1 17.5,16M6.5,16A1.5,1.5 0 0,1 5,14.5A1.5,1.5 0 0,1 6.5,13A1.5,1.5 0 0,1 8,14.5A1.5,1.5 0 0,1 6.5,16M18.92,6C18.72,5.42 18.16,5 17.5,5H6.5C5.84,5 5.28,5.42 5.08,6L3,12V20A1,1 0 0,0 4,21H5A1,1 0 0,0 6,20V19H18V20A1,1 0 0,0 19,21H20A1,1 0 0,0 21,20V12L18.92,6Z\";\r\nvar mdiCar2Plus = \"M8 16C8 13.6 9.1 11.5 10.7 10H3L4.5 5.5H15.5L16.3 8C16.9 8 17.5 8.1 18 8.3L16.9 5C16.7 4.4 16.1 4 15.5 4H4.5C3.8 4 3.3 4.4 3.1 5L1 11V19C1 19.5 1.5 20 2 20H3C3.5 20 4 19.5 4 19V18H8.3C8.1 17.4 8 16.7 8 16M4.5 15C3.7 15 3 14.3 3 13.5S3.7 12 4.5 12 6 12.7 6 13.5 5.3 15 4.5 15M16 20V18H13V17H14C15.1 17 16 16.1 16 15V14C16 12.9 15.1 12 14 12H11V14H14V15H13C11.9 15 11 15.9 11 17V20M23 17H21V19H19V17H17V15H19V13H21V15H23V17Z\";\r\nvar mdiCar3Plus = \"M16.9 5C16.7 4.4 16.1 4 15.5 4H4.5C3.8 4 3.3 4.4 3.1 5L1 11V19C1 19.5 1.5 20 2 20H3C3.5 20 4 19.5 4 19V18H8.3C8.1 17.4 8 16.7 8 16C8 13.6 9.1 11.5 10.7 10H3L4.5 5.5H15.5L16.3 8C16.9 8 17.5 8.1 18 8.3L16.9 5M4.5 12C5.3 12 6 12.7 6 13.5S5.3 15 4.5 15 3 14.3 3 13.5 3.7 12 4.5 12M23 17H21V19H19V17H17V15H19V13H21V15H23V17M14.5 16C15.3 16 16 14.8 16 14C16 12.9 15.1 12 14 12H11V14H14V15H12V17H14V18H11V20H14C15.1 20 16 19.1 16 18C16 17.2 15.3 16 14.5 16Z\";\r\nvar mdiCarArrowLeft = \"M12 18C12 14.69 14.69 12 18 12C19.09 12 20.12 12.3 21 12.81V12L18.92 6C18.72 5.42 18.16 5 17.5 5H6.5C5.84 5 5.28 5.42 5.08 6L3 12V20C3 20.55 3.45 21 4 21H5C5.55 21 6 20.55 6 20V19H12.09C12.04 18.67 12 18.34 12 18M6.5 6.5H17.5L19 11H5L6.5 6.5M6.5 16C5.67 16 5 15.33 5 14.5S5.67 13 6.5 13 8 13.67 8 14.5 7.33 16 6.5 16M18 15V17H22V19H18V21L15 18L18 15\";\r\nvar mdiCarArrowRight = \"M12 18C12 14.69 14.69 12 18 12C19.09 12 20.12 12.3 21 12.81V12L18.92 6C18.72 5.42 18.16 5 17.5 5H6.5C5.84 5 5.28 5.42 5.08 6L3 12V20C3 20.55 3.45 21 4 21H5C5.55 21 6 20.55 6 20V19H12.09C12.04 18.67 12 18.34 12 18M6.5 6.5H17.5L19 11H5L6.5 6.5M6.5 16C5.67 16 5 15.33 5 14.5S5.67 13 6.5 13 8 13.67 8 14.5 7.33 16 6.5 16M19 21V19H15V17H19V15L22 18L19 21\";\r\nvar mdiCarBack = \"M6,11L7,7H17L18,11M18.92,6C18.71,5.4 18.14,5 17.5,5H6.5C5.86,5 5.29,5.4 5.08,6L3,12V20A1,1 0 0,0 4,21H5A1,1 0 0,0 6,20V18H18V20A1,1 0 0,0 19,21H20A1,1 0 0,0 21,20V12L18.92,6M7,16H5V14H7V16M19,16H17V14H19V16M14,16H10V14H14V16Z\";\r\nvar mdiCarBattery = \"M4,3V6H1V20H23V6H20V3H14V6H10V3H4M3,8H21V18H3V8M15,10V12H13V14H15V16H17V14H19V12H17V10H15M5,12V14H11V12H5Z\";\r\nvar mdiCarBrakeAbs = \"M24,12C24,15.31 22.66,18.31 20.5,20.5L19.42,19.42C21.32,17.5 22.5,14.9 22.5,12C22.5,9.11 21.32,6.5 19.42,4.58L20.5,3.5C22.66,5.69 24,8.69 24,12M20,9.6V8H16.8C15.92,8 15.2,8.72 15.2,9.6V11.2A1.6,1.6 0 0,0 16.8,12.8H18.4V14.4H15.2V16H18.4C19.28,16 20,15.28 20,14.4V12.8A1.6,1.6 0 0,0 18.4,11.2H16.8V9.6H20M8.42,6C9.47,5.37 10.69,5 12,5C13.31,5 14.53,5.37 15.58,6H18.69C17.05,4.16 14.66,3 12,3C9.34,3 6.95,4.16 5.31,6H8.42M13.2,12C13.84,12 14.4,12.56 14.4,13.2V14.4A1.6,1.6 0 0,1 12.8,16H9.6V8H12.8A1.6,1.6 0 0,1 14.4,9.6V10.8C14.4,11.44 13.84,12 13.2,12M12.8,12.8H11.2V14.4H12.8V12.8M12.8,9.6H11.2V11.2H12.8V9.6M4.58,4.58L3.5,3.5C1.34,5.69 0,8.69 0,12C0,15.31 1.34,18.31 3.5,20.5L4.58,19.42C2.68,17.5 1.5,14.9 1.5,12C1.5,9.11 2.68,6.5 4.58,4.58M7.2,16V12.8H5.6V16H4V9.6A1.6,1.6 0 0,1 5.6,8H7.2C8.08,8 8.8,8.72 8.8,9.6V16H7.2M7.2,11.2V9.6H5.6V11.2H7.2M15.58,18C14.53,18.63 13.31,19 12,19C10.69,19 9.47,18.63 8.42,18H5.31C6.95,19.84 9.34,21 12,21C14.66,21 17.05,19.84 18.69,18H15.58Z\";\r\nvar mdiCarBrakeAlert = \"M11,15H13V17H11V15M11,7H13V13H11V7M12,3A9,9 0 0,0 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3M12,19C8.14,19 5,15.86 5,12C5,8.14 8.14,5 12,5C15.86,5 19,8.14 19,12C19,15.86 15.86,19 12,19M20.5,20.5C22.66,18.31 24,15.31 24,12C24,8.69 22.66,5.69 20.5,3.5L19.42,4.58C21.32,6.5 22.5,9.11 22.5,12C22.5,14.9 21.32,17.5 19.42,19.42L20.5,20.5M4.58,19.42C2.68,17.5 1.5,14.9 1.5,12C1.5,9.11 2.68,6.5 4.58,4.58L3.5,3.5C1.34,5.69 0,8.69 0,12C0,15.31 1.34,18.31 3.5,20.5L4.58,19.42Z\";\r\nvar mdiCarBrakeHold = \"M12,3C7,3 3,7 3,12C3,17 7,21 12,21C17,21 21,17 21,12C21,7 17,3 12,3M12,19C8.1,19 5,15.9 5,12C5,8.1 8.1,5 12,5C15.9,5 19,8.1 19,12C19,15.9 15.9,19 12,19M20.5,20.5C22.7,18.3 24,15.3 24,12C24,8.7 22.7,5.7 20.5,3.5L19.4,4.6C21.3,6.5 22.5,9.1 22.5,12C22.5,14.9 21.3,17.5 19.4,19.4L20.5,20.5M4.6,19.4C2.7,17.5 1.5,14.9 1.5,12C1.5,9.1 2.7,6.5 4.6,4.6L3.5,3.5C1.3,5.7 0,8.7 0,12C0,15.3 1.3,18.3 3.5,20.5L4.6,19.4M9,7V17H11V13H13V17H15V7H13V11H11V7H9Z\";\r\nvar mdiCarBrakeParking = \"M12,3C7,3 3,7 3,12C3,17 7,21 12,21C17,21 21,17 21,12C21,7 17,3 12,3M12,19C8.1,19 5,15.9 5,12C5,8.1 8.1,5 12,5C15.9,5 19,8.1 19,12C19,15.9 15.9,19 12,19M20.5,20.5C22.7,18.3 24,15.3 24,12C24,8.7 22.7,5.7 20.5,3.5L19.4,4.6C21.3,6.5 22.5,9.1 22.5,12C22.5,14.9 21.3,17.5 19.4,19.4L20.5,20.5M4.6,19.4C2.7,17.5 1.5,14.9 1.5,12C1.5,9.1 2.7,6.5 4.6,4.6L3.5,3.5C1.3,5.7 0,8.7 0,12C0,15.3 1.3,18.3 3.5,20.5L4.6,19.4M9.5,7V17H11.5V13H13.5A2,2 0 0,0 15.5,11V9A2,2 0 0,0 13.5,7H9.5M11.5,9H13.5V11H11.5V9Z\";\r\nvar mdiCarBrakeRetarder = \"M12 3C7 3 3 7 3 12S7 21 12 21 21 17 21 12 17 3 12 3M12 19C8.1 19 5 15.9 5 12S8.1 5 12 5 19 8.1 19 12 15.9 19 12 19M20.5 20.5C22.7 18.3 24 15.3 24 12S22.7 5.7 20.5 3.5L19.4 4.6C21.3 6.5 22.5 9.1 22.5 12S21.3 17.5 19.4 19.4L20.5 20.5M4.6 19.4C2.7 17.5 1.5 14.9 1.5 12S2.7 6.5 4.6 4.6L3.5 3.5C1.3 5.7 0 8.7 0 12S1.3 18.3 3.5 20.5L4.6 19.4M15.3 10.5C15.96 10.5 16.5 11.17 16.5 12C16.5 12.81 15.95 13.5 15.3 13.5C14.93 13.5 14.66 13.29 14.5 13.11L14.47 13.08L14.44 13.05L13.38 12L14.47 10.92L14.5 10.89L14.53 10.86C14.74 10.63 15 10.5 15.3 10.5M8.7 10.5C9.07 10.5 9.34 10.71 9.5 10.88L9.5 10.92L9.56 10.95L10.62 12L9.53 13.08L9.5 13.11L9.47 13.15C9.26 13.37 9 13.5 8.7 13.5C8.05 13.5 7.5 12.81 7.5 12S8.05 10.5 8.7 10.5M15.3 9C14.58 9 13.9 9.31 13.42 9.85L12 11.25L10.61 9.88C10.1 9.31 9.42 9 8.7 9C7.21 9 6 10.35 6 12S7.21 15 8.7 15C9.42 15 10.1 14.69 10.59 14.15L12 12.75L13.39 14.12C13.9 14.68 14.58 15 15.3 15C16.79 15 18 13.65 18 12C18 10.33 16.79 9 15.3 9Z\";\r\nvar mdiCarChildSeat = \"M17 4.5C17 5.9 15.9 7 14.5 7S12 5.9 12 4.5 13.1 2 14.5 2 17 3.1 17 4.5M15 8H14.2C12.1 8 10.1 6.8 9.1 4.9C9 4.8 8.9 4.7 8.9 4.6L7.1 5.4C7.6 6.8 9.2 8.6 11.5 9.5L9.7 14.5L5.8 13.4L3 18.9L5 19.4L6.8 15.8L11.3 17C12.3 17.2 13.3 16.7 13.7 15.8L16 9.4C16.2 8.7 15.7 8 15 8M18.9 7L15.5 16.4C14.9 18 13.4 19 11.8 19C11.5 19 11.1 19 10.8 18.9L7.9 18.1L7 19.9L9 20.4L10.4 20.8C10.9 20.9 11.4 21 11.9 21C14.4 21 16.6 19.5 17.5 17.1L21 7H18.9Z\";\r\nvar mdiCarClutch = \"M10 18.84L14 20.7V23L8 20V14H5V10H8V4L14 1V3.3L10 5.16V18.84M19 10H15V5.41L12 6.8V17.2L15 18.6V14H19V10Z\";\r\nvar mdiCarCog = \"M6.5 5C5.84 5 5.28 5.42 5.08 6L3 12V20A1 1 0 0 0 4 21H5A1 1 0 0 0 6 20V19H11.3A7 7 0 0 1 11 17A7 7 0 0 1 14.41 11H5L6.5 6.5H17.5L18.68 10.03A7 7 0 0 1 20.47 10.46L18.92 6C18.72 5.42 18.16 5 17.5 5H6.5M17 12C16.87 12 16.76 12.09 16.74 12.21L16.55 13.53C16.25 13.66 15.96 13.82 15.7 14L14.46 13.5C14.35 13.5 14.22 13.5 14.15 13.63L13.15 15.36C13.09 15.47 13.11 15.6 13.21 15.68L14.27 16.5C14.25 16.67 14.24 16.83 14.24 17C14.24 17.17 14.25 17.33 14.27 17.5L13.21 18.32C13.12 18.4 13.09 18.53 13.15 18.64L14.15 20.37C14.21 20.5 14.34 20.5 14.46 20.5L15.7 20C15.96 20.18 16.24 20.35 16.55 20.47L16.74 21.79C16.76 21.91 16.86 22 17 22H19C19.11 22 19.22 21.91 19.24 21.79L19.43 20.47C19.73 20.34 20 20.18 20.27 20L21.5 20.5C21.63 20.5 21.76 20.5 21.83 20.37L22.83 18.64C22.89 18.53 22.86 18.4 22.77 18.32L21.7 17.5C21.72 17.33 21.74 17.17 21.74 17C21.74 16.83 21.73 16.67 21.7 16.5L22.76 15.68C22.85 15.6 22.88 15.47 22.82 15.36L21.82 13.63C21.76 13.5 21.63 13.5 21.5 13.5L20.27 14C20 13.82 19.73 13.65 19.42 13.53L19.23 12.21C19.22 12.09 19.11 12 19 12H17M6.5 13A1.5 1.5 0 0 1 8 14.5A1.5 1.5 0 0 1 6.5 16A1.5 1.5 0 0 1 5 14.5A1.5 1.5 0 0 1 6.5 13M18 15.5C18.83 15.5 19.5 16.17 19.5 17C19.5 17.83 18.83 18.5 18 18.5C17.16 18.5 16.5 17.83 16.5 17C16.5 16.17 17.17 15.5 18 15.5Z\";\r\nvar mdiCarConnected = \"M5,14H19L17.5,9.5H6.5L5,14M17.5,19A1.5,1.5 0 0,0 19,17.5A1.5,1.5 0 0,0 17.5,16A1.5,1.5 0 0,0 16,17.5A1.5,1.5 0 0,0 17.5,19M6.5,19A1.5,1.5 0 0,0 8,17.5A1.5,1.5 0 0,0 6.5,16A1.5,1.5 0 0,0 5,17.5A1.5,1.5 0 0,0 6.5,19M18.92,9L21,15V23A1,1 0 0,1 20,24H19A1,1 0 0,1 18,23V22H6V23A1,1 0 0,1 5,24H4A1,1 0 0,1 3,23V15L5.08,9C5.28,8.42 5.85,8 6.5,8H17.5C18.15,8 18.72,8.42 18.92,9M12,0C14.12,0 16.15,0.86 17.65,2.35L16.23,3.77C15.11,2.65 13.58,2 12,2C10.42,2 8.89,2.65 7.77,3.77L6.36,2.35C7.85,0.86 9.88,0 12,0M12,4C13.06,4 14.07,4.44 14.82,5.18L13.4,6.6C13.03,6.23 12.53,6 12,6C11.5,6 10.97,6.23 10.6,6.6L9.18,5.18C9.93,4.44 10.94,4 12,4Z\";\r\nvar mdiCarConvertible = \"M16,6L15,6.75L17.5,10H13.5V8.5H12V10H3C1.89,10 1,10.89 1,12V15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V12C23,10.89 22.11,10 21,10H19L16,6M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiCarCoolantLevel = \"M19 7V5H21V3H13V5H15V7H1V21H23V7H19M21 14.42C20.71 14.13 20.5 14 20 14C19.33 14 19.21 14.21 18.71 14.71S17.33 16 16 16 13.79 15.21 13.29 14.71 12.67 14 12 14C11.78 14 11.63 14.03 11.5 14.08C11.22 14.18 11.05 14.37 10.71 14.71C10.21 15.21 9.33 16 8 16S5.79 15.21 5.29 14.71 4.67 14 4 14C3.5 14 3.29 14.13 3 14.42V9H21V14.42Z\";\r\nvar mdiCarCruiseControl = \"M22,15C22,17.6 20.8,19.9 18.9,21.3L18.4,20.8L16.3,18.7L17.7,17.3L18.9,18.5C19.4,17.8 19.8,16.9 19.9,16H18V14H19.9C19.7,13.1 19.4,12.3 18.9,11.5L17.7,12.7L16.3,11.3L17.5,10.1C16.8,9.6 15.9,9.2 15,9.1V11H13V9.1C12.1,9.3 11.3,9.6 10.5,10.1L13.5,13.1C13.7,13.1 13.8,13 14,13A2,2 0 0,1 16,15A2,2 0 0,1 14,17A2,2 0 0,1 12,15C12,14.8 12,14.7 12.1,14.5L9.1,11.5C8.6,12.2 8.2,13.1 8.1,14H10V16H8.1C8.3,16.9 8.6,17.7 9.1,18.5L10.3,17.3L11.7,18.7L9.1,21.3C7.2,19.9 6,17.6 6,15A8,8 0 0,1 14,7A8,8 0 0,1 22,15M6.7,5.3L3.4,2L2,3.4L5.3,6.7L4,8H8V4L6.7,5.3Z\";\r\nvar mdiCarDefrostFront = \"M15,23C14.7,23 14.5,22.9 14.3,22.7C13.9,22.3 14,21.7 14.4,21.3V21.3C14.9,20.9 16.1,19.5 16.1,18.4C16.1,17.8 15.7,17.2 15.3,16.5C14.8,15.7 14.1,14.7 14.1,13.5C14.1,11.2 15.4,10.3 15.6,10.2C16.1,9.9 16.7,10.1 17,10.5C17.3,11 17.1,11.6 16.7,11.9V11.9C16.7,11.9 16.2,12.3 16.2,13.5C16.2,14.1 16.6,14.7 17,15.4C17.5,16.2 18.2,17.2 18.2,18.4C18.2,20.6 16.1,22.6 15.9,22.8C15.5,22.9 15.2,23 15,23M11.7,22.7C11.9,22.5 14,20.5 14,18.3C14,17.1 13.4,16.1 12.8,15.3C12.4,14.6 12,14 12,13.4C12,12.2 12.5,11.8 12.5,11.8V11.8C13,11.5 13.1,10.9 12.8,10.4C12.5,9.9 11.9,9.8 11.4,10.1C11.2,10.2 9.9,11.1 9.9,13.4C9.9,14.6 10.5,15.6 11.1,16.4C11.5,17.1 11.9,17.7 11.9,18.3C11.9,19.4 10.7,20.8 10.2,21.2V21.2C9.8,21.6 9.8,22.2 10.1,22.6C10.3,22.8 10.6,22.9 10.8,22.9C11.2,23 11.5,22.9 11.7,22.7M7.7,22.7C7.9,22.5 10,20.5 10,18.3C10,17.1 9.4,16.1 8.8,15.3C8.4,14.7 8,14.1 8,13.4C8,12.2 8.5,11.8 8.5,11.8V11.8C9,11.5 9.1,10.9 8.8,10.4C8.6,10 7.9,9.9 7.5,10.1C7.3,10.2 6,11.1 6,13.4C6,14.6 6.6,15.6 7.2,16.4C7.6,17.1 8,17.7 8,18.3C8,19.4 6.8,20.8 6.3,21.2V21.2C5.9,21.6 5.9,22.2 6.2,22.6C6.5,22.9 6.7,23 7,23C7.2,23 7.5,22.9 7.7,22.7M12,3C9.4,3 1,3.3 1,7C1,9.4 2.2,15.4 2.8,18H4L4.8,18H5V16H4.4C3.8,13.1 3,8.8 3,7C3,6 7.4,5 12,5C16.6,5 21,6 21,7C21,8.8 20.2,13.1 19.6,16H19V18H19.2L20,18H21.2C21.8,15.4 23,9.4 23,7C23,3.3 14.6,3 12,3Z\";\r\nvar mdiCarDefrostRear = \"M10,18.3C10,20.5 7.9,22.5 7.7,22.7C7.5,22.9 7.2,23 7,23C6.7,23 6.5,22.9 6.2,22.6C5.9,22.2 5.9,21.6 6.3,21.2C6.8,20.8 8,19.4 8,18.3C8,17.7 7.6,17.1 7.2,16.4C6.6,15.6 6,14.6 6,13.4C6,11.1 7.3,10.2 7.5,10.1C7.9,9.9 8.6,10 8.8,10.4C9.1,10.9 9,11.5 8.5,11.8C8.5,11.8 8,12.2 8,13.4C8,14.1 8.4,14.7 8.8,15.3C9.4,16.1 10,17.1 10,18.3M12,13.4C12,12.2 12.5,11.8 12.5,11.8C13,11.5 13.1,10.9 12.8,10.4C12.5,9.9 11.9,9.8 11.4,10.1C11.2,10.2 9.9,11.1 9.9,13.4C9.9,14.6 10.5,15.6 11.1,16.4C11.5,17.1 11.9,17.7 11.9,18.3C11.9,19.4 10.7,20.8 10.2,21.2C9.8,21.6 9.8,22.2 10.1,22.6C10.3,22.8 10.6,22.9 10.8,22.9C11.2,23 11.5,22.9 11.7,22.7C11.9,22.5 14,20.5 14,18.3C14,17.1 13.4,16.1 12.8,15.3C12.4,14.6 12,14 12,13.4M20,3H4A2,2 0 0,0 2,5V16A2,2 0 0,0 4,18H5V16H4V5H20V16H19V18H20A2,2 0 0,0 22,16V5A2,2 0 0,0 20,3M16.2,13.5C16.2,12.3 16.7,11.9 16.7,11.9C17.1,11.6 17.3,11 17,10.5C16.7,10.1 16.1,9.9 15.6,10.2C15.4,10.3 14.1,11.2 14.1,13.5C14.1,14.7 14.8,15.7 15.3,16.5C15.7,17.2 16.1,17.8 16.1,18.4C16.1,19.5 14.9,20.9 14.4,21.3C14,21.7 13.9,22.3 14.3,22.7C14.5,22.9 14.7,23 15,23C15.2,23 15.5,22.9 15.9,22.8C16.1,22.6 18.2,20.6 18.2,18.4C18.2,17.2 17.5,16.2 17,15.4C16.6,14.7 16.2,14.1 16.2,13.5Z\";\r\nvar mdiCarDoor = \"M19,14H16V16H19V14M22,21H3V11L11,3H21A1,1 0 0,1 22,4V21M11.83,5L5.83,11H20V5H11.83Z\";\r\nvar mdiCarDoorLock = \"M21 3H11L3 11V12H4.5C7.5 12 10 14.91 10 18.5V21H22V4A1 1 0 0 0 21 3M19 16H16V14H19M20 11H5.83L11.83 5H20M7 17V16.5A2.5 2.5 0 0 0 2 16.5V17A1 1 0 0 0 1 18V22A1 1 0 0 0 2 23H7A1 1 0 0 0 8 22V18A1 1 0 0 0 7 17M6.2 17H2.8V16.5A1.7 1.7 0 0 1 6.2 16.5Z\";\r\nvar mdiCarElectric = \"M18.92 2C18.72 1.42 18.16 1 17.5 1H6.5C5.84 1 5.29 1.42 5.08 2L3 8V16C3 16.55 3.45 17 4 17H5C5.55 17 6 16.55 6 16V15H18V16C18 16.55 18.45 17 19 17H20C20.55 17 21 16.55 21 16V8L18.92 2M6.5 12C5.67 12 5 11.33 5 10.5S5.67 9 6.5 9 8 9.67 8 10.5 7.33 12 6.5 12M17.5 12C16.67 12 16 11.33 16 10.5S16.67 9 17.5 9 19 9.67 19 10.5 18.33 12 17.5 12M5 7L6.5 2.5H17.5L19 7H5M7 20H11V18L17 21H13V23L7 20Z\";\r\nvar mdiCarElectricOutline = \"M18.92 2C18.72 1.42 18.16 1 17.5 1H6.5C5.84 1 5.29 1.42 5.08 2L3 8V16C3 16.55 3.45 17 4 17H5C5.55 17 6 16.55 6 16V15H18V16C18 16.55 18.45 17 19 17H20C20.55 17 21 16.55 21 16V8L18.92 2M6.85 3H17.14L18.22 6.11H5.77L6.85 3M19 13H5V8H19V13M7.5 9C8.33 9 9 9.67 9 10.5S8.33 12 7.5 12 6 11.33 6 10.5 6.67 9 7.5 9M16.5 9C17.33 9 18 9.67 18 10.5S17.33 12 16.5 12C15.67 12 15 11.33 15 10.5S15.67 9 16.5 9M7 20H11V18L17 21H13V23L7 20Z\";\r\nvar mdiCarEmergency = \"M11 0V3H13V0H11M7.88 1.46L6.46 2.87L8.59 5L10 3.58L7.88 1.46M16.12 1.46L14 3.58L15.41 5L17.54 2.88L16.12 1.46M12 5A2 2 0 0 0 10 7V8H6.5C5.84 8 5.28 8.42 5.08 9L3 15V23A1 1 0 0 0 4 24H5A1 1 0 0 0 6 23V22H18V23A1 1 0 0 0 19 24H20A1 1 0 0 0 21 23V15L18.92 9C18.72 8.42 18.16 8 17.5 8H14V7A2 2 0 0 0 12 5M6.5 9.5H17.5L19 14H5L6.5 9.5M6.5 16A1.5 1.5 0 0 1 8 17.5A1.5 1.5 0 0 1 6.5 19A1.5 1.5 0 0 1 5 17.5A1.5 1.5 0 0 1 6.5 16M17.5 16A1.5 1.5 0 0 1 19 17.5A1.5 1.5 0 0 1 17.5 19A1.5 1.5 0 0 1 16 17.5A1.5 1.5 0 0 1 17.5 16Z\";\r\nvar mdiCarEsp = \"M5.31,6C6.95,4.16 9.34,3 12,3C14.66,3 17.05,4.16 18.69,6H15.58C14.53,5.37 13.31,5 12,5C10.69,5 9.47,5.37 8.42,6H5.31M14.4,9.6V8H11.2A1.6,1.6 0 0,0 9.6,9.6V11.2C9.6,12.08 10.32,12.8 11.2,12.8H12.8V14.4H9.6V16H12.8A1.6,1.6 0 0,0 14.4,14.4V12.8C14.4,11.92 13.68,11.2 12.8,11.2H11.2V9.6H14.4M18.4,8H15.2V16H16.8V12.8H18.4A1.6,1.6 0 0,0 20,11.2V9.6C20,8.72 19.28,8 18.4,8M18.4,11.2H16.8V9.6H18.4V11.2M8.8,9.6V8H4V16H8.8V14.4H5.6V12.8H8.8V11.2H5.6V9.6H8.8M15.58,18C14.53,18.63 13.31,19 12,19C10.69,19 9.47,18.63 8.42,18H5.31C6.95,19.84 9.34,21 12,21C14.66,21 17.05,19.84 18.69,18H15.58M20.5,3.5L19.42,4.58C21.32,6.5 22.5,9.11 22.5,12C22.5,14.9 21.32,17.5 19.42,19.42L20.5,20.5C22.66,18.31 24,15.31 24,12C24,8.69 22.66,5.69 20.5,3.5M4.58,4.58L3.5,3.5C1.34,5.69 0,8.69 0,12C0,15.31 1.34,18.31 3.5,20.5L4.58,19.42C2.68,17.5 1.5,14.9 1.5,12C1.5,9.11 2.68,6.5 4.58,4.58Z\";\r\nvar mdiCarEstate = \"M3,6H16L19,10H21C22.11,10 23,10.89 23,12V15H21A3,3 0 0,1 18,18A3,3 0 0,1 15,15H9A3,3 0 0,1 6,18A3,3 0 0,1 3,15H1V8C1,6.89 1.89,6 3,6M2.5,7.5V10H10.5V7.5H2.5M12,7.5V10H17.14L15.25,7.5H12M6,13.5A1.5,1.5 0 0,0 4.5,15A1.5,1.5 0 0,0 6,16.5A1.5,1.5 0 0,0 7.5,15A1.5,1.5 0 0,0 6,13.5M18,13.5A1.5,1.5 0 0,0 16.5,15A1.5,1.5 0 0,0 18,16.5A1.5,1.5 0 0,0 19.5,15A1.5,1.5 0 0,0 18,13.5Z\";\r\nvar mdiCarHatchback = \"M16,6H6L1,12V15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V12C23,10.89 22.11,10 21,10H19L16,6M6.5,7.5H10.5V10H4.5L6.5,7.5M12,7.5H15.5L17.46,10H12V7.5M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiCarInfo = \"M19 15H17V13H19M20 20V22H16V20H17V18H16V16H19V20M18.92 5A1.5 1.5 0 0 0 17.5 4H6.5A1.5 1.5 0 0 0 5.08 5L3 11V19A1 1 0 0 0 4 20H5A1 1 0 0 0 6 19V18H11A7 7 0 0 1 18 11A6.84 6.84 0 0 1 21 11.68V11M6.5 15A1.5 1.5 0 1 1 8 13.5A1.5 1.5 0 0 1 6.5 15M5 10L6.5 5.5H17.5L19 10Z\";\r\nvar mdiCarKey = \"M9.5,0A3,3 0 0,0 6.5,3A3,3 0 0,0 9.5,6C10.81,6 11.92,5.17 12.33,4H14.5V6H16.5V4H17.5V2H12.33C11.92,0.83 10.81,0 9.5,0M9.5,2A1,1 0 0,1 10.5,3A1,1 0 0,1 9.5,4A1,1 0 0,1 8.5,3A1,1 0 0,1 9.5,2M6.5,8C5.84,8 5.28,8.42 5.08,9L3,15V23A1,1 0 0,0 4,24H5A1,1 0 0,0 6,23V22H18V23A1,1 0 0,0 19,24H20A1,1 0 0,0 21,23V15L18.92,9C18.72,8.42 18.16,8 17.5,8H6.5M6.5,9.5H17.5L19,14H5L6.5,9.5M6.5,16A1.5,1.5 0 0,1 8,17.5A1.5,1.5 0 0,1 6.5,19A1.5,1.5 0 0,1 5,17.5A1.5,1.5 0 0,1 6.5,16M17.5,16A1.5,1.5 0 0,1 19,17.5A1.5,1.5 0 0,1 17.5,19A1.5,1.5 0 0,1 16,17.5A1.5,1.5 0 0,1 17.5,16Z\";\r\nvar mdiCarLiftedPickup = \"M18 14L18.79 14.1L18.77 14.33L19.24 14.5L19.39 14.34C19.89 14.6 20.32 15 20.6 15.5L20.43 15.67L20.63 16.12L20.86 16.1C20.95 16.39 21 16.69 21 17L20.9 17.78L20.66 17.77L20.47 18.24L20.66 18.39C20.39 18.9 20 19.32 19.5 19.6L19.33 19.42L18.87 19.62L18.89 19.86C18.61 19.95 18.31 20 18 20L17.21 19.9L17.22 19.65L16.76 19.47L16.6 19.66C16.1 19.39 15.67 19 15.39 18.5L15.57 18.32L15.37 17.86L15.13 17.88C15.05 17.6 15 17.31 15 17L15.11 16.2L15.34 16.21L15.53 15.75L15.35 15.6C15.62 15.09 16 14.68 16.5 14.39L16.67 14.56L17.13 14.36L17.11 14.14C17.39 14.05 17.69 14 18 14M18 15.5C17.17 15.5 16.5 16.17 16.5 17C16.5 17.83 17.17 18.5 18 18.5C18.83 18.5 19.5 17.83 19.5 17C19.5 16.17 18.83 15.5 18 15.5M6 14L6.79 14.1L6.77 14.33L7.24 14.5L7.39 14.34C7.89 14.6 8.32 15 8.6 15.5L8.43 15.67L8.63 16.12L8.86 16.1C8.95 16.39 9 16.69 9 17L8.9 17.78L8.65 17.77L8.47 18.24L8.66 18.39C8.39 18.9 8 19.32 7.5 19.6L7.33 19.42L6.87 19.62L6.89 19.86C6.61 19.95 6.31 20 6 20L5.21 19.9L5.22 19.65L4.76 19.47L4.6 19.66C4.1 19.39 3.67 19 3.39 18.5L3.57 18.32L3.37 17.86L3.13 17.88C3.05 17.6 3 17.31 3 17L3.11 16.2L3.34 16.21L3.53 15.75L3.35 15.6C3.62 15.09 4 14.68 4.5 14.39L4.67 14.56L5.13 14.36L5.11 14.14C5.39 14.05 5.69 14 6 14M6 15.5C5.17 15.5 4.5 16.17 4.5 17C4.5 17.83 5.17 18.5 6 18.5C6.83 18.5 7.5 17.83 7.5 17C7.5 16.17 6.83 15.5 6 15.5M16 6L19 10H21C22.11 10 23 10.89 23 12V15H21C21 13.34 19.66 12 18 12C16.34 12 15 13.34 15 15H9C9 13.34 7.66 12 6 12C4.34 12 3 13.34 3 15H1V10H10.5V6L16 6M12 7.5V10H17.46L15.5 7.5H12Z\";\r\nvar mdiCarLightDimmed = \"M13,4.8C9,4.8 9,19.2 13,19.2C17,19.2 22,16.5 22,12C22,7.5 17,4.8 13,4.8M13.1,17.2C12.7,16.8 12,15 12,12C12,9 12.7,7.2 13.1,6.8C16,6.9 20,8.7 20,12C20,15.3 15.9,17.1 13.1,17.2M8,10.5C8,11 7.9,11.5 7.9,12C7.9,12.2 7.9,12.4 7.9,12.6L2.4,14L1.9,12.1L8,10.5M2,7L9.4,5.1C9.2,5.4 9,5.8 8.9,6.3C8.8,6.6 8.7,7 8.6,7.4L2.5,8.9L2,7M8.2,15.5C8.3,16.2 8.5,16.9 8.7,17.4L2.4,19L1.9,17.1L8.2,15.5Z\";\r\nvar mdiCarLightFog = \"M13,4.8C9,4.8 9,19.2 13,19.2C17,19.2 22,16.5 22,12C22,7.5 17,4.8 13,4.8M13.1,17.2C12.7,16.8 12,15 12,12C12,9 12.7,7.2 13.1,6.8C16,6.9 20,8.7 20,12C20,15.3 16,17.1 13.1,17.2M6,8V11H8C8,11.3 8,11.7 8,12C8,12.3 8,12.7 8,13H6V16H8.4C8.6,16.7 8.8,17.4 9,18H6V21H4V18H2V16H4V13H2V11H4V8H2V6H4V3H6V6H9C9,6.1 8.9,6.2 8.9,6.4C8.7,6.9 8.5,7.4 8.4,8H6Z\";\r\nvar mdiCarLightHigh = \"M13,4.8C9,4.8 9,19.2 13,19.2C17,19.2 22,16.5 22,12C22,7.5 17,4.8 13,4.8M13.1,17.2C12.7,16.8 12,15 12,12C12,9 12.7,7.2 13.1,6.8C16,6.9 20,8.7 20,12C20,15.3 16,17.1 13.1,17.2M2,5H9.5C9.3,5.4 9,5.8 8.9,6.4C8.8,6.6 8.8,6.8 8.7,7H2V5M8,11H2V9H8.2C8.1,9.6 8.1,10.3 8,11M8.7,17C8.9,17.8 9.2,18.4 9.6,19H2.1V17H8.7M8.2,15H2V13H8C8.1,13.7 8.1,14.4 8.2,15Z\";\r\nvar mdiCarLimousine = \"M1,6L2.5,7.5L1,9L2.5,10.5L1,12L2.5,13.5L1,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V12C23,10.89 22.11,10 21,10H19L16,6H1M4.62,7.5H10.5V10H4.12L3.12,9L4.62,7.5M12,7.5H15.5L17.46,10H12V7.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiCarMultiple = \"M8,11L9.5,6.5H18.5L20,11M18.5,16A1.5,1.5 0 0,1 17,14.5A1.5,1.5 0 0,1 18.5,13A1.5,1.5 0 0,1 20,14.5A1.5,1.5 0 0,1 18.5,16M9.5,16A1.5,1.5 0 0,1 8,14.5A1.5,1.5 0 0,1 9.5,13A1.5,1.5 0 0,1 11,14.5A1.5,1.5 0 0,1 9.5,16M19.92,6C19.71,5.4 19.14,5 18.5,5H9.5C8.86,5 8.29,5.4 8.08,6L6,12V20A1,1 0 0,0 7,21H8A1,1 0 0,0 9,20V19H19V20A1,1 0 0,0 20,21H21A1,1 0 0,0 22,20V12L19.92,6M14.92,3C14.71,2.4 14.14,2 13.5,2H4.5C3.86,2 3.29,2.4 3.08,3L1,9V17A1,1 0 0,0 2,18H3A1,1 0 0,0 4,17V12.91C3.22,12.63 2.82,11.77 3.1,11C3.32,10.4 3.87,10 4.5,10H4.57L5.27,8H3L4.5,3.5H15.09L14.92,3Z\";\r\nvar mdiCarOff = \"M20.5,19.85L6.41,5.76L2.41,1.76L1.11,3L4.57,6.46L3,11V19A1,1 0 0,0 4,20H5A1,1 0 0,0 6,19V18H16.11L20.84,22.73L22.11,21.46L20.5,19.85M6.5,15A1.5,1.5 0 0,1 5,13.5A1.5,1.5 0 0,1 6.5,12A1.5,1.5 0 0,1 8,13.5A1.5,1.5 0 0,1 6.5,15M5,10L5.78,7.67L8.11,10H5M17.5,5.5L19,10H13.2L16.12,12.92C16.5,12.17 17.37,11.86 18.12,12.21C18.87,12.57 19.18,13.47 18.83,14.21C18.68,14.5 18.43,14.77 18.12,14.92L21,17.8V11L18.92,5C18.71,4.4 18.14,4 17.5,4H7.2L8.7,5.5H17.5Z\";\r\nvar mdiCarOutline = \"M18.9 6C18.7 5.4 18.1 5 17.5 5H6.5C5.8 5 5.3 5.4 5.1 6L3 12V20C3 20.5 3.5 21 4 21H5C5.6 21 6 20.5 6 20V19H18V20C18 20.5 18.5 21 19 21H20C20.5 21 21 20.5 21 20V12L18.9 6M6.8 7H17.1L18.2 10H5.8L6.8 7M19 17H5V12H19V17M7.5 13C8.3 13 9 13.7 9 14.5S8.3 16 7.5 16 6 15.3 6 14.5 6.7 13 7.5 13M16.5 13C17.3 13 18 13.7 18 14.5S17.3 16 16.5 16C15.7 16 15 15.3 15 14.5S15.7 13 16.5 13Z\";\r\nvar mdiCarParkingLights = \"M7.3,9.2C8.1,9.6 9,10.5 9,12C9,13.5 8.1,14.4 7.3,14.8C6.9,13.4 6.9,10.6 7.3,9.2M6.5,7C4.5,7 4.5,17 6.5,17C8.5,17 11,15.1 11,12C11,8.9 8.5,7 6.5,7M16.7,9.2C17,10.6 17,13.4 16.7,14.8C15.9,14.4 15,13.5 15,12C15,10.5 15.9,9.6 16.7,9.2M17.5,7C15.5,7 13,8.9 13,12C13,15.1 15.5,17 17.5,17C19.5,17 19.5,7 17.5,7M4.9,6.2L2.5,4.6L1.4,6.3L4,8C4.2,7.3 4.5,6.6 4.9,6.2M20,8L22.6,6.3L21.5,4.6L19.1,6.2C19.4,6.6 19.8,7.2 20,8M4,16L1.4,17.7L2.5,19.4L4.9,17.8C4.6,17.4 4.2,16.8 4,16M20.5,11C20.5,11.3 20.5,11.7 20.5,12C20.5,12.3 20.5,12.6 20.5,13H24V11H20.5M19.1,17.8L21.5,19.4L22.6,17.7L20,16C19.8,16.7 19.5,17.4 19.1,17.8M3.5,12C3.5,11.7 3.5,11.4 3.5,11H0V13H3.5C3.5,12.7 3.5,12.3 3.5,12Z\";\r\nvar mdiCarPickup = \"M16,6H10.5V10H1V15H3A3,3 0 0,0 6,18A3,3 0 0,0 9,15H15A3,3 0 0,0 18,18A3,3 0 0,0 21,15H23V12C23,10.89 22.11,10 21,10H19L16,6M12,7.5H15.5L17.46,10H12V7.5M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiCarSeat = \"M7 18C7 18 4 10 4 6S6 2 6 2H7C7 2 8 2 8 3S7 4 7 6 10 10 10 13 7 18 7 18M12 17C11 17 8 19.5 8 19.5C7.7 19.7 7.8 20 8 20.3C8 20.3 9 22.1 11 22.1H17C18.1 22.1 19 21.2 19 20.1V19.1C19 18 18.1 17.1 17 17.1H12Z\";\r\nvar mdiCarSeatCooler = \"M20.8 10.2L19.4 10.6L18.2 9.9V8.2L19.4 7.5L20.8 7.9L21.1 6.8L20 6.5L20.3 5.4L19.2 5.1L18.8 6.5L17.6 7.2L16.1 6.3V5L17.1 4L16.3 3.2L15.5 4L14.7 3.2L13.9 4L14.9 5V6.3L13.4 7.2L12.2 6.5L11.9 5.1L10.8 5.4L11.1 6.5L10 6.7L10.3 7.8L11.7 7.4L12.9 8.1V9.8L11.7 10.5L10.3 10.1L10 11.4L11.1 11.7L10.8 12.7L11.9 13L12.3 11.6L13.5 10.9L15 11.8V13.1L14 14.1L14.8 14.9L15.6 14.1L16.4 14.9L17.2 14.1L16.2 13.1V11.8L17.7 10.9L18.9 11.6L19.3 13L20.4 12.7L20 11.6L21.1 11.3L20.8 10.2M14 8.2L15.5 7.3L17 8.2V9.9L15.5 10.8L14 9.9V8.2M5 18C5 18 2 10 2 6S4 2 4 2H5C5 2 6 2 6 3S5 4 5 6 8 10 8 13 5 18 5 18M15 17C16.1 17 17 17.9 17 19V20C17 21.1 16.1 22 15 22H9C7 22 6 20.2 6 20.2C5.8 20 5.7 19.6 6 19.4C6 19.4 9 16.9 10 16.9H15Z\";\r\nvar mdiCarSeatHeater = \"M5 18C5 18 2 10 2 6S4 2 4 2H5C5 2 6 2 6 3S5 4 5 6 8 10 8 13 5 18 5 18M15 17C16.1 17 17 17.9 17 19V20C17 21.1 16.1 22 15 22H9C7 22 6 20.2 6 20.2C5.8 20 5.7 19.6 6 19.4C6 19.4 9 16.9 10 16.9H15M13.7 3.4L12.3 6.8L13.7 10.2L11.7 15L10 13.6L11.4 10.2L10 6.8L12 2L13.7 3.4M17.9 3.4L16.5 6.8L17.9 10.2L15.9 15L14.2 13.6L15.6 10.2L14.2 6.8L16.2 2L17.9 3.4M22 3.4L20.6 6.8L22 10.2L20 15L18.3 13.6L19.7 10.2L18.3 6.8L20.3 2L22 3.4\";\r\nvar mdiCarSettings = \"M15 22H17V24H15M11 22H13V24H11M7 22H9V24H7M5 11L6.5 6.5H17.5L19 11M17.5 16A1.5 1.5 0 0 1 16 14.5A1.5 1.5 0 0 1 17.5 13A1.5 1.5 0 0 1 19 14.5A1.5 1.5 0 0 1 17.5 16M6.5 16A1.5 1.5 0 0 1 5 14.5A1.5 1.5 0 0 1 6.5 13A1.5 1.5 0 0 1 8 14.5A1.5 1.5 0 0 1 6.5 16M18.92 6C18.72 5.42 18.16 5 17.5 5H6.5C5.84 5 5.28 5.42 5.08 6L3 12V20A1 1 0 0 0 4 21H5A1 1 0 0 0 6 20V19H18V20A1 1 0 0 0 19 21H20A1 1 0 0 0 21 20V12Z\";\r\nvar mdiCarShiftPattern = \"M8 5H4V2H8V5M4 22H8V19H4V22M14 2H10V5H14V2M10 22H14V19H10V22M16 2V5H20V2H16M17 11H13V7H11V11H7V7H5V17H7V13H11V17H13V13H19V7H17V11Z\";\r\nvar mdiCarSide = \"M16,6L19,10H21C22.11,10 23,10.89 23,12V15H21A3,3 0 0,1 18,18A3,3 0 0,1 15,15H9A3,3 0 0,1 6,18A3,3 0 0,1 3,15H1V12C1,10.89 1.89,10 3,10L6,6H16M10.5,7.5H6.75L4.86,10H10.5V7.5M12,7.5V10H17.14L15.25,7.5H12M6,13.5A1.5,1.5 0 0,0 4.5,15A1.5,1.5 0 0,0 6,16.5A1.5,1.5 0 0,0 7.5,15A1.5,1.5 0 0,0 6,13.5M18,13.5A1.5,1.5 0 0,0 16.5,15A1.5,1.5 0 0,0 18,16.5A1.5,1.5 0 0,0 19.5,15A1.5,1.5 0 0,0 18,13.5Z\";\r\nvar mdiCarSports = \"M12,8.5H7L4,11H3C1.89,11 1,11.89 1,13V16H3.17C3.6,17.2 4.73,18 6,18C7.27,18 8.4,17.2 8.82,16H15.17C15.6,17.2 16.73,18 18,18C19.27,18 20.4,17.2 20.82,16H23V15C23,13.89 21.97,13.53 21,13L12,8.5M5.25,12L7.5,10H11.5L15.5,12H5.25M6,13.5A1.5,1.5 0 0,1 7.5,15A1.5,1.5 0 0,1 6,16.5A1.5,1.5 0 0,1 4.5,15A1.5,1.5 0 0,1 6,13.5M18,13.5A1.5,1.5 0 0,1 19.5,15A1.5,1.5 0 0,1 18,16.5A1.5,1.5 0 0,1 16.5,15A1.5,1.5 0 0,1 18,13.5Z\";\r\nvar mdiCarTireAlert = \"M11,13H13V15H11V13M11,5H13V11H11V5M17,4.76C18.86,6.19 20,8.61 20,11C20,14 18.33,16.64 15.86,18H8.14C5.67,16.64 4,14 4,11C4,8.61 5.09,6.17 7,4.76V2H5V3.86C3.15,5.68 2,8.2 2,11C2,13.8 3.15,16.32 5,18.14V22H7V20H9V22H11V20H13V22H15V20H17V22H19V18.14C20.85,16.32 22,13.8 22,11C22,8.2 20.85,5.68 19,3.86V2H17V4.76Z\";\r\nvar mdiCarTractionControl = \"M9.5,11H10.5C10.8,11 11,10.8 11,10.5V9H19V10.5C19,10.8 19.2,11 19.5,11H20.5C20.8,11 21,10.8 21,10.5V9L21,8.5V6L19.6,1.7C19.5,1.3 19.1,1 18.7,1H11.4C11,1 10.6,1.3 10.5,1.7L9,6V8.5L9,9V10.5C9,10.8 9.2,11 9.5,11M11.3,2H18.6L19.5,5H10.4L11.3,2M12,23H10C10,22.2 8.1,21.5 6.6,20.9C4.5,20.1 2,19.2 2,17C2,14.7 4.3,14.1 6.2,13.5C7.9,13.1 9,12.7 9,12H11C11,14.3 8.7,14.9 6.8,15.5C5.1,15.9 4,16.3 4,17C4,17.8 5.9,18.5 7.4,19.1C9.5,19.9 12,20.8 12,23M22,23H20C20,22.2 18.1,21.5 16.6,20.9C14.5,20.1 12,19.2 12,17C12,14.7 14.3,14.1 16.2,13.5C17.8,13 19,12.7 19,12H21C21,14.3 18.7,14.9 16.8,15.5C15.2,15.9 14,16.3 14,17C14,17.8 15.9,18.5 17.4,19.1C19.5,19.9 22,20.8 22,23Z\";\r\nvar mdiCarTurbocharger = \"M22 13V15H18.32C18.75 14.09 19 13.08 19 12C19 8.14 15.86 5 12 5H2V3H12C16.97 3 21 7.03 21 12C21 12.34 20.97 12.67 20.94 13H22M12 19C8.14 19 5 15.86 5 12C5 10.93 5.25 9.91 5.69 9H2V11H3.06C3.03 11.33 3 11.66 3 12C3 16.97 7.03 21 12 21H22V19H12M16.86 12.2C15.93 12.94 14.72 12.47 14 12.05V12C16.79 10.31 15.39 7.89 15.39 7.89S14.33 6.04 14.61 7.89C14.78 9.07 13.76 9.88 13.04 10.3L13 10.28C12.93 7 10.13 7 10.13 7S8 7 9.74 7.69C10.85 8.13 11.04 9.42 11.05 10.25L11 10.28C8.14 8.7 6.74 11.12 6.74 11.12S5.67 12.97 7.14 11.8C8.07 11.07 9.28 11.54 10 11.95V12C7.21 13.7 8.61 16.12 8.61 16.12S9.67 17.97 9.4 16.11C9.22 14.94 10.25 14.13 10.97 13.7L11 13.73C11.07 17 13.87 17 13.87 17S16 17 14.26 16.31C13.15 15.87 12.96 14.58 12.95 13.75L13 13.73C15.86 15.31 17.26 12.88 17.26 12.88S18.33 11.04 16.86 12.2Z\";\r\nvar mdiCarWash = \"M5,13L6.5,8.5H17.5L19,13M17.5,18A1.5,1.5 0 0,1 16,16.5A1.5,1.5 0 0,1 17.5,15A1.5,1.5 0 0,1 19,16.5A1.5,1.5 0 0,1 17.5,18M6.5,18A1.5,1.5 0 0,1 5,16.5A1.5,1.5 0 0,1 6.5,15A1.5,1.5 0 0,1 8,16.5A1.5,1.5 0 0,1 6.5,18M18.92,8C18.72,7.42 18.16,7 17.5,7H6.5C5.84,7 5.28,7.42 5.08,8L3,14V22A1,1 0 0,0 4,23H5A1,1 0 0,0 6,22V21H18V22A1,1 0 0,0 19,23H20A1,1 0 0,0 21,22V14M7,5A1.5,1.5 0 0,0 8.5,3.5C8.5,2.5 7,0.8 7,0.8C7,0.8 5.5,2.5 5.5,3.5A1.5,1.5 0 0,0 7,5M12,5A1.5,1.5 0 0,0 13.5,3.5C13.5,2.5 12,0.8 12,0.8C12,0.8 10.5,2.5 10.5,3.5A1.5,1.5 0 0,0 12,5M17,5A1.5,1.5 0 0,0 18.5,3.5C18.5,2.5 17,0.8 17,0.8C17,0.8 15.5,2.5 15.5,3.5A1.5,1.5 0 0,0 17,5Z\";\r\nvar mdiCarWindshield = \"M22.63 15.5L20.21 5.85A1 1 0 0 0 19.14 5.1C17.8 5.24 14.14 5.5 12 5.5S6.2 5.24 4.86 5.1A1 1 0 0 0 3.79 5.85L1.37 15.5A1.5 1.5 0 0 0 2.55 17.36A61.5 61.5 0 0 0 12 18A61.5 61.5 0 0 0 21.45 17.36A1.5 1.5 0 0 0 22.63 15.5Z\";\r\nvar mdiCarWindshieldOutline = \"M22.63 15.5L20.21 5.85A1 1 0 0 0 19.14 5.1C17.8 5.24 14.14 5.5 12 5.5S6.2 5.24 4.86 5.1A1 1 0 0 0 3.79 5.85L1.37 15.5A1.5 1.5 0 0 0 2.55 17.36A61.5 61.5 0 0 0 12 18A61.5 61.5 0 0 0 21.45 17.36A1.5 1.5 0 0 0 22.63 15.5M12 16A63.33 63.33 0 0 1 3.44 15.5L5.5 7.18C7 7.32 10.16 7.5 12 7.5S17 7.32 18.5 7.18L20.56 15.5A63.33 63.33 0 0 1 12 16Z\";\r\nvar mdiCarabiner = \"M8 17.5C8 18.33 7.33 19 6.5 19S5 18.33 5 17.5 5.67 16 6.5 16 8 16.67 8 17.5M18 5.59C17.79 3.54 16.18 2 14.24 2H8.88C6.95 2 5.36 3.5 5.15 5.53L5 6.59C4.92 7.34 5.5 8 6.24 8C6.87 8 7.39 7.53 7.47 6.91L7.61 5.82C7.68 5.07 8.23 4.5 8.88 4.5H14.24C14.89 4.5 15.44 5.07 15.5 5.82L16.5 16.88C16.59 17.74 16 18.5 15.25 18.5L10.04 17.82C9.95 18.77 9.5 19.6 8.8 20.18L14.93 21L15.09 21H15.25C16.27 21 17.26 20.56 17.96 19.78C18.71 18.94 19.09 17.8 19 16.65L18 5.59M11.66 7.94C11.08 7.57 10.31 7.75 9.94 8.34L6.39 14C6.43 14 6.46 14 6.5 14C7.38 14 8.18 14.34 8.8 14.88L12.06 9.66C12.43 9.08 12.25 8.31 11.66 7.94Z\";\r\nvar mdiCaravan = \"M5,7A2,2 0 0,0 3,9V15A2,2 0 0,0 5,17H7A3,3 0 0,0 10,20A3,3 0 0,0 13,17H21V15H19V9A2,2 0 0,0 17,7H5M5,9H10V12H5V9M13,9H17V12H13V9M10,16A1,1 0 0,1 11,17A1,1 0 0,1 10,18A1,1 0 0,1 9,17A1,1 0 0,1 10,16Z\";\r\nvar mdiCard = \"M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20Z\";\r\nvar mdiCardAccountDetails = \"M2,3H22C23.05,3 24,3.95 24,5V19C24,20.05 23.05,21 22,21H2C0.95,21 0,20.05 0,19V5C0,3.95 0.95,3 2,3M14,6V7H22V6H14M14,8V9H21.5L22,9V8H14M14,10V11H21V10H14M8,13.91C6,13.91 2,15 2,17V18H14V17C14,15 10,13.91 8,13.91M8,6A3,3 0 0,0 5,9A3,3 0 0,0 8,12A3,3 0 0,0 11,9A3,3 0 0,0 8,6Z\";\r\nvar mdiCardAccountDetailsOutline = \"M22,3H2C0.91,3.04 0.04,3.91 0,5V19C0.04,20.09 0.91,20.96 2,21H22C23.09,20.96 23.96,20.09 24,19V5C23.96,3.91 23.09,3.04 22,3M22,19H2V5H22V19M14,17V15.75C14,14.09 10.66,13.25 9,13.25C7.34,13.25 4,14.09 4,15.75V17H14M9,7A2.5,2.5 0 0,0 6.5,9.5A2.5,2.5 0 0,0 9,12A2.5,2.5 0 0,0 11.5,9.5A2.5,2.5 0 0,0 9,7M14,7V8H20V7H14M14,9V10H20V9H14M14,11V12H18V11H14\";\r\nvar mdiCardAccountDetailsStar = \"M20 22.09L22.45 23.58L21.8 20.77L24 18.89L21.11 18.64L20 16L18.87 18.64L16 18.89L18.18 20.77L17.5 23.58L20 22.09M14.08 21H2C.95 21 0 20.05 0 19V5C0 3.95 .95 3 2 3H22C23.05 3 24 3.95 24 5V15.53C22.94 14.58 21.54 14 20 14C16.69 14 14 16.69 14 20C14 20.34 14.03 20.68 14.08 21M8 13.91C6 13.91 2 15 2 17V18H14V17C14 15 10 13.91 8 13.91M8 6C6.35 6 5 7.35 5 9C5 10.65 6.35 12 8 12C9.65 12 11 10.65 11 9C11 7.35 9.65 6 8 6M21 10H14V11H21V10M22 8H14V9H22V8M22 6H14V7H22V6Z\";\r\nvar mdiCardAccountDetailsStarOutline = \"M20 22.09L22.45 23.58L21.8 20.77L24 18.89L21.11 18.64L20 16L18.87 18.64L16 18.89L18.18 20.77L17.5 23.58L20 22.09M14.08 21H2C.91 20.96 .04 20.09 0 19V5C.04 3.91 .91 3.04 2 3H22C23.09 3.04 23.96 3.91 24 5V15.53C23.42 15 22.75 14.61 22 14.34V5H2V19H14.08C14.03 19.33 14 19.66 14 20C14 20.34 14.03 20.68 14.08 21M14 17H4V15.75C4 14.09 7.34 13.25 9 13.25C10.66 13.25 14 14.09 14 15.75V17M14 11H18V12H14V11M9 7C7.63 7 6.5 8.13 6.5 9.5C6.5 10.87 7.63 12 9 12C10.37 12 11.5 10.87 11.5 9.5C11.5 8.13 10.37 7 9 7M14 9H20V10H14V9M14 7H20V8H14V7Z\";\r\nvar mdiCardAccountMail = \"M21,8V7L18,9L15,7V8L18,10M22,3H2A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M8,6A3,3 0 0,1 11,9A3,3 0 0,1 8,12A3,3 0 0,1 5,9A3,3 0 0,1 8,6M14,18H2V17C2,15 6,13.9 8,13.9C10,13.9 14,15 14,17M22,12H14V6H22\";\r\nvar mdiCardAccountMailOutline = \"M22,3H2A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M22,19H2V5H22V19M21,6H14V11H21V6M20,8L17.5,9.75L15,8V7L17.5,8.75L20,7V8M9,12A3,3 0 0,0 12,9A3,3 0 0,0 9,6A3,3 0 0,0 6,9A3,3 0 0,0 9,12M9,8A1,1 0 0,1 10,9A1,1 0 0,1 9,10A1,1 0 0,1 8,9A1,1 0 0,1 9,8M15,16.59C15,14.09 11.03,13 9,13C6.97,13 3,14.09 3,16.59V18H15V16.59M5.5,16C6.22,15.5 7.7,15 9,15C10.3,15 11.77,15.5 12.5,16H5.5Z\";\r\nvar mdiCardAccountPhone = \"M22,3H2A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M8,6A3,3 0 0,1 11,9A3,3 0 0,1 8,12A3,3 0 0,1 5,9A3,3 0 0,1 8,6M14,18H2V17C2,15 6,13.9 8,13.9C10,13.9 14,15 14,17V18M17.85,14H19.5L21,16L19,18C17.7,17 16.73,15.61 16.28,14C16.1,13.36 16,12.69 16,12C16,11.31 16.1,10.64 16.28,10C16.73,8.38 17.7,7 19,6L21,8L19.5,10H17.85C17.63,10.63 17.5,11.3 17.5,12C17.5,12.7 17.63,13.37 17.85,14Z\";\r\nvar mdiCardAccountPhoneOutline = \"M22,3H2A2,2 0 0,0 0,5V19A2,2 0 0,0 2,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M22,19H2V5H22V19M19,18L21,16L19.5,14H17.85C17.63,13.37 17.5,12.7 17.5,12C17.5,11.3 17.63,10.63 17.85,10H19.5L21,8L19,6C17.7,7 16.73,8.38 16.28,10C16.1,10.64 16,11.31 16,12C16,12.69 16.1,13.36 16.28,14C16.73,15.61 17.7,17 19,18M9,12A3,3 0 0,0 12,9A3,3 0 0,0 9,6A3,3 0 0,0 6,9A3,3 0 0,0 9,12M9,8A1,1 0 0,1 10,9A1,1 0 0,1 9,10A1,1 0 0,1 8,9A1,1 0 0,1 9,8M15,16.59C15,14.09 11.03,13 9,13C6.97,13 3,14.09 3,16.59V18H15V16.59M5.5,16C6.22,15.5 7.7,15 9,15C10.3,15 11.77,15.5 12.5,16H5.5Z\";\r\nvar mdiCardBulleted = \"M20,4A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20M11,13H9V15H11V13M19,13H13V15H19V13M7,9H5V11H7V9M19,9H9V11H19V9Z\";\r\nvar mdiCardBulletedOff = \"M3.35,3.58L20.65,20.87L19.23,22.29L16.94,20H4A2,2 0 0,1 2,18V6C2,5.72 2.06,5.46 2.16,5.22L1.23,4.29L2.65,2.87L3.35,3.58M6.6,4H20A2,2 0 0,1 22,6V18C22,18.4 21.88,18.77 21.68,19.08L17.6,15H20V13H15.6L13.6,11H20V9H11.6L6.6,4M9.94,13H9V15H11V14.06L9.94,13M5.94,9H5V11H7V10.06L5.94,9Z\";\r\nvar mdiCardBulletedOffOutline = \"M20.59,20.87L19.17,22.29L16.88,20H4A2,2 0 0,1 2,18V6C2,5.74 2.05,5.5 2.14,5.26L1.17,4.29L2.59,2.87L3.73,4L20.59,20.87V20.87M6.54,4H20A2,2 0 0,1 22,6V18C22,18.41 21.87,18.8 21.66,19.12L20,17.46V6H8.54L6.54,4M4,18H14.88L11.88,15H10V13.12L7.88,11H6V9.12L4,7.12V18M18,15H17.54L15.54,13H18V15M18,11H13.54L11.54,9H18V11Z\";\r\nvar mdiCardBulletedOutline = \"M12,15H10V13H12V15M18,15H14V13H18V15M8,11H6V9H8V11M18,11H10V9H18V11M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M4,6V18H20V6H4Z\";\r\nvar mdiCardBulletedSettings = \"M9,22V24H7V22H9M13,22V24H11V22H13M17,22V24H15V22H17M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M11,13H9V15H11V13M19,13H13V15H19V13M7,9H5V11H7V9M19,9H9V11H19V9Z\";\r\nvar mdiCardBulletedSettingsOutline = \"M9,22V24H7V22H9M13,22V24H11V22H13M17,22V24H15V22H17M12,15H10V13H12V15M18,15H14V13H18V15M8,11H6V9H8V11M18,11H10V9H18V11M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M4,6V18H20V6H4Z\";\r\nvar mdiCardMinus = \"M23 18V20H15V18H23M19 13C20.09 13 21.12 13.3 22 13.81V6C22 4.89 21.11 4 20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.04 19.67 13 19.34 13 19C13 15.69 15.69 13 19 13Z\";\r\nvar mdiCardMinusOutline = \"M23 18V20H15V18H23M13.09 18H4V6H20V13.09C20.72 13.21 21.39 13.46 22 13.81V6C22 4.89 21.11 4 20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.04 19.67 13 19.34 13 19C13 18.66 13.04 18.33 13.09 18Z\";\r\nvar mdiCardOff = \"M21.88 18.68L7.2 4H20C21.11 4 22 4.89 22 6V18C22 18.24 21.96 18.47 21.88 18.68M20.56 19.91L20.57 19.91L2.39 1.73L1.11 3L2.65 4.54C2.25 4.9 2 5.42 2 6V18C2 19.11 2.9 20 4 20H18.11L20.84 22.73L22.11 21.46L20.56 19.91Z\";\r\nvar mdiCardOffOutline = \"M9.2 6L7.2 4H20C21.11 4 22 4.89 22 6V18C22 18.24 21.96 18.47 21.88 18.68L20 16.8V6H9.2M22.11 21.46L20.84 22.73L18.11 20H4C2.9 20 2 19.11 2 18V6C2 5.42 2.25 4.9 2.65 4.54L1.11 3L2.39 1.73L6.66 6L18.65 18H18.66L20.57 19.91L20.56 19.91L22.11 21.46M16.11 18L4.11 6H4V18H16.11Z\";\r\nvar mdiCardOutline = \"M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M4,6V18H20V6H4Z\";\r\nvar mdiCardPlus = \"M13.09 20H4C2.9 20 2 19.11 2 18V6C2 4.89 2.9 4 4 4H20C21.11 4 22 4.89 22 6V13.81C21.12 13.3 20.09 13 19 13C15.69 13 13 15.69 13 19C13 19.34 13.04 19.67 13.09 20M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiCardPlusOutline = \"M21 15V18H24V20H21V23H19V20H16V18H19V15H21M14 18H3V6H19V13H21V6C21 4.89 20.11 4 19 4H3C1.9 4 1 4.89 1 6V18C1 19.11 1.9 20 3 20H14V18Z\";\r\nvar mdiCardRemove = \"M20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.47L22.54 16.88L20.41 19M19 13C20.09 13 21.12 13.3 22 13.81V6C22 4.89 21.11 4 20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.04 19.67 13 19.34 13 19C13 15.69 15.69 13 19 13Z\";\r\nvar mdiCardRemoveOutline = \"M20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.47L22.54 16.88L20.41 19M13.09 18H4V6H20V13.09C20.72 13.21 21.39 13.46 22 13.81V6C22 4.89 21.11 4 20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.04 19.67 13 19.34 13 19C13 18.66 13.04 18.33 13.09 18Z\";\r\nvar mdiCardSearch = \"M11.5 9C10.12 9 9 10.12 9 11.5S10.12 14 11.5 14 14 12.88 14 11.5 12.88 9 11.5 9M20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4M16.79 18.21L13.88 15.3C13.19 15.74 12.37 16 11.5 16C9 16 7 14 7 11.5S9 7 11.5 7 16 9 16 11.5C16 12.38 15.74 13.19 15.3 13.89L18.21 16.79L16.79 18.21Z\";\r\nvar mdiCardSearchOutline = \"M11.5 16C12.37 16 13.19 15.74 13.88 15.3L16.32 17.74L17.74 16.32L15.3 13.89C15.74 13.19 16 12.38 16 11.5C16 9 14 7 11.5 7S7 9 7 11.5 9 16 11.5 16M11.5 9C12.88 9 14 10.12 14 11.5S12.88 14 11.5 14 9 12.88 9 11.5 10.12 9 11.5 9M20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4M20 18H4V6H20V18Z\";\r\nvar mdiCardText = \"M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M5,13V15H16V13H5M5,9V11H19V9H5Z\";\r\nvar mdiCardTextOutline = \"M20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20M4,6V18H20V6H4M6,9H18V11H6V9M6,13H16V15H6V13Z\";\r\nvar mdiCards = \"M21.47,4.35L20.13,3.79V12.82L22.56,6.96C22.97,5.94 22.5,4.77 21.47,4.35M1.97,8.05L6.93,20C7.24,20.77 7.97,21.24 8.74,21.26C9,21.26 9.27,21.21 9.53,21.1L16.9,18.05C17.65,17.74 18.11,17 18.13,16.26C18.14,16 18.09,15.71 18,15.45L13,3.5C12.71,2.73 11.97,2.26 11.19,2.25C10.93,2.25 10.67,2.31 10.42,2.4L3.06,5.45C2.04,5.87 1.55,7.04 1.97,8.05M18.12,4.25A2,2 0 0,0 16.12,2.25H14.67L18.12,10.59\";\r\nvar mdiCardsClub = \"M12,2C14.3,2 16.3,4 16.3,6.2C16.21,8.77 14.34,9.83 14.04,10C15.04,9.5 16.5,9.5 16.5,9.5C19,9.5 21,11.3 21,13.8C21,16.3 19,18 16.5,18C16.5,18 15,18 13,17C13,17 12.7,19 15,22H9C11.3,19 11,17 11,17C9,18 7.5,18 7.5,18C5,18 3,16.3 3,13.8C3,11.3 5,9.5 7.5,9.5C7.5,9.5 8.96,9.5 9.96,10C9.66,9.83 7.79,8.77 7.7,6.2C7.7,4 9.7,2 12,2Z\";\r\nvar mdiCardsDiamond = \"M19,12L12,22L5,12L12,2\";\r\nvar mdiCardsDiamondOutline = \"M12 2L5 12L12 22L19 12M7.44 12L12 5.5L16.56 12L12 18.5\";\r\nvar mdiCardsHeart = \"M12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C9.24,3 10.91,3.81 12,5.08C13.09,3.81 14.76,3 16.5,3C19.58,3 22,5.41 22,8.5C22,12.27 18.6,15.36 13.45,20.03L12,21.35Z\";\r\nvar mdiCardsOutline = \"M11.19,2.25C10.93,2.25 10.67,2.31 10.42,2.4L3.06,5.45C2.04,5.87 1.55,7.04 1.97,8.05L6.93,20C7.24,20.77 7.97,21.23 8.74,21.25C9,21.25 9.27,21.22 9.53,21.1L16.9,18.05C17.65,17.74 18.11,17 18.13,16.25C18.14,16 18.09,15.71 18,15.45L13,3.5C12.71,2.73 11.97,2.26 11.19,2.25M14.67,2.25L18.12,10.6V4.25A2,2 0 0,0 16.12,2.25M20.13,3.79V12.82L22.56,6.96C22.97,5.94 22.5,4.78 21.47,4.36M11.19,4.22L16.17,16.24L8.78,19.3L3.8,7.29\";\r\nvar mdiCardsPlayingOutline = \"M11.19,2.25C11.97,2.26 12.71,2.73 13,3.5L18,15.45C18.09,15.71 18.14,16 18.13,16.25C18.11,17 17.65,17.74 16.9,18.05L9.53,21.1C9.27,21.22 9,21.25 8.74,21.25C7.97,21.23 7.24,20.77 6.93,20L1.97,8.05C1.55,7.04 2.04,5.87 3.06,5.45L10.42,2.4C10.67,2.31 10.93,2.25 11.19,2.25M14.67,2.25H16.12A2,2 0 0,1 18.12,4.25V10.6L14.67,2.25M20.13,3.79L21.47,4.36C22.5,4.78 22.97,5.94 22.56,6.96L20.13,12.82V3.79M11.19,4.22L3.8,7.29L8.77,19.3L16.17,16.24L11.19,4.22M8.65,8.54L11.88,10.95L11.44,14.96L8.21,12.54L8.65,8.54Z\";\r\nvar mdiCardsSpade = \"M12,2C9,7 4,9 4,14C4,16 6,18 8,18C9,18 10,18 11,17C11,17 11.32,19 9,22H15C13,19 13,17 13,17C14,18 15,18 16,18C18,18 20,16 20,14C20,9 15,7 12,2Z\";\r\nvar mdiCardsVariant = \"M5,2H19A1,1 0 0,1 20,3V13A1,1 0 0,1 19,14H5A1,1 0 0,1 4,13V3A1,1 0 0,1 5,2M6,4V12H18V4H6M20,17A1,1 0 0,1 19,18H5A1,1 0 0,1 4,17V16H20V17M20,21A1,1 0 0,1 19,22H5A1,1 0 0,1 4,21V20H20V21Z\";\r\nvar mdiCarrot = \"M16,10L15.8,11H13.5A0.5,0.5 0 0,0 13,11.5A0.5,0.5 0 0,0 13.5,12H15.6L14.6,17H12.5A0.5,0.5 0 0,0 12,17.5A0.5,0.5 0 0,0 12.5,18H14.4L14,20A2,2 0 0,1 12,22A2,2 0 0,1 10,20L9,15H10.5A0.5,0.5 0 0,0 11,14.5A0.5,0.5 0 0,0 10.5,14H8.8L8,10C8,8.8 8.93,7.77 10.29,7.29L8.9,5.28C8.59,4.82 8.7,4.2 9.16,3.89C9.61,3.57 10.23,3.69 10.55,4.14L11,4.8V3A1,1 0 0,1 12,2A1,1 0 0,1 13,3V5.28L14.5,3.54C14.83,3.12 15.47,3.07 15.89,3.43C16.31,3.78 16.36,4.41 16,4.84L13.87,7.35C15.14,7.85 16,8.85 16,10Z\";\r\nvar mdiCart = \"M17,18C15.89,18 15,18.89 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20C19,18.89 18.1,18 17,18M1,2V4H3L6.6,11.59L5.24,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H19V15H7.42A0.25,0.25 0 0,1 7.17,14.75C7.17,14.7 7.18,14.66 7.2,14.63L8.1,13H15.55C16.3,13 16.96,12.58 17.3,11.97L20.88,5.5C20.95,5.34 21,5.17 21,5A1,1 0 0,0 20,4H5.21L4.27,2M7,18C5.89,18 5,18.89 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20C9,18.89 8.1,18 7,18Z\";\r\nvar mdiCartArrowDown = \"M10,0V4H8L12,8L16,4H14V0M1,2V4H3L6.6,11.59L5.25,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H19V15H7.42C7.29,15 7.17,14.89 7.17,14.75L7.2,14.63L8.1,13H15.55C16.3,13 16.96,12.59 17.3,11.97L21.16,4.96L19.42,4H19.41L18.31,6L15.55,11H8.53L8.4,10.73L6.16,6L5.21,4L4.27,2M7,18A2,2 0 0,0 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20A2,2 0 0,0 7,18M17,18A2,2 0 0,0 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20A2,2 0 0,0 17,18Z\";\r\nvar mdiCartArrowRight = \"M9,20A2,2 0 0,1 7,22A2,2 0 0,1 5,20A2,2 0 0,1 7,18A2,2 0 0,1 9,20M17,18A2,2 0 0,0 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20A2,2 0 0,0 17,18M7.2,14.63C7.19,14.67 7.19,14.71 7.2,14.75A0.25,0.25 0 0,0 7.45,15H19V17H7A2,2 0 0,1 5,15C5,14.65 5.07,14.31 5.24,14L6.6,11.59L3,4H1V2H4.27L5.21,4H20A1,1 0 0,1 21,5C21,5.17 20.95,5.34 20.88,5.5L17.3,12C16.94,12.62 16.27,13 15.55,13H8.1L7.2,14.63M9,9.5H13V11.5L16,8.5L13,5.5V7.5H9V9.5Z\";\r\nvar mdiCartArrowUp = \"M12,0L8,4H10V8H14V4H16M1,2V4H3L6.6,11.59L5.25,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H19V15H7.42C7.29,15 7.17,14.89 7.17,14.75L7.2,14.63L8.1,13H15.55C16.3,13 16.96,12.59 17.3,11.97L21.16,4.96L19.42,4H19.41L18.31,6L15.55,11H8.53L8.4,10.73L6.16,6L5.21,4L4.27,2M7,18A2,2 0 0,0 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20A2,2 0 0,0 7,18M17,18A2,2 0 0,0 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20A2,2 0 0,0 17,18Z\";\r\nvar mdiCartCheck = \"M9 20C9 21.11 8.11 22 7 22S5 21.11 5 20 5.9 18 7 18 9 18.9 9 20M17 18C15.9 18 15 18.9 15 20S15.9 22 17 22 19 21.11 19 20 18.11 18 17 18M7.17 14.75L7.2 14.63L8.1 13H15.55C16.3 13 16.96 12.59 17.3 11.97L21.16 4.96L19.42 4H19.41L18.31 6L15.55 11H8.53L8.4 10.73L6.16 6L5.21 4L4.27 2H1V4H3L6.6 11.59L5.25 14.04C5.09 14.32 5 14.65 5 15C5 16.11 5.9 17 7 17H19V15H7.42C7.29 15 7.17 14.89 7.17 14.75M18 2.76L16.59 1.34L11.75 6.18L9.16 3.59L7.75 5L11.75 9L18 2.76Z\";\r\nvar mdiCartMinus = \"M16,6V4H8V6M7,18A2,2 0 0,0 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20A2,2 0 0,0 7,18M17,18A2,2 0 0,0 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20A2,2 0 0,0 17,18M7.17,14.75L7.2,14.63L8.1,13H15.55C16.3,13 16.96,12.59 17.3,11.97L21.16,4.96L19.42,4H19.41L18.31,6L15.55,11H8.53L8.4,10.73L6.16,6L5.21,4L4.27,2H1V4H3L6.6,11.59L5.25,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H19V15H7.42C7.29,15 7.17,14.89 7.17,14.75Z\";\r\nvar mdiCartOff = \"M22.73,22.73L1.27,1.27L0,2.54L4.39,6.93L6.6,11.59L5.25,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H14.46L15.84,18.38C15.34,18.74 15,19.33 15,20A2,2 0 0,0 17,22C17.67,22 18.26,21.67 18.62,21.16L21.46,24L22.73,22.73M7.42,15A0.25,0.25 0 0,1 7.17,14.75L7.2,14.63L8.1,13H10.46L12.46,15H7.42M15.55,13C16.3,13 16.96,12.59 17.3,11.97L20.88,5.5C20.96,5.34 21,5.17 21,5A1,1 0 0,0 20,4H6.54L15.55,13M7,18A2,2 0 0,0 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20A2,2 0 0,0 7,18Z\";\r\nvar mdiCartOutline = \"M17,18A2,2 0 0,1 19,20A2,2 0 0,1 17,22C15.89,22 15,21.1 15,20C15,18.89 15.89,18 17,18M1,2H4.27L5.21,4H20A1,1 0 0,1 21,5C21,5.17 20.95,5.34 20.88,5.5L17.3,11.97C16.96,12.58 16.3,13 15.55,13H8.1L7.2,14.63L7.17,14.75A0.25,0.25 0 0,0 7.42,15H19V17H7C5.89,17 5,16.1 5,15C5,14.65 5.09,14.32 5.24,14.04L6.6,11.59L3,4H1V2M7,18A2,2 0 0,1 9,20A2,2 0 0,1 7,22C5.89,22 5,21.1 5,20C5,18.89 5.89,18 7,18M16,11L18.78,6H6.14L8.5,11H16Z\";\r\nvar mdiCartPlus = \"M11,9H13V6H16V4H13V1H11V4H8V6H11M7,18A2,2 0 0,0 5,20A2,2 0 0,0 7,22A2,2 0 0,0 9,20A2,2 0 0,0 7,18M17,18A2,2 0 0,0 15,20A2,2 0 0,0 17,22A2,2 0 0,0 19,20A2,2 0 0,0 17,18M7.17,14.75L7.2,14.63L8.1,13H15.55C16.3,13 16.96,12.59 17.3,11.97L21.16,4.96L19.42,4H19.41L18.31,6L15.55,11H8.53L8.4,10.73L6.16,6L5.21,4L4.27,2H1V4H3L6.6,11.59L5.25,14.04C5.09,14.32 5,14.65 5,15A2,2 0 0,0 7,17H19V15H7.42C7.29,15 7.17,14.89 7.17,14.75Z\";\r\nvar mdiCartRemove = \"M14.12,8.53L12,6.41L9.88,8.54L8.46,7.12L10.59,5L8.47,2.88L9.88,1.47L12,3.59L14.12,1.46L15.54,2.88L13.41,5L15.53,7.12L14.12,8.53M7,18A2,2 0 0,1 9,20A2,2 0 0,1 7,22A2,2 0 0,1 5,20A2,2 0 0,1 7,18M17,18A2,2 0 0,1 19,20A2,2 0 0,1 17,22A2,2 0 0,1 15,20A2,2 0 0,1 17,18M7.17,14.75A0.25,0.25 0 0,0 7.42,15H19V17H7A2,2 0 0,1 5,15C5,14.65 5.09,14.32 5.25,14.04L6.6,11.59L3,4H1V2H4.27L5.21,4L6.16,6L8.4,10.73L8.53,11H15.55L18.31,6L19.41,4H19.42L21.16,4.96L17.3,11.97C16.96,12.59 16.3,13 15.55,13H8.1L7.2,14.63L7.17,14.75Z\";\r\nvar mdiCartVariant = \"M19 20C19 21.11 18.11 22 17 22C15.89 22 15 21.1 15 20C15 18.89 15.89 18 17 18C18.11 18 19 18.9 19 20M7 18C5.89 18 5 18.89 5 20C5 21.1 5.89 22 7 22C8.11 22 9 21.11 9 20S8.11 18 7 18M7.2 14.63L7.17 14.75C7.17 14.89 7.28 15 7.42 15H19V17H7C5.89 17 5 16.1 5 15C5 14.65 5.09 14.32 5.24 14.04L6.6 11.59L3 4H1V2H4.27L5.21 4H20C20.55 4 21 4.45 21 5C21 5.17 20.95 5.34 20.88 5.5L17.3 11.97C16.96 12.58 16.3 13 15.55 13H8.1L7.2 14.63M8.5 11H10V9H7.56L8.5 11M11 9V11H14V9H11M14 8V6H11V8H14M17.11 9H15V11H16L17.11 9M18.78 6H15V8H17.67L18.78 6M6.14 6L7.08 8H10V6H6.14Z\";\r\nvar mdiCaseSensitiveAlt = \"M20,14C20,12.5 19.5,12 18,12H16V11C16,10 16,10 14,10V15.4L14,19H16L18,19C19.5,19 20,18.47 20,17V14M12,12C12,10.5 11.47,10 10,10H6C4.5,10 4,10.5 4,12V19H6V16H10V19H12V12M10,7H14V5H10V7M22,9V20C22,21.11 21.11,22 20,22H4A2,2 0 0,1 2,20V9C2,7.89 2.89,7 4,7H8V5L10,3H14L16,5V7H20A2,2 0 0,1 22,9H22M16,17H18V14H16V17M6,12H10V14H6V12Z\";\r\nvar mdiCash = \"M3,6H21V18H3V6M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M7,8A2,2 0 0,1 5,10V14A2,2 0 0,1 7,16H17A2,2 0 0,1 19,14V10A2,2 0 0,1 17,8H7Z\";\r\nvar mdiCash100 = \"M2,5H22V20H2V5M20,18V7H4V18H20M17,8A2,2 0 0,0 19,10V15A2,2 0 0,0 17,17H7A2,2 0 0,0 5,15V10A2,2 0 0,0 7,8H17M17,13V12C17,10.9 16.33,10 15.5,10C14.67,10 14,10.9 14,12V13C14,14.1 14.67,15 15.5,15C16.33,15 17,14.1 17,13M15.5,11A0.5,0.5 0 0,1 16,11.5V13.5A0.5,0.5 0 0,1 15.5,14A0.5,0.5 0 0,1 15,13.5V11.5A0.5,0.5 0 0,1 15.5,11M13,13V12C13,10.9 12.33,10 11.5,10C10.67,10 10,10.9 10,12V13C10,14.1 10.67,15 11.5,15C12.33,15 13,14.1 13,13M11.5,11A0.5,0.5 0 0,1 12,11.5V13.5A0.5,0.5 0 0,1 11.5,14A0.5,0.5 0 0,1 11,13.5V11.5A0.5,0.5 0 0,1 11.5,11M8,15H9V10H8L7,10.5V11.5L8,11V15Z\";\r\nvar mdiCashCheck = \"M3 6V18H13.32C13.1 17.33 13 16.66 13 16H7C7 14.9 6.11 14 5 14V10C6.11 10 7 9.11 7 8H17C17 9.11 17.9 10 19 10V10.06C19.67 10.06 20.34 10.18 21 10.4V6H3M12 9C10.3 9.03 9 10.3 9 12C9 13.7 10.3 14.94 12 15C12.38 15 12.77 14.92 13.14 14.77C13.41 13.67 13.86 12.63 14.97 11.61C14.85 10.28 13.59 8.97 12 9M21.63 12.27L17.76 16.17L16.41 14.8L15 16.22L17.75 19L23.03 13.68L21.63 12.27Z\";\r\nvar mdiCashLock = \"M21.8 15C22.4 15 23 15.6 23 16.3V19.8C23 20.4 22.4 21 21.7 21H16.2C15.6 21 15 20.4 15 19.7V16.2C15 15.6 15.6 15 16.2 15V13.5C16.2 12.1 17.6 11 19 11C20.4 11 21.8 12.1 21.8 13.5V15M20.5 15V13.5C20.5 12.7 19.8 12.2 19 12.2C18.2 12.2 17.5 12.7 17.5 13.5V15H20.5M2 6H20V9.1L19 9C18.18 9 17.41 9.2 16.73 9.54C16.28 9.18 16 8.62 16 8H6C6 9.11 5.11 10 4 10V14C5.11 14 6 14.9 6 16H13.04L13 16.5V18H2V6M11 9C12.66 9 14 10.34 14 12C14 13.66 12.66 15 11 15C9.34 15 8 13.66 8 12C8 10.34 9.34 9 11 9Z\";\r\nvar mdiCashLockOpen = \"M21.8 16C22.4 16 23 16.6 23 17.3V20.8C23 21.4 22.4 22 21.7 22H16.2C15.6 22 15 21.4 15 20.7V17.2C15 16.6 15.6 16 16.2 16V13.5C16.2 12.1 17.6 11 19 11C20.4 11 21.8 12.1 21.8 13.5V14H20.5V13.5C20.5 12.7 19.8 12.2 19 12.2C18.2 12.2 17.5 12.7 17.5 13.5V16H21.8M2 6H20V9.1L19 9C18.18 9 17.41 9.2 16.73 9.54C16.28 9.18 16 8.62 16 8H6C6 9.11 5.11 10 4 10V14C5.11 14 6 14.9 6 16H13.04L13 16.5V18H2V6M11 9C12.66 9 14 10.34 14 12C14 13.66 12.66 15 11 15C9.34 15 8 13.66 8 12C8 10.34 9.34 9 11 9Z\";\r\nvar mdiCashMarker = \"M18.5,16.8C17.8,16.8 17.3,16.2 17.3,15.6C17.3,14.9 17.9,14.4 18.5,14.4C19.1,14.4 19.7,15 19.7,15.6C19.8,16.2 19.2,16.8 18.5,16.8M18.5,12C16.6,12 15,13.6 15,15.5C15,18.1 18.5,22 18.5,22C18.5,22 22,18.1 22,15.5C22,13.6 20.4,12 18.5,12M14.9,11.3C14.6,10 13.4,9 12,9C10.3,9 9,10.3 9,12C9,13.7 10.3,15 12,15C12.4,15 12.7,14.9 13,14.8C13.2,13.4 13.9,12.2 14.9,11.3M13,16H7A2,2 0 0,0 5,14V10A2,2 0 0,0 7,8H17A2,2 0 0,0 19,10C19,10 20,10 21,10.6V6H3V18H13.5C13.3,17.3 13.1,16.7 13,16Z\";\r\nvar mdiCashMinus = \"M15 15V17H23V15M14.97 11.61C14.85 10.28 13.59 8.97 12 9C10.3 9.03 9 10.3 9 12C9 13.7 10.3 14.94 12 15C12.38 15 12.77 14.92 13.14 14.77C13.41 13.67 13.86 12.63 14.97 11.61M13 16H7C7 14.9 6.11 14 5 14V10C6.11 10 7 9.11 7 8H17C17 9.11 17.9 10 19 10V10.06C19.67 10.06 20.34 10.18 21 10.4V6H3V18H13.32C13.1 17.33 13 16.66 13 16Z\";\r\nvar mdiCashMultiple = \"M5,6H23V18H5V6M14,9A3,3 0 0,1 17,12A3,3 0 0,1 14,15A3,3 0 0,1 11,12A3,3 0 0,1 14,9M9,8A2,2 0 0,1 7,10V14A2,2 0 0,1 9,16H19A2,2 0 0,1 21,14V10A2,2 0 0,1 19,8H9M1,10H3V20H19V22H1V10Z\";\r\nvar mdiCashPlus = \"M15 15V17H18V20H20V17H23V15H20V12H18V15M14.97 11.61C14.85 10.28 13.59 8.97 12 9C10.3 9.03 9 10.3 9 12C9 13.7 10.3 14.94 12 15C12.38 15 12.77 14.92 13.14 14.77C13.41 13.67 13.86 12.63 14.97 11.61M13 16H7C7 14.9 6.11 14 5 14V10C6.11 10 7 9.11 7 8H17C17 9.11 17.9 10 19 10V10.06C19.67 10.06 20.34 10.18 21 10.4V6H3V18H13.32C13.1 17.33 13 16.66 13 16Z\";\r\nvar mdiCashRefund = \"M12.3 8.93L9.88 6.5H15.5V10H17V5H9.88L12.3 2.57L11.24 1.5L7 5.75L11.24 10L12.3 8.93M12 14A3 3 0 1 0 15 17A3 3 0 0 0 12 14M3 11V23H21V11M19 19A2 2 0 0 0 17 21H7A2 2 0 0 0 5 19V15A2 2 0 0 0 7 13H17A2 2 0 0 0 19 15Z\";\r\nvar mdiCashRegister = \"M2,17H22V21H2V17M6.25,7H9V6H6V3H14V6H11V7H17.8C18.8,7 19.8,8 20,9L20.5,16H3.5L4.05,9C4.05,8 5.05,7 6.25,7M13,9V11H18V9H13M6,9V10H8V9H6M9,9V10H11V9H9M6,11V12H8V11H6M9,11V12H11V11H9M6,13V14H8V13H6M9,13V14H11V13H9M7,4V5H13V4H7Z\";\r\nvar mdiCashRemove = \"M15.46 18.12L16.88 19.54L19 17.41L21.12 19.54L22.54 18.12L20.41 16L22.54 13.88L21.12 12.46L19 14.59L16.88 12.46L15.46 13.88L17.59 16M14.97 11.62C14.86 10.28 13.58 8.97 12 9C10.3 9.04 9 10.3 9 12C9 13.7 10.3 14.94 12 15C12.39 15 12.77 14.92 13.14 14.77C13.41 13.67 13.86 12.63 14.97 11.62M13 16H7C7 14.9 6.1 14 5 14V10C6.1 10 7 9.1 7 8H17C17 9.1 17.9 10 19 10V10.05C19.67 10.06 20.34 10.18 21 10.4V6H3V18H13.32C13.1 17.33 13 16.66 13 16Z\";\r\nvar mdiCashUsd = \"M20 4H4C2.89 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H20C21.11 20 22 19.11 22 18V6C22 4.89 21.1 4 20 4M15 10H11V11H14C14.55 11 15 11.45 15 12V15C15 15.55 14.55 16 14 16H13V17H11V16H9V14H13V13H10C9.45 13 9 12.55 9 12V9C9 8.45 9.45 8 10 8H11V7H13V8H15V10Z\";\r\nvar mdiCashUsdOutline = \"M20,18H4V6H20M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4M11,17H13V16H14A1,1 0 0,0 15,15V12A1,1 0 0,0 14,11H11V10H15V8H13V7H11V8H10A1,1 0 0,0 9,9V12A1,1 0 0,0 10,13H13V14H9V16H11V17Z\";\r\nvar mdiCassette = \"M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H6L7,17H17L18,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M6.5,10A1.5,1.5 0 0,1 8,11.5A1.5,1.5 0 0,1 6.5,13A1.5,1.5 0 0,1 5,11.5A1.5,1.5 0 0,1 6.5,10M9,10H15V13H9V10M17.5,10A1.5,1.5 0 0,1 19,11.5A1.5,1.5 0 0,1 17.5,13A1.5,1.5 0 0,1 16,11.5A1.5,1.5 0 0,1 17.5,10Z\";\r\nvar mdiCast = \"M1,10V12A9,9 0 0,1 10,21H12C12,14.92 7.07,10 1,10M1,14V16A5,5 0 0,1 6,21H8A7,7 0 0,0 1,14M1,18V21H4A3,3 0 0,0 1,18M21,3H3C1.89,3 1,3.89 1,5V8H3V5H21V19H14V21H21A2,2 0 0,0 23,19V5C23,3.89 22.1,3 21,3Z\";\r\nvar mdiCastAudio = \"M2 11V13C7 13 11 17 11 22H13C13 15.9 8.1 11 2 11M20 2H10C8.9 2 8 2.9 8 4V10.5C9 11 9.9 11.7 10.7 12.4C11.6 11 13.2 10 15 10C17.8 10 20 12.2 20 15S17.8 20 15 20H14.8C14.9 20.7 15 21.3 15 22H20C21.1 22 22 21.1 22 20V4C22 2.9 21.1 2 20 2M15 8C13.9 8 13 7.1 13 6C13 4.9 13.9 4 15 4C16.1 4 17 4.9 17 6S16.1 8 15 8M15 18C14.8 18 14.5 18 14.3 17.9C13.8 16.4 13.1 15.1 12.2 13.9C12.6 12.8 13.7 11.9 15 11.9C16.7 11.9 18 13.2 18 14.9S16.7 18 15 18M2 15V17C4.8 17 7 19.2 7 22H9C9 18.1 5.9 15 2 15M2 19V22H5C5 20.3 3.7 19 2 19\";\r\nvar mdiCastConnected = \"M21,3H3C1.89,3 1,3.89 1,5V8H3V5H21V19H14V21H21A2,2 0 0,0 23,19V5C23,3.89 22.1,3 21,3M1,10V12A9,9 0 0,1 10,21H12C12,14.92 7.07,10 1,10M19,7H5V8.63C8.96,9.91 12.09,13.04 13.37,17H19M1,14V16A5,5 0 0,1 6,21H8A7,7 0 0,0 1,14M1,18V21H4A3,3 0 0,0 1,18Z\";\r\nvar mdiCastEducation = \"M21,3H3A2,2 0 0,0 1,5V8H3V5H21V19H14V21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3M1,18V21H4A3,3 0 0,0 1,18M1,14V16A5,5 0 0,1 6,21H8A7,7 0 0,0 1,14M1,10V12A9,9 0 0,1 10,21H12C12,14.92 7.07,10 1,10M11,11.09V13.09L14.5,15L18,13.09V11.09L14.5,13L11,11.09M14.5,6L9,9L14.5,12L20,9L14.5,6Z\";\r\nvar mdiCastOff = \"M1.6,1.27L0.25,2.75L1.41,3.8C1.16,4.13 1,4.55 1,5V8H3V5.23L18.2,19H14V21H20.41L22.31,22.72L23.65,21.24M6.5,3L8.7,5H21V16.14L23,17.95V5C23,3.89 22.1,3 21,3M1,10V12A9,9 0 0,1 10,21H12C12,14.92 7.08,10 1,10M1,14V16A5,5 0 0,1 6,21H8A7,7 0 0,0 1,14M1,18V21H4A3,3 0 0,0 1,18Z\";\r\nvar mdiCastle = \"M2,13H4V15H6V13H8V15H10V13H12V15H14V10L17,7V1H19L23,3L19,5V7L22,10V22H11V19A2,2 0 0,0 9,17A2,2 0 0,0 7,19V22H2V13M18,10C17.45,10 17,10.54 17,11.2V13H19V11.2C19,10.54 18.55,10 18,10Z\";\r\nvar mdiCat = \"M12,8L10.67,8.09C9.81,7.07 7.4,4.5 5,4.5C5,4.5 3.03,7.46 4.96,11.41C4.41,12.24 4.07,12.67 4,13.66L2.07,13.95L2.28,14.93L4.04,14.67L4.18,15.38L2.61,16.32L3.08,17.21L4.53,16.32C5.68,18.76 8.59,20 12,20C15.41,20 18.32,18.76 19.47,16.32L20.92,17.21L21.39,16.32L19.82,15.38L19.96,14.67L21.72,14.93L21.93,13.95L20,13.66C19.93,12.67 19.59,12.24 19.04,11.41C20.97,7.46 19,4.5 19,4.5C16.6,4.5 14.19,7.07 13.33,8.09L12,8M9,11A1,1 0 0,1 10,12A1,1 0 0,1 9,13A1,1 0 0,1 8,12A1,1 0 0,1 9,11M15,11A1,1 0 0,1 16,12A1,1 0 0,1 15,13A1,1 0 0,1 14,12A1,1 0 0,1 15,11M11,14H13L12.3,15.39C12.5,16.03 13.06,16.5 13.75,16.5A1.5,1.5 0 0,0 15.25,15H15.75A2,2 0 0,1 13.75,17C13,17 12.35,16.59 12,16V16H12C11.65,16.59 11,17 10.25,17A2,2 0 0,1 8.25,15H8.75A1.5,1.5 0 0,0 10.25,16.5C10.94,16.5 11.5,16.03 11.7,15.39L11,14Z\";\r\nvar mdiCctv = \"M18.15,4.94C17.77,4.91 17.37,5 17,5.2L8.35,10.2C7.39,10.76 7.07,12 7.62,12.94L9.12,15.53C9.67,16.5 10.89,16.82 11.85,16.27L13.65,15.23C13.92,15.69 14.32,16.06 14.81,16.27V18.04C14.81,19.13 15.7,20 16.81,20H22V18.04H16.81V16.27C17.72,15.87 18.31,14.97 18.31,14C18.31,13.54 18.19,13.11 17.97,12.73L20.5,11.27C21.47,10.71 21.8,9.5 21.24,8.53L19.74,5.94C19.4,5.34 18.79,5 18.15,4.94M6.22,13.17L2,13.87L2.75,15.17L4.75,18.63L5.5,19.93L8.22,16.63L6.22,13.17Z\";\r\nvar mdiCeilingLight = \"M8,9H11V4H13V9H16L20,17H4L8,9M14,18A2,2 0 0,1 12,20A2,2 0 0,1 10,18H14Z\";\r\nvar mdiCellphone = \"M17,19H7V5H17M17,1H7C5.89,1 5,1.89 5,3V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3C19,1.89 18.1,1 17,1Z\";\r\nvar mdiCellphoneAndroid = \"M17.25,18H6.75V4H17.25M14,21H10V20H14M16,1H8A3,3 0 0,0 5,4V20A3,3 0 0,0 8,23H16A3,3 0 0,0 19,20V4A3,3 0 0,0 16,1Z\";\r\nvar mdiCellphoneArrowDown = \"M17,1H7A2,2 0 0,0 5,3V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1M17,19H7V5H17V19M16,13H13V8H11V13H8L12,17L16,13Z\";\r\nvar mdiCellphoneBasic = \"M15,2A1,1 0 0,0 14,3V6H10C8.89,6 8,6.89 8,8V20C8,21.11 8.89,22 10,22H15C16.11,22 17,21.11 17,20V8C17,7.26 16.6,6.62 16,6.28V3A1,1 0 0,0 15,2M10,8H15V13H10V8M10,15H11V16H10V15M12,15H13V16H12V15M14,15H15V16H14V15M10,17H11V18H10V17M12,17H13V18H12V17M14,17H15V18H14V17M10,19H11V20H10V19M12,19H13V20H12V19M14,19H15V20H14V19Z\";\r\nvar mdiCellphoneCharging = \"M11 18.5V13H9L13 5.5V11H15M17 19H7V5H17M17 1H7C5.89 1 5 1.89 5 3V21A2 2 0 0 0 7 23H17A2 2 0 0 0 19 21V3C19 1.89 18.1 1 17 1Z\";\r\nvar mdiCellphoneCog = \"M9.82,12.5C9.84,12.33 9.86,12.17 9.86,12C9.86,11.83 9.84,11.67 9.82,11.5L10.9,10.69C11,10.62 11,10.5 10.96,10.37L9.93,8.64C9.87,8.53 9.73,8.5 9.62,8.53L8.34,9.03C8.07,8.83 7.78,8.67 7.47,8.54L7.27,7.21C7.27,7.09 7.16,7 7.03,7H5C4.85,7 4.74,7.09 4.72,7.21L4.5,8.53C4.21,8.65 3.92,8.83 3.65,9L2.37,8.5C2.25,8.47 2.12,8.5 2.06,8.63L1.03,10.36C0.97,10.5 1,10.61 1.1,10.69L2.18,11.5C2.16,11.67 2.15,11.84 2.15,12C2.15,12.17 2.17,12.33 2.19,12.5L1.1,13.32C1,13.39 1,13.53 1.04,13.64L2.07,15.37C2.13,15.5 2.27,15.5 2.38,15.5L3.66,15C3.93,15.18 4.22,15.34 4.53,15.47L4.73,16.79C4.74,16.91 4.85,17 5,17H7.04C7.17,17 7.28,16.91 7.29,16.79L7.5,15.47C7.8,15.35 8.09,15.17 8.36,15L9.64,15.5C9.76,15.53 9.89,15.5 9.95,15.37L11,13.64C11.04,13.53 11,13.4 10.92,13.32L9.82,12.5M6,13.75C5,13.75 4.2,12.97 4.2,12C4.2,11.03 5,10.25 6,10.25C7,10.25 7.8,11.03 7.8,12C7.8,12.97 7,13.75 6,13.75M17,1H7A2,2 0 0,0 5,3V6H7V4H17V20H7V18H5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1Z\";\r\nvar mdiCellphoneDock = \"M16,15H8V5H16M16,1H8C6.89,1 6,1.89 6,3V17A2,2 0 0,0 8,19H16A2,2 0 0,0 18,17V3C18,1.89 17.1,1 16,1M8,23H16V21H8V23Z\";\r\nvar mdiCellphoneErase = \"M11,8.2L10,7.2L6,11.2L2,7.2L1,8.2L5,12.2L1,16.2L2,17.2L6,13.2L10,17.2L11,16.2L7,12.2L11,8.2M17,1H7A2,2 0 0,0 5,3V6H7V4H17V20H7V18H5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1Z\";\r\nvar mdiCellphoneInformation = \"M13 7H11V9H13V7M13 11H11V17H13V11M17 1H7C5.9 1 5 1.9 5 3V21C5 22.1 5.9 23 7 23H17C18.1 23 19 22.1 19 21V3C19 1.9 18.1 1 17 1M17 19H7V5H17V19Z\";\r\nvar mdiCellphoneIphone = \"M16,18H7V4H16M11.5,22A1.5,1.5 0 0,1 10,20.5A1.5,1.5 0 0,1 11.5,19A1.5,1.5 0 0,1 13,20.5A1.5,1.5 0 0,1 11.5,22M15.5,1H7.5A2.5,2.5 0 0,0 5,3.5V20.5A2.5,2.5 0 0,0 7.5,23H15.5A2.5,2.5 0 0,0 18,20.5V3.5A2.5,2.5 0 0,0 15.5,1Z\";\r\nvar mdiCellphoneKey = \"M7,1A2,2 0 0,0 5,3V7H7V4H17V20H7V17H5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1H7M6,9A3,3 0 0,0 3,12A3,3 0 0,0 6,15C7.31,15 8.42,14.17 8.83,13H11V15H13V13H14V11H8.83C8.42,9.83 7.31,9 6,9M6,11A1,1 0 0,1 7,12A1,1 0 0,1 6,13A1,1 0 0,1 5,12A1,1 0 0,1 6,11Z\";\r\nvar mdiCellphoneLink = \"M22,17H18V10H22M23,8H17A1,1 0 0,0 16,9V19A1,1 0 0,0 17,20H23A1,1 0 0,0 24,19V9A1,1 0 0,0 23,8M4,6H22V4H4A2,2 0 0,0 2,6V17H0V20H14V17H4V6Z\";\r\nvar mdiCellphoneLinkOff = \"M23,8H17A1,1 0 0,0 16,9V13.18L18,15.18V10H22V17H19.82L22.82,20H23A1,1 0 0,0 24,19V9A1,1 0 0,0 23,8M4,6.27L14.73,17H4V6.27M1.92,1.65L0.65,2.92L2.47,4.74C2.18,5.08 2,5.5 2,6V17H0V20H17.73L20.08,22.35L21.35,21.08L3.89,3.62L1.92,1.65M22,6V4H6.82L8.82,6H22Z\";\r\nvar mdiCellphoneLock = \"M17,1H7A2,2 0 0,0 5,3V6H7V4H17V20H7V18H5V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1M8.8,11V9.5C8.8,8.1 7.4,7 6,7C4.6,7 3.2,8.1 3.2,9.5V11C2.6,11 2,11.6 2,12.2V15.7C2,16.4 2.6,17 3.2,17H8.7C9.4,17 10,16.4 10,15.8V12.3C10,11.6 9.4,11 8.8,11M7.5,11H4.5V9.5C4.5,8.7 5.2,8.2 6,8.2C6.8,8.2 7.5,8.7 7.5,9.5V11Z\";\r\nvar mdiCellphoneMessage = \"M11,17V7H4V17H11M11,3A2,2 0 0,1 13,5V19A2,2 0 0,1 11,21H4C2.89,21 2,20.1 2,19V5A2,2 0 0,1 4,3H11M16.5,3H21.5A1.5,1.5 0 0,1 23,4.5V7.5A1.5,1.5 0 0,1 21.5,9H18L15,12V9L15,4.5A1.5,1.5 0 0,1 16.5,3Z\";\r\nvar mdiCellphoneMessageOff = \"M2.39 1.73L1.11 3L2.22 4.11C2.08 4.38 2 4.68 2 5V19C2 20.1 2.89 21 4 21H11C12.1 21 13 20.1 13 19V14.89L20.84 22.73L22.11 21.46L2.39 1.73M11 17H4V7H5.11L11 12.89V17M23 4.5V7.5C23 8.33 22.33 9 21.5 9H18L15.1 11.9L15 11.8V4.5C15 3.67 15.67 3 16.5 3H21.5C22.33 3 23 3.67 23 4.5M10.2 7L6.2 3H11C12.1 3 13 3.9 13 5V9.8L11 7.8V7H10.2\";\r\nvar mdiCellphoneNfc = \"M2,16V18A5,5 0 0,1 7,23H9A7,7 0 0,0 2,16M2,20V23H5A3,3 0 0,0 2,20M2,12V14A9,9 0 0,1 11,23H13C13,16.92 8.08,12 2,12M17,1H7A2,2 0 0,0 5,3V10.37C5.69,10.53 6.36,10.74 7,11V5H17V18H13.97C14.5,19.25 14.81,20.59 14.92,22H17A2,2 0 0,0 19,20V3A2,2 0 0,0 17,1Z\";\r\nvar mdiCellphoneNfcOff = \"M20.84 22.73L18.85 20.74C18.56 21.5 17.84 22 17 22H14.92C14.81 20.59 14.5 19.25 13.97 18H16.11L7 8.89V11C6.36 10.74 5.69 10.53 5 10.37V6.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M17 5V13.8L19 15.8V3C19 1.9 18.11 1 17 1H7C6.24 1 5.59 1.43 5.25 2.05L8.2 5H17M2 20V23H5C5 21.34 3.66 20 2 20M2 16V18C4.76 18 7 20.24 7 23H9C9 19.13 5.87 16 2 16M2 12V14C6.97 14 11 18.03 11 23H13C13 16.92 8.08 12 2 12Z\";\r\nvar mdiCellphoneOff = \"M2.38,1.73L1.11,3L5,6.89V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V20.89L20.84,22.73L22.11,21.46M17,19H7V8.89L17,18.89V19M17,5V13.8L19,15.8V3A2,2 0 0,0 17,1H7C6.28,1 5.6,1.37 5.24,2L8.24,5H17Z\";\r\nvar mdiCellphonePlay = \"M17 19H7V5H17M17 1H7C5.89 1 5 1.89 5 3V21C5 22.1 5.9 23 7 23H17C18.1 23 19 22.1 19 21V3C19 1.89 18.1 1 17 1M10 9V15L14 12L10 9Z\";\r\nvar mdiCellphoneScreenshot = \"M7,1A2,2 0 0,0 5,3V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1H7M7,4H17V20H7V4M9,6V10H10.5V7.5H13V6H9M13.5,14V16.5H11V18H15V14H13.5Z\";\r\nvar mdiCellphoneSettings = \"M16,16H8V4H16M16,0H8A2,2 0 0,0 6,2V18A2,2 0 0,0 8,20H16A2,2 0 0,0 18,18V2A2,2 0 0,0 16,0M15,24H17V22H15M11,24H13V22H11M7,24H9V22H7V24Z\";\r\nvar mdiCellphoneSound = \"M19.1,8.7C20.9,10.5 20.9,13.3 19.1,15.2L20.1,16.2C22.6,13.9 22.6,10.1 20.1,7.7L19.1,8.7M18,9.8L17,10.8C17.5,11.5 17.5,12.4 17,13.1L18,14.1C19.2,12.9 19.2,11.1 18,9.8M14,1H4A2,2 0 0,0 2,3V21A2,2 0 0,0 4,23H14A2,2 0 0,0 16,21V3A2,2 0 0,0 14,1M14,20H4V4H14V20Z\";\r\nvar mdiCellphoneText = \"M17,19V5H7V19H17M17,1A2,2 0 0,1 19,3V21A2,2 0 0,1 17,23H7C5.89,23 5,22.1 5,21V3C5,1.89 5.89,1 7,1H17M9,7H15V9H9V7M9,11H13V13H9V11Z\";\r\nvar mdiCellphoneWireless = \"M20.07,4.93C21.88,6.74 23,9.24 23,12C23,14.76 21.88,17.26 20.07,19.07L18.66,17.66C20.11,16.22 21,14.22 21,12C21,9.79 20.11,7.78 18.66,6.34L20.07,4.93M17.24,7.76C18.33,8.85 19,10.35 19,12C19,13.65 18.33,15.15 17.24,16.24L15.83,14.83C16.55,14.11 17,13.11 17,12C17,10.89 16.55,9.89 15.83,9.17L17.24,7.76M13,10A2,2 0 0,1 15,12A2,2 0 0,1 13,14A2,2 0 0,1 11,12A2,2 0 0,1 13,10M11.5,1A2.5,2.5 0 0,1 14,3.5V8H12V4H3V19H12V16H14V20.5A2.5,2.5 0 0,1 11.5,23H3.5A2.5,2.5 0 0,1 1,20.5V3.5A2.5,2.5 0 0,1 3.5,1H11.5Z\";\r\nvar mdiCelticCross = \"M17.8,8C17.26,5.89 15.61,4.24 13.5,3.7V2H10.5V3.7C8.39,4.24 6.74,5.89 6.2,8H4V11H6.2C6.74,13.11 8.39,14.76 10.5,15.3V22H13.5V15.3C15.61,14.76 17.26,13.11 17.8,11H19.97V8H17.8M12.04,9.53L14.5,11H15.76C15.35,12.03 14.53,12.84 13.5,13.26V12L12.06,9.56L12,9.5L11.94,9.56L10.5,12V13.26C9.47,12.84 8.66,12.03 8.24,11H9.5L11.96,9.53L12,9.5H11.96L9.5,8H8.24C8.65,6.97 9.47,6.16 10.5,5.74V7L11.94,9.44L12,9.5L12.06,9.44L13.5,7V5.74C14.53,6.16 15.35,6.97 15.76,8H14.5L12.04,9.5H12L12.04,9.53Z\";\r\nvar mdiCentos = \"M19.07 14.93L22 12L19.07 9.07V4.93H14.93L12 2L9.07 4.93H4.93V9.07L2 12L4.93 14.93V19.07H9.07L12 22L14.93 19.07H19.07V14.93M21.41 12L19.07 14.34V12.46H13.69L13.23 12L13.69 11.54H19.07V9.66L21.41 12M18.66 14.76L17.32 16.09L14.11 12.87H18.66V14.76M12.46 13.1L12 12.65L11.54 13.1V12.46H10.9L11.36 12L10.9 11.54H11.54V10.9L12 11.36L12.46 10.9V11.54H13.1L12.65 12L13.1 12.46H12.46V13.1M14.11 11.13L17.32 7.91L18.66 9.24V11.13H14.11M18.66 5.35V8.65L17.32 7.32L13.5 11.13H12.87V10.5L16.68 6.68L15.35 5.35H18.66M12.87 9.89V5.35H14.76L16.09 6.68L12.87 9.89M12 2.59L14.34 4.93H12.46V10.31L12 10.77L11.54 10.31V4.93H9.66L12 2.59M11.13 9.89L7.91 6.68L9.24 5.35H11.13V9.89M5.35 5.35H8.65L7.32 6.68L11.13 10.5V11.13H10.5L6.68 7.32L5.35 8.65V5.35M5.35 9.24L6.68 7.91L9.89 11.13H5.35V9.24M2.59 12L4.93 9.66V11.54H10.31L10.77 12L10.31 12.46H4.93V14.34L2.59 12M9.89 12.87L6.68 16.09L5.35 14.76V12.87H9.89M5.35 18.66V15.35L6.68 16.68L10.5 12.87H11.13V13.5L7.32 17.32L8.65 18.65H5.35M11.13 14.11V18.66H9.24L7.91 17.32L11.13 14.11M12 21.41L9.66 19.07H11.54V13.69L12 13.23L12.46 13.69V19.07H14.34L12 21.41M12.87 14.11L16.09 17.32L14.76 18.66H12.87V14.11M15.35 18.66L16.68 17.32L12.87 13.5V12.87H13.5L17.32 16.68L18.65 15.35V18.66H15.35Z\";\r\nvar mdiCertificate = \"M4,3C2.89,3 2,3.89 2,5V15A2,2 0 0,0 4,17H12V22L15,19L18,22V17H20A2,2 0 0,0 22,15V8L22,6V5A2,2 0 0,0 20,3H16V3H4M12,5L15,7L18,5V8.5L21,10L18,11.5V15L15,13L12,15V11.5L9,10L12,8.5V5M4,5H9V7H4V5M4,9H7V11H4V9M4,13H9V15H4V13Z\";\r\nvar mdiCertificateOutline = \"M13 21L15 20L17 21V14H13M17 9V7L15 8L13 7V9L11 10L13 11V13L15 12L17 13V11L19 10M20 3H4A2 2 0 0 0 2 5V15A2 2 0 0 0 4 17H11V15H4V5H20V15H19V17H20A2 2 0 0 0 22 15V5A2 2 0 0 0 20 3M11 8H5V6H11M9 11H5V9H9M11 14H5V12H11Z\";\r\nvar mdiChairRolling = \"M22 10V13H19V10H22M2 13H5V10H2V13M17 5C17 3.9 16.1 3 15 3H9C7.9 3 7 3.9 7 5V13H17V5M7 15H6V17H11V18L7 22H9.8L12 19.8L14.2 22H17L13 18V17H18V15H7Z\";\r\nvar mdiChairSchool = \"M22,5V7H17L13.53,12H16V14H14.46L18.17,22H15.97L15.04,20H6.38L5.35,22H3.1L7.23,14H7C6.55,14 6.17,13.7 6.04,13.3L2.87,3.84L3.82,3.5C4.34,3.34 4.91,3.63 5.08,4.15L7.72,12H12.1L15.57,7H12V5H22M9.5,14L7.42,18H14.11L12.26,14H9.5Z\";\r\nvar mdiCharity = \"M12.75,3.94C13.75,3.22 14.91,2.86 16.22,2.86C16.94,2.86 17.73,3.05 18.59,3.45C19.45,3.84 20.13,4.3 20.63,4.83C21.66,6.11 22.09,7.6 21.94,9.3C21.78,11 21.22,12.33 20.25,13.27L12.66,20.86C12.47,21.05 12.23,21.14 11.95,21.14C11.67,21.14 11.44,21.05 11.25,20.86C11.06,20.67 10.97,20.44 10.97,20.16C10.97,19.88 11.06,19.64 11.25,19.45L15.84,14.86C16.09,14.64 16.09,14.41 15.84,14.16C15.59,13.91 15.36,13.91 15.14,14.16L10.55,18.75C10.36,18.94 10.13,19.03 9.84,19.03C9.56,19.03 9.33,18.94 9.14,18.75C8.95,18.56 8.86,18.33 8.86,18.05C8.86,17.77 8.95,17.53 9.14,17.34L13.73,12.75C14,12.5 14,12.25 13.73,12C13.5,11.75 13.28,11.75 13.03,12L8.44,16.64C8.25,16.83 8,16.92 7.73,16.92C7.45,16.92 7.21,16.83 7,16.64C6.8,16.45 6.7,16.22 6.7,15.94C6.7,15.66 6.81,15.41 7.03,15.19L11.63,10.59C11.88,10.34 11.88,10.11 11.63,9.89C11.38,9.67 11.14,9.67 10.92,9.89L6.28,14.5C6.06,14.7 5.83,14.81 5.58,14.81C5.3,14.81 5.06,14.71 4.88,14.5C4.69,14.3 4.59,14.06 4.59,13.78C4.59,13.5 4.69,13.27 4.88,13.08C7.94,10 9.83,8.14 10.55,7.45L14.11,10.97C14.5,11.34 14.95,11.53 15.5,11.53C16.2,11.53 16.75,11.25 17.16,10.69C17.44,10.28 17.54,9.83 17.46,9.33C17.38,8.83 17.17,8.41 16.83,8.06L12.75,3.94M14.81,10.27L10.55,6L3.47,13.08C2.63,12.23 2.15,10.93 2.04,9.16C1.93,7.4 2.41,5.87 3.47,4.59C4.66,3.41 6.08,2.81 7.73,2.81C9.39,2.81 10.8,3.41 11.95,4.59L16.22,8.86C16.41,9.05 16.5,9.28 16.5,9.56C16.5,9.84 16.41,10.08 16.22,10.27C16.03,10.45 15.8,10.55 15.5,10.55C15.23,10.55 15,10.45 14.81,10.27V10.27Z\";\r\nvar mdiChartArc = \"M16.18,19.6L14.17,16.12C15.15,15.4 15.83,14.28 15.97,13H20C19.83,15.76 18.35,18.16 16.18,19.6M13,7.03V3C17.3,3.26 20.74,6.7 21,11H16.97C16.74,8.91 15.09,7.26 13,7.03M7,12.5C7,13.14 7.13,13.75 7.38,14.3L3.9,16.31C3.32,15.16 3,13.87 3,12.5C3,7.97 6.54,4.27 11,4V8.03C8.75,8.28 7,10.18 7,12.5M11.5,21C8.53,21 5.92,19.5 4.4,17.18L7.88,15.17C8.7,16.28 10,17 11.5,17C12.14,17 12.75,16.87 13.3,16.62L15.31,20.1C14.16,20.68 12.87,21 11.5,21Z\";\r\nvar mdiChartAreaspline = \"M17.45,15.18L22,7.31V19L22,21H2V3H4V15.54L9.5,6L16,9.78L20.24,2.45L21.97,3.45L16.74,12.5L10.23,8.75L4.31,19H6.57L10.96,11.44L17.45,15.18Z\";\r\nvar mdiChartAreasplineVariant = \"M22,21H2V3H4V15.54L9.5,6L16,9.78L20.24,2.45L21.97,3.45L22,21Z\";\r\nvar mdiChartBar = \"M22,21H2V3H4V19H6V10H10V19H12V6H16V19H18V14H22V21Z\";\r\nvar mdiChartBarStacked = \"M22,21H2V3H4V19H6V17H10V19H12V16H16V19H18V17H22V21M18,14H22V16H18V14M12,6H16V9H12V6M16,15H12V10H16V15M6,10H10V12H6V10M10,16H6V13H10V16Z\";\r\nvar mdiChartBellCurve = \"M9.96,11.31C10.82,8.1 11.5,6 13,6C14.5,6 15.18,8.1 16.04,11.31C17,14.92 18.1,19 22,19V17C19.8,17 19,14.54 17.97,10.8C17.08,7.46 16.15,4 13,4C9.85,4 8.92,7.46 8.03,10.8C7.03,14.54 6.2,17 4,17V2H2V22H22V20H4V19C7.9,19 9,14.92 9.96,11.31Z\";\r\nvar mdiChartBellCurveCumulative = \"M4 19V20H22V22H2V2H4V17C7 17 10 15 12.1 11.4C15.1 6.4 18.4 4 22 4V6C19.2 6 16.5 8.1 13.9 12.5C11.3 16.6 7.7 19 4 19Z\";\r\nvar mdiChartBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M9 17H7V10H9V17M13 17H11V7H13V17M17 17H15V13H17V17Z\";\r\nvar mdiChartBoxOutline = \"M9 17H7V10H9V17M13 17H11V7H13V17M17 17H15V13H17V17M19.5 19.1H4.5V5H19.5V19.1M19.5 3H4.5C3.4 3 2.5 3.9 2.5 5V19C2.5 20.1 3.4 21 4.5 21H19.5C20.6 21 21.5 20.1 21.5 19V5C21.5 3.9 20.6 3 19.5 3Z\";\r\nvar mdiChartBoxPlusOutline = \"M22 5V7H19V10H17V7H14V5H17V2H19V5H22M19 19H5V5H11V3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V13H19V19M15 13V17H17V13H15M11 17H13V9H11V17M9 17V11H7V17H9Z\";\r\nvar mdiChartBubble = \"M7.2,11.2C8.97,11.2 10.4,12.63 10.4,14.4C10.4,16.17 8.97,17.6 7.2,17.6C5.43,17.6 4,16.17 4,14.4C4,12.63 5.43,11.2 7.2,11.2M14.8,16A2,2 0 0,1 16.8,18A2,2 0 0,1 14.8,20A2,2 0 0,1 12.8,18A2,2 0 0,1 14.8,16M15.2,4A4.8,4.8 0 0,1 20,8.8C20,11.45 17.85,13.6 15.2,13.6A4.8,4.8 0 0,1 10.4,8.8C10.4,6.15 12.55,4 15.2,4Z\";\r\nvar mdiChartDonut = \"M13,2.05V5.08C16.39,5.57 19,8.47 19,12C19,12.9 18.82,13.75 18.5,14.54L21.12,16.07C21.68,14.83 22,13.45 22,12C22,6.82 18.05,2.55 13,2.05M12,19A7,7 0 0,1 5,12C5,8.47 7.61,5.57 11,5.08V2.05C5.94,2.55 2,6.81 2,12A10,10 0 0,0 12,22C15.3,22 18.23,20.39 20.05,17.91L17.45,16.38C16.17,18 14.21,19 12,19Z\";\r\nvar mdiChartDonutVariant = \"M13,2.05C18.05,2.55 22,6.82 22,12C22,13.45 21.68,14.83 21.12,16.07L18.5,14.54C18.82,13.75 19,12.9 19,12C19,8.47 16.39,5.57 13,5.08V2.05M12,19C14.21,19 16.17,18 17.45,16.38L20.05,17.91C18.23,20.39 15.3,22 12,22C6.47,22 2,17.5 2,12C2,6.81 5.94,2.55 11,2.05V5.08C7.61,5.57 5,8.47 5,12A7,7 0 0,0 12,19M12,6A6,6 0 0,1 18,12C18,14.97 15.84,17.44 13,17.92V14.83C14.17,14.42 15,13.31 15,12A3,3 0 0,0 12,9L11.45,9.05L9.91,6.38C10.56,6.13 11.26,6 12,6M6,12C6,10.14 6.85,8.5 8.18,7.38L9.72,10.05C9.27,10.57 9,11.26 9,12C9,13.31 9.83,14.42 11,14.83V17.92C8.16,17.44 6,14.97 6,12Z\";\r\nvar mdiChartGantt = \"M2,5H10V2H12V22H10V18H6V15H10V13H4V10H10V8H2V5M14,5H17V8H14V5M14,10H19V13H14V10M14,15H22V18H14V15Z\";\r\nvar mdiChartHistogram = \"M3,3H5V13H9V7H13V11H17V15H21V21H3V3Z\";\r\nvar mdiChartLine = \"M16,11.78L20.24,4.45L21.97,5.45L16.74,14.5L10.23,10.75L5.46,19H22V21H2V3H4V17.54L9.5,8L16,11.78Z\";\r\nvar mdiChartLineStacked = \"M17.45,15.18L22,6.81V19L22,21H2V3H4V15.54L4,19H4.31L6,19H6.57L10.96,11.44L17.45,15.18M22,3L21.97,3.45L17,11L10,6L6,12V3H22Z\";\r\nvar mdiChartLineVariant = \"M3.5,18.5L9.5,12.5L13.5,16.5L22,6.92L20.59,5.5L13.5,13.5L9.5,9.5L2,17L3.5,18.5Z\";\r\nvar mdiChartMultiline = \"M22,6.92L20.59,5.5L17.74,8.72C15.68,6.4 12.83,5 9.61,5C6.72,5 4.07,6.16 2,8L3.42,9.42C5.12,7.93 7.27,7 9.61,7C12.35,7 14.7,8.26 16.38,10.24L13.5,13.5L9.5,9.5L2,17L3.5,18.5L9.5,12.5L13.5,16.5L17.55,11.93C18.3,13.28 18.8,14.83 19,16.5H21C20.78,14.18 20.05,12.09 18.96,10.34L22,6.92Z\";\r\nvar mdiChartMultiple = \"M22 16V18H6V2H8V13.57L13.71 4.57L16.87 6.68L19.29 4.26L20.71 5.68L17.13 9.29L14.29 7.4L8.82 16M4 20V4H2V22H22V20Z\";\r\nvar mdiChartPie = \"M11,2V22C5.9,21.5 2,17.2 2,12C2,6.8 5.9,2.5 11,2M13,2V11H22C21.5,6.2 17.8,2.5 13,2M13,13V22C17.7,21.5 21.5,17.8 22,13H13Z\";\r\nvar mdiChartPpf = \"M5 6V8C8.2 8 11.36 9.18 13.57 11.15C15.64 13 16.83 15.5 17 18H18.97A14 12.5 0 0 0 5 6M22 21H2V3H4V19H22Z\";\r\nvar mdiChartSankey = \"M22 5H4V2H2V22H22V20H4V9C8.09 9 10.13 11 12.29 13.21S17.09 18 22 18V16C17.91 16 15.87 14 13.71 11.79S8.91 7 4 7H22Z\";\r\nvar mdiChartSankeyVariant = \"M20 4V6H4V4H2V12H4V10C8.16 10 9.92 12.11 11.77 14.34S15.65 19 20 19V21H22V15H20V17C16.59 17 15.07 15.17 13.31 13.06C11.34 10.69 9.1 8 4 8H20V10H22V4Z\";\r\nvar mdiChartScatterPlot = \"M2,2H4V20H22V22H2V2M9,10A3,3 0 0,1 12,13A3,3 0 0,1 9,16A3,3 0 0,1 6,13A3,3 0 0,1 9,10M13,2A3,3 0 0,1 16,5A3,3 0 0,1 13,8A3,3 0 0,1 10,5A3,3 0 0,1 13,2M18,12A3,3 0 0,1 21,15A3,3 0 0,1 18,18A3,3 0 0,1 15,15A3,3 0 0,1 18,12Z\";\r\nvar mdiChartScatterPlotHexbin = \"M2,2H4V20H22V22H2V2M14,14.5L12,18H7.94L5.92,14.5L7.94,11H12L14,14.5M14.08,6.5L12.06,10H8L6,6.5L8,3H12.06L14.08,6.5M21.25,10.5L19.23,14H15.19L13.17,10.5L15.19,7H19.23L21.25,10.5Z\";\r\nvar mdiChartTimeline = \"M2,2H4V20H22V22H2V2M7,10H17V13H7V10M11,15H21V18H11V15M6,4H22V8H20V6H8V8H6V4Z\";\r\nvar mdiChartTimelineVariant = \"M3,14L3.5,14.07L8.07,9.5C7.89,8.85 8.06,8.11 8.59,7.59C9.37,6.8 10.63,6.8 11.41,7.59C11.94,8.11 12.11,8.85 11.93,9.5L14.5,12.07L15,12C15.18,12 15.35,12 15.5,12.07L19.07,8.5C19,8.35 19,8.18 19,8A2,2 0 0,1 21,6A2,2 0 0,1 23,8A2,2 0 0,1 21,10C20.82,10 20.65,10 20.5,9.93L16.93,13.5C17,13.65 17,13.82 17,14A2,2 0 0,1 15,16A2,2 0 0,1 13,14L13.07,13.5L10.5,10.93C10.18,11 9.82,11 9.5,10.93L4.93,15.5L5,16A2,2 0 0,1 3,18A2,2 0 0,1 1,16A2,2 0 0,1 3,14Z\";\r\nvar mdiChartTimelineVariantShimmer = \"M21 8C19.5 8 18.7 9.4 19.1 10.5L15.5 14.1C15.2 14 14.8 14 14.5 14.1L11.9 11.5C12.3 10.4 11.5 9 10 9C8.6 9 7.7 10.4 8.1 11.5L3.5 16C2.4 15.7 1 16.5 1 18C1 19.1 1.9 20 3 20C4.4 20 5.3 18.6 4.9 17.5L9.4 12.9C9.7 13 10.1 13 10.4 12.9L13 15.5C12.7 16.5 13.5 18 15 18C16.5 18 17.3 16.6 16.9 15.5L20.5 11.9C21.6 12.2 23 11.4 23 10C23 8.9 22.1 8 21 8M15 9L15.9 6.9L18 6L15.9 5.1L15 3L14.1 5.1L12 6L14.1 6.9L15 9M3.5 11L4 9L6 8.5L4 8L3.5 6L3 8L1 8.5L3 9L3.5 11Z\";\r\nvar mdiChartTree = \"M14,6H22V22H14V6M2,4H22V2H2V4M2,8H12V6H2V8M9,22H12V10H9V22M2,22H7V10H2V22Z\";\r\nvar mdiChat = \"M12,3C17.5,3 22,6.58 22,11C22,15.42 17.5,19 12,19C10.76,19 9.57,18.82 8.47,18.5C5.55,21 2,21 2,21C4.33,18.67 4.7,17.1 4.75,16.5C3.05,15.07 2,13.13 2,11C2,6.58 6.5,3 12,3Z\";\r\nvar mdiChatAlert = \"M12,3C17.5,3 22,6.58 22,11C22,15.42 17.5,19 12,19C10.76,19 9.57,18.82 8.47,18.5C5.55,21 2,21 2,21C4.33,18.67 4.7,17.1 4.75,16.5C3.05,15.07 2,13.13 2,11C2,6.58 6.5,3 12,3M11,14V16H13V14H11M11,12H13V6H11V12Z\";\r\nvar mdiChatAlertOutline = \"M12 3C6.5 3 2 6.58 2 11C2.05 13.15 3.06 15.17 4.75 16.5C4.75 17.1 4.33 18.67 2 21C4.37 20.89 6.64 20 8.47 18.5C9.61 18.83 10.81 19 12 19C17.5 19 22 15.42 22 11S17.5 3 12 3M12 17C7.58 17 4 14.31 4 11S7.58 5 12 5 20 7.69 20 11 16.42 17 12 17M11 13V15H13V13H11M11 11H13V7H11V11Z\";\r\nvar mdiChatMinus = \"M23 17V19H15V17H23M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C20.95 12.25 20 12 19 12C15.69 12 13 14.69 13 18L13.08 18.95L12 19C10.76 19 9.57 18.82 8.47 18.5C5.55 21 2 21 2 21C4.33 18.67 4.7 17.1 4.75 16.5C3.05 15.07 2 13.14 2 11C2 6.58 6.5 3 12 3Z\";\r\nvar mdiChatMinusOutline = \"M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C21.19 12.38 20.55 12.16 19.88 12.06C19.96 11.72 20 11.36 20 11C20 7.69 16.42 5 12 5S4 7.69 4 11 7.58 17 12 17L13.09 16.95L13 18L13.08 18.95L12 19C10.81 19 9.62 18.83 8.47 18.5C6.64 20 4.37 20.89 2 21C4.33 18.67 4.75 17.1 4.75 16.5C3.06 15.17 2.05 13.15 2 11C2 6.58 6.5 3 12 3M23 17V19H15V17H23Z\";\r\nvar mdiChatOutline = \"M12,3C6.5,3 2,6.58 2,11C2.05,13.15 3.06,15.17 4.75,16.5C4.75,17.1 4.33,18.67 2,21C4.37,20.89 6.64,20 8.47,18.5C9.61,18.83 10.81,19 12,19C17.5,19 22,15.42 22,11C22,6.58 17.5,3 12,3M12,17C7.58,17 4,14.31 4,11C4,7.69 7.58,5 12,5C16.42,5 20,7.69 20,11C20,14.31 16.42,17 12,17Z\";\r\nvar mdiChatPlus = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C20.95 12.25 20 12 19 12C15.69 12 13 14.69 13 18L13.08 18.95L12 19C10.76 19 9.57 18.82 8.47 18.5C5.55 21 2 21 2 21C4.33 18.67 4.7 17.1 4.75 16.5C3.05 15.07 2 13.14 2 11C2 6.58 6.5 3 12 3Z\";\r\nvar mdiChatPlusOutline = \"M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C21.19 12.38 20.55 12.16 19.88 12.06C19.96 11.72 20 11.36 20 11C20 7.69 16.42 5 12 5C7.58 5 4 7.69 4 11C4 14.31 7.58 17 12 17L13.09 16.95L13 18L13.08 18.95L12 19C10.81 19 9.62 18.83 8.47 18.5C6.64 20 4.37 20.89 2 21C4.33 18.67 4.75 17.1 4.75 16.5C3.06 15.17 2.05 13.15 2 11C2 6.58 6.5 3 12 3M18 14H20V17H23V19H20V22H18V19H15V17H18V14Z\";\r\nvar mdiChatProcessing = \"M12,3C17.5,3 22,6.58 22,11C22,15.42 17.5,19 12,19C10.76,19 9.57,18.82 8.47,18.5C5.55,21 2,21 2,21C4.33,18.67 4.7,17.1 4.75,16.5C3.05,15.07 2,13.13 2,11C2,6.58 6.5,3 12,3M17,12V10H15V12H17M13,12V10H11V12H13M9,12V10H7V12H9Z\";\r\nvar mdiChatProcessingOutline = \"M12 3C6.5 3 2 6.58 2 11C2.05 13.15 3.06 15.17 4.75 16.5C4.75 17.1 4.33 18.67 2 21C4.37 20.89 6.64 20 8.47 18.5C9.61 18.83 10.81 19 12 19C17.5 19 22 15.42 22 11S17.5 3 12 3M12 17C7.58 17 4 14.31 4 11S7.58 5 12 5 20 7.69 20 11 16.42 17 12 17M17 12V10H15V12H17M13 12V10H11V12H13M9 12V10H7V12H9Z\";\r\nvar mdiChatRemove = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.54 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.54L15.46 20.12L17.59 18L15.47 15.88M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C20.95 12.25 20 12 19 12C15.69 12 13 14.69 13 18L13.08 18.95L12 19C10.76 19 9.57 18.82 8.47 18.5C5.55 21 2 21 2 21C4.33 18.67 4.7 17.1 4.75 16.5C3.05 15.07 2 13.14 2 11C2 6.58 6.5 3 12 3Z\";\r\nvar mdiChatRemoveOutline = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.54 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.54L15.46 20.12L17.59 18L15.47 15.88M12 3C17.5 3 22 6.58 22 11C22 11.58 21.92 12.14 21.78 12.68C21.19 12.38 20.55 12.16 19.88 12.06C19.96 11.72 20 11.36 20 11C20 7.69 16.42 5 12 5C7.58 5 4 7.69 4 11C4 14.31 7.58 17 12 17L13.09 16.95L13 18L13.08 18.95L12 19C10.81 19 9.62 18.83 8.47 18.5C6.64 20 4.37 20.89 2 21C4.33 18.67 4.75 17.1 4.75 16.5C3.06 15.17 2.05 13.15 2 11C2 6.58 6.5 3 12 3Z\";\r\nvar mdiChatSleep = \"M12 3C6.5 3 2 6.58 2 11C2 13.13 3.05 15.07 4.75 16.5C4.7 17.1 4.33 18.67 2 21C2 21 5.55 21 8.47 18.5C9.57 18.82 10.76 19 12 19C17.5 19 22 15.42 22 11S17.5 3 12 3M15 9.3L11.76 13H15V15H9V12.7L12.24 9H9V7H15V9.3Z\";\r\nvar mdiChatSleepOutline = \"M12 3C6.5 3 2 6.58 2 11C2.05 13.15 3.06 15.17 4.75 16.5C4.75 17.1 4.33 18.67 2 21C4.37 20.89 6.64 20 8.47 18.5C9.61 18.83 10.81 19 12 19C17.5 19 22 15.42 22 11S17.5 3 12 3M12 17C7.58 17 4 14.31 4 11S7.58 5 12 5 20 7.69 20 11 16.42 17 12 17M15 7H9V9H12.24L9 12.7V15H15V13H11.76L15 9.3V7Z\";\r\nvar mdiCheck = \"M21,7L9,19L3.5,13.5L4.91,12.09L9,16.17L19.59,5.59L21,7Z\";\r\nvar mdiCheckAll = \"M0.41,13.41L6,19L7.41,17.58L1.83,12M22.24,5.58L11.66,16.17L7.5,12L6.07,13.41L11.66,19L23.66,7M18,7L16.59,5.58L10.24,11.93L11.66,13.34L18,7Z\";\r\nvar mdiCheckBold = \"M9,20.42L2.79,14.21L5.62,11.38L9,14.77L18.88,4.88L21.71,7.71L9,20.42Z\";\r\nvar mdiCheckBoxMultipleOutline = \"M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M20,16H8V4H20V16M16,20V22H4A2,2 0 0,1 2,20V7H4V20H16M18.53,8.06L17.47,7L12.59,11.88L10.47,9.76L9.41,10.82L12.59,14L18.53,8.06Z\";\r\nvar mdiCheckBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,5V19H5V5H19M10,17L6,13L7.41,11.58L10,14.17L16.59,7.58L18,9\";\r\nvar mdiCheckCircle = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M10 17L5 12L6.41 10.59L10 14.17L17.59 6.58L19 8L10 17Z\";\r\nvar mdiCheckCircleOutline = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 20C7.59 20 4 16.41 4 12S7.59 4 12 4 20 7.59 20 12 16.41 20 12 20M16.59 7.58L10 14.17L7.41 11.59L6 13L10 17L18 9L16.59 7.58Z\";\r\nvar mdiCheckDecagram = \"M23,12L20.56,9.22L20.9,5.54L17.29,4.72L15.4,1.54L12,3L8.6,1.54L6.71,4.72L3.1,5.53L3.44,9.21L1,12L3.44,14.78L3.1,18.47L6.71,19.29L8.6,22.47L12,21L15.4,22.46L17.29,19.28L20.9,18.46L20.56,14.78L23,12M10,17L6,13L7.41,11.59L10,14.17L16.59,7.58L18,9L10,17Z\";\r\nvar mdiCheckNetwork = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M8.25,10.08L9.41,8.92L11,10.5L14.59,6.92L15.75,8.33L11,13.08L8.25,10.08Z\";\r\nvar mdiCheckNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M8,10.37L9.24,9.13L10.93,10.83L14.76,7L16,8.5L10.93,13.57L8,10.37Z\";\r\nvar mdiCheckOutline = \"M19.78,2.2L24,6.42L8.44,22L0,13.55L4.22,9.33L8.44,13.55L19.78,2.2M19.78,5L8.44,16.36L4.22,12.19L2.81,13.55L8.44,19.17L21.19,6.42L19.78,5Z\";\r\nvar mdiCheckUnderline = \"M21,5L9,17L3.5,11.5L4.91,10.09L9,14.17L19.59,3.59L21,5M3,21V19H21V21H3Z\";\r\nvar mdiCheckUnderlineCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M17,18H7V16H17V18M10.3,14L7,10.7L8.4,9.3L10.3,11.2L15.6,5.9L17,7.3L10.3,14Z\";\r\nvar mdiCheckUnderlineCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M7,15H17V17H7V15M10.3,11.2L8.4,9.3L7,10.7L10.3,14L17,7.3L15.6,5.9L10.3,11.2Z\";\r\nvar mdiCheckbook = \"M5,14H19V15H5V14M21,17V8H3V17H21M1,5H23V19H1V5M5,10H12V12H5V10Z\";\r\nvar mdiCheckboxBlank = \"M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiCheckboxBlankCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCheckboxBlankCircleOutline = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCheckboxBlankOff = \"M20.84 22.73L19.1 21C19.06 21 19.03 21 19 21H5C3.9 21 3 20.11 3 19V5C3 4.97 3 4.94 3 4.9L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M21 5C21 3.89 20.1 3 19 3H6.2L21 17.8V5Z\";\r\nvar mdiCheckboxBlankOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L3 4.9V19C3 20.11 3.9 21 5 21H19.1L20.84 22.73L22.11 21.46M5 19V6.89L17.11 19H5M8.2 5L6.2 3H19C20.1 3 21 3.89 21 5V17.8L19 15.8V5H8.2Z\";\r\nvar mdiCheckboxBlankOutline = \"M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M19,5V19H5V5H19Z\";\r\nvar mdiCheckboxIntermediate = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M17,17H7V7H17V17Z\";\r\nvar mdiCheckboxMarked = \"M10,17L5,12L6.41,10.58L10,14.17L17.59,6.58L19,8M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiCheckboxMarkedCircle = \"M10,17L5,12L6.41,10.58L10,14.17L17.59,6.58L19,8M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCheckboxMarkedCircleOutline = \"M20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4C12.76,4 13.5,4.11 14.2,4.31L15.77,2.74C14.61,2.26 13.34,2 12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12M7.91,10.08L6.5,11.5L11,16L21,6L19.59,4.58L11,13.17L7.91,10.08Z\";\r\nvar mdiCheckboxMarkedOutline = \"M19,19H5V5H15V3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V11H19M7.91,10.08L6.5,11.5L11,16L21,6L19.59,4.58L11,13.17L7.91,10.08Z\";\r\nvar mdiCheckboxMultipleBlank = \"M22,16A2,2 0 0,1 20,18H8C6.89,18 6,17.1 6,16V4C6,2.89 6.89,2 8,2H20A2,2 0 0,1 22,4V16M16,20V22H4A2,2 0 0,1 2,20V7H4V20H16Z\";\r\nvar mdiCheckboxMultipleBlankCircle = \"M14,2A8,8 0 0,0 6,10A8,8 0 0,0 14,18A8,8 0 0,0 22,10A8,8 0 0,0 14,2M4.93,5.82C3.08,7.34 2,9.61 2,12A8,8 0 0,0 10,20C10.64,20 11.27,19.92 11.88,19.77C10.12,19.38 8.5,18.5 7.17,17.29C5.22,16.25 4,14.21 4,12C4,11.7 4.03,11.41 4.07,11.11C4.03,10.74 4,10.37 4,10C4,8.56 4.32,7.13 4.93,5.82Z\";\r\nvar mdiCheckboxMultipleBlankCircleOutline = \"M14,2A8,8 0 0,0 6,10A8,8 0 0,0 14,18A8,8 0 0,0 22,10A8,8 0 0,0 14,2M14,4C17.32,4 20,6.69 20,10C20,13.32 17.32,16 14,16A6,6 0 0,1 8,10A6,6 0 0,1 14,4M4.93,5.82C3.08,7.34 2,9.61 2,12A8,8 0 0,0 10,20C10.64,20 11.27,19.92 11.88,19.77C10.12,19.38 8.5,18.5 7.17,17.29C5.22,16.25 4,14.21 4,12C4,11.7 4.03,11.41 4.07,11.11C4.03,10.74 4,10.37 4,10C4,8.56 4.32,7.13 4.93,5.82Z\";\r\nvar mdiCheckboxMultipleBlankOutline = \"M20,16V4H8V16H20M22,16A2,2 0 0,1 20,18H8C6.89,18 6,17.1 6,16V4C6,2.89 6.89,2 8,2H20A2,2 0 0,1 22,4V16M16,20V22H4A2,2 0 0,1 2,20V7H4V20H16Z\";\r\nvar mdiCheckboxMultipleMarked = \"M22,16A2,2 0 0,1 20,18H8C6.89,18 6,17.1 6,16V4C6,2.89 6.89,2 8,2H20A2,2 0 0,1 22,4V16M16,20V22H4A2,2 0 0,1 2,20V7H4V20H16M13,14L20,7L18.59,5.59L13,11.17L9.91,8.09L8.5,9.5L13,14Z\";\r\nvar mdiCheckboxMultipleMarkedCircle = \"M14,2A8,8 0 0,0 6,10A8,8 0 0,0 14,18A8,8 0 0,0 22,10A8,8 0 0,0 14,2M4.93,5.82C3.08,7.34 2,9.61 2,12A8,8 0 0,0 10,20C10.64,20 11.27,19.92 11.88,19.77C10.12,19.38 8.5,18.5 7.17,17.29C5.22,16.25 4,14.21 4,12C4,11.7 4.03,11.41 4.07,11.11C4.03,10.74 4,10.37 4,10C4,8.56 4.32,7.13 4.93,5.82M18.09,6.08L19.5,7.5L13,14L9.21,10.21L10.63,8.79L13,11.17\";\r\nvar mdiCheckboxMultipleMarkedCircleOutline = \"M14,2A8,8 0 0,0 6,10A8,8 0 0,0 14,18A8,8 0 0,0 22,10H20C20,13.32 17.32,16 14,16A6,6 0 0,1 8,10A6,6 0 0,1 14,4C14.43,4 14.86,4.05 15.27,4.14L16.88,2.54C15.96,2.18 15,2 14,2M20.59,3.58L14,10.17L11.62,7.79L10.21,9.21L14,13L22,5M4.93,5.82C3.08,7.34 2,9.61 2,12A8,8 0 0,0 10,20C10.64,20 11.27,19.92 11.88,19.77C10.12,19.38 8.5,18.5 7.17,17.29C5.22,16.25 4,14.21 4,12C4,11.7 4.03,11.41 4.07,11.11C4.03,10.74 4,10.37 4,10C4,8.56 4.32,7.13 4.93,5.82Z\";\r\nvar mdiCheckboxMultipleMarkedOutline = \"M20,16V10H22V16A2,2 0 0,1 20,18H8C6.89,18 6,17.1 6,16V4C6,2.89 6.89,2 8,2H16V4H8V16H20M10.91,7.08L14,10.17L20.59,3.58L22,5L14,13L9.5,8.5L10.91,7.08M16,20V22H4A2,2 0 0,1 2,20V7H4V20H16Z\";\r\nvar mdiCheckerboard = \"M2 2V22H22V2H2M20 12H16V16H20V20H16V16H12V20H8V16H4V12H8V8H4V4H8V8H12V4H16V8H20V12M16 8V12H12V8H16M12 12V16H8V12H12Z\";\r\nvar mdiCheckerboardMinus = \"M14 17V19H22V17M8 16H12V12H8V16M12 12H16V8H12V12M2 2V22H13.5C13 21.4 12.6 20.7 12.3 20H8V16H4V12H8V8H4V4H8V8H12V4H16V8H20V12.4C20.7 12.7 21.4 13.1 22 13.6V2H2Z\";\r\nvar mdiCheckerboardPlus = \"M19 17H22V19H19V22H17V19H14V17H17V14H19V17M8 16H12V12H8V16M12 12H16V8H12V12M2 2V22H13.54C13 21.42 12.63 20.74 12.36 20H8V16H4V12H8V8H4V4H8V8H12V4H16V8H20V12.36C20.74 12.63 21.42 13 22 13.54V2H2Z\";\r\nvar mdiCheckerboardRemove = \"M8 16H12V12H8V16M12 12H16V8H12V12M2 2V22H13.5C13 21.4 12.6 20.7 12.3 20H8V16H4V12H8V8H4V4H8V8H12V4H16V8H20V12.4C20.7 12.7 21.4 13.1 22 13.6V2H2M20.1 14.5L18 16.6L15.9 14.5L14.5 15.9L16.6 18L14.5 20.1L15.9 21.5L18 19.4L20.1 21.5L21.5 20.1L19.4 18L21.5 15.9L20.1 14.5Z\";\r\nvar mdiCheese = \"M11 17.5C11 16.67 11.67 16 12.5 16C12.79 16 13.06 16.09 13.29 16.23L20.75 11.93C20.35 11.22 19.9 10.55 19.41 9.9C19.29 9.96 19.15 10 19 10C18.45 10 18 9.55 18 9C18 8.8 18.08 8.62 18.18 8.46C16.45 6.64 14.34 5.2 12 4.25C11.85 5.24 11 6 10 6C8.9 6 8 5.11 8 4C8 3.72 8.06 3.45 8.16 3.21C7.3 3.08 6.41 3 5.5 3C5.33 3 5.17 3 5 3.03V9.05C6.14 9.28 7 10.29 7 11.5S6.14 13.72 5 13.95V21L11 17.54C11 17.53 11 17.5 11 17.5M14 9C15.11 9 16 9.9 16 11S15.11 13 14 13 12 12.11 12 11 12.9 9 14 9M9 16C8.45 16 8 15.55 8 15S8.45 14 9 14 10 14.45 10 15 9.55 16 9 16M9 10C8.45 10 8 9.55 8 9S8.45 8 9 8 10 8.45 10 9 9.55 10 9 10Z\";\r\nvar mdiCheeseOff = \"M3.5 1.7L2.2 3L6.1 6.9V9C7.2 9.2 8.1 10.2 8.1 11.5S7.2 13.7 6.1 14V21L12.1 17.5C12.1 16.7 12.8 16 13.6 16C13.9 16 14.2 16.1 14.4 16.2L15.1 15.8L20.3 21L21.6 19.7L3.5 1.7M10.1 16C9.6 16 9.1 15.5 9.1 15S9.6 14 10.1 14 11.1 14.5 11.1 15 10.6 16 10.1 16M13.8 9.5L9.9 5.6C10.2 5.9 10.6 6 11.1 6C12.1 6 12.9 5.2 13.1 4.2C15.4 5.2 17.6 6.6 19.3 8.4C19.2 8.6 19.1 8.7 19.1 8.9C19.1 9.4 19.6 9.9 20.1 9.9C20.3 9.9 20.4 9.9 20.5 9.8C21 10.4 21.4 11.1 21.8 11.8L18.3 13.8L16.6 12.1C16.9 11.8 17.1 11.3 17.1 10.8C17.1 9.7 16.2 8.8 15.1 8.8C14.6 9 14.1 9.2 13.8 9.5M9.5 5.2L7.3 3C8 3 8.6 3.1 9.2 3.2C9.1 3.5 9.1 3.7 9.1 4C9.1 4.4 9.2 4.9 9.5 5.2Z\";\r\nvar mdiChefHat = \"M12.5,1.5C10.73,1.5 9.17,2.67 8.67,4.37C8.14,4.13 7.58,4 7,4A4,4 0 0,0 3,8C3,9.82 4.24,11.41 6,11.87V19H19V11.87C20.76,11.41 22,9.82 22,8A4,4 0 0,0 18,4C17.42,4 16.86,4.13 16.33,4.37C15.83,2.67 14.27,1.5 12.5,1.5M12,10.5H13V17.5H12V10.5M9,12.5H10V17.5H9V12.5M15,12.5H16V17.5H15V12.5M6,20V21A1,1 0 0,0 7,22H18A1,1 0 0,0 19,21V20H6Z\";\r\nvar mdiChemicalWeapon = \"M11,7.83C9.83,7.42 9,6.3 9,5A3,3 0 0,1 12,2A3,3 0 0,1 15,5C15,6.31 14.16,7.42 13,7.83V10.64C12.68,10.55 12.35,10.5 12,10.5C11.65,10.5 11.32,10.55 11,10.64V7.83M18.3,21.1C17.16,20.45 16.62,19.18 16.84,17.96L14.4,16.55C14.88,16.09 15.24,15.5 15.4,14.82L17.84,16.23C18.78,15.42 20.16,15.26 21.29,15.91C22.73,16.74 23.22,18.57 22.39,20C21.56,21.44 19.73,21.93 18.3,21.1M2.7,15.9C3.83,15.25 5.21,15.42 6.15,16.22L8.6,14.81C8.76,15.5 9.11,16.08 9.6,16.54L7.15,17.95C7.38,19.17 6.83,20.45 5.7,21.1C4.26,21.93 2.43,21.44 1.6,20C0.77,18.57 1.26,16.73 2.7,15.9M14,14A2,2 0 0,1 12,16C10.89,16 10,15.1 10,14A2,2 0 0,1 12,12C13.11,12 14,12.9 14,14M17,14L16.97,14.57L15.5,13.71C15.4,12.64 14.83,11.71 14,11.12V9.41C15.77,10.19 17,11.95 17,14M14.97,18.03C14.14,18.64 13.11,19 12,19C10.89,19 9.86,18.64 9.03,18L10.5,17.17C10.96,17.38 11.47,17.5 12,17.5C12.53,17.5 13.03,17.38 13.5,17.17L14.97,18.03M7.03,14.56L7,14C7,11.95 8.23,10.19 10,9.42V11.13C9.17,11.71 8.6,12.64 8.5,13.7L7.03,14.56Z\";\r\nvar mdiChessBishop = \"M19,22H5V20H19V22M17.16,8.26C18.22,9.63 18.86,11.28 19,13C19,15.76 15.87,18 12,18C8.13,18 5,15.76 5,13C5,10.62 7.33,6.39 10.46,5.27C10.16,4.91 10,4.46 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.46 13.84,4.91 13.54,5.27C14.4,5.6 15.18,6.1 15.84,6.74L11.29,11.29L12.71,12.71L17.16,8.26Z\";\r\nvar mdiChessKing = \"M19,22H5V20H19V22M17,10C15.58,10 14.26,10.77 13.55,12H13V7H16V5H13V2H11V5H8V7H11V12H10.45C9.35,10.09 6.9,9.43 5,10.54C3.07,11.64 2.42,14.09 3.5,16C4.24,17.24 5.57,18 7,18H17A4,4 0 0,0 21,14A4,4 0 0,0 17,10Z\";\r\nvar mdiChessKnight = \"M19,22H5V20H19V22M13,2V2C11.75,2 10.58,2.62 9.89,3.66L7,8L9,10L11.06,8.63C11.5,8.32 12.14,8.44 12.45,8.9C12.47,8.93 12.5,8.96 12.5,9V9C12.8,9.59 12.69,10.3 12.22,10.77L7.42,15.57C6.87,16.13 6.87,17.03 7.43,17.58C7.69,17.84 8.05,18 8.42,18H17V6A4,4 0 0,0 13,2Z\";\r\nvar mdiChessPawn = \"M19 22H5V20H19V22M16 18H8L10.18 10H8V8H10.72L10.79 7.74C10.1 7.44 9.55 6.89 9.25 6.2C8.58 4.68 9.27 2.91 10.79 2.25C12.31 1.58 14.08 2.27 14.74 3.79C15.41 5.31 14.72 7.07 13.2 7.74L13.27 8H16V10H13.82L16 18Z\";\r\nvar mdiChessQueen = \"M18,3A2,2 0 0,1 20,5C20,5.81 19.5,6.5 18.83,6.82L17,13.15V18H7V13.15L5.17,6.82C4.5,6.5 4,5.81 4,5A2,2 0 0,1 6,3A2,2 0 0,1 8,5C8,5.5 7.82,5.95 7.5,6.3L10.3,9.35L10.83,5.62C10.33,5.26 10,4.67 10,4A2,2 0 0,1 12,2A2,2 0 0,1 14,4C14,4.67 13.67,5.26 13.17,5.62L13.7,9.35L16.47,6.29C16.18,5.94 16,5.5 16,5A2,2 0 0,1 18,3M5,20H19V22H5V20Z\";\r\nvar mdiChessRook = \"M5,20H19V22H5V20M17,2V5H15V2H13V5H11V2H9V5H7V2H5V8H7V18H17V8H19V2H17Z\";\r\nvar mdiChevronDoubleDown = \"M16.59,5.59L18,7L12,13L6,7L7.41,5.59L12,10.17L16.59,5.59M16.59,11.59L18,13L12,19L6,13L7.41,11.59L12,16.17L16.59,11.59Z\";\r\nvar mdiChevronDoubleLeft = \"M18.41,7.41L17,6L11,12L17,18L18.41,16.59L13.83,12L18.41,7.41M12.41,7.41L11,6L5,12L11,18L12.41,16.59L7.83,12L12.41,7.41Z\";\r\nvar mdiChevronDoubleRight = \"M5.59,7.41L7,6L13,12L7,18L5.59,16.59L10.17,12L5.59,7.41M11.59,7.41L13,6L19,12L13,18L11.59,16.59L16.17,12L11.59,7.41Z\";\r\nvar mdiChevronDoubleUp = \"M7.41,18.41L6,17L12,11L18,17L16.59,18.41L12,13.83L7.41,18.41M7.41,12.41L6,11L12,5L18,11L16.59,12.41L12,7.83L7.41,12.41Z\";\r\nvar mdiChevronDown = \"M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58Z\";\r\nvar mdiChevronDownBox = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M12,15.71L6,9.71L7.41,8.29L12,12.88L16.59,8.29L18,9.71L12,15.71Z\";\r\nvar mdiChevronDownBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M7.41,8.29L12,12.88L16.59,8.29L18,9.71L12,15.71L6,9.71L7.41,8.29Z\";\r\nvar mdiChevronDownCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M6,10L12,16L18,10L16.6,8.6L12,13.2L7.4,8.6L6,10Z\";\r\nvar mdiChevronDownCircleOutline = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M6,10L12,16L18,10L16.6,8.6L12,13.2L7.4,8.6L6,10Z\";\r\nvar mdiChevronLeft = \"M15.41,16.58L10.83,12L15.41,7.41L14,6L8,12L14,18L15.41,16.58Z\";\r\nvar mdiChevronLeftBox = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M15.71,16.59L14.29,18L8.29,12L14.29,6L15.71,7.41L11.12,12L15.71,16.59Z\";\r\nvar mdiChevronLeftBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M15.71,7.41L11.12,12L15.71,16.59L14.29,18L8.29,12L14.29,6L15.71,7.41Z\";\r\nvar mdiChevronLeftCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M15.4,16.6L10.8,12L15.4,7.4L14,6L8,12L14,18L15.4,16.6Z\";\r\nvar mdiChevronLeftCircleOutline = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M15.4,16.6L10.8,12L15.4,7.4L14,6L8,12L14,18L15.4,16.6Z\";\r\nvar mdiChevronRight = \"M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z\";\r\nvar mdiChevronRightBox = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M9.71,18L8.29,16.59L12.88,12L8.29,7.41L9.71,6L15.71,12L9.71,18Z\";\r\nvar mdiChevronRightBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M8.29,16.59L12.88,12L8.29,7.41L9.71,6L15.71,12L9.71,18L8.29,16.59Z\";\r\nvar mdiChevronRightCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M10,18L16,12L10,6L8.6,7.4L13.2,12L8.6,16.6L10,18Z\";\r\nvar mdiChevronRightCircleOutline = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M8.6,16.6L13.2,12L8.6,7.4L10,6L16,12L10,18L8.6,16.6Z\";\r\nvar mdiChevronTripleDown = \"M7.41,14.58L12,19.17L16.59,14.58L18,16L12,22L6,16L7.41,14.58M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58M7.41,2.58L12,7.17L16.59,2.58L18,4L12,10L6,4L7.41,2.58Z\";\r\nvar mdiChevronTripleLeft = \"M9.42,7.41L4.83,12L9.42,16.59L8,18L2,12L8,6L9.42,7.41M15.42,7.41L10.83,12L15.42,16.59L14,18L8,12L14,6L15.42,7.41M21.42,7.41L16.83,12L21.42,16.59L20,18L14,12L20,6L21.42,7.41Z\";\r\nvar mdiChevronTripleRight = \"M14.58,16.59L19.17,12L14.58,7.41L16,6L22,12L16,18L14.58,16.59M8.58,16.59L13.17,12L8.58,7.41L10,6L16,12L10,18L8.58,16.59M2.58,16.59L7.17,12L2.58,7.41L4,6L10,12L4,18L2.58,16.59Z\";\r\nvar mdiChevronTripleUp = \"M16.59,9.42L12,4.83L7.41,9.42L6,8L12,2L18,8L16.59,9.42M16.59,15.42L12,10.83L7.41,15.42L6,14L12,8L18,14L16.59,15.42M16.59,21.42L12,16.83L7.41,21.42L6,20L12,14L18,20L16.59,21.42Z\";\r\nvar mdiChevronUp = \"M7.41,15.41L12,10.83L16.59,15.41L18,14L12,8L6,14L7.41,15.41Z\";\r\nvar mdiChevronUpBox = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M16.59,15.71L12,11.12L7.41,15.71L6,14.29L12,8.29L18,14.29L16.59,15.71Z\";\r\nvar mdiChevronUpBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M16.59,15.71L12,11.12L7.41,15.71L6,14.29L12,8.29L18,14.29L16.59,15.71Z\";\r\nvar mdiChevronUpCircle = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M7.4,15.4L12,10.8L16.6,15.4L18,14L12,8L6,14L7.4,15.4Z\";\r\nvar mdiChevronUpCircleOutline = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M7.4,15.4L12,10.8L16.6,15.4L18,14L12,8L6,14L7.4,15.4Z\";\r\nvar mdiChiliHot = \"M17.75,9L18.95,8.24C19.58,8.58 20,9.24 20,10V21.75C20,21.75 12,20 12,11V10C12,9.27 12.39,8.63 12.97,8.28L14.43,9L16,8L17.75,9M14,2C15.53,2 16.8,3.15 17,4.64C18,4.93 18.81,5.67 19.22,6.63L17.75,7.5L16,6.5L14.43,7.5L12.76,6.67C13.15,5.72 13.95,5 14.94,4.66C14.8,4.28 14.43,4 14,4V2M10,10C10,18 13.63,19.84 16,21.75C16,21.75 8,20 8,11V10C8,9.27 8.39,8.63 8.97,8.28L10.3,8.94C10.11,9.25 10,9.61 10,10M10.43,7.5L8.76,6.67C9.15,5.72 9.95,5 10.94,4.66C10.8,4.28 10.43,4 10,4V2C10.77,2 11.47,2.29 12,2.76V4C12.43,4 12.8,4.28 12.94,4.66C11.95,5 11.15,5.72 10.43,7.5M6,10C6,18 9.63,19.84 12,21.75C12,21.75 4,20 4,11V10C4,9.27 4.39,8.63 4.97,8.28L6.3,8.94C6.11,9.25 6,9.61 6,10M6.43,7.5L4.76,6.67C5.15,5.72 5.95,5 6.94,4.66C6.8,4.28 6.43,4 6,4V2C6.77,2 7.47,2.29 8,2.76V4C8.43,4 8.8,4.28 8.94,4.66C7.95,5 7.15,5.72 6.43,7.5Z\";\r\nvar mdiChiliMedium = \"M15.75,9L16.95,8.24C17.58,8.58 18,9.24 18,10V21.75C18,21.75 10,20 10,11V10C10,9.27 10.39,8.63 10.97,8.28L12.43,9L14,8L15.75,9M12,2C13.53,2 14.8,3.15 15,4.64C16,4.93 16.81,5.67 17.22,6.63L15.75,7.5L14,6.5L12.43,7.5L10.76,6.67C11.15,5.72 11.95,5 12.94,4.66C12.8,4.28 12.43,4 12,4V2M8,10C8,18 11.63,19.84 14,21.75C14,21.75 6,20 6,11V10C6,9.27 6.39,8.63 6.97,8.28L8.3,8.94C8.11,9.25 8,9.61 8,10M8.43,7.5L6.76,6.67C7.15,5.72 7.95,5 8.94,4.66C8.8,4.28 8.43,4 8,4V2C8.77,2 9.47,2.29 10,2.76V4C10.43,4 10.8,4.28 10.94,4.66C9.95,5 9.15,5.72 8.43,7.5Z\";\r\nvar mdiChiliMild = \"M13.75,9L14.95,8.24C15.58,8.58 16,9.24 16,10V21.75C16,21.75 8,20 8,11V10C8,9.27 8.39,8.63 8.97,8.28L10.43,9L12,8L13.75,9M10,2C11.53,2 12.8,3.15 13,4.64C14,4.93 14.81,5.67 15.22,6.63L13.75,7.5L12,6.5L10.43,7.5L8.76,6.67C9.15,5.72 9.95,5 10.94,4.66C10.8,4.28 10.43,4 10,4V2Z\";\r\nvar mdiChiliOff = \"M20.8 22.7L16 17.9V21.8C16 21.8 8 20 8 11V10 9.9L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M13.8 9L12 8L11.5 8.3L16 12.8V10C16 9.2 15.6 8.6 15 8.2L13.8 9M12 6.5L13.8 7.5L15.3 6.6C14.9 5.6 14.1 4.9 13.1 4.6C12.8 3.2 11.5 2 10 2V4C10.4 4 10.8 4.3 10.9 4.7C10.2 4.9 9.6 5.4 9.2 6L10.6 7.4L12 6.5Z\";\r\nvar mdiChip = \"M6,4H18V5H21V7H18V9H21V11H18V13H21V15H18V17H21V19H18V20H6V19H3V17H6V15H3V13H6V11H3V9H6V7H3V5H6V4M11,15V18H12V15H11M13,15V18H14V15H13M15,15V18H16V15H15Z\";\r\nvar mdiChristianity = \"M10.5,2H13.5V8H19V11H13.5V22H10.5V11H5V8H10.5V2Z\";\r\nvar mdiChristianityOutline = \"M15.5,6V1H8.5V6H3V13H8.5V23H15.5V13H21V6H15.5M19,11H13.5V21H10.5V11H5V8H10.5V3H13.5V8H19V11Z\";\r\nvar mdiChurch = \"M11,2H13V4H15V6H13V9.4L22,13V15L20,14.2V22H14V17A2,2 0 0,0 12,15A2,2 0 0,0 10,17V22H4V14.2L2,15V13L11,9.4V6H9V4H11V2M6,20H8V15L7,14L6,15V20M16,20H18V15L17,14L16,15V20Z\";\r\nvar mdiCigar = \"M16 10.2H14.5A2 2 0 0 1 12.65 8.2A1.78 1.78 0 0 1 14.5 6.45V5A3.35 3.35 0 1 0 14.5 11.7H16A1.93 1.93 0 0 1 18 13.7V15H19.5V13.36A3.31 3.31 0 0 0 16 10.2M18.82 7.73A3.34 3.34 0 0 0 16.5 2V3.5A1.85 1.85 0 1 1 16.5 7.2V8.7A4 4 0 0 1 20.5 12.77V15H22V12.76A5.55 5.55 0 0 0 18.85 7.73M18 16V22H19.5V16M20.5 16V22H22V16M12 16V17.27A2 2 0 0 1 12 20.73V22H17V16M2.88 16.88A3 3 0 0 0 5 22H10V20.73A2 2 0 0 1 10 17.27V16H5A3 3 0 0 0 2.88 16.88M12 19A1 1 0 1 1 11 18A1 1 0 0 1 12 19Z\";\r\nvar mdiCigarOff = \"M20.84 22.73L18.11 20H18V19.89L17 18.89V20H12V18.73C12.3 18.56 12.55 18.31 12.73 18C13.28 17.05 12.96 15.83 12 15.27V14H12.11L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M14.5 9.7H16C17.07 9.66 17.96 10.5 18 11.56C18 11.61 18 11.65 18 11.7V13H19.5V11.36C19.42 9.53 17.88 8.12 16.05 8.2L16 8.2H14.5C13.45 8.12 12.65 7.25 12.65 6.2C12.67 5.22 13.5 4.43 14.46 4.45L14.5 4.45V3C12.65 3 11.15 4.5 11.15 6.35S12.65 9.7 14.5 9.7M20.5 10.7L20.5 10.77V13H22V10.76C22 8.62 20.78 6.66 18.85 5.73H18.82C19.58 5 19.9 4 19.8 3H18.32C18.34 3.11 18.35 3.23 18.35 3.35C18.35 4.37 17.5 5.2 16.5 5.2H16.5V6.7C18.71 6.7 20.5 8.5 20.5 10.7M9.27 16C9.45 15.7 9.7 15.45 10 15.27V14H5C4.21 14 3.44 14.32 2.88 14.88C1.71 16.05 1.71 17.95 2.88 19.12C3.45 19.68 4.21 20 5 20H10V18.73C9.05 18.18 8.72 16.95 9.27 16M18 14.8L19.5 16.3V14H18V14.8M20.5 17.3L22 18.8V14H20.5V17.3M11 16C10.45 16 10 16.45 10 17S10.45 18 11 18 12 17.55 12 17 11.55 16 11 16Z\";\r\nvar mdiCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCircleBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M12 16C9.79 16 8 14.21 8 12S9.79 8 12 8 16 9.79 16 12 14.21 16 12 16Z\";\r\nvar mdiCircleBoxOutline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M12 8C9.79 8 8 9.79 8 12S9.79 16 12 16 16 14.21 16 12 14.21 8 12 8Z\";\r\nvar mdiCircleDouble = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M12,6A6,6 0 0,0 6,12A6,6 0 0,0 12,18A6,6 0 0,0 18,12A6,6 0 0,0 12,6M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8Z\";\r\nvar mdiCircleEditOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12H20A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4V2M18.78,3C18.61,3 18.43,3.07 18.3,3.2L17.08,4.41L19.58,6.91L20.8,5.7C21.06,5.44 21.06,5 20.8,4.75L19.25,3.2C19.12,3.07 18.95,3 18.78,3M16.37,5.12L9,12.5V15H11.5L18.87,7.62L16.37,5.12Z\";\r\nvar mdiCircleExpand = \"M16,4L20,8V4M20,16L16,20H20M8,20L4,16V20M4,8L8,4H4M16.95,7.05C14.22,4.32 9.78,4.32 7.05,7.05C4.32,9.78 4.32,14.22 7.05,16.95C9.78,19.68 14.22,19.68 16.95,16.95C19.68,14.22 19.68,9.79 16.95,7.05M15.85,15.85C13.72,18 10.28,18 8.15,15.85C6,13.72 6,10.28 8.15,8.15C10.28,6 13.72,6 15.85,8.15C18,10.28 18,13.72 15.85,15.85Z\";\r\nvar mdiCircleHalf = \"M12 2A10 10 0 0 0 2 12A10 10 0 0 0 12 22V2Z\";\r\nvar mdiCircleHalfFull = \"M12 2A10 10 0 0 0 2 12A10 10 0 0 0 12 22A10 10 0 0 0 22 12A10 10 0 0 0 12 2M12 4A8 8 0 0 1 20 12A8 8 0 0 1 12 20V4Z\";\r\nvar mdiCircleMedium = \"M12,8A4,4 0 0,0 8,12A4,4 0 0,0 12,16A4,4 0 0,0 16,12A4,4 0 0,0 12,8Z\";\r\nvar mdiCircleMultiple = \"M15 4A8 8 0 1 1 7 12A8 8 0 0 1 15 4M3 12A6 6 0 0 0 7 17.65V19.74A8 8 0 0 1 7 4.26V6.35A6 6 0 0 0 3 12Z\";\r\nvar mdiCircleMultipleOutline = \"M15,4A8,8 0 0,1 23,12A8,8 0 0,1 15,20A8,8 0 0,1 7,12A8,8 0 0,1 15,4M15,18A6,6 0 0,0 21,12A6,6 0 0,0 15,6A6,6 0 0,0 9,12A6,6 0 0,0 15,18M3,12C3,14.61 4.67,16.83 7,17.65V19.74C3.55,18.85 1,15.73 1,12C1,8.27 3.55,5.15 7,4.26V6.35C4.67,7.17 3,9.39 3,12Z\";\r\nvar mdiCircleOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L4.06 5.95C2.78 7.63 2 9.72 2 12C2 17.5 6.5 22 12 22C14.28 22 16.37 21.23 18.05 19.94L20.84 22.73L22.11 21.46M12 20C7.58 20 4 16.42 4 12C4 10.27 4.56 8.68 5.5 7.38L16.62 18.5C15.32 19.45 13.73 20 12 20M8.17 4.97L6.72 3.5C8.25 2.56 10.06 2 12 2C17.5 2 22 6.5 22 12C22 13.94 21.44 15.75 20.5 17.28L19.03 15.83C19.65 14.69 20 13.39 20 12C20 7.58 16.42 4 12 4C10.61 4 9.31 4.35 8.17 4.97Z\";\r\nvar mdiCircleOutline = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCircleSlice1 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C13.93 5 15.68 5.78 16.95 7.05L12 12V5Z\";\r\nvar mdiCircleSlice2 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12H12V5Z\";\r\nvar mdiCircleSlice3 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12C19 13.93 18.22 15.68 16.95 16.95L12 12V5Z\";\r\nvar mdiCircleSlice4 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12C19 15.87 15.87 19 12 19V5Z\";\r\nvar mdiCircleSlice5 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12C19 15.87 15.87 19 12 19C10.07 19 8.32 18.22 7.05 16.95L12 12V5Z\";\r\nvar mdiCircleSlice6 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12C19 15.87 15.87 19 12 19C8.13 19 5 15.87 5 12H12V5Z\";\r\nvar mdiCircleSlice7 = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M12 5C15.87 5 19 8.13 19 12C19 15.87 15.87 19 12 19C8.13 19 5 15.87 5 12C5 10.07 5.78 8.32 7.05 7.05L12 12V5Z\";\r\nvar mdiCircleSlice8 = \"M12 5C15.87 5 19 8.13 19 12C19 15.87 15.87 19 12 19C8.13 19 5 15.87 5 12C5 8.13 8.13 5 12 5M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4Z\";\r\nvar mdiCircleSmall = \"M12,10A2,2 0 0,0 10,12C10,13.11 10.9,14 12,14C13.11,14 14,13.11 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiCircularSaw = \"M13,11A1,1 0 0,1 14,12A1,1 0 0,1 13,13A1,1 0 0,1 12,12A1,1 0 0,1 13,11M7.86,6.25C9.14,4.87 10.97,4 13,4C16.5,4 19.44,6.61 19.93,10H22V12H16A3,3 0 0,0 13,9A3,3 0 0,0 10,12H2V10H2.05C2.25,7.73 3.14,5.66 4.5,4L7.86,6.25M6.73,7.89L5.06,6.77C4.53,7.75 4.18,8.84 4.06,10H6.07C6.18,9.25 6.4,8.54 6.73,7.89M7.4,15.4L6,14H11.79C12.03,14.42 12.5,14.7 13,14.7C13.5,14.7 13.97,14.42 14.21,14H20V15.4C18.39,14.42 18.46,15.75 18.46,15.75V17.71L16.5,19.67C16,17.92 15.1,18.9 15.1,18.9L13.7,20.3H10.9C11.88,18.69 10.55,18.76 10.55,18.76H8.59L6.63,16.8C8.38,16.31 7.4,15.4 7.4,15.4Z\";\r\nvar mdiCity = \"M19,15H17V13H19M19,19H17V17H19M13,7H11V5H13M13,11H11V9H13M13,15H11V13H13M13,19H11V17H13M7,11H5V9H7M7,15H5V13H7M7,19H5V17H7M15,11V5L12,2L9,5V7H3V21H21V11H15Z\";\r\nvar mdiCityVariant = \"M19,9V7A2,2 0 0,0 17,5H16V2H14V5H13A2,2 0 0,0 11,7V9A2,2 0 0,0 9,11V12H5A2,2 0 0,0 3,14V22H6V20H8V22H12V20H14V22H16V20H18V22H21V11A2,2 0 0,0 19,9M8,18H6V16H8V18M14,18H12V16H14V18M14,14H12V12H14V14M13,9V7H17V9H13M18,18H16V16H18V18M18,14H16V12H18V14Z\";\r\nvar mdiCityVariantOutline = \"M15,23H13V21H15V23M19,21H17V23H19V21M15,17H13V19H15V17M7,21H5V23H7V21M7,17H5V19H7V17M19,17H17V19H19V17M15,13H13V15H15V13M19,13H17V15H19V13M21,9A2,2 0 0,1 23,11V23H21V11H11V23H9V15H3V23H1V15A2,2 0 0,1 3,13H9V11A2,2 0 0,1 11,9V7A2,2 0 0,1 13,5H15V1H17V5H19A2,2 0 0,1 21,7V9M19,9V7H13V9H19Z\";\r\nvar mdiClipboard = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3\";\r\nvar mdiClipboardAccount = \"M18,19H6V17.6C6,15.6 10,14.5 12,14.5C14,14.5 18,15.6 18,17.6M12,7A3,3 0 0,1 15,10A3,3 0 0,1 12,13A3,3 0 0,1 9,10A3,3 0 0,1 12,7M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardAccountOutline = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7M12,9A2,2 0 0,1 14,11A2,2 0 0,1 12,13A2,2 0 0,1 10,11A2,2 0 0,1 12,9M8,17V16C8,14.9 9.79,14 12,14C14.21,14 16,14.9 16,16V17H8Z\";\r\nvar mdiClipboardAlert = \"M12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5M13,14H11V8H13M13,18H11V16H13M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardAlertOutline = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7M11,9H13V13.5H11V9M11,15H13V17H11V15Z\";\r\nvar mdiClipboardArrowDown = \"M12,18L7,13H10V9H14V13H17M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardArrowDownOutline = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7M12,18L7,13H10V9H14V13H17L12,18Z\";\r\nvar mdiClipboardArrowLeft = \"M16,15H12V18L7,13L12,8V11H16M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardArrowLeftOutline = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7M7,13L12,18V15H16V11H12V8L7,13Z\";\r\nvar mdiClipboardArrowRight = \"M17,13L12,18V15H8V11H12V8M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardArrowRightOutline = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7M16.91,13L11.91,18V15H7.91V11H11.91V8L16.91,13Z\";\r\nvar mdiClipboardArrowUp = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,8L7,13H10V17H14V13H17L12,8M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3Z\";\r\nvar mdiClipboardArrowUpOutline = \"M12,8L17,13H14V17H10V13H7L12,8M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.6,1.84 10.7,1 12,1C13.3,1 14.4,1.84 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M7,7V5H5V19H19V5H17V7H7Z\";\r\nvar mdiClipboardCheck = \"M10,17L6,13L7.41,11.59L10,14.17L16.59,7.58L18,9M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardCheckMultiple = \"M4 7H2V21C2 22.1 2.9 23 4 23H18V21H4M20 3H16.8C16.4 1.8 15.3 1 14 1C12.7 1 11.6 1.8 11.2 3H8C6.9 3 6 3.9 6 5V17C6 18.1 6.9 19 8 19H20C21.1 19 22 18.1 22 17V5C22 3.9 21.1 3 20 3M14 3C14.6 3 15 3.5 15 4C15 4.5 14.5 5 14 5C13.5 5 13 4.5 13 4C13 3.5 13.4 3 14 3M12.3 15.1L9 11.8L10.4 10.4L12.3 12.3L17.6 7L19 8.4\";\r\nvar mdiClipboardCheckMultipleOutline = \"M4 7V21H18V23H4C2.9 23 2 22.1 2 21V7H4M12.8 15.35L9.5 12.05L10.9 10.65L12.8 12.55L17.1 8.25L18.5 9.65L12.8 15.35M20 3C21.1 3 22 3.9 22 5V17C22 18.1 21.1 19 20 19H8C6.9 19 6 18.1 6 17V5C6 3.9 6.9 3 8 3H11.18C11.6 1.84 12.7 1 14 1C15.3 1 16.4 1.84 16.82 3H20M14 3C13.45 3 13 3.45 13 4C13 4.55 13.45 5 14 5C14.55 5 15 4.55 15 4C15 3.45 14.55 3 14 3M10 7V5H8V17H20V5H18V7H10Z\";\r\nvar mdiClipboardCheckOutline = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M7,7H17V5H19V19H5V5H7V7M7.5,13.5L9,12L11,14L15.5,9.5L17,11L11,17L7.5,13.5Z\";\r\nvar mdiClipboardEdit = \"M21.04 12.13C21.18 12.13 21.31 12.19 21.42 12.3L22.7 13.58C22.92 13.79 22.92 14.14 22.7 14.35L21.7 15.35L19.65 13.3L20.65 12.3C20.76 12.19 20.9 12.13 21.04 12.13M19.07 13.88L21.12 15.93L15.06 22H13V19.94L19.07 13.88M19 3C20.1 3 21 3.9 21 5V9L11 19V21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H9.18C9.6 1.84 10.7 1 12 1C13.3 1 14.4 1.84 14.82 3H19M12 3C11.45 3 11 3.45 11 4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4C13 3.45 12.55 3 12 3Z\";\r\nvar mdiClipboardEditOutline = \"M21.04 12.13C21.18 12.13 21.31 12.19 21.42 12.3L22.7 13.58C22.92 13.79 22.92 14.14 22.7 14.35L21.7 15.35L19.65 13.3L20.65 12.3C20.76 12.19 20.9 12.13 21.04 12.13M19.07 13.88L21.12 15.93L15.06 22H13V19.94L19.07 13.88M11 19L9 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H9.18C9.6 1.84 10.7 1 12 1C13.3 1 14.4 1.84 14.82 3H19C20.1 3 21 3.9 21 5V9L19 11V5H17V7H7V5H5V19H11M12 3C11.45 3 11 3.45 11 4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4C13 3.45 12.55 3 12 3Z\";\r\nvar mdiClipboardFile = \"M19 3C20.1 3 21 3.9 21 5V9.17L19.83 8H15C12.79 8 11 9.79 11 12V21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H9.18C9.6 1.84 10.7 1 12 1C13.3 1 14.4 1.84 14.82 3H19M12 3C11.45 3 11 3.45 11 4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4C13 3.45 12.55 3 12 3M15 23C13.9 23 13 22.11 13 21V12C13 10.9 13.9 10 15 10H19L23 14V21C23 22.11 22.11 23 21 23H15M21 14.83L18.17 12H18V15H21V14.83Z\";\r\nvar mdiClipboardFileOutline = \"M15 23C13.9 23 13 22.11 13 21V12C13 10.9 13.9 10 15 10H19L23 14V21C23 22.11 22.11 23 21 23H15M15 21H21V14.83L18.17 12H15V21M19 3C20.1 3 21 3.9 21 5V9.17L19.83 8H19V5H17V7H7V5H5V19H11V21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H9.18C9.6 1.84 10.7 1 12 1C13.3 1 14.4 1.84 14.82 3H19M12 3C11.45 3 11 3.45 11 4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4C13 3.45 12.55 3 12 3Z\";\r\nvar mdiClipboardFlow = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M15,19L11,15H14V8H16V15H19L15,19M10,16H8V9H5L9,5L13,9H10V16\";\r\nvar mdiClipboardFlowOutline = \"M19 3H14.82C14.4 1.84 13.3 1 12 1S9.6 1.84 9.18 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M12 3C12.55 3 13 3.45 13 4S12.55 5 12 5 11 4.55 11 4 11.45 3 12 3M7 7H17V5H19V19H5V5H7V7M10 16H8V11H6L9 8L12 11H10V16M14 10H16V15H18L15 18L12 15H14V10Z\";\r\nvar mdiClipboardList = \"M19 3H14.82C14.4 1.84 13.3 1 12 1S9.6 1.84 9.18 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M7 8H9V12H8V9H7V8M10 17V18H7V17.08L9 15H7V14H9.25C9.66 14 10 14.34 10 14.75C10 14.95 9.92 15.14 9.79 15.27L8.12 17H10M11 4C11 3.45 11.45 3 12 3S13 3.45 13 4 12.55 5 12 5 11 4.55 11 4M17 17H12V15H17V17M17 11H12V9H17V11Z\";\r\nvar mdiClipboardListOutline = \"M19 3H14.82C14.4 1.84 13.3 1 12 1S9.6 1.84 9.18 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M12 3C12.55 3 13 3.45 13 4S12.55 5 12 5 11 4.55 11 4 11.45 3 12 3M7 7H17V5H19V19H5V5H7V7M12 17V15H17V17H12M12 11V9H17V11H12M8 12V9H7V8H9V12H8M9.25 14C9.66 14 10 14.34 10 14.75C10 14.95 9.92 15.14 9.79 15.27L8.12 17H10V18H7V17.08L9 15H7V14H9.25\";\r\nvar mdiClipboardMultiple = \"M4 7H2V21C2 22.1 2.9 23 4 23H18V21H4M20 3H16.8C16.4 1.8 15.3 1 14 1C12.7 1 11.6 1.8 11.2 3H8C6.9 3 6 3.9 6 5V17C6 18.1 6.9 19 8 19H20C21.1 19 22 18.1 22 17V5C22 3.9 21.1 3 20 3M14 3C14.6 3 15 3.5 15 4C15 4.5 14.5 5 14 5C13.5 5 13 4.5 13 4C13 3.5 13.4 3 14 3Z\";\r\nvar mdiClipboardMultipleOutline = \"M4 7V21H18V23H4C2.9 23 2 22.1 2 21V7H4M20 3C21.1 3 22 3.9 22 5V17C22 18.1 21.1 19 20 19H8C6.9 19 6 18.1 6 17V5C6 3.9 6.9 3 8 3H11.18C11.6 1.84 12.7 1 14 1C15.3 1 16.4 1.84 16.82 3H20M14 3C13.45 3 13 3.45 13 4C13 4.55 13.45 5 14 5C14.55 5 15 4.55 15 4C15 3.45 14.55 3 14 3M10 7V5H8V17H20V5H18V7H10Z\";\r\nvar mdiClipboardOutline = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M7,7H17V5H19V19H5V5H7V7Z\";\r\nvar mdiClipboardPlay = \"M19,3H14.82C14.25,1.44 12.53,0.64 11,1.2C10.14,1.5 9.5,2.16 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M10,17V9L15,13L10,17Z\";\r\nvar mdiClipboardPlayMultiple = \"M4 21H18V23H4C2.9 23 2 22.1 2 21V7H4M22 5V17C22 18.1 21.1 19 20 19H8C6.9 19 6 18.1 6 17V5C6 3.9 6.9 3 8 3H11.2C11.6 1.8 12.7 1 14 1C15.3 1 16.4 1.8 16.8 3H20C21.1 3 22 3.9 22 5M13 4C13 4.5 13.5 5 14 5C14.5 5 15 4.5 15 4C15 3.5 14.6 3 14 3C13.4 3 13 3.5 13 4M17 12L12 8V16\";\r\nvar mdiClipboardPlayMultipleOutline = \"M4 7V21H18V23H4C2.9 23 2 22.1 2 21V7H4M20 3C21.1 3 22 3.9 22 5V17C22 18.1 21.1 19 20 19H8C6.9 19 6 18.1 6 17V5C6 3.9 6.9 3 8 3H11.2C11.6 1.8 12.7 1 14 1C15.3 1 16.4 1.8 16.8 3H20M14 3C13.4 3 13 3.5 13 4C13 4.5 13.4 5 14 5C14.6 5 15 4.6 15 4C15 3.4 14.6 3 14 3M10 7V5H8V17H20V5H18V7M12 15V9L17 12\";\r\nvar mdiClipboardPlayOutline = \"M19,3H14.82C14.25,1.44 12.53,0.64 11,1.2C10.14,1.5 9.5,2.16 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M7,7H17V5H19V19H5V5H7V7M10,17V9L15,13L10,17Z\";\r\nvar mdiClipboardPlus = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M13,12H16V14H13V17H11V14H8V12H11V9H13V12Z\";\r\nvar mdiClipboardPlusOutline = \"M19 3H14.82C14.4 1.84 13.3 1 12 1S9.6 1.84 9.18 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M12 3C12.55 3 13 3.45 13 4S12.55 5 12 5 11 4.55 11 4 11.45 3 12 3M7 7H17V5H19V19H5V5H7V7M13 12H16V14H13V17H11V14H8V12H11V9H13V12Z\";\r\nvar mdiClipboardPulse = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M5,13.46H7.17L10.5,7.08L11.44,14.05L13.93,10.86L16.53,13.46H19V15H15.89L14.07,13.21L10.38,17.92L9.62,12.15L8.11,15H5V13.46Z\";\r\nvar mdiClipboardPulseOutline = \"M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M5,15H8.11L9.62,12.15L10.38,17.92L14.07,13.21L15.89,15H19V19H5V15M19,13.46H16.53L13.93,10.86L11.44,14.05L10.5,7.08L7.17,13.46H5V5H7V6H17V5H19V6L19,13.46Z\";\r\nvar mdiClipboardText = \"M17,9H7V7H17M17,13H7V11H17M14,17H7V15H14M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M19,3H14.82C14.4,1.84 13.3,1 12,1C10.7,1 9.6,1.84 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiClipboardTextMultiple = \"M20 3H16.8C16.4 1.8 15.3 1 14 1C12.7 1 11.6 1.8 11.2 3H8C6.9 3 6 3.9 6 5V17C6 18.1 6.9 19 8 19H20C21.1 19 22 18.1 22 17V5C22 3.9 21.1 3 20 3M14 3C14.6 3 15 3.5 15 4C15 4.5 14.5 5 14 5C13.5 5 13 4.5 13 4C13 3.5 13.4 3 14 3M16 14H9V12H16M19 10H9V8H19M4 21H18V23H4C2.9 23 2 22.1 2 21V7H4\";\r\nvar mdiClipboardTextMultipleOutline = \"M4 7V21H18V23H4C2.9 23 2 22.1 2 21V7H4M20 3C21.1 3 22 3.9 22 5V17C22 18.1 21.1 19 20 19H8C6.9 19 6 18.1 6 17V5C6 3.9 6.9 3 8 3H11.18C11.6 1.84 12.7 1 14 1C15.3 1 16.4 1.84 16.82 3H20M14 3C13.45 3 13 3.45 13 4C13 4.55 13.45 5 14 5C14.55 5 15 4.55 15 4C15 3.45 14.55 3 14 3M10 7V5H8V17H20V5H18V7M15 15H10V13H15M18 11H10V9H18V11Z\";\r\nvar mdiClipboardTextOutline = \"M19,3H14.82C14.25,1.44 12.53,0.64 11,1.2C10.14,1.5 9.5,2.16 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M7,7H17V5H19V19H5V5H7V7M17,11H7V9H17V11M15,15H7V13H15V15Z\";\r\nvar mdiClipboardTextPlay = \"M19,3A2,2 0 0,1 21,5V13.34C20.36,13.11 19.68,13 19,13C15.68,13 13,15.69 13,19C13,19.68 13.11,20.36 13.34,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H9.18C9.5,2.16 10.14,1.5 11,1.2C12.53,0.64 14.25,1.44 14.82,3H19M12,3A1,1 0 0,0 11,4A1,1 0 0,0 12,5A1,1 0 0,0 13,4A1,1 0 0,0 12,3M11,17V15H7V17H11M13,13V11H7V13H13M17,9V7H7V9H17M17,16L22,19L17,22V16Z\";\r\nvar mdiClipboardTextPlayOutline = \"M19,3H14.82C14.25,1.44 12.53,0.64 11,1.2C10.14,1.5 9.5,2.16 9.18,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H15V19H5V5H7V7H17V5H19V14H21V5A2,2 0 0,0 19,3M12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5M17,16V22L22,19L17,16M17,11H7V9H17V11M15,15H7V13H15V15Z\";\r\nvar mdiClippy = \"M15,15.5A2.5,2.5 0 0,1 12.5,18A2.5,2.5 0 0,1 10,15.5V13.75A0.75,0.75 0 0,1 10.75,13A0.75,0.75 0 0,1 11.5,13.75V15.5A1,1 0 0,0 12.5,16.5A1,1 0 0,0 13.5,15.5V11.89C12.63,11.61 12,10.87 12,10C12,8.9 13,8 14.25,8C15.5,8 16.5,8.9 16.5,10C16.5,10.87 15.87,11.61 15,11.89V15.5M8.25,8C9.5,8 10.5,8.9 10.5,10C10.5,10.87 9.87,11.61 9,11.89V17.25A3.25,3.25 0 0,0 12.25,20.5A3.25,3.25 0 0,0 15.5,17.25V13.75A0.75,0.75 0 0,1 16.25,13A0.75,0.75 0 0,1 17,13.75V17.25A4.75,4.75 0 0,1 12.25,22A4.75,4.75 0 0,1 7.5,17.25V11.89C6.63,11.61 6,10.87 6,10C6,8.9 7,8 8.25,8M10.06,6.13L9.63,7.59C9.22,7.37 8.75,7.25 8.25,7.25C7.34,7.25 6.53,7.65 6.03,8.27L4.83,7.37C5.46,6.57 6.41,6 7.5,5.81V5.75A3.75,3.75 0 0,1 11.25,2A3.75,3.75 0 0,1 15,5.75V5.81C16.09,6 17.04,6.57 17.67,7.37L16.47,8.27C15.97,7.65 15.16,7.25 14.25,7.25C13.75,7.25 13.28,7.37 12.87,7.59L12.44,6.13C12.77,6 13.13,5.87 13.5,5.81V5.75C13.5,4.5 12.5,3.5 11.25,3.5C10,3.5 9,4.5 9,5.75V5.81C9.37,5.87 9.73,6 10.06,6.13M14.25,9.25C13.7,9.25 13.25,9.59 13.25,10C13.25,10.41 13.7,10.75 14.25,10.75C14.8,10.75 15.25,10.41 15.25,10C15.25,9.59 14.8,9.25 14.25,9.25M8.25,9.25C7.7,9.25 7.25,9.59 7.25,10C7.25,10.41 7.7,10.75 8.25,10.75C8.8,10.75 9.25,10.41 9.25,10C9.25,9.59 8.8,9.25 8.25,9.25Z\";\r\nvar mdiClock = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M16.2,16.2L11,13V7H12.5V12.2L17,14.9L16.2,16.2Z\";\r\nvar mdiClockAlert = \"M20 12H22V18H20V12M20 20H22V22H20V20M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22C14.3 22 16.3 21.2 18 20V10H21.8C20.9 5.4 16.8 2 12 2M16.2 16.2L11 13V7H12.5V12.2L17 14.9L16.2 16.2Z\";\r\nvar mdiClockAlertOutline = \"M11 7V13L16.2 16.1L17 14.9L12.5 12.2V7H11M20 12V18H22V12H20M20 20V22H22V20H20M18 20C16.3 21.3 14.3 22 12 22C6.5 22 2 17.5 2 12S6.5 2 12 2C16.8 2 20.9 5.4 21.8 10H19.7C18.8 6.6 15.7 4 12 4C7.6 4 4 7.6 4 12S7.6 20 12 20C14.4 20 16.5 18.9 18 17.3V20Z\";\r\nvar mdiClockCheck = \"M23.5 17L18.5 22L15 18.5L16.5 17L18.5 19L22 15.5L23.5 17M13 19C13 17.5 13.5 16.2 14.4 15.1L11 13V7H12.5V12.2L15.6 14.1C16.6 13.4 17.7 13 19 13C20 13 21 13.3 21.8 13.7C21.9 13.1 22 12.6 22 12C22 6.5 17.5 2 12 2S2 6.5 2 12 6.5 22 12 22C12.6 22 13.2 21.9 13.7 21.8C13.3 21 13 20 13 19Z\";\r\nvar mdiClockCheckOutline = \"M23.5 17L18.5 22L15 18.5L16.5 17L18.5 19L22 15.5L23.5 17M13.1 19.9C12.7 20 12.4 20 12 20C7.6 20 4 16.4 4 12S7.6 4 12 4 20 7.6 20 12C20 12.4 20 12.7 19.9 13.1C20.6 13.2 21.2 13.4 21.8 13.7C21.9 13.1 22 12.6 22 12C22 6.5 17.5 2 12 2S2 6.5 2 12C2 17.5 6.5 22 12 22C12.6 22 13.2 21.9 13.7 21.8C13.4 21.3 13.2 20.6 13.1 19.9M15.6 14.1L12.5 12.3V7H11V13L14.5 15.1C14.8 14.7 15.2 14.4 15.6 14.1Z\";\r\nvar mdiClockDigital = \"M2,6A2,2 0 0,0 0,8V16A2,2 0 0,0 2,18H22A2,2 0 0,0 24,16V8A2,2 0 0,0 22,6M2,8H22V16H2M3,9V10.5H6.25L3,15H4.75L8,10.5V9M9.25,9V10.5H10.75V9M12,9V10.5H13.5V15H15V9M17,9A1,1 0 0,0 16,10V14A1,1 0 0,0 17,15H20A1,1 0 0,0 21,14V10A1,1 0 0,0 20,9M17.5,10.5H19.5V13.5H17.5M9.25,13.5V15H10.75V13.5\";\r\nvar mdiClockEnd = \"M12,1C8.14,1 5,4.14 5,8A7,7 0 0,0 12,15C15.86,15 19,11.87 19,8C19,4.14 15.86,1 12,1M12,3.15C14.67,3.15 16.85,5.32 16.85,8C16.85,10.68 14.67,12.85 12,12.85A4.85,4.85 0 0,1 7.15,8A4.85,4.85 0 0,1 12,3.15M11,5V8.69L14.19,10.53L14.94,9.23L12.5,7.82V5M15,16V19H3V21H15V24L19,20M19,20V24H21V16H19\";\r\nvar mdiClockFast = \"M15,4A8,8 0 0,1 23,12A8,8 0 0,1 15,20A8,8 0 0,1 7,12A8,8 0 0,1 15,4M15,6A6,6 0 0,0 9,12A6,6 0 0,0 15,18A6,6 0 0,0 21,12A6,6 0 0,0 15,6M14,8H15.5V11.78L17.83,14.11L16.77,15.17L14,12.4V8M2,18A1,1 0 0,1 1,17A1,1 0 0,1 2,16H5.83C6.14,16.71 6.54,17.38 7,18H2M3,13A1,1 0 0,1 2,12A1,1 0 0,1 3,11H5.05L5,12L5.05,13H3M4,8A1,1 0 0,1 3,7A1,1 0 0,1 4,6H7C6.54,6.62 6.14,7.29 5.83,8H4Z\";\r\nvar mdiClockIn = \"M2.21,0.79L0.79,2.21L4.8,6.21L3,8H8V3L6.21,4.8M12,8C8.14,8 5,11.13 5,15A7,7 0 0,0 12,22C15.86,22 19,18.87 19,15A7,7 0 0,0 12,8M12,10.15C14.67,10.15 16.85,12.32 16.85,15A4.85,4.85 0 0,1 12,19.85C9.32,19.85 7.15,17.68 7.15,15A4.85,4.85 0 0,1 12,10.15M11,12V15.69L14.19,17.53L14.94,16.23L12.5,14.82V12\";\r\nvar mdiClockOut = \"M18,1L19.8,2.79L15.79,6.79L17.21,8.21L21.21,4.21L23,6V1M12,8C8.14,8 5,11.13 5,15A7,7 0 0,0 12,22C15.86,22 19,18.87 19,15A7,7 0 0,0 12,8M12,10.15C14.67,10.15 16.85,12.32 16.85,15A4.85,4.85 0 0,1 12,19.85C9.32,19.85 7.15,17.68 7.15,15A4.85,4.85 0 0,1 12,10.15M11,12V15.69L14.19,17.53L14.94,16.23L12.5,14.82V12\";\r\nvar mdiClockOutline = \"M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22C6.47,22 2,17.5 2,12A10,10 0 0,1 12,2M12.5,7V12.25L17,14.92L16.25,16.15L11,13V7H12.5Z\";\r\nvar mdiClockStart = \"M12,1C8.14,1 5,4.14 5,8A7,7 0 0,0 12,15C15.86,15 19,11.87 19,8C19,4.14 15.86,1 12,1M12,3.15C14.67,3.15 16.85,5.32 16.85,8C16.85,10.68 14.67,12.85 12,12.85A4.85,4.85 0 0,1 7.15,8A4.85,4.85 0 0,1 12,3.15M11,5V8.69L14.19,10.53L14.94,9.23L12.5,7.82V5M4,16V24H6V21H18V24L22,20L18,16V19H6V16\";\r\nvar mdiClockTimeEight = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M7.7 15.5L7 14.2L11 11.9V7H12.5V12.8L7.7 15.5Z\";\r\nvar mdiClockTimeEightOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 12.8L7.7 15.6L7 14.2L11 11.9V7H12.5V12.8Z\";\r\nvar mdiClockTimeEleven = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 13H11L8.5 8.6L9.8 7.8L11 10V7H12.5V13Z\";\r\nvar mdiClockTimeElevenOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 7V13H11L8.5 8.6L9.8 7.8L11 10V7H12.5Z\";\r\nvar mdiClockTimeFive = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M14 17L11 11.8V7H12.5V11.4L15.3 16.3L14 17Z\";\r\nvar mdiClockTimeFiveOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M15.3 16.2L14 17L11 11.8V7H12.5V11.4L15.3 16.2Z\";\r\nvar mdiClockTimeFour = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M16.3 15.2L11 12.3V7H12.5V11.4L17 13.9L16.3 15.2Z\";\r\nvar mdiClockTimeFourOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M17 13.9L16.3 15.2L11 12.3V7H12.5V11.4L17 13.9Z\";\r\nvar mdiClockTimeNine = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 13H7V11.5H11V7H12.5V13Z\";\r\nvar mdiClockTimeNineOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 7V13H7V11.5H11V7H12.5Z\";\r\nvar mdiClockTimeOne = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.3 13H11V7H12.5V9.7L14 7.1L15.3 7.9L12.3 13Z\";\r\nvar mdiClockTimeOneOutline = \"M12 20C16.42 20 20 16.42 20 12S16.42 4 12 4 4 7.58 4 12 7.58 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.47 22 2 17.5 2 12C2 6.5 6.5 2 12 2M15.3 7.8L12.3 13H11V7H12.5V9.65L14 7.05L15.3 7.8Z\";\r\nvar mdiClockTimeSeven = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 12.2L9.8 17L8.5 16.2L11 11.8V7H12.5V12.2Z\";\r\nvar mdiClockTimeSevenOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 7V12.2L9.8 17L8.5 16.2L11 11.8V7H12.5Z\";\r\nvar mdiClockTimeSix = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 17H11V7H12.5V17Z\";\r\nvar mdiClockTimeSixOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 7V17H11V7H12.5Z\";\r\nvar mdiClockTimeTen = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 13H11L7 10.7L7.8 9.4L11.1 11.3V7H12.6V13Z\";\r\nvar mdiClockTimeTenOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 13H11L7 10.7L7.8 9.4L11.1 11.3V7H12.6V13Z\";\r\nvar mdiClockTimeThree = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M17 13H11V7H12.5V11.5H17V13Z\";\r\nvar mdiClockTimeThreeOutline = \"M12 20C16.4 20 20 16.4 20 12S16.4 4 12 4 4 7.6 4 12 7.6 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M17 11.5V13H11V7H12.5V11.5H17Z\";\r\nvar mdiClockTimeTwelve = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 13H11V7H12.5V13Z\";\r\nvar mdiClockTimeTwelveOutline = \"M12 20C16.42 20 20 16.42 20 12S16.42 4 12 4 4 7.58 4 12 7.58 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.47 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 13.03H11V7H12.5V13.03Z\";\r\nvar mdiClockTimeTwo = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12.5 13H11V7H12.5V11.3L16.2 9.2L17 10.5L12.5 13Z\";\r\nvar mdiClockTimeTwoOutline = \"M12 20C16.42 20 20 16.42 20 12S16.42 4 12 4 4 7.58 4 12 7.58 20 12 20M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22C6.47 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12.5 13V13H11V7H12.5V11.26L16.2 9.13L16.95 10.43L12.5 13Z\";\r\nvar mdiClose = \"M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z\";\r\nvar mdiCloseBox = \"M19,3H16.3H7.7H5A2,2 0 0,0 3,5V7.7V16.4V19A2,2 0 0,0 5,21H7.7H16.4H19A2,2 0 0,0 21,19V16.3V7.7V5A2,2 0 0,0 19,3M15.6,17L12,13.4L8.4,17L7,15.6L10.6,12L7,8.4L8.4,7L12,10.6L15.6,7L17,8.4L13.4,12L17,15.6L15.6,17Z\";\r\nvar mdiCloseBoxMultiple = \"M4 20H18V22H4C2.9 22 2 21.11 2 20V6H4V20M20.22 2H7.78C6.8 2 6 2.8 6 3.78V16.22C6 17.2 6.8 18 7.78 18H20.22C21.2 18 22 17.2 22 16.22V3.78C22 2.8 21.2 2 20.22 2M19 13.6L17.6 15L14 11.4L10.4 15L9 13.6L12.6 10L9 6.4L10.4 5L14 8.6L17.6 5L19 6.4L15.4 10L19 13.6Z\";\r\nvar mdiCloseBoxMultipleOutline = \"M20 2H8C6.9 2 6 2.9 6 4V16C6 17.11 6.9 18 8 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H8V4H20V16M4 6V20H18V22H4C2.9 22 2 21.11 2 20V6H4M9.77 12.84L12.6 10L9.77 7.15L11.17 5.75L14 8.6L16.84 5.77L18.24 7.17L15.4 10L18.23 12.84L16.83 14.24L14 11.4L11.17 14.24L9.77 12.84Z\";\r\nvar mdiCloseBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M17,8.4L13.4,12L17,15.6L15.6,17L12,13.4L8.4,17L7,15.6L10.6,12L7,8.4L8.4,7L12,10.6L15.6,7L17,8.4Z\";\r\nvar mdiCloseCircle = \"M12,2C17.53,2 22,6.47 22,12C22,17.53 17.53,22 12,22C6.47,22 2,17.53 2,12C2,6.47 6.47,2 12,2M15.59,7L12,10.59L8.41,7L7,8.41L10.59,12L7,15.59L8.41,17L12,13.41L15.59,17L17,15.59L13.41,12L17,8.41L15.59,7Z\";\r\nvar mdiCloseCircleMultiple = \"M2 12C2 9.21 3.64 6.8 6 5.68V3.5C2.5 4.76 0 8.09 0 12S2.5 19.24 6 20.5V18.32C3.64 17.2 2 14.79 2 12M15 3C10.04 3 6 7.04 6 12S10.04 21 15 21 24 16.96 24 12 19.96 3 15 3M20 15.59L18.59 17L15 13.41L11.41 17L10 15.59L13.59 12L10 8.41L11.41 7L15 10.59L18.59 7L20 8.41L16.41 12L20 15.59Z\";\r\nvar mdiCloseCircleMultipleOutline = \"M18.54 9.88L17.12 8.47L15 10.59L12.88 8.47L11.47 9.88L13.59 12L11.47 14.12L12.88 15.54L15 13.41L17.12 15.54L18.54 14.12L16.41 12M2 12C2 9.21 3.64 6.8 6 5.68V3.5C2.5 4.76 0 8.09 0 12S2.5 19.24 6 20.5V18.32C3.64 17.2 2 14.79 2 12M15 3C10.04 3 6 7.04 6 12S10.04 21 15 21 24 16.96 24 12 19.96 3 15 3M15 19C11.14 19 8 15.86 8 12S11.14 5 15 5 22 8.14 22 12 18.86 19 15 19Z\";\r\nvar mdiCloseCircleOutline = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22C17.53,22 22,17.53 22,12C22,6.47 17.53,2 12,2M14.59,8L12,10.59L9.41,8L8,9.41L10.59,12L8,14.59L9.41,16L12,13.41L14.59,16L16,14.59L13.41,12L16,9.41L14.59,8Z\";\r\nvar mdiCloseNetwork = \"M14.59,6L12,8.59L9.41,6L8,7.41L10.59,10L8,12.59L9.41,14L12,11.41L14.59,14L16,12.59L13.41,10L16,7.41L14.59,6M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17Z\";\r\nvar mdiCloseNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M15.54,12.12L13.41,10L15.53,7.87L14.12,6.46L12,8.59L9.88,6.46L8.47,7.87L10.59,10L8.47,12.13L9.88,13.54L12,11.41L14.12,13.54L15.54,12.12Z\";\r\nvar mdiCloseOctagon = \"M8.27,3L3,8.27V15.73L8.27,21H15.73L21,15.73V8.27L15.73,3M8.41,7L12,10.59L15.59,7L17,8.41L13.41,12L17,15.59L15.59,17L12,13.41L8.41,17L7,15.59L10.59,12L7,8.41\";\r\nvar mdiCloseOctagonOutline = \"M8.27,3L3,8.27V15.73L8.27,21H15.73C17.5,19.24 21,15.73 21,15.73V8.27L15.73,3M9.1,5H14.9L19,9.1V14.9L14.9,19H9.1L5,14.9V9.1M9.12,7.71L7.71,9.12L10.59,12L7.71,14.88L9.12,16.29L12,13.41L14.88,16.29L16.29,14.88L13.41,12L16.29,9.12L14.88,7.71L12,10.59\";\r\nvar mdiCloseOutline = \"M3,16.74L7.76,12L3,7.26L7.26,3L12,7.76L16.74,3L21,7.26L16.24,12L21,16.74L16.74,21L12,16.24L7.26,21L3,16.74M12,13.41L16.74,18.16L18.16,16.74L13.41,12L18.16,7.26L16.74,5.84L12,10.59L7.26,5.84L5.84,7.26L10.59,12L5.84,16.74L7.26,18.16L12,13.41Z\";\r\nvar mdiCloseThick = \"M20 6.91L17.09 4L12 9.09L6.91 4L4 6.91L9.09 12L4 17.09L6.91 20L12 14.91L17.09 20L20 17.09L14.91 12L20 6.91Z\";\r\nvar mdiClosedCaption = \"M18,11H16.5V10.5H14.5V13.5H16.5V13H18V14A1,1 0 0,1 17,15H14A1,1 0 0,1 13,14V10A1,1 0 0,1 14,9H17A1,1 0 0,1 18,10M11,11H9.5V10.5H7.5V13.5H9.5V13H11V14A1,1 0 0,1 10,15H7A1,1 0 0,1 6,14V10A1,1 0 0,1 7,9H10A1,1 0 0,1 11,10M19,4H5C3.89,4 3,4.89 3,6V18A2,2 0 0,0 5,20H19A2,2 0 0,0 21,18V6C21,4.89 20.1,4 19,4Z\";\r\nvar mdiClosedCaptionOutline = \"M5,4C4.45,4 4,4.18 3.59,4.57C3.2,4.96 3,5.44 3,6V18C3,18.56 3.2,19.04 3.59,19.43C4,19.82 4.45,20 5,20H19C19.5,20 20,19.81 20.39,19.41C20.8,19 21,18.53 21,18V6C21,5.47 20.8,5 20.39,4.59C20,4.19 19.5,4 19,4H5M4.5,5.5H19.5V18.5H4.5V5.5M7,9C6.7,9 6.47,9.09 6.28,9.28C6.09,9.47 6,9.7 6,10V14C6,14.3 6.09,14.53 6.28,14.72C6.47,14.91 6.7,15 7,15H10C10.27,15 10.5,14.91 10.71,14.72C10.91,14.53 11,14.3 11,14V13H9.5V13.5H7.5V10.5H9.5V11H11V10C11,9.7 10.91,9.47 10.71,9.28C10.5,9.09 10.27,9 10,9H7M14,9C13.73,9 13.5,9.09 13.29,9.28C13.09,9.47 13,9.7 13,10V14C13,14.3 13.09,14.53 13.29,14.72C13.5,14.91 13.73,15 14,15H17C17.3,15 17.53,14.91 17.72,14.72C17.91,14.53 18,14.3 18,14V13H16.5V13.5H14.5V10.5H16.5V11H18V10C18,9.7 17.91,9.47 17.72,9.28C17.53,9.09 17.3,9 17,9H14Z\";\r\nvar mdiCloud = \"M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudAlert = \"M19 20H6C2.7 20 0 17.3 0 14C0 10.9 2.3 8.4 5.3 8C6.6 5.6 9.1 4 12 4C15.6 4 18.7 6.6 19.4 10C22 10.2 24 12.3 24 15C24 17.7 21.7 20 19 20M11 15V17H13V15H11M11 13H13V7H11V13Z\";\r\nvar mdiCloudBraces = \"M6,20A6,6 0 0,1 0,14C0,10.91 2.34,8.36 5.35,8.04C6.6,5.64 9.11,4 12,4C15.63,4 18.66,6.58 19.35,10C21.95,10.19 24,12.36 24,15A5,5 0 0,1 19,20H6M18.5,12H18A1,1 0 0,1 17,11V10A2,2 0 0,0 15,8H13.5V10H15V11A2,2 0 0,0 17,13A2,2 0 0,0 15,15V16H13.5V18H15A2,2 0 0,0 17,16V15A1,1 0 0,1 18,14H18.5V12M5.5,12V14H6A1,1 0 0,1 7,15V16A2,2 0 0,0 9,18H10.5V16H9V15A2,2 0 0,0 7,13A2,2 0 0,0 9,11V10H10.5V8H9A2,2 0 0,0 7,10V11A1,1 0 0,1 6,12H5.5Z\";\r\nvar mdiCloudCheck = \"M10,17L6.5,13.5L7.91,12.08L10,14.17L15.18,9L16.59,10.41M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudCheckOutline = \"M19 18H6C3.79 18 2 16.21 2 14S3.79 10 6 10H6.71C7.37 7.69 9.5 6 12 6C15.04 6 17.5 8.46 17.5 11.5V12H19C20.66 12 22 13.34 22 15S20.66 18 19 18M19.35 10.03C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.03C2.34 8.36 0 10.9 0 14C0 17.31 2.69 20 6 20H19C21.76 20 24 17.76 24 15C24 12.36 21.95 10.22 19.35 10.03M10 17L6.5 13.5L7.91 12.08L10 14.17L14.59 9.59L16 11\";\r\nvar mdiCloudCircle = \"M16.5,16H8A3,3 0 0,1 5,13A3,3 0 0,1 8,10C8.05,10 8.09,10 8.14,10C8.58,8.28 10.13,7 12,7A4,4 0 0,1 16,11H16.5A2.5,2.5 0 0,1 19,13.5A2.5,2.5 0 0,1 16.5,16M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCloudDownload = \"M17,13L12,18L7,13H10V9H14V13M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudDownloadOutline = \"M8,13H10.55V10H13.45V13H16L12,17L8,13M19.35,10.04C21.95,10.22 24,12.36 24,15A5,5 0 0,1 19,20H6A6,6 0 0,1 0,14C0,10.91 2.34,8.36 5.35,8.04C6.6,5.64 9.11,4 12,4C15.64,4 18.67,6.59 19.35,10.04M19,18A3,3 0 0,0 22,15C22,13.45 20.78,12.14 19.22,12.04L17.69,11.93L17.39,10.43C16.88,7.86 14.62,6 12,6C9.94,6 8.08,7.14 7.13,8.97L6.63,9.92L5.56,10.03C3.53,10.24 2,11.95 2,14A4,4 0 0,0 6,18H19Z\";\r\nvar mdiCloudLock = \"M22 17C22.5 17 23 17.5 23 18V22C23 22.5 22.5 23 22 23H17C16.5 23 16 22.5 16 22V18C16 17.5 16.5 17 17 17V15.5C17 14.1 18.1 13 19.5 13C20.9 13 22 14.1 22 15.5V17M21 17V15.5C21 14.7 20.3 14 19.5 14C18.7 14 18 14.7 18 15.5V17H21M19.36 9.03C21.95 9.22 24 11.36 24 14L23.94 14.77C23.59 12.63 21.74 11 19.5 11C17 11 15 13 15 15.5L15 15.76C14.39 16.31 14 17.11 14 18V19H6C2.69 19 0 16.31 0 13C0 9.9 2.34 7.36 5.35 7.04C6.6 4.64 9.11 3 12 3C15.64 3 18.67 5.59 19.36 9.03Z\";\r\nvar mdiCloudLockOutline = \"M22 17C22.5 17 23 17.5 23 18V22C23 22.5 22.5 23 22 23H17C16.5 23 16 22.5 16 22V18C16 17.5 16.5 17 17 17V15.5C17 14.1 18.1 13 19.5 13C20.9 13 22 14.1 22 15.5V17M21 17V15.5C21 14.7 20.3 14 19.5 14C18.7 14 18 14.7 18 15.5V17H21M17.5 11V10.5C17.5 7.46 15.04 5 12 5C9.5 5 7.37 6.69 6.71 9H6C3.79 9 2 10.79 2 13C2 15.21 3.79 17 6 17H14.17C14.06 17.31 14 17.65 14 18V19H6C2.69 19 0 16.31 0 13C0 9.9 2.34 7.36 5.35 7.04C6.6 4.64 9.11 3 12 3C15.64 3 18.67 5.6 19.36 9.04C21.95 9.22 24 11.36 24 14L23.94 14.77C23.59 12.63 21.74 11 19.5 11H17.5Z\";\r\nvar mdiCloudOffOutline = \"M7.73,10L15.73,18H6A4,4 0 0,1 2,14A4,4 0 0,1 6,10M3,5.27L5.75,8C2.56,8.15 0,10.77 0,14A6,6 0 0,0 6,20H17.73L19.73,22L21,20.73L4.27,4M19.35,10.03C18.67,6.59 15.64,4 12,4C10.5,4 9.15,4.43 8,5.17L9.45,6.63C10.21,6.23 11.08,6 12,6A5.5,5.5 0 0,1 17.5,11.5V12H19A3,3 0 0,1 22,15C22,16.13 21.36,17.11 20.44,17.62L21.89,19.07C23.16,18.16 24,16.68 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudOutline = \"M19,18H6A4,4 0 0,1 2,14A4,4 0 0,1 6,10H6.71C7.37,7.69 9.5,6 12,6A5.5,5.5 0 0,1 17.5,11.5V12H19A3,3 0 0,1 22,15A3,3 0 0,1 19,18M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudPrint = \"M12,2C9.11,2 6.6,3.64 5.35,6.04C2.34,6.36 0,8.91 0,12A6,6 0 0,0 6,18V22H18V18H19A5,5 0 0,0 24,13C24,10.36 21.95,8.22 19.35,8.04C18.67,4.59 15.64,2 12,2M8,13H16V20H8V13M9,14V15H15V14H9M9,16V17H15V16H9M9,18V19H15V18H9Z\";\r\nvar mdiCloudPrintOutline = \"M19,16A3,3 0 0,0 22,13A3,3 0 0,0 19,10H17.5V9.5A5.5,5.5 0 0,0 12,4C9.5,4 7.37,5.69 6.71,8H6A4,4 0 0,0 2,12A4,4 0 0,0 6,16V11H18V16H19M19.36,8.04C21.95,8.22 24,10.36 24,13A5,5 0 0,1 19,18H18V22H6V18A6,6 0 0,1 0,12C0,8.91 2.34,6.36 5.35,6.04C6.6,3.64 9.11,2 12,2C15.64,2 18.67,4.6 19.36,8.04M8,13V20H16V13H8M9,18H15V19H9V18M15,17H9V16H15V17M9,14H15V15H9V14Z\";\r\nvar mdiCloudQuestion = \"M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03M13,17H11V15H13V17M14.8,11.82C14.5,12.21 14.13,12.5 13.67,12.75C13.41,12.91 13.24,13.07 13.15,13.26C13.06,13.45 13,13.69 13,14H11C11,13.45 11.11,13.08 11.3,12.82C11.5,12.56 11.85,12.25 12.37,11.91C12.63,11.75 12.84,11.56 13,11.32C13.15,11.09 13.23,10.81 13.23,10.5C13.23,10.18 13.14,9.94 12.96,9.76C12.78,9.56 12.5,9.47 12.2,9.47C11.93,9.47 11.71,9.55 11.5,9.7C11.35,9.85 11.25,10.08 11.25,10.39H9.28C9.23,9.64 9.5,9 10.06,8.59C10.6,8.2 11.31,8 12.2,8C13.14,8 13.89,8.23 14.43,8.68C14.97,9.13 15.24,9.75 15.24,10.5C15.24,11 15.09,11.41 14.8,11.82Z\";\r\nvar mdiCloudRefresh = \"M12 4C15.64 4 18.67 6.59 19.35 10.04C21.95 10.22 24 12.36 24 15C24 17.76 21.76 20 19 20H6C2.69 20 0 17.31 0 14C0 10.91 2.34 8.36 5.35 8.04C6.6 5.64 9.11 4 12 4M17 13V9L16 10C15.09 8.79 13.64 8 12 8C9.24 8 7 10.24 7 13C7 15.76 9.24 18 12 18C14.05 18 15.81 16.77 16.58 15H14.24C13.69 15.61 12.89 16 12 16C10.34 16 9 14.66 9 13C9 11.34 10.34 10 12 10C13.09 10 14.04 10.58 14.56 11.44L13 13H17Z\";\r\nvar mdiCloudSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M19.35,8.03C21.95,8.22 24,10.36 24,13C24,14.64 23.21,16.1 22,17V16.5A6.5,6.5 0 0,0 15.5,10A6.5,6.5 0 0,0 9,16.5C9,17 9.06,17.5 9.17,18H6A6,6 0 0,1 0,12C0,8.9 2.34,6.36 5.35,6.03C6.6,3.64 9.11,2 12,2C15.64,2 18.67,4.59 19.35,8.03Z\";\r\nvar mdiCloudSearchOutline = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M22,13A3,3 0 0,0 19,10H17.5V9.5A5.5,5.5 0 0,0 12,4C9.5,4 7.37,5.69 6.71,8H6A4,4 0 0,0 2,12A4,4 0 0,0 6,16H9V16.5C9,17 9.06,17.5 9.17,18H6A6,6 0 0,1 0,12C0,8.9 2.34,6.36 5.35,6.04C6.6,3.64 9.11,2 12,2C15.64,2 18.67,4.59 19.36,8.04C21.95,8.22 24,10.36 24,13C24,14.65 23.21,16.1 22,17V16.5C22,15.77 21.88,15.06 21.65,14.4C21.87,14 22,13.5 22,13Z\";\r\nvar mdiCloudSync = \"M19 12V13.5C21.21 13.5 23 15.29 23 17.5C23 18.32 22.75 19.08 22.33 19.71L21.24 18.62C21.41 18.28 21.5 17.9 21.5 17.5C21.5 16.12 20.38 15 19 15V16.5L16.75 14.25L16.72 14.22C16.78 14.17 16.85 14.13 19 12M19 23V21.5C16.79 21.5 15 19.71 15 17.5C15 16.68 15.25 15.92 15.67 15.29L16.76 16.38C16.59 16.72 16.5 17.1 16.5 17.5C16.5 18.88 17.62 20 19 20V18.5L21.25 20.75L21.28 20.78C21.22 20.83 21.15 20.87 19 23M13 17.5C13 13.91 15.91 11 19.5 11C20.78 11 21.97 11.38 23 12C22.13 10.9 20.84 10.14 19.35 10.03C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.03C2.34 8.36 0 10.9 0 14C0 17.31 2.69 20 6 20H13.5C13.18 19.23 13 18.39 13 17.5Z\";\r\nvar mdiCloudSyncOutline = \"M19 12V13.5C21.21 13.5 23 15.29 23 17.5C23 18.32 22.75 19.08 22.33 19.71L21.24 18.62C21.41 18.28 21.5 17.9 21.5 17.5C21.5 16.12 20.38 15 19 15V16.5L16.75 14.25L16.72 14.22C16.78 14.17 16.85 14.13 19 12M19 23V21.5C16.79 21.5 15 19.71 15 17.5C15 16.68 15.25 15.92 15.67 15.29L16.76 16.38C16.59 16.72 16.5 17.1 16.5 17.5C16.5 18.88 17.62 20 19 20V18.5L21.25 20.75L21.28 20.78C21.22 20.83 21.15 20.87 19 23M13.03 18H6C3.79 18 2 16.21 2 14S3.79 10 6 10H6.71C7.37 7.69 9.5 6 12 6C15 6 17.4 8.37 17.5 11.32C18.12 11.11 18.8 11 19.5 11C20.78 11 21.97 11.38 23 12C22.13 10.9 20.84 10.14 19.35 10.03C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.03C2.34 8.36 0 10.9 0 14C0 17.31 2.69 20 6 20H13.5C13.24 19.38 13.08 18.7 13.03 18Z\";\r\nvar mdiCloudTags = \"M6,20A6,6 0 0,1 0,14C0,10.91 2.34,8.36 5.35,8.04C6.6,5.64 9.11,4 12,4C15.63,4 18.66,6.58 19.35,10C21.95,10.19 24,12.36 24,15A5,5 0 0,1 19,20H6M9.09,8.4L4.5,13L9.09,17.6L10.5,16.18L7.32,13L10.5,9.82L9.09,8.4M14.91,8.4L13.5,9.82L16.68,13L13.5,16.18L14.91,17.6L19.5,13L14.91,8.4Z\";\r\nvar mdiCloudUpload = \"M14,13V17H10V13H7L12,8L17,13M19.35,10.03C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.03C2.34,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.03Z\";\r\nvar mdiCloudUploadOutline = \"M19.35,10.04C18.67,6.59 15.64,4 12,4C9.11,4 6.6,5.64 5.35,8.04C2.34,8.36 0,10.91 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.04M19,18H6A4,4 0 0,1 2,14C2,11.95 3.53,10.24 5.56,10.03L6.63,9.92L7.13,8.97C8.08,7.14 9.94,6 12,6C14.62,6 16.88,7.86 17.39,10.43L17.69,11.93L19.22,12.04C20.78,12.14 22,13.45 22,15A3,3 0 0,1 19,18M8,13H10.55V16H13.45V13H16L12,9L8,13Z\";\r\nvar mdiClover = \"M12,11.18C15.3,8.18 17,6.64 17,4.69C17,3.19 15.75,2 14.25,2C13.39,2 12.57,2.36 12,3C11.43,2.36 10.61,2 9.69,2C8.19,2 7,3.25 7,4.75C7,6.64 8.7,8.18 12,11.18M11.18,12C8.18,8.7 6.64,7 4.69,7C3.19,7 2,8.25 2,9.75C2,10.61 2.36,11.43 3,12C2.36,12.57 2,13.39 2,14.31C2,15.81 3.25,17 4.75,17C6.64,17 8.18,15.3 11.18,12M12.83,12C15.82,15.3 17.36,17 19.31,17C20.81,17 22,15.75 22,14.25C22,13.39 21.64,12.57 21,12C21.64,11.43 22,10.61 22,9.69C22,8.19 20.75,7 19.25,7C17.36,7 15.82,8.7 12.83,12M12,12.82C8.7,15.82 7,17.36 7,19.31C7,20.81 8.25,22 9.75,22C10.61,22 11.43,21.64 12,21C12.57,21.64 13.39,22 14.31,22C15.81,22 17,20.75 17,19.25C17,17.36 15.3,15.82 12,12.82Z\";\r\nvar mdiCoachLamp = \"M16 5L15 2H13L12 5L6 8H8L8.6 11H4V7H2V17H4V13H9L10 18L12 20L13 22H15L16 20L18 18L20 8H22M16.16 17H11.84L10 8H18Z\";\r\nvar mdiCoatRack = \"M18.33 7.78A1 1 0 0 0 16.66 8.89A2 2 0 1 1 13 10V7.82A3 3 0 1 0 11 7.82V10A2 2 0 1 1 7.34 8.89A1 1 0 1 0 5.67 7.78A4 4 0 0 0 11 13.46V20A2 2 0 0 0 9 22H15A2 2 0 0 0 13 20V13.46A4 4 0 0 0 18.33 7.78M12 4A1 1 0 1 1 11 5A1 1 0 0 1 12 4Z\";\r\nvar mdiCodeArray = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M6,6V18H10V16H8V8H10V6H6M16,16H14V18H18V6H14V8H16V16Z\";\r\nvar mdiCodeBraces = \"M8,3A2,2 0 0,0 6,5V9A2,2 0 0,1 4,11H3V13H4A2,2 0 0,1 6,15V19A2,2 0 0,0 8,21H10V19H8V14A2,2 0 0,0 6,12A2,2 0 0,0 8,10V5H10V3M16,3A2,2 0 0,1 18,5V9A2,2 0 0,0 20,11H21V13H20A2,2 0 0,0 18,15V19A2,2 0 0,1 16,21H14V19H16V14A2,2 0 0,1 18,12A2,2 0 0,1 16,10V5H14V3H16Z\";\r\nvar mdiCodeBracesBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M11 8H9V10C9 11.1 8.1 12 7 12C8.1 12 9 12.9 9 14V16H11V18H9C7.9 18 7 17.1 7 16V15C7 13.9 6.1 13 5 13V11C6.1 11 7 10.1 7 9V8C7 6.9 7.9 6 9 6H11V8M19 13C17.9 13 17 13.9 17 15V16C17 17.1 16.1 18 15 18H13V16H15V14C15 12.9 15.9 12 17 12C15.9 12 15 11.1 15 10V8H13V6H15C16.1 6 17 6.9 17 8V9C17 10.1 17.9 11 19 11V13Z\";\r\nvar mdiCodeBrackets = \"M15,4V6H18V18H15V20H20V4M4,4V20H9V18H6V6H9V4H4Z\";\r\nvar mdiCodeEqual = \"M6,13H11V15H6M13,13H18V15H13M13,9H18V11H13M6,9H11V11H6M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeGreaterThan = \"M10.41,7.41L15,12L10.41,16.6L9,15.18L12.18,12L9,8.82M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeGreaterThanOrEqual = \"M13,13H18V15H13M13,9H18V11H13M6.91,7.41L11.5,12L6.91,16.6L5.5,15.18L8.68,12L5.5,8.82M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeJson = \"M5,3H7V5H5V10A2,2 0 0,1 3,12A2,2 0 0,1 5,14V19H7V21H5C3.93,20.73 3,20.1 3,19V15A2,2 0 0,0 1,13H0V11H1A2,2 0 0,0 3,9V5A2,2 0 0,1 5,3M19,3A2,2 0 0,1 21,5V9A2,2 0 0,0 23,11H24V13H23A2,2 0 0,0 21,15V19A2,2 0 0,1 19,21H17V19H19V14A2,2 0 0,1 21,12A2,2 0 0,1 19,10V5H17V3H19M12,15A1,1 0 0,1 13,16A1,1 0 0,1 12,17A1,1 0 0,1 11,16A1,1 0 0,1 12,15M8,15A1,1 0 0,1 9,16A1,1 0 0,1 8,17A1,1 0 0,1 7,16A1,1 0 0,1 8,15M16,15A1,1 0 0,1 17,16A1,1 0 0,1 16,17A1,1 0 0,1 15,16A1,1 0 0,1 16,15Z\";\r\nvar mdiCodeLessThan = \"M13.59,7.41L9,12L13.59,16.6L15,15.18L11.82,12L15,8.82M19,3C20.11,3 21,3.9 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19Z\";\r\nvar mdiCodeLessThanOrEqual = \"M13,13H18V15H13M13,9H18V11H13M10.09,7.41L11.5,8.82L8.32,12L11.5,15.18L10.09,16.6L5.5,12M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeNotEqual = \"M6,15H8V17H6M11,13H18V15H11M11,9H18V11H11M6,7H8V13H6M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeNotEqualVariant = \"M11,6.5V9.33L8.33,12L11,14.67V17.5L5.5,12M13,6.43L18.57,12L13,17.57V14.74L15.74,12L13,9.26M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5Z\";\r\nvar mdiCodeParentheses = \"M17.62,3C19.13,5.27 20,8.55 20,12C20,15.44 19.13,18.72 17.62,21L16,19.96C17.26,18.07 18,15.13 18,12C18,8.87 17.26,5.92 16,4.03L17.62,3M6.38,3L8,4.04C6.74,5.92 6,8.87 6,12C6,15.13 6.74,18.08 8,19.96L6.38,21C4.87,18.73 4,15.45 4,12C4,8.55 4.87,5.27 6.38,3Z\";\r\nvar mdiCodeParenthesesBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M10 17.3L8.4 18C6.9 16.5 6 14.3 6 12S6.9 7.5 8.4 6L10 6.7C8.7 7.9 8 9.9 8 12S8.7 16.1 10 17.3M15.6 18L14 17.3C15.3 16 16 14.1 16 12S15.3 7.9 14 6.7L15.6 6C17.1 7.5 18 9.7 18 12C18 14.3 17.1 16.5 15.6 18Z\";\r\nvar mdiCodeString = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M12.5,11H11.5A1.5,1.5 0 0,1 10,9.5A1.5,1.5 0 0,1 11.5,8H12.5A1.5,1.5 0 0,1 14,9.5H16A3.5,3.5 0 0,0 12.5,6H11.5A3.5,3.5 0 0,0 8,9.5A3.5,3.5 0 0,0 11.5,13H12.5A1.5,1.5 0 0,1 14,14.5A1.5,1.5 0 0,1 12.5,16H11.5A1.5,1.5 0 0,1 10,14.5H8A3.5,3.5 0 0,0 11.5,18H12.5A3.5,3.5 0 0,0 16,14.5A3.5,3.5 0 0,0 12.5,11Z\";\r\nvar mdiCodeTags = \"M14.6,16.6L19.2,12L14.6,7.4L16,6L22,12L16,18L14.6,16.6M9.4,16.6L4.8,12L9.4,7.4L8,6L2,12L8,18L9.4,16.6Z\";\r\nvar mdiCodeTagsCheck = \"M6.59,3.41L2,8L6.59,12.6L8,11.18L4.82,8L8,4.82L6.59,3.41M12.41,3.41L11,4.82L14.18,8L11,11.18L12.41,12.6L17,8L12.41,3.41M21.59,11.59L13.5,19.68L9.83,16L8.42,17.41L13.5,22.5L23,13L21.59,11.59Z\";\r\nvar mdiCodepen = \"M8.21 12L6.88 12.89V11.11L8.21 12M11.47 9.82V7.34L7.31 10.12L9.16 11.36L11.47 9.82M16.7 10.12L12.53 7.34V9.82L14.84 11.36L16.7 10.12M7.31 13.88L11.47 16.66V14.18L9.16 12.64L7.31 13.88M12.53 14.18V16.66L16.7 13.88L14.84 12.64L12.53 14.18M12 10.74L10.12 12L12 13.26L13.88 12L12 10.74M22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C17.5 2 22 6.5 22 12M18.18 10.12C18.18 10.09 18.18 10.07 18.18 10.05L18.17 10L18.17 10L18.16 9.95C18.15 9.94 18.15 9.93 18.14 9.91L18.13 9.89L18.11 9.85L18.1 9.83L18.08 9.8L18.06 9.77L18.03 9.74L18 9.72L18 9.7L17.96 9.68L17.95 9.67L12.3 5.91C12.12 5.79 11.89 5.79 11.71 5.91L6.05 9.67L6.05 9.68L6 9.7C6 9.71 6 9.72 6 9.72L5.97 9.74L5.94 9.77L5.93 9.8L5.9 9.83L5.89 9.85L5.87 9.89L5.86 9.91L5.84 9.95L5.84 10L5.83 10L5.82 10.05C5.82 10.07 5.82 10.09 5.82 10.12V13.88C5.82 13.91 5.82 13.93 5.82 13.95L5.83 14L5.84 14L5.84 14.05C5.85 14.06 5.85 14.07 5.86 14.09L5.87 14.11L5.89 14.15L5.9 14.17L5.92 14.2L5.94 14.23C5.95 14.24 5.96 14.25 5.97 14.26L6 14.28L6 14.3L6.04 14.32L6.05 14.33L11.71 18.1C11.79 18.16 11.9 18.18 12 18.18C12.1 18.18 12.21 18.15 12.3 18.1L17.95 14.33L17.96 14.32L18 14.3L18 14.28L18.03 14.26L18.06 14.23L18.08 14.2L18.1 14.17L18.11 14.15L18.13 14.11L18.14 14.09L18.16 14.05L18.16 14L18.17 14L18.18 13.95C18.18 13.93 18.18 13.91 18.18 13.88V10.12M17.12 12.89V11.11L15.79 12L17.12 12.89Z\";\r\nvar mdiCoffee = \"M2,21H20V19H2M20,8H18V5H20M20,3H4V13A4,4 0 0,0 8,17H14A4,4 0 0,0 18,13V10H20A2,2 0 0,0 22,8V5C22,3.89 21.1,3 20,3Z\";\r\nvar mdiCoffeeMaker = \"M21 1V4H7V21H21V23H2V3C2 1.89 2.89 1 4 1H21M22 13V15C22 16.11 21.11 17 20 17H18C18 20 15 20 14 20S10 20 10 17V11H20C21.11 11 22 11.9 22 13M20 13H18V15H20V13M17 9L19 5H9L11 9H17Z\";\r\nvar mdiCoffeeOff = \"M3.27 2L22 20.72L20.72 22L19.73 21H2V19H17.73L15.44 16.71C15 16.89 14.5 17 14 17H8C5.79 17 4 15.21 4 13V5.27L2 3.27L3.27 2M22 5V8C22 9.1 21.1 10 20 10H18V13C18 13.36 17.94 13.7 17.85 14.04L6.81 3H20C21.1 3 22 3.89 22 5M20 5H18V8H20V5Z\";\r\nvar mdiCoffeeOffOutline = \"M2 3.27L4 5.27V13C4 15.21 5.79 17 8 17H14C14.5 17 15 16.89 15.44 16.71L17.73 19H2V21H19.73L20.72 22L22 20.72L3.27 2L2 3.27M8 15C6.9 15 6 14.1 6 13V7.27L13.73 15H8M20 3H6.81L8.81 5H16V12.19L17.85 14.04C17.94 13.7 18 13.36 18 13V10H20C21.1 10 22 9.1 22 8V5C22 3.9 21.1 3 20 3M20 8H18V5H20V8Z\";\r\nvar mdiCoffeeOutline = \"M2,21V19H20V21H2M20,8V5H18V8H20M20,3A2,2 0 0,1 22,5V8A2,2 0 0,1 20,10H18V13A4,4 0 0,1 14,17H8A4,4 0 0,1 4,13V3H20M16,5H6V13A2,2 0 0,0 8,15H14A2,2 0 0,0 16,13V5Z\";\r\nvar mdiCoffeeToGo = \"M3,19V17H17L15.26,15.24L16.67,13.83L20.84,18L16.67,22.17L15.26,20.76L17,19H3M17,8V5H15V8H17M17,3C18.11,3 19,3.9 19,5V8C19,9.11 18.11,10 17,10H15V11A4,4 0 0,1 11,15H7A4,4 0 0,1 3,11V3H17Z\";\r\nvar mdiCoffeeToGoOutline = \"M3 3V11A4 4 0 0 0 7 15H11A4 4 0 0 0 15 11V10H17C18.11 10 19 9.11 19 8V5C19 3.9 18.11 3 17 3H3M5 5H13V11A2 2 0 0 1 11 13H7A2 2 0 0 1 5 11V5M15 5H17V8H15V5M16.67 13.83L15.26 15.24L17 17H3V19H17L15.26 20.76L16.67 22.17L20.84 18L16.67 13.83Z\";\r\nvar mdiCoffin = \"M8,22L5,8L8,2H16L19,8L16,22H8M11,6V8H9V10H11V15H13V10H15V8H13V6H11Z\";\r\nvar mdiCog = \"M12,15.5A3.5,3.5 0 0,1 8.5,12A3.5,3.5 0 0,1 12,8.5A3.5,3.5 0 0,1 15.5,12A3.5,3.5 0 0,1 12,15.5M19.43,12.97C19.47,12.65 19.5,12.33 19.5,12C19.5,11.67 19.47,11.34 19.43,11L21.54,9.37C21.73,9.22 21.78,8.95 21.66,8.73L19.66,5.27C19.54,5.05 19.27,4.96 19.05,5.05L16.56,6.05C16.04,5.66 15.5,5.32 14.87,5.07L14.5,2.42C14.46,2.18 14.25,2 14,2H10C9.75,2 9.54,2.18 9.5,2.42L9.13,5.07C8.5,5.32 7.96,5.66 7.44,6.05L4.95,5.05C4.73,4.96 4.46,5.05 4.34,5.27L2.34,8.73C2.21,8.95 2.27,9.22 2.46,9.37L4.57,11C4.53,11.34 4.5,11.67 4.5,12C4.5,12.33 4.53,12.65 4.57,12.97L2.46,14.63C2.27,14.78 2.21,15.05 2.34,15.27L4.34,18.73C4.46,18.95 4.73,19.03 4.95,18.95L7.44,17.94C7.96,18.34 8.5,18.68 9.13,18.93L9.5,21.58C9.54,21.82 9.75,22 10,22H14C14.25,22 14.46,21.82 14.5,21.58L14.87,18.93C15.5,18.67 16.04,18.34 16.56,17.94L19.05,18.95C19.27,19.03 19.54,18.95 19.66,18.73L21.66,15.27C21.78,15.05 21.73,14.78 21.54,14.63L19.43,12.97Z\";\r\nvar mdiCogBox = \"M17.25,12C17.25,12.23 17.23,12.46 17.2,12.68L18.68,13.84C18.81,13.95 18.85,14.13 18.76,14.29L17.36,16.71C17.27,16.86 17.09,16.92 16.93,16.86L15.19,16.16C14.83,16.44 14.43,16.67 14,16.85L13.75,18.7C13.72,18.87 13.57,19 13.4,19H10.6C10.43,19 10.28,18.87 10.25,18.7L10,16.85C9.56,16.67 9.17,16.44 8.81,16.16L7.07,16.86C6.91,16.92 6.73,16.86 6.64,16.71L5.24,14.29C5.15,14.13 5.19,13.95 5.32,13.84L6.8,12.68C6.77,12.46 6.75,12.23 6.75,12C6.75,11.77 6.77,11.54 6.8,11.32L5.32,10.16C5.19,10.05 5.15,9.86 5.24,9.71L6.64,7.29C6.73,7.13 6.91,7.07 7.07,7.13L8.81,7.84C9.17,7.56 9.56,7.32 10,7.15L10.25,5.29C10.28,5.13 10.43,5 10.6,5H13.4C13.57,5 13.72,5.13 13.75,5.29L14,7.15C14.43,7.32 14.83,7.56 15.19,7.84L16.93,7.13C17.09,7.07 17.27,7.13 17.36,7.29L18.76,9.71C18.85,9.86 18.81,10.05 18.68,10.16L17.2,11.32C17.23,11.54 17.25,11.77 17.25,12M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M12,10C10.89,10 10,10.89 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12C14,10.89 13.1,10 12,10Z\";\r\nvar mdiCogClockwise = \"M12 3C7.03 3 3 7.03 3 12S7.03 21 12 21C14 21 15.92 20.34 17.5 19.14L16.06 17.7C14.87 18.54 13.45 19 12 19C8.13 19 5 15.87 5 12S8.13 5 12 5 19 8.13 19 12H16L20 16L24 12H21C21 7.03 16.97 3 12 3M7.71 13.16C7.62 13.23 7.59 13.35 7.64 13.45L8.54 15C8.6 15.12 8.72 15.12 8.82 15.12L9.95 14.67C10.19 14.83 10.44 14.97 10.7 15.09L10.88 16.28C10.9 16.39 11 16.47 11.1 16.47H12.9C13 16.5 13.11 16.41 13.13 16.3L13.31 15.12C13.58 15 13.84 14.85 14.07 14.67L15.19 15.12C15.3 15.16 15.42 15.11 15.47 15L16.37 13.5C16.42 13.38 16.39 13.26 16.31 13.19L15.31 12.45C15.34 12.15 15.34 11.85 15.31 11.55L16.31 10.79C16.4 10.72 16.42 10.61 16.37 10.5L15.47 8.95C15.41 8.85 15.3 8.81 15.19 8.85L14.07 9.3C13.83 9.13 13.57 9 13.3 8.88L13.13 7.69C13.11 7.58 13 7.5 12.9 7.5H11.14C11.04 7.5 10.95 7.57 10.93 7.67L10.76 8.85C10.5 8.97 10.23 9.12 10 9.3L8.85 8.88C8.74 8.84 8.61 8.89 8.56 9L7.65 10.5C7.6 10.62 7.63 10.74 7.71 10.81L8.71 11.55C8.69 11.7 8.69 11.85 8.71 12C8.7 12.15 8.7 12.3 8.71 12.45L7.71 13.19M12 13.5H12C11.16 13.5 10.5 12.82 10.5 12C10.5 11.17 11.17 10.5 12 10.5S13.5 11.17 13.5 12 12.83 13.5 12 13.5\";\r\nvar mdiCogCounterclockwise = \"M12 3C7.03 3 3 7.03 3 12H0L4 16L8 12H5C5 8.13 8.13 5 12 5S19 8.13 19 12 15.87 19 12 19C10.55 19 9.13 18.54 7.94 17.7L6.5 19.14C8.08 20.34 10 21 12 21C16.97 21 21 16.97 21 12S16.97 3 12 3M16.29 13.19L15.29 12.45C15.3 12.3 15.3 12.15 15.29 12C15.31 11.85 15.31 11.7 15.29 11.55L16.29 10.81C16.37 10.74 16.4 10.62 16.35 10.5L15.44 9C15.39 8.89 15.26 8.84 15.15 8.88L14 9.3C13.77 9.12 13.5 8.97 13.24 8.85L13.07 7.67C13.05 7.57 12.96 7.5 12.86 7.5H11.1C11 7.5 10.89 7.58 10.87 7.69L10.7 8.88C10.43 9 10.17 9.13 9.93 9.3L8.81 8.85C8.71 8.81 8.59 8.85 8.53 8.95L7.63 10.5C7.58 10.61 7.6 10.72 7.69 10.79L8.69 11.55C8.66 11.85 8.66 12.15 8.69 12.45L7.69 13.19C7.61 13.26 7.58 13.38 7.63 13.5L8.53 15C8.58 15.11 8.7 15.16 8.81 15.12L9.93 14.67C10.16 14.85 10.42 15 10.69 15.12L10.87 16.3C10.89 16.41 11 16.5 11.1 16.47H12.9C13 16.47 13.11 16.39 13.12 16.28L13.3 15.09C13.56 14.97 13.81 14.83 14.05 14.67L15.18 15.12C15.28 15.12 15.4 15.12 15.46 15L16.36 13.45C16.41 13.35 16.38 13.23 16.29 13.16M12 13.5C11.17 13.5 10.5 12.83 10.5 12S11.17 10.5 12 10.5 13.5 11.17 13.5 12C13.5 12.82 12.84 13.5 12 13.5H12\";\r\nvar mdiCogOff = \"M22.12 21.46L2.4 1.73L1.12 3L4 5.87L2.34 8.73C2.21 8.95 2.27 9.22 2.46 9.37L4.57 11C4.53 11.34 4.5 11.67 4.5 12S4.53 12.65 4.57 12.97L2.46 14.63C2.27 14.78 2.21 15.05 2.34 15.27L4.34 18.73C4.46 18.95 4.73 19.03 4.95 18.95L7.44 17.94C7.96 18.34 8.5 18.68 9.13 18.93L9.5 21.58C9.54 21.82 9.75 22 10 22H14C14.25 22 14.46 21.82 14.5 21.58L14.87 18.93C15.38 18.72 15.83 18.45 16.26 18.14L20.85 22.73L22.12 21.46M12 15.5C10.07 15.5 8.5 13.93 8.5 12C8.5 11.5 8.62 11.08 8.79 10.67L13.33 15.21C12.92 15.39 12.5 15.5 12 15.5M11.74 8.53L8.56 5.35C8.75 5.25 8.93 5.15 9.13 5.07L9.5 2.42C9.54 2.18 9.75 2 10 2H14C14.25 2 14.46 2.18 14.5 2.42L14.87 5.07C15.5 5.32 16.04 5.66 16.56 6.05L19.05 5.05C19.27 4.96 19.54 5.05 19.66 5.27L21.66 8.73C21.78 8.95 21.73 9.22 21.54 9.37L19.43 11C19.47 11.34 19.5 11.67 19.5 12S19.47 12.65 19.43 12.97L21.54 14.63C21.73 14.78 21.78 15.05 21.66 15.27L20.5 17.29L15.47 12.26C15.5 12.18 15.5 12.09 15.5 12C15.5 10.07 13.93 8.5 12 8.5C11.91 8.5 11.83 8.5 11.74 8.53Z\";\r\nvar mdiCogOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L4 5.88L2.34 8.73C2.21 8.95 2.27 9.22 2.46 9.37L4.57 11L4.5 12L4.57 12.97L2.46 14.63C2.27 14.78 2.21 15.05 2.34 15.27L4.34 18.73C4.46 18.95 4.73 19.03 4.95 18.95L7.44 17.94C7.96 18.34 8.5 18.68 9.13 18.93L9.5 21.58C9.54 21.82 9.75 22 10 22H14C14.25 22 14.46 21.82 14.5 21.58L14.87 18.93C15.38 18.73 15.83 18.45 16.26 18.15L20.84 22.73L22.11 21.46M10 11.9L12.1 14C12.06 14 12.03 14 12 14C10.9 14 10 13.11 10 12C10 11.97 10 11.94 10 11.9M13.13 17.39L12.76 20H11.24L10.87 17.38C9.68 17.14 8.63 16.5 7.86 15.62L5.43 16.66L4.68 15.36L6.8 13.8C6.4 12.64 6.4 11.37 6.8 10.2L4.69 8.65L5.44 7.35L5.5 7.37L8.4 10.29C8.15 10.8 8 11.38 8 12C8 14.21 9.79 16 12 16C12.62 16 13.2 15.86 13.71 15.6L14.83 16.72C14.31 17.03 13.74 17.26 13.13 17.39M10.06 6.86L8.55 5.35C8.74 5.26 8.93 5.15 9.13 5.07L9.5 2.42C9.54 2.18 9.75 2 10 2H14C14.25 2 14.46 2.18 14.5 2.42L14.87 5.07C15.5 5.32 16.04 5.66 16.56 6.05L19.05 5.05C19.27 4.96 19.54 5.05 19.66 5.27L21.66 8.73C21.79 8.95 21.73 9.22 21.54 9.37L19.43 11L19.5 12L19.43 13L21.54 14.63C21.73 14.78 21.79 15.05 21.66 15.27L20.5 17.29L19.04 15.84L19.32 15.36L17.2 13.81C17.6 12.64 17.6 11.37 17.2 10.2L19.31 8.65L18.56 7.35L16.15 8.39C15.38 7.5 14.32 6.86 13.12 6.62L12.75 4H11.25L10.88 6.61C10.6 6.67 10.32 6.75 10.06 6.86M12 8C14.21 8 16 9.79 16 12C16 12.25 15.97 12.5 15.93 12.73L11.27 8.07C11.5 8.03 11.75 8 12 8Z\";\r\nvar mdiCogOutline = \"M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M10,22C9.75,22 9.54,21.82 9.5,21.58L9.13,18.93C8.5,18.68 7.96,18.34 7.44,17.94L4.95,18.95C4.73,19.03 4.46,18.95 4.34,18.73L2.34,15.27C2.21,15.05 2.27,14.78 2.46,14.63L4.57,12.97L4.5,12L4.57,11L2.46,9.37C2.27,9.22 2.21,8.95 2.34,8.73L4.34,5.27C4.46,5.05 4.73,4.96 4.95,5.05L7.44,6.05C7.96,5.66 8.5,5.32 9.13,5.07L9.5,2.42C9.54,2.18 9.75,2 10,2H14C14.25,2 14.46,2.18 14.5,2.42L14.87,5.07C15.5,5.32 16.04,5.66 16.56,6.05L19.05,5.05C19.27,4.96 19.54,5.05 19.66,5.27L21.66,8.73C21.79,8.95 21.73,9.22 21.54,9.37L19.43,11L19.5,12L19.43,13L21.54,14.63C21.73,14.78 21.79,15.05 21.66,15.27L19.66,18.73C19.54,18.95 19.27,19.04 19.05,18.95L16.56,17.95C16.04,18.34 15.5,18.68 14.87,18.93L14.5,21.58C14.46,21.82 14.25,22 14,22H10M11.25,4L10.88,6.61C9.68,6.86 8.62,7.5 7.85,8.39L5.44,7.35L4.69,8.65L6.8,10.2C6.4,11.37 6.4,12.64 6.8,13.8L4.68,15.36L5.43,16.66L7.86,15.62C8.63,16.5 9.68,17.14 10.87,17.38L11.24,20H12.76L13.13,17.39C14.32,17.14 15.37,16.5 16.14,15.62L18.57,16.66L19.32,15.36L17.2,13.81C17.6,12.64 17.6,11.37 17.2,10.2L19.31,8.65L18.56,7.35L16.15,8.39C15.38,7.5 14.32,6.86 13.12,6.62L12.75,4H11.25Z\";\r\nvar mdiCogRefresh = \"M18 14.5C19.1 14.5 20.1 14.9 20.8 15.7L22 14.5V18.5H18L19.8 16.7C19.3 16.3 18.7 16 18 16C16.6 16 15.5 17.1 15.5 18.5S16.6 21 18 21C18.8 21 19.5 20.6 20 20H21.7C21.1 21.5 19.7 22.5 18 22.5C15.8 22.5 14 20.7 14 18.5S15.8 14.5 18 14.5M11.5 18.5C11.5 17.4 11.8 16.4 12.2 15.5H12C10.1 15.5 8.5 13.9 8.5 12S10.1 8.5 12 8.5 15.5 10.1 15.5 12C15.5 12.2 15.5 12.4 15.4 12.5C16.2 12.2 17 12 18 12C18.5 12 19 12.1 19.5 12.2V12C19.5 11.7 19.5 11.3 19.4 11L21.5 9.4C21.7 9.2 21.7 9 21.6 8.8L19.6 5.3C19.5 5 19.3 5 19 5L16.5 6C16 5.6 15.4 5.3 14.8 5L14.4 2.3C14.5 2.2 14.2 2 14 2H10C9.8 2 9.5 2.2 9.5 2.4L9.1 5.1C8.5 5.3 8 5.7 7.4 6L5 5C4.7 5 4.5 5 4.3 5.3L2.3 8.8C2.2 9 2.3 9.2 2.5 9.4L4.6 11C4.6 11.3 4.5 11.7 4.5 12S4.5 12.7 4.6 13L2.5 14.7C2.3 14.9 2.3 15.1 2.4 15.3L4.4 18.8C4.5 19 4.7 19 5 19L7.5 18C8 18.4 8.6 18.7 9.2 19L9.6 21.7C9.6 21.9 9.8 22.1 10.1 22.1H12.6C11.9 21 11.5 19.8 11.5 18.5Z\";\r\nvar mdiCogRefreshOutline = \"M18 14.5C19.1 14.5 20.1 14.9 20.8 15.7L22 14.5V18.5H18L19.8 16.7C19.3 16.3 18.7 16 18 16C16.6 16 15.5 17.1 15.5 18.5S16.6 21 18 21C18.8 21 19.5 20.6 20 20H21.7C21.1 21.5 19.7 22.5 18 22.5C15.8 22.5 14 20.7 14 18.5S15.8 14.5 18 14.5M11.7 20H11.3L10.9 17.4C9.7 17.2 8.7 16.5 7.9 15.6L5.5 16.6L4.7 15.3L6.8 13.7C6.4 12.5 6.4 11.3 6.8 10.1L4.7 8.7L5.5 7.4L7.9 8.4C8.7 7.5 9.7 6.9 10.9 6.6L11.2 4H12.7L13.1 6.6C14.3 6.8 15.4 7.5 16.1 8.4L18.5 7.4L19.3 8.7L17.2 10.2C17.4 10.8 17.5 11.4 17.5 12H18C18.5 12 19 12.1 19.5 12.2V12L19.4 11L21.5 9.4C21.7 9.2 21.7 9 21.6 8.8L19.6 5.3C19.5 5 19.3 5 19 5L16.5 6C16 5.6 15.4 5.3 14.8 5L14.4 2.3C14.5 2.2 14.2 2 14 2H10C9.8 2 9.5 2.2 9.5 2.4L9.1 5.1C8.5 5.3 8 5.7 7.4 6L5 5C4.7 5 4.5 5 4.3 5.3L2.3 8.8C2.2 9 2.3 9.2 2.5 9.4L4.6 11L4.5 12L4.6 13L2.5 14.7C2.3 14.9 2.3 15.1 2.4 15.3L4.4 18.8C4.5 19 4.7 19 5 19L7.5 18C8 18.4 8.6 18.7 9.2 19L9.6 21.7C9.6 21.9 9.8 22.1 10.1 22.1H12.6C12.1 21.4 11.9 20.7 11.7 20M16 12.3V12C16 9.8 14.2 8 12 8S8 9.8 8 12C8 14.2 9.8 16 12 16C12.7 14.3 14.2 12.9 16 12.3M10 12C10 10.9 10.9 10 12 10S14 10.9 14 12 13.1 14 12 14 10 13.1 10 12Z\";\r\nvar mdiCogSync = \"M11.5 18.5C11.5 17.4 11.8 16.4 12.2 15.5H12C10.1 15.5 8.5 13.9 8.5 12S10.1 8.5 12 8.5 15.5 10.1 15.5 12C15.5 12.2 15.5 12.4 15.4 12.5C16.2 12.2 17 12 18 12C18.5 12 19 12.1 19.5 12.2V12C19.5 11.7 19.5 11.3 19.4 11L21.5 9.4C21.7 9.2 21.7 9 21.6 8.8L19.6 5.3C19.5 5 19.3 5 19 5L16.5 6C16 5.6 15.4 5.3 14.8 5L14.4 2.3C14.5 2.2 14.2 2 14 2H10C9.8 2 9.5 2.2 9.5 2.4L9.1 5.1C8.5 5.3 8 5.7 7.4 6L5 5C4.7 5 4.5 5 4.3 5.3L2.3 8.8C2.2 9 2.3 9.2 2.5 9.4L4.6 11C4.6 11.3 4.5 11.7 4.5 12S4.5 12.7 4.6 13L2.5 14.7C2.3 14.9 2.3 15.1 2.4 15.3L4.4 18.8C4.5 19 4.7 19 5 19L7.5 18C8 18.4 8.6 18.7 9.2 19L9.6 21.7C9.6 21.9 9.8 22.1 10.1 22.1H12.6C11.9 21 11.5 19.8 11.5 18.5M18 14.5V13L15.8 15.2L18 17.4V16C19.4 16 20.5 17.1 20.5 18.5C20.5 18.9 20.4 19.3 20.2 19.6L21.3 20.7C22.5 18.9 22 16.4 20.2 15.2C19.6 14.7 18.8 14.5 18 14.5M18 21C16.6 21 15.5 19.9 15.5 18.5C15.5 18.1 15.6 17.7 15.8 17.4L14.7 16.3C13.5 18.1 14 20.6 15.8 21.8C16.5 22.2 17.2 22.5 18 22.5V24L20.2 21.8L18 19.5V21Z\";\r\nvar mdiCogSyncOutline = \"M11.7 20H11.3L10.9 17.4C9.7 17.2 8.7 16.5 7.9 15.6L5.5 16.6L4.7 15.3L6.8 13.7C6.4 12.5 6.4 11.3 6.8 10.1L4.7 8.7L5.5 7.4L7.9 8.4C8.7 7.5 9.7 6.9 10.9 6.6L11.2 4H12.7L13.1 6.6C14.3 6.8 15.4 7.5 16.1 8.4L18.5 7.4L19.3 8.7L17.2 10.2C17.4 10.8 17.5 11.4 17.5 12H18C18.5 12 19 12.1 19.5 12.2V12L19.4 11L21.5 9.4C21.7 9.2 21.7 9 21.6 8.8L19.6 5.3C19.5 5 19.3 5 19 5L16.5 6C16 5.6 15.4 5.3 14.8 5L14.4 2.3C14.5 2.2 14.2 2 14 2H10C9.8 2 9.5 2.2 9.5 2.4L9.1 5.1C8.5 5.3 8 5.7 7.4 6L5 5C4.7 5 4.5 5 4.3 5.3L2.3 8.8C2.2 9 2.3 9.2 2.5 9.4L4.6 11L4.5 12L4.6 13L2.5 14.7C2.3 14.9 2.3 15.1 2.4 15.3L4.4 18.8C4.5 19 4.7 19 5 19L7.5 18C8 18.4 8.6 18.7 9.2 19L9.6 21.7C9.6 21.9 9.8 22.1 10.1 22.1H12.6C12.1 21.4 11.9 20.7 11.7 20M16 12.3V12C16 9.8 14.2 8 12 8S8 9.8 8 12C8 14.2 9.8 16 12 16C12.7 14.3 14.2 12.9 16 12.3M10 12C10 10.9 10.9 10 12 10S14 10.9 14 12 13.1 14 12 14 10 13.1 10 12M18 14.5V13L15.8 15.2L18 17.4V16C19.4 16 20.5 17.1 20.5 18.5C20.5 18.9 20.4 19.3 20.2 19.6L21.3 20.7C22.5 18.9 22 16.4 20.2 15.2C19.6 14.7 18.8 14.5 18 14.5M18 21C16.6 21 15.5 19.9 15.5 18.5C15.5 18.1 15.6 17.7 15.8 17.4L14.7 16.3C13.5 18.1 14 20.6 15.8 21.8C16.5 22.2 17.2 22.5 18 22.5V24L20.2 21.8L18 19.5V21Z\";\r\nvar mdiCogTransfer = \"M14 18V16L10 19.5L14 23V21H17V18H14M22 15.5L18 12V14H15V17H18V19L22 15.5M21.66 8.73L19.66 5.27C19.54 5.05 19.28 4.96 19.05 5.05L16.56 6.05C16.05 5.64 15.5 5.31 14.87 5.05L14.5 2.42C14.46 2.18 14.25 2 14 2H10C9.75 2 9.54 2.18 9.5 2.42L9.13 5.07C8.5 5.33 7.96 5.66 7.44 6.07L5 5.05C4.77 4.96 4.5 5.05 4.39 5.27L2.39 8.73C2.26 8.94 2.31 9.22 2.5 9.37L4.57 11C4.53 11.33 4.5 11.67 4.5 12C4.5 12.33 4.53 12.67 4.57 13L2.46 14.63C2.26 14.78 2.21 15.06 2.34 15.27L4.34 18.73C4.45 19 4.74 19.11 5 19L5 19L7.5 18C7.74 18.19 8 18.37 8.26 18.53L11.77 15.53C9.84 15.4 8.38 13.73 8.5 11.8C8.65 9.87 10.32 8.41 12.25 8.55C13.69 8.64 14.92 9.62 15.35 11H19.43L21.54 9.37C21.73 9.22 21.78 8.94 21.66 8.73Z\";\r\nvar mdiCogTransferOutline = \"M15 17V14H18V12L22 15.5L18 19V17H15M17 18V21H14V23L10 19.5L14 16V18H17M12 8C9.79 8 8 9.8 8 12C8 13.91 9.35 15.54 11.21 15.92L16 11.86C15.93 9.71 14.16 8 12 8M12 14C10.9 14 10 13.11 10 12S10.9 10 12 10 14 10.9 14 12 13.11 14 12 14M21.66 8.73L19.66 5.27C19.54 5.05 19.28 4.96 19.05 5.05L16.56 6.05C16.05 5.64 15.5 5.31 14.87 5.05L14.5 2.42C14.46 2.18 14.25 2 14 2H10C9.75 2 9.54 2.18 9.5 2.42L9.13 5.07C8.5 5.33 7.96 5.66 7.44 6.07L5 5.05C4.77 4.96 4.5 5.05 4.39 5.27L2.39 8.73C2.26 8.94 2.31 9.22 2.5 9.37L4.57 11L4.5 12L4.57 13L2.46 14.63C2.26 14.78 2.21 15.06 2.34 15.27L4.34 18.73C4.45 19 4.74 19.11 5 19L5 19L7.5 18C7.74 18.19 8 18.37 8.26 18.53L9.91 17.13C9.14 16.8 8.46 16.31 7.91 15.68L5.5 16.68L4.73 15.38L6.8 13.8C6.4 12.63 6.4 11.37 6.8 10.2L4.69 8.65L5.44 7.35L7.85 8.35C8.63 7.45 9.68 6.82 10.85 6.57L11.25 4H12.75L13.12 6.62C14.29 6.86 15.34 7.5 16.12 8.39L18.53 7.39L19.28 8.69L17.2 10.2C17.29 10.46 17.36 10.73 17.4 11H19.4L21.5 9.37C21.72 9.23 21.78 8.95 21.66 8.73M12 8C9.79 8 8 9.8 8 12C8 13.91 9.35 15.54 11.21 15.92L16 11.86C15.93 9.71 14.16 8 12 8M12 14C10.9 14 10 13.11 10 12S10.9 10 12 10 14 10.9 14 12 13.11 14 12 14M12 8C9.79 8 8 9.8 8 12C8 13.91 9.35 15.54 11.21 15.92L16 11.86C15.93 9.71 14.16 8 12 8M12 14C10.9 14 10 13.11 10 12S10.9 10 12 10 14 10.9 14 12 13.11 14 12 14Z\";\r\nvar mdiCogs = \"M15.9,18.45C17.25,18.45 18.35,17.35 18.35,16C18.35,14.65 17.25,13.55 15.9,13.55C14.54,13.55 13.45,14.65 13.45,16C13.45,17.35 14.54,18.45 15.9,18.45M21.1,16.68L22.58,17.84C22.71,17.95 22.75,18.13 22.66,18.29L21.26,20.71C21.17,20.86 21,20.92 20.83,20.86L19.09,20.16C18.73,20.44 18.33,20.67 17.91,20.85L17.64,22.7C17.62,22.87 17.47,23 17.3,23H14.5C14.32,23 14.18,22.87 14.15,22.7L13.89,20.85C13.46,20.67 13.07,20.44 12.71,20.16L10.96,20.86C10.81,20.92 10.62,20.86 10.54,20.71L9.14,18.29C9.05,18.13 9.09,17.95 9.22,17.84L10.7,16.68L10.65,16L10.7,15.31L9.22,14.16C9.09,14.05 9.05,13.86 9.14,13.71L10.54,11.29C10.62,11.13 10.81,11.07 10.96,11.13L12.71,11.84C13.07,11.56 13.46,11.32 13.89,11.15L14.15,9.29C14.18,9.13 14.32,9 14.5,9H17.3C17.47,9 17.62,9.13 17.64,9.29L17.91,11.15C18.33,11.32 18.73,11.56 19.09,11.84L20.83,11.13C21,11.07 21.17,11.13 21.26,11.29L22.66,13.71C22.75,13.86 22.71,14.05 22.58,14.16L21.1,15.31L21.15,16L21.1,16.68M6.69,8.07C7.56,8.07 8.26,7.37 8.26,6.5C8.26,5.63 7.56,4.92 6.69,4.92A1.58,1.58 0 0,0 5.11,6.5C5.11,7.37 5.82,8.07 6.69,8.07M10.03,6.94L11,7.68C11.07,7.75 11.09,7.87 11.03,7.97L10.13,9.53C10.08,9.63 9.96,9.67 9.86,9.63L8.74,9.18L8,9.62L7.81,10.81C7.79,10.92 7.7,11 7.59,11H5.79C5.67,11 5.58,10.92 5.56,10.81L5.4,9.62L4.64,9.18L3.5,9.63C3.41,9.67 3.3,9.63 3.24,9.53L2.34,7.97C2.28,7.87 2.31,7.75 2.39,7.68L3.34,6.94L3.31,6.5L3.34,6.06L2.39,5.32C2.31,5.25 2.28,5.13 2.34,5.03L3.24,3.47C3.3,3.37 3.41,3.33 3.5,3.37L4.63,3.82L5.4,3.38L5.56,2.19C5.58,2.08 5.67,2 5.79,2H7.59C7.7,2 7.79,2.08 7.81,2.19L8,3.38L8.74,3.82L9.86,3.37C9.96,3.33 10.08,3.37 10.13,3.47L11.03,5.03C11.09,5.13 11.07,5.25 11,5.32L10.03,6.06L10.06,6.5L10.03,6.94Z\";\r\nvar mdiCollage = \"M5,3C3.89,3 3,3.89 3,5V19C3,20.11 3.89,21 5,21H11V3M13,3V11H21V5C21,3.89 20.11,3 19,3M13,13V21H19C20.11,21 21,20.11 21,19V13\";\r\nvar mdiCollapseAll = \"M14,4H4V14H2V4A2,2 0 0,1 4,2H14V4M18,6H8A2,2 0 0,0 6,8V18H8V8H18V6M22,12V20A2,2 0 0,1 20,22H12A2,2 0 0,1 10,20V12A2,2 0 0,1 12,10H20A2,2 0 0,1 22,12M20,15H12V17H20V15Z\";\r\nvar mdiCollapseAllOutline = \"M4,2A2,2 0 0,0 2,4V14H4V4H14V2H4M8,6A2,2 0 0,0 6,8V18H8V8H18V6H8M20,12V20H12V12H20M20,10H12A2,2 0 0,0 10,12V20A2,2 0 0,0 12,22H20A2,2 0 0,0 22,20V12A2,2 0 0,0 20,10M19,17H13V15H19V17Z\";\r\nvar mdiColorHelper = \"M0,24H24V20H0V24Z\";\r\nvar mdiComma = \"M7,3H16.95V12.96L12.96,20.94H8L11.97,12.96H7V3Z\";\r\nvar mdiCommaBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M15,13V7H9V13H12L10,17H13L15,13Z\";\r\nvar mdiCommaBoxOutline = \"M10,17L12,13H9V7H15V13L13,17H10M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiCommaCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M15,13L13,17H10L12,13H9V7H15V13Z\";\r\nvar mdiCommaCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M10,17H13L15,13V7H9V13H12L10,17Z\";\r\nvar mdiComment = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9Z\";\r\nvar mdiCommentAccount = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M16,14V13C16,11.67 13.33,11 12,11C10.67,11 8,11.67 8,13V14H16M12,6A2,2 0 0,0 10,8A2,2 0 0,0 12,10A2,2 0 0,0 14,8A2,2 0 0,0 12,6Z\";\r\nvar mdiCommentAccountOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M16,14H8V13C8,11.67 10.67,11 12,11C13.33,11 16,11.67 16,13V14M12,6A2,2 0 0,1 14,8A2,2 0 0,1 12,10A2,2 0 0,1 10,8A2,2 0 0,1 12,6Z\";\r\nvar mdiCommentAlert = \"M9 22C8.4 22 8 21.6 8 21V18H4C2.9 18 2 17.1 2 16V4C2 2.9 2.9 2 4 2H20C21.1 2 22 2.9 22 4V16C22 17.1 21.1 18 20 18H13.9L10.2 21.7C10 21.9 9.8 22 9.5 22H9M13 11V5H11V11M13 15V13H11V15H13Z\";\r\nvar mdiCommentAlertOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M13,10H11V6H13V10M13,14H11V12H13V14Z\";\r\nvar mdiCommentArrowLeft = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M16 11H11.5L13.3 12.8L12 14L8 10L12 6L13.2 7.2L11.5 9H16V11Z\";\r\nvar mdiCommentArrowLeftOutline = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H13.1L10 19.1V16H4V4H20V16M16 11V9H11.5L13.3 7.2L12 6L8 10L12 14L13.2 12.8L11.5 11H16Z\";\r\nvar mdiCommentArrowRight = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M12 14L10.8 12.8L12.6 11H8V9H12.5L10.7 7.2L12 6L16 10L12 14Z\";\r\nvar mdiCommentArrowRightOutline = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H13.1L10 19.1V16H4V4H20V16M8 9V11H12.5L10.7 12.8L12 14L16 10L12 6L10.8 7.2L12.5 9H8Z\";\r\nvar mdiCommentBookmark = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M19 13L16.5 11.5L14 13V5H19V13Z\";\r\nvar mdiCommentBookmarkOutline = \"M9 22C8.4 22 8 21.6 8 21V18H4C2.9 18 2 17.1 2 16V4C2 2.9 2.9 2 4 2H20C21.1 2 22 2.9 22 4V16C22 17.1 21.1 18 20 18H13.9L10.2 21.7C10 21.9 9.8 22 9.5 22H9M10 16V19.1L13.1 16H20V4H4V16H10M18 14V6H13V14L15.5 12.5L18 14Z\";\r\nvar mdiCommentCheck = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,15L18,7L16.59,5.58L10,12.17L7.41,9.59L6,11L10,15Z\";\r\nvar mdiCommentCheckOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M16.5,8L11,13.5L7.5,10L8.91,8.59L11,10.67L15.09,6.59L16.5,8Z\";\r\nvar mdiCommentEdit = \"M20 2H4C2.89 2 2 2.89 2 4V16C2 17.11 2.9 18 4 18H8V21C8 21.55 8.45 22 9 22H9.5C9.75 22 10 21.9 10.2 21.71L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.89 21.1 2 20 2M9.08 15H7V12.91L13.17 6.72L15.24 8.8L9.08 15M16.84 7.2L15.83 8.21L13.76 6.18L14.77 5.16C14.97 4.95 15.31 4.94 15.55 5.16L16.84 6.41C17.05 6.62 17.06 6.96 16.84 7.2Z\";\r\nvar mdiCommentEditOutline = \"M9 22C8.45 22 8 21.55 8 21V18H4C2.9 18 2 17.11 2 16V4C2 2.89 2.9 2 4 2H20C21.11 2 22 2.9 22 4V16C22 17.11 21.11 18 20 18H13.9L10.2 21.71C10 21.9 9.75 22 9.5 22H9M10 16V19.08L13.08 16H20V4H4V16H10M15.84 8.2L14.83 9.21L12.76 7.18L13.77 6.16C13.97 5.95 14.31 5.94 14.55 6.16L15.84 7.41C16.05 7.62 16.06 7.96 15.84 8.2M8 11.91L12.17 7.72L14.24 9.8L10.08 14H8V11.91Z\";\r\nvar mdiCommentEye = \"M20,12V16C20,17.11 19.11,18 18,18H13.9L10.2,21.71C10,21.89 9.76,22 9.5,22H9A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V6C2,4.89 2.9,4 4,4H9.5C8.95,4.67 8.5,5.42 8.14,6.25L7.85,7L8.14,7.75C9.43,10.94 12.5,13 16,13C17.44,13 18.8,12.63 20,12M16,6C16.56,6 17,6.44 17,7C17,7.56 16.56,8 16,8C15.44,8 15,7.56 15,7C15,6.44 15.44,6 16,6M16,3C18.73,3 21.06,4.66 22,7C21.06,9.34 18.73,11 16,11C13.27,11 10.94,9.34 10,7C10.94,4.66 13.27,3 16,3M16,4.5A2.5,2.5 0 0,0 13.5,7A2.5,2.5 0 0,0 16,9.5A2.5,2.5 0 0,0 18.5,7A2.5,2.5 0 0,0 16,4.5\";\r\nvar mdiCommentEyeOutline = \"M16,6C16.56,6 17,6.44 17,7C17,7.56 16.56,8 16,8C15.44,8 15,7.56 15,7C15,6.44 15.44,6 16,6M16,3C18.73,3 21.06,4.66 22,7C21.06,9.34 18.73,11 16,11C13.27,11 10.94,9.34 10,7C10.94,4.66 13.27,3 16,3M16,4.5A2.5,2.5 0 0,0 13.5,7A2.5,2.5 0 0,0 16,9.5A2.5,2.5 0 0,0 18.5,7A2.5,2.5 0 0,0 16,4.5M18,12.75V16H13.08L10,19.08V16H4V6H8.27C8.59,5.27 9,4.6 9.5,4H4A2,2 0 0,0 2,6V16C2,17.11 2.9,18 4,18H8V21A1,1 0 0,0 9,22H9.5C9.75,22 10,21.9 10.2,21.71L13.9,18H18C19.11,18 20,17.11 20,16V12C19.37,12.33 18.7,12.58 18,12.75Z\";\r\nvar mdiCommentFlash = \"M22.5 16H20.3L22 12H17V18H19V23L22.5 16M15 18H13.9L10.2 21.7C10 21.9 9.8 22 9.5 22H9C8.4 22 8 21.6 8 21V18H4C2.9 18 2 17.1 2 16V4C2 2.9 2.9 2 4 2H20C21.1 2 22 2.9 22 4V10H15V18Z\";\r\nvar mdiCommentFlashOutline = \"M22.5 16H20.3L22 12H17V18H19V23L22.5 16M15 18H13.9L10.2 21.7C10 21.9 9.8 22 9.5 22H9C8.4 22 8 21.6 8 21V18H4C2.9 18 2 17.1 2 16V4C2 2.9 2.9 2 4 2H20C21.1 2 22 2.9 22 4V10H20V4H4V16H10V19.1L13.1 16H15V18Z\";\r\nvar mdiCommentMinus = \"M20 2H4C2.9 2 2 2.89 2 4V16C2 17.11 2.9 18 4 18H8V21C8 21.55 8.45 22 9 22H9.5C9.75 22 10 21.9 10.2 21.71L13.9 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M16 11H8V9H16V11Z\";\r\nvar mdiCommentMinusOutline = \"M16 11H8V9H16V11M22 4V16C22 17.11 21.11 18 20 18H13.9L10.2 21.71C10 21.9 9.75 22 9.5 22H9C8.45 22 8 21.55 8 21V18H4C2.9 18 2 17.11 2 16V4C2 2.89 2.9 2 4 2H20C21.11 2 22 2.9 22 4M20 4H4V16H10V19.08L13.08 16H20V4\";\r\nvar mdiCommentMultiple = \"M12,23A1,1 0 0,1 11,22V19H7A2,2 0 0,1 5,17V7A2,2 0 0,1 7,5H21A2,2 0 0,1 23,7V17A2,2 0 0,1 21,19H16.9L13.2,22.71C13,22.89 12.76,23 12.5,23H12M3,15H1V3A2,2 0 0,1 3,1H19V3H3V15Z\";\r\nvar mdiCommentMultipleOutline = \"M12,23A1,1 0 0,1 11,22V19H7A2,2 0 0,1 5,17V7C5,5.89 5.9,5 7,5H21A2,2 0 0,1 23,7V17A2,2 0 0,1 21,19H16.9L13.2,22.71C13,22.9 12.75,23 12.5,23V23H12M13,17V20.08L16.08,17H21V7H7V17H13M3,15H1V3A2,2 0 0,1 3,1H19V3H3V15Z\";\r\nvar mdiCommentOff = \"M22.11 21.46L20.84 22.73L16.11 18H13.9L10.2 21.71C10 21.9 9.75 22 9.5 22H9C8.45 22 8 21.55 8 21V18H4C2.9 18 2 17.11 2 16V4 3.9L1.11 3L2.39 1.73L22.11 21.46M22 16V4C22 2.9 21.11 2 20 2H5.2L20.95 17.75C21.57 17.41 22 16.76 22 16Z\";\r\nvar mdiCommentOffOutline = \"M7.2 4L5.2 2H20C21.11 2 22 2.9 22 4V16C22 16.76 21.57 17.41 20.95 17.75L19.2 16H20V4H7.2M22.11 21.46L20.84 22.73L16.11 18H13.9L10.2 21.71C10 21.9 9.75 22 9.5 22H9C8.45 22 8 21.55 8 21V18H4C2.9 18 2 17.11 2 16V4C2 3.97 2 3.93 2 3.9L1.11 3L2.39 1.73L22.11 21.46M14.11 16L4 5.89V16H10V19.08L13.08 16H14.11Z\";\r\nvar mdiCommentOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10Z\";\r\nvar mdiCommentPlus = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22H9M11,6V9H8V11H11V14H13V11H16V9H13V6H11Z\";\r\nvar mdiCommentPlusOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M11,6H13V9H16V11H13V14H11V11H8V9H11V6Z\";\r\nvar mdiCommentProcessing = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M17,11V9H15V11H17M13,11V9H11V11H13M9,11V9H7V11H9Z\";\r\nvar mdiCommentProcessingOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M17,11H15V9H17V11M13,11H11V9H13V11M9,11H7V9H9V11Z\";\r\nvar mdiCommentQuestion = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2M12.19,5.5C11.3,5.5 10.59,5.68 10.05,6.04C9.5,6.4 9.22,7 9.27,7.69H11.24C11.24,7.41 11.34,7.2 11.5,7.06C11.7,6.92 11.92,6.85 12.19,6.85C12.5,6.85 12.77,6.93 12.95,7.11C13.13,7.28 13.22,7.5 13.22,7.8C13.22,8.08 13.14,8.33 13,8.54C12.83,8.76 12.62,8.94 12.36,9.08C11.84,9.4 11.5,9.68 11.29,9.92C11.1,10.16 11,10.5 11,11H13C13,10.72 13.05,10.5 13.14,10.32C13.23,10.15 13.4,10 13.66,9.85C14.12,9.64 14.5,9.36 14.79,9C15.08,8.63 15.23,8.24 15.23,7.8C15.23,7.1 14.96,6.54 14.42,6.12C13.88,5.71 13.13,5.5 12.19,5.5M11,12V14H13V12H11Z\";\r\nvar mdiCommentQuestionOutline = \"M4,2A2,2 0 0,0 2,4V16A2,2 0 0,0 4,18H8V21A1,1 0 0,0 9,22H9.5V22C9.75,22 10,21.9 10.2,21.71L13.9,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2H4M4,4H20V16H13.08L10,19.08V16H4V4M12.19,5.5C11.3,5.5 10.59,5.68 10.05,6.04C9.5,6.4 9.22,7 9.27,7.69C0.21,7.69 6.57,7.69 11.24,7.69C11.24,7.41 11.34,7.2 11.5,7.06C11.7,6.92 11.92,6.85 12.19,6.85C12.5,6.85 12.77,6.93 12.95,7.11C13.13,7.28 13.22,7.5 13.22,7.8C13.22,8.08 13.14,8.33 13,8.54C12.83,8.76 12.62,8.94 12.36,9.08C11.84,9.4 11.5,9.68 11.29,9.92C11.1,10.16 11,10.5 11,11H13C13,10.72 13.05,10.5 13.14,10.32C13.23,10.15 13.4,10 13.66,9.85C14.12,9.64 14.5,9.36 14.79,9C15.08,8.63 15.23,8.24 15.23,7.8C15.23,7.1 14.96,6.54 14.42,6.12C13.88,5.71 13.13,5.5 12.19,5.5M11,12V14H13V12H11Z\";\r\nvar mdiCommentQuote = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.1 2.9 18 4 18H8V21C8 21.6 8.4 22 9 22H9.5C9.7 22 10 21.9 10.2 21.7L13.9 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M11 13H7V8.8L8.3 6H10.3L8.9 9H11V13M17 13H13V8.8L14.3 6H16.3L14.9 9H17V13Z\";\r\nvar mdiCommentQuoteOutline = \"M9 22C8.4 22 8 21.6 8 21V18H4C2.9 18 2 17.1 2 16V4C2 2.9 2.9 2 4 2H20C21.1 2 22 2.9 22 4V16C22 17.1 21.1 18 20 18H13.9L10.2 21.7C10 21.9 9.8 22 9.5 22H9M10 16V19.1L13.1 16H20V4H4V16H10M16.3 6L14.9 9H17V13H13V8.8L14.3 6H16.3M10.3 6L8.9 9H11V13H7V8.8L8.3 6H10.3Z\";\r\nvar mdiCommentRemove = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M9.41,6L8,7.41L10.59,10L8,12.59L9.41,14L12,11.41L14.59,14L16,12.59L13.41,10L16,7.41L14.59,6L12,8.59L9.41,6Z\";\r\nvar mdiCommentRemoveOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M9.41,6L12,8.59L14.59,6L16,7.41L13.41,10L16,12.59L14.59,14L12,11.41L9.41,14L8,12.59L10.59,10L8,7.41L9.41,6Z\";\r\nvar mdiCommentSearch = \"M15.5,2C18,2 20,4 20,6.5C20,7.38 19.75,8.2 19.31,8.89L22.41,12L21,13.39L17.89,10.31C17.2,10.75 16.38,11 15.5,11C13,11 11,9 11,6.5C11,4 13,2 15.5,2M15.5,4A2.5,2.5 0 0,0 13,6.5A2.5,2.5 0 0,0 15.5,9A2.5,2.5 0 0,0 18,6.5A2.5,2.5 0 0,0 15.5,4M4,4H9.5C9.19,4.79 9,5.64 9,6.5A6.5,6.5 0 0,0 15.5,13C16.18,13 16.83,12.89 17.46,12.69L20,15.23V16A2,2 0 0,1 18,18H13.9L10.2,21.71C10,21.89 9.76,22 9.5,22H9A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V6A2,2 0 0,1 4,4Z\";\r\nvar mdiCommentSearchOutline = \"M4,4H9.5C9.25,4.64 9.09,5.31 9.04,6H4V16H10V19.08L13.08,16H18V13.23L20,15.23V16A2,2 0 0,1 18,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22H9A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V6C2,4.89 2.9,4 4,4M15.5,2C18,2 20,4 20,6.5C20,7.38 19.75,8.2 19.31,8.89L22.41,12L21,13.39L17.89,10.31C17.2,10.75 16.38,11 15.5,11C13,11 11,9 11,6.5C11,4 13,2 15.5,2M15.5,4A2.5,2.5 0 0,0 13,6.5A2.5,2.5 0 0,0 15.5,9A2.5,2.5 0 0,0 18,6.5A2.5,2.5 0 0,0 15.5,4Z\";\r\nvar mdiCommentText = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M5,5V7H19V5H5M5,9V11H13V9H5M5,13V15H15V13H5Z\";\r\nvar mdiCommentTextMultiple = \"M3,15H1V3A2,2 0 0,1 3,1H19V3H3V15M12,23A1,1 0 0,1 11,22V19H7A2,2 0 0,1 5,17V7A2,2 0 0,1 7,5H21A2,2 0 0,1 23,7V17A2,2 0 0,1 21,19H16.9L13.2,22.71C13,22.89 12.76,23 12.5,23H12M9,9V11H19V9H9M9,13V15H17V13H9Z\";\r\nvar mdiCommentTextMultipleOutline = \"M12,23A1,1 0 0,1 11,22V19H7A2,2 0 0,1 5,17V7A2,2 0 0,1 7,5H21A2,2 0 0,1 23,7V17A2,2 0 0,1 21,19H16.9L13.2,22.71C13,22.89 12.76,23 12.5,23H12M13,17V20.08L16.08,17H21V7H7V17H13M3,15H1V3A2,2 0 0,1 3,1H19V3H3V15M9,9H19V11H9V9M9,13H17V15H9V13Z\";\r\nvar mdiCommentTextOutline = \"M9,22A1,1 0 0,1 8,21V18H4A2,2 0 0,1 2,16V4C2,2.89 2.9,2 4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H13.9L10.2,21.71C10,21.9 9.75,22 9.5,22V22H9M10,16V19.08L13.08,16H20V4H4V16H10M6,7H18V9H6V7M6,11H15V13H6V11Z\";\r\nvar mdiCompare = \"M19,3H14V5H19V18L14,12V21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M10,18H5L10,12M10,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H10V23H12V1H10V3Z\";\r\nvar mdiCompareHorizontal = \"M9 14H2V16H9V19L13 15L9 11V14M15 13V10H22V8H15V5L11 9L15 13Z\";\r\nvar mdiCompareVertical = \"M14 15V22H16V15H19L15 11L11 15H14M13 9H10V2H8V9H5L9 13L13 9Z\";\r\nvar mdiCompass = \"M14.19,14.19L6,18L9.81,9.81L18,6M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,10.9A1.1,1.1 0 0,0 10.9,12A1.1,1.1 0 0,0 12,13.1A1.1,1.1 0 0,0 13.1,12A1.1,1.1 0 0,0 12,10.9Z\";\r\nvar mdiCompassOff = \"M1,3.5L2.28,2.25L21.75,21.72L20.5,23L17.7,20.22C16.08,21.34 14.12,22 12,22A10,10 0 0,1 2,12C2,9.88 2.66,7.92 3.78,6.3L1,3.5M6,18L12.47,15L9,11.53L6,18M18,6L11.56,9L6.33,3.76C7.94,2.65 9.9,2 12,2A10,10 0 0,1 22,12C22,14.1 21.35,16.06 20.24,17.67L15,12.44L18,6Z\";\r\nvar mdiCompassOffOutline = \"M1,3.5L2.28,2.25L21.75,21.72L20.5,23L17.7,20.22C16.08,21.34 14.12,22 12,22A10,10 0 0,1 2,12C2,9.88 2.66,7.92 3.78,6.3L1,3.5M7,17L9.39,11.91L5.23,7.74C4.45,9 4,10.44 4,12A8,8 0 0,0 12,20C13.56,20 15,19.55 16.26,18.77L12.09,14.61L7,17M17,7L14.62,12.05L11.95,9.38L17,7M12,2A10,10 0 0,1 22,12C22,14.1 21.35,16.06 20.24,17.67L18.8,16.22C19.56,15 20,13.55 20,12A8,8 0 0,0 12,4C10.45,4 9,4.44 7.78,5.2L6.33,3.76C7.94,2.65 9.9,2 12,2Z\";\r\nvar mdiCompassOutline = \"M7,17L10.2,10.2L17,7L13.8,13.8L7,17M12,11.1A0.9,0.9 0 0,0 11.1,12A0.9,0.9 0 0,0 12,12.9A0.9,0.9 0 0,0 12.9,12A0.9,0.9 0 0,0 12,11.1M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiCompassRose = \"M15 9L12 0L9 9L0 12L9 15L12 24L15 15L24 12L15 9M4 12L10 10L11 12H4M12 20L10 14L12 13V20M12 4L14 10L12 11V4M14 14L13 12H20L14 14M8.7 17.3L5 19L6.7 15.3L8.3 15.8L8.7 17.3M17.3 15.3L19 19L15.3 17.3L15.8 15.7L17.3 15.3M6.7 8.7L5 5L8.7 6.7L8.2 8.2L6.7 8.7M15.3 6.7L19 5L17.3 8.7L15.7 8.2L15.3 6.7Z\";\r\nvar mdiConcourseCi = \"M10.94 12.09A1.06 1.06 0 1 0 11.91 10.95A1.06 1.06 0 0 0 10.94 12.09M13.54 13.21A2.62 2.62 0 0 1 12.58 13.88L12.57 13.89A11.17 11.17 0 0 0 13.87 16.92A4.83 4.83 0 0 1 12.92 17.3A4.9 4.9 0 0 1 12.24 17.44L12.16 17.45L12.06 17.46L11.87 17.47C11.75 17.47 11.64 17.5 11.5 17.47A5 5 0 0 1 10.79 17.4A5.13 5.13 0 0 1 10.09 17.23A4.78 4.78 0 0 1 9.46 17A5 5 0 0 1 8.93 16.68A4.45 4.45 0 0 1 8.5 16.38C8.38 16.29 8.28 16.19 8.2 16.12L7.95 15.87C7.95 15.87 8 15.97 8.16 16.15C8.24 16.23 8.32 16.34 8.44 16.45A4.93 4.93 0 0 0 8.82 16.82A5.21 5.21 0 0 0 9.33 17.2A5.08 5.08 0 0 0 9.96 17.56A5.43 5.43 0 0 0 10.68 17.85A5.5 5.5 0 0 0 11.46 18.03C11.6 18.06 11.74 18.07 11.88 18.08L12.07 18.1H12.27A5.5 5.5 0 0 0 13.07 18.05A5.61 5.61 0 0 0 14.39 17.7Q14.63 18.03 14.9 18.34L14.87 18.36L14.66 18.5H14.62C14.59 18.53 14.67 18.5 14.66 18.5H14.64L14.58 18.54L14.44 18.61L14.37 18.64L14.33 18.66L14.32 18.67H14.31C14.3 18.68 14.36 18.66 14.33 18.67H14.32L14.17 18.74Q14.09 18.77 14 18.81V18.82L13.93 18.84L13.84 18.87A6.5 6.5 0 0 1 12.25 19.26A6.4 6.4 0 0 1 11.31 19.3H11.19L11.07 19.29L10.81 19.27C10.65 19.24 10.5 19.23 10.33 19.2A6.59 6.59 0 0 1 8.5 18.57C8.35 18.5 8.21 18.43 8.08 18.35C7.95 18.27 7.83 18.19 7.71 18.11A6.64 6.64 0 0 1 7.07 17.6A6.35 6.35 0 0 1 6.57 17.11C6.43 16.96 6.32 16.82 6.22 16.7C6.13 16.58 6.06 16.5 6 16.42L5.94 16.32L6 16.43C6.04 16.5 6.1 16.6 6.18 16.73C6.26 16.86 6.36 17 6.5 17.18A6.5 6.5 0 0 0 6.94 17.73A6.86 6.86 0 0 0 7.55 18.31C7.67 18.41 7.78 18.5 7.91 18.6C8.04 18.7 8.17 18.79 8.31 18.88A7.12 7.12 0 0 0 9.21 19.37A7.2 7.2 0 0 0 10.2 19.74C10.37 19.8 10.55 19.83 10.73 19.87L11 19.92L11.11 19.94L11.25 19.96A7.27 7.27 0 0 0 12.29 20.03A7.38 7.38 0 0 0 14.14 19.77L14.23 19.74L14.28 19.73L14.34 19.71C14.4 19.69 14.46 19.68 14.5 19.66L14.68 19.6L14.85 19.54L15 19.5L15.06 19.45H15.08L15.13 19.43L15.14 19.42L15.17 19.41L15.39 19.3L15.67 19.16C15.86 19.34 16.06 19.5 16.26 19.69C16.26 19.69 17.23 20.69 17.76 20.28C18.26 19.89 17.68 18.68 17.68 18.68A11.2 11.2 0 0 0 13.54 13.21M10.16 11.57L10.15 11.56A11.18 11.18 0 0 0 6.91 11.11A4.72 4.72 0 0 1 7.34 9.39L7.38 9.31L7.42 9.23L7.5 9.06C7.57 8.96 7.62 8.85 7.69 8.75A4.97 4.97 0 0 1 8.14 8.17A5.05 5.05 0 0 1 8.66 7.67A4.77 4.77 0 0 1 9.2 7.27A5.06 5.06 0 0 1 9.74 7A4.88 4.88 0 0 1 10.22 6.78C10.37 6.72 10.5 6.69 10.61 6.66C10.82 6.6 10.95 6.58 10.95 6.58S10.82 6.59 10.6 6.61C10.5 6.63 10.35 6.64 10.19 6.68A4.94 4.94 0 0 0 9.67 6.82A5.34 5.34 0 0 0 9.08 7.05A5.08 5.08 0 0 0 8.45 7.39A5.47 5.47 0 0 0 7.82 7.84A5.55 5.55 0 0 0 7.25 8.41C7.16 8.5 7.08 8.63 7 8.74L6.88 8.89L6.82 8.97L6.76 9.06A5.5 5.5 0 0 0 6.38 9.77A5.61 5.61 0 0 0 5.97 11.14L5.96 11.16C5.7 11.18 5.43 11.21 5.16 11.26V11.12L5.17 10.87V10.82C5.17 10.78 5.16 10.88 5.16 10.87V10.84L5.17 10.77L5.18 10.62L5.19 10.54V10.5H5.2V10.47C5.2 10.46 5.19 10.5 5.19 10.5L5.22 10.32L5.24 10.14L5.25 10.12V10.11L5.24 10.13L5.25 10.12V10.11L5.26 10.07L5.27 9.97A6.5 6.5 0 0 1 6.26 7.59L6.32 7.5L6.39 7.4L6.55 7.19C6.65 7.07 6.74 6.94 6.86 6.82A6.61 6.61 0 0 1 8.37 5.59C8.5 5.5 8.64 5.43 8.77 5.37C8.9 5.29 9.04 5.24 9.17 5.18A6.76 6.76 0 0 1 9.94 4.9A6.5 6.5 0 0 1 10.62 4.74C10.82 4.69 11 4.68 11.15 4.66C11.3 4.64 11.42 4.64 11.5 4.63L11.62 4.62H11.5C11.42 4.62 11.3 4.61 11.15 4.61C11 4.61 10.82 4.61 10.61 4.63A6.41 6.41 0 0 0 9.9 4.73A7.03 7.03 0 0 0 9.08 4.93C8.94 5 8.79 5.03 8.65 5.09C8.5 5.14 8.35 5.21 8.2 5.28A7.26 7.26 0 0 0 7.31 5.78A7.33 7.33 0 0 0 6.47 6.42C6.33 6.54 6.2 6.68 6.07 6.8L5.9 7L5.82 7.09L5.72 7.19A7.25 7.25 0 0 0 5.12 8.04A7.38 7.38 0 0 0 4.36 9.75L4.33 9.84L4.32 9.89L4.3 9.95L4.25 10.13L4.21 10.29L4.18 10.5L4.15 10.63C4.14 10.65 4.14 10.67 4.14 10.7L4.13 10.72V10.78L4.12 10.81L4.09 11.06L4.05 11.5C3.79 11.57 3.53 11.65 3.28 11.74C3.28 11.74 1.93 12.05 2 12.72C2.08 13.35 3.41 13.5 3.41 13.5A11.21 11.21 0 0 0 10.24 12.74A2.62 2.62 0 0 1 10.16 11.57M19.7 10.84A7.19 7.19 0 0 0 19.53 9.79C19.5 9.62 19.43 9.45 19.38 9.27L19.3 9.03L19.26 8.91L19.21 8.77A7.23 7.23 0 0 0 18.75 7.83A7.35 7.35 0 0 0 17.62 6.35L17.55 6.28L17.5 6.25L17.47 6.2L17.33 6.08L17.21 5.97L17.06 5.85L16.94 5.75L16.89 5.7L16.88 5.69H16.87L16.83 5.66L16.8 5.64L16.59 5.5L16.32 5.31Q16.42 4.88 16.5 4.45S16.88 3.11 16.25 2.85C15.67 2.61 14.91 3.72 14.91 3.72A11.21 11.21 0 0 0 12.25 10.05A2.63 2.63 0 0 1 13.32 10.55A11.2 11.2 0 0 0 15.25 8A4.73 4.73 0 0 1 16.08 8.66A4.81 4.81 0 0 1 16.53 9.19L16.58 9.25L16.63 9.33L16.74 9.5C16.8 9.59 16.86 9.69 16.92 9.8A4.89 4.89 0 0 1 17.4 11.16A4.78 4.78 0 0 1 17.5 11.83A4.88 4.88 0 0 1 17.5 12.44A4.76 4.76 0 0 1 17.44 12.96C17.42 13.11 17.39 13.25 17.36 13.36C17.31 13.57 17.27 13.7 17.27 13.7L17.41 13.37C17.45 13.26 17.5 13.14 17.54 13A5.06 5.06 0 0 0 17.67 12.46A5.34 5.34 0 0 0 17.75 11.83A5.04 5.04 0 0 0 17.76 11.11A5.38 5.38 0 0 0 17.43 9.57C17.38 9.44 17.32 9.31 17.27 9.19L17.18 9L17.14 8.93L17.09 8.83A5.53 5.53 0 0 0 15.67 7.16C15.79 6.9 15.89 6.65 16 6.38L16.03 6.41L16.25 6.53L16.28 6.54V6.55H16.29C16.32 6.57 16.24 6.5 16.25 6.53H16.26L16.27 6.54L16.33 6.58L16.45 6.66L16.5 6.71L16.56 6.73L16.57 6.74H16.58L16.56 6.73H16.57L16.71 6.84L16.85 6.94L16.87 6.96L16.86 6.95L16.87 6.96L16.91 7L17 7.05A6.46 6.46 0 0 1 18.6 9.05L18.65 9.15L18.71 9.27L18.82 9.5C18.87 9.65 18.94 9.79 19 9.95A6.69 6.69 0 0 1 19.24 10.9A6.78 6.78 0 0 1 19.35 11.86C19.36 12 19.36 12.17 19.35 12.32C19.35 12.5 19.34 12.62 19.33 12.77A6.79 6.79 0 0 1 19.2 13.58A6.4 6.4 0 0 1 19 14.25C18.96 14.45 18.89 14.62 18.84 14.76C18.78 14.9 18.73 15 18.7 15.07L18.64 15.19L18.71 15.08C18.75 15 18.81 14.91 18.88 14.78C18.95 14.64 19.04 14.5 19.12 14.29A6.5 6.5 0 0 0 19.37 13.62A6.93 6.93 0 0 0 19.59 12.81C19.61 12.66 19.64 12.5 19.66 12.35C19.68 12.19 19.7 12.03 19.7 11.87A7.1 7.1 0 0 0 19.69 10.84\";\r\nvar mdiConnection = \"M21.4 7.5C22.2 8.3 22.2 9.6 21.4 10.3L18.6 13.1L10.8 5.3L13.6 2.5C14.4 1.7 15.7 1.7 16.4 2.5L18.2 4.3L21.2 1.3L22.6 2.7L19.6 5.7L21.4 7.5M15.6 13.3L14.2 11.9L11.4 14.7L9.3 12.6L12.1 9.8L10.7 8.4L7.9 11.2L6.4 9.8L3.6 12.6C2.8 13.4 2.8 14.7 3.6 15.4L5.4 17.2L1.4 21.2L2.8 22.6L6.8 18.6L8.6 20.4C9.4 21.2 10.7 21.2 11.4 20.4L14.2 17.6L12.8 16.2L15.6 13.3Z\";\r\nvar mdiConsole = \"M20,19V7H4V19H20M20,3A2,2 0 0,1 22,5V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V5C2,3.89 2.9,3 4,3H20M13,17V15H18V17H13M9.58,13L5.57,9H8.4L11.7,12.3C12.09,12.69 12.09,13.33 11.7,13.72L8.42,17H5.59L9.58,13Z\";\r\nvar mdiConsoleLine = \"M13,19V16H21V19H13M8.5,13L2.47,7H6.71L11.67,11.95C12.25,12.54 12.25,13.5 11.67,14.07L6.74,19H2.5L8.5,13Z\";\r\nvar mdiConsoleNetwork = \"M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7A2,2 0 0,1 5,15V5A2,2 0 0,1 7,3H17M7,7L11,11L7,15H9.85L13.13,11.72C13.5,11.33 13.5,10.7 13.13,10.3L9.83,7H7M17,13H14V15H17V13Z\";\r\nvar mdiConsoleNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M8,6.89L11.56,10.45L8,14H10.53L13.45,11.08C13.78,10.74 13.78,10.18 13.45,9.82L10.5,6.89H8M16,12.22H13.33V14H16V12.22Z\";\r\nvar mdiConsolidate = \"M18 9H20V4H22V9A2 2 0 0 1 20 11H18V13L15 10L18 7M14 10A2 2 0 1 0 12 12A2 2 0 0 0 14 10M2 11V16H4V11H6V13L9 10L6 7V9H4A2 2 0 0 0 2 11M15 16L12 13L9 16H11V18A2 2 0 0 0 13 20H18V18H13V16\";\r\nvar mdiContactlessPayment = \"M16.79,23C16.37,22.83 16.07,22.45 16,22C15.95,21.74 16,21.56 16.4,20.84C17.9,18.14 18.67,15.09 18.63,12C18.67,9 17.94,6.07 16.5,3.44C16.29,3 16.1,2.58 15.94,2.13C16,1.75 16.19,1.4 16.5,1.19C16.95,0.95 17.5,1 17.91,1.28C18.19,1.64 18.43,2 18.63,2.42C19.71,4.5 20.44,6.7 20.8,9C21.03,10.81 21.06,12.65 20.89,14.47C20.58,16.81 19.89,19.07 18.83,21.18C18.19,22.46 17.83,23 17.45,23C17.37,23 17.28,23 17.2,23C17.06,23 16.93,23 16.79,23V23M12.43,20.79C11.86,20.63 11.5,20.05 11.62,19.47C11.62,19.35 11.93,18.8 12.21,18.24C13.39,15.97 13.9,13.41 13.67,10.86C13.53,9.03 13,7.25 12.13,5.64C11.5,4.38 11.46,4.18 11.83,3.64C12.27,3.15 13,3.08 13.54,3.5C14.26,4.56 14.83,5.72 15.25,6.94C16.53,10.73 16.33,14.86 14.69,18.5C13.85,20.39 13.26,21 12.43,20.74V20.79M7.93,18.56C7.57,18.4 7.3,18.08 7.2,17.7C7.2,17.5 7.2,17.24 7.65,16.44C9.14,13.74 9.14,10.46 7.65,7.76C7,6.5 7,6.24 7.53,5.76C7.72,5.54 8,5.43 8.3,5.47C8.94,5.47 9.3,5.78 9.84,6.91C10.69,8.47 11.13,10.22 11.12,12C11.16,13.81 10.72,15.61 9.85,17.2C9.31,18.25 9.04,18.5 8.5,18.59C8.31,18.61 8.11,18.59 7.93,18.5V18.56M3.72,16.43C3.39,16.27 3.13,16 3,15.65C2.9,15.3 3,15 3.4,14.36C3.9,13.68 4.14,12.84 4.09,12C4.16,11.15 3.93,10.31 3.44,9.61C3.27,9.36 3.13,9.09 3,8.82C2.89,8.19 3.31,7.59 4,7.47C4.54,7.37 4.92,7.6 5.42,8.36C6.87,10.57 6.87,13.42 5.42,15.63C4.91,16.4 4.33,16.63 3.73,16.43H3.72Z\";\r\nvar mdiContactlessPaymentCircle = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M8.43 14.44L7.07 13.83C7.35 13.27 7.5 12.67 7.5 12.05C7.5 11.39 7.35 10.76 7.07 10.17L8.43 9.56C8.81 10.37 9 11.2 9 12.05C9 12.8 8.81 13.6 8.43 14.44M11.53 15.94L10.22 15.29C10.75 14.16 11 13 11 11.86C11 10.73 10.75 9.69 10.22 8.71L11.53 7.96C12.19 9.12 12.5 10.42 12.5 11.86C12.5 13.33 12.19 14.69 11.53 15.94M14.68 17.35L13.31 16.65C14.1 15.11 14.5 13.57 14.5 12S14.1 8.87 13.31 7.31L14.68 6.65C15.55 8.43 16 10.22 16 12C16 13.82 15.55 15.6 14.68 17.35Z\";\r\nvar mdiContactlessPaymentCircleOutline = \"M12 4C16.41 4 20 7.59 20 12S16.41 20 12 20 4 16.41 4 12 7.59 4 12 4M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M8.43 14.44L7.07 13.83C7.35 13.27 7.5 12.67 7.5 12.05C7.5 11.39 7.35 10.76 7.07 10.17L8.43 9.56C8.81 10.37 9 11.2 9 12.05C9 12.8 8.81 13.6 8.43 14.44M11.53 15.94L10.22 15.29C10.75 14.16 11 13 11 11.86C11 10.73 10.75 9.69 10.22 8.71L11.53 7.96C12.19 9.12 12.5 10.42 12.5 11.86C12.5 13.33 12.19 14.69 11.53 15.94M14.68 17.35L13.31 16.65C14.1 15.11 14.5 13.57 14.5 12S14.1 8.87 13.31 7.31L14.68 6.65C15.55 8.43 16 10.22 16 12C16 13.82 15.55 15.6 14.68 17.35Z\";\r\nvar mdiContacts = \"M20,0H4V2H20V0M4,24H20V22H4V24M20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6A2,2 0 0,0 20,4M12,6.75A2.25,2.25 0 0,1 14.25,9A2.25,2.25 0 0,1 12,11.25A2.25,2.25 0 0,1 9.75,9A2.25,2.25 0 0,1 12,6.75M17,17H7V15.5C7,13.83 10.33,13 12,13C13.67,13 17,13.83 17,15.5V17Z\";\r\nvar mdiContactsOutline = \"M20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4M20 18H4V6H20V18M4 0H20V2H4M4 22H20V24H4M12 12C13.38 12 14.5 10.88 14.5 9.5S13.38 7 12 7 9.5 8.12 9.5 9.5 10.62 12 12 12M12 8.5C12.55 8.5 13 8.95 13 9.5S12.55 10.5 12 10.5 11 10.05 11 9.5 11.45 8.5 12 8.5M17 16C17 13.9 13.69 13 12 13S7 13.9 7 16V17H17V16M8.81 15.5C9.42 15 10.84 14.5 12 14.5C13.17 14.5 14.59 15 15.2 15.5H8.81Z\";\r\nvar mdiContain = \"M2,3H8V5H4V19H8V21H2V3M7,17V15H9V17H7M11,17V15H13V17H11M15,17V15H17V17H15M22,3V21H16V19H20V5H16V3H22Z\";\r\nvar mdiContainEnd = \"M7,17V15H9V17H7M11,17V15H13V17H11M15,17V15H17V17H15M22,3V21H16V19H20V5H16V3H22Z\";\r\nvar mdiContainStart = \"M2,3H8V5H4V19H8V21H2V3M7,17V15H9V17H7M11,17V15H13V17H11M15,17V15H17V17H15Z\";\r\nvar mdiContentCopy = \"M19,21H8V7H19M19,5H8A2,2 0 0,0 6,7V21A2,2 0 0,0 8,23H19A2,2 0 0,0 21,21V7A2,2 0 0,0 19,5M16,1H4A2,2 0 0,0 2,3V17H4V3H16V1Z\";\r\nvar mdiContentCut = \"M19,3L13,9L15,11L22,4V3M12,12.5A0.5,0.5 0 0,1 11.5,12A0.5,0.5 0 0,1 12,11.5A0.5,0.5 0 0,1 12.5,12A0.5,0.5 0 0,1 12,12.5M6,20A2,2 0 0,1 4,18C4,16.89 4.9,16 6,16A2,2 0 0,1 8,18C8,19.11 7.1,20 6,20M6,8A2,2 0 0,1 4,6C4,4.89 4.9,4 6,4A2,2 0 0,1 8,6C8,7.11 7.1,8 6,8M9.64,7.64C9.87,7.14 10,6.59 10,6A4,4 0 0,0 6,2A4,4 0 0,0 2,6A4,4 0 0,0 6,10C6.59,10 7.14,9.87 7.64,9.64L10,12L7.64,14.36C7.14,14.13 6.59,14 6,14A4,4 0 0,0 2,18A4,4 0 0,0 6,22A4,4 0 0,0 10,18C10,17.41 9.87,16.86 9.64,16.36L12,14L19,21H22V20L9.64,7.64Z\";\r\nvar mdiContentDuplicate = \"M11,17H4A2,2 0 0,1 2,15V3A2,2 0 0,1 4,1H16V3H4V15H11V13L15,16L11,19V17M19,21V7H8V13H6V7A2,2 0 0,1 8,5H19A2,2 0 0,1 21,7V21A2,2 0 0,1 19,23H8A2,2 0 0,1 6,21V19H8V21H19Z\";\r\nvar mdiContentPaste = \"M19,20H5V4H7V7H17V4H19M12,2A1,1 0 0,1 13,3A1,1 0 0,1 12,4A1,1 0 0,1 11,3A1,1 0 0,1 12,2M19,2H14.82C14.4,0.84 13.3,0 12,0C10.7,0 9.6,0.84 9.18,2H5A2,2 0 0,0 3,4V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V4A2,2 0 0,0 19,2Z\";\r\nvar mdiContentSave = \"M15,9H5V5H15M12,19A3,3 0 0,1 9,16A3,3 0 0,1 12,13A3,3 0 0,1 15,16A3,3 0 0,1 12,19M17,3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V7L17,3Z\";\r\nvar mdiContentSaveAlert = \"M13 9H3V5H13M10 19C8.3 19 7 17.7 7 16S8.3 13 10 13 13 14.3 13 16 11.7 19 10 19M15 3H3C1.9 3 1 3.9 1 5V19C1 20.1 1.9 21 3 21H17C18.1 21 19 20.1 19 19V7L15 3M23 14H21V7H23V14M23 18H21V16H23V18Z\";\r\nvar mdiContentSaveAlertOutline = \"M15 3H3C1.9 3 1 3.9 1 5V19C1 20.1 1.9 21 3 21H17C18.1 21 19 20.1 19 19V7L15 3M17 19H3V5H14.2L17 7.8V19M10 12C8.3 12 7 13.3 7 15S8.3 18 10 18 13 16.7 13 15 11.7 12 10 12M4 6H13V10H4V6M23 14H21V7H23V14M23 18H21V16H23V18Z\";\r\nvar mdiContentSaveAll = \"M17,7V3H7V7H17M14,17A3,3 0 0,0 17,14A3,3 0 0,0 14,11A3,3 0 0,0 11,14A3,3 0 0,0 14,17M19,1L23,5V17A2,2 0 0,1 21,19H7C5.89,19 5,18.1 5,17V3A2,2 0 0,1 7,1H19M1,7H3V21H17V23H3A2,2 0 0,1 1,21V7Z\";\r\nvar mdiContentSaveAllOutline = \"M1 7H3V21H17V23H3C1.9 23 1 22.11 1 21V7M19 1H7C5.89 1 5 1.9 5 3V17C5 18.1 5.89 19 7 19H21C22.1 19 23 18.1 23 17V5L19 1M21 17H7V3H18.17L21 5.83V17M14 10C12.34 10 11 11.34 11 13S12.34 16 14 16 17 14.66 17 13 15.66 10 14 10M8 4H17V8H8V4Z\";\r\nvar mdiContentSaveCog = \"M21 11.7V7L17 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H11.7C11.4 20.3 11.2 19.6 11.1 18.8C9.9 18.4 9 17.3 9 16C9 14.3 10.3 13 12 13C12.3 13 12.6 13.1 12.9 13.2C14.2 11.8 16 11 18 11C19.1 11 20.1 11.2 21 11.7M15 9H5V5H15V9M21.7 18.6V17.6L22.8 16.8C22.9 16.7 23 16.6 22.9 16.5L21.9 14.8C21.9 14.7 21.7 14.7 21.6 14.7L20.4 15.2C20.1 15 19.8 14.8 19.5 14.7L19.3 13.4C19.3 13.3 19.2 13.2 19.1 13.2H17.1C16.9 13.2 16.8 13.3 16.8 13.4L16.6 14.7C16.3 14.9 16.1 15 15.8 15.2L14.6 14.7C14.5 14.7 14.4 14.7 14.3 14.8L13.3 16.5C13.3 16.6 13.3 16.7 13.4 16.8L14.5 17.6V18.6L13.4 19.4C13.3 19.5 13.2 19.6 13.3 19.7L14.3 21.4C14.4 21.5 14.5 21.5 14.6 21.5L15.8 21C16 21.2 16.3 21.4 16.6 21.5L16.8 22.8C16.9 22.9 17 23 17.1 23H19.1C19.2 23 19.3 22.9 19.3 22.8L19.5 21.5C19.8 21.3 20 21.2 20.3 21L21.5 21.4C21.6 21.4 21.7 21.4 21.8 21.3L22.8 19.6C22.9 19.5 22.9 19.4 22.8 19.4L21.7 18.6M18 19.5C17.2 19.5 16.5 18.8 16.5 18S17.2 16.5 18 16.5 19.5 17.2 19.5 18 18.8 19.5 18 19.5Z\";\r\nvar mdiContentSaveCogOutline = \"M11.1 19C11.2 19.7 11.4 20.4 11.7 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H17L21 7V11.7C20.4 11.4 19.7 11.2 19 11.1V7.8L16.2 5H5V19H11.1M12 12C10.3 12 9 13.3 9 15C9 16.3 9.8 17.4 11 17.8C11.1 15.6 12.1 13.7 13.7 12.5C13.2 12.2 12.6 12 12 12M15 10V6H6V10H15M22.8 19.6L21.8 21.3C21.7 21.4 21.6 21.4 21.5 21.4L20.3 21C20 21.2 19.8 21.3 19.5 21.5L19.3 22.8C19.3 22.9 19.2 23 19.1 23H17.1C17 23 16.9 22.9 16.8 22.8L16.6 21.5C16.3 21.4 16 21.2 15.8 21L14.6 21.5C14.5 21.5 14.4 21.5 14.3 21.4L13.3 19.7C13.2 19.6 13.3 19.5 13.4 19.4L14.5 18.6V17.6L13.4 16.8C13.3 16.7 13.3 16.6 13.3 16.5L14.3 14.8C14.4 14.7 14.5 14.7 14.6 14.7L15.8 15.2C16.1 15 16.3 14.9 16.6 14.7L16.8 13.4C16.8 13.3 16.9 13.2 17.1 13.2H19.1C19.2 13.2 19.3 13.3 19.3 13.4L19.5 14.7C19.8 14.8 20.1 15 20.4 15.2L21.6 14.7C21.7 14.7 21.9 14.7 21.9 14.8L22.9 16.5C23 16.6 22.9 16.7 22.8 16.8L21.7 17.6V18.6L22.8 19.4C22.9 19.4 22.9 19.5 22.8 19.6M19.5 18C19.5 17.2 18.8 16.5 18 16.5S16.5 17.2 16.5 18 17.2 19.5 18 19.5C18.8 19.5 19.5 18.8 19.5 18Z\";\r\nvar mdiContentSaveEdit = \"M10,19L10.14,18.86C8.9,18.5 8,17.36 8,16A3,3 0 0,1 11,13C12.36,13 13.5,13.9 13.86,15.14L20,9V7L16,3H4C2.89,3 2,3.9 2,5V19A2,2 0 0,0 4,21H10V19M4,5H14V9H4V5M20.04,12.13C19.9,12.13 19.76,12.19 19.65,12.3L18.65,13.3L20.7,15.35L21.7,14.35C21.92,14.14 21.92,13.79 21.7,13.58L20.42,12.3C20.31,12.19 20.18,12.13 20.04,12.13M18.07,13.88L12,19.94V22H14.06L20.12,15.93L18.07,13.88Z\";\r\nvar mdiContentSaveEditOutline = \"M4 19H10V21H4C2.89 21 2 20.1 2 19V5C2 3.9 2.89 3 4 3H16L20 7V9.12L18 11.12V7.83L15.17 5H4V19M14 10V6H5V10H14M20.42 12.3C20.31 12.19 20.18 12.13 20.04 12.13C19.9 12.13 19.76 12.19 19.65 12.3L18.65 13.3L20.7 15.35L21.7 14.35C21.92 14.14 21.92 13.79 21.7 13.58L20.42 12.3M12 19.94V22H14.06L20.12 15.93L18.07 13.88L12 19.94M14 15C14 13.34 12.66 12 11 12S8 13.34 8 15 9.34 18 11 18C11.04 18 11.08 18 11.13 18L14 15.13C14 15.09 14 15.05 14 15\";\r\nvar mdiContentSaveMove = \"M17,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H11.81C11.42,20.34 11.17,19.6 11.07,18.84C9.5,18.31 8.66,16.6 9.2,15.03C9.61,13.83 10.73,13 12,13C12.44,13 12.88,13.1 13.28,13.29C15.57,11.5 18.83,11.59 21,13.54V7L17,3M15,9H5V5H15V9M13,17H17V14L22,18.5L17,23V20H13V17\";\r\nvar mdiContentSaveMoveOutline = \"M13 17H17V14L22 18.5L17 23V20H13V17M14 12.8C13.5 12.31 12.78 12 12 12C10.34 12 9 13.34 9 15C9 16.31 9.84 17.41 11 17.82C11.07 15.67 12.27 13.8 14 12.8M11.09 19H5V5H16.17L19 7.83V12.35C19.75 12.61 20.42 13 21 13.54V7L17 3H5C3.89 3 3 3.9 3 5V19C3 20.1 3.89 21 5 21H11.81C11.46 20.39 11.21 19.72 11.09 19M6 10H15V6H6V10Z\";\r\nvar mdiContentSaveOutline = \"M17 3H5C3.89 3 3 3.9 3 5V19C3 20.1 3.89 21 5 21H19C20.1 21 21 20.1 21 19V7L17 3M19 19H5V5H16.17L19 7.83V19M12 12C10.34 12 9 13.34 9 15S10.34 18 12 18 15 16.66 15 15 13.66 12 12 12M6 6H15V10H6V6Z\";\r\nvar mdiContentSaveSettings = \"M15,8V4H5V8H15M12,18A3,3 0 0,0 15,15A3,3 0 0,0 12,12A3,3 0 0,0 9,15A3,3 0 0,0 12,18M17,2L21,6V18A2,2 0 0,1 19,20H5C3.89,20 3,19.1 3,18V4A2,2 0 0,1 5,2H17M11,22H13V24H11V22M7,22H9V24H7V22M15,22H17V24H15V22Z\";\r\nvar mdiContentSaveSettingsOutline = \"M7 22H9V24H7V22M11 22H13V24H11V22M15 22H17V24H15V22M17 2H5C3.89 2 3 2.9 3 4V18C3 19.1 3.89 20 5 20H19C20.1 20 21 19.1 21 18V6L17 2M19 18H5V4H16.17L19 6.83V18M12 11C10.34 11 9 12.34 9 14S10.34 17 12 17 15 15.66 15 14 13.66 11 12 11M6 5H15V9H6V5Z\";\r\nvar mdiContrast = \"M4.38,20.9C3.78,20.71 3.3,20.23 3.1,19.63L19.63,3.1C20.23,3.3 20.71,3.78 20.9,4.38L4.38,20.9M20,16V18H13V16H20M3,6H6V3H8V6H11V8H8V11H6V8H3V6Z\";\r\nvar mdiContrastBox = \"M17,15.5H12V17H17M19,19H5L19,5M5.5,7.5H7.5V5.5H9V7.5H11V9H9V11H7.5V9H5.5M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiContrastCircle = \"M12,20C9.79,20 7.79,19.1 6.34,17.66L17.66,6.34C19.1,7.79 20,9.79 20,12A8,8 0 0,1 12,20M6,8H8V6H9.5V8H11.5V9.5H9.5V11.5H8V9.5H6M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,16H17V14.5H12V16Z\";\r\nvar mdiControllerClassic = \"M6,7H18A5,5 0 0,1 23,12A5,5 0 0,1 18,17C16.36,17 14.91,16.21 14,15H10C9.09,16.21 7.64,17 6,17A5,5 0 0,1 1,12A5,5 0 0,1 6,7M19.75,9.5A1.25,1.25 0 0,0 18.5,10.75A1.25,1.25 0 0,0 19.75,12A1.25,1.25 0 0,0 21,10.75A1.25,1.25 0 0,0 19.75,9.5M17.25,12A1.25,1.25 0 0,0 16,13.25A1.25,1.25 0 0,0 17.25,14.5A1.25,1.25 0 0,0 18.5,13.25A1.25,1.25 0 0,0 17.25,12M5,9V11H3V13H5V15H7V13H9V11H7V9H5Z\";\r\nvar mdiControllerClassicOutline = \"M17.5,7A5.5,5.5 0 0,1 23,12.5A5.5,5.5 0 0,1 17.5,18C15.79,18 14.27,17.22 13.26,16H10.74C9.73,17.22 8.21,18 6.5,18A5.5,5.5 0 0,1 1,12.5A5.5,5.5 0 0,1 6.5,7H17.5M6.5,9A3.5,3.5 0 0,0 3,12.5A3.5,3.5 0 0,0 6.5,16C7.9,16 9.1,15.18 9.66,14H14.34C14.9,15.18 16.1,16 17.5,16A3.5,3.5 0 0,0 21,12.5A3.5,3.5 0 0,0 17.5,9H6.5M5.75,10.25H7.25V11.75H8.75V13.25H7.25V14.75H5.75V13.25H4.25V11.75H5.75V10.25M16.75,12.5A1,1 0 0,1 17.75,13.5A1,1 0 0,1 16.75,14.5A1,1 0 0,1 15.75,13.5A1,1 0 0,1 16.75,12.5M18.75,10.5A1,1 0 0,1 19.75,11.5A1,1 0 0,1 18.75,12.5A1,1 0 0,1 17.75,11.5A1,1 0 0,1 18.75,10.5Z\";\r\nvar mdiCookie = \"M12,3A9,9 0 0,0 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12C21,11.5 20.96,11 20.87,10.5C20.6,10 20,10 20,10H18V9C18,8 17,8 17,8H15V7C15,6 14,6 14,6H13V4C13,3 12,3 12,3M9.5,6A1.5,1.5 0 0,1 11,7.5A1.5,1.5 0 0,1 9.5,9A1.5,1.5 0 0,1 8,7.5A1.5,1.5 0 0,1 9.5,6M6.5,10A1.5,1.5 0 0,1 8,11.5A1.5,1.5 0 0,1 6.5,13A1.5,1.5 0 0,1 5,11.5A1.5,1.5 0 0,1 6.5,10M11.5,11A1.5,1.5 0 0,1 13,12.5A1.5,1.5 0 0,1 11.5,14A1.5,1.5 0 0,1 10,12.5A1.5,1.5 0 0,1 11.5,11M16.5,13A1.5,1.5 0 0,1 18,14.5A1.5,1.5 0 0,1 16.5,16H16.5A1.5,1.5 0 0,1 15,14.5H15A1.5,1.5 0 0,1 16.5,13M11,16A1.5,1.5 0 0,1 12.5,17.5A1.5,1.5 0 0,1 11,19A1.5,1.5 0 0,1 9.5,17.5A1.5,1.5 0 0,1 11,16Z\";\r\nvar mdiCoolantTemperature = \"M11.5,1A1.5,1.5 0 0,0 10,2.5V14.5C9.37,14.97 9,15.71 9,16.5A2.5,2.5 0 0,0 11.5,19A2.5,2.5 0 0,0 14,16.5C14,15.71 13.63,15 13,14.5V13H17V11H13V9H17V7H13V5H17V3H13V2.5A1.5,1.5 0 0,0 11.5,1M0,15V17C0.67,17 0.79,17.21 1.29,17.71C1.79,18.21 2.67,19 4,19C5.33,19 6.21,18.21 6.71,17.71C6.82,17.59 6.91,17.5 7,17.41V15.16C6.21,15.42 5.65,15.93 5.29,16.29C4.79,16.79 4.67,17 4,17C3.33,17 3.21,16.79 2.71,16.29C2.21,15.79 1.33,15 0,15M16,15V17C16.67,17 16.79,17.21 17.29,17.71C17.79,18.21 18.67,19 20,19C21.33,19 22.21,18.21 22.71,17.71C23.21,17.21 23.33,17 24,17V15C22.67,15 21.79,15.79 21.29,16.29C20.79,16.79 20.67,17 20,17C19.33,17 19.21,16.79 18.71,16.29C18.21,15.79 17.33,15 16,15M8,20C6.67,20 5.79,20.79 5.29,21.29C4.79,21.79 4.67,22 4,22C3.33,22 3.21,21.79 2.71,21.29C2.35,20.93 1.79,20.42 1,20.16V22.41C1.09,22.5 1.18,22.59 1.29,22.71C1.79,23.21 2.67,24 4,24C5.33,24 6.21,23.21 6.71,22.71C7.21,22.21 7.33,22 8,22C8.67,22 8.79,22.21 9.29,22.71C9.73,23.14 10.44,23.8 11.5,23.96C11.66,24 11.83,24 12,24C13.33,24 14.21,23.21 14.71,22.71C15.21,22.21 15.33,22 16,22C16.67,22 16.79,22.21 17.29,22.71C17.79,23.21 18.67,24 20,24C21.33,24 22.21,23.21 22.71,22.71C22.82,22.59 22.91,22.5 23,22.41V20.16C22.21,20.42 21.65,20.93 21.29,21.29C20.79,21.79 20.67,22 20,22C19.33,22 19.21,21.79 18.71,21.29C18.21,20.79 17.33,20 16,20C14.67,20 13.79,20.79 13.29,21.29C12.79,21.79 12.67,22 12,22C11.78,22 11.63,21.97 11.5,21.92C11.22,21.82 11.05,21.63 10.71,21.29C10.21,20.79 9.33,20 8,20Z\";\r\nvar mdiCopyright = \"M10.08,10.86C10.13,10.53 10.24,10.24 10.38,10C10.5,9.74 10.72,9.53 10.97,9.37C11.21,9.22 11.5,9.15 11.88,9.14C12.11,9.15 12.32,9.19 12.5,9.27C12.71,9.36 12.89,9.5 13.03,9.63C13.17,9.78 13.28,9.96 13.37,10.16C13.46,10.36 13.5,10.58 13.5,10.8H15.3C15.28,10.33 15.19,9.9 15,9.5C14.85,9.12 14.62,8.78 14.32,8.5C14,8.22 13.66,8 13.24,7.84C12.82,7.68 12.36,7.61 11.85,7.61C11.2,7.61 10.63,7.72 10.15,7.95C9.67,8.18 9.27,8.5 8.95,8.87C8.63,9.26 8.39,9.71 8.24,10.23C8.09,10.75 8,11.29 8,11.87V12.14C8,12.72 8.08,13.26 8.23,13.78C8.38,14.3 8.62,14.75 8.94,15.13C9.26,15.5 9.66,15.82 10.14,16.04C10.62,16.26 11.19,16.38 11.84,16.38C12.31,16.38 12.75,16.3 13.16,16.15C13.57,16 13.93,15.79 14.24,15.5C14.55,15.25 14.8,14.94 15,14.58C15.16,14.22 15.27,13.84 15.28,13.43H13.5C13.5,13.64 13.43,13.83 13.34,14C13.25,14.19 13.13,14.34 13,14.47C12.83,14.6 12.66,14.7 12.46,14.77C12.27,14.84 12.07,14.86 11.86,14.87C11.5,14.86 11.2,14.79 10.97,14.64C10.72,14.5 10.5,14.27 10.38,14C10.24,13.77 10.13,13.47 10.08,13.14C10.03,12.81 10,12.47 10,12.14V11.87C10,11.5 10.03,11.19 10.08,10.86M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20Z\";\r\nvar mdiCordova = \"M20.18,21.55H16.94L17.17,18.82H15.58L15.35,21.55H8.65L8.42,18.82H6.83L7.06,21.55H3.82L2,9.73L6.55,2.45H17.45L22,9.73L20.18,21.55M16.55,6.09H13.62L13.82,7.45H10.18L10.38,6.09H7.45L5.64,9.73L6.55,17H17.45L18.36,9.73L16.55,6.09M14.95,14.59C14.7,14.59 14.5,13.83 14.5,12.9C14.5,11.96 14.7,11.2 14.95,11.2C15.21,11.2 15.41,11.96 15.41,12.9C15.41,13.83 15.21,14.59 14.95,14.59M9.22,14.73C8.96,14.73 8.76,13.97 8.76,13.04C8.76,12.1 8.96,11.35 9.22,11.35C9.47,11.35 9.67,12.1 9.67,13.04C9.67,13.97 9.47,14.73 9.22,14.73Z\";\r\nvar mdiCorn = \"M11,12H8.82C9.62,12.5 10.35,13.07 11,13.68V12M7,11C7.27,5.88 9.37,2 12,2C14.66,2 16.77,5.94 17,11.12C18.5,10.43 20.17,10 22,10C16.25,12.57 18.25,22 12,22C6,22 7.93,12.57 2,10C3.82,10 5.5,10.4 7,11M11,11V9H8.24L8.03,11H11M11,8V6H9.05C8.8,6.6 8.6,7.27 8.43,8H11M11,5V3.3C10.45,3.63 9.95,4.22 9.5,5H11M12,3V5H13V6H12V8H14V9H12V11H15V12H12V14H14V15H12.23C13.42,16.45 14.15,18 14.32,19.23C15.31,17.56 15.96,14.84 16,11.76C15.94,7 14.13,3 12,3Z\";\r\nvar mdiCornOff = \"M22.1 21.5L2.4 1.7L1.1 3L7.2 9.1C7.1 9.7 7 10.3 7 11C5.5 10.4 3.8 10 2 10C7.9 12.6 6 22 12 22C14.5 22 15.7 20.5 16.6 18.5L20.9 22.8L22.1 21.5M8.1 10L9.1 11H8L8.1 10M8.8 12H10.1L11 12.9V13.7C10.3 13.1 9.6 12.5 8.8 12M14.3 19.2C14.1 18 13.4 16.4 12.2 15H13.1L15.2 17.1C15 17.9 14.7 18.6 14.3 19.2M11 6V7.8L12.2 9H14V8H12V6H13V5H12V3C14.1 3 15.9 7 16 11.8V12.8L18 14.8C18.8 12.8 19.9 10.9 22 10C20.2 10 18.5 10.4 17 11.1C16.8 5.9 14.7 2 12 2C10.5 2 9.2 3.2 8.3 5.1L9.2 6H11M11 3.3V5H9.5C10 4.2 10.5 3.6 11 3.3M15 11.8L14.2 11H15V11.8Z\";\r\nvar mdiCosineWave = \"M22 2V4C20.26 4 19 8.58 17.96 12.27C16.57 17.27 15.26 22 12 22C8.74 22 7.43 17.27 6.04 12.27C5 8.58 3.74 4 2 4V2C5.26 2 6.57 6.73 7.96 11.73C9 15.42 10.26 20 12 20C13.74 20 15 15.42 16.04 11.73C17.43 6.73 18.74 2 22 2Z\";\r\nvar mdiCounter = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H11V6H4M20,18V6H18.76C19,6.54 18.95,7.07 18.95,7.13C18.88,7.8 18.41,8.5 18.24,8.75L15.91,11.3L19.23,11.28L19.24,12.5L14.04,12.47L14,11.47C14,11.47 17.05,8.24 17.2,7.95C17.34,7.67 17.91,6 16.5,6C15.27,6.05 15.41,7.3 15.41,7.3L13.87,7.31C13.87,7.31 13.88,6.65 14.25,6H13V18H15.58L15.57,17.14L16.54,17.13C16.54,17.13 17.45,16.97 17.46,16.08C17.5,15.08 16.65,15.08 16.5,15.08C16.37,15.08 15.43,15.13 15.43,15.95H13.91C13.91,15.95 13.95,13.89 16.5,13.89C19.1,13.89 18.96,15.91 18.96,15.91C18.96,15.91 19,17.16 17.85,17.63L18.37,18H20M8.92,16H7.42V10.2L5.62,10.76V9.53L8.76,8.41H8.92V16Z\";\r\nvar mdiCow = \"M10.5,18A0.5,0.5 0 0,1 11,18.5A0.5,0.5 0 0,1 10.5,19A0.5,0.5 0 0,1 10,18.5A0.5,0.5 0 0,1 10.5,18M13.5,18A0.5,0.5 0 0,1 14,18.5A0.5,0.5 0 0,1 13.5,19A0.5,0.5 0 0,1 13,18.5A0.5,0.5 0 0,1 13.5,18M10,11A1,1 0 0,1 11,12A1,1 0 0,1 10,13A1,1 0 0,1 9,12A1,1 0 0,1 10,11M14,11A1,1 0 0,1 15,12A1,1 0 0,1 14,13A1,1 0 0,1 13,12A1,1 0 0,1 14,11M18,18C18,20.21 15.31,22 12,22C8.69,22 6,20.21 6,18C6,17.1 6.45,16.27 7.2,15.6C6.45,14.6 6,13.35 6,12L6.12,10.78C5.58,10.93 4.93,10.93 4.4,10.78C3.38,10.5 1.84,9.35 2.07,8.55C2.3,7.75 4.21,7.6 5.23,7.9C5.82,8.07 6.45,8.5 6.82,8.96L7.39,8.15C6.79,7.05 7,4 10,3L9.91,3.14V3.14C9.63,3.58 8.91,4.97 9.67,6.47C10.39,6.17 11.17,6 12,6C12.83,6 13.61,6.17 14.33,6.47C15.09,4.97 14.37,3.58 14.09,3.14L14,3C17,4 17.21,7.05 16.61,8.15L17.18,8.96C17.55,8.5 18.18,8.07 18.77,7.9C19.79,7.6 21.7,7.75 21.93,8.55C22.16,9.35 20.62,10.5 19.6,10.78C19.07,10.93 18.42,10.93 17.88,10.78L18,12C18,13.35 17.55,14.6 16.8,15.6C17.55,16.27 18,17.1 18,18M12,16C9.79,16 8,16.9 8,18C8,19.1 9.79,20 12,20C14.21,20 16,19.1 16,18C16,16.9 14.21,16 12,16M12,14C13.12,14 14.17,14.21 15.07,14.56C15.65,13.87 16,13 16,12A4,4 0 0,0 12,8A4,4 0 0,0 8,12C8,13 8.35,13.87 8.93,14.56C9.83,14.21 10.88,14 12,14M14.09,3.14V3.14Z\";\r\nvar mdiCpu32Bit = \"M9,3V5H7A2,2 0 0,0 5,7V9H3V11H5V13H3V15H5V17A2,2 0 0,0 7,19H9V21H11V19H13V21H15V19H17A2,2 0 0,0 19,17V15H21V13H19V11H21V9H19V7A2,2 0 0,0 17,5H15V3H13V5H11V3M7,9H10.5A1,1 0 0,1 11.5,10V14A1,1 0 0,1 10.5,15H7V13.5H10V12.75H8.5V11.25H10V10.5H7M12.5,9H16A1,1 0 0,1 17,10V11.75A1,1 0 0,1 16,12.75H14V13.5H17V15H12.5V12.25A1,1 0 0,1 13.5,11.25H15.5V10.5H12.5\";\r\nvar mdiCpu64Bit = \"M9,3V5H7A2,2 0 0,0 5,7V9H3V11H5V13H3V15H5V17A2,2 0 0,0 7,19H9V21H11V19H13V21H15V19H17A2,2 0 0,0 19,17V15H21V13H19V11H21V9H19V7A2,2 0 0,0 17,5H15V3H13V5H11V3M8,9H11.5V10.5H8.5V11.25H10.5A1,1 0 0,1 11.5,12.25V14A1,1 0 0,1 10.5,15H8A1,1 0 0,1 7,14V10A1,1 0 0,1 8,9M12.5,9H14V11H15.5V9H17V15H15.5V12.5H12.5M8.5,12.75V13.5H10V12.75\";\r\nvar mdiCrane = \"M20,6V5A1,1 0 0,0 19,4H9V3H6V4H5V6H6V15H5V13H3V15H2V17H3V21H5V17H10V21H12V19.92L12,17H13V15H12V13H10V15H9V6H17V10.62C16.53,10.79 16.19,11.23 16.19,11.76C16.19,12.2 16.43,12.6 16.8,12.82V14H17.42C17.76,14 18.03,14.28 18.03,14.62C18.03,14.96 17.76,15.24 17.42,15.24C17.2,15.24 17,15.12 16.89,14.93C16.71,14.64 16.34,14.54 16.05,14.71C15.75,14.87 15.65,15.25 15.82,15.55C16.15,16.11 16.76,16.47 17.42,16.47C18.43,16.47 19.26,15.64 19.26,14.62C19.26,13.84 18.76,13.14 18.03,12.88V12.82C18.41,12.6 18.65,12.2 18.65,11.76C18.65,11.3 18.38,10.91 18,10.7V6H20M8,13.66L7,14.66V13.24L8,12.24V13.66M8,10.71L7,11.71V10.29L8,9.29V10.71M7,8.71V7.29L8,6.29V7.71L7,8.71Z\";\r\nvar mdiCreation = \"M19,1L17.74,3.75L15,5L17.74,6.26L19,9L20.25,6.26L23,5L20.25,3.75M9,4L6.5,9.5L1,12L6.5,14.5L9,20L11.5,14.5L17,12L11.5,9.5M19,15L17.74,17.74L15,19L17.74,20.25L19,23L20.25,20.25L23,19L20.25,17.74\";\r\nvar mdiCreativeCommons = \"M11.89,10.34L10.55,11.04C10.41,10.74 10.24,10.53 10.03,10.41C9.82,10.29 9.62,10.23 9.45,10.23C8.55,10.23 8.11,10.82 8.11,12C8.11,12.54 8.22,12.97 8.45,13.29C8.67,13.61 9,13.77 9.45,13.77C10.03,13.77 10.44,13.5 10.68,12.91L11.91,13.54C11.65,14.03 11.29,14.41 10.82,14.69C10.36,14.97 9.85,15.11 9.29,15.11C8.39,15.11 7.67,14.84 7.12,14.29C6.58,13.74 6.3,13 6.3,12C6.3,11.05 6.58,10.3 7.13,9.74C7.69,9.18 8.39,8.9 9.23,8.9C10.47,8.89 11.36,9.38 11.89,10.34M17.66,10.34L16.34,11.04C16.2,10.74 16,10.53 15.81,10.41C15.6,10.29 15.4,10.23 15.21,10.23C14.32,10.23 13.87,10.82 13.87,12C13.87,12.54 14,12.97 14.21,13.29C14.44,13.61 14.77,13.77 15.21,13.77C15.8,13.77 16.21,13.5 16.45,12.91L17.7,13.54C17.42,14.03 17.05,14.41 16.59,14.69C16.12,14.97 15.62,15.11 15.07,15.11C14.17,15.11 13.44,14.84 12.9,14.29C12.36,13.74 12.09,13 12.09,12C12.09,11.05 12.37,10.3 12.92,9.74C13.47,9.18 14.17,8.9 15,8.9C16.26,8.89 17.14,9.38 17.66,10.34M12,3.5A8.5,8.5 0 0,1 20.5,12A8.5,8.5 0 0,1 12,20.5A8.5,8.5 0 0,1 3.5,12A8.5,8.5 0 0,1 12,3.5M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiCreditCard = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V6A2 2 0 0 0 20 4M20 11H4V8H20Z\";\r\nvar mdiCreditCardCheck = \"M20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.03 19.67 13 19.34 13 19C13 15.69 15.69 13 19 13C20.06 13 21.09 13.28 22 13.81V6C22 4.89 21.11 4 20 4M20 11H4V8H20M17.75 22L15 19L16.16 17.84L17.75 19.43L21.34 15.84L22.5 17.25L17.75 22\";\r\nvar mdiCreditCardCheckOutline = \"M13 19C13 18.66 13.04 18.33 13.09 18H3V12H19V13C19.7 13 20.37 13.13 21 13.35V6C21 4.89 20.11 4 19 4H3C1.89 4 1 4.89 1 6V18C1 19.1 1.89 20 3 20H13.09C13.04 19.67 13 19.34 13 19M3 6H19V8H3V6M17.75 22L15 19L16.16 17.84L17.75 19.43L21.34 15.84L22.5 17.25L17.75 22\";\r\nvar mdiCreditCardClock = \"M16,14H17.5V16.82L19.94,18.23L19.19,19.53L16,17.69V14M24,17A7,7 0 0,1 17,24C14.21,24 11.8,22.36 10.67,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H20A2,2 0 0,1 22,6V12.1C23.24,13.36 24,15.09 24,17M17,12A5,5 0 0,0 12,17A5,5 0 0,0 17,22A5,5 0 0,0 22,17A5,5 0 0,0 17,12M20,10V7H4V10H20Z\";\r\nvar mdiCreditCardClockOutline = \"M16,14H17.5V16.82L19.94,18.23L19.19,19.53L16,17.69V14M24,17A7,7 0 0,1 17,24C14.21,24 11.8,22.36 10.67,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H20A2,2 0 0,1 22,6V12.1C23.24,13.36 24,15.09 24,17M10,17C10,15.04 10.81,13.27 12.1,12H4V18H10.07C10,17.67 10,17.34 10,17M17,12A5,5 0 0,0 12,17A5,5 0 0,0 17,22A5,5 0 0,0 22,17A5,5 0 0,0 17,12M20,8V6H4V8H20Z\";\r\nvar mdiCreditCardMarker = \"M18.5 12C16.6 12 15 13.6 15 15.5C15 18.1 18.5 22 18.5 22S22 18.1 22 15.5C22 13.6 20.4 12 18.5 12M18.5 16.8C17.8 16.8 17.3 16.2 17.3 15.6C17.3 14.9 17.9 14.4 18.5 14.4S19.7 15 19.7 15.6C19.8 16.2 19.2 16.8 18.5 16.8M14.55 20H4C2.9 20 2 19.11 2 18V6C2 4.89 2.9 4 4 4H20C21.11 4 22 4.89 22 6V11.3C21.42 10.81 20.74 10.44 20 10.22V8H4V11H15.39C13.96 12 13 13.66 13 15.5C13 17 13.72 18.61 14.55 20Z\";\r\nvar mdiCreditCardMarkerOutline = \"M13.5,18H4V12H14.3C15.3,10.8 16.8,10 18.5,10C19.8,10 21,10.5 22,11.3V6A2,2 0 0,0 20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H14.6C14.2,19.4 13.8,18.7 13.5,18M4,6H20V8H4V6M18.5,12C16.6,12 15,13.6 15,15.5C15,18.1 18.5,22 18.5,22C18.5,22 22,18.1 22,15.5C22,13.6 20.4,12 18.5,12M18.5,16.8C17.8,16.8 17.3,16.2 17.3,15.6C17.3,14.9 17.9,14.4 18.5,14.4C19.1,14.4 19.7,15 19.7,15.6C19.8,16.2 19.2,16.8 18.5,16.8Z\";\r\nvar mdiCreditCardMinus = \"M20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13.09C13.03 19.67 13 19.34 13 19C13 15.69 15.69 13 19 13C20.06 13 21.09 13.28 22 13.81V6C22 4.89 21.11 4 20 4M20 11H4V8H20M23 18V20H15V18H23Z\";\r\nvar mdiCreditCardMinusOutline = \"M24 18V20H16V18M19 8V6H3V8H19M19 12H3V18H14V20H3C1.89 20 1 19.1 1 18V6C1 4.89 1.89 4 3 4H19C20.11 4 21 4.89 21 6V13H19V12Z\";\r\nvar mdiCreditCardMultiple = \"M21 9V6H7V9H21M21 3A2 2 0 0 1 23 5V15A2 2 0 0 1 21 17H7A2 2 0 0 1 5 15V5A2 2 0 0 1 7 3H21M3 19H18V21H3A2 2 0 0 1 1 19V8H3Z\";\r\nvar mdiCreditCardMultipleOutline = \"M21,8V6H7V8H21M21,16V11H7V16H21M21,4A2,2 0 0,1 23,6V16A2,2 0 0,1 21,18H7C5.89,18 5,17.1 5,16V6C5,4.89 5.89,4 7,4H21M3,20H18V22H3A2,2 0 0,1 1,20V9H3V20Z\";\r\nvar mdiCreditCardOff = \"M11.2 8L7.2 4H20A2 2 0 0 1 22 6V18A1.91 1.91 0 0 1 21.88 18.68L14.2 11H20V8M20.84 22.73L18.11 20H4A2 2 0 0 1 2 18V6A2 2 0 0 1 2.65 4.54L1.11 3L2.39 1.73L22.11 21.46M9.11 11L6.11 8H4V11Z\";\r\nvar mdiCreditCardOffOutline = \"M0.93,4.2L2.21,2.93L20,20.72L18.73,22L16.73,20H4C2.89,20 2,19.1 2,18V6C2,5.78 2.04,5.57 2.11,5.38L0.93,4.2M20,8V6H7.82L5.82,4H20A2,2 0 0,1 22,6V18C22,18.6 21.74,19.13 21.32,19.5L19.82,18H20V12H13.82L9.82,8H20M4,8H4.73L4,7.27V8M4,12V18H14.73L8.73,12H4Z\";\r\nvar mdiCreditCardOutline = \"M20,8H4V6H20M20,18H4V12H20M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiCreditCardPlus = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H13.09A5.47 5.47 0 0 1 13 19A6 6 0 0 1 19 13A5.88 5.88 0 0 1 22 13.81V6A2 2 0 0 0 20 4M20 11H4V8H20M20 15V18H23V20H20V23H18V20H15V18H18V15Z\";\r\nvar mdiCreditCardPlusOutline = \"M21,18H24V20H21V23H19V20H16V18H19V15H21V18M19,8V6H3V8H19M19,12H3V18H14V20H3C1.89,20 1,19.1 1,18V6C1,4.89 1.89,4 3,4H19A2,2 0 0,1 21,6V13H19V12Z\";\r\nvar mdiCreditCardRefund = \"M18 11H6A2 2 0 0 0 4 13V21A2 2 0 0 0 6 23H18A2 2 0 0 0 20 21V13A2 2 0 0 0 18 11M18 17H6V14H18M17 5V10H15.5V6.5H9.88L12.3 8.93L11.24 10L7 5.75L11.24 1.5L12.3 2.57L9.88 5Z\";\r\nvar mdiCreditCardRefundOutline = \"M18,11H6A2,2 0 0,0 4,13V21A2,2 0 0,0 6,23H18A2,2 0 0,0 20,21V13A2,2 0 0,0 18,11M18,21H6V17H18V21M18,15H6V13H18V15M17,5V10H15.5V6.5H9.88L12.3,8.93L11.24,10L7,5.75L11.24,1.5L12.3,2.57L9.88,5H17Z\";\r\nvar mdiCreditCardRemove = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H13.09A5.47 5.47 0 0 1 13 19A6 6 0 0 1 19 13A5.88 5.88 0 0 1 22 13.81V6A2 2 0 0 0 20 4M20 11H4V8H20M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.46 21.12L17.59 19L15.46 16.88L16.88 15.46L19 17.59L21.12 15.46Z\";\r\nvar mdiCreditCardRemoveOutline = \"M13 19C13 18.66 13.04 18.33 13.09 18H3V12H19V13C19.7 13 20.37 13.13 21 13.35V6C21 4.89 20.11 4 19 4H3C1.89 4 1 4.89 1 6V18C1 19.1 1.89 20 3 20H13.09C13.04 19.67 13 19.34 13 19M3 6H19V8H3V6M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.46L22.54 16.88Z\";\r\nvar mdiCreditCardScan = \"M18 6H6A2 2 0 0 0 4 8V16A2 2 0 0 0 6 18H18A2 2 0 0 0 20 16V8A2 2 0 0 0 18 6M18 12H6V9H18M2 4H6V2H2A2 2 0 0 0 0 4V8H2V4M22 2H18V4H22V8H24V4A2 2 0 0 0 22 2M2 16H0V20A2 2 0 0 0 2 22H6V20H2V16M22 20H18V22H22A2 2 0 0 0 24 20V16H22V20\";\r\nvar mdiCreditCardScanOutline = \"M2,4H6V2H2A2,2 0 0,0 0,4V8H2V4M22,2H18V4H22V8H24V4A2,2 0 0,0 22,2M2,16H0V20A2,2 0 0,0 2,22H6V20H2V16M22,20H18V22H22A2,2 0 0,0 24,20V16H22V20M4,8V16A2,2 0 0,0 6,18H18A2,2 0 0,0 20,16V8A2,2 0 0,0 18,6H6A2,2 0 0,0 4,8M6,16V12H18V16H6M18,8V10H6V8H18Z\";\r\nvar mdiCreditCardSettings = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V6A2 2 0 0 0 20 4M20 11H4V8H20M7 22H9V24H7V22M11 22H13V24H11V22M15 22H17V24H15Z\";\r\nvar mdiCreditCardSettingsOutline = \"M20,8H4V6H20M20,18H4V12H20M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiCreditCardWireless = \"M4.93 4.92L6.34 6.33C9.46 3.2 14.53 3.2 17.66 6.33L19.07 4.92C15.17 1 8.84 1 4.93 4.92M7.76 7.75L9.17 9.16C10.73 7.6 13.26 7.6 14.83 9.16L16.24 7.75C13.9 5.41 10.1 5.41 7.76 7.75M18 11H6C4.89 11 4 11.9 4 13V21C4 22.11 4.89 23 6 23H18C19.11 23 20 22.11 20 21V13C20 11.9 19.11 11 18 11M18 17H6V14H18V17Z\";\r\nvar mdiCreditCardWirelessOff = \"M12 2C9.85 2 7.7 2.69 5.9 4.08L7.32 5.5C10.45 3.24 14.84 3.5 17.66 6.33L19.07 4.92C17.12 2.96 14.56 2 12 2M3.28 4L2 5.27L7.73 11H6C4.89 11 4 11.9 4 13V21C4 22.11 4.89 23 6 23H18C18.5 23 18.92 22.82 19.27 22.54L19.73 23L21 21.72M12 6C10.87 6 9.75 6.31 8.77 6.94L10.24 8.41C11.73 7.68 13.58 7.92 14.83 9.16L16.24 7.75C15.07 6.58 13.54 6 12 6M12.82 11L15.82 14H18V16.18L20 18.18V13C20 11.9 19.11 11 18 11M6 14H10.73L13.73 17H6Z\";\r\nvar mdiCreditCardWirelessOffOutline = \"M12 2C9.85 2 7.7 2.69 5.9 4.08L7.32 5.5C10.45 3.24 14.84 3.5 17.66 6.33L19.07 4.92C17.12 2.96 14.56 2 12 2M3.28 4L2 5.27L7.73 11H6C4.89 11 4 11.9 4 13V21C4 22.11 4.89 23 6 23H18C18.47 23 18.92 22.84 19.27 22.54L19.73 23L21 21.72M12 6C10.87 6 9.75 6.31 8.77 6.94L10.24 8.41C11.73 7.68 13.58 7.92 14.83 9.16L16.24 7.75C15.07 6.58 13.54 6 12 6M12.82 11L14.82 13H18V15H16.82L20 18.18V13C20 11.9 19.11 11 18 11M6 13H9.73L11.73 15H6M6 17H13.73L17.73 21H6Z\";\r\nvar mdiCreditCardWirelessOutline = \"M18,11H6A2,2 0 0,0 4,13V21A2,2 0 0,0 6,23H18A2,2 0 0,0 20,21V13A2,2 0 0,0 18,11M18,21H6V17H18V21M18,15H6V13H18V15M4.93,4.92L6.34,6.33C9.46,3.2 14.53,3.2 17.66,6.33L19.07,4.92C15.17,1 8.84,1 4.93,4.92M7.76,7.75L9.17,9.16C10.73,7.6 13.26,7.6 14.83,9.16L16.24,7.75C13.9,5.41 10.1,5.41 7.76,7.75Z\";\r\nvar mdiCricket = \"M14.34,17.77L15.75,16.36L20,20.58L18.56,22L14.34,17.77M18.5,2A3.5,3.5 0 0,1 22,5.5A3.5,3.5 0 0,1 18.5,9A3.5,3.5 0 0,1 15,5.5A3.5,3.5 0 0,1 18.5,2M2.24,7.11L5.07,4.28C5.46,3.89 6.09,3.89 6.5,4.28L14.97,12.77C15.36,13.16 15.36,13.79 14.97,14.18L12.14,17C11.75,17.4 11.12,17.4 10.72,17L2.24,8.53C1.85,8.13 1.85,7.5 2.24,7.11Z\";\r\nvar mdiCrop = \"M7,17V1H5V5H1V7H5V17A2,2 0 0,0 7,19H17V23H19V19H23V17M17,15H19V7C19,5.89 18.1,5 17,5H9V7H17V15Z\";\r\nvar mdiCropFree = \"M19,3H15V5H19V9H21V5C21,3.89 20.1,3 19,3M19,19H15V21H19A2,2 0 0,0 21,19V15H19M5,15H3V19A2,2 0 0,0 5,21H9V19H5M3,5V9H5V5H9V3H5A2,2 0 0,0 3,5Z\";\r\nvar mdiCropLandscape = \"M19,17H5V7H19M19,5H5A2,2 0 0,0 3,7V17A2,2 0 0,0 5,19H19A2,2 0 0,0 21,17V7C21,5.89 20.1,5 19,5Z\";\r\nvar mdiCropPortrait = \"M17,19H7V5H17M17,3H7A2,2 0 0,0 5,5V19A2,2 0 0,0 7,21H17A2,2 0 0,0 19,19V5C19,3.89 18.1,3 17,3Z\";\r\nvar mdiCropRotate = \"M7.47,21.5C4.2,19.93 1.86,16.76 1.5,13H0C0.5,19.16 5.66,24 11.95,24C12.18,24 12.39,24 12.61,23.97L8.8,20.15L7.47,21.5M12.05,0C11.82,0 11.61,0 11.39,0.04L15.2,3.85L16.53,2.5C19.8,4.07 22.14,7.24 22.5,11H24C23.5,4.84 18.34,0 12.05,0M16,14H18V8C18,6.89 17.1,6 16,6H10V8H16V14M8,16V4H6V6H4V8H6V16A2,2 0 0,0 8,18H16V20H18V18H20V16H8Z\";\r\nvar mdiCropSquare = \"M18,18H6V6H18M18,4H6A2,2 0 0,0 4,6V18A2,2 0 0,0 6,20H18A2,2 0 0,0 20,18V6C20,4.89 19.1,4 18,4Z\";\r\nvar mdiCrosshairs = \"M3.05,13H1V11H3.05C3.5,6.83 6.83,3.5 11,3.05V1H13V3.05C17.17,3.5 20.5,6.83 20.95,11H23V13H20.95C20.5,17.17 17.17,20.5 13,20.95V23H11V20.95C6.83,20.5 3.5,17.17 3.05,13M12,5A7,7 0 0,0 5,12A7,7 0 0,0 12,19A7,7 0 0,0 19,12A7,7 0 0,0 12,5Z\";\r\nvar mdiCrosshairsGps = \"M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8M3.05,13H1V11H3.05C3.5,6.83 6.83,3.5 11,3.05V1H13V3.05C17.17,3.5 20.5,6.83 20.95,11H23V13H20.95C20.5,17.17 17.17,20.5 13,20.95V23H11V20.95C6.83,20.5 3.5,17.17 3.05,13M12,5A7,7 0 0,0 5,12A7,7 0 0,0 12,19A7,7 0 0,0 19,12A7,7 0 0,0 12,5Z\";\r\nvar mdiCrosshairsOff = \"M20.94 11C20.5 6.83 17.17 3.5 13 3.06V1H11V3.06C9.87 3.18 8.81 3.5 7.84 4.03L9.34 5.53C10.16 5.19 11.06 5 12 5C15.87 5 19 8.13 19 12C19 12.94 18.81 13.84 18.5 14.65L20 16.15C20.5 15.19 20.82 14.13 20.95 13H23V11H20.94M3 4.27L5.04 6.31C3.97 7.62 3.25 9.23 3.06 11H1V13H3.06C3.5 17.17 6.83 20.5 11 20.94V23H13V20.94C14.77 20.74 16.38 20.03 17.69 18.96L19.73 21L21 19.73L4.27 3L3 4.27M16.27 17.54C15.09 18.45 13.61 19 12 19C8.13 19 5 15.87 5 12C5 10.39 5.55 8.91 6.46 7.73L16.27 17.54Z\";\r\nvar mdiCrosshairsQuestion = \"M3.05 13H1V11H3.05C3.5 6.83 6.83 3.5 11 3.05V1H13V3.05C17.17 3.5 20.5 6.83 20.95 11H23V13H20.95C20.5 17.17 17.17 20.5 13 20.95V23H11V20.95C6.83 20.5 3.5 17.17 3.05 13M12 5C8.13 5 5 8.13 5 12S8.13 19 12 19 19 15.87 19 12 15.87 5 12 5M11.13 17.25H12.88V15.5H11.13V17.25M12 6.75C10.07 6.75 8.5 8.32 8.5 10.25H10.25C10.25 9.28 11.03 8.5 12 8.5S13.75 9.28 13.75 10.25C13.75 12 11.13 11.78 11.13 14.63H12.88C12.88 12.66 15.5 12.44 15.5 10.25C15.5 8.32 13.93 6.75 12 6.75Z\";\r\nvar mdiCrown = \"M5 16L3 5L8.5 10L12 4L15.5 10L21 5L19 16H5M19 19C19 19.6 18.6 20 18 20H6C5.4 20 5 19.6 5 19V18H19V19Z\";\r\nvar mdiCrownOutline = \"M12 8L15 13.2L18 10.5L17.3 14H6.7L6 10.5L9 13.2L12 8M12 4L8.5 10L3 5L5 16H19L21 5L15.5 10L12 4M19 18H5V19C5 19.6 5.4 20 6 20H18C18.6 20 19 19.6 19 19V18Z\";\r\nvar mdiCryengine = \"M23.03,12.4M23.03,12.5V12.5C23,13 20.91,15.23 17.82,16.24C14.05,17.5 7.97,17.03 7.97,12.3C7.97,10.08 9.78,8.27 12,8.27C14.25,8.27 16.05,10.09 16.05,12.31C16.05,13.39 15.58,14.44 14.87,15.18C15.54,15.17 17.94,15 20.21,13.12C20.46,12.88 20.62,12.68 20.69,12.55C20.71,12.5 20.74,12.46 20.73,12.4C20.73,11.92 18.12,8.19 12.72,7.12C19.22,7.46 23,11.32 23.03,12.4V12.5H23.03M12,10C10.74,10 9.71,11.04 9.71,12.3C9.71,13.57 10.74,14.59 12,14.59C13.27,14.59 14.29,13.57 14.29,12.3C14.29,11.04 13.27,10 12,10M3.31,12.34C3.31,12.34 3.31,12.31 3.31,12.42V12.42C3.41,12.94 4.82,15.41 10.28,16.88C3.96,16.37 1.12,13.28 1.04,12.42H1.03C1.03,12.31 1.03,12.36 1.03,12.35C1.03,11.5 4.96,7.58 10.92,7.15C6.14,8.26 3.31,11.87 3.31,12.34V12.34Z\";\r\nvar mdiCrystalBall = \"M9.38,8.38L11.5,9.34L13.62,8.38L12.66,10.5L13.62,12.62L11.5,11.66L9.38,12.62L10.34,10.5L9.38,8.38M16.5,2.5L17.59,5.41L20.5,6.5L17.59,7.59L16.5,10.5L15.41,7.59L12.5,6.5L15.41,5.41L16.5,2.5M6,19H7V18A1,1 0 0,1 8,17H8.26C6,15.7 4.5,13.28 4.5,10.5A7.5,7.5 0 0,1 12,3C13.05,3 14.05,3.22 14.96,3.61L14.59,4.59L13.17,5.12C12.79,5.04 12.4,5 12,5A5.5,5.5 0 0,0 6.5,10.5A5.5,5.5 0 0,0 12,16C14.91,16 17.3,13.73 17.5,10.87L18.41,8.41L19.12,8.14C19.37,8.88 19.5,9.68 19.5,10.5C19.5,13.28 18,15.7 15.74,17H16A1,1 0 0,1 17,18V19H18A2,2 0 0,1 20,21V22H4V21A2,2 0 0,1 6,19Z\";\r\nvar mdiCube = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L6.04,7.5L12,10.85L17.96,7.5L12,4.15Z\";\r\nvar mdiCubeOff = \"M20.84 22.73L17.28 19.17L12.57 21.82C12.41 21.94 12.21 22 12 22S11.59 21.94 11.43 21.82L3.53 17.38C3.21 17.21 3 16.88 3 16.5V7.5C3 7.12 3.21 6.79 3.53 6.62L4.3 6.19L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M12 4.15L17.96 7.5L13.31 10.11L20.53 17.33C20.82 17.16 21 16.85 21 16.5V7.5C21 7.12 20.79 6.79 20.47 6.62L12.57 2.18C12.41 2.06 12.21 2 12 2S11.59 2.06 11.43 2.18L7.56 4.36L9 5.82L12 4.15Z\";\r\nvar mdiCubeOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L4.3 6.19L3.53 6.62C3.21 6.79 3 7.12 3 7.5V16.5C3 16.88 3.21 17.21 3.53 17.38L11.43 21.82C11.59 21.94 11.79 22 12 22S12.41 21.94 12.57 21.82L17.28 19.17L20.84 22.73L22.11 21.46M5 15.91V9.21L10.29 12.18L11 12.89V19.29L5 15.91M13 19.29V14.89L15.82 17.7L13 19.29M9 5.82L7.56 4.36L11.43 2.18C11.59 2.06 11.79 2 12 2S12.41 2.06 12.57 2.18L20.47 6.62C20.79 6.79 21 7.12 21 7.5V16.5C21 16.85 20.82 17.16 20.53 17.33L19 15.8V9.21L14.78 11.58L13.31 10.11L17.96 7.5L12 4.15L9 5.82Z\";\r\nvar mdiCubeOutline = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L6.04,7.5L12,10.85L17.96,7.5L12,4.15M5,15.91L11,19.29V12.58L5,9.21V15.91M19,15.91V9.21L13,12.58V19.29L19,15.91Z\";\r\nvar mdiCubeScan = \"M17,22V20H20V17H22V20.5C22,20.89 21.84,21.24 21.54,21.54C21.24,21.84 20.89,22 20.5,22H17M7,22H3.5C3.11,22 2.76,21.84 2.46,21.54C2.16,21.24 2,20.89 2,20.5V17H4V20H7V22M17,2H20.5C20.89,2 21.24,2.16 21.54,2.46C21.84,2.76 22,3.11 22,3.5V7H20V4H17V2M7,2V4H4V7H2V3.5C2,3.11 2.16,2.76 2.46,2.46C2.76,2.16 3.11,2 3.5,2H7M13,17.25L17,14.95V10.36L13,12.66V17.25M12,10.92L16,8.63L12,6.28L8,8.63L12,10.92M7,14.95L11,17.25V12.66L7,10.36V14.95M18.23,7.59C18.73,7.91 19,8.34 19,8.91V15.23C19,15.8 18.73,16.23 18.23,16.55L12.75,19.73C12.25,20.05 11.75,20.05 11.25,19.73L5.77,16.55C5.27,16.23 5,15.8 5,15.23V8.91C5,8.34 5.27,7.91 5.77,7.59L11.25,4.41C11.5,4.28 11.75,4.22 12,4.22C12.25,4.22 12.5,4.28 12.75,4.41L18.23,7.59Z\";\r\nvar mdiCubeSend = \"M16,4L9,8.04V15.96L16,20L23,15.96V8.04M16,6.31L19.8,8.5L16,10.69L12.21,8.5M0,7V9H7V7M11,10.11L15,12.42V17.11L11,14.81M21,10.11V14.81L17,17.11V12.42M2,11V13H7V11M4,15V17H7V15\";\r\nvar mdiCubeUnfolded = \"M6,9V4H13V9H23V16H18V21H11V16H1V9H6M16,16H13V19H16V16M8,9H11V6H8V9M6,14V11H3V14H6M18,11V14H21V11H18M13,11V14H16V11H13M8,11V14H11V11H8Z\";\r\nvar mdiCup = \"M18.32,8H5.67L5.23,4H18.77M3,2L5,20.23C5.13,21.23 5.97,22 7,22H17C18,22 18.87,21.23 19,20.23L21,2H3Z\";\r\nvar mdiCupOff = \"M1,4.27L2.28,3L21,21.72L19.73,23L18.27,21.54C17.93,21.83 17.5,22 17,22H7C5.97,22 5.13,21.23 5,20.23L3.53,6.8L1,4.27M18.32,8L18.77,4H5.82L3.82,2H21L19.29,17.47L9.82,8H18.32Z\";\r\nvar mdiCupOffOutline = \"M3.83 2L5.83 4H18.78L17.5 15.66L19.3 17.5L21 2M2.27 3L1 4.27L3.53 6.8L5 20.23C5.13 21.23 5.97 22 7 22H17C17.47 22 17.91 21.82 18.26 21.54L19.73 23L21 21.73M5.78 9.06L16.73 20H7Z\";\r\nvar mdiCupOutline = \"M3 2L5 20.23C5.13 21.23 5.97 22 7 22H17C18 22 18.87 21.23 19 20.23L21 2H3M5.22 4H18.78L17 20H7L5.22 4Z\";\r\nvar mdiCupWater = \"M18.32,8H5.67L5.23,4H18.77M12,19A3,3 0 0,1 9,16C9,14 12,10.6 12,10.6C12,10.6 15,14 15,16A3,3 0 0,1 12,19M3,2L5,20.23C5.13,21.23 5.97,22 7,22H17C18,22 18.87,21.23 19,20.23L21,2H3Z\";\r\nvar mdiCupboard = \"M17 2H7C5.9 2 5 2.9 5 4V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C18.11 21 19 20.11 19 19V4C19 2.9 18.11 2 17 2M10 18H8V15H10V18M16 18H14V15H16V18M17 12H7V9H17V12M17 7H7V4H17V7Z\";\r\nvar mdiCupboardOutline = \"M7 2C5.9 2 5 2.9 5 4V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C18.11 21 19 20.11 19 19V4C19 2.9 18.11 2 17 2H7M7 4H17V7H7V4M7 9H17V12H7V9M7 14H11V19H7V14M13 14H17V19H13V14M8 15V18H10V15H8M14 15V18H16V15H14Z\";\r\nvar mdiCupcake = \"M12,1.5A2.5,2.5 0 0,1 14.5,4A2.5,2.5 0 0,1 12,6.5A2.5,2.5 0 0,1 9.5,4A2.5,2.5 0 0,1 12,1.5M15.87,5C18,5 20,7 20,9C22.7,9 22.7,13 20,13H4C1.3,13 1.3,9 4,9C4,7 6,5 8.13,5C8.57,6.73 10.14,8 12,8C13.86,8 15.43,6.73 15.87,5M5,15H8L9,22H7L5,15M10,15H14L13,22H11L10,15M16,15H19L17,22H15L16,15Z\";\r\nvar mdiCurling = \"M10,3V5C12.5,5 13.9,5.05 14.72,5.41C15.26,5.65 15.73,6.21 16.25,7H5V9H19.62L18.89,7.55C17.86,5.5 16.96,4.22 15.53,3.59C14.1,2.95 12.5,3 10,3M6,11C3.78,11 2,12.78 2,15V18C2,20.22 3.78,22 6,22H18C20.22,22 22,20.22 22,18V15C22,12.78 20.22,11 18,11H6Z\";\r\nvar mdiCurrencyBdt = \"M18.09,10.5V9H9.59V4.5A1.5,1.5 0 0,0 8.09,3A1.5,1.5 0 0,0 6.59,4.5A1.5,1.5 0 0,0 8.09,6V9H5.09V10.5H8.09V16.7C8.09,19.06 10,20.97 12.34,21C14.68,20.96 16.54,19.04 16.5,16.7C16.5,15.11 15.75,13.61 14.5,12.62C14.28,12.44 14.05,12.28 13.8,12.15C13.58,12.05 13.34,12 13.1,12C12.39,12 11.74,12.39 11.39,13C11.2,13.3 11.1,13.65 11.1,14C11.11,15.1 12,16 13.11,16C13.73,16 14.31,15.69 14.69,15.2C14.9,15.67 15,16.18 15,16.7C15.04,18.2 13.86,19.45 12.34,19.5C10.81,19.5 9.58,18.23 9.59,16.7V10.5H18.09Z\";\r\nvar mdiCurrencyBrl = \"M12,15H14C14,16.08 15.37,17 17,17C18.63,17 20,16.08 20,15C20,13.9 18.96,13.5 16.76,12.97C14.64,12.44 12,11.78 12,9C12,7.21 13.47,5.69 15.5,5.18V3H18.5V5.18C20.53,5.69 22,7.21 22,9H20C20,7.92 18.63,7 17,7C15.37,7 14,7.92 14,9C14,10.1 15.04,10.5 17.24,11.03C19.36,11.56 22,12.22 22,15C22,16.79 20.53,18.31 18.5,18.82V21H15.5V18.82C13.47,18.31 12,16.79 12,15M2,3H5.5A5.5,5.5 0 0,1 11,8.5C11,10.69 9.71,12.59 7.86,13.47L11.64,21H9.4L5.88,14H5.5L4,14V21H2V3M5.5,12A3.5,3.5 0 0,0 9,8.5A3.5,3.5 0 0,0 5.5,5H4V12H5.5Z\";\r\nvar mdiCurrencyBtc = \"M6,4H8V2H10V4H12V2H14V4.03C16.25,4.28 18,6.18 18,8.5C18,9.8 17.45,11 16.56,11.8C17.73,12.61 18.5,13.97 18.5,15.5C18.5,18 16.5,20 14,20V22H12V20H10V22H8V20H6L6.5,18H8V6H6V4M10,13V18H14A2.5,2.5 0 0,0 16.5,15.5A2.5,2.5 0 0,0 14,13H10M10,6V11H13.5A2.5,2.5 0 0,0 16,8.5A2.5,2.5 0 0,0 13.5,6H13.5L10,6Z\";\r\nvar mdiCurrencyCny = \"M11,21V16H6V14H11V13.71L10.16,12H6V10H9.19L5.77,3H8L12,11.2L16,3H18.23L14.81,10H18V12H13.84L13,13.71V14H18V16H13V21H11Z\";\r\nvar mdiCurrencyEth = \"M6,5H18V7H6M7,11H17V13H7M5.5,17H18.5V19H5.5\";\r\nvar mdiCurrencyEur = \"M7.07,11L7,12L7.07,13H17.35L16.5,15H7.67C8.8,17.36 11.21,19 14,19C16.23,19 18.22,17.96 19.5,16.33V19.12C18,20.3 16.07,21 14,21C10.08,21 6.75,18.5 5.5,15H2L3,13H5.05L5,12L5.05,11H2L3,9H5.5C6.75,5.5 10.08,3 14,3C16.5,3 18.8,4.04 20.43,5.71L19.57,7.75C18.29,6.08 16.27,5 14,5C11.21,5 8.8,6.64 7.67,9H19.04L18.19,11H7.07Z\";\r\nvar mdiCurrencyEurOff = \"M22.11 21.46L2.39 1.73L1.11 3L6 7.89C5.81 8.25 5.64 8.62 5.5 9H3L2 11H5.05L5 12L5.05 13H3L2 15H5.5C6.75 18.5 10.08 21 14 21C15.5 21 16.89 20.65 18.12 20L20.84 22.73L22.11 21.46M7 12L7.07 11H9.12L11.12 13H7.07L7 12M14 19C11.21 19 8.8 17.37 7.67 15H13.12L16.6 18.5C15.79 18.81 14.92 19 14 19M17 13.81L16.21 13H17.35L17 13.81M18.19 11H14.21L12.21 9H19.04L18.19 11M9.7 6.5L8.27 5.07C9.83 3.78 11.82 3 14 3C16.5 3 18.8 4.05 20.43 5.72L19.57 7.76C18.29 6.09 16.27 5 14 5C12.38 5 10.89 5.58 9.7 6.5Z\";\r\nvar mdiCurrencyGbp = \"M6,21V19C10,17 9.5,13 9.5,13H7V11H9.5C8.5,6.5 10,3 14,3C16,3 17,3.5 17,3.5V5.5C11,3.5 11,8 11.5,11H16V13H11.5C11.5,13 12,17 9.5,19H18V21H6Z\";\r\nvar mdiCurrencyIls = \"M22,16A5,5 0 0,1 17,21H8V9H10V19H17A3,3 0 0,0 20,16V3H22V16M16,8V15H14V8A3,3 0 0,0 11,5H4V21H2V3H11A5,5 0 0,1 16,8Z\";\r\nvar mdiCurrencyInr = \"M8,3H18L17,5H13.74C14.22,5.58 14.58,6.26 14.79,7H18L17,9H15C14.75,11.57 12.74,13.63 10.2,13.96V14H9.5L15.5,21H13L7,14V12H9.5V12C11.26,12 12.72,10.7 12.96,9H7L8,7H12.66C12.1,5.82 10.9,5 9.5,5H7L8,3Z\";\r\nvar mdiCurrencyJpy = \"M11,21V16H6V14H11V13.71L10.16,12H6V10H9.19L5.77,3H8L12,11.2L16,3H18.23L14.81,10H18V12H13.84L13,13.71V14H18V16H13V21H11Z\";\r\nvar mdiCurrencyKrw = \"M2,3H4L5.33,9H9.33L10.67,3H13.33L14.67,9H18.67L20,3H22L20.67,9H22V11H20.22L19.78,13H22V15H19.33L18,21H15.33L14,15H10L8.67,21H6L4.67,15H2V13H4.22L3.78,11H2V9H3.33L2,3M13.11,11H10.89L10.44,13H13.56L13.11,11M7.33,18L8,15H6.67L7.33,18M8.89,11H5.78L6.22,13H8.44L8.89,11M16.67,18L17.33,15H16L16.67,18M18.22,11H15.11L15.56,13H17.78L18.22,11M12,6L11.33,9H12.67L12,6Z\";\r\nvar mdiCurrencyKzt = \"M5,3H19V5H5V3M5,6H19V8H13V21H11V8H5V6Z\";\r\nvar mdiCurrencyMnt = \"M13 5V8.62L17 7.17V9.29L13 10.74V12.5L17 11.07V13.2L13 14.65V21H11V15.38L7 16.84V14.71L11 13.24V11.47L7 12.92V10.8L11 9.35V5H5V3H19V5H13Z\";\r\nvar mdiCurrencyNgn = \"M4,9H6V3H8L11.42,9H16V3H18V9H20V11H18V13H20V15H18V21H16L12.57,15H8V21H6V15H4V13H6V11H4V9M8,9H9.13L8,7.03V9M8,11V13H11.42L10.28,11H8M16,17V15H14.85L16,17M12.56,11L13.71,13H16V11H12.56Z\";\r\nvar mdiCurrencyPhp = \"M5,2V6H3V8H5V10H3V12H5V22H7V16H13C15.7,16 18.16,14.44 19.32,12H22V10H19.92C20.03,9.34 20.03,8.66 19.92,8H22V6H19.32C18.16,3.56 15.7,2 13,2M7,4H13C14.57,4 16.06,4.74 17,6H7V4M13,14H7V12H17C16.06,13.26 14.57,14 13,14M18,9C18,9.34 17.96,9.67 17.9,10H7V8H17.9C17.96,8.33 18,8.66 18,9Z\";\r\nvar mdiCurrencyRial = \"M11,17H13V19H11V17M14,17H16V19H14V17M9,4H11V15A4,4 0 0,1 7,19H5A3,3 0 0,1 2,16V12H4V16A1,1 0 0,0 5,17H7C8.11,17 9,16.11 9,15V4M12,4H14V13H17V8H19V13C19,14.11 18.11,15 17,15H14C12.89,15 12,14.11 12,13V4M20,10H22V17A3,3 0 0,1 19,20H17V18H19A1,1 0 0,0 20,17V10Z\";\r\nvar mdiCurrencyRub = \"M6,10H7V3H14.5C17,3 19,5 19,7.5C19,10 17,12 14.5,12H9V14H15V16H9V21H7V16H6V14H7V12H6V10M14.5,5H9V10H14.5A2.5,2.5 0 0,0 17,7.5A2.5,2.5 0 0,0 14.5,5Z\";\r\nvar mdiCurrencySign = \"M4.41 3L3 4.41L5.69 7.1C4.63 8.46 4 10.15 4 12C4 13.85 4.63 15.55 5.69 16.9L3 19.59L4.41 21L7.1 18.31C8.46 19.37 10.15 20 12 20C13.85 20 15.55 19.37 16.9 18.31L19.59 21L21 19.59L18.31 16.9C19.37 15.54 20 13.85 20 12C20 10.15 19.37 8.45 18.31 7.1L21 4.41L19.59 3L16.9 5.69C15.54 4.63 13.85 4 12 4C10.15 4 8.45 4.63 7.1 5.69L4.41 3M12 6C15.31 6 18 8.69 18 12C18 15.31 15.31 18 12 18C8.69 18 6 15.31 6 12C6 8.69 8.69 6 12 6Z\";\r\nvar mdiCurrencyTry = \"M19,12A9,9 0 0,1 10,21H8V12.77L5,13.87V11.74L8,10.64V8.87L5,9.96V7.84L8,6.74V3H10V6L15,4.2V6.32L10,8.14V9.92L15,8.1V10.23L10,12.05V19A7,7 0 0,0 17,12H19Z\";\r\nvar mdiCurrencyTwd = \"M3,11H21V13H15V19H21V21H15A2,2 0 0,1 13,19V13H10.35L5.73,21L4,20L8.04,13H3V11M5,3H19V5H5V3Z\";\r\nvar mdiCurrencyUsd = \"M7,15H9C9,16.08 10.37,17 12,17C13.63,17 15,16.08 15,15C15,13.9 13.96,13.5 11.76,12.97C9.64,12.44 7,11.78 7,9C7,7.21 8.47,5.69 10.5,5.18V3H13.5V5.18C15.53,5.69 17,7.21 17,9H15C15,7.92 13.63,7 12,7C10.37,7 9,7.92 9,9C9,10.1 10.04,10.5 12.24,11.03C14.36,11.56 17,12.22 17,15C17,16.79 15.53,18.31 13.5,18.82V21H10.5V18.82C8.47,18.31 7,16.79 7,15Z\";\r\nvar mdiCurrencyUsdCircle = \"M12 2A10 10 0 1 0 22 12A10 10 0 0 0 12 2M15 10H11V11H14A1 1 0 0 1 15 12V15A1 1 0 0 1 14 16H13V17H11V16H9V14H13V13H10A1 1 0 0 1 9 12V9A1 1 0 0 1 10 8H11V7H13V8H15Z\";\r\nvar mdiCurrencyUsdCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M11,17V16H9V14H13V13H10A1,1 0 0,1 9,12V9A1,1 0 0,1 10,8H11V7H13V8H15V10H11V11H14A1,1 0 0,1 15,12V15A1,1 0 0,1 14,16H13V17H11Z\";\r\nvar mdiCurrencyUsdOff = \"M3,4.27L4.28,3L21,19.72L19.73,21L16.06,17.33C15.44,18 14.54,18.55 13.5,18.82V21H10.5V18.82C8.47,18.31 7,16.79 7,15H9C9,16.08 10.37,17 12,17C13.13,17 14.14,16.56 14.65,15.92L11.68,12.95C9.58,12.42 7,11.75 7,9C7,8.77 7,8.55 7.07,8.34L3,4.27M10.5,5.18V3H13.5V5.18C15.53,5.69 17,7.21 17,9H15C15,7.92 13.63,7 12,7C11.63,7 11.28,7.05 10.95,7.13L9.4,5.58L10.5,5.18Z\";\r\nvar mdiCurrentAc = \"M12.43 11C12.28 10.84 10 7 7 7S2.32 10.18 2 11V13H11.57C11.72 13.16 14 17 17 17S21.68 13.82 22 13V11H12.43M7 9C8.17 9 9.18 9.85 10 11H4.31C4.78 10.17 5.54 9 7 9M17 15C15.83 15 14.82 14.15 14 13H19.69C19.22 13.83 18.46 15 17 15Z\";\r\nvar mdiCurrentDc = \"M2,9V11H22V9H2M2,13V15H7V13H2M9,13V15H15V13H9M17,13V15H22V13H17Z\";\r\nvar mdiCursorDefault = \"M13.64,21.97C13.14,22.21 12.54,22 12.31,21.5L10.13,16.76L7.62,18.78C7.45,18.92 7.24,19 7,19A1,1 0 0,1 6,18V3A1,1 0 0,1 7,2C7.24,2 7.47,2.09 7.64,2.23L7.65,2.22L19.14,11.86C19.57,12.22 19.62,12.85 19.27,13.27C19.12,13.45 18.91,13.57 18.7,13.61L15.54,14.23L17.74,18.96C18,19.46 17.76,20.05 17.26,20.28L13.64,21.97Z\";\r\nvar mdiCursorDefaultClick = \"M10.76,8.69A0.76,0.76 0 0,0 10,9.45V20.9C10,21.32 10.34,21.66 10.76,21.66C10.95,21.66 11.11,21.6 11.24,21.5L13.15,19.95L14.81,23.57C14.94,23.84 15.21,24 15.5,24C15.61,24 15.72,24 15.83,23.92L18.59,22.64C18.97,22.46 19.15,22 18.95,21.63L17.28,18L19.69,17.55C19.85,17.5 20,17.43 20.12,17.29C20.39,16.97 20.35,16.5 20,16.21L11.26,8.86L11.25,8.87C11.12,8.76 10.95,8.69 10.76,8.69M15,10V8H20V10H15M13.83,4.76L16.66,1.93L18.07,3.34L15.24,6.17L13.83,4.76M10,0H12V5H10V0M3.93,14.66L6.76,11.83L8.17,13.24L5.34,16.07L3.93,14.66M3.93,3.34L5.34,1.93L8.17,4.76L6.76,6.17L3.93,3.34M7,10H2V8H7V10\";\r\nvar mdiCursorDefaultClickOutline = \"M11.5,11L17.88,16.37L17,16.55L16.36,16.67C15.73,16.8 15.37,17.5 15.65,18.07L15.92,18.65L17.28,21.59L15.86,22.25L14.5,19.32L14.24,18.74C13.97,18.15 13.22,17.97 12.72,18.38L12.21,18.78L11.5,19.35V11M10.76,8.69A0.76,0.76 0 0,0 10,9.45V20.9C10,21.32 10.34,21.66 10.76,21.66C10.95,21.66 11.11,21.6 11.24,21.5L13.15,19.95L14.81,23.57C14.94,23.84 15.21,24 15.5,24C15.61,24 15.72,24 15.83,23.92L18.59,22.64C18.97,22.46 19.15,22 18.95,21.63L17.28,18L19.69,17.55C19.85,17.5 20,17.43 20.12,17.29C20.39,16.97 20.35,16.5 20,16.21L11.26,8.86L11.25,8.87C11.12,8.76 10.95,8.69 10.76,8.69M15,10V8H20V10H15M13.83,4.76L16.66,1.93L18.07,3.34L15.24,6.17L13.83,4.76M10,0H12V5H10V0M3.93,14.66L6.76,11.83L8.17,13.24L5.34,16.07L3.93,14.66M3.93,3.34L5.34,1.93L8.17,4.76L6.76,6.17L3.93,3.34M7,10H2V8H7V10\";\r\nvar mdiCursorDefaultGesture = \"M15.59 8C15.26 8 15 8.27 15 8.6V17.57C15 17.9 15.26 18.17 15.59 18.17C15.74 18.17 15.86 18.12 15.96 18.04L17.45 16.83L18.74 19.66C18.84 19.88 19.05 20 19.27 20C19.36 20 19.44 20 19.53 19.94L21.67 18.93C21.97 18.79 22.11 18.43 21.95 18.14L20.66 15.3L22.53 14.94C22.65 14.91 22.77 14.85 22.86 14.74C23.07 14.5 23.04 14.12 22.77 13.89L16 8.13C15.88 8.05 15.74 8 15.59 8M12.5 6.73C12.72 6.66 13.17 7.19 13.59 7.76L15 6.71C14.87 6.5 14.69 6.25 14.47 5.96C14.31 5.75 13.59 4.93 12.66 4.8C12.04 4.72 10.81 5.06 10.6 6.61C10.47 7.58 10.76 8.19 11.21 9.08C11.46 9.6 12.04 10.96 12.18 11.78C12.33 12.59 12.06 13.16 11.74 13.12C11.44 13.08 11.2 12.65 11.03 12.41C10.89 12.22 10 10.82 9.67 10.23C9.22 9.5 8.04 7.96 6.44 7.74C4.35 7.46 3.44 9.2 3.18 10.36L1 10.06V11.88L2.93 12.15C2.75 15.6 4.5 16.82 5.67 17C6.92 17.15 8.08 16.28 8.24 15.06C8.41 13.84 7.56 11.5 4.96 10.69C5.1 10.15 5.21 9.43 6.36 9.59C7.26 9.71 8.21 11.26 8.93 12.44C9.58 13.53 10.1 14.39 10.83 14.72C11.45 15 12.16 14.97 12.73 14.65C13.42 14.26 13.86 13.55 14 12.63C14.22 10.9 12.7 8.17 12.57 7.84C12.4 7.46 12.12 6.82 12.5 6.73M6.5 14.78C6.43 15.11 6.1 15.25 5.88 15.22C5.38 15.16 4.66 14.5 4.71 12.53C6.17 13.13 6.53 14.35 6.5 14.78Z\";\r\nvar mdiCursorDefaultGestureOutline = \"M16.5 10.54L20.37 13.83L18.5 14.18L19.29 15.92L20.22 17.96L19.72 18.19L18.81 16.2L18 14.43L16.5 15.66V10.54M15.59 8C15.26 8 15 8.27 15 8.6V17.57C15 17.9 15.26 18.17 15.59 18.17C15.74 18.17 15.86 18.12 15.96 18.04L17.45 16.83L18.74 19.66C18.84 19.88 19.05 20 19.27 20C19.36 20 19.44 20 19.53 19.94L21.67 18.93C21.97 18.79 22.11 18.43 21.95 18.14L20.66 15.3L22.53 14.94C22.65 14.91 22.77 14.85 22.86 14.74C23.07 14.5 23.04 14.12 22.77 13.89L16 8.13C15.88 8.05 15.74 8 15.59 8M12.5 6.73C12.72 6.66 13.17 7.19 13.59 7.76L15 6.71C14.87 6.5 14.69 6.25 14.47 5.96C14.31 5.75 13.59 4.93 12.66 4.8C12.04 4.72 10.81 5.06 10.6 6.61C10.47 7.58 10.76 8.19 11.21 9.08C11.46 9.6 12.04 10.96 12.18 11.78C12.33 12.59 12.06 13.16 11.74 13.12C11.44 13.08 11.2 12.65 11.03 12.41C10.89 12.22 10 10.82 9.67 10.23C9.22 9.5 8.04 7.96 6.44 7.74C4.35 7.46 3.44 9.2 3.18 10.36L1 10.06V11.88L2.93 12.15C2.75 15.6 4.5 16.82 5.67 17C6.92 17.15 8.08 16.28 8.24 15.06C8.41 13.84 7.56 11.5 4.96 10.69C5.1 10.15 5.21 9.43 6.36 9.59C7.26 9.71 8.21 11.26 8.93 12.44C9.58 13.53 10.1 14.39 10.83 14.72C11.45 15 12.16 14.97 12.73 14.65C13.42 14.26 13.86 13.55 14 12.63C14.22 10.9 12.7 8.17 12.57 7.84C12.4 7.46 12.12 6.82 12.5 6.73M6.5 14.78C6.43 15.11 6.1 15.25 5.88 15.22C5.38 15.16 4.66 14.5 4.71 12.53C6.17 13.13 6.53 14.35 6.5 14.78Z\";\r\nvar mdiCursorDefaultOutline = \"M10.07,14.27C10.57,14.03 11.16,14.25 11.4,14.75L13.7,19.74L15.5,18.89L13.19,13.91C12.95,13.41 13.17,12.81 13.67,12.58L13.95,12.5L16.25,12.05L8,5.12V15.9L9.82,14.43L10.07,14.27M13.64,21.97C13.14,22.21 12.54,22 12.31,21.5L10.13,16.76L7.62,18.78C7.45,18.92 7.24,19 7,19A1,1 0 0,1 6,18V3A1,1 0 0,1 7,2C7.24,2 7.47,2.09 7.64,2.23L7.65,2.22L19.14,11.86C19.57,12.22 19.62,12.85 19.27,13.27C19.12,13.45 18.91,13.57 18.7,13.61L15.54,14.23L17.74,18.96C18,19.46 17.76,20.05 17.26,20.28L13.64,21.97Z\";\r\nvar mdiCursorMove = \"M13,6V11H18V7.75L22.25,12L18,16.25V13H13V18H16.25L12,22.25L7.75,18H11V13H6V16.25L1.75,12L6,7.75V11H11V6H7.75L12,1.75L16.25,6H13Z\";\r\nvar mdiCursorPointer = \"M13.75,10.19L14.38,10.32L18.55,12.4C19.25,12.63 19.71,13.32 19.65,14.06V14.19L19.65,14.32L18.75,20.44C18.69,20.87 18.5,21.27 18.15,21.55C17.84,21.85 17.43,22 17,22H10.12C9.63,22 9.18,21.82 8.85,21.47L2.86,15.5L3.76,14.5C4,14.25 4.38,14.11 4.74,14.13H5.03L9,15V4.5A2,2 0 0,1 11,2.5A2,2 0 0,1 13,4.5V10.19H13.75Z\";\r\nvar mdiCursorText = \"M13,19A1,1 0 0,0 14,20H16V22H13.5C12.95,22 12,21.55 12,21C12,21.55 11.05,22 10.5,22H8V20H10A1,1 0 0,0 11,19V5A1,1 0 0,0 10,4H8V2H10.5C11.05,2 12,2.45 12,3C12,2.45 12.95,2 13.5,2H16V4H14A1,1 0 0,0 13,5V19Z\";\r\nvar mdiDanceBallroom = \"M14 3.5C14 4.33 13.33 5 12.5 5S11 4.33 11 3.5 11.67 2 12.5 2 14 2.67 14 3.5M8.5 5C7.67 5 7 5.67 7 6.5S7.67 8 8.5 8 10 7.33 10 6.5 9.33 5 8.5 5M14 12L13.22 9.75H16.18L18.34 8.67C18.71 8.5 18.86 8.04 18.67 7.67C18.5 7.3 18.04 7.14 17.67 7.33L16.85 7.74L16.36 6.9C16.07 6.25 15.36 5.88 14.66 6.04L12.19 6.57C11.5 6.72 11 7.35 11 8.07V8.77L8.57 10.39H8.58C8.5 10.46 8.39 10.55 8.33 10.67L7.44 12.44L5.66 13.33C5.29 13.5 5.14 13.97 5.33 14.34C5.46 14.6 5.73 14.75 6 14.75C6.11 14.75 6.23 14.73 6.34 14.67L8.56 13.56L9.6 11.5L11 13C10 16 3 20 3 20S7 22 12 22 21 20 21 20 16 16 14 12M16.85 11.09L16.53 11.25H15.33L15.39 11.41C15.91 12.44 16.67 13.5 17.5 14.44L16.97 11.03L16.85 11.09Z\";\r\nvar mdiDancePole = \"M12 1V2L11.23 1.36L7.76 5.5L11 7.5V5.16L10.78 5L12 3.56V23H14V13.24L15.93 11.31C18.5 11.71 21.13 10.36 22.66 8.83L21.24 7.41C20.1 8.56 17.7 9.61 16 9.26L14 7.24V1M17 4A2 2 0 0 0 15 6A2 2 0 0 0 17 8A2 2 0 0 0 19 6A2 2 0 0 0 17 4M11 7.76L7.1 11.66C5.25 13.5 4.31 14.85 3.06 18.16L4.94 18.86C5.94 16.2 6.66 15.14 7.87 13.84L9.22 15.19L4.27 20.14L5.69 21.56L11 16.24Z\";\r\nvar mdiDataMatrix = \"M2 2V22H22V20H20V18H22V16H20V14H22V12H18V10H16V12H14V10H12V8H8V12H12V16H10V18H12V20H10V18H8V16H6V14H4V12H6V6H4V2H2M6 6H8V2H6V6M8 16H10V14H8V16M18 10H22V8H18V10M18 8V4H16V6H14V8H18M16 4V2H14V4H16M18 4H20V2H18V4M20 4V6H22V4H20M10 2V6H12V2H10M14 14H16V16H18V20H14V14M4 18H6V20H4V18Z\";\r\nvar mdiDataMatrixEdit = \"M20 12.1C19.9 12.1 19.7 12.2 19.6 12.3L18.6 13.3L20.7 15.4L21.7 14.4C21.9 14.2 21.9 13.8 21.7 13.6L20.4 12.3C20.3 12.2 20.2 12.1 20 12.1M18.1 13.9L12 19.9V22H14.1L20.2 15.9L18.1 13.9M8 6H6V2H8V6M10 16H8V14H10V16M12 6H10V2H12V6M16 2V4H14V2H16M20 4H18V2H20V4M10 20V18H8V16H6V14H4V12H6V6H4V2H2V22H10V20M6 20H4V18H6V20M22 10H18V8H22V10M20 6V4H22V6H20M18 4V8H14V6H16V4H18M10 18V16H12V12H8V8H12V10H14V12H16V10H18V11.1L15.1 14H14V15.1L11.1 18H10Z\";\r\nvar mdiDataMatrixMinus = \"M16 2V4H14V2H16M12 2H10V6H12V2M10 14H8V16H10V14M16 4V6H14V8H18V4H16M8 2H6V6H8V2M20 2H18V4H20V2M13.8 22H2V2H4V6H6V12H4V14H6V16H8V18H10V20H12V18H10V16H12V12H8V8H12V10H14V12H16V10H18V12H22V13.8C21.1 13.3 20.1 13 19 13C17.8 13 16.6 13.4 15.7 14H14V15.7C13.4 16.6 13 17.8 13 19C13 20.1 13.3 21.1 13.8 22M6 18H4V20H6V18M22 8H18V10H22V8M22 6V4H20V6H22M15 18V20H23V18H15Z\";\r\nvar mdiDataMatrixPlus = \"M16 2V4H14V2H16M12 2H10V6H12V2M10 14H8V16H10V14M16 4V6H14V8H18V4H16M8 2H6V6H8V2M20 2H18V4H20V2M13.8 22H2V2H4V6H6V12H4V14H6V16H8V18H10V20H12V18H10V16H12V12H8V8H12V10H14V12H16V10H18V12H22V13.8C21.1 13.3 20.1 13 19 13C17.8 13 16.6 13.4 15.7 14H14V15.7C13.4 16.6 13 17.8 13 19C13 20.1 13.3 21.1 13.8 22M6 18H4V20H6V18M22 8H18V10H22V8M22 6V4H20V6H22M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiDataMatrixRemove = \"M16 2V4H14V2H16M12 2H10V6H12V2M10 14H8V16H10V14M16 4V6H14V8H18V4H16M8 2H6V6H8V2M20 2H18V4H20V2M13.8 22H2V2H4V6H6V12H4V14H6V16H8V18H10V20H12V18H10V16H12V12H8V8H12V10H14V12H16V10H18V12H22V13.8C21.1 13.3 20.1 13 19 13C17.8 13 16.6 13.4 15.7 14H14V15.7C13.4 16.6 13 17.8 13 19C13 20.1 13.3 21.1 13.8 22M6 18H4V20H6V18M22 8H18V10H22V8M22 6V4H20V6H22M21.1 15.5L19 17.6L16.9 15.5L15.5 16.9L17.6 19L15.5 21.1L16.9 22.5L19 20.4L21.1 22.5L22.5 21.1L20.4 19L22.5 16.9L21.1 15.5Z\";\r\nvar mdiDataMatrixScan = \"M2 2H6V0H2C.9 0 0 .9 0 2V6H2V2M22 0H18V2H22V6H24V2C24 .9 23.1 0 22 0M2 18H0V22C0 23.1 .9 24 2 24H6V22H2V18M22 22H18V24H22C23.1 24 24 23.1 24 22V18H22V22M8 6V4H10V6H8M10 14V12H12V14H10M16 4H18V6H16V4M18 6H20V8H18V6M18 14H20V16H18V14M20 12H16V18H20V20H4V4H6V6H8V10H6V12H8V14H10V16H12V18H14V16H12V14H14V10H10V6H12V4H14V8H16V10H20V12M8 18V16H6V18H8Z\";\r\nvar mdiDatabase = \"M12,3C7.58,3 4,4.79 4,7C4,9.21 7.58,11 12,11C16.42,11 20,9.21 20,7C20,4.79 16.42,3 12,3M4,9V12C4,14.21 7.58,16 12,16C16.42,16 20,14.21 20,12V9C20,11.21 16.42,13 12,13C7.58,13 4,11.21 4,9M4,14V17C4,19.21 7.58,21 12,21C16.42,21 20,19.21 20,17V14C20,16.21 16.42,18 12,18C7.58,18 4,16.21 4,14Z\";\r\nvar mdiDatabaseCheck = \"M12 3C16.42 3 20 4.79 20 7S16.42 11 12 11 4 9.21 4 7 7.58 3 12 3M4 9C4 11.21 7.58 13 12 13S20 11.21 20 9V12.08L19 12C16.41 12 14.2 13.64 13.36 15.94L12 16C7.58 16 4 14.21 4 12V9M4 14C4 16.21 7.58 18 12 18H13C13 19.05 13.27 20.04 13.75 20.9L12 21C7.58 21 4 19.21 4 17V14M18 21.08L15.25 18.08L16.41 16.92L18 18.5L21.59 14.92L22.75 16.33L18 21.08\";\r\nvar mdiDatabaseEdit = \"M4,14V17C4,19 7.05,20.72 11,21V18.11L11.13,18C7.12,17.76 4,16.06 4,14M12,13C7.58,13 4,11.21 4,9V12C4,14.21 7.58,16 12,16C12.39,16 12.77,16 13.16,16L17,12.12C15.4,12.72 13.71,13 12,13M12,3C7.58,3 4,4.79 4,7C4,9.21 7.58,11 12,11C16.42,11 20,9.21 20,7C20,4.79 16.42,3 12,3M21,11.13C20.85,11.13 20.71,11.19 20.61,11.3L19.61,12.3L21.66,14.3L22.66,13.3C22.87,13.1 22.88,12.76 22.66,12.53L21.42,11.3C21.32,11.19 21.18,11.13 21.04,11.13M19.04,12.88L13,18.94V21H15.06L21.12,14.93L19.04,12.88Z\";\r\nvar mdiDatabaseExport = \"M12,3C7.58,3 4,4.79 4,7C4,9.21 7.58,11 12,11C12.5,11 13,10.97 13.5,10.92V9.5H16.39L15.39,8.5L18.9,5C17.5,3.8 14.94,3 12,3M18.92,7.08L17.5,8.5L20,11H15V13H20L17.5,15.5L18.92,16.92L23.84,12M4,9V12C4,14.21 7.58,16 12,16C13.17,16 14.26,15.85 15.25,15.63L16.38,14.5H13.5V12.92C13,12.97 12.5,13 12,13C7.58,13 4,11.21 4,9M4,14V17C4,19.21 7.58,21 12,21C14.94,21 17.5,20.2 18.9,19L17,17.1C15.61,17.66 13.9,18 12,18C7.58,18 4,16.21 4,14Z\";\r\nvar mdiDatabaseImport = \"M12,3C8.59,3 5.69,4.07 4.54,5.57L9.79,10.82C10.5,10.93 11.22,11 12,11C16.42,11 20,9.21 20,7C20,4.79 16.42,3 12,3M3.92,7.08L2.5,8.5L5,11H0V13H5L2.5,15.5L3.92,16.92L8.84,12M20,9C20,11.21 16.42,13 12,13C11.34,13 10.7,12.95 10.09,12.87L7.62,15.34C8.88,15.75 10.38,16 12,16C16.42,16 20,14.21 20,12M20,14C20,16.21 16.42,18 12,18C9.72,18 7.67,17.5 6.21,16.75L4.53,18.43C5.68,19.93 8.59,21 12,21C16.42,21 20,19.21 20,17\";\r\nvar mdiDatabaseLock = \"M11,3C15.42,3 19,4.79 19,7C19,9.21 15.42,11 11,11C6.58,11 3,9.21 3,7C3,4.79 6.58,3 11,3M19,12.03C17.11,12.24 15.57,13.62 15.13,15.43C13.92,15.79 12.5,16 11,16C6.58,16 3,14.21 3,12V9C3,11.21 6.58,13 11,13C15.42,13 19,11.21 19,9V12.03M14,17.71V20.71C13.07,20.9 12.06,21 11,21C6.58,21 3,19.21 3,17V14C3,16.21 6.58,18 11,18C12.06,18 13.07,17.9 14,17.71M19.5,14A2.5,2.5 0 0,1 22,16.5V17A1,1 0 0,1 23,18V22A1,1 0 0,1 22,23H17A1,1 0 0,1 16,22V18A1,1 0 0,1 17,17V16.5A2.5,2.5 0 0,1 19.5,14M19.5,15A1.5,1.5 0 0,0 18,16.5V17H21V16.5A1.5,1.5 0 0,0 19.5,15Z\";\r\nvar mdiDatabaseMarker = \"M18.5 12C16.6 12 15 13.6 15 15.5C15 18.1 18.5 22 18.5 22S22 18.1 22 15.5C22 13.6 20.4 12 18.5 12M18.5 16.8C17.8 16.8 17.3 16.2 17.3 15.6C17.3 14.9 17.9 14.4 18.5 14.4S19.7 15 19.7 15.6C19.8 16.2 19.2 16.8 18.5 16.8M4 12V9C4 11.21 7.58 13 12 13C12.57 13 13.13 12.97 13.67 12.91C13.25 13.69 13 14.57 13 15.5C13 15.65 13 15.81 13.03 15.96C12.69 16 12.35 16 12 16C7.58 16 4 14.21 4 12M4 7C4 4.79 7.58 3 12 3S20 4.79 20 7 16.42 11 12 11 4 9.21 4 7M15 20.71C14.07 20.9 13.06 21 12 21C7.58 21 4 19.21 4 17V14C4 16.21 7.58 18 12 18C12.5 18 13.03 17.97 13.5 17.93C13.9 18.91 14.44 19.87 15 20.71Z\";\r\nvar mdiDatabaseMinus = \"M23 17V19H15V17M12 3C16.42 3 20 4.79 20 7S16.42 11 12 11 4 9.21 4 7 7.58 3 12 3M4 9C4 11.21 7.58 13 12 13S20 11.21 20 9V12.08L19 12C16.41 12 14.2 13.64 13.36 15.94L12 16C7.58 16 4 14.21 4 12V9M4 14C4 16.21 7.58 18 12 18H13C13 19.05 13.27 20.04 13.75 20.9L12 21C7.58 21 4 19.21 4 17V14Z\";\r\nvar mdiDatabasePlus = \"M18,14H20V17H23V19H20V22H18V19H15V17H18V14M12,3C16.42,3 20,4.79 20,7C20,9.21 16.42,11 12,11C7.58,11 4,9.21 4,7C4,4.79 7.58,3 12,3M4,9C4,11.21 7.58,13 12,13C16.42,13 20,11.21 20,9V9L20,12.08L19,12C16.41,12 14.2,13.64 13.36,15.94L12,16C7.58,16 4,14.21 4,12V9M4,14C4,16.21 7.58,18 12,18H13C13,19.05 13.27,20.04 13.75,20.9L12,21C7.58,21 4,19.21 4,17V14Z\";\r\nvar mdiDatabaseRefresh = \"M12 3C16.42 3 20 4.79 20 7C20 9.21 16.42 11 12 11C7.58 11 4 9.21 4 7C4 4.79 7.58 3 12 3M4 9C4 11.21 7.58 13 12 13C13.11 13 14.18 12.89 15.14 12.68C14.19 13.54 13.5 14.67 13.18 15.96L12 16C7.58 16 4 14.21 4 12V9M20 9V11L19.5 11L18.9 11.03C19.6 10.43 20 9.74 20 9M4 14C4 16.21 7.58 18 12 18L13 17.97C13.09 19.03 13.42 20 13.95 20.88L12 21C7.58 21 4 19.21 4 17V14M19 13.5C20.11 13.5 21.11 13.95 21.83 14.67L23 13.5V17.5H19L20.77 15.73C20.32 15.28 19.69 15 19 15C17.62 15 16.5 16.12 16.5 17.5C16.5 18.88 17.62 20 19 20C19.82 20 20.54 19.61 21 19H22.71C22.12 20.47 20.68 21.5 19 21.5C16.79 21.5 15 19.71 15 17.5C15 15.29 16.79 13.5 19 13.5Z\";\r\nvar mdiDatabaseRemove = \"M15.46,15.88L16.88,14.46L19,16.59L21.12,14.47L22.53,15.88L20.41,18L22.54,20.12L21.12,21.54L19,19.41L16.88,21.53L15.47,20.12L17.59,18L15.46,15.88M12,3C16.42,3 20,4.79 20,7C20,9.21 16.42,11 12,11C7.58,11 4,9.21 4,7C4,4.79 7.58,3 12,3M4,9C4,11.21 7.58,13 12,13C16.42,13 20,11.21 20,9V12.08L19,12C16.41,12 14.2,13.64 13.36,15.94L12,16C7.58,16 4,14.21 4,12V9M4,14C4,16.21 7.58,18 12,18H13C13,19.05 13.27,20.04 13.75,20.9L12,21C7.58,21 4,19.21 4,17V14Z\";\r\nvar mdiDatabaseSearch = \"M18.68,12.32C16.92,10.56 14.07,10.57 12.32,12.33C10.56,14.09 10.56,16.94 12.32,18.69C13.81,20.17 16.11,20.43 17.89,19.32L21,22.39L22.39,21L19.3,17.89C20.43,16.12 20.17,13.8 18.68,12.32M17.27,17.27C16.29,18.25 14.71,18.24 13.73,17.27C12.76,16.29 12.76,14.71 13.74,13.73C14.71,12.76 16.29,12.76 17.27,13.73C18.24,14.71 18.24,16.29 17.27,17.27M10.9,20.1C10.25,19.44 9.74,18.65 9.42,17.78C6.27,17.25 4,15.76 4,14V17C4,19.21 7.58,21 12,21V21C11.6,20.74 11.23,20.44 10.9,20.1M4,9V12C4,13.68 6.07,15.12 9,15.7C9,15.63 9,15.57 9,15.5C9,14.57 9.2,13.65 9.58,12.81C6.34,12.3 4,10.79 4,9M12,3C7.58,3 4,4.79 4,7C4,9 7,10.68 10.85,11H10.9C12.1,9.74 13.76,9 15.5,9C16.41,9 17.31,9.19 18.14,9.56C19.17,9.09 19.87,8.12 20,7C20,4.79 16.42,3 12,3Z\";\r\nvar mdiDatabaseSettings = \"M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22M12,3C16.42,3 20,4.79 20,7C20,9.21 16.42,11 12,11C7.58,11 4,9.21 4,7C4,4.79 7.58,3 12,3M4,9C4,11.21 7.58,13 12,13C16.42,13 20,11.21 20,9V12C20,14.21 16.42,16 12,16C7.58,16 4,14.21 4,12V9M4,14C4,16.21 7.58,18 12,18C16.42,18 20,16.21 20,14V17C20,18.19 18.95,19.27 17.29,20H6.71C5.05,19.27 4,18.19 4,17V14Z\";\r\nvar mdiDatabaseSync = \"M19,12V13.5A4,4 0 0,1 23,17.5C23,18.32 22.75,19.08 22.33,19.71L21.24,18.62C21.41,18.28 21.5,17.9 21.5,17.5A2.5,2.5 0 0,0 19,15V16.5L16.75,14.25L19,12M19,23V21.5A4,4 0 0,1 15,17.5C15,16.68 15.25,15.92 15.67,15.29L16.76,16.38C16.59,16.72 16.5,17.1 16.5,17.5A2.5,2.5 0 0,0 19,20V18.5L21.25,20.75L19,23M12,3C16.42,3 20,4.79 20,7C20,9.21 16.42,11 12,11C7.58,11 4,9.21 4,7C4,4.79 7.58,3 12,3M4,9C4,11.21 7.58,13 12,13C13.11,13 14.17,12.89 15.14,12.68C14.19,13.54 13.5,14.67 13.18,15.96L12,16C7.58,16 4,14.21 4,12V9M20,9V11H19.5L18.9,11.03C19.6,10.43 20,9.74 20,9M4,14C4,16.21 7.58,18 12,18L13,17.97C13.09,19.03 13.42,20 13.95,20.88L12,21C7.58,21 4,19.21 4,17V14Z\";\r\nvar mdiDeathStar = \"M2.05,13H21.95C21.45,18.05 17.19,22 12,22C6.82,22 2.55,18.05 2.05,13M21.95,11H2.05C2.55,5.95 6.82,2 12,2C17.18,2 21.45,5.95 21.95,11M12,6.75A2.5,2.5 0 0,0 9.5,4.25A2.5,2.5 0 0,0 7,6.75A2.5,2.5 0 0,0 9.5,9.25A2.5,2.5 0 0,0 12,6.75Z\";\r\nvar mdiDeathStarVariant = \"M2.05,13H21.94C21.88,13.69 21.74,14.36 21.54,15H14V17H17V19H15V21H12.5V22C12.33,22 12.17,22 12,22C6.82,22 2.55,18.05 2.05,13M21.94,11H2.05C2.55,5.95 6.82,2 12,2C13.62,2 15.15,2.39 16.5,3.08V5H18.5V7H20V9H21.54C21.74,9.64 21.88,10.31 21.94,11M12,6.75A2.5,2.5 0 0,0 9.5,4.25A2.5,2.5 0 0,0 7,6.75A2.5,2.5 0 0,0 9.5,9.25A2.5,2.5 0 0,0 12,6.75Z\";\r\nvar mdiDeathlyHallows = \"M12,2L1,21H23L12,2M12.75,11.47C14.56,11.87 15.7,13.67 15.3,15.5C15,16.75 14,17.75 12.75,18.03V11.47M11.25,18C9.44,17.6 8.3,15.8 8.7,14C9,12.72 10,11.72 11.25,11.44V18M16.88,14.72C16.83,12.35 15.09,10.36 12.75,10V6.29L20.4,19.5H13.07C15.29,19 16.87,17.03 16.88,14.75V14.72M11.25,6.29V10C8.6,10.4 6.77,12.88 7.18,15.54C7.5,17.5 8.97,19.12 10.93,19.55H3.6L11.25,6.29Z\";\r\nvar mdiDebian = \"M18.5,10.57L18.3,10.94C18.56,10.16 18.41,9.31 18.45,8.57L18.38,8.55C18.31,6.7 16.71,4.73 15.29,4.07C14.06,3.5 12.17,3.4 11.3,3.83C11.42,3.72 11.9,3.68 11.75,3.6C10.38,3.73 10.69,4.07 9.64,4.34C9.35,4.62 10.5,4.12 9.87,4.5C9.31,4.63 9.05,4.38 8.22,5.24C8.29,5.36 8.75,4.89 8.37,5.36C7.58,5.27 5.89,7.16 5.53,7.78L5.72,7.82C5.41,8.59 5,9.08 4.95,9.54C4.87,10.68 4.5,12.75 5.03,13.39L4.97,13.92L5.2,14.37L5.08,14.38C5.66,16.21 5.7,14.42 6.47,16.32C6.36,16.28 6.24,16.24 6.08,16C6.06,16.19 6.32,16.69 6.62,17.08L6.5,17.22C6.66,17.53 6.82,17.6 6.93,17.71C6.3,17.36 7.5,18.84 7.63,19.03L7.73,18.86C7.71,19.1 7.9,19.42 8.26,19.87L8.56,19.86C8.69,20.1 9.14,20.54 9.41,20.56L9.23,20.8C9.92,21 9.56,21.09 10.41,21.39L10.24,21.09C10.67,21.46 10.8,21.79 11.41,22.07C12.26,22.37 12.37,22.25 13.23,22.5C12.5,22.5 11.64,22.5 11.06,22.28C7.1,21.21 3.5,16.56 3.74,11.78C3.68,10.81 3.84,9.6 3.68,9.36C3.9,8.62 4.16,7.72 4.69,6.65C4.65,6.58 4.78,6.86 5.05,6.41C5.21,6.05 5.34,5.66 5.55,5.31L5.65,5.28C5.76,4.67 7.08,3.73 7.5,3.26V3.44C8.36,2.63 9.9,2.09 10.76,1.71C10.53,1.96 11.27,1.68 11.8,1.65L11.31,1.93C11.94,1.77 11.91,2 12.56,1.9C12.33,1.93 12.06,2 12.1,2.06C12.82,2.14 12.94,1.84 13.61,2.06L13.56,1.86C14.5,2.2 14.69,2.14 15.7,2.68C16.06,2.69 16.1,2.46 16.63,2.68C16.73,2.84 16.61,2.87 17.27,3.27C17.34,3.24 17.14,3.05 17,2.9C18.3,3.61 19.75,5.12 20.18,6.74C19.77,6 20.14,7.13 20,7.07C20.18,7.56 20.33,8.07 20.43,8.6C20.31,8.17 20.04,7.12 19.57,6.45C19.54,6.88 18.97,6.15 19.28,7.11C19.5,7.45 19.33,6.76 19.62,7.36C19.62,7.65 19.73,7.94 19.8,8.31C19.7,8.29 19.58,7.9 19.5,8C19.6,8.5 19.77,8.72 19.83,8.76C19.8,8.84 19.71,8.68 19.71,9C19.75,9.74 19.92,9.43 20,9.46C19.91,9.83 19.59,10.25 19.75,10.88L19.55,10.32C19.5,10.85 19.66,10.95 19.42,11.6C19.6,11 19.58,10.5 19.41,10.75C19.5,11.57 18.76,12.2 18.83,12.73L18.62,12.44C18.05,13.27 18.61,12.89 18.22,13.5C18.36,13.27 18.15,13.42 18.33,13.14C18.21,13.15 17.78,13.67 17.39,13.97C15.85,15.2 14,15.37 12.24,14.7H12.23C12.24,14.66 12.23,14.61 12.11,14.53C10.6,13.38 9.71,12.4 10,10.12C10.25,9.95 10.31,9 10.84,8.67C11.16,7.96 12.12,7.31 13.15,7.29C14.2,7.23 15.09,7.85 15.54,8.43C14.72,7.68 13.4,7.45 12.26,8C11.11,8.53 10.42,9.8 10.5,11.07C10.56,11 10.6,11.05 10.62,10.89C10.59,13.36 13.28,15.17 15.22,14.26L15.25,14.31C16.03,14.09 15.93,13.92 16.44,13.56C16.4,13.65 16.1,13.86 16.28,13.86C16.53,13.8 17.31,13.07 17.7,12.73C17.87,12.35 17.6,12.5 17.85,12.04L18.15,11.89C18.32,11.41 18.5,11.14 18.5,10.57\";\r\nvar mdiDebugStepInto = \"M12,22A2,2 0 0,1 10,20A2,2 0 0,1 12,18A2,2 0 0,1 14,20A2,2 0 0,1 12,22M13,2V13L17.5,8.5L18.92,9.92L12,16.84L5.08,9.92L6.5,8.5L11,13V2H13Z\";\r\nvar mdiDebugStepOut = \"M12,22A2,2 0 0,1 10,20A2,2 0 0,1 12,18A2,2 0 0,1 14,20A2,2 0 0,1 12,22M13,16H11V6L6.5,10.5L5.08,9.08L12,2.16L18.92,9.08L17.5,10.5L13,6V16Z\";\r\nvar mdiDebugStepOver = \"M12,14A2,2 0 0,1 14,16A2,2 0 0,1 12,18A2,2 0 0,1 10,16A2,2 0 0,1 12,14M23.46,8.86L21.87,15.75L15,14.16L18.8,11.78C17.39,9.5 14.87,8 12,8C8.05,8 4.77,10.86 4.12,14.63L2.15,14.28C2.96,9.58 7.06,6 12,6C15.58,6 18.73,7.89 20.5,10.72L23.46,8.86Z\";\r\nvar mdiDecagram = \"M23,12L20.56,9.22L20.9,5.54L17.29,4.72L15.4,1.54L12,3L8.6,1.54L6.71,4.72L3.1,5.53L3.44,9.21L1,12L3.44,14.78L3.1,18.47L6.71,19.29L8.6,22.47L12,21L15.4,22.46L17.29,19.28L20.9,18.46L20.56,14.78L23,12Z\";\r\nvar mdiDecagramOutline = \"M23,12L20.56,14.78L20.9,18.46L17.29,19.28L15.4,22.46L12,21L8.6,22.47L6.71,19.29L3.1,18.47L3.44,14.78L1,12L3.44,9.21L3.1,5.53L6.71,4.72L8.6,1.54L12,3L15.4,1.54L17.29,4.72L20.9,5.54L20.56,9.22L23,12M20.33,12L18.5,9.89L18.74,7.1L16,6.5L14.58,4.07L12,5.18L9.42,4.07L8,6.5L5.26,7.09L5.5,9.88L3.67,12L5.5,14.1L5.26,16.9L8,17.5L9.42,19.93L12,18.81L14.58,19.92L16,17.5L18.74,16.89L18.5,14.1L20.33,12Z\";\r\nvar mdiDecimal = \"M10 7A3 3 0 0 0 7 10V13A3 3 0 0 0 13 13V10A3 3 0 0 0 10 7M11 13A1 1 0 0 1 9 13V10A1 1 0 0 1 11 10M17 7A3 3 0 0 0 14 10V13A3 3 0 0 0 20 13V10A3 3 0 0 0 17 7M18 13A1 1 0 0 1 16 13V10A1 1 0 0 1 18 10M6 15A1 1 0 1 1 5 14A1 1 0 0 1 6 15Z\";\r\nvar mdiDecimalComma = \"M10 7A3 3 0 0 1 13 10V13A3 3 0 0 1 7 13V10A3 3 0 0 1 10 7M10 9A1 1 0 0 0 9 10V13A1 1 0 0 0 11 13V10A1 1 0 0 0 10 9M17 7A3 3 0 0 1 20 10V13A3 3 0 0 1 14 13V10A3 3 0 0 1 17 7M17 9A1 1 0 0 0 16 10V13A1 1 0 0 0 18 13V10A1 1 0 0 0 17 9M5 14A1 1 0 0 0 4 15L5 18H6V15A1 1 0 0 0 5 14Z\";\r\nvar mdiDecimalCommaDecrease = \"M5 13V16H4L3 13A1 1 0 0 1 5 13M15 16V14L12 17L15 20V18H21V16M12 11A3 3 0 0 1 6 11V8A3 3 0 0 1 12 8M10 8A1 1 0 0 0 8 8V11A1 1 0 0 0 10 11Z\";\r\nvar mdiDecimalCommaIncrease = \"M9 5A3 3 0 0 0 6 8V11A3 3 0 0 0 12 11V8A3 3 0 0 0 9 5M10 11A1 1 0 0 1 8 11V8A1 1 0 0 1 10 8M16 14A3 3 0 0 0 19 11V8A3 3 0 0 0 13 8V11A3 3 0 0 0 16 14M15 8A1 1 0 0 1 17 8V11A1 1 0 0 1 15 11M19 20V18H13V16H19V14L22 17M5 13V16H4L3 13A1 1 0 0 1 5 13Z\";\r\nvar mdiDecimalDecrease = \"M12,17L15,20V18H21V16H15V14L12,17M9,5A3,3 0 0,1 12,8V11A3,3 0 0,1 9,14A3,3 0 0,1 6,11V8A3,3 0 0,1 9,5M9,7A1,1 0 0,0 8,8V11A1,1 0 0,0 9,12A1,1 0 0,0 10,11V8A1,1 0 0,0 9,7M4,12A1,1 0 0,1 5,13A1,1 0 0,1 4,14A1,1 0 0,1 3,13A1,1 0 0,1 4,12Z\";\r\nvar mdiDecimalIncrease = \"M22,17L19,20V18H13V16H19V14L22,17M9,5A3,3 0 0,1 12,8V11A3,3 0 0,1 9,14A3,3 0 0,1 6,11V8A3,3 0 0,1 9,5M9,7A1,1 0 0,0 8,8V11A1,1 0 0,0 9,12A1,1 0 0,0 10,11V8A1,1 0 0,0 9,7M16,5A3,3 0 0,1 19,8V11A3,3 0 0,1 16,14A3,3 0 0,1 13,11V8A3,3 0 0,1 16,5M16,7A1,1 0 0,0 15,8V11A1,1 0 0,0 16,12A1,1 0 0,0 17,11V8A1,1 0 0,0 16,7M4,12A1,1 0 0,1 5,13A1,1 0 0,1 4,14A1,1 0 0,1 3,13A1,1 0 0,1 4,12Z\";\r\nvar mdiDelete = \"M19,4H15.5L14.5,3H9.5L8.5,4H5V6H19M6,19A2,2 0 0,0 8,21H16A2,2 0 0,0 18,19V7H6V19Z\";\r\nvar mdiDeleteAlert = \"M17 4V6H3V4H6.5L7.5 3H12.5L13.5 4H17M4 19V7H16V19C16 20.1 15.1 21 14 21H6C4.9 21 4 20.1 4 19M19 15H21V17H19V15M19 7H21V13H19V7Z\";\r\nvar mdiDeleteAlertOutline = \"M4 19V7H16V19C16 20.1 15.1 21 14 21H6C4.9 21 4 20.1 4 19M6 9V19H14V9H6M13.5 4H17V6H3V4H6.5L7.5 3H12.5L13.5 4M19 17V15H21V17H19M19 13V7H21V13H19Z\";\r\nvar mdiDeleteCircle = \"M12,2C17.53,2 22,6.47 22,12C22,17.53 17.53,22 12,22C6.47,22 2,17.53 2,12C2,6.47 6.47,2 12,2M17,7H14.5L13.5,6H10.5L9.5,7H7V9H17V7M9,18H15A1,1 0 0,0 16,17V10H8V17A1,1 0 0,0 9,18Z\";\r\nvar mdiDeleteCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M16,10V17A1,1 0 0,1 15,18H9A1,1 0 0,1 8,17V10H16M13.5,6L14.5,7H17V9H7V7H9.5L10.5,6H13.5Z\";\r\nvar mdiDeleteClock = \"M15 13H16.5V15.82L18.94 17.23L18.19 18.53L15 16.69V13M23 16C23 19.87 19.87 23 16 23C14.09 23 12.36 22.24 11.1 21H8C6.9 21 6 20.1 6 19V7H18V9.29C20.89 10.15 23 12.83 23 16M16 11C13.24 11 11 13.24 11 16C11 18.76 13.24 21 16 21C18.76 21 21 18.76 21 16C21 13.24 18.76 11 16 11M19 4V6H5V4H8.5L9.5 3H14.5L15.5 4H19Z\";\r\nvar mdiDeleteClockOutline = \"M15 13H16.5V15.82L18.94 17.23L18.19 18.53L15 16.69V13M23 16C23 19.87 19.87 23 16 23C14.09 23 12.36 22.24 11.1 21H8C6.9 21 6 20.1 6 19V7H18V9.29C20.89 10.15 23 12.83 23 16M9 16C9 12.13 12.13 9 16 9H8V19H9.67C9.24 18.09 9 17.07 9 16M16 11C13.24 11 11 13.24 11 16C11 18.76 13.24 21 16 21C18.76 21 21 18.76 21 16C21 13.24 18.76 11 16 11M15.5 4H19V6H5V4H8.5L9.5 3H14.5L15.5 4Z\";\r\nvar mdiDeleteEmpty = \"M20.37,8.91L19.37,10.64L7.24,3.64L8.24,1.91L11.28,3.66L12.64,3.29L16.97,5.79L17.34,7.16L20.37,8.91M6,19V7H11.07L18,11V19A2,2 0 0,1 16,21H8A2,2 0 0,1 6,19Z\";\r\nvar mdiDeleteEmptyOutline = \"M20.37,8.91L19.37,10.64L7.24,3.64L8.24,1.91L11.28,3.66L12.64,3.29L16.97,5.79L17.34,7.16L20.37,8.91M6,19V7H11.07L18,11V19A2,2 0 0,1 16,21H8A2,2 0 0,1 6,19M8,19H16V12.2L10.46,9H8V19Z\";\r\nvar mdiDeleteForever = \"M6,19A2,2 0 0,0 8,21H16A2,2 0 0,0 18,19V7H6V19M8.46,11.88L9.87,10.47L12,12.59L14.12,10.47L15.53,11.88L13.41,14L15.53,16.12L14.12,17.53L12,15.41L9.88,17.53L8.47,16.12L10.59,14L8.46,11.88M15.5,4L14.5,3H9.5L8.5,4H5V6H19V4H15.5Z\";\r\nvar mdiDeleteForeverOutline = \"M14.12,10.47L12,12.59L9.87,10.47L8.46,11.88L10.59,14L8.47,16.12L9.88,17.53L12,15.41L14.12,17.53L15.53,16.12L13.41,14L15.53,11.88L14.12,10.47M15.5,4L14.5,3H9.5L8.5,4H5V6H19V4H15.5M6,19A2,2 0 0,0 8,21H16A2,2 0 0,0 18,19V7H6V19M8,9H16V19H8V9Z\";\r\nvar mdiDeleteOff = \"M2 5.27L3.28 4L5 5.72L5.28 6L6.28 7L18 18.72L20 20.72L18.73 22L17.27 20.54C16.93 20.83 16.5 21 16 21H8C6.9 21 6 20.1 6 19V9.27L2 5.27M19 4V6H7.82L5.82 4H8.5L9.5 3H14.5L15.5 4H19M18 7V16.18L8.82 7H18Z\";\r\nvar mdiDeleteOffOutline = \"M2 5.27L3.28 4L5 5.72L5.28 6L6.28 7L8.28 9L16 16.72L18 18.72L20 20.72L18.73 22L17.27 20.54C16.93 20.83 16.5 21 16 21H8C6.9 21 6 20.1 6 19V9.27L2 5.27M8 19H15.73L8 11.27V19M18 7V16.18L16 14.18V9H10.82L8.82 7H18M15.5 4H19V6H7.82L5.82 4H8.5L9.5 3H14.5L15.5 4Z\";\r\nvar mdiDeleteOutline = \"M6,19A2,2 0 0,0 8,21H16A2,2 0 0,0 18,19V7H6V19M8,9H16V19H8V9M15.5,4L14.5,3H9.5L8.5,4H5V6H19V4H15.5Z\";\r\nvar mdiDeleteRestore = \"M14,14H16L12,10L8,14H10V18H14V14M6,7H18V19C18,19.5 17.8,20 17.39,20.39C17,20.8 16.5,21 16,21H8C7.5,21 7,20.8 6.61,20.39C6.2,20 6,19.5 6,19V7M19,4V6H5V4H8.5L9.5,3H14.5L15.5,4H19Z\";\r\nvar mdiDeleteSweep = \"M15,16H19V18H15V16M15,8H22V10H15V8M15,12H21V14H15V12M3,18A2,2 0 0,0 5,20H11A2,2 0 0,0 13,18V8H3V18M14,5H11L10,4H6L5,5H2V7H14V5Z\";\r\nvar mdiDeleteSweepOutline = \"M15,16H19V18H15V16M15,8H22V10H15V8M15,12H21V14H15V12M11,10V18H5V10H11M13,8H3V18A2,2 0 0,0 5,20H11A2,2 0 0,0 13,18V8M14,5H11L10,4H6L5,5H2V7H14V5Z\";\r\nvar mdiDeleteVariant = \"M21.03,3L18,20.31C17.83,21.27 17,22 16,22H8C7,22 6.17,21.27 6,20.31L2.97,3H21.03M5.36,5L8,20H16L18.64,5H5.36M9,18V14H13V18H9M13,13.18L9.82,10L13,6.82L16.18,10L13,13.18Z\";\r\nvar mdiDelta = \"M12,7.77L18.39,18H5.61L12,7.77M12,4L2,20H22\";\r\nvar mdiDesk = \"M3 6H21C21.55 6 22 6.45 22 7C22 7.55 21.55 8 21 8V19H19V17H15V19H13V8H5V19H3V8C2.45 8 2 7.55 2 7C2 6.45 2.45 6 3 6M16 10.5V11H18V10.5C18 10.22 17.78 10 17.5 10H16.5C16.22 10 16 10.22 16 10.5M16 14.5V15H18V14.5C18 14.22 17.78 14 17.5 14H16.5C16.22 14 16 14.22 16 14.5Z\";\r\nvar mdiDeskLamp = \"M10.85,2L9.18,4.5L10.32,5.25L7.14,10C7.1,10 7.05,10 7,10A2,2 0 0,0 5,12C5,12.94 5.66,13.75 6.58,13.95L10.62,20H7V22H17V20H13L8.53,13.28C8.83,12.92 9,12.47 9,12C9,11.7 8.93,11.4 8.8,11.13L12,6.37C11.78,8.05 12.75,9.89 14.45,11L18.89,4.37C17.2,3.24 15.12,3.04 13.65,3.87L10.85,2M18.33,7L16.67,9.5C17.35,9.95 18.29,9.77 18.75,9.08C19.21,8.39 19,7.46 18.33,7Z\";\r\nvar mdiDeskphone = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M15,5V19H19V5H15M5,5V9H13V5H5M5,11V13H7V11H5M8,11V13H10V11H8M11,11V13H13V11H11M5,14V16H7V14H5M8,14V16H10V14H8M11,14V16H13V14H11M11,17V19H13V17H11M8,17V19H10V17H8M5,17V19H7V17H5Z\";\r\nvar mdiDesktopClassic = \"M6,2C4.89,2 4,2.89 4,4V12C4,13.11 4.89,14 6,14H18C19.11,14 20,13.11 20,12V4C20,2.89 19.11,2 18,2H6M6,4H18V12H6V4M4,15C2.89,15 2,15.89 2,17V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V17C22,15.89 21.11,15 20,15H4M8,17H20V20H8V17M9,17.75V19.25H13V17.75H9M15,17.75V19.25H19V17.75H15Z\";\r\nvar mdiDesktopMac = \"M21,14H3V4H21M21,2H3C1.89,2 1,2.89 1,4V16A2,2 0 0,0 3,18H10L8,21V22H16V21L14,18H21A2,2 0 0,0 23,16V4C23,2.89 22.1,2 21,2Z\";\r\nvar mdiDesktopMacDashboard = \"M21,14V4H3V14H21M21,2A2,2 0 0,1 23,4V16A2,2 0 0,1 21,18H14L16,21V22H8V21L10,18H3C1.89,18 1,17.1 1,16V4C1,2.89 1.89,2 3,2H21M4,5H15V10H4V5M16,5H20V7H16V5M20,8V13H16V8H20M4,11H9V13H4V11M10,11H15V13H10V11Z\";\r\nvar mdiDesktopTower = \"M8,2H16A2,2 0 0,1 18,4V20A2,2 0 0,1 16,22H8A2,2 0 0,1 6,20V4A2,2 0 0,1 8,2M8,4V6H16V4H8M16,8H8V10H16V8M16,18H14V20H16V18Z\";\r\nvar mdiDesktopTowerMonitor = \"M22,18H17A1,1 0 0,1 16,17V7A1,1 0 0,1 17,6H22A1,1 0 0,1 23,7V17A1,1 0 0,1 22,18M22,8H17V9H22V8M22,10H17V11H22V10M9,15V17H10V18H5V17H6V15H2A1,1 0 0,1 1,14V7A1,1 0 0,1 2,6H13A1,1 0 0,1 14,7V14A1,1 0 0,1 13,15H9M12,8H3V13H12V8Z\";\r\nvar mdiDetails = \"M6.38,6H17.63L12,16L6.38,6M3,4L12,20L21,4H3Z\";\r\nvar mdiDevTo = \"M7.73 11.93C7.73 13.65 7.71 13.76 7.5 14C7.31 14.17 7.12 14.23 6.74 14.23L6.23 14.24L6.2 11.97L6.18 9.7H6.7C7.05 9.7 7.3 9.77 7.47 9.91C7.71 10.12 7.73 10.16 7.73 11.93M22 7.5V16.5C22 17.61 21.11 18.5 20 18.5H4C2.89 18.5 2 17.61 2 16.5V7.5C2 6.39 2.89 5.5 4 5.5H20C21.11 5.5 22 6.39 22 7.5M8.93 11.73C8.9 9.89 8.88 9.74 8.64 9.34C8.24 8.66 7.79 8.5 6.28 8.5H5V15.5H6.21C7.54 15.5 8.1 15.33 8.5 14.79C8.91 14.26 9 13.81 8.93 11.73M13.12 8.5H11.64C10.15 8.5 10.14 8.5 9.93 8.78S9.7 9.21 9.7 12V14.96L9.97 15.23C10.22 15.5 10.28 15.5 11.68 15.5H13.12V14.31L12.03 14.27L10.93 14.24V12.6L11.61 12.57L12.27 12.53V11.34H10.88V9.7H13.12V8.5M19 8.56C19 8.5 18.7 8.5 18.34 8.5L17.66 8.56L17.07 10.91C16.69 12.39 16.45 13.18 16.4 13.04C16.32 12.77 15.26 8.6 15.26 8.55C15.26 8.5 14.95 8.5 14.58 8.5H13.89L14.3 10.05C14.5 10.92 14.89 12.33 15.11 13.2C15.45 14.55 15.57 14.85 15.86 15.14C16.06 15.36 16.31 15.5 16.47 15.5C16.8 15.5 17.23 15.16 17.37 14.77C17.5 14.5 19 8.69 19 8.56Z\";\r\nvar mdiDeveloperBoard = \"M22,9V7H20V5A2,2 0 0,0 18,3H4A2,2 0 0,0 2,5V19A2,2 0 0,0 4,21H18A2,2 0 0,0 20,19V17H22V15H20V13H22V11H20V9H22M18,19H4V5H18V19M6,13H11V17H6V13M12,7H16V10H12V7M6,7H11V12H6V7M12,11H16V17H12V11Z\";\r\nvar mdiDeviantart = \"M6,6H12L14,2H18V6L14.5,13H18V18H12L10,22H6V18L9.5,11H6V6Z\";\r\nvar mdiDevices = \"M3 6H21V4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H7V18H3V6M13 12H9V13.78C8.39 14.33 8 15.11 8 16C8 16.89 8.39 17.67 9 18.22V20H13V18.22C13.61 17.67 14 16.88 14 16S13.61 14.33 13 13.78V12M11 17.5C10.17 17.5 9.5 16.83 9.5 16S10.17 14.5 11 14.5 12.5 15.17 12.5 16 11.83 17.5 11 17.5M22 8H16C15.5 8 15 8.5 15 9V19C15 19.5 15.5 20 16 20H22C22.5 20 23 19.5 23 19V9C23 8.5 22.5 8 22 8M21 18H17V10H21V18Z\";\r\nvar mdiDiabetes = \"M14.73 2.29A1 1 0 0 1 16.14 3.7L13 6.79L13.76 7.74L15.7 12.74A1.46 1.46 0 0 1 15.36 14.29L12.27 17.38A1.55 1.55 0 0 1 10.15 17.38L5.55 12.78A1.37 1.37 0 0 1 5.15 11.78L4.65 5.34H5.72A1 1 0 0 1 6.47 5.64L6.61 5.81L7.66 9.29M7.66 22L2 16.36L4.12 14.24L9.78 19.9M19.5 4.5S17 7.26 17 9A2.5 2.5 0 1 0 22 9C22 7.26 19.5 4.5 19.5 4.5Z\";\r\nvar mdiDialpad = \"M12,19A2,2 0 0,0 10,21A2,2 0 0,0 12,23A2,2 0 0,0 14,21A2,2 0 0,0 12,19M6,1A2,2 0 0,0 4,3A2,2 0 0,0 6,5A2,2 0 0,0 8,3A2,2 0 0,0 6,1M6,7A2,2 0 0,0 4,9A2,2 0 0,0 6,11A2,2 0 0,0 8,9A2,2 0 0,0 6,7M6,13A2,2 0 0,0 4,15A2,2 0 0,0 6,17A2,2 0 0,0 8,15A2,2 0 0,0 6,13M18,5A2,2 0 0,0 20,3A2,2 0 0,0 18,1A2,2 0 0,0 16,3A2,2 0 0,0 18,5M12,13A2,2 0 0,0 10,15A2,2 0 0,0 12,17A2,2 0 0,0 14,15A2,2 0 0,0 12,13M18,13A2,2 0 0,0 16,15A2,2 0 0,0 18,17A2,2 0 0,0 20,15A2,2 0 0,0 18,13M18,7A2,2 0 0,0 16,9A2,2 0 0,0 18,11A2,2 0 0,0 20,9A2,2 0 0,0 18,7M12,7A2,2 0 0,0 10,9A2,2 0 0,0 12,11A2,2 0 0,0 14,9A2,2 0 0,0 12,7M12,1A2,2 0 0,0 10,3A2,2 0 0,0 12,5A2,2 0 0,0 14,3A2,2 0 0,0 12,1Z\";\r\nvar mdiDiameter = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M17,15V13H7V15L4,12L7,9V11H17V9L20,12L17,15Z\";\r\nvar mdiDiameterOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M16,15V13H8V15L5,12L8,9V11H16V9L19,12L16,15Z\";\r\nvar mdiDiameterVariant = \"M4.15,21.46L5.47,19.58C3.35,17.74 2,15.03 2,12A10,10 0 0,1 12,2C13.78,2 15.44,2.46 16.89,3.27L18.21,1.39L19.85,2.54L18.53,4.42C20.65,6.26 22,8.97 22,12A10,10 0 0,1 12,22C10.22,22 8.56,21.54 7.11,20.73L5.79,22.61L4.15,21.46M12,4A8,8 0 0,0 4,12C4,14.35 5,16.46 6.63,17.93L15.73,4.92C14.62,4.33 13.35,4 12,4M12,20A8,8 0 0,0 20,12C20,9.65 19,7.54 17.37,6.07L8.27,19.08C9.38,19.67 10.65,20 12,20Z\";\r\nvar mdiDiamond = \"M6,2L2,8L12,22L22,8L18,2H6Z\";\r\nvar mdiDiamondOutline = \"M18,2H6L2,8L12,22L22,8L18,2M4.43,8L7.07,4H16.93L19.57,8L12,18.56L4.43,8Z\";\r\nvar mdiDiamondStone = \"M16,9H19L14,16M10,9H14L12,17M5,9H8L10,16M15,4H17L19,7H16M11,4H13L14,7H10M7,4H9L8,7H5M6,2L2,8L12,22L22,8L18,2H6Z\";\r\nvar mdiDice1 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiDice1Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M12 10.5C11.17 10.5 10.5 11.17 10.5 12S11.17 13.5 12 13.5 13.5 12.83 13.5 12 12.83 10.5 12 10.5\";\r\nvar mdiDice2 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15Z\";\r\nvar mdiDice2Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M7.5 6C6.67 6 6 6.67 6 7.5S6.67 9 7.5 9 9 8.33 9 7.5 8.33 6 7.5 6M16.5 15C15.67 15 15 15.67 15 16.5C15 17.33 15.67 18 16.5 18C17.33 18 18 17.33 18 16.5C18 15.67 17.33 15 16.5 15Z\";\r\nvar mdiDice3 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15Z\";\r\nvar mdiDice3Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M12 10.5C11.2 10.5 10.5 11.2 10.5 12S11.2 13.5 12 13.5 13.5 12.8 13.5 12 12.8 10.5 12 10.5M7.5 6C6.7 6 6 6.7 6 7.5S6.7 9 7.5 9 9 8.3 9 7.5 8.3 6 7.5 6M16.5 15C15.7 15 15 15.7 15 16.5C15 17.3 15.7 18 16.5 18C17.3 18 18 17.3 18 16.5C18 15.7 17.3 15 16.5 15Z\";\r\nvar mdiDice4 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15M17,5A2,2 0 0,0 15,7A2,2 0 0,0 17,9A2,2 0 0,0 19,7A2,2 0 0,0 17,5M7,15A2,2 0 0,0 5,17A2,2 0 0,0 7,19A2,2 0 0,0 9,17A2,2 0 0,0 7,15Z\";\r\nvar mdiDice4Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.9 20.11 3 19 3M7.5 6C6.67 6 6 6.67 6 7.5S6.67 9 7.5 9 9 8.33 9 7.5 8.33 6 7.5 6M16.5 15C15.67 15 15 15.67 15 16.5C15 17.33 15.67 18 16.5 18C17.33 18 18 17.33 18 16.5C18 15.67 17.33 15 16.5 15M16.5 6C15.67 6 15 6.67 15 7.5S15.67 9 16.5 9C17.33 9 18 8.33 18 7.5S17.33 6 16.5 6M7.5 15C6.67 15 6 15.67 6 16.5C6 17.33 6.67 18 7.5 18S9 17.33 9 16.5C9 15.67 8.33 15 7.5 15Z\";\r\nvar mdiDice5 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15M17,5A2,2 0 0,0 15,7A2,2 0 0,0 17,9A2,2 0 0,0 19,7A2,2 0 0,0 17,5M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M7,15A2,2 0 0,0 5,17A2,2 0 0,0 7,19A2,2 0 0,0 9,17A2,2 0 0,0 7,15Z\";\r\nvar mdiDice5Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M7.5 6C6.7 6 6 6.7 6 7.5S6.7 9 7.5 9 9 8.3 9 7.5 8.3 6 7.5 6M16.5 15C15.7 15 15 15.7 15 16.5C15 17.3 15.7 18 16.5 18C17.3 18 18 17.3 18 16.5C18 15.7 17.3 15 16.5 15M16.5 6C15.7 6 15 6.7 15 7.5S15.7 9 16.5 9C17.3 9 18 8.3 18 7.5S17.3 6 16.5 6M12 10.5C11.2 10.5 10.5 11.2 10.5 12S11.2 13.5 12 13.5 13.5 12.8 13.5 12 12.8 10.5 12 10.5M7.5 15C6.7 15 6 15.7 6 16.5C6 17.3 6.7 18 7.5 18S9 17.3 9 16.5C9 15.7 8.3 15 7.5 15Z\";\r\nvar mdiDice6 = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15M17,10A2,2 0 0,0 15,12A2,2 0 0,0 17,14A2,2 0 0,0 19,12A2,2 0 0,0 17,10M17,5A2,2 0 0,0 15,7A2,2 0 0,0 17,9A2,2 0 0,0 19,7A2,2 0 0,0 17,5M7,10A2,2 0 0,0 5,12A2,2 0 0,0 7,14A2,2 0 0,0 9,12A2,2 0 0,0 7,10M7,15A2,2 0 0,0 5,17A2,2 0 0,0 7,19A2,2 0 0,0 9,17A2,2 0 0,0 7,15Z\";\r\nvar mdiDice6Outline = \"M19 5V19H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M7.5 6C6.7 6 6 6.7 6 7.5S6.7 9 7.5 9 9 8.3 9 7.5 8.3 6 7.5 6M16.5 15C15.7 15 15 15.7 15 16.5C15 17.3 15.7 18 16.5 18C17.3 18 18 17.3 18 16.5C18 15.7 17.3 15 16.5 15M16.5 10.5C15.7 10.5 15 11.2 15 12S15.7 13.5 16.5 13.5C17.3 13.5 18 12.8 18 12S17.3 10.5 16.5 10.5M16.5 6C15.7 6 15 6.7 15 7.5S15.7 9 16.5 9C17.3 9 18 8.3 18 7.5S17.3 6 16.5 6M7.5 10.5C6.7 10.5 6 11.2 6 12S6.7 13.5 7.5 13.5 9 12.8 9 12 8.3 10.5 7.5 10.5M7.5 15C6.7 15 6 15.7 6 16.5C6 17.3 6.7 18 7.5 18S9 17.3 9 16.5C9 15.7 8.3 15 7.5 15Z\";\r\nvar mdiDiceD10 = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M14.07 8.21C15.5 8.21 16.64 9.36 16.64 10.78V13.42C16.64 14.84 15.5 16 14.07 16C12.64 16 11.5 14.84 11.5 13.42V10.78C11.5 9.36 12.65 8.21 14.07 8.21M10.36 8.41H10.5V16H9V10.21L7.22 10.76V9.53L10.36 8.41M14.06 9.65C13.47 9.65 13 10.13 13 10.71V13.5C13 14.07 13.47 14.54 14.06 14.54C14.64 14.54 15.14 14.06 15.14 13.5V10.71C15.14 10.12 14.64 9.65 14.06 9.65Z\";\r\nvar mdiDiceD10Outline = \"M10.5 16H9V10.21L7.22 10.76V9.53L10.36 8.41H10.5V16M14.07 8.21C15.5 8.21 16.64 9.36 16.64 10.78V13.42C16.64 14.84 15.5 16 14.07 16C12.64 16 11.5 14.84 11.5 13.42V10.78C11.5 9.36 12.65 8.21 14.07 8.21M14.06 9.65C13.47 9.65 13 10.13 13 10.71V13.5C13 14.07 13.47 14.54 14.06 14.54C14.64 14.54 15.14 14.06 15.14 13.5V10.71C15.14 10.12 14.64 9.65 14.06 9.65M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L20 12L12 20L4 12Z\";\r\nvar mdiDiceD12 = \"M12 2L1.5 9.64L5.5 22H18.5L22.5 9.64L12 2M10.5 17H8.89V10.89L7 11.47V10.19L10.31 9H10.5V17M17 17H11.66V15.91C11.66 15.91 15.23 12.45 15.23 11.4C15.23 10.12 14.18 10.25 14.18 10.25C13.5 10.3 13 10.87 13 11.55H11.44C11.5 10.09 12.72 8.94 14.27 9C16.74 9 16.77 10.85 16.77 11.3C16.77 13.07 13.58 15.77 13.58 15.77L17 15.75V17Z\";\r\nvar mdiDiceD12Outline = \"M12,2L1.5,9.64L5.5,22H18.5L22.5,9.64L12,2M17,20H7L3.85,10.4L12,4.47L20.15,10.4L17,20M17,15.75V17H11.66V15.91C11.66,15.91 15.23,12.45 15.23,11.4C15.23,10.12 14.18,10.25 14.18,10.25C13.5,10.3 13,10.87 13,11.55H11.44C11.5,10.09 12.72,8.94 14.27,9C16.74,9 16.77,10.85 16.77,11.3C16.77,13.07 13.58,15.77 13.58,15.77L17,15.75M10.5,17H8.89V10.89L7,11.47V10.19L10.31,9H10.5V17Z\";\r\nvar mdiDiceD20 = \"M20.47 6.62L12.57 2.18C12.41 2.06 12.21 2 12 2S11.59 2.06 11.43 2.18L3.53 6.62C3.21 6.79 3 7.12 3 7.5V16.5C3 16.88 3.21 17.21 3.53 17.38L11.43 21.82C11.59 21.94 11.79 22 12 22S12.41 21.94 12.57 21.82L20.47 17.38C20.79 17.21 21 16.88 21 16.5V7.5C21 7.12 20.79 6.79 20.47 6.62M11.45 15.96L6.31 15.93V14.91C6.31 14.91 9.74 11.58 9.75 10.57C9.75 9.33 8.73 9.46 8.73 9.46S7.75 9.5 7.64 10.71L6.14 10.76C6.14 10.76 6.18 8.26 8.83 8.26C11.2 8.26 11.23 10.04 11.23 10.5C11.23 12.18 8.15 14.77 8.15 14.77L11.45 14.76V15.96M17.5 13.5C17.5 14.9 16.35 16.05 14.93 16.05C13.5 16.05 12.36 14.9 12.36 13.5V10.84C12.36 9.42 13.5 8.27 14.93 8.27S17.5 9.42 17.5 10.84V13.5M16 10.77V13.53C16 14.12 15.5 14.6 14.92 14.6C14.34 14.6 13.86 14.12 13.86 13.53V10.77C13.86 10.18 14.34 9.71 14.92 9.71C15.5 9.71 16 10.18 16 10.77Z\";\r\nvar mdiDiceD20Outline = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15M14.93,8.27A2.57,2.57 0 0,1 17.5,10.84V13.5C17.5,14.9 16.35,16.05 14.93,16.05C13.5,16.05 12.36,14.9 12.36,13.5V10.84A2.57,2.57 0 0,1 14.93,8.27M14.92,9.71C14.34,9.71 13.86,10.18 13.86,10.77V13.53C13.86,14.12 14.34,14.6 14.92,14.6C15.5,14.6 16,14.12 16,13.53V10.77C16,10.18 15.5,9.71 14.92,9.71M11.45,14.76V15.96L6.31,15.93V14.91C6.31,14.91 9.74,11.58 9.75,10.57C9.75,9.33 8.73,9.46 8.73,9.46C8.73,9.46 7.75,9.5 7.64,10.71L6.14,10.76C6.14,10.76 6.18,8.26 8.83,8.26C11.2,8.26 11.23,10.04 11.23,10.5C11.23,12.18 8.15,14.77 8.15,14.77L11.45,14.76Z\";\r\nvar mdiDiceD4 = \"M10.25 15.15L11.92 12.47V15.15H10.25M21.92 21H2.08C1.24 21 .72 20.08 1.16 19.36L11.08 3.13C11.5 2.44 12.5 2.44 12.92 3.13L22.84 19.36C23.28 20.08 22.76 21 21.92 21M14.29 15.15H13.43V10.42H11.91L8.75 15.41L8.82 16.36H11.92V18H13.43V16.36H14.29V15.15Z\";\r\nvar mdiDiceD4Outline = \"M13.43,15.15H14.29V16.36H13.43V18H11.92V16.36H8.82L8.75,15.41L11.91,10.42H13.43V15.15M10.25,15.15H11.92V12.47L10.25,15.15M22,21H2C1.64,21 1.31,20.81 1.13,20.5C0.95,20.18 0.96,19.79 1.15,19.5L11.15,3C11.5,2.38 12.5,2.38 12.86,3L22.86,19.5C23.04,19.79 23.05,20.18 22.87,20.5C22.69,20.81 22.36,21 22,21M3.78,19H20.23L12,5.43L3.78,19Z\";\r\nvar mdiDiceD6 = \"M13.05 13.5C13.05 14.27 12.61 14.83 12 14.83S10.85 14.27 10.85 13.5L10.83 12.78C10.83 12.78 11.21 12 11.95 12.1C12.56 12.1 13.05 12.73 13.05 13.5M21 5V19C21 20.11 20.11 21 19 21H5C3.9 21 3 20.11 3 19V5C3 3.9 3.9 3 5 3H19C20.11 3 21 3.9 21 5M14.55 13.41C14.5 11.45 13.19 10.87 12.53 10.87C11.41 10.87 10.86 11.53 10.86 11.53S10.89 9.5 13.39 9.53V8.33C13.39 8.33 9.33 7.94 9.3 12.66C9.27 16.86 12.77 16 12.77 16S14.61 15.47 14.55 13.41Z\";\r\nvar mdiDiceD6Outline = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5M13.39,9.53C10.89,9.5 10.86,11.53 10.86,11.53C10.86,11.53 11.41,10.87 12.53,10.87C13.19,10.87 14.5,11.45 14.55,13.41C14.61,15.47 12.77,16 12.77,16C12.77,16 9.27,16.86 9.3,12.66C9.33,7.94 13.39,8.33 13.39,8.33V9.53M11.95,12.1C11.21,12 10.83,12.78 10.83,12.78L10.85,13.5C10.85,14.27 11.39,14.83 12,14.83C12.61,14.83 13.05,14.27 13.05,13.5C13.05,12.73 12.56,12.1 11.95,12.1Z\";\r\nvar mdiDiceD8 = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 8.25C13.31 8.25 14.38 9.2 14.38 10.38C14.38 11.07 14 11.68 13.44 12.07C14.14 12.46 14.6 13.13 14.6 13.9C14.6 15.12 13.44 16.1 12 16.1C10.56 16.1 9.4 15.12 9.4 13.9C9.4 13.13 9.86 12.46 10.56 12.07C10 11.68 9.63 11.07 9.63 10.38C9.63 9.2 10.69 8.25 12 8.25M12 9.5C11.5 9.5 11.1 9.95 11.1 10.5C11.1 11.05 11.5 11.5 12 11.5C12.5 11.5 12.9 11.05 12.9 10.5C12.9 9.95 12.5 9.5 12 9.5M12 12.65C11.39 12.65 10.9 13.14 10.9 13.75C10.9 14.36 11.39 14.85 12 14.85C12.61 14.85 13.1 14.36 13.1 13.75C13.1 13.14 12.61 12.65 12 12.65Z\";\r\nvar mdiDiceD8Outline = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L20 12L12 20L4 12M12 8.25C13.31 8.25 14.38 9.2 14.38 10.38C14.38 11.07 14 11.68 13.44 12.07C14.14 12.46 14.6 13.13 14.6 13.9C14.6 15.12 13.44 16.1 12 16.1C10.56 16.1 9.4 15.12 9.4 13.9C9.4 13.13 9.86 12.46 10.56 12.07C10 11.68 9.63 11.07 9.63 10.38C9.63 9.2 10.69 8.25 12 8.25M12 12.65C11.39 12.65 10.9 13.14 10.9 13.75C10.9 14.36 11.39 14.85 12 14.85C12.61 14.85 13.1 14.36 13.1 13.75C13.1 13.14 12.61 12.65 12 12.65M12 9.5C11.5 9.5 11.1 9.95 11.1 10.5C11.1 11.05 11.5 11.5 12 11.5C12.5 11.5 12.9 11.05 12.9 10.5C12.9 9.95 12.5 9.5 12 9.5\";\r\nvar mdiDiceMultiple = \"M19.78,3H11.22C10.55,3 10,3.55 10,4.22V8H16V14H19.78C20.45,14 21,13.45 21,12.78V4.22C21,3.55 20.45,3 19.78,3M12.44,6.67C11.76,6.67 11.21,6.12 11.21,5.44C11.21,4.76 11.76,4.21 12.44,4.21A1.23,1.23 0 0,1 13.67,5.44C13.67,6.12 13.12,6.67 12.44,6.67M18.56,12.78C17.88,12.79 17.33,12.24 17.32,11.56C17.31,10.88 17.86,10.33 18.54,10.32C19.22,10.31 19.77,10.86 19.78,11.56C19.77,12.23 19.23,12.77 18.56,12.78M18.56,6.67C17.88,6.68 17.33,6.13 17.32,5.45C17.31,4.77 17.86,4.22 18.54,4.21C19.22,4.2 19.77,4.75 19.78,5.44C19.78,6.12 19.24,6.66 18.56,6.67M4.22,10H12.78A1.22,1.22 0 0,1 14,11.22V19.78C14,20.45 13.45,21 12.78,21H4.22C3.55,21 3,20.45 3,19.78V11.22C3,10.55 3.55,10 4.22,10M8.5,14.28C7.83,14.28 7.28,14.83 7.28,15.5C7.28,16.17 7.83,16.72 8.5,16.72C9.17,16.72 9.72,16.17 9.72,15.5A1.22,1.22 0 0,0 8.5,14.28M5.44,11.22C4.77,11.22 4.22,11.77 4.22,12.44A1.22,1.22 0 0,0 5.44,13.66C6.11,13.66 6.66,13.11 6.66,12.44V12.44C6.66,11.77 6.11,11.22 5.44,11.22M11.55,17.33C10.88,17.33 10.33,17.88 10.33,18.55C10.33,19.22 10.88,19.77 11.55,19.77A1.22,1.22 0 0,0 12.77,18.55H12.77C12.77,17.88 12.23,17.34 11.56,17.33H11.55Z\";\r\nvar mdiDiceMultipleOutline = \"M14 8C13.45 8 13 7.55 13 7S13.45 6 14 6C14.55 6 15 6.45 15 7C15 7.55 14.55 8 14 8M12 12V19H5V12H12M12.78 10H4.22C3.55 10 3 10.55 3 11.22V19.78C3 20.45 3.55 21 4.22 21H12.78C13.45 21 14 20.45 14 19.78V11.22C14 10.55 13.45 10 12.78 10M19.78 3H11.22C10.55 3 10 3.55 10 4.22V8H12V5H19V12H16V14H19.78C20.45 14 21 13.45 21 12.78V4.22C21 3.55 20.45 3 19.78 3M17 8C16.45 8 16 7.55 16 7S16.45 6 17 6C17.55 6 18 6.45 18 7C18 7.55 17.55 8 17 8M17 11C16.45 11 16 10.55 16 10S16.45 9 17 9C17.55 9 18 9.45 18 10C18 10.55 17.55 11 17 11M7 15C6.45 15 6 14.55 6 14S6.45 13 7 13C7.55 13 8 13.45 8 14C8 14.55 7.55 15 7 15M10 18C9.45 18 9 17.55 9 17S9.45 16 10 16C10.55 16 11 16.45 11 17C11 17.55 10.55 18 10 18\";\r\nvar mdiDigitalOcean = \"M6 12H2C2 6.5 6.5 2 12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22V18H8V14H12V18C15.32 18 18 15.31 18 12C18 8.69 15.31 6 12 6C8.69 6 6 8.69 6 12M8 18V21H5V18H8M3 16H5V18H3V16Z\";\r\nvar mdiDipSwitch = \"M3,4H7A1,1 0 0,1 8,5V19A1,1 0 0,1 7,20H3A1,1 0 0,1 2,19V5A1,1 0 0,1 3,4M10,4H14A1,1 0 0,1 15,5V19A1,1 0 0,1 14,20H10A1,1 0 0,1 9,19V5A1,1 0 0,1 10,4M17,4H21A1,1 0 0,1 22,5V19A1,1 0 0,1 21,20H17A1,1 0 0,1 16,19V5A1,1 0 0,1 17,4M4,18H6V13H4V18M11,11H13V6H11V11M18,18H20V13H18V18Z\";\r\nvar mdiDirections = \"M14,14.5V12H10V15H8V11A1,1 0 0,1 9,10H14V7.5L17.5,11M21.71,11.29L12.71,2.29H12.7C12.31,1.9 11.68,1.9 11.29,2.29L2.29,11.29C1.9,11.68 1.9,12.32 2.29,12.71L11.29,21.71C11.68,22.09 12.31,22.1 12.71,21.71L21.71,12.71C22.1,12.32 22.1,11.68 21.71,11.29Z\";\r\nvar mdiDirectionsFork = \"M3,4V12.5L6,9.5L9,13C10,14 10,15 10,15V21H14V14C14,14 14,13 13.47,12C12.94,11 12,10 12,10L9,6.58L11.5,4M18,4L13.54,8.47L14,9C14,9 14.93,10 15.47,11C15.68,11.4 15.8,11.79 15.87,12.13L21,7\";\r\nvar mdiDisc = \"M12,14C10.89,14 10,13.1 10,12C10,10.89 10.89,10 12,10C13.11,10 14,10.89 14,12A2,2 0 0,1 12,14M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiDiscAlert = \"M10 14C8.9 14 8 13.1 8 12C8 10.9 8.9 10 10 10C11.1 10 12 10.9 12 12S11.1 14 10 14M10 4C5.6 4 2 7.6 2 12S5.6 20 10 20 18 16.4 18 12 14.4 4 10 4M20 13H22V7H20M20 17H22V15H20V17Z\";\r\nvar mdiDiscPlayer = \"M14.5,10.37C15.54,10.37 16.38,9.53 16.38,8.5C16.38,7.46 15.54,6.63 14.5,6.63C13.46,6.63 12.63,7.46 12.63,8.5A1.87,1.87 0 0,0 14.5,10.37M14.5,1A7.5,7.5 0 0,1 22,8.5C22,10.67 21.08,12.63 19.6,14H9.4C7.93,12.63 7,10.67 7,8.5C7,4.35 10.36,1 14.5,1M6,21V22H4V21H2V15H22V21H20V22H18V21H6M4,18V19H13V18H4M15,17V19H17V17H15M19,17A1,1 0 0,0 18,18A1,1 0 0,0 19,19A1,1 0 0,0 20,18A1,1 0 0,0 19,17Z\";\r\nvar mdiDiscord = \"M22,24L16.75,19L17.38,21H4.5A2.5,2.5 0 0,1 2,18.5V3.5A2.5,2.5 0 0,1 4.5,1H19.5A2.5,2.5 0 0,1 22,3.5V24M12,6.8C9.32,6.8 7.44,7.95 7.44,7.95C8.47,7.03 10.27,6.5 10.27,6.5L10.1,6.33C8.41,6.36 6.88,7.53 6.88,7.53C5.16,11.12 5.27,14.22 5.27,14.22C6.67,16.03 8.75,15.9 8.75,15.9L9.46,15C8.21,14.73 7.42,13.62 7.42,13.62C7.42,13.62 9.3,14.9 12,14.9C14.7,14.9 16.58,13.62 16.58,13.62C16.58,13.62 15.79,14.73 14.54,15L15.25,15.9C15.25,15.9 17.33,16.03 18.73,14.22C18.73,14.22 18.84,11.12 17.12,7.53C17.12,7.53 15.59,6.36 13.9,6.33L13.73,6.5C13.73,6.5 15.53,7.03 16.56,7.95C16.56,7.95 14.68,6.8 12,6.8M9.93,10.59C10.58,10.59 11.11,11.16 11.1,11.86C11.1,12.55 10.58,13.13 9.93,13.13C9.29,13.13 8.77,12.55 8.77,11.86C8.77,11.16 9.28,10.59 9.93,10.59M14.1,10.59C14.75,10.59 15.27,11.16 15.27,11.86C15.27,12.55 14.75,13.13 14.1,13.13C13.46,13.13 12.94,12.55 12.94,11.86C12.94,11.16 13.45,10.59 14.1,10.59Z\";\r\nvar mdiDishwasher = \"M18,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2M10,4A1,1 0 0,1 11,5A1,1 0 0,1 10,6A1,1 0 0,1 9,5A1,1 0 0,1 10,4M7,4A1,1 0 0,1 8,5A1,1 0 0,1 7,6A1,1 0 0,1 6,5A1,1 0 0,1 7,4M18,20H6V8H18V20M14.67,15.33C14.69,16.03 14.41,16.71 13.91,17.21C12.86,18.26 11.15,18.27 10.09,17.21C9.59,16.71 9.31,16.03 9.33,15.33C9.4,14.62 9.63,13.94 10,13.33C10.37,12.5 10.81,11.73 11.33,11L12,10C13.79,12.59 14.67,14.36 14.67,15.33\";\r\nvar mdiDishwasherAlert = \"M16 2H4C2.9 2 2 2.9 2 4V20C2 21.11 2.9 22 4 22H16C17.11 22 18 21.11 18 20V4C18 2.9 17.11 2 16 2M8 4C8.55 4 9 4.45 9 5S8.55 6 8 6 7 5.55 7 5 7.45 4 8 4M5 4C5.55 4 6 4.45 6 5S5.55 6 5 6 4 5.55 4 5 4.45 4 5 4M16 20H4V8H16V20M12.67 15.33C12.69 16.03 12.41 16.71 11.91 17.21C10.86 18.26 9.15 18.27 8.09 17.21C7.59 16.71 7.31 16.03 7.33 15.33C7.4 14.62 7.63 13.94 8 13.33C8.37 12.5 8.81 11.73 9.33 11L10 10C11.79 12.59 12.67 14.36 12.67 15.33M20 15H22V17H20V15M20 7H22V13H20V7Z\";\r\nvar mdiDishwasherOff = \"M22.11 21.46L2.39 1.73L1.11 3L4 5.89V20C4 21.11 4.89 22 6 22H18C18.58 22 19.1 21.75 19.46 21.35L20.84 22.73L22.11 21.46M18 20H6V8H6.11L10.5 12.37C10.31 12.69 10.15 13 10 13.33C9.63 13.94 9.4 14.62 9.33 15.33C9.31 16.03 9.59 16.71 10.09 17.21C11.15 18.27 12.86 18.26 13.91 17.21C14.16 16.97 14.35 16.68 14.5 16.36L18 19.89V20M11.2 8H18V14.8L20 16.8V4C20 2.9 19.11 2 18 2H6C5.76 2 5.54 2.05 5.33 2.13L11.2 8M10 4C10.55 4 11 4.45 11 5S10.55 6 10 6 9 5.55 9 5 9.45 4 10 4Z\";\r\nvar mdiDisqus = \"M12.08,22C9.63,22 7.39,21.11 5.66,19.63L1.41,20.21L3.05,16.15C2.5,14.88 2.16,13.5 2.16,12C2.16,6.5 6.6,2 12.08,2C17.56,2 22,6.5 22,12C22,17.5 17.56,22 12.08,22M17.5,11.97V11.94C17.5,9.06 15.46,7 11.95,7H8.16V17H11.9C15.43,17 17.5,14.86 17.5,11.97M12,14.54H10.89V9.46H12C13.62,9.46 14.7,10.39 14.7,12V12C14.7,13.63 13.62,14.54 12,14.54Z\";\r\nvar mdiDistributeHorizontalCenter = \"M8 2V5H10V19H8V22H6V19H4V5H6V2H8M16 2V7H14V17H16V22H18V17H20V7H18V2H16Z\";\r\nvar mdiDistributeHorizontalLeft = \"M21 7V17H16V22H14V2H16V7H21M5 2H3V22H5V19H10V5H5V2Z\";\r\nvar mdiDistributeHorizontalRight = \"M3 17V7H8V2H10V22H8V17H3M19 22H21V2H19V5H14V19H19V22Z\";\r\nvar mdiDistributeVerticalBottom = \"M7 3H17V8H22V10H2V8H7V3M2 19V21H22V19H19V14H5V19H2Z\";\r\nvar mdiDistributeVerticalCenter = \"M2 16H5V14H19V16H22V18H19V20H5V18H2V16M2 8H7V10H17V8H22V6H17V4H7V6H2V8Z\";\r\nvar mdiDistributeVerticalTop = \"M17 21H7V16H2V14H22V16H17V21M22 5V3H2V5H5V10H19V5H22Z\";\r\nvar mdiDivingFlippers = \"M20.28,3.66C19.28,3.44 18.54,2.25 17.57,2.04C16.6,1.83 15.4,2.59 14.42,2.37C13.38,2 12.22,2.13 11.28,2.71L11.21,17L11,18C10.64,19.62 11.67,21.22 13.29,21.58C14.9,21.93 16.5,20.91 16.86,19.29L17.07,18.29L23,5.28C22.39,4.35 21.39,3.76 20.28,3.66M14.91,18.86C14.79,19.41 14.25,19.76 13.7,19.65C13.14,19.53 12.79,19 12.91,18.43L13.77,14.5C13.86,13.97 14.37,13.6 14.92,13.69C15.46,13.78 15.83,14.3 15.74,14.84C15.74,14.88 15.73,14.91 15.72,14.95L14.91,18.86M9.72,21.34C9.33,20.73 9.08,20.05 9,19.34L8.24,16C8.1,15.47 8.41,14.92 9,14.76C9.07,14.75 9.15,14.75 9.22,14.76V3.43C8.31,3.43 7.22,2.86 6.38,3.06C5.54,3.26 4.69,4.44 3.72,4.66C2.61,4.76 1.61,5.35 1,6.28L6.93,19.28L7.14,20.28C7.5,21.9 9.09,22.92 10.71,22.57H10.81C10.38,22.22 10,21.81 9.72,21.34Z\";\r\nvar mdiDivingHelmet = \"M16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12M19.45,7.89L18.07,8.58L18.32,9H20V15H18.33C17.84,16.03 17.11,16.92 16.21,17.6C17.85,18.11 19.1,18.91 19.67,19.86C18.69,21.1 15.62,22 12,22C8.38,22 5.31,21.1 4.33,19.86C4.9,18.91 6.15,18.11 7.79,17.6C6.89,16.92 6.16,16.03 5.67,15H4V9H5.68C6.37,7.54 7.54,6.37 9,5.68V4H15V5.68C15.68,6 16.29,6.46 16.82,7L18.55,6.14C19.93,5.42 20,4.1 20,2H22C22,4.06 22,6.62 19.45,7.89M17,12A5,5 0 0,0 12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12Z\";\r\nvar mdiDivingScuba = \"M12,15C13.31,15 14.42,15.83 14.83,17H18A4,4 0 0,1 22,21V22H20V21A2,2 0 0,0 18,19H14.83C14.42,20.17 13.31,21 12,21A3,3 0 0,1 9,18A3,3 0 0,1 12,15M12,17A1,1 0 0,0 11,18A1,1 0 0,0 12,19A1,1 0 0,0 13,18A1,1 0 0,0 12,17M18,3A2,2 0 0,1 20,5V10A2,2 0 0,1 18,12H14.85C14.43,12 14.05,12.24 13.9,12.63C13.7,13.23 13.23,13.71 12.62,13.91C11.58,14.25 10.44,13.68 10.1,12.63C9.95,12.24 9.57,12 9.15,12H6A2,2 0 0,1 4,10V5A2,2 0 0,1 6,3H18M18,10V5H6V10H10.65C10.9,9.46 11.41,9.09 12,9C12.59,9.09 13.1,9.46 13.35,10H18Z\";\r\nvar mdiDivingScubaFlag = \"M2,6L19,20H2V6M5,4L22,18V4H5Z\";\r\nvar mdiDivingScubaTank = \"M19,18.5A2.5,2.5 0 0,1 16.5,21A2.5,2.5 0 0,1 14,18.5C14,17.47 14.62,16.59 15.5,16.21V6H11V7.35C12.22,7.93 13,9.15 13,10.5V22H6V10.5C6,9.15 6.78,7.93 8,7.35V6H6V4H8V3.5A1.5,1.5 0 0,1 9.5,2A1.5,1.5 0 0,1 11,3.5V4H15.5A2,2 0 0,1 17.5,6V16.21C18.38,16.59 19,17.47 19,18.5Z\";\r\nvar mdiDivingScubaTankMultiple = \"M22,18.5A2.5,2.5 0 0,1 19.5,21A2.5,2.5 0 0,1 17,18.5C17,17.47 17.62,16.59 18.5,16.21V6H14V7.35C15.22,7.93 16,9.15 16,10.5V22H2V10.5C2,9.15 2.78,7.93 4,7.35V6H2V4H4V3.5A1.5,1.5 0 0,1 5.5,2A1.5,1.5 0 0,1 7,3.5V4H11V3.5A1.5,1.5 0 0,1 12.5,2A1.5,1.5 0 0,1 14,3.5V4H18.5A2,2 0 0,1 20.5,6V16.21C21.38,16.59 22,17.47 22,18.5M11,7.35V6H7V7.35C8.22,7.93 9,9.15 9,10.5C9,9.15 9.78,7.93 11,7.35Z\";\r\nvar mdiDivingSnorkel = \"M16,3H4A2,2 0 0,0 2,5V10A2,2 0 0,0 4,12H7.15C7.57,12 7.95,12.24 8.1,12.63C8.44,13.68 9.58,14.25 10.62,13.91C11.23,13.71 11.7,13.23 11.9,12.63C12.05,12.24 12.43,12 12.85,12H16A2,2 0 0,0 18,10V5A2,2 0 0,0 16,3M16,10H11.35C11.1,9.46 10.59,9.09 10,9C9.41,9.09 8.9,9.46 8.65,10H4V5H16V10M22,2V15.5A6.5,6.5 0 0,1 15.5,22C13.79,22 12.15,21.32 10.93,20.12C8.95,20.58 6.88,19.79 5.71,18.12L7.62,17.29C8.5,18.22 9.84,18.5 11,18C11.2,17.91 11.39,17.8 11.56,17.67C12.4,17.05 12.87,16.04 12.78,15L14.69,14.17C15.1,16.04 14.41,18 12.9,19.17C13.66,19.71 14.57,20 15.5,20C18,20 20,18 20,15.5V2H22Z\";\r\nvar mdiDivision = \"M19,13H5V11H19V13M12,5A2,2 0 0,1 14,7A2,2 0 0,1 12,9A2,2 0 0,1 10,7A2,2 0 0,1 12,5M12,15A2,2 0 0,1 14,17A2,2 0 0,1 12,19A2,2 0 0,1 10,17A2,2 0 0,1 12,15Z\";\r\nvar mdiDivisionBox = \"M17,13V11H7V13H17M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19M12,7A1,1 0 0,0 11,8A1,1 0 0,0 12,9A1,1 0 0,0 13,8A1,1 0 0,0 12,7M12,15A1,1 0 0,0 11,16A1,1 0 0,0 12,17A1,1 0 0,0 13,16A1,1 0 0,0 12,15Z\";\r\nvar mdiDlna = \"M21.38,12.56H12.85C11.97,12.56 11.1,12.96 10.61,13.61V13.6C10.12,14.28 9.32,14.72 8.41,14.72C6.92,14.72 5.71,13.5 5.71,12C5.71,10.5 6.92,9.31 8.41,9.31C9.32,9.31 10.12,9.75 10.61,10.43V10.42C11.1,11.07 11.97,11.5 12.85,11.5H21.29C21.45,11.5 22,11.4 22,10.67C21.26,6.43 17.1,3.18 12.06,3.18C8.96,3.18 6.19,4.41 4.34,6.35C4.05,6.79 4.35,6.92 4.63,6.96H10.14C11,6.96 11.89,6.54 12.38,5.89V5.91C12.88,5.23 13.67,4.78 14.58,4.78C16.07,4.78 17.28,6 17.28,7.5C17.28,9 16.07,10.2 14.58,10.2C13.67,10.2 12.88,9.75 12.38,9.07V9.08C11.89,8.44 11,8.03 10.14,8.03H4.13L4.15,8.03C4.15,8.03 3.26,8 2.72,8.75C2.3,9.42 2,10.85 2,12C2,13.16 2.17,14.21 2.72,15.27C3.19,16.03 4.15,16 4.15,16H4.11L10.14,16C11,16 11.89,15.58 12.38,14.93V14.94C12.88,14.26 13.67,13.81 14.58,13.81C16.07,13.81 17.28,15.03 17.28,16.5C17.28,18 16.07,19.23 14.58,19.23C13.67,19.23 12.88,18.78 12.38,18.1V18.12C11.89,17.47 11,17.05 10.14,17.05H4.64C4.36,17.09 4.06,17.22 4.32,17.64C6.17,19.58 8.95,20.82 12.06,20.82C17.11,20.82 21.28,17.57 22,13.31C22,12.72 21.59,12.58 21.38,12.56\";\r\nvar mdiDna = \"M4,2H6V4C6,5.44 6.68,6.61 7.88,7.78C8.74,8.61 9.89,9.41 11.09,10.2L9.26,11.39C8.27,10.72 7.31,10 6.5,9.21C5.07,7.82 4,6.1 4,4V2M18,2H20V4C20,6.1 18.93,7.82 17.5,9.21C16.09,10.59 14.29,11.73 12.54,12.84C10.79,13.96 9.09,15.05 7.88,16.22C6.68,17.39 6,18.56 6,20V22H4V20C4,17.9 5.07,16.18 6.5,14.79C7.91,13.41 9.71,12.27 11.46,11.16C13.21,10.04 14.91,8.95 16.12,7.78C17.32,6.61 18,5.44 18,4V2M14.74,12.61C15.73,13.28 16.69,14 17.5,14.79C18.93,16.18 20,17.9 20,20V22H18V20C18,18.56 17.32,17.39 16.12,16.22C15.26,15.39 14.11,14.59 12.91,13.8L14.74,12.61M7,3H17V4L16.94,4.5H7.06L7,4V3M7.68,6H16.32C16.08,6.34 15.8,6.69 15.42,7.06L14.91,7.5H9.07L8.58,7.06C8.2,6.69 7.92,6.34 7.68,6M9.09,16.5H14.93L15.42,16.94C15.8,17.31 16.08,17.66 16.32,18H7.68C7.92,17.66 8.2,17.31 8.58,16.94L9.09,16.5M7.06,19.5H16.94L17,20V21H7V20L7.06,19.5Z\";\r\nvar mdiDns = \"M7,9A2,2 0 0,1 5,7A2,2 0 0,1 7,5A2,2 0 0,1 9,7A2,2 0 0,1 7,9M20,3H4A1,1 0 0,0 3,4V10A1,1 0 0,0 4,11H20A1,1 0 0,0 21,10V4A1,1 0 0,0 20,3M7,19A2,2 0 0,1 5,17A2,2 0 0,1 7,15A2,2 0 0,1 9,17A2,2 0 0,1 7,19M20,13H4A1,1 0 0,0 3,14V20A1,1 0 0,0 4,21H20A1,1 0 0,0 21,20V14A1,1 0 0,0 20,13Z\";\r\nvar mdiDnsOutline = \"M19,15V19H5V15H19M20,13H4A1,1 0 0,0 3,14V20A1,1 0 0,0 4,21H20A1,1 0 0,0 21,20V14A1,1 0 0,0 20,13M7,18.5A1.5,1.5 0 0,1 5.5,17A1.5,1.5 0 0,1 7,15.5A1.5,1.5 0 0,1 8.5,17A1.5,1.5 0 0,1 7,18.5M19,5V9H5V5H19M20,3H4A1,1 0 0,0 3,4V10A1,1 0 0,0 4,11H20A1,1 0 0,0 21,10V4A1,1 0 0,0 20,3M7,8.5A1.5,1.5 0 0,1 5.5,7A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 8.5,7A1.5,1.5 0 0,1 7,8.5Z\";\r\nvar mdiDoNotDisturb = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M17,13H7V11H17V13Z\";\r\nvar mdiDoNotDisturbOff = \"M17,11V13H15.54L20.22,17.68C21.34,16.07 22,14.11 22,12A10,10 0 0,0 12,2C9.89,2 7.93,2.66 6.32,3.78L13.54,11H17M2.27,2.27L1,3.54L3.78,6.32C2.66,7.93 2,9.89 2,12A10,10 0 0,0 12,22C14.11,22 16.07,21.34 17.68,20.22L20.46,23L21.73,21.73L2.27,2.27M7,13V11H8.46L10.46,13H7Z\";\r\nvar mdiDockBottom = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V6A2 2 0 0 0 20 4M20 13H4V6H20Z\";\r\nvar mdiDockLeft = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V6A2 2 0 0 0 20 4M20 18H9V6H20Z\";\r\nvar mdiDockRight = \"M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V6A2 2 0 0 0 20 4M15 18H4V6H15Z\";\r\nvar mdiDockTop = \"M4 20H20C21.11 20 22 19.11 22 18V6C22 4.89 21.11 4 20 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20M4 11H20V18H4V11Z\";\r\nvar mdiDockWindow = \"M18 18V20H4A2 2 0 0 1 2 18V8H4V18M22 6V14A2 2 0 0 1 20 16H8A2 2 0 0 1 6 14V6A2 2 0 0 1 8 4H20A2 2 0 0 1 22 6M20 6H8V14H20Z\";\r\nvar mdiDocker = \"M21.81 10.25C21.75 10.21 21.25 9.82 20.17 9.82C19.89 9.82 19.61 9.85 19.33 9.9C19.12 8.5 17.95 7.79 17.9 7.76L17.61 7.59L17.43 7.86C17.19 8.22 17 8.63 16.92 9.05C16.72 9.85 16.84 10.61 17.25 11.26C16.76 11.54 15.96 11.61 15.79 11.61H2.62C2.28 11.61 2 11.89 2 12.24C2 13.39 2.18 14.54 2.58 15.62C3.03 16.81 3.71 17.69 4.58 18.23C5.56 18.83 7.17 19.17 9 19.17C9.79 19.17 10.61 19.1 11.42 18.95C12.54 18.75 13.62 18.36 14.61 17.79C15.43 17.32 16.16 16.72 16.78 16C17.83 14.83 18.45 13.5 18.9 12.35H19.09C20.23 12.35 20.94 11.89 21.33 11.5C21.59 11.26 21.78 10.97 21.92 10.63L22 10.39L21.81 10.25M3.85 11.24H5.61C5.69 11.24 5.77 11.17 5.77 11.08V9.5C5.77 9.42 5.7 9.34 5.61 9.34H3.85C3.76 9.34 3.69 9.41 3.69 9.5V11.08C3.7 11.17 3.76 11.24 3.85 11.24M6.28 11.24H8.04C8.12 11.24 8.2 11.17 8.2 11.08V9.5C8.2 9.42 8.13 9.34 8.04 9.34H6.28C6.19 9.34 6.12 9.41 6.12 9.5V11.08C6.13 11.17 6.19 11.24 6.28 11.24M8.75 11.24H10.5C10.6 11.24 10.67 11.17 10.67 11.08V9.5C10.67 9.42 10.61 9.34 10.5 9.34H8.75C8.67 9.34 8.6 9.41 8.6 9.5V11.08C8.6 11.17 8.66 11.24 8.75 11.24M11.19 11.24H12.96C13.04 11.24 13.11 11.17 13.11 11.08V9.5C13.11 9.42 13.05 9.34 12.96 9.34H11.19C11.11 9.34 11.04 9.41 11.04 9.5V11.08C11.04 11.17 11.11 11.24 11.19 11.24M6.28 9H8.04C8.12 9 8.2 8.91 8.2 8.82V7.25C8.2 7.16 8.13 7.09 8.04 7.09H6.28C6.19 7.09 6.12 7.15 6.12 7.25V8.82C6.13 8.91 6.19 9 6.28 9M8.75 9H10.5C10.6 9 10.67 8.91 10.67 8.82V7.25C10.67 7.16 10.61 7.09 10.5 7.09H8.75C8.67 7.09 8.6 7.15 8.6 7.25V8.82C8.6 8.91 8.66 9 8.75 9M11.19 9H12.96C13.04 9 13.11 8.91 13.11 8.82V7.25C13.11 7.16 13.04 7.09 12.96 7.09H11.19C11.11 7.09 11.04 7.15 11.04 7.25V8.82C11.04 8.91 11.11 9 11.19 9M11.19 6.72H12.96C13.04 6.72 13.11 6.65 13.11 6.56V5C13.11 4.9 13.04 4.83 12.96 4.83H11.19C11.11 4.83 11.04 4.89 11.04 5V6.56C11.04 6.64 11.11 6.72 11.19 6.72M13.65 11.24H15.41C15.5 11.24 15.57 11.17 15.57 11.08V9.5C15.57 9.42 15.5 9.34 15.41 9.34H13.65C13.57 9.34 13.5 9.41 13.5 9.5V11.08C13.5 11.17 13.57 11.24 13.65 11.24\";\r\nvar mdiDoctor = \"M14.84,16.26C17.86,16.83 20,18.29 20,20V22H4V20C4,18.29 6.14,16.83 9.16,16.26L12,21L14.84,16.26M8,8H16V10A4,4 0 0,1 12,14A4,4 0 0,1 8,10V8M8,7L8.41,2.9C8.46,2.39 8.89,2 9.41,2H14.6C15.11,2 15.54,2.39 15.59,2.9L16,7H8M12,3H11V4H10V5H11V6H12V5H13V4H12V3Z\";\r\nvar mdiDog = \"M18,4C16.29,4 15.25,4.33 14.65,4.61C13.88,4.23 13,4 12,4C11,4 10.12,4.23 9.35,4.61C8.75,4.33 7.71,4 6,4C3,4 1,12 1,14C1,14.83 2.32,15.59 4.14,15.9C4.78,18.14 7.8,19.85 11.5,20V15.72C10.91,15.35 10,14.68 10,14C10,13 12,13 12,13C12,13 14,13 14,14C14,14.68 13.09,15.35 12.5,15.72V20C16.2,19.85 19.22,18.14 19.86,15.9C21.68,15.59 23,14.83 23,14C23,12 21,4 18,4M4.15,13.87C3.65,13.75 3.26,13.61 3,13.5C3.25,10.73 5.2,6.4 6.05,6C6.59,6 7,6.06 7.37,6.11C5.27,8.42 4.44,12.04 4.15,13.87M9,12A1,1 0 0,1 8,11C8,10.46 8.45,10 9,10A1,1 0 0,1 10,11C10,11.56 9.55,12 9,12M15,12A1,1 0 0,1 14,11C14,10.46 14.45,10 15,10A1,1 0 0,1 16,11C16,11.56 15.55,12 15,12M19.85,13.87C19.56,12.04 18.73,8.42 16.63,6.11C17,6.06 17.41,6 17.95,6C18.8,6.4 20.75,10.73 21,13.5C20.75,13.61 20.36,13.75 19.85,13.87Z\";\r\nvar mdiDogService = \"M14,8L17,11V21H15V15H8L6,18V21H4V15L5,14V11L2,8L3,7L5,9H7V12A1,1 0 0,0 8,13H12A1,1 0 0,0 13,12V9L14,8M19,5V3L15,7L18,10L19,9L20,10L22,8L19,5M11.5,9.5L4.5,2.5C4.23,2.22 3.79,2.22 3.5,2.5V2.5C3.22,2.77 3.22,3.21 3.5,3.5L10.5,10.5C10.77,10.78 11.21,10.78 11.5,10.5V10.5C11.78,10.23 11.78,9.79 11.5,9.5Z\";\r\nvar mdiDogSide = \"M19,3L15,7L18,10L19,9L20,10L22,8L19,5V3M3,7L2,8L5,11V14L4,15V21H6V18L8,15H15V21H17V11L14,8L13,9H5L3,7Z\";\r\nvar mdiDolby = \"M2,5V19H22V5H2M6,17H4V7H6C8.86,7.09 11.1,9.33 11,12C11.1,14.67 8.86,16.91 6,17M20,17H18C15.14,16.91 12.9,14.67 13,12C12.9,9.33 15.14,7.09 18,7H20V17Z\";\r\nvar mdiDolly = \"M11.97,19.88C10.93,20.26 9.78,19.72 9.4,18.69C9,17.65 9.55,16.5 10.59,16.13C11.63,15.75 12.78,16.28 13.16,17.31C13.54,18.35 13,19.5 11.97,19.88M9.9,14.25C7.83,15 6.76,17.3 7.5,19.38C8.28,21.45 10.58,22.5 12.66,21.75C14.73,21 15.79,18.7 15.04,16.63C14.28,14.55 11.97,13.5 9.9,14.25M15.94,4.58L9.37,7L10.75,10.74L17.32,8.33M20.32,13.62L15.54,15.37C15.71,15.66 15.85,15.96 15.97,16.28C16.09,16.6 16.17,16.93 16.22,17.25L21,15.5M19.54,8.58L11.09,11.68L11.58,13C12.83,13.09 14,13.64 14.89,14.55L20.92,12.34M2,2V4H5.09L8.66,13.75C8.94,13.57 9.24,13.43 9.56,13.31C9.88,13.19 10.21,13.11 10.53,13.06L6.5,2\";\r\nvar mdiDomain = \"M18,15H16V17H18M18,11H16V13H18M20,19H12V17H14V15H12V13H14V11H12V9H20M10,7H8V5H10M10,11H8V9H10M10,15H8V13H10M10,19H8V17H10M6,7H4V5H6M6,11H4V9H6M6,15H4V13H6M6,19H4V17H6M12,7V3H2V21H22V7H12Z\";\r\nvar mdiDomainOff = \"M12,19H16L14,17H12V19M10,15V13H8V15H10M10,19V17H8V19H10M6,11V9H4V11H6M6,15V13H4V15H6M6,19V17H4V19H6M1.31,1.78L22.31,22.69L21,24L18,21H2V5L0.09,3.09L1.31,1.78M16,11H18V13H16V11M8,5V5.91L5.11,3H12V7H22V19.92L20,17.91V9H12V9.89L9.09,7H10V5H8Z\";\r\nvar mdiDomainPlus = \"M12 7V3H2V21H13.35A5.8 5.8 0 0 1 13 19H12V17H13.35A5 5 0 0 1 14 15.69V15H12V13H14V11H12V9H20V13.09A5.58 5.58 0 0 1 22 13.81V7M6 19H4V17H6M6 15H4V13H6M6 11H4V9H6M6 7H4V5H6M10 19H8V17H10M10 15H8V13H10M10 11H8V9H10M10 7H8V5H10M16 13H18V11H16M16 11V13H18V11M16 11V13H18V11M20 15V18H23V20H20V23H18V20H15V18H18V15Z\";\r\nvar mdiDomainRemove = \"M12 7V3H2V21H13.35A5.8 5.8 0 0 1 13 19H12V17H13.35A5 5 0 0 1 14 15.69V15H12V13H14V11H12V9H20V13.09A5.58 5.58 0 0 1 22 13.81V7M6 19H4V17H6M6 15H4V13H6M6 11H4V9H6M6 7H4V5H6M10 19H8V17H10M10 15H8V13H10M10 11H8V9H10M10 7H8V5H10M16 13H18V11H16M16 11V13H18V11M16 11V13H18V11M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.46 21.12L17.59 19L15.46 16.88L16.88 15.46L19 17.59L21.12 15.46Z\";\r\nvar mdiDomeLight = \"M21 10C21 14.97 16.97 19 12 19C7.03 19 3 14.97 3 10V9.03C3 8.76 3.11 8.5 3.3 8.3C3.5 8.11 3.76 8 4.03 8H20C20.25 8 20.5 8.11 20.7 8.3C20.89 8.5 21 8.75 21 9V10M5 10C5 13.86 8.14 17 12 17C15.86 17 19 13.86 19 10H5M20 6V7H4V6C4 5.73 4.1 5.5 4.29 5.29C4.5 5.1 4.73 5 5 5H10V3H14V5H19C19.25 5 19.5 5.11 19.7 5.3C19.89 5.5 20 5.75 20 6Z\";\r\nvar mdiDominoMask = \"M15.83 9.81C14.7 9.7 13.69 10.38 13.46 11.5C13.46 11.84 14.81 12.29 16.05 12.29C17.29 12.29 18.41 11.5 18.41 11.28C18.41 11.05 17.63 9.93 15.83 9.81M8.18 9.81C6.38 9.93 5.59 10.94 5.59 11.27C5.59 11.5 6.82 12.29 7.95 12.29S10.54 11.84 10.54 11.5C10.31 10.38 9.19 9.7 8.18 9.81M16.95 16C15.04 16 13.8 13.75 12 13.75S8.85 16 7.05 16C4.69 16 3 13.86 3 10.04C3 7.68 3.68 7 6.71 7S10.54 8.24 12 8.24 14.36 7 17.29 7 21 7.79 21 10.04C21 13.86 19.31 16 16.95 16Z\";\r\nvar mdiDonkey = \"M21.34,10.35L21.27,10.28L21.18,10.19L18,7V6A0.5,0.5 0 0,0 17.5,5.5C17.36,5.5 17.22,5.56 17.13,5.66L13.46,9H7C6.32,9 5.69,9.35 5.32,9.92L2.62,12.59C2.29,13.04 2.39,13.66 2.84,14C3.18,14.24 3.65,14.25 4,14L5,13.07V19H8V15H13V19H16V13.83C16,13.3 16.21,12.79 16.59,12.42L18,11L20,12V12C20.15,12.08 20.32,12.13 20.5,12.13C21.1,12.11 21.59,11.61 21.58,11C21.57,10.76 21.5,10.53 21.34,10.35Z\";\r\nvar mdiDoor = \"M8,3C6.89,3 6,3.89 6,5V21H18V5C18,3.89 17.11,3 16,3H8M8,5H16V19H8V5M13,11V13H15V11H13Z\";\r\nvar mdiDoorClosed = \"M16,11H18V13H16V11M12,3H19C20.11,3 21,3.89 21,5V19H22V21H2V19H10V5C10,3.89 10.89,3 12,3M12,5V19H19V5H12Z\";\r\nvar mdiDoorClosedLock = \"M16 11H18V13H16V11M12 3H19A2 2 0 0 1 21 5V19H22V21H2V19H10V5A2 2 0 0 1 12 3M12 5V19H19V5M6.2 5H2.8V4.5A1.7 1.7 0 0 1 6.2 4.5M7 5V4.5A2.5 2.5 0 0 0 2 4.5V5A1 1 0 0 0 1 6V10A1 1 0 0 0 2 11H7A1 1 0 0 0 8 10V6A1 1 0 0 0 7 5\";\r\nvar mdiDoorOpen = \"M12,3C10.89,3 10,3.89 10,5H3V19H2V21H22V19H21V5C21,3.89 20.11,3 19,3H12M12,5H19V19H12V5M5,11H7V13H5V11Z\";\r\nvar mdiDoorbell = \"M12 10C10.9 10 10 10.9 10 12S10.9 14 12 14 14 13.1 14 12 13.1 10 12 10M16 2H8C6.9 2 6 2.9 6 4V20C6 21.1 6.9 22 8 22H16C17.1 22 18 21.1 18 20V4C18 2.9 17.1 2 16 2M16 20H8V4H16V20Z\";\r\nvar mdiDoorbellVideo = \"M14 15C14 16.11 13.11 17 12 17S10 16.11 10 15 10.9 13 12 13 14 13.9 14 15M18 4V20C18 21.1 17.11 22 16 22H8C6.9 22 6 21.11 6 20V4C6 2.9 6.9 2 8 2H16C17.11 2 18 2.9 18 4M10.5 7C10.5 7.83 11.17 8.5 12 8.5S13.5 7.83 13.5 7 12.83 5.5 12 5.5 10.5 6.17 10.5 7M16 10H8V20H16V10Z\";\r\nvar mdiDotNet = \"M2,15A1,1 0 0,1 3,16A1,1 0 0,1 2,17A1,1 0 0,1 1,16A1,1 0 0,1 2,15M21,17H19V9H17V7H23V9H21V17M16,7V9H14V11H16V13H14V15H16V17H12V7H16M11,7V17H9L6,11V17H4V7H6L9,13V7H11Z\";\r\nvar mdiDotsGrid = \"M12 16C13.1 16 14 16.9 14 18S13.1 20 12 20 10 19.1 10 18 10.9 16 12 16M12 10C13.1 10 14 10.9 14 12S13.1 14 12 14 10 13.1 10 12 10.9 10 12 10M12 4C13.1 4 14 4.9 14 6S13.1 8 12 8 10 7.1 10 6 10.9 4 12 4M6 16C7.1 16 8 16.9 8 18S7.1 20 6 20 4 19.1 4 18 4.9 16 6 16M6 10C7.1 10 8 10.9 8 12S7.1 14 6 14 4 13.1 4 12 4.9 10 6 10M6 4C7.1 4 8 4.9 8 6S7.1 8 6 8 4 7.1 4 6 4.9 4 6 4M18 16C19.1 16 20 16.9 20 18S19.1 20 18 20 16 19.1 16 18 16.9 16 18 16M18 10C19.1 10 20 10.9 20 12S19.1 14 18 14 16 13.1 16 12 16.9 10 18 10M18 4C19.1 4 20 4.9 20 6S19.1 8 18 8 16 7.1 16 6 16.9 4 18 4Z\";\r\nvar mdiDotsHexagon = \"M16 12C16 10.9 16.9 10 18 10S20 10.9 20 12 19.1 14 18 14 16 13.1 16 12M10 12C10 10.9 10.9 10 12 10S14 10.9 14 12 13.1 14 12 14 10 13.1 10 12M4 12C4 10.9 4.9 10 6 10S8 10.9 8 12 7.1 14 6 14 4 13.1 4 12M13 18C13 16.9 13.9 16 15 16S17 16.9 17 18 16.1 20 15 20 13 19.1 13 18M7 18C7 16.9 7.9 16 9 16S11 16.9 11 18 10.1 20 9 20 7 19.1 7 18M13 6C13 4.9 13.9 4 15 4S17 4.9 17 6 16.1 8 15 8 13 7.1 13 6M7 6C7 4.9 7.9 4 9 4S11 4.9 11 6 10.1 8 9 8 7 7.1 7 6\";\r\nvar mdiDotsHorizontal = \"M16,12A2,2 0 0,1 18,10A2,2 0 0,1 20,12A2,2 0 0,1 18,14A2,2 0 0,1 16,12M10,12A2,2 0 0,1 12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12M4,12A2,2 0 0,1 6,10A2,2 0 0,1 8,12A2,2 0 0,1 6,14A2,2 0 0,1 4,12Z\";\r\nvar mdiDotsHorizontalCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 12,13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 12,10.5M6.5,10.5A1.5,1.5 0 0,0 5,12A1.5,1.5 0 0,0 6.5,13.5A1.5,1.5 0 0,0 8,12A1.5,1.5 0 0,0 6.5,10.5M17.5,10.5A1.5,1.5 0 0,0 16,12A1.5,1.5 0 0,0 17.5,13.5A1.5,1.5 0 0,0 19,12A1.5,1.5 0 0,0 17.5,10.5Z\";\r\nvar mdiDotsHorizontalCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M12,10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 12,10.5M7.5,10.5A1.5,1.5 0 0,1 9,12A1.5,1.5 0 0,1 7.5,13.5A1.5,1.5 0 0,1 6,12A1.5,1.5 0 0,1 7.5,10.5M16.5,10.5A1.5,1.5 0 0,1 18,12A1.5,1.5 0 0,1 16.5,13.5A1.5,1.5 0 0,1 15,12A1.5,1.5 0 0,1 16.5,10.5Z\";\r\nvar mdiDotsSquare = \"M12 16C13.1 16 14 16.9 14 18S13.1 20 12 20 10 19.1 10 18 10.9 16 12 16M12 4C13.1 4 14 4.9 14 6S13.1 8 12 8 10 7.1 10 6 10.9 4 12 4M6 16C7.1 16 8 16.9 8 18S7.1 20 6 20 4 19.1 4 18 4.9 16 6 16M6 10C7.1 10 8 10.9 8 12S7.1 14 6 14 4 13.1 4 12 4.9 10 6 10M6 4C7.1 4 8 4.9 8 6S7.1 8 6 8 4 7.1 4 6 4.9 4 6 4M18 16C19.1 16 20 16.9 20 18S19.1 20 18 20 16 19.1 16 18 16.9 16 18 16M18 10C19.1 10 20 10.9 20 12S19.1 14 18 14 16 13.1 16 12 16.9 10 18 10M18 4C19.1 4 20 4.9 20 6S19.1 8 18 8 16 7.1 16 6 16.9 4 18 4Z\";\r\nvar mdiDotsTriangle = \"M12 16C13.1 16 14 16.9 14 18S13.1 20 12 20 10 19.1 10 18 10.9 16 12 16M15 10C16.1 10 17 10.9 17 12S16.1 14 15 14 13 13.1 13 12 13.9 10 15 10M6 16C7.1 16 8 16.9 8 18S7.1 20 6 20 4 19.1 4 18 4.9 16 6 16M9 10C10.1 10 11 10.9 11 12S10.1 14 9 14 7 13.1 7 12 7.9 10 9 10M12 4C13.1 4 14 4.9 14 6S13.1 8 12 8 10 7.1 10 6 10.9 4 12 4M18 16C19.1 16 20 16.9 20 18S19.1 20 18 20 16 19.1 16 18 16.9 16 18 16\";\r\nvar mdiDotsVertical = \"M12,16A2,2 0 0,1 14,18A2,2 0 0,1 12,20A2,2 0 0,1 10,18A2,2 0 0,1 12,16M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M12,4A2,2 0 0,1 14,6A2,2 0 0,1 12,8A2,2 0 0,1 10,6A2,2 0 0,1 12,4Z\";\r\nvar mdiDotsVerticalCircle = \"M2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12M10.5,12A1.5,1.5 0 0,0 12,13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 12,10.5A1.5,1.5 0 0,0 10.5,12M10.5,17.5A1.5,1.5 0 0,0 12,19A1.5,1.5 0 0,0 13.5,17.5A1.5,1.5 0 0,0 12,16A1.5,1.5 0 0,0 10.5,17.5M10.5,6.5A1.5,1.5 0 0,0 12,8A1.5,1.5 0 0,0 13.5,6.5A1.5,1.5 0 0,0 12,5A1.5,1.5 0 0,0 10.5,6.5Z\";\r\nvar mdiDotsVerticalCircleOutline = \"M10.5,12A1.5,1.5 0 0,1 12,10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,12M10.5,16.5A1.5,1.5 0 0,1 12,15A1.5,1.5 0 0,1 13.5,16.5A1.5,1.5 0 0,1 12,18A1.5,1.5 0 0,1 10.5,16.5M10.5,7.5A1.5,1.5 0 0,1 12,6A1.5,1.5 0 0,1 13.5,7.5A1.5,1.5 0 0,1 12,9A1.5,1.5 0 0,1 10.5,7.5M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiDouban = \"M20,6H4V4H20V6M20,18V20H4V18H7.33L6.26,14H5V8H19V14H17.74L16.67,18H20M7,12H17V10H7V12M9.4,18H14.6L15.67,14H8.33L9.4,18Z\";\r\nvar mdiDownload = \"M5,20H19V18H5M19,9H15V3H9V9H5L12,16L19,9Z\";\r\nvar mdiDownloadBox = \"M5 3H19C20.11 3 21 3.9 21 5V19C21 20.11 20.11 21 19 21H5C3.9 21 3 20.11 3 19V5C3 3.9 3.9 3 5 3M8 17H16V15H8V17M16 10H13.5V7H10.5V10H8L12 14L16 10Z\";\r\nvar mdiDownloadBoxOutline = \"M8 17V15H16V17H8M16 10L12 14L8 10H10.5V7H13.5V10H16M5 3H19C20.11 3 21 3.9 21 5V19C21 20.11 20.11 21 19 21H5C3.9 21 3 20.11 3 19V5C3 3.9 3.9 3 5 3M5 5V19H19V5H5Z\";\r\nvar mdiDownloadCircle = \"M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M8 17H16V15H8V17M16 10H13.5V6H10.5V10H8L12 14L16 10Z\";\r\nvar mdiDownloadCircleOutline = \"M8 17V15H16V17H8M16 10L12 14L8 10H10.5V6H13.5V10H16M12 2C17.5 2 22 6.5 22 12C22 17.5 17.5 22 12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4Z\";\r\nvar mdiDownloadLock = \"M5 20H14V18H5M19 9H15V3H9V9H5L12 16M22 16A1.08 1.08 0 0 1 23 17V21A1.08 1.08 0 0 1 22 22H17A1.08 1.08 0 0 1 16 21V17A1.08 1.08 0 0 1 17 16V14.5A2.5 2.5 0 0 1 22 14.5V16M21 16V14.5A1.5 1.5 0 0 0 18 14.5V16H21\";\r\nvar mdiDownloadLockOutline = \"M22 16A1.08 1.08 0 0 1 23 17V21A1.08 1.08 0 0 1 22 22H17A1.08 1.08 0 0 1 16 21V17A1.08 1.08 0 0 1 17 16V14.5A2.5 2.5 0 0 1 22 14.5V16M21 16V14.5A1.5 1.5 0 0 0 18 14.5V16H21M13 5V11H14.17L12 13.17L9.83 11H11V5H13M15 3H9V9H5L12 16L19 9H15V3M14 18H5V20H14Z\";\r\nvar mdiDownloadMultiple = \"M9,1V7H5L12,14L19,7H15V1H9M5,16V18H19V16H5M5,20V22H19V20H5Z\";\r\nvar mdiDownloadNetwork = \"M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17M12,14.5L16.5,10H13V6H11V10H7.5L12,14.5Z\";\r\nvar mdiDownloadNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M12,14L16,10H13V6H11V10H8L12,14Z\";\r\nvar mdiDownloadOff = \"M20.84 22.73L18.11 20H5V18H16.11L13.06 14.95L12 16L5 9H7.11L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M19 9H15V3H9V5.8L15.6 12.4L19 9Z\";\r\nvar mdiDownloadOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L7.11 9H5L12 16L13.06 14.95L16.11 18H5V20H18.11L20.84 22.73L22.11 21.46M11 5H13V9.8L15.6 12.4L19 9H15V3H9V5.8L11 7.8V5Z\";\r\nvar mdiDownloadOutline = \"M13,5V11H14.17L12,13.17L9.83,11H11V5H13M15,3H9V9H5L12,16L19,9H15V3M19,18H5V20H19V18Z\";\r\nvar mdiDrag = \"M7,19V17H9V19H7M11,19V17H13V19H11M15,19V17H17V19H15M7,15V13H9V15H7M11,15V13H13V15H11M15,15V13H17V15H15M7,11V9H9V11H7M11,11V9H13V11H11M15,11V9H17V11H15M7,7V5H9V7H7M11,7V5H13V7H11M15,7V5H17V7H15Z\";\r\nvar mdiDragHorizontal = \"M3,15V13H5V15H3M3,11V9H5V11H3M7,15V13H9V15H7M7,11V9H9V11H7M11,15V13H13V15H11M11,11V9H13V11H11M15,15V13H17V15H15M15,11V9H17V11H15M19,15V13H21V15H19M19,11V9H21V11H19Z\";\r\nvar mdiDragHorizontalVariant = \"M21 11H3V9H21V11M21 13H3V15H21V13Z\";\r\nvar mdiDragVariant = \"M22.67,12L18.18,16.5L15.67,14L17.65,12L15.67,10.04L18.18,7.53L22.67,12M12,1.33L16.47,5.82L13.96,8.33L12,6.35L10,8.33L7.5,5.82L12,1.33M12,22.67L7.53,18.18L10.04,15.67L12,17.65L14,15.67L16.5,18.18L12,22.67M1.33,12L5.82,7.5L8.33,10L6.35,12L8.33,13.96L5.82,16.47L1.33,12M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10Z\";\r\nvar mdiDragVertical = \"M9,3H11V5H9V3M13,3H15V5H13V3M9,7H11V9H9V7M13,7H15V9H13V7M9,11H11V13H9V11M13,11H15V13H13V11M9,15H11V17H9V15M13,15H15V17H13V15M9,19H11V21H9V19M13,19H15V21H13V19Z\";\r\nvar mdiDragVerticalVariant = \"M11 21H9V3H11V21M15 3H13V21H15V3Z\";\r\nvar mdiDramaMasks = \"M8.11,19.45C5.94,18.65 4.22,16.78 3.71,14.35L2.05,6.54C1.81,5.46 2.5,4.4 3.58,4.17L13.35,2.1L13.38,2.09C14.45,1.88 15.5,2.57 15.72,3.63L16.07,5.3L20.42,6.23H20.45C21.5,6.47 22.18,7.53 21.96,8.59L20.3,16.41C19.5,20.18 15.78,22.6 12,21.79C10.42,21.46 9.08,20.61 8.11,19.45V19.45M20,8.18L10.23,6.1L8.57,13.92V13.95C8,16.63 9.73,19.27 12.42,19.84C15.11,20.41 17.77,18.69 18.34,16L20,8.18M16,16.5C15.37,17.57 14.11,18.16 12.83,17.89C11.56,17.62 10.65,16.57 10.5,15.34L16,16.5M8.47,5.17L4,6.13L5.66,13.94L5.67,13.97C5.82,14.68 6.12,15.32 6.53,15.87C6.43,15.1 6.45,14.3 6.62,13.5L7.05,11.5C6.6,11.42 6.21,11.17 6,10.81C6.06,10.2 6.56,9.66 7.25,9.5C7.33,9.5 7.4,9.5 7.5,9.5L8.28,5.69C8.32,5.5 8.38,5.33 8.47,5.17M15.03,12.23C15.35,11.7 16.03,11.42 16.72,11.57C17.41,11.71 17.91,12.24 18,12.86C17.67,13.38 17,13.66 16.3,13.5C15.61,13.37 15.11,12.84 15.03,12.23M10.15,11.19C10.47,10.66 11.14,10.38 11.83,10.53C12.5,10.67 13.03,11.21 13.11,11.82C12.78,12.34 12.11,12.63 11.42,12.5C10.73,12.33 10.23,11.8 10.15,11.19M11.97,4.43L13.93,4.85L13.77,4.05L11.97,4.43Z\";\r\nvar mdiDraw = \"M9.75 20.85C11.53 20.15 11.14 18.22 10.24 17C9.35 15.75 8.12 14.89 6.88 14.06C6 13.5 5.19 12.8 4.54 12C4.26 11.67 3.69 11.06 4.27 10.94C4.86 10.82 5.88 11.4 6.4 11.62C7.31 12 8.21 12.44 9.05 12.96L10.06 11.26C8.5 10.23 6.5 9.32 4.64 9.05C3.58 8.89 2.46 9.11 2.1 10.26C1.78 11.25 2.29 12.25 2.87 13.03C4.24 14.86 6.37 15.74 7.96 17.32C8.3 17.65 8.71 18.04 8.91 18.5C9.12 18.94 9.07 18.97 8.6 18.97C7.36 18.97 5.81 18 4.8 17.36L3.79 19.06C5.32 20 7.88 21.47 9.75 20.85M20.84 5.25C21.06 5.03 21.06 4.67 20.84 4.46L19.54 3.16C19.33 2.95 18.97 2.95 18.76 3.16L17.74 4.18L19.82 6.26M11 10.92V13H13.08L19.23 6.85L17.15 4.77L11 10.92Z\";\r\nvar mdiDrawing = \"M8.5,3A5.5,5.5 0 0,1 14,8.5C14,9.83 13.53,11.05 12.74,12H21V21H12V12.74C11.05,13.53 9.83,14 8.5,14A5.5,5.5 0 0,1 3,8.5A5.5,5.5 0 0,1 8.5,3Z\";\r\nvar mdiDrawingBox = \"M18,18H12V12.21C11.34,12.82 10.47,13.2 9.5,13.2C7.46,13.2 5.8,11.54 5.8,9.5A3.7,3.7 0 0,1 9.5,5.8C11.54,5.8 13.2,7.46 13.2,9.5C13.2,10.47 12.82,11.34 12.21,12H18M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiDresser = \"M4 3C2.9 3 2 3.9 2 5V8H22V5C22 3.9 21.11 3 20 3H4M10 5H14V6H10V5M2 9V14H22V9H2M10 11H14V12H10V11M2 15V18C2 19.11 2.9 20 4 20V21H6V20H18V21H20V20C21.11 20 22 19.11 22 18V15H2M10 17H14V18H10V17Z\";\r\nvar mdiDresserOutline = \"M4 3C2.9 3 2 3.9 2 5V18C2 19.11 2.9 20 4 20V21H6V20H18V21H20V20C21.11 20 22 19.11 22 18V5C22 3.9 21.11 3 20 3H4M4 5H20V8H4V5M10 6V7H14V6H10M4 10H20V13H4V10M10 11V12H14V11H10M4 15H20V18H4V15M10 16V17H14V16H10Z\";\r\nvar mdiDrone = \"M22,11H21L20,9H13.75L16,12.5H14L10.75,9H4C3.45,9 2,8.55 2,8C2,7.45 3.5,5.5 5.5,5.5C7.5,5.5 7.67,6.5 9,7H21A1,1 0 0,1 22,8V9L22,11M10.75,6.5L14,3H16L13.75,6.5H10.75M18,11V9.5H19.75L19,11H18M3,19A1,1 0 0,1 2,18A1,1 0 0,1 3,17A4,4 0 0,1 7,21A1,1 0 0,1 6,22A1,1 0 0,1 5,21A2,2 0 0,0 3,19M11,21A1,1 0 0,1 10,22A1,1 0 0,1 9,21A6,6 0 0,0 3,15A1,1 0 0,1 2,14A1,1 0 0,1 3,13A8,8 0 0,1 11,21Z\";\r\nvar mdiDropbox = \"M3 6.2L8 9.39L13 6.2L8 3L3 6.2M13 6.2L18 9.39L23 6.2L18 3L13 6.2M3 12.55L8 15.74L13 12.55L8 9.35L3 12.55M18 9.35L13 12.55L18 15.74L23 12.55L18 9.35M8.03 16.8L13.04 20L18.04 16.8L13.04 13.61L8.03 16.8Z\";\r\nvar mdiDrupal = \"M20.47,14.65C20.47,15.29 20.25,16.36 19.83,17.1C19.4,17.85 19.08,18.06 18.44,18.06C17.7,17.95 16.31,15.82 15.36,15.72C14.18,15.72 11.73,18.17 9.71,18.17C8.54,18.17 8.11,17.95 7.79,17.74C7.15,17.31 6.94,16.67 6.94,15.82C6.94,14.22 8.43,12.84 10.24,12.84C12.59,12.84 14.18,15.18 15.36,15.08C16.31,15.08 18.23,13.16 19.19,13.16C20.15,12.95 20.47,14 20.47,14.65M16.63,5.28C15.57,4.64 14.61,4.32 13.54,3.68C12.91,3.25 12.05,2.3 11.31,1.44C11,2.83 10.78,3.36 10.24,3.79C9.18,4.53 8.64,4.85 7.69,5.28C6.94,5.7 3,8.05 3,13.16C3,18.27 7.37,22 12.05,22C16.85,22 21,18.5 21,13.27C21.21,8.05 17.27,5.7 16.63,5.28Z\";\r\nvar mdiDuck = \"M8.5,5A1.5,1.5 0 0,0 7,6.5A1.5,1.5 0 0,0 8.5,8A1.5,1.5 0 0,0 10,6.5A1.5,1.5 0 0,0 8.5,5M10,2A5,5 0 0,1 15,7C15,8.7 14.15,10.2 12.86,11.1C14.44,11.25 16.22,11.61 18,12.5C21,14 22,12 22,12C22,12 21,21 15,21H9C9,21 4,21 4,16C4,13 7,12 6,10C2,10 2,6.5 2,6.5C3,7 4.24,7 5,6.65C5.19,4.05 7.36,2 10,2Z\";\r\nvar mdiDumbbell = \"M20.57,14.86L22,13.43L20.57,12L17,15.57L8.43,7L12,3.43L10.57,2L9.14,3.43L7.71,2L5.57,4.14L4.14,2.71L2.71,4.14L4.14,5.57L2,7.71L3.43,9.14L2,10.57L3.43,12L7,8.43L15.57,17L12,20.57L13.43,22L14.86,20.57L16.29,22L18.43,19.86L19.86,21.29L21.29,19.86L19.86,18.43L22,16.29L20.57,14.86Z\";\r\nvar mdiDumpTruck = \"M20,8H19L17,8H15V14H2V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V12L20,8M6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5M18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5M17,12V9.5H19.5L21.46,12H17M18,7H14V13H3L1.57,8H1V6H13L14,5H18V7Z\";\r\nvar mdiEarHearing = \"M17,20C16.71,20 16.44,19.94 16.24,19.85C15.53,19.5 15.03,18.97 14.53,17.47C14,15.91 13.06,15.18 12.14,14.47C11.35,13.86 10.53,13.23 9.82,11.94C9.29,11 9,9.93 9,9C9,6.2 11.2,4 14,4C16.8,4 19,6.2 19,9H21C21,5.07 17.93,2 14,2C10.07,2 7,5.07 7,9C7,10.26 7.38,11.65 8.07,12.9C9,14.55 10.05,15.38 10.92,16.05C11.73,16.67 12.31,17.12 12.63,18.1C13.23,19.92 14,20.94 15.36,21.65C15.87,21.88 16.43,22 17,22A4,4 0 0,0 21,18H19A2,2 0 0,1 17,20M7.64,2.64L6.22,1.22C4.23,3.21 3,5.96 3,9C3,12.04 4.23,14.79 6.22,16.78L7.63,15.37C6,13.74 5,11.5 5,9C5,6.5 6,4.26 7.64,2.64M11.5,9A2.5,2.5 0 0,0 14,11.5A2.5,2.5 0 0,0 16.5,9A2.5,2.5 0 0,0 14,6.5A2.5,2.5 0 0,0 11.5,9Z\";\r\nvar mdiEarHearingOff = \"M1,4.27L2.28,3L20,20.72L18.73,22L12.91,16.18C12.19,16.74 11.67,17.19 11.37,18.1C10.77,19.92 10,20.94 8.64,21.65C8.13,21.88 7.57,22 7,22A4,4 0 0,1 3,18H5A2,2 0 0,0 7,20C7.29,20 7.56,19.94 7.76,19.85C8.47,19.5 8.97,18.97 9.47,17.47C9.91,16.12 10.69,15.39 11.5,14.76L5.04,8.31C5,8.54 5,8.77 5,9H3C3,8.17 3.14,7.39 3.39,6.66L1,4.27M14.18,11.94C14.71,11 15,9.93 15,9C15,6.2 12.8,4 10,4C8.81,4 7.74,4.39 6.89,5.06L5.46,3.63C6.67,2.61 8.25,2 10,2C13.93,2 17,5.07 17,9C17,10.26 16.62,11.65 15.93,12.9L15.47,13.65L14.03,12.2L14.18,11.94M16.36,2.64L17.78,1.22C19.77,3.21 21,5.96 21,9C21,11.83 19.93,14.41 18.18,16.36L16.77,14.94C18.15,13.36 19,11.28 19,9C19,6.5 18,4.26 16.36,2.64M12.5,9C12.5,9.5 12.36,9.93 12.13,10.31L8.69,6.87C9.07,6.64 9.5,6.5 10,6.5A2.5,2.5 0 0,1 12.5,9Z\";\r\nvar mdiEarth = \"M17.9,17.39C17.64,16.59 16.89,16 16,16H15V13A1,1 0 0,0 14,12H8V10H10A1,1 0 0,0 11,9V7H13A2,2 0 0,0 15,5V4.59C17.93,5.77 20,8.64 20,12C20,14.08 19.2,15.97 17.9,17.39M11,19.93C7.05,19.44 4,16.08 4,12C4,11.38 4.08,10.78 4.21,10.21L9,15V16A2,2 0 0,0 11,18M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiEarthArrowRight = \"M19 21V19H15V17H19V15L22 18L19 21M12 18C12 15.8 13.2 13.9 15 12.8C14.9 12.3 14.5 12 14 12H8V10H10C10.6 10 11 9.6 11 9V7H13C14.1 7 15 6.1 15 5V4.6C17.9 5.8 20 8.6 20 12V12.3C20.7 12.5 21.3 12.9 21.9 13.4C22 13 22 12.5 22 12C22 6.5 17.5 2 12 2S2 6.5 2 12 6.5 22 12 22C12.5 22 13 22 13.4 21.9C12.5 20.8 12 19.5 12 18M11 19.9C7 19.4 4 16.1 4 12C4 11.4 4.1 10.8 4.2 10.2L9 15V16C9 17.1 9.9 18 11 18V19.9Z\";\r\nvar mdiEarthBox = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H5M15.78,5H19V17.18C18.74,16.38 17.69,15.79 16.8,15.79H15.8V12.79A1,1 0 0,0 14.8,11.79H8.8V9.79H10.8A1,1 0 0,0 11.8,8.79V6.79H13.8C14.83,6.79 15.67,6 15.78,5M5,10.29L9.8,14.79V15.79C9.8,16.9 10.7,17.79 11.8,17.79V19H5V10.29Z\";\r\nvar mdiEarthBoxMinus = \"M22 17V19H14V17H22M5 3H19C20.1 3 21 3.89 21 5V12.8C20.39 12.45 19.72 12.2 19 12.08V5H15.78C15.67 6 14.83 6.79 13.8 6.79H11.8V8.79C11.8 9.35 11.35 9.79 10.8 9.79H8.8V11.79H14.8C15.23 11.79 15.6 12.06 15.74 12.44C13.6 13.31 12.07 15.39 12 17.83C10.7 17.79 9.8 16.9 9.8 15.79V14.79L5 10.29V19H12.08C12.2 19.72 12.45 20.39 12.8 21H5C3.9 21 3 20.11 3 19V5C3 3.89 3.89 3 5 3Z\";\r\nvar mdiEarthBoxOff = \"M23,4.27L21,6.27V19A2,2 0 0,1 19,21H6.27L4.27,23L3,21.72L21.72,3L23,4.27M5,3H19.18L17.18,5H15.78C15.67,6 14.83,6.79 13.8,6.79H11.8V8.79C11.8,9.35 11.35,9.79 10.8,9.79H8.8V11.79H10.38L8.55,13.62L5,10.29V17.18L3,19.18V5C3,3.89 3.89,3 5,3M11.8,19V17.79C11.17,17.79 10.6,17.5 10.23,17.04L8.27,19H11.8M15.8,12.79V15.79H16.8C17.69,15.79 18.74,16.38 19,17.18V8.27L15.33,11.94C15.61,12.12 15.8,12.43 15.8,12.79Z\";\r\nvar mdiEarthBoxPlus = \"M17 14H19V17H22V19H19V22H17V19H14V17H17V14M5 3H19C20.1 3 21 3.89 21 5V12.8C20.39 12.45 19.72 12.2 19 12.08V5H15.78C15.67 6 14.83 6.79 13.8 6.79H11.8V8.79C11.8 9.35 11.35 9.79 10.8 9.79H8.8V11.79H14.8C15.23 11.79 15.6 12.06 15.74 12.44C13.6 13.31 12.07 15.39 12 17.83C10.7 17.79 9.8 16.9 9.8 15.79V14.79L5 10.29V19H12.08C12.2 19.72 12.45 20.39 12.8 21H5C3.9 21 3 20.11 3 19V5C3 3.89 3.89 3 5 3Z\";\r\nvar mdiEarthBoxRemove = \"M14.46 15.88L15.88 14.46L18 16.59L20.12 14.47L21.54 15.88L19.41 18L21.54 20.12L20.12 21.54L18 19.41L15.88 21.54L14.46 20.12L16.59 18L14.47 15.88M5 3H19C20.1 3 21 3.89 21 5V12.8C20.39 12.45 19.72 12.2 19 12.08V5H15.78C15.67 6 14.83 6.79 13.8 6.79H11.8V8.79C11.8 9.35 11.35 9.79 10.8 9.79H8.8V11.79H14.8C15.23 11.79 15.6 12.06 15.74 12.44C13.6 13.31 12.07 15.39 12 17.83C10.7 17.79 9.8 16.9 9.8 15.79V14.79L5 10.29V19H12.08C12.2 19.72 12.45 20.39 12.8 21H5C3.9 21 3 20.11 3 19V5C3 3.89 3.89 3 5 3Z\";\r\nvar mdiEarthMinus = \"M14 17H22V19H14V17M20 12C20 8.64 17.93 5.77 15 4.59V5C15 6.1 14.1 7 13 7H11V9C11 9.55 10.55 10 10 10H8V12H14C14.5 12 14.9 12.35 15 12.81C13.2 13.85 12 15.79 12 18C12 19.5 12.54 20.85 13.44 21.9L12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C17.5 2 22 6.5 22 12L21.9 13.44C21.34 12.96 20.7 12.59 20 12.34L20 12M11 19.93V18C9.9 18 9 17.1 9 16V15L4.21 10.21C4.08 10.78 4 11.38 4 12C4 16.08 7.06 19.44 11 19.93Z\";\r\nvar mdiEarthOff = \"M22,5.27L20.5,6.75C21.46,8.28 22,10.07 22,12A10,10 0 0,1 12,22C10.08,22 8.28,21.46 6.75,20.5L5.27,22L4,20.72L20.72,4L22,5.27M17.9,17.39C19.2,15.97 20,14.08 20,12C20,10.63 19.66,9.34 19.05,8.22L14.83,12.44C14.94,12.6 15,12.79 15,13V16H16C16.89,16 17.64,16.59 17.9,17.39M11,19.93V18C10.5,18 10.07,17.83 9.73,17.54L8.22,19.05C9.07,19.5 10,19.8 11,19.93M15,4.59V5A2,2 0 0,1 13,7H11V9A1,1 0 0,1 10,10H8V12H10.18L8.09,14.09L4.21,10.21C4.08,10.78 4,11.38 4,12C4,13.74 4.56,15.36 5.5,16.67L4.08,18.1C2.77,16.41 2,14.3 2,12A10,10 0 0,1 12,2C14.3,2 16.41,2.77 18.1,4.08L16.67,5.5C16.16,5.14 15.6,4.83 15,4.59Z\";\r\nvar mdiEarthPlus = \"M17 14H19V17H22V19H19V22H17V19H14V17H17V14M20 12C20 8.64 17.93 5.77 15 4.59V5C15 6.1 14.1 7 13 7H11V9C11 9.55 10.55 10 10 10H8V12H14C14.5 12 14.9 12.35 15 12.81C13.2 13.85 12 15.79 12 18C12 19.5 12.54 20.85 13.44 21.9L12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C17.5 2 22 6.5 22 12L21.9 13.44C21.34 12.96 20.7 12.59 20 12.34L20 12M11 19.93V18C9.9 18 9 17.1 9 16V15L4.21 10.21C4.08 10.78 4 11.38 4 12C4 16.08 7.06 19.44 11 19.93Z\";\r\nvar mdiEarthRemove = \"M14.46 15.88L15.88 14.46L18 16.59L20.12 14.47L21.54 15.88L19.41 18L21.54 20.12L20.12 21.54L18 19.41L15.88 21.54L14.46 20.12L16.59 18L14.47 15.88M20 12C20 8.64 17.93 5.77 15 4.59V5C15 6.1 14.1 7 13 7H11V9C11 9.55 10.55 10 10 10H8V12H14C14.5 12 14.9 12.35 15 12.81C13.2 13.85 12 15.79 12 18C12 19.5 12.54 20.85 13.44 21.9L12 22C6.5 22 2 17.5 2 12C2 6.5 6.5 2 12 2C17.5 2 22 6.5 22 12L21.9 13.44C21.34 12.96 20.7 12.59 20 12.34L20 12M11 19.93V18C9.9 18 9 17.1 9 16V15L4.21 10.21C4.08 10.78 4 11.38 4 12C4 16.08 7.06 19.44 11 19.93Z\";\r\nvar mdiEgg = \"M19.5,14.5A7.5,7.5 0 0,1 12,22A7.5,7.5 0 0,1 4.5,14.5C4.5,10.36 7.86,2 12,2C16.14,2 19.5,10.36 19.5,14.5Z\";\r\nvar mdiEggEaster = \"M6.89,6.36C8.23,3.91 10,2 12,2C14,2 15.77,3.91 17.11,6.36C16.26,6.57 15.5,7.07 15,7.77C13.79,6.11 11.46,5.75 9.8,6.97C9.5,7.19 9.22,7.46 9,7.77C8.5,7.07 7.74,6.57 6.89,6.36M15,18.06L12,15.06L9,18.06L6,15.06L4.73,16.33C5.75,20.35 9.83,22.77 13.84,21.76C16.5,21.08 18.59,19 19.27,16.33L18,15.06L15,18.06M9,15.94L12,12.94L15,15.94L18,12.94L19.5,14.44C19.37,12.13 18.8,9.86 17.81,7.76C16.65,7.86 15.75,8.83 15.75,10H14.25A2.25,2.25 0 0,0 12,7.75A2.25,2.25 0 0,0 9.75,10H8.25C8.25,8.83 7.35,7.86 6.19,7.76C5.2,9.86 4.63,12.13 4.5,14.44L6,12.94L9,15.94Z\";\r\nvar mdiEggOff = \"M22.1 21.5L2.4 1.7L1.1 3L6.1 8C5.1 10.3 4.5 12.8 4.5 14.5C4.5 18.6 7.9 22 12 22C14.2 22 16.2 21 17.6 19.5L20.8 22.7L22.1 21.5M19.5 14.5C19.5 10.4 16.1 2 12 2C10.5 2 9.1 3.1 7.9 4.7L19.3 16.1C19.4 15.6 19.5 15.1 19.5 14.5Z\";\r\nvar mdiEggOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L6.1 8C5.1 10.28 4.5 12.76 4.5 14.5C4.5 18.64 7.86 22 12 22C14.23 22 16.22 21 17.59 19.5L20.84 22.73L22.11 21.46M12 20C8.97 20 6.5 17.53 6.5 14.5C6.5 13.08 6.95 11.25 7.63 9.5L16.17 18.06C15.16 19.24 13.67 20 12 20M9.36 6.16L7.92 4.72C9.1 3.11 10.5 2 12 2C16.14 2 19.5 10.36 19.5 14.5C19.5 15.06 19.43 15.6 19.32 16.12L17.5 14.29C17.38 10.46 14.28 4 12 4C11.17 4 10.22 4.87 9.36 6.16Z\";\r\nvar mdiEggOutline = \"M12 4C14.32 4 17.5 10.7 17.5 14.5C17.5 17.53 15.03 20 12 20S6.5 17.53 6.5 14.5C6.5 10.7 9.68 4 12 4M12 2C7.86 2 4.5 10.36 4.5 14.5C4.5 18.64 7.86 22 12 22S19.5 18.64 19.5 14.5C19.5 10.36 16.14 2 12 2Z\";\r\nvar mdiEiffelTower = \"M8.21 17C8.65 16.15 9.06 15.16 9.44 14H9V12H10C10.61 9.4 11 6.13 11 2H13C13 6.13 13.4 9.4 14 12H15V14H14.56C14.94 15.16 15.35 16.15 15.79 17H17L17 19L19 22H16.58C15.81 20.24 14.05 19 12 19C9.95 19 8.19 20.24 7.42 22H5L7 19L6.97 17H8.21M12.59 14H11.41C11.07 15.13 10.69 16.13 10.28 17H13.72C13.32 16.13 12.93 15.13 12.59 14Z\";\r\nvar mdiEightTrack = \"M7,2L5,5V16L6,20C6.27,21.07 6.9,22 8,22H16A2,2 0 0,0 18,20L19,16V5L17,2H15V3H13V2H7M7,6H17V16H7V6Z\";\r\nvar mdiEject = \"M12,5L5.33,15H18.67M5,17H19V19H5V17Z\";\r\nvar mdiEjectOutline = \"M5,17H19V19H5V17M12,5L5.33,15H18.67L12,5M12,8.6L14.93,13H9.07L12,8.6Z\";\r\nvar mdiElectricSwitch = \"M1,11H3.17C3.58,9.83 4.69,9 6,9C6.65,9 7.25,9.21 7.74,9.56L14.44,4.87L15.58,6.5L8.89,11.2C8.96,11.45 9,11.72 9,12A3,3 0 0,1 6,15C4.69,15 3.58,14.17 3.17,13H1V11M23,11V13H20.83C20.42,14.17 19.31,15 18,15A3,3 0 0,1 15,12A3,3 0 0,1 18,9C19.31,9 20.42,9.83 20.83,11H23M6,11A1,1 0 0,0 5,12A1,1 0 0,0 6,13A1,1 0 0,0 7,12A1,1 0 0,0 6,11M18,11A1,1 0 0,0 17,12A1,1 0 0,0 18,13A1,1 0 0,0 19,12A1,1 0 0,0 18,11Z\";\r\nvar mdiElectricSwitchClosed = \"M20.83 11A3 3 0 0 0 15.18 11H8.82A3 3 0 0 0 3.17 11H1V13H3.17A3 3 0 0 0 8.82 13H15.18A3 3 0 0 0 20.83 13H23V11M6 13A1 1 0 1 1 7 12A1 1 0 0 1 6 13M18 13A1 1 0 1 1 19 12A1 1 0 0 1 18 13Z\";\r\nvar mdiElectronFramework = \"M12 22C10.33 22 8.84 20.5 7.9 17.93C7.83 17.73 7.93 17.5 8.14 17.44C8.34 17.36 8.56 17.47 8.63 17.67C9.44 19.9 10.7 21.23 12 21.23C12.94 21.23 13.87 20.55 14.62 19.31C14.73 19.13 14.96 19.07 15.15 19.18C15.33 19.29 15.39 19.53 15.28 19.71C14.38 21.19 13.22 22 12 22M15.91 17.72C15.87 17.72 15.83 17.71 15.8 17.7C15.59 17.63 15.5 17.42 15.54 17.21C16 15.81 16.22 14.18 16.22 12.5C16.22 8.65 14.97 5.24 13.19 4.14C12.94 4.5 12.5 4.78 12 4.78C11.24 4.78 10.61 4.16 10.61 3.39C10.61 2.62 11.24 2 12 2C12.77 2 13.4 2.61 13.41 3.37C15.53 4.5 17 8.21 17 12.5C17 14.25 16.75 15.96 16.28 17.45C16.23 17.61 16.08 17.72 15.91 17.72M12 2.77C11.66 2.77 11.38 3.05 11.38 3.39C11.38 3.73 11.67 4 12 4C12.35 4 12.64 3.73 12.64 3.39C12.64 3.05 12.35 2.77 12 2.77M4.08 18.54C3.31 18.54 2.68 17.91 2.68 17.15C2.68 16.66 2.94 16.22 3.33 15.97C3.19 13.56 5.68 10.41 9.5 8.22C11.09 7.32 12.75 6.67 14.32 6.34C14.5 6.29 14.73 6.42 14.77 6.63C14.82 6.84 14.69 7.05 14.5 7.09C13 7.41 11.41 8.03 9.9 8.89C6.46 10.86 4.1 13.68 4.1 15.76C4.86 15.77 5.5 16.39 5.5 17.15C5.5 17.92 4.85 18.54 4.08 18.54M4.08 16.53C3.74 16.53 3.46 16.81 3.46 17.15C3.46 17.5 3.74 17.77 4.08 17.77S4.71 17.5 4.71 17.15C4.71 16.81 4.42 16.53 4.08 16.53M18.5 13.44C18.43 13.44 18.34 13.41 18.27 13.35C18.11 13.21 18.09 12.97 18.23 12.8C19.77 11 20.3 9.26 19.64 8.14C19.17 7.33 18.1 6.88 16.63 6.86C16.41 6.86 16.24 6.68 16.25 6.47C16.25 6.26 16.43 6.1 16.64 6.09C18.39 6.11 19.7 6.7 20.31 7.75C21.15 9.19 20.6 11.21 18.82 13.3C18.74 13.39 18.63 13.44 18.5 13.44M16.5 18.9C14.5 18.9 11.94 18.16 9.5 16.77C7.95 15.88 6.57 14.79 5.5 13.63C5.35 13.47 5.36 13.23 5.5 13.08C5.68 12.94 5.92 12.95 6.07 13.11C7.08 14.21 8.4 15.25 9.89 16.1C13.2 18 16.77 18.63 18.65 17.72C18.57 17.55 18.5 17.35 18.5 17.15C18.5 16.38 19.15 15.76 19.92 15.76C20.69 15.76 21.32 16.38 21.32 17.15C21.32 17.92 20.69 18.54 19.92 18.54C19.64 18.54 19.39 18.46 19.17 18.32C18.47 18.71 17.56 18.9 16.5 18.9M19.5 17.63C19.63 17.71 19.77 17.77 19.92 17.77C20.27 17.77 20.55 17.5 20.55 17.15C20.55 16.81 20.27 16.53 19.92 16.53S19.3 16.81 19.3 17.15C19.3 17.29 19.35 17.42 19.43 17.53C19.47 17.55 19.5 17.59 19.5 17.63M4.46 12C4.33 12 4.2 11.92 4.13 11.8C3.23 10.25 3.08 8.81 3.7 7.74C4.54 6.3 6.58 5.76 9.31 6.25C9.5 6.29 9.66 6.5 9.62 6.7C9.59 6.91 9.39 7.05 9.18 7C6.82 6.59 5 7 4.37 8.13C3.89 8.95 4.04 10.11 4.8 11.41C4.9 11.6 4.84 11.83 4.65 11.94C4.59 11.97 4.53 12 4.46 12M12.21 13.4C11.71 13.5 11.21 13.19 11.11 12.69C11 12.2 11.32 11.71 11.81 11.6C12.31 11.5 12.81 11.81 12.91 12.31C13 12.8 12.7 13.29 12.21 13.4Z\";\r\nvar mdiElephant = \"M19.5,15.5A0.5,0.5 0 0,1 19,16A0.5,0.5 0 0,1 18.5,15.5V8.5C18.5,6.57 16.43,5 14.5,5H6A4,4 0 0,0 2,9V19H6V15H11V19H15V14.5A0.5,0.5 0 0,1 15.5,14A0.5,0.5 0 0,1 16,14.5V16A3,3 0 0,0 19,19A3,3 0 0,0 22,16V14H19.5V15.5Z\";\r\nvar mdiElevationDecline = \"M21,21H3V11.25L9.45,15L13.22,12.8L21,17.29V21M3,8.94V6.75L9.45,10.5L13.22,8.3L21,12.79V15L13.22,10.5L9.45,12.67L3,8.94Z\";\r\nvar mdiElevationRise = \"M3,21V17.29L10.78,12.8L14.55,15L21,11.25V21H3M21,8.94L14.55,12.67L10.78,10.5L3,15V12.79L10.78,8.3L14.55,10.5L21,6.75V8.94Z\";\r\nvar mdiElevator = \"M7,2L11,6H8V10H6V6H3L7,2M17,10L13,6H16V2H18V6H21L17,10M7,12H17A2,2 0 0,1 19,14V20A2,2 0 0,1 17,22H7A2,2 0 0,1 5,20V14A2,2 0 0,1 7,12M7,14V20H17V14H7Z\";\r\nvar mdiElevatorDown = \"M7 10L11 6H8V2H6V6H3L7 10M17 10L13 6H16V2H18V6H21L17 10M7 12H17C18.11 12 19 12.9 19 14V20C19 21.11 18.11 22 17 22H7C5.9 22 5 21.11 5 20V14C5 12.9 5.9 12 7 12M7 14V20H17V14H7Z\";\r\nvar mdiElevatorPassenger = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M8 5C8.8 5 9.5 5.7 9.5 6.5S8.8 8 8 8 6.5 7.3 6.5 6.5 7.2 5 8 5M11 14H9.5V19H6.5V14H5V11C5 9.9 5.9 9 7 9H9C10.1 9 11 9.9 11 11V14M15.9 19L13 14.2H18.8L15.9 19M13 10L16 5L19 10H13Z\";\r\nvar mdiElevatorUp = \"M7 2L11 6H8V10H6V6H3L7 2M17 2L13 6H16V10H18V6H21L17 2M7 12H17C18.11 12 19 12.9 19 14V20C19 21.11 18.11 22 17 22H7C5.9 22 5 21.11 5 20V14C5 12.9 5.9 12 7 12M7 14V20H17V14H7Z\";\r\nvar mdiEllipse = \"M12,4C6.5,4 2,7.58 2,12C2,16.42 6.5,20 12,20C17.5,20 22,16.42 22,12C22,7.58 17.5,4 12,4Z\";\r\nvar mdiEllipseOutline = \"M12,6C16.41,6 20,8.69 20,12C20,15.31 16.41,18 12,18C7.59,18 4,15.31 4,12C4,8.69 7.59,6 12,6M12,4C6.5,4 2,7.58 2,12C2,16.42 6.5,20 12,20C17.5,20 22,16.42 22,12C22,7.58 17.5,4 12,4Z\";\r\nvar mdiEmail = \"M20,8L12,13L4,8V6L12,11L20,6M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiEmailAlert = \"M18 8L10 13L2 8V6L10 11L18 6M18 4H2C.9 4 0 4.9 0 6V18C0 19.1 .9 20 2 20H18C19.1 20 20 19.1 20 18V6C20 4.9 19.1 4 18 4M24 7H22V13H24V7M24 15H22V17H24V15Z\";\r\nvar mdiEmailAlertOutline = \"M24 7H22V13H24V7M24 15H22V17H24V15M20 6C20 4.9 19.1 4 18 4H2C.9 4 0 4.9 0 6V18C0 19.1 .9 20 2 20H18C19.1 20 20 19.1 20 18V6M18 6L10 11L2 6H18M18 18H2V8L10 13L18 8V18Z\";\r\nvar mdiEmailBox = \"M5,3A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M6.4,6.5H17.6C18.37,6.5 19,7.12 19,7.9V16.1A1.4,1.4 0 0,1 17.6,17.5H6.4C5.63,17.5 5,16.87 5,16.1V7.9C5,7.12 5.62,6.5 6.4,6.5M6,8V10L12,14L18,10V8L12,12L6,8Z\";\r\nvar mdiEmailCheck = \"M21,13.34C20.37,13.12 19.7,13 19,13A6,6 0 0,0 13,19C13,19.34 13.03,19.67 13.08,20H3A2,2 0 0,1 1,18V6C1,4.89 1.89,4 3,4H19A2,2 0 0,1 21,6V13.34M23.5,17L18.5,22L15,18.5L16.5,17L18.5,19L22,15.5L23.5,17M3,6V8L11,13L19,8V6L11,11L3,6Z\";\r\nvar mdiEmailCheckOutline = \"M23.5 17L18.5 22L15 18.5L16.5 17L18.5 19L22 15.5L23.5 17M13 18H3V8L11 13L19 8V13H21V6C21 4.9 20.1 4 19 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H13V18M19 6L11 11L3 6H19Z\";\r\nvar mdiEmailEdit = \"M21,12.13C20.85,12.14 20.71,12.19 20.61,12.3L19.61,13.3L21.66,15.3L22.66,14.3C22.88,14.09 22.88,13.74 22.66,13.53L21.42,12.3C21.32,12.19 21.18,12.14 21.04,12.13M19.04,13.88L13,19.94V22H15.06L21.12,15.93M20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H11V19.11L19.24,10.89C19.71,10.4 20.36,10.13 21.04,10.13C21.38,10.13 21.72,10.19 22.04,10.32V6C22.04,4.88 21.12,4 20,4M20,8L12,13L4,8V6L12,11L20,6\";\r\nvar mdiEmailEditOutline = \"M19.07 13.88L13 19.94V22H15.06L21.12 15.93M22.7 13.58L21.42 12.3C21.32 12.19 21.18 12.13 21.04 12.13C20.89 12.14 20.75 12.19 20.65 12.3L19.65 13.3L21.7 15.3L22.7 14.3C22.89 14.1 22.89 13.78 22.7 13.58M11 18H4V8L12 13L20 8V10H22V6C22 4.9 21.1 4 20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H11V18M20 6L12 11L4 6H20Z\";\r\nvar mdiEmailLock = \"M20.5,0A2.5,2.5 0 0,1 23,2.5V3A1,1 0 0,1 24,4V8A1,1 0 0,1 23,9H18A1,1 0 0,1 17,8V4A1,1 0 0,1 18,3V2.5A2.5,2.5 0 0,1 20.5,0M12,11L4,6V8L12,13L16.18,10.39C16.69,10.77 17.32,11 18,11H22V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H15V8C15,8.36 15.06,8.7 15.18,9L12,11M20.5,1A1.5,1.5 0 0,0 19,2.5V3H22V2.5A1.5,1.5 0 0,0 20.5,1Z\";\r\nvar mdiEmailMarkAsUnread = \"M18.84,7H16.22L10.5,4L4,7.41V17A2,2 0 0,1 2,15V7.17C2,6.5 2.28,6.06 2.81,5.81L10.5,2L18.05,5.81C18.5,6.09 18.78,6.5 18.84,7M7,8H20A2,2 0 0,1 22,10V19A2,2 0 0,1 20,21H7A2,2 0 0,1 5,19V10A2,2 0 0,1 7,8M20,11.67V10L13.5,13.31L7,10V11.67L13.5,15L20,11.67Z\";\r\nvar mdiEmailMinus = \"M3,4C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H14.09C14.03,19.67 14,19.34 14,19A6,6 0 0,1 20,13C20.34,13 20.67,13.03 21,13.09V6C21,4.89 20.1,4 19,4H3M3,6L11,11L19,6V8L11,13L3,8V6M16,18V20H24V18H16Z\";\r\nvar mdiEmailMinusOutline = \"M16 18V20H24V18H16M14 19C14 18.66 14.04 18.33 14.09 18H3V8L11 13L19 8V13.09C19.33 13.04 19.66 13 20 13S20.67 13.04 21 13.09V6C21 4.9 20.1 4 19 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H14.09C14.04 19.67 14 19.34 14 19M19 6L11 11L3 6H19Z\";\r\nvar mdiEmailMultiple = \"M22,6V4L14,9L6,4V6L14,11L22,6M22,2A2,2 0 0,1 24,4V16A2,2 0 0,1 22,18H6C4.89,18 4,17.1 4,16V4C4,2.89 4.89,2 6,2H22M2,6V20H20V22H2A2,2 0 0,1 0,20V6H2Z\";\r\nvar mdiEmailMultipleOutline = \"M2 6V20H20V22H2C.895 22 0 21.11 0 20V6H2M24 4C24 2.9 23.1 2 22 2H6C4.9 2 4 2.9 4 4V16C4 17.1 4.9 18 6 18H22C23.1 18 24 17.1 24 16V4M22 4L14 9L6 4H22M22 16H6V6L14 11L22 6V16Z\";\r\nvar mdiEmailNewsletter = \"M12 .64L8.23 3H5V5L2.97 6.29C2.39 6.64 2 7.27 2 8V18C2 19.11 2.9 20 4 20H20C21.11 20 22 19.11 22 18V8C22 7.27 21.61 6.64 21.03 6.29L19 5V3H15.77M7 5H17V9.88L12 13L7 9.88M8 6V7.5H16V6M5 7.38V8.63L4 8M19 7.38L20 8L19 8.63M8 8.5V10H16V8.5Z\";\r\nvar mdiEmailOff = \"M22.1 21.5L2.4 1.7L1.1 3L2.6 4.5C2.2 4.9 2 5.4 2 6V18C2 19.1 2.9 20 4 20H18.1L20.8 22.7L22.1 21.5M4 8V6L4.3 6.2L9.6 11.5L4 8M13.4 10.2L7.2 4H20C21.1 4 22 4.9 22 6V18C22 18.2 22 18.5 21.9 18.7L14.6 11.4L20 8V6L13.4 10.2Z\";\r\nvar mdiEmailOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L2.6 4.5C2.3 4.9 2 5.4 2 6V18C2 19.1 2.9 20 4 20H18.1L20.8 22.7L22.1 21.5M4 18V8L9.6 11.5L16.1 18H4M9.2 6L7.2 4H20C21.1 4 22 4.9 22 6V18C22 18.2 22 18.5 21.9 18.7L20 16.8V8L14.6 11.4L13.4 10.2L20 6H9.2Z\";\r\nvar mdiEmailOpen = \"M4,8L12,13L20,8V8L12,3L4,8V8M22,8V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V8C2,7.27 2.39,6.64 2.97,6.29L12,0.64L21.03,6.29C21.61,6.64 22,7.27 22,8Z\";\r\nvar mdiEmailOpenMultiple = \"M6,8L14,13L22,8V8L14,3L6,8V8M24,8V18A2,2 0 0,1 22,20H6A2,2 0 0,1 4,18V8C4,7.27 4.39,6.64 4.97,6.29L14,0.64L23.03,6.29C23.61,6.64 24,7.27 24,8M2,8V22H20V24H2A2,2 0 0,1 0,22V8H2Z\";\r\nvar mdiEmailOpenMultipleOutline = \"M2 8V22H20V24H2C.895 24 0 23.11 0 22V8H2M23.03 6.29L14 .64L4.97 6.29C4.39 6.64 4 7.27 4 8V18C4 19.1 4.9 20 6 20H22C23.1 20 24 19.1 24 18V8C24 7.27 23.61 6.64 23.03 6.29M22 18H6V10L14 15L22 10V18M14 13L6 8L14 3L22 8L14 13Z\";\r\nvar mdiEmailOpenOutline = \"M21.03 6.29L12 .64L2.97 6.29C2.39 6.64 2 7.27 2 8V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 7.27 21.61 6.64 21.03 6.29M20 18H4V10L12 15L20 10V18M12 13L4 8L12 3L20 8L12 13Z\";\r\nvar mdiEmailOutline = \"M22 6C22 4.9 21.1 4 20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6M20 6L12 11L4 6H20M20 18H4V8L12 13L20 8V18Z\";\r\nvar mdiEmailPlus = \"M3,4C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H14.09C14.03,19.67 14,19.34 14,19A6,6 0 0,1 20,13C20.34,13 20.67,13.03 21,13.09V6C21,4.89 20.1,4 19,4H3M3,6L11,11L19,6V8L11,13L3,8V6M19,15V18H16V20H19V23H21V20H24V18H21V15H19Z\";\r\nvar mdiEmailPlusOutline = \"M19 15V18H16V20H19V23H21V20H24V18H21V15H19M14 18H3V8L11 13L19 8V13H21V6C21 4.9 20.1 4 19 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H14V18M19 6L11 11L3 6H19Z\";\r\nvar mdiEmailReceive = \"M22 20H18V23L13 18.5L18 14V17H22V20M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H11.35A5.8 5.8 0 0 1 11 18A6 6 0 0 1 22 14.69V6A2 2 0 0 0 20 4M20 8L12 13L4 8V6L12 11L20 6Z\";\r\nvar mdiEmailReceiveOutline = \"M22 20H18V23L13 18.5L18 14V17H22V20M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H11V18H4V8L12 13L20 8V15H22V6A2 2 0 0 0 20 4M12 11L4 6H20Z\";\r\nvar mdiEmailSearch = \"M3,4H19A2,2 0 0,1 21,6V10.82C20,9.85 18.7,9.23 17.31,9.06L19,8V6L11,11L3,6V8L10.62,12.76C10.21,13.62 10,14.55 10,15.5C10,17.18 10.65,18.79 11.81,20H3A2,2 0 0,1 1,18V6C1,4.89 1.89,4 3,4M16.5,11C19,11 21,13 21,15.5C21,16.38 20.75,17.21 20.31,17.9L23.39,21L22,22.39L18.88,19.32C18.19,19.75 17.37,20 16.5,20C14,20 12,18 12,15.5C12,13 14,11 16.5,11M16.5,13A2.5,2.5 0 0,0 14,15.5A2.5,2.5 0 0,0 16.5,18A2.5,2.5 0 0,0 19,15.5A2.5,2.5 0 0,0 16.5,13Z\";\r\nvar mdiEmailSearchOutline = \"M16.5 11C19 11 21 13 21 15.5C21 16.38 20.75 17.21 20.31 17.9L23.39 21L22 22.39L18.88 19.32C18.19 19.75 17.37 20 16.5 20C14 20 12 18 12 15.5S14 11 16.5 11M16.5 13C15.12 13 14 14.12 14 15.5S15.12 18 16.5 18 19 16.88 19 15.5 17.88 13 16.5 13M10.5 18H3V8L10.62 12.76C11.65 10.54 13.9 9 16.5 9C16.77 9 17.04 9 17.31 9.06L19 8V9.5C19.75 9.81 20.42 10.27 21 10.82V6C21 4.9 20.1 4 19 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H11.82C11.27 19.42 10.82 18.75 10.5 18M19 6L11 11L3 6H19Z\";\r\nvar mdiEmailSend = \"M13 17H17V14L22 18.5L17 23V20H13V17M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H11.35A5.8 5.8 0 0 1 11 18A6 6 0 0 1 22 14.69V6A2 2 0 0 0 20 4M20 8L12 13L4 8V6L12 11L20 6Z\";\r\nvar mdiEmailSendOutline = \"M13 17H17V14L22 18.5L17 23V20H13V17M20 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H11V18H4V8L12 13L20 8V14H22V6A2 2 0 0 0 20 4M12 11L4 6H20Z\";\r\nvar mdiEmailSync = \"M3 4C1.89 4 1 4.89 1 6V18C1 19.11 1.9 20 3 20H13.5A6.5 6.5 0 0 1 13 17.5A6.5 6.5 0 0 1 19.5 11A6.5 6.5 0 0 1 21 11.18V6C21 4.89 20.1 4 19 4H3M3 6L11 11L19 6V8L11 13L3 8V6M19 12L16.75 14.25L19 16.5V15C20.38 15 21.5 16.12 21.5 17.5C21.5 17.9 21.41 18.28 21.24 18.62L22.33 19.71C22.75 19.08 23 18.32 23 17.5C23 15.29 21.21 13.5 19 13.5V12M15.67 15.29C15.25 15.92 15 16.68 15 17.5C15 19.71 16.79 21.5 19 21.5V23L21.25 20.75L19 18.5V20C17.62 20 16.5 18.88 16.5 17.5C16.5 17.1 16.59 16.72 16.76 16.38L15.67 15.29Z\";\r\nvar mdiEmailSyncOutline = \"M3 4C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H13.5A6.5 6.5 0 0 1 13 18H3V8L11 13L19 8V11A6.5 6.5 0 0 1 19.5 11A6.5 6.5 0 0 1 21 11.18V6C21 4.9 20.1 4 19 4H3M3 6H19L11 11L3 6M19 12L16.75 14.25L19 16.5V15C20.38 15 21.5 16.12 21.5 17.5C21.5 17.9 21.41 18.28 21.24 18.62L22.33 19.71C22.75 19.08 23 18.32 23 17.5C23 15.29 21.21 13.5 19 13.5V12M15.67 15.29C15.25 15.92 15 16.68 15 17.5C15 19.71 16.79 21.5 19 21.5V23L21.25 20.75L19 18.5V20C17.62 20 16.5 18.88 16.5 17.5C16.5 17.1 16.59 16.72 16.76 16.38L15.67 15.29Z\";\r\nvar mdiEmailVariant = \"M12,13L2,6.76V6C2,4.89 2.89,4 4,4H20A2,2 0 0,1 22,6V6.75L12,13M22,18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V9.11L4,10.36V18H20V10.36L22,9.11V18Z\";\r\nvar mdiEmber = \"M22,14.22C22,14.22 17.61,17.35 14.72,17.39C11.84,17.44 12.13,15.56 12.13,15.56C12.13,15.56 22.71,11.94 19.83,4.79C18.53,2.95 17,2.37 14.89,2.42C12.76,2.46 10.17,3.76 8.46,7.6C7.64,9.44 7.41,11.18 7.24,12.5V12.5C7.24,12.5 5.32,12.88 4.32,12.04C3.32,11.2 2.77,12.04 2.77,12.04C2.77,12.04 1.03,14.2 2.75,14.87C4.46,15.54 7.12,15.82 7.12,15.82V15.82C7.36,17 8.08,19 10.17,20.6C13.3,23 19.32,20.4 19.32,20.4M11.63,12.33C11.76,7.36 15,5.18 16.15,6.27C17.27,7.36 16.86,9.7 14.72,11.16C12.59,12.63 11.63,12.33 11.63,12.33Z\";\r\nvar mdiEmby = \"M11,2L6,7L7,8L2,13L7,18L8,17L13,22L18,17L17,16L22,11L17,6L16,7L11,2M10,8.5L16,12L10,15.5V8.5Z\";\r\nvar mdiEmoticon = \"M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M15.5,8A1.5,1.5 0 0,1 17,9.5A1.5,1.5 0 0,1 15.5,11A1.5,1.5 0 0,1 14,9.5A1.5,1.5 0 0,1 15.5,8M8.5,8A1.5,1.5 0 0,1 10,9.5A1.5,1.5 0 0,1 8.5,11A1.5,1.5 0 0,1 7,9.5A1.5,1.5 0 0,1 8.5,8M12,17.5C9.67,17.5 7.69,16.04 6.89,14H17.11C16.3,16.04 14.33,17.5 12,17.5Z\";\r\nvar mdiEmoticonAngry = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,9.5V8L10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5M14.77,17.23C14.32,16.5 13.25,16 12,16C10.75,16 9.68,16.5 9.23,17.23L7.81,15.81C8.71,14.72 10.25,14 12,14C13.75,14 15.29,14.72 16.19,15.81L14.77,17.23M17,9.5C17,10.3 16.3,11 15.5,11C14.7,11 14,10.3 14,9.5L17,8V9.5Z\";\r\nvar mdiEmoticonAngryOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,14C13.75,14 15.29,14.72 16.19,15.81L14.77,17.23C14.32,16.5 13.25,16 12,16C10.75,16 9.68,16.5 9.23,17.23L7.81,15.81C8.71,14.72 10.25,14 12,14M10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5V8L10,9.5M17,9.5C17,10.3 16.3,11 15.5,11C14.7,11 14,10.3 14,9.5L17,8V9.5\";\r\nvar mdiEmoticonConfused = \"M12 2A10 10 0 1 0 22 12A10 10 0 0 0 12 2M8.5 8A1.5 1.5 0 1 1 7 9.5A1.54 1.54 0 0 1 8.5 8M17 16H13A4 4 0 0 0 9.53 18L7.8 17A6 6 0 0 1 13 14H17M15.5 11A1.5 1.5 0 1 1 17 9.5A1.54 1.54 0 0 1 15.5 11Z\";\r\nvar mdiEmoticonConfusedOutline = \"M20 12A8 8 0 1 0 12 20A8 8 0 0 0 20 12M22 12A10 10 0 1 1 12 2A10 10 0 0 1 22 12M15.5 8A1.5 1.5 0 1 1 14 9.5A1.54 1.54 0 0 1 15.5 8M10 9.5A1.5 1.5 0 1 1 8.5 8A1.54 1.54 0 0 1 10 9.5M17 15H13A4 4 0 0 0 9.53 17L7.8 16A6 6 0 0 1 13 13H17Z\";\r\nvar mdiEmoticonCool = \"M3.22,7.22C4.91,4.11 8.21,2 12,2C15.79,2 19.09,4.11 20.78,7.22L20,8H4L3.22,7.22M21.4,8.6C21.78,9.67 22,10.81 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12C2,10.81 2.22,9.67 2.6,8.6L4,10H5C5,11.38 7.12,12.5 8.5,12.5C9.88,12.5 11.25,11.38 11.25,10H12.75C12.75,11.38 14.12,12.5 15.5,12.5C16.88,12.5 19,11.38 19,10H20L21.4,8.6M16.19,15.42L14.77,14C14.32,14.72 13.25,15.23 12,15.23C10.75,15.23 9.68,14.72 9.23,14L7.81,15.42C8.71,16.5 10.25,17.23 12,17.23C13.75,17.23 15.29,16.5 16.19,15.42Z\";\r\nvar mdiEmoticonCoolOutline = \"M19,10C19,11.38 16.88,12.5 15.5,12.5C14.12,12.5 12.75,11.38 12.75,10H11.25C11.25,11.38 9.88,12.5 8.5,12.5C7.12,12.5 5,11.38 5,10H4.25C4.09,10.64 4,11.31 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12C20,11.31 19.91,10.64 19.75,10H19M12,4C9.04,4 6.45,5.61 5.07,8H18.93C17.55,5.61 14.96,4 12,4M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23Z\";\r\nvar mdiEmoticonCry = \"M5.14,17.57C5.14,16.5 6.32,14.5 7.57,12.81C8.82,14.5 10,16.5 10,17.57A2.43,2.43 0 0,1 7.57,20C6.23,20 5.14,18.91 5.14,17.57M22,12A10,10 0 0,1 12,22C11.08,22 10.18,21.86 9.33,21.63C10.9,20.95 12,19.39 12,17.57C12,17.12 11.89,16.6 11.69,16C11.79,16 11.89,16 12,16C13.25,16 14.32,16.5 14.77,17.23L16.19,15.81C15.29,14.72 13.75,14 12,14C11.59,14 11.19,14.04 10.81,14.12C10.38,13.36 9.85,12.53 9.19,11.63L8.71,11C9.42,10.87 10,10.23 10,9.5C10,8.7 9.3,8 8.5,8C7.7,8 7,8.7 7,9.5C7,9.69 7.04,9.87 7.11,10.04L5.96,11.63C4.4,13.75 3.5,15.5 3.23,16.81C2.45,15.38 2,13.74 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M17,9.5C17,8.7 16.3,8 15.5,8C14.7,8 14,8.7 14,9.5C14,10.3 14.7,11 15.5,11C16.3,11 17,10.3 17,9.5Z\";\r\nvar mdiEmoticonCryOutline = \"M7.57,20C6.23,20 5.14,18.91 5.14,17.57C5.14,16.5 6.32,14.5 7.57,12.81C8.82,14.5 10,16.5 10,17.57A2.43,2.43 0 0,1 7.57,20M12,2A10,10 0 0,0 2,12C2,13.75 2.45,15.38 3.24,16.81C3.4,16 3.81,15.07 4.31,14.17C4.11,13.5 4,12.75 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20C11.76,20 11.53,20 11.29,19.96C10.82,20.7 10.14,21.28 9.34,21.63C10.19,21.87 11.08,22 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,14C11.59,14 11.19,14.04 10.81,14.12C11.16,14.75 11.47,15.4 11.69,16C11.79,16 11.89,16 12,16C13.25,16 14.32,16.5 14.77,17.23L16.19,15.81C15.29,14.72 13.75,14 12,14M15.5,8C14.7,8 14,8.7 14,9.5C14,10.3 14.7,11 15.5,11C16.3,11 17,10.3 17,9.5C17,8.7 16.3,8 15.5,8M10,9.5C10,8.7 9.3,8 8.5,8C7.7,8 7,8.7 7,9.5C7,10.3 7.7,11 8.5,11C9.3,11 10,10.3 10,9.5\";\r\nvar mdiEmoticonDead = \"M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2M6.76,8.82L7.82,7.76L8.88,8.82L9.94,7.76L11,8.82L9.94,9.88L11,10.94L9.94,12L8.88,10.94L7.82,12L6.76,10.94L7.82,9.88L6.76,8.82M6.89,17.5C7.69,15.46 9.67,14 12,14C14.33,14 16.31,15.46 17.11,17.5H6.89M17.24,10.94L16.18,12L15.12,10.94L14.06,12L13,10.94L14.06,9.88L13,8.82L14.06,7.76L15.12,8.82L16.18,7.76L17.24,8.82L16.18,9.88L17.24,10.94Z\";\r\nvar mdiEmoticonDeadOutline = \"M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M16.18,7.76L15.12,8.82L14.06,7.76L13,8.82L14.06,9.88L13,10.94L14.06,12L15.12,10.94L16.18,12L17.24,10.94L16.18,9.88L17.24,8.82L16.18,7.76M7.82,12L8.88,10.94L9.94,12L11,10.94L9.94,9.88L11,8.82L9.94,7.76L8.88,8.82L7.82,7.76L6.76,8.82L7.82,9.88L6.76,10.94L7.82,12M12,14C9.67,14 7.69,15.46 6.89,17.5H17.11C16.31,15.46 14.33,14 12,14Z\";\r\nvar mdiEmoticonDevil = \"M22.5,2.09C21.6,3 20.13,3.73 18.31,4.25C16.59,2.84 14.39,2 12,2C9.61,2 7.41,2.84 5.69,4.25C3.87,3.73 2.4,3 1.5,2.09C1.53,3.72 2.35,5.21 3.72,6.4C2.63,8 2,9.92 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,9.92 21.37,8 20.28,6.4C21.65,5.21 22.47,3.72 22.5,2.09M7.5,8.5L10.5,10C10.5,10.8 9.8,11.5 9,11.5C8.2,11.5 7.5,10.8 7.5,10V8.5M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23M16.5,10C16.5,10.8 15.8,11.5 15,11.5C14.2,11.5 13.5,10.8 13.5,10L16.5,8.5V10Z\";\r\nvar mdiEmoticonDevilOutline = \"M1.5,2.09C2.4,3 3.87,3.73 5.69,4.25C7.41,2.84 9.61,2 12,2C14.39,2 16.59,2.84 18.31,4.25C20.13,3.73 21.6,3 22.5,2.09C22.47,3.72 21.65,5.21 20.28,6.4C21.37,8 22,9.92 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12C2,9.92 2.63,8 3.72,6.4C2.35,5.21 1.53,3.72 1.5,2.09M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M10.5,10C10.5,10.8 9.8,11.5 9,11.5C8.2,11.5 7.5,10.8 7.5,10V8.5L10.5,10M16.5,10C16.5,10.8 15.8,11.5 15,11.5C14.2,11.5 13.5,10.8 13.5,10L16.5,8.5V10M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23Z\";\r\nvar mdiEmoticonExcited = \"M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2M8.88,7.82L11,9.94L9.94,11L8.88,9.94L7.82,11L6.76,9.94L8.88,7.82M12,17.5C9.67,17.5 7.69,16.04 6.89,14H17.11C16.31,16.04 14.33,17.5 12,17.5M16.18,11L15.12,9.94L14.06,11L13,9.94L15.12,7.82L17.24,9.94L16.18,11Z\";\r\nvar mdiEmoticonExcitedOutline = \"M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M13,9.94L14.06,11L15.12,9.94L16.18,11L17.24,9.94L15.12,7.82L13,9.94M8.88,9.94L9.94,11L11,9.94L8.88,7.82L6.76,9.94L7.82,11L8.88,9.94M12,17.5C14.33,17.5 16.31,16.04 17.11,14H6.89C7.69,16.04 9.67,17.5 12,17.5Z\";\r\nvar mdiEmoticonFrown = \"M12 2C6.47 2 2 6.5 2 12S6.47 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M15.5 8C16.33 8 17 8.67 17 9.5S16.33 11 15.5 11 14 10.33 14 9.5 14.67 8 15.5 8M8.5 8C9.33 8 10 8.67 10 9.5S9.33 11 8.5 11 7 10.33 7 9.5 7.67 8 8.5 8M6.89 17C7.69 14.96 9.67 13.5 12 13.5S16.31 14.96 17.11 17H6.89Z\";\r\nvar mdiEmoticonFrownOutline = \"M12 2C6.47 2 2 6.5 2 12S6.47 22 12 22C17.5 22 22 17.5 22 12S17.5 2 12 2M12 20C7.58 20 4 16.42 4 12S7.58 4 12 4 20 7.58 20 12 16.42 20 12 20M15.5 11C16.33 11 17 10.33 17 9.5S16.33 8 15.5 8 14 8.67 14 9.5 14.67 11 15.5 11M8.5 11C9.33 11 10 10.33 10 9.5S9.33 8 8.5 8 7 8.67 7 9.5 7.67 11 8.5 11M12 13.5C9.67 13.5 7.69 14.96 6.89 17H17.11C16.31 14.96 14.33 13.5 12 13.5Z\";\r\nvar mdiEmoticonHappy = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23M15.5,11C14.7,11 14,10.3 14,9.5C14,8.7 14.7,8 15.5,8C16.3,8 17,8.7 17,9.5C17,10.3 16.3,11 15.5,11Z\";\r\nvar mdiEmoticonHappyOutline = \"M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5M17,9.5C17,10.3 16.3,11 15.5,11C14.7,11 14,10.3 14,9.5C14,8.7 14.7,8 15.5,8C16.3,8 17,8.7 17,9.5M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23Z\";\r\nvar mdiEmoticonKiss = \"M18.9,18.94L15.94,16C15.76,15.79 15.55,15.5 15.55,15.05A1.3,1.3 0 0,1 16.85,13.75C17.19,13.75 17.53,13.89 17.77,14.15L18.91,15.26L20.03,14.13C20.27,13.89 20.61,13.75 20.95,13.75A1.3,1.3 0 0,1 22.25,15.05C22.25,15.39 22.11,15.73 21.87,15.97L18.9,18.94M17.46,19.62C15.72,21.1 13.47,22 11,22A10,10 0 0,1 1,12A10,10 0 0,1 11,2A10,10 0 0,1 21,12C21,12.09 21,12.17 20.95,12.25C20.21,12.25 19.5,12.55 18.97,13.07L18.9,13.14L18.84,13.09C18.32,12.55 17.6,12.25 16.85,12.25A2.8,2.8 0 0,0 14.05,15.05C14.05,15.78 14.34,16.5 14.87,17.03L17.46,19.62M13,9.5C13,10.3 13.7,11 14.5,11C15.3,11 16,10.3 16,9.5C16,8.7 15.3,8 14.5,8C13.7,8 13,8.7 13,9.5M9,9.5C9,8.7 8.3,8 7.5,8C6.7,8 6,8.7 6,9.5C6,10.3 6.7,11 7.5,11C8.3,11 9,10.3 9,9.5M12.94,15.18L14,14.12L11.88,12L10.82,13.06L11.88,14.12L10.82,15.18L11.88,16.24L10.82,17.3L11.88,18.36L14,16.24L12.94,15.18Z\";\r\nvar mdiEmoticonKissOutline = \"M9,9.5C9,10.3 8.3,11 7.5,11C6.7,11 6,10.3 6,9.5C6,8.7 6.7,8 7.5,8C8.3,8 9,8.7 9,9.5M16,9.5C16,10.3 15.3,11 14.5,11C13.7,11 13,10.3 13,9.5C13,8.7 13.7,8 14.5,8C15.3,8 16,8.7 16,9.5M14,14.12L11.88,12L10.82,13.06L11.88,14.12L10.82,15.18L11.88,16.24L10.82,17.3L11.88,18.36L14,16.24L12.94,15.18L14,14.12M16.85,13A2.05,2.05 0 0,0 14.8,15.05C14.8,15.62 15.03,16.12 15.4,16.5L18.9,20L22.4,16.5C22.77,16.13 23,15.61 23,15.05A2.05,2.05 0 0,0 20.95,13C20.4,13 19.87,13.23 19.5,13.6L18.9,14.2L18.3,13.61C17.93,13.23 17.4,13 16.85,13M15,18.92C13.82,19.6 12.46,20 11,20A8,8 0 0,1 3,12A8,8 0 0,1 11,4C15.26,4 18.73,7.33 19,11.5C19.58,11.19 20.26,11 20.95,11C20.45,5.95 16.18,2 11,2A10,10 0 0,0 1,12A10,10 0 0,0 11,22C13,22 14.88,21.4 16.45,20.38L15,18.92Z\";\r\nvar mdiEmoticonLol = \"M15.07 8.93V4.93A4.06 4.06 0 0 1 15.73 2.72A10 10 0 0 0 2.73 15.72A4.06 4.06 0 0 1 4.94 15.06H8.94V19.06A4.06 4.06 0 0 1 8.28 21.27A10 10 0 0 0 21.28 8.27A4.06 4.06 0 0 1 19.07 8.93M11 6H12.5V7.5H14V9H11M7.5 14V12.5H6V11H9V14M15.89 15.9A5.5 5.5 0 0 1 9.8 17L17 9.8A5.5 5.5 0 0 1 15.89 15.89M4.89 21.08A2 2 0 0 1 2.89 19.08A2 2 0 0 1 4.89 17.08H6.89V19.08A2 2 0 0 1 4.93 21.07M19.07 2.93A2 2 0 0 1 21.07 4.93A2 2 0 0 1 19.07 6.93H17.07V4.93A2 2 0 0 1 19.07 2.93Z\";\r\nvar mdiEmoticonLolOutline = \"M6 11V12.5H7.5V14H9V11M12.5 6H11V9H14V7.5H12.5M9.8 17A5.5 5.5 0 0 0 17 9.8M6.34 6.34A8 8 0 0 1 15.08 4.62A4.11 4.11 0 0 1 15.73 2.72A10 10 0 0 0 2.73 15.72A4.11 4.11 0 0 1 4.63 15.07A8 8 0 0 1 6.34 6.34M17.66 17.66A8 8 0 0 1 8.92 19.38A4.11 4.11 0 0 1 8.27 21.28A10 10 0 0 0 21.27 8.28A4.11 4.11 0 0 1 19.37 8.93A8 8 0 0 1 17.66 17.66M6 11V12.5H7.5V14H9V11M9.8 17A5.5 5.5 0 0 0 17 9.8M12.5 6H11V9H14V7.5H12.5M6 11V12.5H7.5V14H9V11M12.5 6H11V9H14V7.5H12.5M9.8 17A5.5 5.5 0 0 0 17 9.8M4.93 21A2 2 0 0 1 2.93 19A2 2 0 0 1 4.93 17H6.93V19A2 2 0 0 1 4.93 21.07M19.07 2.93A2 2 0 0 1 21.07 4.93A2 2 0 0 1 19.07 6.93H17.07V4.93A2 2 0 0 1 19.07 2.93Z\";\r\nvar mdiEmoticonNeutral = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,9.5A1.5,1.5 0 0,1 8.5,8A1.5,1.5 0 0,1 10,9.5A1.5,1.5 0 0,1 8.5,11A1.5,1.5 0 0,1 7,9.5M16,16H8V14H16V16M15.5,11A1.5,1.5 0 0,1 14,9.5A1.5,1.5 0 0,1 15.5,8A1.5,1.5 0 0,1 17,9.5A1.5,1.5 0 0,1 15.5,11Z\";\r\nvar mdiEmoticonNeutralOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M8.5,11A1.5,1.5 0 0,1 7,9.5A1.5,1.5 0 0,1 8.5,8A1.5,1.5 0 0,1 10,9.5A1.5,1.5 0 0,1 8.5,11M17,9.5A1.5,1.5 0 0,1 15.5,11A1.5,1.5 0 0,1 14,9.5A1.5,1.5 0 0,1 15.5,8A1.5,1.5 0 0,1 17,9.5M16,14V16H8V14H16Z\";\r\nvar mdiEmoticonOutline = \"M12,17.5C14.33,17.5 16.3,16.04 17.11,14H6.89C7.69,16.04 9.67,17.5 12,17.5M8.5,11A1.5,1.5 0 0,0 10,9.5A1.5,1.5 0 0,0 8.5,8A1.5,1.5 0 0,0 7,9.5A1.5,1.5 0 0,0 8.5,11M15.5,11A1.5,1.5 0 0,0 17,9.5A1.5,1.5 0 0,0 15.5,8A1.5,1.5 0 0,0 14,9.5A1.5,1.5 0 0,0 15.5,11M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiEmoticonPoop = \"M11.36,2C11.15,2 10.87,2.12 10.57,2.32C10,2.7 8.85,3.9 8.4,5.1C8.06,6 8.05,6.82 8.19,7.43C7.63,7.53 7.22,7.71 7.06,7.78C6.55,8 5.47,8.96 5.37,10.45C5.34,10.97 5.41,11.5 5.57,12C4.91,12.19 4.53,12.43 4.5,12.44C4.18,12.56 3.65,12.93 3.5,13.13C3.15,13.53 2.92,14 2.79,14.5C2.5,15.59 2.6,16.83 3.13,17.83C3.42,18.39 3.82,19 4.26,19.43C5.7,20.91 8.18,21.47 10.14,21.79C12.53,22.19 15.03,22.05 17.26,21.13C20.61,19.74 21.5,17.5 21.64,16.89C21.93,15.5 21.57,14.19 21.42,13.87C21.2,13.41 20.84,12.94 20.25,12.64C19.85,12.39 19.5,12.26 19.24,12.2C19.5,11.25 19.13,10.5 18.62,9.94C17.85,9.12 17.06,9 17.06,9V9C17.32,8.5 17.42,7.9 17.28,7.32C17.12,6.61 16.73,6.16 16.22,5.86C15.7,5.55 15.06,5.4 14.4,5.28C14.08,5.22 12.75,5.03 12.2,4.27C11.75,3.65 11.74,2.53 11.62,2.2C11.57,2.07 11.5,2 11.36,2M16,9.61C16.07,9.61 16.13,9.62 16.19,9.62C17.62,9.78 18.64,11.16 18.47,12.69C18.3,14.22 17,15.34 15.57,15.18V15.18C14.14,15 13.12,13.65 13.29,12.11C13.45,10.66 14.64,9.56 16,9.61M8.62,9.61C9.95,9.65 11.06,10.78 11.16,12.21C11.28,13.75 10.21,15.08 8.78,15.19H8.77C7.34,15.3 6.08,14.14 5.96,12.6V12.6C5.85,11.06 6.92,9.73 8.35,9.62V9.62C8.44,9.61 8.53,9.61 8.62,9.61M8.64,11.31C8.6,11.31 8.57,11.31 8.53,11.32C7.97,11.39 7.57,11.9 7.64,12.45C7.7,13 8.21,13.39 8.77,13.32C9.33,13.25 9.73,12.74 9.67,12.19C9.61,11.67 9.15,11.3 8.64,11.31M15.94,11.33C15.42,11.35 15,11.75 14.96,12.28C14.92,12.83 15.35,13.31 15.91,13.34C16.5,13.38 16.96,12.95 17,12.4C17.04,11.84 16.61,11.36 16.05,11.33C16,11.33 16,11.33 15.94,11.33M8.71,16.15C9,16.14 9.26,16.23 9.5,16.28C10.68,16.5 11.7,16.53 12.19,16.53C12.68,16.53 13.69,16.5 14.86,16.28C15.27,16.2 15.74,16.03 16.11,16.28C16.59,16.6 16.24,17.75 15.5,18.53C15.04,19 13.97,19.91 12.19,19.91C10.41,19.91 9.33,19 8.88,18.53C8.14,17.75 7.79,16.6 8.26,16.28C8.4,16.19 8.55,16.15 8.71,16.15Z\";\r\nvar mdiEmoticonPoopOutline = \"M21.42,13.87C21.2,13.41 20.84,12.94 20.25,12.64C19.85,12.39 19.5,12.26 19.24,12.2C19.5,11.25 19.13,10.5 18.62,9.94C17.85,9.12 17.06,9 17.06,9C17.32,8.5 17.42,7.9 17.28,7.32C17.12,6.61 16.73,6.16 16.22,5.86C15.7,5.55 15.06,5.4 14.4,5.28C14.08,5.22 12.75,5.03 12.2,4.27C11.75,3.65 11.74,2.53 11.62,2.2C11.57,2.07 11.5,2 11.36,2C11.15,2 10.87,2.12 10.57,2.32C10,2.7 8.85,3.9 8.4,5.1C8.06,6 8.05,6.82 8.19,7.43C7.63,7.53 7.22,7.71 7.06,7.78C6.55,8 5.47,8.96 5.37,10.45C5.34,10.89 5.41,11.34 5.5,11.78C5.5,11.86 5.5,11.94 5.5,12.03C4.88,12.22 4.53,12.43 4.5,12.44C4.18,12.56 3.65,12.93 3.5,13.13C3.15,13.53 2.92,14 2.79,14.5C2.5,15.59 2.6,16.83 3.13,17.83C3.42,18.39 3.82,19 4.26,19.43C5.7,20.91 8.18,21.47 10.14,21.79C10.96,21.93 11.8,22 12.63,22C14.22,22 15.8,21.73 17.26,21.13C20.61,19.74 21.5,17.5 21.64,16.89C21.93,15.5 21.57,14.19 21.42,13.87M16.05,11.33C16.61,11.36 17.04,11.84 17,12.4C16.96,12.95 16.5,13.38 15.91,13.34C15.35,13.31 14.92,12.83 14.96,12.28C15,11.75 15.42,11.35 15.94,11.33C16,11.33 16,11.33 16.05,11.33M20.18,16.55C20.17,16.57 19.7,18.5 16.69,19.74C15.47,20.25 14.1,20.5 12.63,20.5C11.9,20.5 11.14,20.44 10.38,20.31C8.76,20.05 6.5,19.56 5.31,18.36C5.04,18.09 4.72,17.63 4.46,17.13C4.12,16.5 4.04,15.65 4.24,14.88C4.32,14.58 4.45,14.32 4.63,14.12L4.65,14.09C4.74,14 4.95,13.88 5.03,13.84V13.84L5.14,13.8L5.26,13.74C5.32,13.7 5.46,13.63 5.67,13.55C6.13,14.81 7.28,15.7 8.59,15.7C8.67,15.7 8.74,15.69 8.82,15.69C9.65,15.63 10.41,15.22 10.94,14.55C11.47,13.89 11.73,13.04 11.66,12.17C11.54,10.5 10.22,9.16 8.64,9.11H8.62C8.5,9.11 8.4,9.11 8.31,9.12C8,9.15 7.73,9.23 7.46,9.34C7.55,9.24 7.63,9.17 7.66,9.15C7.79,9.1 8.07,9 8.45,8.91L10,8.63L9.65,7.09C9.61,6.9 9.53,6.35 9.81,5.63C9.96,5.2 10.27,4.76 10.58,4.38C10.68,4.65 10.81,4.91 11,5.15C11.77,6.23 13.12,6.58 14.06,6.74L14.13,6.76C14.6,6.84 15.13,6.95 15.46,7.15C15.67,7.28 15.76,7.41 15.82,7.67C15.87,7.87 15.84,8.1 15.73,8.31L15.21,9.2C13.95,9.5 12.95,10.64 12.79,12.06C12.59,13.87 13.78,15.46 15.5,15.68C15.62,15.69 15.74,15.7 15.85,15.7C16.56,15.7 17.25,15.44 17.82,14.95C18.23,14.59 18.54,14.13 18.74,13.62L18.9,13.66C19,13.68 19.17,13.74 19.45,13.91L19.5,13.95L19.57,14C19.78,14.08 19.94,14.26 20.05,14.5C20.13,14.67 20.38,15.6 20.18,16.55M7.64,12.45C7.57,11.9 7.97,11.39 8.53,11.32C8.57,11.31 8.6,11.31 8.64,11.31C9.15,11.3 9.61,11.67 9.67,12.19C9.73,12.74 9.33,13.25 8.77,13.32C8.21,13.39 7.7,13 7.64,12.45M8.71,16.15C9,16.14 9.26,16.23 9.5,16.28C10.68,16.5 11.7,16.53 12.19,16.53C12.68,16.53 13.69,16.5 14.86,16.28C15.27,16.2 15.74,16.03 16.11,16.28C16.59,16.6 16.24,17.75 15.5,18.53C15.04,19 13.97,19.91 12.19,19.91C10.41,19.91 9.33,19 8.88,18.53C8.14,17.75 7.79,16.6 8.26,16.28C8.4,16.19 8.55,16.15 8.71,16.15Z\";\r\nvar mdiEmoticonSad = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5M14.77,17.23C14.32,16.5 13.25,16 12,16C10.75,16 9.68,16.5 9.23,17.23L7.81,15.81C8.71,14.72 10.25,14 12,14C13.75,14 15.29,14.72 16.19,15.81L14.77,17.23M15.5,11C14.7,11 14,10.3 14,9.5C14,8.7 14.7,8 15.5,8C16.3,8 17,8.7 17,9.5C17,10.3 16.3,11 15.5,11Z\";\r\nvar mdiEmoticonSadOutline = \"M20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M15.5,8C16.3,8 17,8.7 17,9.5C17,10.3 16.3,11 15.5,11C14.7,11 14,10.3 14,9.5C14,8.7 14.7,8 15.5,8M10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5M12,14C13.75,14 15.29,14.72 16.19,15.81L14.77,17.23C14.32,16.5 13.25,16 12,16C10.75,16 9.68,16.5 9.23,17.23L7.81,15.81C8.71,14.72 10.25,14 12,14Z\";\r\nvar mdiEmoticonSick = \"M21 9C19.9 9 19 8.1 19 7S21 3 21 3 23 5.9 23 7 22.1 9 21 9M17.5 7C17.5 6.27 17.91 5.29 18.42 4.34C16.68 2.88 14.44 2 12 2C6.47 2 2 6.5 2 12S6.47 22 12 22C17.5 22 22 17.5 22 12C22 11.45 21.94 10.91 21.86 10.38C21.58 10.45 21.3 10.5 21 10.5C19.07 10.5 17.5 8.93 17.5 7M15.62 7.38L16.68 8.44L15.62 9.5L16.68 10.56L15.62 11.62L13.5 9.5L15.62 7.38M7.32 8.44L8.38 7.38L10.5 9.5L8.38 11.62L7.32 10.56L8.38 9.5L7.32 8.44M15.44 17C14.75 15.81 13.47 15 12 15S9.25 15.81 8.56 17H6.88C7.18 16.24 7.64 15.57 8.22 15L5.24 13.3C4.79 13.56 4.23 13.58 3.75 13.3C3.03 12.89 2.79 11.97 3.2 11.25S4.53 10.29 5.25 10.7C5.73 11 6 11.5 6 12L9.57 14.06C10.3 13.7 11.12 13.5 12 13.5C14.33 13.5 16.32 14.95 17.12 17H15.44Z\";\r\nvar mdiEmoticonSickOutline = \"M7.32 10.56L8.38 9.5L7.32 8.44L8.38 7.38L10.5 9.5L8.38 11.62L7.32 10.56M4.5 9C4.53 9 4.55 9 4.58 9C5.77 6.07 8.64 4 12 4C14.19 4 16.16 4.88 17.61 6.3C17.76 5.7 18.06 5 18.42 4.34C16.68 2.88 14.44 2 12 2C7.11 2 3.05 5.5 2.18 10.14C2.74 9.44 3.59 9 4.5 9M21 10.5C20.58 10.5 20.18 10.41 19.81 10.28C19.93 10.83 20 11.41 20 12C20 16.42 16.42 20 12 20C8.64 20 5.77 17.93 4.58 15C4.55 15 4.53 15 4.5 15C4 15 3.46 14.86 3 14.6C2.68 14.42 2.41 14.18 2.18 13.9C3.07 18.5 7.11 22 12 22C17.5 22 22 17.5 22 12C22 11.45 21.94 10.91 21.86 10.38C21.58 10.45 21.3 10.5 21 10.5M21 3C21 3 19 5.9 19 7S19.9 9 21 9 23 8.1 23 7 21 3 21 3M15.62 7.38L13.5 9.5L15.62 11.62L16.68 10.56L15.62 9.5L16.68 8.44L15.62 7.38M8.56 17C9.25 15.81 10.53 15 12 15S14.75 15.81 15.44 17H17.12C16.32 14.95 14.33 13.5 12 13.5C11.13 13.5 10.3 13.7 9.57 14.07L6 12C6 11.5 5.73 11 5.25 10.71C4.53 10.3 3.62 10.54 3.2 11.26C2.79 12 3.03 12.89 3.75 13.31C4.23 13.59 4.8 13.56 5.24 13.31L8.21 15.03C7.64 15.56 7.18 16.24 6.88 17H8.56Z\";\r\nvar mdiEmoticonTongue = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7.27,11C7.1,10.71 7,10.36 7,10C7,8.89 7.89,8 9,8A2,2 0 0,1 11,10C11,10.36 10.9,10.71 10.73,11C10.39,10.4 9.74,10 9,10C8.26,10 7.61,10.4 7.27,11M16,15H15C15,17 14.1,18 13,18C11.9,18 11,17 11,15H8V13H16V15M16.73,11C16.39,10.4 15.74,10 15,10C14.26,10 13.61,10.4 13.27,11C13.1,10.71 13,10.36 13,10C13,8.89 13.89,8 15,8A2,2 0 0,1 17,10C17,10.36 16.9,10.71 16.73,11Z\";\r\nvar mdiEmoticonTongueOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M9,10C8.26,10 7.61,10.4 7.27,11C7.1,10.71 7,10.36 7,10A2,2 0 0,1 9,8C10.11,8 11,8.9 11,10C11,10.36 10.9,10.71 10.73,11C10.39,10.4 9.74,10 9,10M17,10C17,10.36 16.9,10.71 16.73,11C16.39,10.4 15.74,10 15,10C14.26,10 13.61,10.4 13.27,11C13.1,10.71 13,10.36 13,10A2,2 0 0,1 15,8C16.11,8 17,8.9 17,10M16,13V15H15C15,17 14.1,18 13,18C11.9,18 11,17 11,15H8V13H16Z\";\r\nvar mdiEmoticonWink = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23M17,10H13V9H17V10Z\";\r\nvar mdiEmoticonWinkOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M10,9.5C10,10.3 9.3,11 8.5,11C7.7,11 7,10.3 7,9.5C7,8.7 7.7,8 8.5,8C9.3,8 10,8.7 10,9.5M12,17.23C10.25,17.23 8.71,16.5 7.81,15.42L9.23,14C9.68,14.72 10.75,15.23 12,15.23C13.25,15.23 14.32,14.72 14.77,14L16.19,15.42C15.29,16.5 13.75,17.23 12,17.23M17,10H13V9H17V10Z\";\r\nvar mdiEngine = \"M7,4V6H10V8H7L5,10V13H3V10H1V18H3V15H5V18H8L10,20H18V16H20V19H23V9H20V12H18V8H12V6H15V4H7Z\";\r\nvar mdiEngineOff = \"M3.78,2.5L21.5,20.22L20.23,21.5L18,19.27V20H10L8,18H5V15H3V18H1V10H3V13H5V10L6.87,8.14L2.5,3.77L3.78,2.5M20,9V12H18V8H12V6H15V4H7.82L22.82,19H23V9H20Z\";\r\nvar mdiEngineOffOutline = \"M2.5,3.77L6.87,8.14L5,10V13H3V10H1V18H3V15H5V18H8L10,20H18V19.27L21.23,22.5L22.5,21.22L3.78,2.5L2.5,3.77M16,18H11L9,16H7V11L8,10H8.73L16,17.27V18M23,9V19H22.82L16,12.18V10H13.82L7.82,4H15V6H12V8H18V12H20V9H23Z\";\r\nvar mdiEngineOutline = \"M8,10H16V18H11L9,16H7V11M7,4V6H10V8H7L5,10V13H3V10H1V18H3V15H5V18H8L10,20H18V16H20V19H23V9H20V12H18V8H12V6H15V4H7Z\";\r\nvar mdiEpsilon = \"M15.05 7.78L16.15 6.18C16.15 6.18 14.91 5 12.77 5C10.04 5 8.35 6.84 8.35 8.76C8.35 10.68 10.08 11.69 10.08 11.69C10.08 11.69 8 12.38 8 15C8 17.63 10.14 19 12.44 19C15.38 19 17 17.04 17 17.04L15.6 15.5C15.6 15.5 14.14 16.87 12.59 16.87C10.66 16.87 10.21 15.69 10.21 14.92C10.21 13.87 10.54 12.65 13.83 12.65L13.82 10.77C13.82 10.77 10.44 11.11 10.44 8.78C10.44 7.21 11.9 6.92 12.64 6.92C14.28 6.92 15.05 7.78 15.05 7.78\";\r\nvar mdiEqual = \"M19,10H5V8H19V10M19,16H5V14H19V16Z\";\r\nvar mdiEqualBox = \"M17,16V14H7V16H17M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19M17,10V8H7V10H17Z\";\r\nvar mdiEqualizer = \"M10,20H14V4H10V20M4,20H8V12H4V20M16,9V20H20V9H16Z\";\r\nvar mdiEqualizerOutline = \"M15,21H9V3H15V21M11,19H13V5H11V19M8,21H2V11H8V21M4,19H6V13H4V19M22,21H16V8H22V21M18,19H20V10H18V19Z\";\r\nvar mdiEraser = \"M16.24,3.56L21.19,8.5C21.97,9.29 21.97,10.55 21.19,11.34L12,20.53C10.44,22.09 7.91,22.09 6.34,20.53L2.81,17C2.03,16.21 2.03,14.95 2.81,14.16L13.41,3.56C14.2,2.78 15.46,2.78 16.24,3.56M4.22,15.58L7.76,19.11C8.54,19.9 9.8,19.9 10.59,19.11L14.12,15.58L9.17,10.63L4.22,15.58Z\";\r\nvar mdiEraserVariant = \"M15.14,3C14.63,3 14.12,3.2 13.73,3.59L2.59,14.73C1.81,15.5 1.81,16.77 2.59,17.56L5.03,20H12.69L21.41,11.27C22.2,10.5 22.2,9.23 21.41,8.44L16.56,3.59C16.17,3.2 15.65,3 15.14,3M17,18L15,20H22V18\";\r\nvar mdiEscalator = \"M20,8H18.95L6.95,20H4A2,2 0 0,1 2,18A2,2 0 0,1 4,16H5.29L7,14.29V10A1,1 0 0,1 8,9H9A1,1 0 0,1 10,10V11.29L17.29,4H20A2,2 0 0,1 22,6A2,2 0 0,1 20,8M8.5,5A1.5,1.5 0 0,1 10,6.5A1.5,1.5 0 0,1 8.5,8A1.5,1.5 0 0,1 7,6.5A1.5,1.5 0 0,1 8.5,5Z\";\r\nvar mdiEscalatorBox = \"M5 3C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3H5M14.34 6H17.05C18.16 6 19.05 6.9 19.05 8C19.05 9.11 18.16 10 17.05 10H16L10 18H7.05C5.95 18 5.05 17.11 5.05 16C5.05 14.9 5.95 14 7.05 14H8.34L14.34 6Z\";\r\nvar mdiEscalatorDown = \"M20 8H18.95L6.95 20H4C2.9 20 2 19.11 2 18C2 16.9 2.9 16 4 16H5.29L7 14.29V10C7 9.45 7.45 9 8 9H9C9.55 9 10 9.45 10 10V11.29L17.29 4H20C21.11 4 22 4.89 22 6C22 7.11 21.11 8 20 8M8.5 5C9.33 5 10 5.67 10 6.5C10 7.33 9.33 8 8.5 8C7.67 8 7 7.33 7 6.5C7 5.67 7.67 5 8.5 5M14.83 17.34L20.34 11.83L22.17 13.66L16.66 19.17L18.5 21H13V15.5L14.83 17.34Z\";\r\nvar mdiEscalatorUp = \"M20 8H18.95L6.95 20H4C2.9 20 2 19.11 2 18C2 16.9 2.9 16 4 16H5.29L7 14.29V10C7 9.45 7.45 9 8 9H9C9.55 9 10 9.45 10 10V11.29L17.29 4H20C21.11 4 22 4.89 22 6C22 7.11 21.11 8 20 8M8.5 5C9.33 5 10 5.67 10 6.5C10 7.33 9.33 8 8.5 8C7.67 8 7 7.33 7 6.5C7 5.67 7.67 5 8.5 5M20.17 15.66L14.66 21.17L12.83 19.34L18.34 13.83L16.5 12H22V17.5L20.17 15.66Z\";\r\nvar mdiEslint = \"M7.95,9.55L11.84,7.3C11.94,7.25 12.06,7.25 12.16,7.3L16.05,9.55C16.15,9.61 16.21,9.71 16.21,9.82V14.32C16.21,14.43 16.15,14.53 16.05,14.59L12.16,16.84C12.06,16.89 11.94,16.89 11.84,16.84L7.95,14.59C7.85,14.53 7.79,14.43 7.79,14.32V9.82C7.79,9.71 7.85,9.61 7.95,9.55M22.12,11.6C22.29,11.89 22.29,12.23 22.12,12.53L17.47,20.56C17.3,20.86 17,21 16.65,21H7.35C7,21 6.7,20.85 6.53,20.56L1.88,12.53C1.71,12.24 1.71,11.87 1.88,11.58L6.53,3.5C6.7,3.22 7,3 7.35,3H16.65C17,3 17.3,3.22 17.47,3.5L22.12,11.6M18.27,15.5V8.65C18.27,8.53 18.2,8.42 18.09,8.36L12.16,4.95C12.06,4.89 11.93,4.89 11.83,4.95L5.91,8.36C5.8,8.42 5.73,8.53 5.73,8.65V15.5C5.73,15.61 5.8,15.72 5.91,15.78L11.84,19.19C11.94,19.25 12.07,19.25 12.17,19.19L18.09,15.78C18.2,15.72 18.27,15.61 18.27,15.5Z\";\r\nvar mdiEt = \"M23,8.78L21.71,7.22C21.45,7.42 20.53,8 19.77,8C19.26,8 18.3,7.75 17.45,7.53C16.39,7.26 15.39,7 14.6,7C14,7 13.43,7.15 12.93,7.35C12.62,5.45 11,4 9,4C4.58,4 2,7.58 2,12C2,16.42 5.58,19 10,19C12.06,19 13.93,18.43 15.34,17.39L15,21.29L17,21.47L18,9.74C18.66,9.89 19.27,10 19.77,10C21.38,10 22.84,8.91 23,8.78M9,6A2,2 0 0,1 11,8A2,2 0 0,1 9,10H4.23C4.8,7.67 6.39,6 9,6M10,17C6.69,17 4,15.31 4,12H9C10.6,12 11.83,11.17 12.5,9.91V9.91C12.76,9.71 13.85,9 14.6,9C14.94,9 15.5,9.11 16.05,9.25L15.65,13.89C14.82,15.95 12.6,17 10,17Z\";\r\nvar mdiEthereum = \"M12,1.75L5.75,12.25L12,16L18.25,12.25L12,1.75M5.75,13.5L12,22.25L18.25,13.5L12,17.25L5.75,13.5Z\";\r\nvar mdiEthernet = \"M7,15H9V18H11V15H13V18H15V15H17V18H19V9H15V6H9V9H5V18H7V15M4.38,3H19.63C20.94,3 22,4.06 22,5.38V19.63A2.37,2.37 0 0,1 19.63,22H4.38C3.06,22 2,20.94 2,19.63V5.38C2,4.06 3.06,3 4.38,3Z\";\r\nvar mdiEthernetCable = \"M11,3V7H13V3H11M8,4V11H16V4H14V8H10V4H8M10,12V22H14V12H10Z\";\r\nvar mdiEthernetCableOff = \"M11,3H13V7H11V3M8,4H10V8H14V4H16V11H12.82L8,6.18V4M20,20.72L18.73,22L14,17.27V22H10V13.27L2,5.27L3.28,4L20,20.72Z\";\r\nvar mdiEvPlugCcs1 = \"M16 15H15.59C17.63 13.78 19 11.55 19 9C19 5.47 16.39 2.57 13 2.08V.949H11V2.08C7.61 2.57 5 5.47 5 9C5 11.55 6.37 13.78 8.41 15H8C5.79 15 4 16.79 4 19S5.79 23 8 23H16C18.21 23 20 21.21 20 19S18.21 15 16 15M17.5 11C17.5 11.83 16.83 12.5 16 12.5S14.5 11.83 14.5 11 15.17 9.5 16 9.5 17.5 10.17 17.5 11M15 5C16.11 5 17 5.9 17 7S16.11 9 15 9 13 8.11 13 7 13.9 5 15 5M9 5C10.11 5 11 5.9 11 7S10.11 9 9 9 7 8.11 7 7 7.9 5 9 5M8 12.5C7.17 12.5 6.5 11.83 6.5 11S7.17 9.5 8 9.5 9.5 10.17 9.5 11 8.83 12.5 8 12.5M9 21.82V21H7V21.82C5.84 21.4 5 20.3 5 19C5 17.34 6.34 16 8 16S11 17.34 11 19C11 20.3 10.16 21.4 9 21.82M10 12C10 10.9 10.9 10 12 10S14 10.9 14 12 13.11 14 12 14 10 13.11 10 12M17 21.82V21H15V21.82C13.84 21.4 13 20.3 13 19C13 17.34 14.34 16 16 16S19 17.34 19 19C19 20.3 18.16 21.4 17 21.82M14.5 7C14.5 6.72 14.72 6.5 15 6.5S15.5 6.72 15.5 7 15.28 7.5 15 7.5 14.5 7.28 14.5 7M8.5 7C8.5 6.72 8.72 6.5 9 6.5S9.5 6.72 9.5 7 9.28 7.5 9 7.5 8.5 7.28 8.5 7M9 19C9 19.55 8.55 20 8 20S7 19.55 7 19 7.45 18 8 18 9 18.45 9 19M17 19C17 19.55 16.55 20 16 20S15 19.55 15 19 15.45 18 16 18 17 18.45 17 19M12.5 12C12.5 12.28 12.28 12.5 12 12.5S11.5 12.28 11.5 12 11.72 11.5 12 11.5 12.5 11.72 12.5 12Z\";\r\nvar mdiEvPlugCcs2 = \"M14 4.5C14 4.22 14.22 4 14.5 4S15 4.22 15 4.5 14.78 5 14.5 5 14 4.78 14 4.5M20 19C20 21.21 18.21 23 16 23H8C5.79 23 4 21.21 4 19C4 16.79 5.79 15 8 15H8.13C5.67 13.64 4 11 4 8C4 5.61 5.06 3.47 6.72 2H17.28C18.94 3.47 20 5.61 20 8C20 11 18.33 13.64 15.87 15H16C18.21 15 20 16.79 20 19M16.5 12C16.5 10.9 15.61 10 14.5 10S12.5 10.9 12.5 12C12.5 13.11 13.4 14 14.5 14S16.5 13.11 16.5 12M17 6C15.9 6 15 6.9 15 8C15 9.11 15.9 10 17 10S19 9.11 19 8C19 6.9 18.11 6 17 6M13 4.5C13 5.33 13.67 6 14.5 6S16 5.33 16 4.5 15.33 3 14.5 3 13 3.67 13 4.5M12 6C10.9 6 10 6.9 10 8C10 9.11 10.9 10 12 10S14 9.11 14 8C14 6.9 13.11 6 12 6M8 4.5C8 5.33 8.67 6 9.5 6S11 5.33 11 4.5 10.33 3 9.5 3 8 3.67 8 4.5M7 10C8.11 10 9 9.11 9 8C9 6.9 8.11 6 7 6S5 6.9 5 8C5 9.11 5.9 10 7 10M9.5 14C10.61 14 11.5 13.11 11.5 12C11.5 10.9 10.61 10 9.5 10S7.5 10.9 7.5 12C7.5 13.11 8.4 14 9.5 14M11 19C11 17.34 9.66 16 8 16S5 17.34 5 19 6.34 22 8 22 11 20.66 11 19M19 19C19 17.34 17.66 16 16 16S13 17.34 13 19 14.34 22 16 22 19 20.66 19 19M17 8.5C17.28 8.5 17.5 8.28 17.5 8S17.28 7.5 17 7.5 16.5 7.72 16.5 8 16.72 8.5 17 8.5M14.5 11.5C14.22 11.5 14 11.72 14 12S14.22 12.5 14.5 12.5 15 12.28 15 12 14.78 11.5 14.5 11.5M16 18C15.45 18 15 18.45 15 19C15 19.55 15.45 20 16 20S17 19.55 17 19C17 18.45 16.55 18 16 18M12 8.5C12.28 8.5 12.5 8.28 12.5 8S12.28 7.5 12 7.5 11.5 7.72 11.5 8 11.72 8.5 12 8.5M8 18C7.45 18 7 18.45 7 19C7 19.55 7.45 20 8 20S9 19.55 9 19C9 18.45 8.55 18 8 18M7 7.5C6.72 7.5 6.5 7.72 6.5 8S6.72 8.5 7 8.5 7.5 8.28 7.5 8 7.28 7.5 7 7.5M9.5 5C9.78 5 10 4.78 10 4.5S9.78 4 9.5 4 9 4.22 9 4.5 9.22 5 9.5 5M10 12C10 11.72 9.78 11.5 9.5 11.5S9 11.72 9 12 9.22 12.5 9.5 12.5 10 12.28 10 12Z\";\r\nvar mdiEvPlugChademo = \"M8 10.5C8.83 10.5 9.5 11.17 9.5 12S8.83 13.5 8 13.5 6.5 12.83 6.5 12 7.17 10.5 8 10.5M8 9C6.34 9 5 10.34 5 12S6.34 15 8 15 11 13.66 11 12 9.66 9 8 9M16 10.5C16.83 10.5 17.5 11.17 17.5 12S16.83 13.5 16 13.5C15.17 13.5 14.5 12.83 14.5 12S15.17 10.5 16 10.5M16 9C14.34 9 13 10.34 13 12S14.34 15 16 15 19 13.66 19 12 17.66 9 16 9M14.12 8.41L12.71 7L14.12 5.59L13.41 4.88L12 6.29L10.59 4.88L9.88 5.59L11.29 7L9.88 8.41L10.59 9.12L12 7.71L13.41 9.12L14.12 8.41M14.12 18.41L12.71 17L14.12 15.59L13.41 14.88L12 16.29L10.59 14.88L9.88 15.59L11.29 17L9.88 18.41L10.59 19.12L12 17.71L13.41 19.12L14.12 18.41M19.74 5.67L20.5 4.93L19.07 3.5L18.33 4.26C16.6 2.85 14.4 2 12 2S7.4 2.85 5.67 4.26L4.93 3.5L3.5 4.93L4.26 5.67C2.85 7.4 2 9.6 2 12C2 17.5 6.5 22 12 22S22 17.5 22 12C22 9.6 21.15 7.4 19.74 5.67M12 20C7.59 20 4 16.41 4 12S7.59 4 12 4 20 7.59 20 12 16.41 20 12 20Z\";\r\nvar mdiEvPlugTesla = \"M6 9C6 8.45 6.45 8 7 8S8 8.45 8 9 7.55 10 7 10 6 9.55 6 9M17 10C17.55 10 18 9.55 18 9S17.55 8 17 8 16 8.45 16 9 16.45 10 17 10M22 9.93V11C22 15.97 17.97 20 13 20H11C6.03 20 2 16 2 11V9.93C2 6.65 4.65 4 7.93 4H16.07C19.35 4 22 6.65 22 9.93M14.5 9C14.5 10.38 15.62 11.5 17 11.5S19.5 10.38 19.5 9 18.38 6.5 17 6.5 14.5 7.62 14.5 9M4.5 9C4.5 10.38 5.62 11.5 7 11.5S9.5 10.38 9.5 9 8.38 6.5 7 6.5 4.5 7.62 4.5 9M9 17C9 16.45 8.55 16 8 16S7 16.45 7 17 7.45 18 8 18 9 17.55 9 17M13.5 17C13.5 16.17 12.83 15.5 12 15.5S10.5 16.17 10.5 17 11.17 18.5 12 18.5 13.5 17.83 13.5 17M17 17C17 16.45 16.55 16 16 16S15 16.45 15 17 15.45 18 16 18 17 17.55 17 17M19.97 11.66C19.23 12.5 18.18 13 17 13C14.79 13 13 11.21 13 9C13 7.8 13.54 6.73 14.38 6H9.62C10.46 6.73 11 7.8 11 9C11 11.21 9.21 13 7 13C5.82 13 4.76 12.5 4.03 11.66C4.19 13.32 4.93 14.82 6.04 15.94C7.71 14.73 9.76 14 12 14C14.24 14 16.29 14.73 17.96 15.94C19.07 14.82 19.81 13.32 19.97 11.66Z\";\r\nvar mdiEvPlugType1 = \"M12.5 15C12.5 15.28 12.28 15.5 12 15.5S11.5 15.28 11.5 15 11.72 14.5 12 14.5 12.5 14.72 12.5 15M15 10.5C15.28 10.5 15.5 10.28 15.5 10S15.28 9.5 15 9.5 14.5 9.72 14.5 10 14.72 10.5 15 10.5M9 10.5C9.28 10.5 9.5 10.28 9.5 10S9.28 9.5 9 9.5 8.5 9.72 8.5 10 8.72 10.5 9 10.5M13 18.92V20H11V18.92C7.61 18.43 5 15.53 5 12S7.61 5.57 11 5.08V4H13V5.08C16.39 5.57 19 8.5 19 12S16.39 18.43 13 18.92M13 10C13 11.11 13.9 12 15 12S17 11.11 17 10 16.11 8 15 8 13 8.9 13 10M7 10C7 11.11 7.9 12 9 12S11 11.11 11 10 10.11 8 9 8 7 8.9 7 10M9.5 14C9.5 13.17 8.83 12.5 8 12.5S6.5 13.17 6.5 14 7.17 15.5 8 15.5 9.5 14.83 9.5 14M14 15C14 13.9 13.11 13 12 13S10 13.9 10 15 10.9 17 12 17 14 16.11 14 15M16 15.5C16.83 15.5 17.5 14.83 17.5 14S16.83 12.5 16 12.5 14.5 13.17 14.5 14 15.17 15.5 16 15.5Z\";\r\nvar mdiEvPlugType2 = \"M7.5 11C7.5 11.28 7.28 11.5 7 11.5S6.5 11.28 6.5 11 6.72 10.5 7 10.5 7.5 10.72 7.5 11M9.5 14.5C9.22 14.5 9 14.72 9 15S9.22 15.5 9.5 15.5 10 15.28 10 15 9.78 14.5 9.5 14.5M9.5 8C9.78 8 10 7.78 10 7.5S9.78 7 9.5 7 9 7.22 9 7.5 9.22 8 9.5 8M14.5 8C14.78 8 15 7.78 15 7.5S14.78 7 14.5 7 14 7.22 14 7.5 14.22 8 14.5 8M12 10.5C11.72 10.5 11.5 10.72 11.5 11S11.72 11.5 12 11.5 12.5 11.28 12.5 11 12.28 10.5 12 10.5M20 11C20 15.42 16.42 19 12 19S4 15.42 4 11C4 8.61 5.06 6.47 6.72 5H17.28C18.94 6.47 20 8.61 20 11M13 7.5C13 8.33 13.67 9 14.5 9S16 8.33 16 7.5 15.33 6 14.5 6 13 6.67 13 7.5M8 7.5C8 8.33 8.67 9 9.5 9S11 8.33 11 7.5 10.33 6 9.5 6 8 6.67 8 7.5M7 13C8.11 13 9 12.11 9 11C9 9.9 8.11 9 7 9S5 9.9 5 11C5 12.11 5.9 13 7 13M11.5 15C11.5 13.9 10.61 13 9.5 13S7.5 13.9 7.5 15C7.5 16.11 8.4 17 9.5 17S11.5 16.11 11.5 15M12 13C13.11 13 14 12.11 14 11C14 9.9 13.11 9 12 9S10 9.9 10 11C10 12.11 10.9 13 12 13M16.5 15C16.5 13.9 15.61 13 14.5 13S12.5 13.9 12.5 15C12.5 16.11 13.4 17 14.5 17S16.5 16.11 16.5 15M19 11C19 9.9 18.11 9 17 9S15 9.9 15 11C15 12.11 15.9 13 17 13S19 12.11 19 11M17 10.5C16.72 10.5 16.5 10.72 16.5 11S16.72 11.5 17 11.5 17.5 11.28 17.5 11 17.28 10.5 17 10.5M14.5 14.5C14.22 14.5 14 14.72 14 15S14.22 15.5 14.5 15.5 15 15.28 15 15 14.78 14.5 14.5 14.5Z\";\r\nvar mdiEvStation = \"M19.77,7.23L19.78,7.22L16.06,3.5L15,4.56L17.11,6.67C16.17,7.03 15.5,7.93 15.5,9A2.5,2.5 0 0,0 18,11.5C18.36,11.5 18.69,11.42 19,11.29V18.5A1,1 0 0,1 18,19.5A1,1 0 0,1 17,18.5V14A2,2 0 0,0 15,12H14V5A2,2 0 0,0 12,3H6A2,2 0 0,0 4,5V21H14V13.5H15.5V18.5A2.5,2.5 0 0,0 18,21A2.5,2.5 0 0,0 20.5,18.5V9C20.5,8.31 20.22,7.68 19.77,7.23M18,10A1,1 0 0,1 17,9A1,1 0 0,1 18,8A1,1 0 0,1 19,9A1,1 0 0,1 18,10M8,18V13.5H6L10,6V11H12L8,18Z\";\r\nvar mdiEvernote = \"M15.09,11.63C15.09,11.63 15.28,10.35 16,10.35C16.76,10.35 17.78,12.06 17.78,12.06C17.78,12.06 15.46,11.63 15.09,11.63M19,4.69C18.64,4.09 16.83,3.41 15.89,3.41C14.96,3.41 13.5,3.41 13.5,3.41C13.5,3.41 12.7,2 10.88,2C9.05,2 9.17,2.81 9.17,3.5V6.32L8.34,7.19H4.5C4.5,7.19 3.44,7.91 3.44,9.44C3.44,11 3.92,16.35 7.13,16.85C10.93,17.43 11.58,15.67 11.58,15.46C11.58,14.56 11.6,13.21 11.6,13.21C11.6,13.21 12.71,15.33 14.39,15.33C16.07,15.33 17.04,16.3 17.04,17.29C17.04,18.28 17.04,19.13 17.04,19.13C17.04,19.13 17,20.28 16,20.28C15,20.28 13.89,20.28 13.89,20.28C13.89,20.28 13.2,19.74 13.2,19C13.2,18.25 13.53,18.05 13.93,18.05C14.32,18.05 14.65,18.09 14.65,18.09V16.53C14.65,16.53 11.47,16.5 11.47,18.94C11.47,21.37 13.13,22 14.46,22C15.8,22 16.63,22 16.63,22C16.63,22 20.56,21.5 20.56,13.75C20.56,6 19.33,5.28 19,4.69M7.5,6.31H4.26L8.32,2.22V5.5L7.5,6.31Z\";\r\nvar mdiExcavator = \"M18.5 18.5C19.04 18.5 19.5 18.96 19.5 19.5S19.04 20.5 18.5 20.5H6.5C5.96 20.5 5.5 20.04 5.5 19.5S5.96 18.5 6.5 18.5H18.5M18.5 17H6.5C5.13 17 4 18.13 4 19.5S5.13 22 6.5 22H18.5C19.88 22 21 20.88 21 19.5S19.88 17 18.5 17M21 11H18V7H13L10 11V16H22L21 11M11.54 11L13.5 8.5H16V11H11.54M9.76 3.41L4.76 2L2 11.83C1.66 13.11 2.41 14.44 3.7 14.8L4.86 15.12L8.15 12.29L4.27 11.21L6.15 4.46L8.94 5.24C9.5 5.53 10.71 6.34 11.47 7.37L12.5 6H12.94C11.68 4.41 9.85 3.46 9.76 3.41Z\";\r\nvar mdiExclamation = \"M 11,4L 13,4L 13,15L 11,15L 11,4 Z M 13,18L 13,20L 11,20L 11,18L 13,18 Z\";\r\nvar mdiExclamationThick = \"M10 3H14V14H10V3M10 21V17H14V21H10Z\";\r\nvar mdiExitRun = \"M13.34,8.17C12.41,8.17 11.65,7.4 11.65,6.47A1.69,1.69 0 0,1 13.34,4.78C14.28,4.78 15.04,5.54 15.04,6.47C15.04,7.4 14.28,8.17 13.34,8.17M10.3,19.93L4.37,18.75L4.71,17.05L8.86,17.9L10.21,11.04L8.69,11.64V14.5H7V10.54L11.4,8.67L12.07,8.59C12.67,8.59 13.17,8.93 13.5,9.44L14.36,10.79C15.04,12 16.39,12.82 18,12.82V14.5C16.14,14.5 14.44,13.67 13.34,12.4L12.84,14.94L14.61,16.63V23H12.92V17.9L11.14,16.21L10.3,19.93M21,23H19V3H6V16.11L4,15.69V1H21V23M6,23H4V19.78L6,20.2V23Z\";\r\nvar mdiExitToApp = \"M19,3H5C3.89,3 3,3.89 3,5V9H5V5H19V19H5V15H3V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M10.08,15.58L11.5,17L16.5,12L11.5,7L10.08,8.41L12.67,11H3V13H12.67L10.08,15.58Z\";\r\nvar mdiExpandAll = \"M18,8H8V18H6V8A2,2 0 0,1 8,6H18V8M14,2H4A2,2 0 0,0 2,4V14H4V4H14V2M22,12V20A2,2 0 0,1 20,22H12A2,2 0 0,1 10,20V12A2,2 0 0,1 12,10H20A2,2 0 0,1 22,12M20,15H17V12H15V15H12V17H15V20H17V17H20V15Z\";\r\nvar mdiExpandAllOutline = \"M4,2A2,2 0 0,0 2,4V14H4V4H14V2H4M8,6A2,2 0 0,0 6,8V18H8V8H18V6H8M20,12V20H12V12H20M20,10H12A2,2 0 0,0 10,12V20A2,2 0 0,0 12,22H20A2,2 0 0,0 22,20V12A2,2 0 0,0 20,10M19,17H17V19H15V17H13V15H15V13H17V15H19V17Z\";\r\nvar mdiExpansionCard = \"M2,7V8.5H3V17H4.5V7C3.7,7 2.8,7 2,7M6,7V7L6,16H7V17H14V16H22V7H6M17.5,9A2.5,2.5 0 0,1 20,11.5A2.5,2.5 0 0,1 17.5,14A2.5,2.5 0 0,1 15,11.5A2.5,2.5 0 0,1 17.5,9Z\";\r\nvar mdiExpansionCardVariant = \"M2 7H4.5V17H3V8.5H2M22 7V16H14V17H7V16H6V7M10 9H8V12H10M13 9H11V12H13M20 9H15V14H20V9Z\";\r\nvar mdiExponent = \"M15.38,3L17.77,8.75C17.55,9.68 17.27,10.32 17,10.7C16.67,11.18 16.44,11.25 16.19,11.25V12.75C16.94,12.75 17.74,12.35 18.24,11.56C19.87,8.94 22,3 22,3H20.38L18.69,7.05L17,3H15.38M3.42,8.59L2,10L6.79,14.79L2,19.59L3.41,21L8.21,16.21L13,21L14.41,19.59L9.62,14.79L14.41,10L13,8.59L8.21,13.38L3.41,8.59H3.42Z\";\r\nvar mdiExponentBox = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M13.76,6H15.39L16.5,8.6L17.59,6H19.24C19.24,6 17.5,10.57 16.46,12.32C16.08,12.89 15.35,13.27 14.5,13.25V11.75C14.96,11.76 15.25,11.5 15.5,11.13C15.61,11 15.68,10.8 15.74,10.64L13.76,6M6.41,9.59L9.21,12.38L12,9.59L13.41,11L10.62,13.79L13.41,16.59L12,18L9.21,15.21L6.41,18L5,16.59L7.79,13.79L5,11L6.41,9.59Z\";\r\nvar mdiExport = \"M23,12L19,8V11H10V13H19V16M1,18V6C1,4.89 1.9,4 3,4H15A2,2 0 0,1 17,6V9H15V6H3V18H15V15H17V18A2,2 0 0,1 15,20H3A2,2 0 0,1 1,18Z\";\r\nvar mdiExportVariant = \"M12,1L8,5H11V14H13V5H16M18,23H6C4.89,23 4,22.1 4,21V9A2,2 0 0,1 6,7H9V9H6V21H18V9H15V7H18A2,2 0 0,1 20,9V21A2,2 0 0,1 18,23Z\";\r\nvar mdiEye = \"M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17M12,4.5C7,4.5 2.73,7.61 1,12C2.73,16.39 7,19.5 12,19.5C17,19.5 21.27,16.39 23,12C21.27,7.61 17,4.5 12,4.5Z\";\r\nvar mdiEyeCheck = \"M23.5,17L18.5,22L15,18.5L16.5,17L18.5,19L22,15.5L23.5,17M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M12,17C12.5,17 12.97,16.93 13.42,16.79C13.15,17.5 13,18.22 13,19V19.45L12,19.5C7,19.5 2.73,16.39 1,12C2.73,7.61 7,4.5 12,4.5C17,4.5 21.27,7.61 23,12C22.75,12.64 22.44,13.26 22.08,13.85C21.18,13.31 20.12,13 19,13C18.22,13 17.5,13.15 16.79,13.42C16.93,12.97 17,12.5 17,12A5,5 0 0,0 12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17Z\";\r\nvar mdiEyeCheckOutline = \"M23.5,17L18.5,22L15,18.5L16.5,17L18.5,19L22,15.5L23.5,17M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M12,4.5C17,4.5 21.27,7.61 23,12C22.75,12.65 22.44,13.26 22.08,13.85C21.5,13.5 20.86,13.25 20.18,13.12L20.82,12C19.17,8.64 15.76,6.5 12,6.5C8.24,6.5 4.83,8.64 3.18,12C4.83,15.36 8.24,17.5 12,17.5L13.21,17.43C13.07,17.93 13,18.46 13,19V19.46L12,19.5C7,19.5 2.73,16.39 1,12C2.73,7.61 7,4.5 12,4.5Z\";\r\nvar mdiEyeCircle = \"M12,9.5A2.5,2.5 0 0,0 9.5,12A2.5,2.5 0 0,0 12,14.5A2.5,2.5 0 0,0 14.5,12A2.5,2.5 0 0,0 12,9.5M12,13A1,1 0 0,1 11,12A1,1 0 0,1 12,11A1,1 0 0,1 13,12A1,1 0 0,1 12,13M12,9.5A2.5,2.5 0 0,0 9.5,12A2.5,2.5 0 0,0 12,14.5A2.5,2.5 0 0,0 14.5,12A2.5,2.5 0 0,0 12,9.5M12,13A1,1 0 0,1 11,12A1,1 0 0,1 12,11A1,1 0 0,1 13,12A1,1 0 0,1 12,13M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,16C9.37,16 7,14.43 6,12C7.38,8.69 11.19,7.12 14.5,8.5C16.08,9.16 17.34,10.42 18,12C17,14.43 14.63,16 12,16M12,9.5A2.5,2.5 0 0,0 9.5,12A2.5,2.5 0 0,0 12,14.5A2.5,2.5 0 0,0 14.5,12A2.5,2.5 0 0,0 12,9.5M12,13A1,1 0 0,1 11,12A1,1 0 0,1 12,11A1,1 0 0,1 13,12A1,1 0 0,1 12,13Z\";\r\nvar mdiEyeCircleOutline = \"M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20M12,11A1,1 0 0,1 13,12A1,1 0 0,1 12,13A1,1 0 0,1 11,12A1,1 0 0,1 12,11M12,8C14.63,8 17,9.57 18,12C16.62,15.31 12.81,16.88 9.5,15.5C7.92,14.84 6.66,13.58 6,12C7,9.57 9.37,8 12,8M12,9.5A2.5,2.5 0 0,0 9.5,12A2.5,2.5 0 0,0 12,14.5A2.5,2.5 0 0,0 14.5,12A2.5,2.5 0 0,0 12,9.5\";\r\nvar mdiEyeMinus = \"M12 4.5A11.8 11.8 0 0 0 1 12A11.8 11.8 0 0 0 12 19.5H13.1A3.8 3.8 0 0 1 13 18.5A9.9 9.9 0 0 1 13.2 16.8L12 17A5 5 0 1 1 17 12A2.8 2.8 0 0 1 16.9 12.9A5.2 5.2 0 0 1 19 12.5A5.6 5.6 0 0 1 22.3 13.5A10.1 10.1 0 0 0 23 12A11.8 11.8 0 0 0 12 4.5M12 9A3 3 0 1 0 15 12A2.9 2.9 0 0 0 12 9M15 17.5V19.5H23V17.5Z\";\r\nvar mdiEyeMinusOutline = \"M12 4.5A11.8 11.8 0 0 0 1 12A11.8 11.8 0 0 0 12 19.5H13.1A3.8 3.8 0 0 1 13 18.5A4.1 4.1 0 0 1 13.1 17.4H12A9.6 9.6 0 0 1 3.2 12A9.6 9.6 0 0 1 12 6.5A9.6 9.6 0 0 1 20.8 12L20.4 12.7A4.6 4.6 0 0 1 22.3 13.5A10.1 10.1 0 0 0 23 12A11.8 11.8 0 0 0 12 4.5M12 9A3 3 0 1 0 15 12A2.9 2.9 0 0 0 12 9M15 17.5V19.5H23V17.5Z\";\r\nvar mdiEyeOff = \"M11.83,9L15,12.16C15,12.11 15,12.05 15,12A3,3 0 0,0 12,9C11.94,9 11.89,9 11.83,9M7.53,9.8L9.08,11.35C9.03,11.56 9,11.77 9,12A3,3 0 0,0 12,15C12.22,15 12.44,14.97 12.65,14.92L14.2,16.47C13.53,16.8 12.79,17 12,17A5,5 0 0,1 7,12C7,11.21 7.2,10.47 7.53,9.8M2,4.27L4.28,6.55L4.73,7C3.08,8.3 1.78,10 1,12C2.73,16.39 7,19.5 12,19.5C13.55,19.5 15.03,19.2 16.38,18.66L16.81,19.08L19.73,22L21,20.73L3.27,3M12,7A5,5 0 0,1 17,12C17,12.64 16.87,13.26 16.64,13.82L19.57,16.75C21.07,15.5 22.27,13.86 23,12C21.27,7.61 17,4.5 12,4.5C10.6,4.5 9.26,4.75 8,5.2L10.17,7.35C10.74,7.13 11.35,7 12,7Z\";\r\nvar mdiEyeOffOutline = \"M2,5.27L3.28,4L20,20.72L18.73,22L15.65,18.92C14.5,19.3 13.28,19.5 12,19.5C7,19.5 2.73,16.39 1,12C1.69,10.24 2.79,8.69 4.19,7.46L2,5.27M12,9A3,3 0 0,1 15,12C15,12.35 14.94,12.69 14.83,13L11,9.17C11.31,9.06 11.65,9 12,9M12,4.5C17,4.5 21.27,7.61 23,12C22.18,14.08 20.79,15.88 19,17.19L17.58,15.76C18.94,14.82 20.06,13.54 20.82,12C19.17,8.64 15.76,6.5 12,6.5C10.91,6.5 9.84,6.68 8.84,7L7.3,5.47C8.74,4.85 10.33,4.5 12,4.5M3.18,12C4.83,15.36 8.24,17.5 12,17.5C12.69,17.5 13.37,17.43 14,17.29L11.72,15C10.29,14.85 9.15,13.71 9,12.28L5.6,8.87C4.61,9.72 3.78,10.78 3.18,12Z\";\r\nvar mdiEyeOutline = \"M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M12,4.5C17,4.5 21.27,7.61 23,12C21.27,16.39 17,19.5 12,19.5C7,19.5 2.73,16.39 1,12C2.73,7.61 7,4.5 12,4.5M3.18,12C4.83,15.36 8.24,17.5 12,17.5C15.76,17.5 19.17,15.36 20.82,12C19.17,8.64 15.76,6.5 12,6.5C8.24,6.5 4.83,8.64 3.18,12Z\";\r\nvar mdiEyePlus = \"M12,4.5C7,4.5 2.73,7.61 1,12C2.73,16.39 7,19.5 12,19.5C12.36,19.5 12.72,19.5 13.08,19.45C13.03,19.13 13,18.82 13,18.5C13,17.94 13.08,17.38 13.24,16.84C12.83,16.94 12.42,17 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7A5,5 0 0,1 17,12C17,12.29 16.97,12.59 16.92,12.88C17.58,12.63 18.29,12.5 19,12.5C20.17,12.5 21.31,12.84 22.29,13.5C22.56,13 22.8,12.5 23,12C21.27,7.61 17,4.5 12,4.5M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M18,14.5V17.5H15V19.5H18V22.5H20V19.5H23V17.5H20V14.5H18Z\";\r\nvar mdiEyePlusOutline = \"M12,4.5C7,4.5 2.73,7.61 1,12C2.73,16.39 7,19.5 12,19.5C12.36,19.5 12.72,19.5 13.08,19.45C13.03,19.13 13,18.82 13,18.5C13,18.14 13.04,17.78 13.1,17.42C12.74,17.46 12.37,17.5 12,17.5C8.24,17.5 4.83,15.36 3.18,12C4.83,8.64 8.24,6.5 12,6.5C15.76,6.5 19.17,8.64 20.82,12C20.7,12.24 20.56,12.45 20.43,12.68C21.09,12.84 21.72,13.11 22.29,13.5C22.56,13 22.8,12.5 23,12C21.27,7.61 17,4.5 12,4.5M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M18,14.5V17.5H15V19.5H18V22.5H20V19.5H23V17.5H20V14.5H18Z\";\r\nvar mdiEyeRemove = \"M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.47L22.54 16.88M12 9C10.34 9 9 10.34 9 12S10.34 15 12 15 15 13.66 15 12 13.66 9 12 9M12 17C9.24 17 7 14.76 7 12S9.24 7 12 7 17 9.24 17 12C17 12.5 16.9 13 16.77 13.43C17.46 13.16 18.21 13 19 13C20.12 13 21.17 13.32 22.07 13.85C22.43 13.27 22.74 12.65 23 12C21.27 7.61 17 4.5 12 4.5S2.73 7.61 1 12C2.73 16.39 7 19.5 12 19.5C12.35 19.5 12.69 19.5 13.03 19.45C13 19.3 13 19.15 13 19C13 18.21 13.16 17.46 13.43 16.77C13 16.9 12.5 17 12 17Z\";\r\nvar mdiEyeRemoveOutline = \"M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.47L22.54 16.88M12 9C10.34 9 9 10.34 9 12S10.34 15 12 15 15 13.66 15 12 13.66 9 12 9M12 17.5C8.24 17.5 4.83 15.36 3.18 12C4.83 8.64 8.24 6.5 12 6.5S19.17 8.64 20.82 12C20.63 12.39 20.41 12.77 20.17 13.13C20.85 13.26 21.5 13.5 22.07 13.85C22.43 13.27 22.74 12.65 23 12C21.27 7.61 17 4.5 12 4.5S2.73 7.61 1 12C2.73 16.39 7 19.5 12 19.5C12.35 19.5 12.69 19.5 13.03 19.45C13 19.3 13 19.15 13 19C13 18.45 13.08 17.92 13.22 17.41C12.82 17.46 12.41 17.5 12 17.5Z\";\r\nvar mdiEyeSettings = \"M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17M12,4.5C7.14,4.5 2.78,7.5 1,12C3.39,18.08 10.25,21.06 16.33,18.67C19.38,17.47 21.8,15.06 23,12C21.22,7.5 16.86,4.5 12,4.5M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiEyeSettingsOutline = \"M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M12,4.5C16.86,4.5 21.22,7.5 23,12C20.61,18.08 13.75,21.06 7.67,18.67C4.62,17.47 2.2,15.06 1,12C2.78,7.5 7.14,4.5 12,4.5M3.18,12C5.56,16.87 11.45,18.89 16.32,16.5C18.28,15.54 19.86,13.96 20.82,12C18.44,7.13 12.55,5.11 7.68,7.5C5.72,8.46 4.14,10.04 3.18,12M9,22H7V24H9V22M13,22H11V24H13V22M17,22H15V24H17V22Z\";\r\nvar mdiEyedropper = \"M19.35,11.72L17.22,13.85L15.81,12.43L8.1,20.14L3.5,22L2,20.5L3.86,15.9L11.57,8.19L10.15,6.78L12.28,4.65L19.35,11.72M16.76,3C17.93,1.83 19.83,1.83 21,3C22.17,4.17 22.17,6.07 21,7.24L19.08,9.16L14.84,4.92L16.76,3M5.56,17.03L4.5,19.5L6.97,18.44L14.4,11L13,9.6L5.56,17.03Z\";\r\nvar mdiEyedropperMinus = \"M19.35 11.72L17.22 13.85L15.81 12.43L8.1 20.14L3.5 22L2 20.5L3.86 15.9L11.57 8.19L10.15 6.78L12.28 4.65L19.35 11.72M16.76 3C17.93 1.83 19.83 1.83 21 3S22.17 6.07 21 7.24L19.08 9.16L14.84 4.92L16.76 3M5.56 17.03L4.5 19.5L6.97 18.44L14.4 11L13 9.6L5.56 17.03M9 4V6H1V4H9Z\";\r\nvar mdiEyedropperOff = \"M21 7.24L19.08 9.16L14.84 4.92L16.76 3C17.93 1.83 19.83 1.83 21 3S22.17 6.07 21 7.24M10.94 8.82L12.36 10.24L13 9.6L14.4 11L13.76 11.64L15.18 13.06L15.81 12.43L17.22 13.85L19.35 11.72L12.28 4.65L10.15 6.78L11.57 8.19L10.94 8.82M19.86 20.29L18.58 21.57L12.63 15.61L8.1 20.14L3.5 22L2 20.5L3.86 15.9L8.39 11.37L1.86 4.85L3.14 3.57L19.86 20.29M11.21 14.2L9.81 12.79L5.56 17.03L4.5 19.5L6.97 18.44L11.21 14.2Z\";\r\nvar mdiEyedropperPlus = \"M19.35 11.72L17.22 13.85L15.81 12.43L8.1 20.14L3.5 22L2 20.5L3.86 15.9L11.57 8.19L10.15 6.78L12.28 4.65L19.35 11.72M16.76 3C17.93 1.83 19.83 1.83 21 3S22.17 6.07 21 7.24L19.08 9.16L14.84 4.92L16.76 3M5.56 17.03L4.5 19.5L6.97 18.44L14.4 11L13 9.6L5.56 17.03M6 1V4H9V6H6V9H4V6H1V4H4V1H6Z\";\r\nvar mdiEyedropperRemove = \"M19.35 11.72L17.22 13.85L15.81 12.43L8.1 20.14L3.5 22L2 20.5L3.86 15.9L11.57 8.19L10.15 6.78L12.28 4.65L19.35 11.72M16.76 3C17.93 1.83 19.83 1.83 21 3S22.17 6.07 21 7.24L19.08 9.16L14.84 4.92L16.76 3M5.56 17.03L4.5 19.5L6.97 18.44L14.4 11L13 9.6L5.56 17.03M8.54 2.88L6.41 5L8.54 7.12L7.12 8.54L5 6.41L2.88 8.54L1.46 7.12L3.59 5L1.46 2.88L2.88 1.47L5 3.59L7.12 1.47L8.54 2.88Z\";\r\nvar mdiEyedropperVariant = \"M6.92,19L5,17.08L13.06,9L15,10.94M20.71,5.63L18.37,3.29C18,2.9 17.35,2.9 16.96,3.29L13.84,6.41L11.91,4.5L10.5,5.91L11.92,7.33L3,16.25V21H7.75L16.67,12.08L18.09,13.5L19.5,12.09L17.58,10.17L20.7,7.05C21.1,6.65 21.1,6 20.71,5.63Z\";\r\nvar mdiFace = \"M9,11.75A1.25,1.25 0 0,0 7.75,13A1.25,1.25 0 0,0 9,14.25A1.25,1.25 0 0,0 10.25,13A1.25,1.25 0 0,0 9,11.75M15,11.75A1.25,1.25 0 0,0 13.75,13A1.25,1.25 0 0,0 15,14.25A1.25,1.25 0 0,0 16.25,13A1.25,1.25 0 0,0 15,11.75M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,11.71 4,11.42 4.05,11.14C6.41,10.09 8.28,8.16 9.26,5.77C11.07,8.33 14.05,10 17.42,10C18.2,10 18.95,9.91 19.67,9.74C19.88,10.45 20,11.21 20,12C20,16.41 16.41,20 12,20Z\";\r\nvar mdiFaceAgent = \"M18.72,14.76C19.07,13.91 19.26,13 19.26,12C19.26,11.28 19.15,10.59 18.96,9.95C18.31,10.1 17.63,10.18 16.92,10.18C13.86,10.18 11.15,8.67 9.5,6.34C8.61,8.5 6.91,10.26 4.77,11.22C4.73,11.47 4.73,11.74 4.73,12A7.27,7.27 0 0,0 12,19.27C13.05,19.27 14.06,19.04 14.97,18.63C15.54,19.72 15.8,20.26 15.78,20.26C14.14,20.81 12.87,21.08 12,21.08C9.58,21.08 7.27,20.13 5.57,18.42C4.53,17.38 3.76,16.11 3.33,14.73H2V10.18H3.09C3.93,6.04 7.6,2.92 12,2.92C14.4,2.92 16.71,3.87 18.42,5.58C19.69,6.84 20.54,8.45 20.89,10.18H22V14.67H22V14.69L22,14.73H21.94L18.38,18L13.08,17.4V15.73H17.91L18.72,14.76M9.27,11.77C9.57,11.77 9.86,11.89 10.07,12.11C10.28,12.32 10.4,12.61 10.4,12.91C10.4,13.21 10.28,13.5 10.07,13.71C9.86,13.92 9.57,14.04 9.27,14.04C8.64,14.04 8.13,13.54 8.13,12.91C8.13,12.28 8.64,11.77 9.27,11.77M14.72,11.77C15.35,11.77 15.85,12.28 15.85,12.91C15.85,13.54 15.35,14.04 14.72,14.04C14.09,14.04 13.58,13.54 13.58,12.91A1.14,1.14 0 0,1 14.72,11.77Z\";\r\nvar mdiFaceMask = \"M20.25 6C18.79 6 17.61 7.14 17.5 8.58L12.55 7.16C12.19 7.05 11.81 7.05 11.45 7.16L6.5 8.58C6.39 7.14 5.21 6 3.75 6C2.23 6 1 7.23 1 8.75V12.25C1 13.77 2.23 15 3.75 15H5.68C6.81 17.36 9.21 19 12 19S17.19 17.36 18.32 15H20.25C21.77 15 23 13.77 23 12.25V8.75C23 7.23 21.77 6 20.25 6M5 13.5H3.75C3.06 13.5 2.5 12.94 2.5 12.25V8.75C2.5 8.06 3.06 7.5 3.75 7.5S5 8.06 5 8.75V13.5M15 12L12.4 11.3C12.1 11.2 11.8 11.2 11.6 11.3L9 12V11L11.3 10.3C11.7 10.2 12.2 10.2 12.7 10.3L15 11V12M21.5 12.25C21.5 12.94 20.94 13.5 20.25 13.5H19V8.75C19 8.06 19.56 7.5 20.25 7.5S21.5 8.06 21.5 8.75V12.25Z\";\r\nvar mdiFaceMaskOutline = \"M15 12L12.4 11.3C12.1 11.2 11.8 11.2 11.6 11.3L9 12V11L11.3 10.3C11.7 10.2 12.2 10.2 12.7 10.3L15 11V12M20.25 6C18.79 6 17.61 7.14 17.5 8.58L12.55 7.16C12.37 7.11 12.19 7.08 12 7.08C11.82 7.08 11.63 7.11 11.45 7.16L6.5 8.58C6.39 7.14 5.21 6 3.75 6C2.23 6 1 7.23 1 8.75V12.25C1 13.77 2.23 15 3.75 15H5.68C6.81 17.36 9.21 19 12 19S17.19 17.36 18.32 15H20.25C21.77 15 23 13.77 23 12.25V8.75C23 7.23 21.77 6 20.25 6M5 13.5H3.75C3.06 13.5 2.5 12.94 2.5 12.25V8.75C2.5 8.06 3.06 7.5 3.75 7.5S5 8.06 5 8.75V13.5M17 12C17 14.76 14.76 17 12 17S7 14.76 7 12L7 10.5L12 9.08H12L17 10.5V12M21.5 12.25C21.5 12.94 20.94 13.5 20.25 13.5H19V8.75C19 8.06 19.56 7.5 20.25 7.5S21.5 8.06 21.5 8.75V12.25Z\";\r\nvar mdiFaceOutline = \"M10.25,13A1.25,1.25 0 0,1 9,14.25A1.25,1.25 0 0,1 7.75,13A1.25,1.25 0 0,1 9,11.75A1.25,1.25 0 0,1 10.25,13M15,11.75A1.25,1.25 0 0,0 13.75,13A1.25,1.25 0 0,0 15,14.25A1.25,1.25 0 0,0 16.25,13A1.25,1.25 0 0,0 15,11.75M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M10.66,4.12C12.06,6.44 14.6,8 17.5,8C17.96,8 18.41,7.95 18.84,7.88C17.44,5.56 14.9,4 12,4C11.54,4 11.09,4.05 10.66,4.12M4.42,9.47C6.13,8.5 7.45,6.92 8.08,5.03C6.37,6 5.05,7.58 4.42,9.47M20,12C20,11.22 19.88,10.47 19.67,9.76C18.97,9.91 18.25,10 17.5,10C14.37,10 11.58,8.56 9.74,6.31C8.69,8.87 6.6,10.88 4,11.86C4,11.9 4,11.95 4,12C4,16.41 7.59,20 12,20C16.41,20 20,16.41 20,12Z\";\r\nvar mdiFaceProfile = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,8.39C13.57,9.4 15.42,10 17.42,10C18.2,10 18.95,9.91 19.67,9.74C19.88,10.45 20,11.21 20,12C20,16.41 16.41,20 12,20C9,20 6.39,18.34 5,15.89L6.75,14V13A1.25,1.25 0 0,1 8,11.75A1.25,1.25 0 0,1 9.25,13V14H12M16,11.75A1.25,1.25 0 0,0 14.75,13A1.25,1.25 0 0,0 16,14.25A1.25,1.25 0 0,0 17.25,13A1.25,1.25 0 0,0 16,11.75Z\";\r\nvar mdiFaceProfileWoman = \"M17.25 13C17.25 13.69 16.69 14.25 16 14.25S14.75 13.69 14.75 13 15.31 11.75 16 11.75 17.25 12.31 17.25 13M22 12C22 17.5 17.5 22 12 22H2V12C2 6.5 6.5 2 12 2S22 6.5 22 12M7 18C8.41 19.23 10 20 12 20C16.41 20 20 16.41 20 12C20 11.21 19.88 10.45 19.67 9.74C18.95 9.91 18.2 10 17.42 10C15.42 10 13.57 9.4 12 8.39C12 8.39 10.54 13.76 8.03 13C7.37 12.8 7 13.31 7 14\";\r\nvar mdiFaceRecognition = \"M9,11.75A1.25,1.25 0 0,0 7.75,13A1.25,1.25 0 0,0 9,14.25A1.25,1.25 0 0,0 10.25,13A1.25,1.25 0 0,0 9,11.75M15,11.75A1.25,1.25 0 0,0 13.75,13A1.25,1.25 0 0,0 15,14.25A1.25,1.25 0 0,0 16.25,13A1.25,1.25 0 0,0 15,11.75M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12C3.97,11.71 3.97,11.43 4,11.14C6.38,10.1 8.27,8.17 9.26,5.77C11.13,8.42 14.17,10 17.42,10C18.18,10 18.93,9.91 19.67,9.74C20.92,14 18.5,18.43 14.26,19.67C13.5,19.89 12.76,20 12,20M0,2A2,2 0 0,1 2,0H6V2H2V6H0V2M24,22A2,2 0 0,1 22,24H18V22H22V18H24V22M2,24A2,2 0 0,1 0,22V18H2V22H6V24H2M22,0A2,2 0 0,1 24,2V6H22V2H18V0H22Z\";\r\nvar mdiFaceShimmer = \"M18.41 3.41L16 4.5L18.41 5.59L19.5 8L20.6 5.59L23 4.5L20.6 3.41L19.5 1M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 10.53 21.67 9.13 21.1 7.87L19.86 10.59C19.94 11.05 20 11.5 20 12C20 16.43 16.43 20 12 20C7.57 20 4 16.43 4 12C4 11.96 4 11.91 4 11.87A10 10 0 0 0 9.74 6.31A10 10 0 0 0 17.5 10A10 10 0 0 0 18.83 9.91L17.35 6.65L12.6 4.5L16.13 2.9C14.87 2.33 13.47 2 12 2M9 11.75A1.25 1.25 0 0 0 7.75 13A1.25 1.25 0 0 0 9 14.25A1.25 1.25 0 0 0 10.25 13A1.25 1.25 0 0 0 9 11.75M15 11.75A1.25 1.25 0 0 0 13.75 13A1.25 1.25 0 0 0 15 14.25A1.25 1.25 0 0 0 16.25 13A1.25 1.25 0 0 0 15 11.75Z\";\r\nvar mdiFaceShimmerOutline = \"M19.5 1L18.41 3.41L16 4.5L18.41 5.59L19.5 8L20.6 5.59L23 4.5L20.6 3.41L19.5 1M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 10.53 21.67 9.13 21.1 7.87L19.86 10.57C19.95 11.04 20 11.5 20 12C20 16.43 16.43 20 12 20C7.57 20 4 16.43 4 12C4 11.95 4 11.91 4 11.86A10 10 0 0 0 9.74 6.31C11.61 8.61 14.44 10 17.5 10C17.94 10 18.39 9.97 18.83 9.91L17.96 8C17.81 8 17.65 8 17.5 8C14.68 8 12.1 6.5 10.66 4.12C11.1 4.05 11.54 4 12 4C12.5 4 12.96 4.05 13.42 4.13L16.13 2.91C14.87 2.33 13.47 2 12 2M8.09 5A8 8 0 0 1 4.41 9.5C5.04 7.57 6.37 6 8.09 5M9 11.75A1.25 1.25 0 0 0 7.75 13A1.25 1.25 0 0 0 9 14.25A1.25 1.25 0 0 0 10.25 13A1.25 1.25 0 0 0 9 11.75M15 11.75A1.25 1.25 0 0 0 13.75 13A1.25 1.25 0 0 0 15 14.25A1.25 1.25 0 0 0 16.25 13A1.25 1.25 0 0 0 15 11.75Z\";\r\nvar mdiFaceWoman = \"M13.75 13C13.75 12.31 14.31 11.75 15 11.75S16.25 12.31 16.25 13 15.69 14.25 15 14.25 13.75 13.69 13.75 13M22 12V22H2V12C2 6.5 6.5 2 12 2S22 6.5 22 12M4 12C4 16.41 7.59 20 12 20S20 16.41 20 12C20 11.21 19.88 10.45 19.67 9.74C18.95 9.91 18.2 10 17.42 10C14.05 10 11.07 8.33 9.26 5.77C8.28 8.16 6.41 10.09 4.05 11.14C4 11.42 4 11.71 4 12M9 14.25C9.69 14.25 10.25 13.69 10.25 13S9.69 11.75 9 11.75 7.75 12.31 7.75 13 8.31 14.25 9 14.25Z\";\r\nvar mdiFaceWomanOutline = \"M12 2C6.5 2 2 6.5 2 12V22H22V12C22 6.5 17.5 2 12 2M12 4C14.9 4 17.44 5.56 18.84 7.88C18.41 7.95 17.96 8 17.5 8C14.6 8 12.06 6.44 10.66 4.12C11.09 4.05 11.54 4 12 4M8.08 5.03C7.45 6.92 6.13 8.5 4.42 9.47C5.05 7.58 6.37 6 8.08 5.03M4 11.86C6.6 10.88 8.69 8.87 9.74 6.31C11.58 8.56 14.37 10 17.5 10C18.25 10 18.97 9.91 19.67 9.76C19.88 10.47 20 11.22 20 12C20 16.41 16.41 20 12 20S4 16.41 4 12V11.86M4 20V18C4.57 18.75 5.25 19.43 6 20H4M20 20H18C18.75 19.43 19.43 18.75 20 18V20M13.75 13C13.75 12.31 14.31 11.75 15 11.75S16.25 12.31 16.25 13 15.69 14.25 15 14.25 13.75 13.69 13.75 13M7.75 13C7.75 12.31 8.31 11.75 9 11.75S10.25 12.31 10.25 13 9.69 14.25 9 14.25 7.75 13.69 7.75 13Z\";\r\nvar mdiFaceWomanShimmer = \"M19.5 1L18.41 3.41L16 4.5L18.41 5.59L19.5 8L20.6 5.59L23 4.5L20.6 3.41L19.5 1M12 2C6.5 2 2 6.5 2 12V22H22V12C22 10.53 21.67 9.13 21.1 7.87L19.86 10.59C19.94 11.05 20 11.5 20 12C20 16.43 16.43 20 12 20C7.57 20 4 16.43 4 12C4 11.96 4 11.91 4 11.87A10 10 0 0 0 9.74 6.31A10 10 0 0 0 17.5 10A10 10 0 0 0 18.83 9.91L17.35 6.65L12.6 4.5L16.13 2.9C14.87 2.33 13.47 2 12 2M9 11.75A1.25 1.25 0 0 0 7.75 13A1.25 1.25 0 0 0 9 14.25A1.25 1.25 0 0 0 10.25 13A1.25 1.25 0 0 0 9 11.75M15 11.75A1.25 1.25 0 0 0 13.75 13A1.25 1.25 0 0 0 15 14.25A1.25 1.25 0 0 0 16.25 13A1.25 1.25 0 0 0 15 11.75Z\";\r\nvar mdiFaceWomanShimmerOutline = \"M19.5 1L18.41 3.41L16 4.5L18.41 5.59L19.5 8L20.6 5.59L23 4.5L20.6 3.41M12 2C6.5 2 2 6.5 2 12V22H22V12C22 10.53 21.67 9.13 21.1 7.87L19.86 10.57C19.95 11.04 20 11.5 20 12C20 16.43 16.43 20 12 20C7.57 20 4 16.43 4 12C4 11.95 4 11.91 4 11.86C6.61 10.89 8.69 8.88 9.74 6.31C11.61 8.61 14.44 10 17.5 10C17.94 10 18.39 9.97 18.83 9.91L17.96 8C17.81 8 17.65 8 17.5 8C14.68 8 12.1 6.5 10.66 4.12C11.1 4.05 11.54 4 12 4C12.5 4 12.96 4.05 13.42 4.13L16.13 2.91C14.87 2.33 13.47 2 12 2M8.09 5C7.46 6.91 6.15 8.5 4.41 9.5C5.04 7.57 6.37 6 8.09 5M9 11.75C8.31 11.75 7.75 12.31 7.75 13C7.75 13.69 8.31 14.25 9 14.25C9.69 14.25 10.25 13.69 10.25 13C10.25 12.31 9.69 11.75 9 11.75M15 11.75C14.31 11.75 13.75 12.31 13.75 13C13.75 13.69 14.31 14.25 15 14.25C15.69 14.25 16.25 13.69 16.25 13C16.25 12.31 15.69 11.75 15 11.75M4 17.97C4.58 18.74 5.26 19.42 6.03 20H4M20 17.97V20H17.97C18.74 19.42 19.42 18.74 20 17.97Z\";\r\nvar mdiFacebook = \"M12 2.04C6.5 2.04 2 6.53 2 12.06C2 17.06 5.66 21.21 10.44 21.96V14.96H7.9V12.06H10.44V9.85C10.44 7.34 11.93 5.96 14.22 5.96C15.31 5.96 16.45 6.15 16.45 6.15V8.62H15.19C13.95 8.62 13.56 9.39 13.56 10.18V12.06H16.34L15.89 14.96H13.56V21.96A10 10 0 0 0 22 12.06C22 6.53 17.5 2.04 12 2.04Z\";\r\nvar mdiFacebookGaming = \"M9.5 14.5V9.5H21V21H15.5V14.5H9.5M3 3H21L21 8.5H8.5V15.5H14.5V21H3V3Z\";\r\nvar mdiFacebookMessenger = \"M12,2C6.36,2 2,6.13 2,11.7C2,14.61 3.19,17.14 5.14,18.87C5.3,19 5.4,19.22 5.41,19.44L5.46,21.22C5.5,21.79 6.07,22.16 6.59,21.93L8.57,21.06C8.74,21 8.93,20.97 9.1,21C10,21.27 11,21.4 12,21.4C17.64,21.4 22,17.27 22,11.7C22,6.13 17.64,2 12,2M18,9.46L15.07,14.13C14.6,14.86 13.6,15.05 12.9,14.5L10.56,12.77C10.35,12.61 10.05,12.61 9.84,12.77L6.68,15.17C6.26,15.5 5.71,15 6,14.54L8.93,9.87C9.4,9.14 10.4,8.95 11.1,9.47L13.44,11.23C13.66,11.39 13.95,11.39 14.16,11.23L17.32,8.83C17.74,8.5 18.29,9 18,9.46Z\";\r\nvar mdiFacebookWorkplace = \"M19.69,16.12C19.42,16.43 18.95,16.92 18.19,16.92C17.13,16.92 16.78,16.15 16.46,15.34L14.86,11.41L13.26,15.34C13,16 12.7,16.92 11.53,16.92C10.36,16.92 10.07,16 9.79,15.34L7.11,8.72H9.37L11.53,14.17L13.14,10.2C13.39,9.57 13.69,8.62 14.86,8.62C16,8.62 16.32,9.57 16.58,10.2L18.33,14.5C19.22,13.14 19.6,11.5 19.38,9.89C19.16,8.28 18.37,6.8 17.14,5.73C15.92,4.66 14.34,4.06 12.72,4.06C11.03,4.05 9.39,4.58 8,5.56C6.66,6.55 5.64,7.94 5.12,9.54C4.6,11.14 4.6,12.87 5.12,14.47C5.64,16.07 6.66,17.46 8.03,18.44C9.4,19.43 11.04,19.95 12.72,19.94C13.45,19.94 14.17,19.84 14.87,19.64V21.75C14.16,21.91 13.44,22 12.72,22C10.61,22 8.54,21.34 6.82,20.1C5.1,18.86 3.82,17.11 3.17,15.1C2.5,13.09 2.5,10.92 3.16,8.9C3.82,6.89 5.1,5.14 6.82,3.9C8.53,2.66 10.6,2 12.72,2C17.56,2 21.5,5.94 21.5,10.79C21.5,12.71 20.86,14.59 19.69,16.12V16.12Z\";\r\nvar mdiFactory = \"M4,18V20H8V18H4M4,14V16H14V14H4M10,18V20H14V18H10M16,14V16H20V14H16M16,18V20H20V18H16M2,22V8L7,12V8L12,12V8L17,12L18,2H21L22,12V22H2Z\";\r\nvar mdiFamilyTree = \"M12 1A2.5 2.5 0 0 0 9.5 3.5A2.5 2.5 0 0 0 11 5.79V7H7A2 2 0 0 0 5 9V9.71A2.5 2.5 0 0 0 3.5 12A2.5 2.5 0 0 0 5 14.29V15H4A2 2 0 0 0 2 17V18.21A2.5 2.5 0 0 0 .5 20.5A2.5 2.5 0 0 0 3 23A2.5 2.5 0 0 0 5.5 20.5A2.5 2.5 0 0 0 4 18.21V17H8V18.21A2.5 2.5 0 0 0 6.5 20.5A2.5 2.5 0 0 0 9 23A2.5 2.5 0 0 0 11.5 20.5A2.5 2.5 0 0 0 10 18.21V17A2 2 0 0 0 8 15H7V14.29A2.5 2.5 0 0 0 8.5 12A2.5 2.5 0 0 0 7 9.71V9H17V9.71A2.5 2.5 0 0 0 15.5 12A2.5 2.5 0 0 0 17 14.29V15H16A2 2 0 0 0 14 17V18.21A2.5 2.5 0 0 0 12.5 20.5A2.5 2.5 0 0 0 15 23A2.5 2.5 0 0 0 17.5 20.5A2.5 2.5 0 0 0 16 18.21V17H20V18.21A2.5 2.5 0 0 0 18.5 20.5A2.5 2.5 0 0 0 21 23A2.5 2.5 0 0 0 23.5 20.5A2.5 2.5 0 0 0 22 18.21V17A2 2 0 0 0 20 15H19V14.29A2.5 2.5 0 0 0 20.5 12A2.5 2.5 0 0 0 19 9.71V9A2 2 0 0 0 17 7H13V5.79A2.5 2.5 0 0 0 14.5 3.5A2.5 2.5 0 0 0 12 1M12 2.5A1 1 0 0 1 13 3.5A1 1 0 0 1 12 4.5A1 1 0 0 1 11 3.5A1 1 0 0 1 12 2.5M6 11A1 1 0 0 1 7 12A1 1 0 0 1 6 13A1 1 0 0 1 5 12A1 1 0 0 1 6 11M18 11A1 1 0 0 1 19 12A1 1 0 0 1 18 13A1 1 0 0 1 17 12A1 1 0 0 1 18 11M3 19.5A1 1 0 0 1 4 20.5A1 1 0 0 1 3 21.5A1 1 0 0 1 2 20.5A1 1 0 0 1 3 19.5M9 19.5A1 1 0 0 1 10 20.5A1 1 0 0 1 9 21.5A1 1 0 0 1 8 20.5A1 1 0 0 1 9 19.5M15 19.5A1 1 0 0 1 16 20.5A1 1 0 0 1 15 21.5A1 1 0 0 1 14 20.5A1 1 0 0 1 15 19.5M21 19.5A1 1 0 0 1 22 20.5A1 1 0 0 1 21 21.5A1 1 0 0 1 20 20.5A1 1 0 0 1 21 19.5Z\";\r\nvar mdiFan = \"M12,11A1,1 0 0,0 11,12A1,1 0 0,0 12,13A1,1 0 0,0 13,12A1,1 0 0,0 12,11M12.5,2C17,2 17.11,5.57 14.75,6.75C13.76,7.24 13.32,8.29 13.13,9.22C13.61,9.42 14.03,9.73 14.35,10.13C18.05,8.13 22.03,8.92 22.03,12.5C22.03,17 18.46,17.1 17.28,14.73C16.78,13.74 15.72,13.3 14.79,13.11C14.59,13.59 14.28,14 13.88,14.34C15.87,18.03 15.08,22 11.5,22C7,22 6.91,18.42 9.27,17.24C10.25,16.75 10.69,15.71 10.89,14.79C10.4,14.59 9.97,14.27 9.65,13.87C5.96,15.85 2,15.07 2,11.5C2,7 5.56,6.89 6.74,9.26C7.24,10.25 8.29,10.68 9.22,10.87C9.41,10.39 9.73,9.97 10.14,9.65C8.15,5.96 8.94,2 12.5,2Z\";\r\nvar mdiFanAlert = \"M10 11C9.43 11 9 11.45 9 12S9.43 13 10 13C10.54 13 11 12.55 11 12S10.54 11 10 11M10.5 2C15 2 15.09 5.57 12.73 6.75C11.74 7.24 11.3 8.29 11.11 9.22C11.59 9.42 12 9.73 12.33 10.13C16.03 8.13 20 8.92 20 12.5C20 17 16.43 17.1 15.26 14.73C14.76 13.74 13.7 13.3 12.77 13.11C12.57 13.59 12.26 14 11.86 14.34C13.85 18.03 13.06 22 9.5 22C5 22 4.9 18.42 7.26 17.24C8.24 16.75 8.68 15.71 8.88 14.79C8.39 14.59 7.96 14.27 7.64 13.87C3.95 15.85 0 15.07 0 11.5C0 7 3.56 6.89 4.73 9.26C5.23 10.25 6.28 10.68 7.21 10.87C7.4 10.39 7.72 9.97 8.13 9.65C6.14 5.96 6.93 2 10.5 2M22 13V7H24V13H22M22 17V15H24V17H22Z\";\r\nvar mdiFanChevronDown = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M19 19.17L22.17 16L23.59 17.41L19 22L14.41 17.41L15.83 16L19 19.17\";\r\nvar mdiFanChevronUp = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M19 17.83L15.83 21L14.41 19.59L19 15L23.59 19.59L22.17 21L19 17.83\";\r\nvar mdiFanMinus = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M23 18V20H15V18H23Z\";\r\nvar mdiFanOff = \"M12.5,2C9.64,2 8.57,4.55 9.29,7.47L15,13.16C15.87,13.37 16.81,13.81 17.28,14.73C18.46,17.1 22.03,17 22.03,12.5C22.03,8.92 18.05,8.13 14.35,10.13C14.03,9.73 13.61,9.42 13.13,9.22C13.32,8.29 13.76,7.24 14.75,6.75C17.11,5.57 17,2 12.5,2M3.28,4L2,5.27L4.47,7.73C3.22,7.74 2,8.87 2,11.5C2,15.07 5.96,15.85 9.65,13.87C9.97,14.27 10.4,14.59 10.89,14.79C10.69,15.71 10.25,16.75 9.27,17.24C6.91,18.42 7,22 11.5,22C13.8,22 14.94,20.36 14.94,18.21L18.73,22L20,20.72L3.28,4Z\";\r\nvar mdiFanPlus = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M20 15V18H23V20H20V23H18V20H15V18H18V15H20Z\";\r\nvar mdiFanRemove = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.47L22.54 16.88Z\";\r\nvar mdiFanSpeed1 = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M17 15V17H18V23H20V15H17Z\";\r\nvar mdiFanSpeed2 = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M16 15V17H19V18H18C16.9 18 16 18.9 16 20V23H21V21H18V20H19C20.11 20 21 19.11 21 18V17C21 15.9 20.11 15 19 15H16Z\";\r\nvar mdiFanSpeed3 = \"M13 19C13 17.59 13.5 16.3 14.3 15.28C14.17 14.97 14.03 14.65 13.86 14.34C14.26 14 14.57 13.59 14.77 13.11C15.26 13.21 15.78 13.39 16.25 13.67C17.07 13.25 18 13 19 13C20.05 13 21.03 13.27 21.89 13.74C21.95 13.37 22 12.96 22 12.5C22 8.92 18.03 8.13 14.33 10.13C14 9.73 13.59 9.42 13.11 9.22C13.3 8.29 13.74 7.24 14.73 6.75C17.09 5.57 17 2 12.5 2C8.93 2 8.14 5.96 10.13 9.65C9.72 9.97 9.4 10.39 9.21 10.87C8.28 10.68 7.23 10.25 6.73 9.26C5.56 6.89 2 7 2 11.5C2 15.07 5.95 15.85 9.64 13.87C9.96 14.27 10.39 14.59 10.88 14.79C10.68 15.71 10.24 16.75 9.26 17.24C6.9 18.42 7 22 11.5 22C12.31 22 13 21.78 13.5 21.41C13.19 20.67 13 19.86 13 19M12 13C11.43 13 11 12.55 11 12S11.43 11 12 11C12.54 11 13 11.45 13 12S12.54 13 12 13M21 21V20.5C21 19.67 20.33 19 19.5 19C20.33 19 21 18.33 21 17.5V17C21 15.89 20.1 15 19 15H16V17H19V18H17V20H19V21H16V23H19C20.11 23 21 22.11 21 21\";\r\nvar mdiFastForward = \"M13,6V18L21.5,12M4,18L12.5,12L4,6V18Z\";\r\nvar mdiFastForward10 = \"M10,12V22H8V14H6V12H10M18,14V20C18,21.11 17.11,22 16,22H14A2,2 0 0,1 12,20V14A2,2 0 0,1 14,12H16C17.11,12 18,12.9 18,14M14,14V20H16V14H14M11.5,3C14.15,3 16.55,4 18.4,5.6L21,3V10H14L16.62,7.38C15.23,6.22 13.46,5.5 11.5,5.5C7.96,5.5 4.95,7.81 3.9,11L1.53,10.22C2.92,6.03 6.85,3 11.5,3Z\";\r\nvar mdiFastForward30 = \"M11.5,3C6.85,3 2.92,6.03 1.53,10.22L3.9,11C4.95,7.81 7.96,5.5 11.5,5.5C13.46,5.5 15.23,6.22 16.62,7.38L14,10H21V3L18.4,5.6C16.55,4 14.15,3 11.5,3M19,14V20C19,21.11 18.11,22 17,22H15A2,2 0 0,1 13,20V14A2,2 0 0,1 15,12H17C18.11,12 19,12.9 19,14M15,14V20H17V14H15M11,20C11,21.11 10.1,22 9,22H5V20H9V18H7V16H9V14H5V12H9A2,2 0 0,1 11,14V15.5A1.5,1.5 0 0,1 9.5,17A1.5,1.5 0 0,1 11,18.5V20Z\";\r\nvar mdiFastForward5 = \"M11.5 3C14.15 3 16.55 4 18.4 5.6L21 3V10H14L16.62 7.38C15.23 6.22 13.46 5.5 11.5 5.5C7.96 5.5 4.95 7.81 3.9 11L1.53 10.22C2.92 6.03 6.85 3 11.5 3M9 12H15V14H11V16H13C14.11 16 15 16.9 15 18V20C15 21.11 14.11 22 13 22H9V20H13V18H9V12Z\";\r\nvar mdiFastForward60 = \"M11.5 3C6.8 3 2.9 6 1.5 10.2L3.9 11C4.9 7.8 8 5.5 11.5 5.5C13.5 5.5 15.2 6.2 16.6 7.4L14 10H21V3L18.4 5.6C16.5 4 14.1 3 11.5 3M19 14V20C19 21.1 18.1 22 17 22H15C13.9 22 13 21.1 13 20V14C13 12.9 13.9 12 15 12H17C18.1 12 19 12.9 19 14M15 14V20H17V14H15M7 12C5.9 12 5 12.9 5 14V20C5 21.1 5.9 22 7 22H9C10.1 22 11 21.1 11 20V18C11 16.9 10.1 16 9 16H7V14H11V12H7M7 18H9V20H7V18Z\";\r\nvar mdiFastForwardOutline = \"M15,9.9L18,12L15,14.1V9.9M6,9.9L9,12L6,14.1V9.9M13,6V18L21.5,12L13,6M4,6V18L12.5,12L4,6Z\";\r\nvar mdiFax = \"M11,6H16V8H11V6M8,9V3H19V9A3,3 0 0,1 22,12V18H19V21H8V18H7V9H8M10,5V9H17V5H10M10,15V19H17V15H10M19,11A1,1 0 0,0 18,12A1,1 0 0,0 19,13A1,1 0 0,0 20,12A1,1 0 0,0 19,11M4,9H5A1,1 0 0,1 6,10V17A1,1 0 0,1 5,18H4A2,2 0 0,1 2,16V11A2,2 0 0,1 4,9Z\";\r\nvar mdiFeather = \"M22,2C22,2 14.36,1.63 8.34,9.88C3.72,16.21 2,22 2,22L3.94,21C5.38,18.5 6.13,17.47 7.54,16C10.07,16.74 12.71,16.65 15,14C13,13.44 11.4,13.57 9.04,13.81C11.69,12 13.5,11.6 16,12L17,10C15.2,9.66 14,9.63 12.22,10.04C14.19,8.65 15.56,7.87 18,8L19.21,6.07C17.65,5.96 16.71,6.13 14.92,6.57C16.53,5.11 18,4.45 20.14,4.32C20.14,4.32 21.19,2.43 22,2Z\";\r\nvar mdiFeatureSearch = \"M20,20A2,2 0 0,1 18,22H4A2,2 0 0,1 2,20V6A2,2 0 0,1 4,4H9.5C9.2,4.8 9,5.6 9,6.5C9,10.1 11.9,13 15.5,13C16.3,13 17,12.9 17.6,12.6L20,15V20M19.3,8.9C19.7,8.2 20,7.4 20,6.5C20,4 18,2 15.5,2C13,2 11,4 11,6.5C11,9 13,11 15.5,11C16.4,11 17.2,10.7 17.9,10.3L21,13.4L22.4,12L19.3,8.9M15.5,9C14.1,9 13,7.9 13,6.5C13,5.1 14.1,4 15.5,4C16.9,4 18,5.1 18,6.5C18,7.9 16.9,9 15.5,9Z\";\r\nvar mdiFeatureSearchOutline = \"M15.5,2C13,2 11,4 11,6.5C11,9 13,11 15.5,11C16.4,11 17.2,10.7 17.9,10.3L21,13.4L22.4,12L19.3,8.9C19.7,8.2 20,7.4 20,6.5C20,4 18,2 15.5,2M4,4A2,2 0 0,0 2,6V20A2,2 0 0,0 4,22H18A2,2 0 0,0 20,20V15L18,13V20H4V6H9.03C9.09,5.3 9.26,4.65 9.5,4H4M15.5,4C16.9,4 18,5.1 18,6.5C18,7.9 16.9,9 15.5,9C14.1,9 13,7.9 13,6.5C13,5.1 14.1,4 15.5,4Z\";\r\nvar mdiFedora = \"M4.4,22C3.07,22 2,20.93 2,19.6V12A10,10 0 0,1 12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22H4.4M14.9,4.4C12.3,4.4 10.2,6.5 10.2,9.1V11.6H8.3C7.69,11.6 7.2,12.09 7.2,12.7C7.2,13.31 7.69,13.8 8.3,13.8H9.8C10,13.8 10.2,14 10.2,14.2V16.3C10.2,17.68 9.08,18.8 7.7,18.8C7.55,18.8 7.41,18.79 7.27,18.76C7.19,18.74 7.1,18.73 7,18.73C6.41,18.73 5.91,19.23 5.91,19.83C5.91,20.37 6.3,20.81 6.8,20.91V20.91C7.09,20.97 7.39,21 7.7,21C10.3,21 12.4,18.9 12.4,16.3V13.8H14.3C14.91,13.8 15.4,13.31 15.4,12.7A1.1,1.1 0 0,0 14.3,11.6H12.8A0.4,0.4 0 0,1 12.4,11.2V9.1A2.5,2.5 0 0,1 14.9,6.6C15.05,6.6 15.2,6.61 15.34,6.64C15.42,6.66 15.5,6.67 15.59,6.67C16.19,6.67 16.69,6.17 16.69,5.57C16.69,5.03 16.3,4.58 15.8,4.5V4.5C15.5,4.43 15.21,4.4 14.9,4.4M6.8,12.7C6.8,12.58 6.81,12.46 6.84,12.34L6.31,11.81C6.1,11.87 5.89,11.95 5.7,12.05L6.91,13.26C6.84,13.08 6.8,12.9 6.8,12.7M6.54,18.5H6.47L6.5,18.5H6.54M5.61,19.83C5.61,19.6 5.67,19.38 5.77,19.19L3,16.42C3,16.76 3.05,17.08 3.13,17.4L5.61,19.88V19.83M5.86,20.63C5.77,20.5 5.71,20.37 5.67,20.22L3.24,17.79C3.67,19.07 4.63,20.1 5.86,20.63M15.8,12.7C15.8,12.82 15.79,12.94 15.76,13.06L16.29,13.59C16.5,13.53 16.71,13.45 16.9,13.35L15.69,12.14C15.76,12.32 15.8,12.5 15.8,12.7M16.06,6.88L16.13,6.92L16.08,6.88H16.06M17,5.57C17,5.8 16.93,6 16.83,6.21L19.6,9C19.59,8.64 19.55,8.32 19.47,8L17,5.5V5.57M16.74,4.77C16.83,4.9 16.89,5.03 16.93,5.18L19.36,7.61C18.93,6.33 17.97,5.3 16.74,4.77M16.07,13.65L15.69,13.27C15.61,13.46 15.5,13.63 15.35,13.78V13.78C15.6,13.76 15.84,13.71 16.07,13.65M18.23,12.42L16.67,10.86C16.53,11 16.37,11.13 16.2,11.24L17.78,12.82C17.94,12.69 18.09,12.56 18.23,12.42M17.62,12.94L16,11.34C15.82,11.44 15.61,11.5 15.39,11.55L17.09,13.26C17.27,13.16 17.45,13.05 17.62,12.94M18.75,11.8L17.15,10.2C17.05,10.39 16.94,10.56 16.81,10.71L18.37,12.27C18.5,12.12 18.63,11.97 18.75,11.8M19.16,11.09L17.39,9.32C17.37,9.56 17.32,9.79 17.23,10L18.86,11.63C18.97,11.46 19.07,11.28 19.16,11.09M19.6,9.26L16.72,6.38C16.6,6.55 16.45,6.69 16.28,6.79L19.5,10C19.56,9.77 19.59,9.5 19.6,9.26M19.46,10.25L17.08,7.87C17.27,8.22 17.39,8.62 17.4,9.04L19.25,10.89C19.33,10.68 19.4,10.47 19.46,10.25M4.82,12.58C4.66,12.71 4.5,12.84 4.37,13L5.93,14.54C6.07,14.4 6.23,14.27 6.4,14.16L4.82,12.58M5.5,12.14C5.33,12.24 5.15,12.35 5,12.46L6.58,14.06C6.78,13.96 7,13.89 7.21,13.85L5.5,12.14M7.25,11.62C7,11.64 6.76,11.69 6.53,11.75L6.91,12.13C7,11.94 7.11,11.77 7.25,11.62V11.62M3.09,15.38C3.04,15.63 3,15.88 3,16.14L5.88,19C6,18.85 6.15,18.71 6.32,18.61L3.09,15.38M3.74,13.77C3.63,13.94 3.53,14.12 3.44,14.31L5.21,16.08C5.23,15.84 5.28,15.61 5.37,15.4L3.74,13.77M3.35,14.5C3.27,14.72 3.2,14.93 3.14,15.15L5.5,17.53C5.33,17.18 5.21,16.78 5.2,16.36L3.35,14.5M4.23,13.13C4.1,13.28 3.97,13.43 3.85,13.6L5.45,15.2C5.55,15 5.66,14.84 5.79,14.69L4.23,13.13Z\";\r\nvar mdiFencing = \"M4.5 17.42L5.58 18.5L3.28 20.78C3 21.07 2.5 21.07 2.22 20.78S1.93 20 2.22 19.72L4.5 17.42M18.29 5.42L18.29 4L12 10.29L5.71 4L5.71 5.42L11.29 11L7.5 14.81C6.32 13.97 4.68 14.07 3.63 15.12L7.88 19.37C8.93 18.32 9.03 16.68 8.2 15.5L18.29 5.42M21.78 19.72L19.5 17.42L18.42 18.5L20.72 20.78C21 21.07 21.5 21.07 21.78 20.78S22.07 20 21.78 19.72M16.5 14.81L13.42 11.71L12.71 12.42L15.81 15.5C14.97 16.68 15.07 18.32 16.12 19.37L20.37 15.12C19.32 14.07 17.68 13.97 16.5 14.81Z\";\r\nvar mdiFerrisWheel = \"M12,19C12.86,19 13.59,19.54 13.87,20.29C14.42,20.17 14.95,20 15.46,19.77L13.7,15.62C13.18,15.87 12.61,16 12,16C11.39,16 10.82,15.87 10.3,15.62L8.54,19.77C9.05,20 9.58,20.17 10.13,20.29C10.41,19.54 11.14,19 12,19M18.25,17.76C18,17.42 17.81,17 17.81,16.5C17.81,15.41 18.71,14.5 19.81,14.5L20.12,14.53C20.37,13.73 20.5,12.88 20.5,12C20.5,11.12 20.37,10.27 20.12,9.5H19.81C18.7,9.5 17.81,8.61 17.81,7.5C17.81,7 17.97,6.59 18.25,6.24C17.1,5 15.59,4.09 13.87,3.71C13.59,4.46 12.86,5 12,5C11.14,5 10.41,4.46 10.13,3.71C8.41,4.09 6.9,5 5.75,6.24C6.03,6.59 6.2,7.03 6.2,7.5C6.2,8.61 5.3,9.5 4.2,9.5H3.88C3.63,10.28 3.5,11.12 3.5,12C3.5,12.89 3.64,13.74 3.89,14.55L4.2,14.5C5.31,14.5 6.2,15.42 6.2,16.5C6.2,17 6.04,17.43 5.76,17.77C6.08,18.12 6.44,18.44 6.81,18.73L8.71,14.27C8.26,13.62 8,12.84 8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12C16,12.84 15.74,13.62 15.29,14.27L17.19,18.73C17.57,18.44 17.92,18.11 18.25,17.76M12,23C11,23 10.16,22.26 10,21.29C9.37,21.16 8.75,20.95 8.15,20.69L7.17,23H5L6.41,19.68C5.88,19.3 5.39,18.86 4.96,18.37C4.72,18.47 4.47,18.5 4.2,18.5A2,2 0 0,1 2.2,16.5C2.2,15.88 2.5,15.32 2.97,14.95C2.66,14 2.5,13.03 2.5,12C2.5,11 2.66,10 2.96,9.08C2.5,8.71 2.2,8.15 2.2,7.5C2.2,6.41 3.09,5.5 4.2,5.5C4.46,5.5 4.71,5.56 4.93,5.65C6.25,4.18 8,3.13 10,2.71C10.16,1.74 11,1 12,1C13,1 13.84,1.74 14,2.71C16,3.13 17.74,4.18 19.06,5.64C19.29,5.55 19.54,5.5 19.81,5.5A2,2 0 0,1 21.81,7.5C21.81,8.14 21.5,8.71 21.04,9.07C21.34,10 21.5,11 21.5,12C21.5,13 21.34,14 21.04,14.93C21.5,15.3 21.81,15.87 21.81,16.5C21.81,17.62 20.92,18.5 19.81,18.5C19.54,18.5 19.29,18.46 19.05,18.36C18.61,18.85 18.12,19.29 17.59,19.68L19,23H16.83L15.85,20.69C15.25,20.95 14.63,21.16 14,21.29C13.84,22.26 13,23 12,23Z\";\r\nvar mdiFerry = \"M6,6H18V9.96L12,8L6,9.96M3.94,19H4C5.6,19 7,18.12 8,17C9,18.12 10.4,19 12,19C13.6,19 15,18.12 16,17C17,18.12 18.4,19 20,19H20.05L21.95,12.31C22.03,12.06 22,11.78 21.89,11.54C21.76,11.3 21.55,11.12 21.29,11.04L20,10.62V6C20,4.89 19.1,4 18,4H15V1H9V4H6A2,2 0 0,0 4,6V10.62L2.71,11.04C2.45,11.12 2.24,11.3 2.11,11.54C2,11.78 1.97,12.06 2.05,12.31M20,21C18.61,21 17.22,20.53 16,19.67C13.56,21.38 10.44,21.38 8,19.67C6.78,20.53 5.39,21 4,21H2V23H4C5.37,23 6.74,22.65 8,22C10.5,23.3 13.5,23.3 16,22C17.26,22.65 18.62,23 20,23H22V21H20Z\";\r\nvar mdiFile = \"M13,9V3.5L18.5,9M6,2C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2H6Z\";\r\nvar mdiFileAccount = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M14,20V19C14,17.67 11.33,17 10,17C8.67,17 6,17.67 6,19V20H14M10,12A2,2 0 0,0 8,14A2,2 0 0,0 10,16A2,2 0 0,0 12,14A2,2 0 0,0 10,12Z\";\r\nvar mdiFileAccountOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M13 13C13 14.1 12.1 15 11 15S9 14.1 9 13 9.9 11 11 11 13 11.9 13 13M15 18V19H7V18C7 16.67 9.67 16 11 16S15 16.67 15 18Z\";\r\nvar mdiFileAlert = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M9 19H7V17H9M9 15H7V9H9M13 9V3.5L18.5 9H13Z\";\r\nvar mdiFileAlertOutline = \"M10 18H8V16H10V18M10 14H8V8H10V14M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13V9H18V20Z\";\r\nvar mdiFileCabinet = \"M14,8H10V6H14V8M20,4V20C20,21.11 19.11,22 18,22H6C4.89,22 4,21.11 4,20V4A2,2 0 0,1 6,2H18C19.11,2 20,2.9 20,4M18,13H6V20H18V13M18,4H6V11H18V4M14,15H10V17H14V15Z\";\r\nvar mdiFileCad = \"M6 2C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M13 3.5L18.5 9H13M9.88 9.25H11.12V10.19C11.81 10.18 12.38 10.75 12.38 11.44V13.5L12.26 13.63L13.15 15.17C13.47 14.67 13.63 14.09 13.62 13.5H14.88C14.88 14.54 14.5 15.55 13.83 16.35L15.5 19.25V20.5L14.42 19.88L12.87 17.19C12.17 17.65 11.34 17.89 10.5 17.89C9.66 17.89 8.84 17.65 8.13 17.19L6.58 19.88L5.5 20.5V19.25L8.74 13.63L8.62 13.5V11.44C8.62 10.75 9.19 10.18 9.88 10.19M10.5 11.44C9.81 11.44 9.46 12.28 9.95 12.77C10.44 13.26 11.28 12.92 11.28 12.22C11.28 11.79 10.93 11.44 10.5 11.44M9.66 14.54L8.76 16.11C9.81 16.82 11.19 16.82 12.24 16.11L11.34 14.54C10.87 15 10.13 15 9.66 14.54Z\";\r\nvar mdiFileCadBox = \"M5 3C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M11.25 5.25H12.75V6.38C13.58 6.38 14.25 7.05 14.25 7.88V10.37L14.11 10.5L15.18 12.36C15.55 11.76 15.75 11.07 15.75 10.36H17.25C17.26 11.61 16.81 12.82 16 13.77L18 17.25V18.75L16.7 18L14.84 14.78C13.12 15.91 10.89 15.91 9.16 14.78L7.3 18L6 18.75V17.25L9.89 10.5L9.75 10.37V7.88C9.75 7.05 10.42 6.38 11.25 6.38M12 7.88C11.16 7.88 10.74 8.9 11.34 9.5C11.94 10.08 12.95 9.65 12.94 8.81C12.94 8.29 12.5 7.88 12 7.88M11 11.6L9.91 13.5C11.17 14.36 12.83 14.36 14.09 13.5L13 11.6C12.43 12.11 11.57 12.11 11 11.6Z\";\r\nvar mdiFileCancel = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M10.5,11C8,11 6,13 6,15.5C6,18 8,20 10.5,20C13,20 15,18 15,15.5C15,13 13,11 10.5,11M10.5,12.5A3,3 0 0,1 13.5,15.5C13.5,16.06 13.35,16.58 13.08,17L9,12.92C9.42,12.65 9.94,12.5 10.5,12.5M7.5,15.5C7.5,14.94 7.65,14.42 7.92,14L12,18.08C11.58,18.35 11.06,18.5 10.5,18.5A3,3 0 0,1 7.5,15.5Z\";\r\nvar mdiFileCancelOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M11.5,10C14,10 16,12 16,14.5C16,17 14,19 11.5,19C9,19 7,17 7,14.5C7,12 9,10 11.5,10M11.5,11.5C10.94,11.5 10.42,11.65 10,11.92L14.08,16C14.35,15.58 14.5,15.06 14.5,14.5A3,3 0 0,0 11.5,11.5M8.5,14.5A3,3 0 0,0 11.5,17.5C12.06,17.5 12.58,17.35 13,17.08L8.92,13C8.65,13.42 8.5,13.94 8.5,14.5Z\";\r\nvar mdiFileCertificate = \"M14 2H7A2 2 0 0 0 5 4V18A2 2 0 0 0 7 20H10V23L12 22L14 23V20H17A2 2 0 0 0 19 18V7M14 15V17L12 16L10 17V15L8 14L10 13V11L12 12L14 11V13L16 14M13 8V3.5L17.5 8Z\";\r\nvar mdiFileCertificateOutline = \"M14 13V11L12 12L10 11V13L8 14L10 15V17L12 16L14 17V15L16 14M14 2H7A2 2 0 0 0 5 4V18A2 2 0 0 0 7 20H8V18H7V4H13V8H17V18H16V20H17A2 2 0 0 0 19 18V7M14 13V11L12 12L10 11V13L8 14L10 15V17L12 16L14 17V15L16 14M10 23L12 22L14 23V18H10M14 13V11L12 12L10 11V13L8 14L10 15V17L12 16L14 17V15L16 14Z\";\r\nvar mdiFileChart = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M7,20H9V14H7V20M11,20H13V12H11V20M15,20H17V16H15V20Z\";\r\nvar mdiFileChartOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13V9H18V20M9 13V19H7V13H9M15 15V19H17V15H15M11 11V19H13V11H11Z\";\r\nvar mdiFileCheck = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M11.2,18.46L15.95,13.71L14.78,12.3L11.2,15.88L9.61,14.3L8.45,15.46L11.2,18.46Z\";\r\nvar mdiFileCheckOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M11.2,18.46L8.45,15.46L9.61,14.3L11.2,15.88L14.78,12.3L15.95,13.71L11.2,18.46Z\";\r\nvar mdiFileClock = \"M4 2C2.89 2 2 2.89 2 4V20A2 2 0 0 0 4 22H12.41A7 7 0 0 0 16 23A7 7 0 0 0 23 16A7 7 0 0 0 18 9.3V8L12 2H4M11 3.5L16.5 9H11V3.5M16 11A5 5 0 0 1 21 16A5 5 0 0 1 16 21A5 5 0 0 1 11 16A5 5 0 0 1 16 11M15 12V17L18.61 19.16L19.36 17.94L16.5 16.25V12H15Z\";\r\nvar mdiFileClockOutline = \"M4 2A2 2 0 0 0 2 4V20A2 2 0 0 0 4 22H12.41A7 7 0 0 0 16 23A7 7 0 0 0 23 16A7 7 0 0 0 18 9.3V8L12 2H4M4 4H11V9H16A7 7 0 0 0 9 16A7 7 0 0 0 10.26 20H4V4M16 11A5 5 0 0 1 21 16A5 5 0 0 1 16 21A5 5 0 0 1 11 16A5 5 0 0 1 16 11M15 12V17L18.61 19.16L19.36 17.94L16.5 16.25V12H15Z\";\r\nvar mdiFileCloud = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M15.68,15C15.34,13.3 13.82,12 12,12C10.55,12 9.3,12.82 8.68,14C7.17,14.18 6,15.45 6,17A3,3 0 0,0 9,20H15.5A2.5,2.5 0 0,0 18,17.5C18,16.18 16.97,15.11 15.68,15Z\";\r\nvar mdiFileCloudOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M17 16.92C17 18.07 16.07 19 14.92 19H9.5C8.12 19 7 17.88 7 16.5C7 15.21 8 14.15 9.23 14C9.75 13 10.79 12.33 12 12.33C13.5 12.33 14.78 13.42 15.07 14.83C16.14 14.93 17 15.82 17 16.92Z\";\r\nvar mdiFileCode = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M6.12,15.5L9.86,19.24L11.28,17.83L8.95,15.5L11.28,13.17L9.86,11.76L6.12,15.5M17.28,15.5L13.54,11.76L12.12,13.17L14.45,15.5L12.12,17.83L13.54,19.24L17.28,15.5Z\";\r\nvar mdiFileCodeOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M9.54 15.65L11.63 17.74L10.35 19L7 15.65L10.35 12.3L11.63 13.56L9.54 15.65M17 15.65L13.65 19L12.38 17.74L14.47 15.65L12.38 13.56L13.65 12.3L17 15.65Z\";\r\nvar mdiFileCog = \"M6 2C4.89 2 4 2.89 4 4V20A2 2 0 0 0 6 22H12.68A7 7 0 0 1 12 19A7 7 0 0 1 19 12A7 7 0 0 1 20 12.08V8L14 2H6M13 3.5L18.5 9H13V3.5M18 14C17.87 14 17.76 14.09 17.74 14.21L17.55 15.53C17.25 15.66 16.96 15.82 16.7 16L15.46 15.5C15.35 15.5 15.22 15.5 15.15 15.63L14.15 17.36C14.09 17.47 14.11 17.6 14.21 17.68L15.27 18.5C15.25 18.67 15.24 18.83 15.24 19C15.24 19.17 15.25 19.33 15.27 19.5L14.21 20.32C14.12 20.4 14.09 20.53 14.15 20.64L15.15 22.37C15.21 22.5 15.34 22.5 15.46 22.5L16.7 22C16.96 22.18 17.24 22.35 17.55 22.47L17.74 23.79C17.76 23.91 17.86 24 18 24H20C20.11 24 20.22 23.91 20.24 23.79L20.43 22.47C20.73 22.34 21 22.18 21.27 22L22.5 22.5C22.63 22.5 22.76 22.5 22.83 22.37L23.83 20.64C23.89 20.53 23.86 20.4 23.77 20.32L22.7 19.5C22.72 19.33 22.74 19.17 22.74 19C22.74 18.83 22.73 18.67 22.7 18.5L23.76 17.68C23.85 17.6 23.88 17.47 23.82 17.36L22.82 15.63C22.76 15.5 22.63 15.5 22.5 15.5L21.27 16C21 15.82 20.73 15.65 20.42 15.53L20.23 14.21C20.22 14.09 20.11 14 20 14H18M19 17.5C19.83 17.5 20.5 18.17 20.5 19C20.5 19.83 19.83 20.5 19 20.5C18.16 20.5 17.5 19.83 17.5 19C17.5 18.17 18.17 17.5 19 17.5Z\";\r\nvar mdiFileCogOutline = \"M6 2C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H12V20H6V4H13V9H18V12H20V8L14 2M18 14C17.87 14 17.76 14.09 17.74 14.21L17.55 15.53C17.25 15.66 16.96 15.82 16.7 16L15.46 15.5C15.35 15.5 15.22 15.5 15.15 15.63L14.15 17.36C14.09 17.47 14.11 17.6 14.21 17.68L15.27 18.5C15.25 18.67 15.24 18.83 15.24 19C15.24 19.17 15.25 19.33 15.27 19.5L14.21 20.32C14.12 20.4 14.09 20.53 14.15 20.64L15.15 22.37C15.21 22.5 15.34 22.5 15.46 22.5L16.7 22C16.96 22.18 17.24 22.35 17.55 22.47L17.74 23.79C17.76 23.91 17.86 24 18 24H20C20.11 24 20.22 23.91 20.24 23.79L20.43 22.47C20.73 22.34 21 22.18 21.27 22L22.5 22.5C22.63 22.5 22.76 22.5 22.83 22.37L23.83 20.64C23.89 20.53 23.86 20.4 23.77 20.32L22.7 19.5C22.72 19.33 22.74 19.17 22.74 19C22.74 18.83 22.73 18.67 22.7 18.5L23.76 17.68C23.85 17.6 23.88 17.47 23.82 17.36L22.82 15.63C22.76 15.5 22.63 15.5 22.5 15.5L21.27 16C21 15.82 20.73 15.65 20.42 15.53L20.23 14.21C20.22 14.09 20.11 14 20 14M19 17.5C19.83 17.5 20.5 18.17 20.5 19C20.5 19.83 19.83 20.5 19 20.5C18.16 20.5 17.5 19.83 17.5 19C17.5 18.17 18.17 17.5 19 17.5Z\";\r\nvar mdiFileCompare = \"M10,18H6V16H10V18M10,14H6V12H10V14M10,1V2H6C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H10V23H12V1H10M20,8V20C20,21.11 19.11,22 18,22H14V20H18V11H14V9H18.5L14,4.5V2L20,8M16,14H14V12H16V14M16,18H14V16H16V18Z\";\r\nvar mdiFileDelimited = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M15 16L13 20H10L12 16H9V11H15V16M13 9V3.5L18.5 9H13Z\";\r\nvar mdiFileDelimitedOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13V9H18V20M10 19L12 15H9V10H15V15L13 19H10\";\r\nvar mdiFileDocument = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M15,18V16H6V18H15M18,14V12H6V14H18Z\";\r\nvar mdiFileDocumentEdit = \"M6,2C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H10V20.09L12.09,18H6V16H14.09L16.09,14H6V12H18.09L20,10.09V8L14,2H6M13,3.5L18.5,9H13V3.5M20.15,13C20,13 19.86,13.05 19.75,13.16L18.73,14.18L20.82,16.26L21.84,15.25C22.05,15.03 22.05,14.67 21.84,14.46L20.54,13.16C20.43,13.05 20.29,13 20.15,13M18.14,14.77L12,20.92V23H14.08L20.23,16.85L18.14,14.77Z\";\r\nvar mdiFileDocumentEditOutline = \"M8,12H16V14H8V12M10,20H6V4H13V9H18V12.1L20,10.1V8L14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H10V20M8,18H12.1L13,17.1V16H8V18M20.2,13C20.3,13 20.5,13.1 20.6,13.2L21.9,14.5C22.1,14.7 22.1,15.1 21.9,15.3L20.9,16.3L18.8,14.2L19.8,13.2C19.9,13.1 20,13 20.2,13M20.2,16.9L14.1,23H12V20.9L18.1,14.8L20.2,16.9Z\";\r\nvar mdiFileDocumentMultiple = \"M4 4V22H20V24H4C2.9 24 2 23.1 2 22V4H4M15 7H20.5L15 1.5V7M8 0H16L22 6V18C22 19.11 21.11 20 20 20H8C6.89 20 6 19.1 6 18V2C6 .89 6.89 0 8 0M17 16V14H8V16H17M20 12V10H8V12H20Z\";\r\nvar mdiFileDocumentMultipleOutline = \"M16 0H8C6.9 0 6 .9 6 2V18C6 19.1 6.9 20 8 20H20C21.1 20 22 19.1 22 18V6L16 0M20 18H8V2H15V7H20V18M4 4V22H20V24H4C2.9 24 2 23.1 2 22V4H4M10 10V12H18V10H10M10 14V16H15V14H10Z\";\r\nvar mdiFileDocumentOutline = \"M6,2A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2H6M6,4H13V9H18V20H6V4M8,12V14H16V12H8M8,16V18H13V16H8Z\";\r\nvar mdiFileDownload = \"M14,2H6C4.89,2 4,2.89 4,4V20C4,21.11 4.89,22 6,22H18C19.11,22 20,21.11 20,20V8L14,2M12,19L8,15H10.5V12H13.5V15H16L12,19M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileDownloadOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M12,19L8,15H10.5V12H13.5V15H16L12,19Z\";\r\nvar mdiFileEdit = \"M6 2C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H10V20.1L20 10.1V8L14 2H6M13 3.5L18.5 9H13V3.5M20.1 13C20 13 19.8 13.1 19.7 13.2L18.7 14.2L20.8 16.3L21.8 15.3C22 15.1 22 14.7 21.8 14.5L20.5 13.2C20.4 13.1 20.3 13 20.1 13M18.1 14.8L12 20.9V23H14.1L20.2 16.9L18.1 14.8Z\";\r\nvar mdiFileEditOutline = \"M10 20H6V4H13V9H18V12.1L20 10.1V8L14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H10V20M20.2 13C20.3 13 20.5 13.1 20.6 13.2L21.9 14.5C22.1 14.7 22.1 15.1 21.9 15.3L20.9 16.3L18.8 14.2L19.8 13.2C19.9 13.1 20 13 20.2 13M20.2 16.9L14.1 23H12V20.9L18.1 14.8L20.2 16.9Z\";\r\nvar mdiFileExcel = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M15.8,20H14L12,16.6L10,20H8.2L11.1,15.5L8.2,11H10L12,14.4L14,11H15.8L12.9,15.5L15.8,20M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileExcelBox = \"M16.2,17H14.2L12,13.2L9.8,17H7.8L11,12L7.8,7H9.8L12,10.8L14.2,7H16.2L13,12M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiFileExcelBoxOutline = \"M5 3C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3H5M5 5H19V19H5V5M13 12L16.2 17H14.2L12 13.2L9.8 17H7.8L11 12L7.8 7H9.8L12 10.8L14.2 7H16.2L13 12Z\";\r\nvar mdiFileExcelOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M12.9 14.5L15.8 19H14L12 15.6L10 19H8.2L11.1 14.5L8.2 10H10L12 13.4L14 10H15.8L12.9 14.5Z\";\r\nvar mdiFileExport = \"M6,2C4.89,2 4,2.9 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M13,3.5L18.5,9H13M8.93,12.22H16V19.29L13.88,17.17L11.05,20L8.22,17.17L11.05,14.35\";\r\nvar mdiFileExportOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13V9H18V20M16 11V18.1L13.9 16L11.1 18.8L8.3 16L11.1 13.2L8.9 11H16Z\";\r\nvar mdiFileEye = \"M17,18C17.56,18 18,18.44 18,19C18,19.56 17.56,20 17,20C16.44,20 16,19.56 16,19C16,18.44 16.44,18 17,18M17,15C14.27,15 11.94,16.66 11,19C11.94,21.34 14.27,23 17,23C19.73,23 22.06,21.34 23,19C22.06,16.66 19.73,15 17,15M17,21.5A2.5,2.5 0 0,1 14.5,19A2.5,2.5 0 0,1 17,16.5A2.5,2.5 0 0,1 19.5,19A2.5,2.5 0 0,1 17,21.5M9.14,19.75L8.85,19L9.14,18.26C10.43,15.06 13.5,13 17,13C18.05,13 19.06,13.21 20,13.56V8L14,2H6C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H10.5C9.95,21.34 9.5,20.58 9.14,19.75M13,3.5L18.5,9H13V3.5Z\";\r\nvar mdiFileEyeOutline = \"M17,18C17.56,18 18,18.44 18,19C18,19.56 17.56,20 17,20C16.44,20 16,19.56 16,19C16,18.44 16.44,18 17,18M17,15C14.27,15 11.94,16.66 11,19C11.94,21.34 14.27,23 17,23C19.73,23 22.06,21.34 23,19C22.06,16.66 19.73,15 17,15M17,21.5A2.5,2.5 0 0,1 14.5,19A2.5,2.5 0 0,1 17,16.5A2.5,2.5 0 0,1 19.5,19A2.5,2.5 0 0,1 17,21.5M9.27,20H6V4H13V9H18V13.07C18.7,13.15 19.36,13.32 20,13.56V8L14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H10.5C10,21.41 9.59,20.73 9.27,20Z\";\r\nvar mdiFileFind = \"M9,13A3,3 0 0,0 12,16A3,3 0 0,0 15,13A3,3 0 0,0 12,10A3,3 0 0,0 9,13M20,19.59V8L14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18C18.45,22 18.85,21.85 19.19,21.6L14.76,17.17C13.96,17.69 13,18 12,18A5,5 0 0,1 7,13A5,5 0 0,1 12,8A5,5 0 0,1 17,13C17,14 16.69,14.96 16.17,15.75L20,19.59Z\";\r\nvar mdiFileFindOutline = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M6,4H13L18,9V17.58L16.16,15.74C17.44,13.8 17.23,11.17 15.5,9.46C14.55,8.5 13.28,8 12,8C10.72,8 9.45,8.5 8.47,9.46C6.5,11.41 6.5,14.57 8.47,16.5C9.44,17.5 10.72,17.97 12,17.97C12.96,17.97 13.92,17.69 14.75,17.14L17.6,20H6V4M14.11,15.1C13.55,15.66 12.8,16 12,16C11.2,16 10.45,15.67 9.89,15.1C9.33,14.54 9,13.79 9,13C9,12.19 9.32,11.44 9.89,10.88C10.45,10.31 11.2,10 12,10C12.8,10 13.55,10.31 14.11,10.88C14.67,11.44 15,12.19 15,13C15,13.79 14.68,14.54 14.11,15.1Z\";\r\nvar mdiFileHidden = \"M13,9H14V11H11V7H13V9M18.5,9L16.38,6.88L17.63,5.63L20,8V10H18V11H15V9H18.5M13,3.5V2H12V4H13V6H11V4H9V2H8V4H6V5H4V4C4,2.89 4.89,2 6,2H14L16.36,4.36L15.11,5.61L13,3.5M20,20A2,2 0 0,1 18,22H16V20H18V19H20V20M18,15H20V18H18V15M12,22V20H15V22H12M8,22V20H11V22H8M6,22C4.89,22 4,21.1 4,20V18H6V20H7V22H6M4,14H6V17H4V14M4,10H6V13H4V10M18,11H20V14H18V11M4,6H6V9H4V6Z\";\r\nvar mdiFileImage = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M6,20H15L18,20V12L14,16L12,14L6,20M8,9A2,2 0 0,0 6,11A2,2 0 0,0 8,13A2,2 0 0,0 10,11A2,2 0 0,0 8,9Z\";\r\nvar mdiFileImageOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M17,13V19H7L12,14L14,16M10,10.5A1.5,1.5 0 0,1 8.5,12A1.5,1.5 0 0,1 7,10.5A1.5,1.5 0 0,1 8.5,9A1.5,1.5 0 0,1 10,10.5Z\";\r\nvar mdiFileImport = \"M6,2C4.89,2 4,2.9 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M13,3.5L18.5,9H13M10.05,11.22L12.88,14.05L15,11.93V19H7.93L10.05,16.88L7.22,14.05\";\r\nvar mdiFileImportOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M15 11.93V19H7.93L10.05 16.88L7.22 14.05L10.05 11.22L12.88 14.05L15 11.93Z\";\r\nvar mdiFileKey = \"M11 16A1 1 0 1 1 10 15A1 1 0 0 1 11 16M20 8V20A2 2 0 0 1 18 22H6A2 2 0 0 1 4 20V4A2 2 0 0 1 6 2H14M17 15H12.83A3 3 0 1 0 12.83 17H14V19H16V17H17M18.5 9L13 3.5V9Z\";\r\nvar mdiFileKeyOutline = \"M14 2H6A2 2 0 0 0 4 4V20A2 2 0 0 0 6 22H18A2 2 0 0 0 20 20V8L14 2M18 20H6V4H13V9H18M12.83 15A3 3 0 1 0 12.83 17H14V19H16V17H17V15M10 17A1 1 0 1 1 11 16A1 1 0 0 1 10 17Z\";\r\nvar mdiFileLink = \"M14 2H6C4.89 2 4 2.89 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M11 20H10C8.39 20 6 18.94 6 16C6 13.07 8.39 12 10 12H11V14H10C9.54 14 8 14.17 8 16C8 17.9 9.67 18 10 18H11V20M15 15V17H9V15H15M14 20H13V18H14C14.46 18 16 17.83 16 16C16 14.1 14.33 14 14 14H13V12H14C15.61 12 18 13.07 18 16C18 18.94 15.61 20 14 20M13 9V3.5L18.5 9H13Z\";\r\nvar mdiFileLinkOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M11 19H10.75C9.45 19 7 18.22 7 15.25S9.45 11.5 10.75 11.5H11V13H10.75C10.38 13 8.5 13.13 8.5 15.25C8.5 17.44 10.5 17.5 10.75 17.5H11V19M14 16H10V14.5H14V16M13 11.5H13.25C14.55 11.5 17 12.28 17 15.25S14.55 19 13.25 19H13V17.5H13.25C13.62 17.5 15.5 17.37 15.5 15.25C15.5 13.06 13.5 13 13.25 13H13V11.5Z\";\r\nvar mdiFileLock = \"M6,2C4.89,2 4,2.9 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2H6M13,3.5L18.5,9H13V3.5M12,11A3,3 0 0,1 15,14V15H16V19H8V15H9V14C9,12.36 10.34,11 12,11M12,13A1,1 0 0,0 11,14V15H13V14C13,13.47 12.55,13 12,13Z\";\r\nvar mdiFileLockOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M15 15V14C15 12.34 13.66 11 12 11S9 12.36 9 14V15H8V19H16V15H15M13 15H11V14C11 13.45 11.45 13 12 13S13 13.47 13 14V15Z\";\r\nvar mdiFileMove = \"M14,17H18V14L23,18.5L18,23V20H14V17M13,9H18.5L13,3.5V9M6,2H14L20,8V12.34C19.37,12.12 18.7,12 18,12A6,6 0 0,0 12,18C12,19.54 12.58,20.94 13.53,22H6C4.89,22 4,21.1 4,20V4A2,2 0 0,1 6,2Z\";\r\nvar mdiFileMoveOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 20.41 4.12 20.8 4.34 21.12C4.41 21.23 4.5 21.33 4.59 21.41C4.95 21.78 5.45 22 6 22H13.53C13 21.42 12.61 20.75 12.35 20H6V4H13V9H18V12C18.7 12 19.37 12.12 20 12.34V8L14 2M18 23L23 18.5L20 15.8L18 14V17H14V20H18V23Z\";\r\nvar mdiFileMultiple = \"M15,7H20.5L15,1.5V7M8,0H16L22,6V18A2,2 0 0,1 20,20H8C6.89,20 6,19.1 6,18V2A2,2 0 0,1 8,0M4,4V22H20V24H4A2,2 0 0,1 2,22V4H4Z\";\r\nvar mdiFileMultipleOutline = \"M16 0H8C6.9 0 6 .9 6 2V18C6 19.1 6.9 20 8 20H20C21.1 20 22 19.1 22 18V6L16 0M20 18H8V2H15V7H20V18M4 4V22H20V24H4C2.9 24 2 23.1 2 22V4H4Z\";\r\nvar mdiFileMusic = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M13,13H11V18A2,2 0 0,1 9,20A2,2 0 0,1 7,18A2,2 0 0,1 9,16C9.4,16 9.7,16.1 10,16.3V11H13V13M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileMusicOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M13,10V12H11V17A2,2 0 0,1 9,19A2,2 0 0,1 7,17A2,2 0 0,1 9,15C9.4,15 9.7,15.1 10,15.3V10H13Z\";\r\nvar mdiFileOutline = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M18,20H6V4H13V9H18V20Z\";\r\nvar mdiFilePdf = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M10.1,11.4C10.08,11.44 9.81,13.16 8,16.09C8,16.09 4.5,17.91 5.33,19.27C6,20.35 7.65,19.23 9.07,16.59C9.07,16.59 10.89,15.95 13.31,15.77C13.31,15.77 17.17,17.5 17.7,15.66C18.22,13.8 14.64,14.22 14,14.41C14,14.41 12,13.06 11.5,11.2C11.5,11.2 12.64,7.25 10.89,7.3C9.14,7.35 9.8,10.43 10.1,11.4M10.91,12.44C10.94,12.45 11.38,13.65 12.8,14.9C12.8,14.9 10.47,15.36 9.41,15.8C9.41,15.8 10.41,14.07 10.91,12.44M14.84,15.16C15.42,15 17.17,15.31 17.1,15.64C17.04,15.97 14.84,15.16 14.84,15.16M7.77,17C7.24,18.24 6.33,19 6.1,19C5.87,19 6.8,17.4 7.77,17M10.91,10.07C10.91,10 10.55,7.87 10.91,7.92C11.45,8 10.91,10 10.91,10.07Z\";\r\nvar mdiFilePdfBox = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19M10.59,10.08C10.57,10.13 10.3,11.84 8.5,14.77C8.5,14.77 5,16.58 5.83,17.94C6.5,19 8.15,17.9 9.56,15.27C9.56,15.27 11.38,14.63 13.79,14.45C13.79,14.45 17.65,16.19 18.17,14.34C18.69,12.5 15.12,12.9 14.5,13.09C14.5,13.09 12.46,11.75 12,9.89C12,9.89 13.13,5.95 11.38,6C9.63,6.05 10.29,9.12 10.59,10.08M11.4,11.13C11.43,11.13 11.87,12.33 13.29,13.58C13.29,13.58 10.96,14.04 9.9,14.5C9.9,14.5 10.9,12.75 11.4,11.13M15.32,13.84C15.9,13.69 17.64,14 17.58,14.32C17.5,14.65 15.32,13.84 15.32,13.84M8.26,15.7C7.73,16.91 6.83,17.68 6.6,17.67C6.37,17.66 7.3,16.07 8.26,15.7M11.4,8.76C11.39,8.71 11.03,6.57 11.4,6.61C11.94,6.67 11.4,8.71 11.4,8.76Z\";\r\nvar mdiFilePdfBoxOutline = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M19 5V19H5V5H19M17.9 13.5C17.6 13 16.9 12.8 15.7 12.8C15.3 12.8 14.9 12.8 14.5 12.9C14.2 12.7 13.9 12.5 13.7 12.3C13.1 11.8 12.5 10.9 12.2 9.8V9.7C12.5 8.4 12.8 6.9 12.2 6.2C11.9 6.1 11.7 6 11.5 6H11.3C10.9 6 10.6 6.4 10.5 6.7C10.1 8 10.4 8.7 10.7 9.9C10.5 10.8 10.1 11.7 9.7 12.7C9.3 13.4 9 14 8.7 14.5C8.3 14.7 8 14.8 7.8 15C6.7 15.7 6.1 16.5 6 17V17.5L6.5 17.8C6.7 18 6.8 18 7 18C7.8 18 8.7 17.1 9.9 15H10C11 14.7 12.2 14.5 13.9 14.3C14.9 14.8 16.1 15 16.8 15C17.2 15 17.5 14.9 17.7 14.7C17.9 14.5 18 14.3 18 14.1C18 13.8 18 13.6 17.9 13.5M6.8 17.3C6.8 16.9 7.3 16.3 8 15.7C8.1 15.6 8.3 15.5 8.5 15.4C7.8 16.5 7.2 17.2 6.8 17.3M11.3 6.7C11.3 6.7 11.3 6.6 11.4 6.6H11.5C11.7 6.8 11.7 7.1 11.6 7.7V7.9C11.5 8.1 11.5 8.4 11.4 8.7C11.1 7.8 11.1 7.1 11.3 6.7M10.1 14.3H10C10.1 14 10.3 13.7 10.5 13.3C10.9 12.5 11.3 11.7 11.5 11C11.9 11.9 12.4 12.6 13 13.1C13.1 13.2 13.3 13.3 13.4 13.4C12.5 13.5 11.3 13.8 10.1 14.3M17.3 14.2H17.1C16.7 14.2 16 14 15.3 13.7C15.4 13.6 15.5 13.6 15.5 13.6C16.9 13.6 17.2 13.8 17.3 13.9L17.4 14C17.4 14.2 17.4 14.2 17.3 14.2Z\";\r\nvar mdiFilePdfOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M10.92,12.31C10.68,11.54 10.15,9.08 11.55,9.04C12.95,9 12.03,12.16 12.03,12.16C12.42,13.65 14.05,14.72 14.05,14.72C14.55,14.57 17.4,14.24 17,15.72C16.57,17.2 13.5,15.81 13.5,15.81C11.55,15.95 10.09,16.47 10.09,16.47C8.96,18.58 7.64,19.5 7.1,18.61C6.43,17.5 9.23,16.07 9.23,16.07C10.68,13.72 10.9,12.35 10.92,12.31M11.57,13.15C11.17,14.45 10.37,15.84 10.37,15.84C11.22,15.5 13.08,15.11 13.08,15.11C11.94,14.11 11.59,13.16 11.57,13.15M14.71,15.32C14.71,15.32 16.46,15.97 16.5,15.71C16.57,15.44 15.17,15.2 14.71,15.32M9.05,16.81C8.28,17.11 7.54,18.39 7.72,18.39C7.9,18.4 8.63,17.79 9.05,16.81M11.57,11.26C11.57,11.21 12,9.58 11.57,9.53C11.27,9.5 11.56,11.22 11.57,11.26Z\";\r\nvar mdiFilePercent = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M7.37,20L15,12.35L13.65,11L6,18.65L7.37,20M13,9H18.5L13,3.5V9M7.5,11A1.5,1.5 0 0,0 6,12.5A1.5,1.5 0 0,0 7.5,14A1.5,1.5 0 0,0 9,12.5A1.5,1.5 0 0,0 7.5,11M13.5,17A1.5,1.5 0 0,0 12,18.5A1.5,1.5 0 0,0 13.5,20A1.5,1.5 0 0,0 15,18.5A1.5,1.5 0 0,0 13.5,17Z\";\r\nvar mdiFilePercentOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M10 11.5C10 12.33 9.33 13 8.5 13S7 12.33 7 11.5 7.67 10 8.5 10 10 10.67 10 11.5M16 17.5C16 18.33 15.33 19 14.5 19S13 18.33 13 17.5 13.67 16 14.5 16 16 16.67 16 17.5M16 11.35L8.37 19L7 17.65L14.65 10L16 11.35Z\";\r\nvar mdiFilePhone = \"M14 2H6C4.89 2 4 2.89 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M17 19.44C17 19.75 16.75 20 16.44 20C11.23 20 7 15.77 7 10.56C7 10.25 7.25 10 7.56 10H9.5C9.81 10 10.06 10.25 10.06 10.56C10.06 11.25 10.17 11.92 10.37 12.54C10.43 12.73 10.39 12.95 10.23 13.11L9 14.33C9.81 15.9 11.1 17.19 12.67 18L13.9 16.77C14.05 16.61 14.27 16.57 14.46 16.63C15.08 16.83 15.75 16.95 16.45 16.95C16.75 16.95 17 17.19 17 17.5V19.44M13 9V3.5L18.5 9H13Z\";\r\nvar mdiFilePhoneOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M9 13.33C9.81 14.9 11.1 16.19 12.67 17L13.89 15.77C14.05 15.61 14.27 15.57 14.46 15.63C15.08 15.83 15.75 15.95 16.44 15.95C16.75 15.95 17 16.19 17 16.5V18.45C17 18.75 16.75 19 16.44 19C11.23 19 7 14.77 7 9.56C7 9.25 7.25 9 7.56 9H9.5C9.81 9 10.06 9.25 10.06 9.56C10.06 10.25 10.17 10.92 10.37 11.54C10.43 11.73 10.39 11.95 10.23 12.11L9 13.33Z\";\r\nvar mdiFilePlus = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M11,15V12H9V15H6V17H9V20H11V17H14V15H11Z\";\r\nvar mdiFilePlusOutline = \"M12,14V11H10V14H7V16H10V19H12V16H15V14M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M18,20H6V4H13V9H18\";\r\nvar mdiFilePowerpoint = \"M12.6,12.3H10.6V15.5H12.7C13.3,15.5 13.6,15.3 13.9,15C14.2,14.7 14.3,14.4 14.3,13.9C14.3,13.4 14.2,13.1 13.9,12.8C13.6,12.5 13.2,12.3 12.6,12.3M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M15.2,16C14.6,16.5 14.1,16.7 12.8,16.7H10.6V20H9V11H12.8C14.1,11 14.7,11.3 15.2,11.8C15.8,12.4 16,13 16,13.9C16,14.8 15.8,15.5 15.2,16M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFilePowerpointBox = \"M9.8,13.4H12.3C13.8,13.4 14.46,13.12 15.1,12.58C15.74,12.03 16,11.25 16,10.23C16,9.26 15.75,8.5 15.1,7.88C14.45,7.29 13.83,7 12.3,7H8V17H9.8V13.4M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5C3,3.89 3.9,3 5,3H19M9.8,12V8.4H12.1C12.76,8.4 13.27,8.65 13.6,9C13.93,9.35 14.1,9.72 14.1,10.24C14.1,10.8 13.92,11.19 13.6,11.5C13.28,11.81 12.9,12 12.22,12H9.8Z\";\r\nvar mdiFilePowerpointBoxOutline = \"M5 3C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3H5M5 5H19V19H5V5M15.1 7.88C14.45 7.29 13.83 7 12.3 7H8V17H9.8V13.4H12.3C13.8 13.4 14.46 13.12 15.1 12.58C15.74 12.03 16 11.25 16 10.23C16 9.26 15.75 8.5 15.1 7.88M13.6 11.5C13.28 11.81 12.9 12 12.22 12H9.8V8.4H12.1C12.76 8.4 13.27 8.65 13.6 9C13.93 9.35 14.1 9.72 14.1 10.24C14.1 10.8 13.92 11.19 13.6 11.5Z\";\r\nvar mdiFilePowerpointOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M15.2 10.8C14.7 10.3 14.1 10 12.8 10H9V19H10.6V15.7H12.8C14.1 15.7 14.6 15.5 15.2 15C15.8 14.5 16 13.8 16 12.9C16 12 15.8 11.4 15.2 10.8M13.9 14C13.6 14.3 13.3 14.5 12.7 14.5H10.6V11.3H12.6C13.2 11.3 13.6 11.5 13.9 11.8C14.2 12.1 14.3 12.4 14.3 12.9S14.2 13.7 13.9 14Z\";\r\nvar mdiFilePresentationBox = \"M19,16H5V8H19M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiFileQuestion = \"M6,2C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2H6M13,3.5L18.5,9H13V3.5M12,11A3,3 0 0,1 15,14C15,15.88 12.75,16.06 12.75,17.75H11.25C11.25,15.31 13.5,15.5 13.5,14A1.5,1.5 0 0,0 12,12.5A1.5,1.5 0 0,0 10.5,14H9A3,3 0 0,1 12,11M11.25,18.5H12.75V20H11.25V18.5Z\";\r\nvar mdiFileQuestionOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M15 13C15 14.89 12.75 15.07 12.75 16.76H11.25C11.25 14.32 13.5 14.5 13.5 13C13.5 12.18 12.83 11.5 12 11.5S10.5 12.18 10.5 13H9C9 11.35 10.34 10 12 10S15 11.35 15 13M12.75 17.5V19H11.25V17.5H12.75Z\";\r\nvar mdiFileRefresh = \"M18 14.5C19.11 14.5 20.11 14.95 20.83 15.67L22 14.5V18.5H18L19.77 16.73C19.32 16.28 18.69 16 18 16C16.62 16 15.5 17.12 15.5 18.5C15.5 19.88 16.62 21 18 21C18.82 21 19.54 20.61 20 20H21.71C21.12 21.47 19.68 22.5 18 22.5C15.79 22.5 14 20.71 14 18.5C14 16.29 15.79 14.5 18 14.5M13 9H18.5L13 3.5V9M6 2H14L20 8V12.17C19.5 12.06 19 12 18.5 12C14.91 12 12 14.91 12 18.5C12 19.79 12.37 21 13 22H6C4.88 22 4 21.1 4 20L4 4C4 2.89 4.89 2 6 2Z\";\r\nvar mdiFileRefreshOutline = \"M18 14.5C19.11 14.5 20.11 14.95 20.83 15.67L22 14.5V18.5H18L19.77 16.73C19.32 16.28 18.69 16 18 16C16.62 16 15.5 17.12 15.5 18.5C15.5 19.88 16.62 21 18 21C18.82 21 19.54 20.61 20 20H21.71C21.12 21.47 19.68 22.5 18 22.5C15.79 22.5 14 20.71 14 18.5C14 16.29 15.79 14.5 18 14.5M14 2L20 8V12.17C19.5 12.06 19 12 18.5 12L18 12V9H13V4H6V20H12.17C12.34 20.72 12.63 21.39 13 22H6C4.9 22 4 21.1 4 20V4C4 2.9 4.9 2 6 2H14Z\";\r\nvar mdiFileRemove = \"M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M13,9H18.5L13,3.5V9M10,14.59L7.88,12.46L6.46,13.88L8.59,16L6.46,18.12L7.88,19.54L10,17.41L12.12,19.54L13.54,18.12L11.41,16L13.54,13.88L12.12,12.46L10,14.59Z\";\r\nvar mdiFileRemoveOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M11.95 15.46L14.08 17.58L12.66 19L10.54 16.87L8.42 19L7 17.58L9.13 15.46L7 13.34L8.42 11.92L10.54 14.05L12.66 11.92L14.08 13.34L11.95 15.46Z\";\r\nvar mdiFileReplace = \"M14,12H19.5L14,6.5V12M8,5H15L21,11V21A2,2 0 0,1 19,23H8C6.89,23 6,22.1 6,21V18H11V20L15,17L11,14V16H6V7A2,2 0 0,1 8,5M13.5,3H4V16H6V18H4A2,2 0 0,1 2,16V3A2,2 0 0,1 4,1H11.5L13.5,3Z\";\r\nvar mdiFileReplaceOutline = \"M14,3L12,1H4A2,2 0 0,0 2,3V15A2,2 0 0,0 4,17H11V19L15,16L11,13V15H4V3H14M21,10V21A2,2 0 0,1 19,23H8A2,2 0 0,1 6,21V19H8V21H19V12H14V7H8V13H6V7A2,2 0 0,1 8,5H16L21,10Z\";\r\nvar mdiFileRestore = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M12,18C9.95,18 8.19,16.76 7.42,15H9.13C9.76,15.9 10.81,16.5 12,16.5A3.5,3.5 0 0,0 15.5,13A3.5,3.5 0 0,0 12,9.5C10.65,9.5 9.5,10.28 8.9,11.4L10.5,13H6.5V9L7.8,10.3C8.69,8.92 10.23,8 12,8A5,5 0 0,1 17,13A5,5 0 0,1 12,18Z\";\r\nvar mdiFileRestoreOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13L18 9V20M17 13.24C17 15.86 14.87 18 12.24 18C10.29 18 8.61 16.82 7.88 15.14H9.5C10.11 16 11.11 16.57 12.24 16.57C14.08 16.57 15.57 15.07 15.57 13.24S14.08 9.9 12.24 9.9C10.95 9.9 9.86 10.65 9.29 11.71L10.81 13.24H7V9.43L8.24 10.67C9.09 9.35 10.55 8.5 12.24 8.5C14.87 8.47 17 10.61 17 13.24Z\";\r\nvar mdiFileSearch = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H13C12.59,21.75 12.2,21.44 11.86,21.1C9.22,18.67 9.05,14.56 11.5,11.92C13.69,9.5 17.33,9.13 20,11V8L14,2M13,9V3.5L18.5,9H13M20.31,18.9C21.64,16.79 21,14 18.91,12.68C16.8,11.35 14,12 12.69,14.08C11.35,16.19 12,18.97 14.09,20.3C15.55,21.23 17.41,21.23 18.88,20.32L22,23.39L23.39,22L20.31,18.9M16.5,19A2.5,2.5 0 0,1 14,16.5A2.5,2.5 0 0,1 16.5,14A2.5,2.5 0 0,1 19,16.5A2.5,2.5 0 0,1 16.5,19Z\";\r\nvar mdiFileSearchOutline = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H13C12.59,21.75 12.2,21.44 11.86,21.1C11.53,20.77 11.25,20.4 11,20H6V4H13V9H18V10.18C18.71,10.34 19.39,10.61 20,11V8L14,2M20.31,18.9C21.64,16.79 21,14 18.91,12.68C16.8,11.35 14,12 12.69,14.08C11.35,16.19 12,18.97 14.09,20.3C15.55,21.23 17.41,21.23 18.88,20.32L22,23.39L23.39,22L20.31,18.9M16.5,19A2.5,2.5 0 0,1 14,16.5A2.5,2.5 0 0,1 16.5,14A2.5,2.5 0 0,1 19,16.5A2.5,2.5 0 0,1 16.5,19Z\";\r\nvar mdiFileSend = \"M14,2H6C4.89,2 4,2.89 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M12.54,19.37V17.37H8.54V15.38H12.54V13.38L15.54,16.38L12.54,19.37M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileSendOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M12.54 18.5V16.5H8.54V14.5H12.54V12.5L15.54 15.5L12.54 18.5Z\";\r\nvar mdiFileSettings = \"M6 0C4.89 0 4 .89 4 2V18A2 2 0 0 0 6 20H18A2 2 0 0 0 20 18V6L14 0H6M13 1.5L18.5 7H13V1.5M7 22V24H9V22H7M11 22V24H13V22H11M15 22V24H17V22H15Z\";\r\nvar mdiFileSettingsOutline = \"M6 0A2 2 0 0 0 4 2V18A2 2 0 0 0 6 20H18A2 2 0 0 0 20 18V6L14 0H6M6 2H13V7H18V18H6V2M7 22V24H9V22H7M11 22V24H13V22H11M15 22V24H17V22H15Z\";\r\nvar mdiFileStar = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M14.5 18.9L12 17.5L9.5 19L10.2 16.2L8 14.3L10.9 14.1L12 11.4L13.1 14L16 14.2L13.8 16.1L14.5 18.9M13 9V3.5L18.5 9H13Z\";\r\nvar mdiFileStarOutline = \"M14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V8L14 2M18 20H6V4H13V9H18V20M9.5 18L10.2 15.2L8 13.3L10.9 13.1L12 10.4L13.1 13L16 13.2L13.8 15.1L14.5 17.9L12 16.5L9.5 18Z\";\r\nvar mdiFileSwap = \"M14 2H6A2 2 0 0 0 4 4V20A2 2 0 0 0 6 22H18A2 2 0 0 0 20 20V8M14 18V16H10V18L7 15L10 12V14H14V12L17 15M13 9V3.5L18.5 9Z\";\r\nvar mdiFileSwapOutline = \"M17 15L14 12V14H10V12L7 15L10 18V16H14V18M14 2H6A2 2 0 0 0 4 4V20A2 2 0 0 0 6 22H18A2 2 0 0 0 20 20V8L14 2M18 20H6V4H13V9H18Z\";\r\nvar mdiFileSync = \"M11 17.5C11 13.9 13.9 11 17.5 11C18.4 11 19.2 11.2 20 11.5V8L14 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.9 22 6 22H12.8C11.7 20.8 11 19.2 11 17.5M13 3.5L18.5 9H13V3.5M17 12V13.5C19.2 13.5 21 15.3 21 17.5C21 18.3 20.8 19.1 20.3 19.7L19.2 18.6C19.4 18.3 19.5 17.9 19.5 17.5C19.5 16.1 18.4 15 17 15V16.5L14.8 14.3L17 12M17 23V21.5C14.8 21.5 13 19.7 13 17.5C13 16.7 13.2 15.9 13.7 15.3L14.8 16.4C14.6 16.7 14.5 17.1 14.5 17.5C14.5 18.9 15.6 20 17 20V18.5L19.2 20.7L17 23Z\";\r\nvar mdiFileSyncOutline = \"M12.8 22H6C4.9 22 4 21.1 4 20V4C4 2.9 4.9 2 6 2H14L20 8V11.5C19.4 11.2 18.7 11.1 18 11V9H13V4H6V20H11.5C11.8 20.7 12.3 21.4 12.8 22M17 12L14.8 14.2L17 16.4V15C18.4 15 19.5 16.1 19.5 17.5C19.5 17.9 19.4 18.3 19.2 18.6L20.3 19.7C20.7 19.1 21 18.3 21 17.5C21 15.3 19.2 13.5 17 13.5V12M19.2 20.8L17 18.5V20C15.6 20 14.5 18.9 14.5 17.5C14.5 17.1 14.6 16.7 14.8 16.4L13.7 15.3C13.3 15.9 13 16.7 13 17.5C13 19.7 14.8 21.5 17 21.5V23L19.2 20.8Z\";\r\nvar mdiFileTable = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M10,19H7V17H10V19M10,16H7V14H10V16M10,13H7V11H10V13M14,19H11V17H14V19M14,16H11V14H14V16M14,13H11V11H14V13M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileTableBox = \"M19 3H5C3.89 3 3 3.89 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.89 20.1 3 19 3M9 18H6V16H9V18M9 15H6V13H9V15M9 12H6V10H9V12M13 18H10V16H13V18M13 15H10V13H13V15M13 12H10V10H13V12Z\";\r\nvar mdiFileTableBoxMultiple = \"M3 5V21H19V23H3C1.9 23 1 22.1 1 21V5H3M21 1H7C5.89 1 5 1.89 5 3V17C5 18.11 5.9 19 7 19H21C22.11 19 23 18.11 23 17V3C23 1.89 22.1 1 21 1M11 16H8V14H11V16M11 13H8V11H11V13M11 10H8V8H11V10M15 16H12V14H15V16M15 13H12V11H15V13M15 10H12V8H15V10Z\";\r\nvar mdiFileTableBoxMultipleOutline = \"M3 5V21H19V23H3C1.9 23 1 22.1 1 21V5H3M21 1H7C5.89 1 5 1.89 5 3V17C5 18.1 5.9 19 7 19H21C22.11 19 23 18.11 23 17V3C23 1.9 22.1 1 21 1M21 17H7V3H21V17M11 14H8V16H11V14M15 14H12V16H15V14M11 11H8V13H11V11M15 11H12V13H15V11M11 8H8V10H11V8M15 8H12V10H15V8Z\";\r\nvar mdiFileTableBoxOutline = \"M19 3H5C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3M19 19H5V5H19V19M9 18H6V16H9V18M13 18H10V16H13V18M9 15H6V13H9V15M13 15H10V13H13V15M9 12H6V10H9V12M13 12H10V10H13V12Z\";\r\nvar mdiFileTableOutline = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M18,20H6V4H13V9H18V20M10,13H7V11H10V13M14,13H11V11H14V13M10,16H7V14H10V16M14,16H11V14H14V16M10,19H7V17H10V19M14,19H11V17H14V19Z\";\r\nvar mdiFileTree = \"M3,3H9V7H3V3M15,10H21V14H15V10M15,17H21V21H15V17M13,13H7V18H13V20H7L5,20V9H7V11H13V13Z\";\r\nvar mdiFileTreeOutline = \"M12 13H7V18H12V20H5V10H7V11H12V13M8 4V6H4V4H8M10 2H2V8H10V2M20 11V13H16V11H20M22 9H14V15H22V9M20 18V20H16V18H20M22 16H14V22H22V16Z\";\r\nvar mdiFileUndo = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M12.16,14.31C10.6,14.31 9.19,14.89 8.11,15.83L6,13.72V19H11.28L9.15,16.88C9.97,16.2 11,15.78 12.16,15.78C14.23,15.78 16,17.13 16.61,19L18,18.54C17.19,16.09 14.88,14.31 12.16,14.31Z\";\r\nvar mdiFileUndoOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M17 17.61L15.84 18C15.33 16.44 13.86 15.31 12.13 15.31C11.17 15.31 10.31 15.66 9.63 16.23L11.4 18H7V13.6L8.76 15.36C9.66 14.57 10.83 14.09 12.13 14.09C14.4 14.09 16.33 15.57 17 17.61Z\";\r\nvar mdiFileUpload = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M13.5,16V19H10.5V16H8L12,12L16,16H13.5M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileUploadOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M12,12L16,16H13.5V19H10.5V16H8L12,12Z\";\r\nvar mdiFileVideo = \"M13,9H18.5L13,3.5V9M6,2H14L20,8V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V4C4,2.89 4.89,2 6,2M17,19V13L14,15.2V13H7V19H14V16.8L17,19Z\";\r\nvar mdiFileVideoOutline = \"M14,2L20,8V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2H14M18,20V9H13V4H6V20H18M16,18L13.5,16.3V18H8V13H13.5V14.7L16,13V18Z\";\r\nvar mdiFileWord = \"M14,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V8L14,2M15.2,20H13.8L12,13.2L10.2,20H8.8L6.6,11H8.1L9.5,17.8L11.3,11H12.6L14.4,17.8L15.8,11H17.3L15.2,20M13,9V3.5L18.5,9H13Z\";\r\nvar mdiFileWordBox = \"M15.5,17H14L12,9.5L10,17H8.5L6.1,7H7.8L9.34,14.5L11.3,7H12.7L14.67,14.5L16.2,7H17.9M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiFileWordBoxOutline = \"M5 3C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3H5M5 5H19V19H5V5M17.9 7L15.5 17H14L12 9.5L10 17H8.5L6.1 7H7.8L9.34 14.5L11.3 7H12.7L14.67 14.5L16.2 7H17.9Z\";\r\nvar mdiFileWordOutline = \"M14 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V8L14 2M18 20H6V4H13V9H18V20M17.35 10L15.25 19H13.85L12.05 12.21L10.25 19H8.85L6.65 10H8.15L9.55 16.81L11.35 10H12.65L14.45 16.81L15.85 10H17.35Z\";\r\nvar mdiFilm = \"M3.5,3H5V1.8C5,1.36 5.36,1 5.8,1H10.2C10.64,1 11,1.36 11,1.8V3H12.5A1.5,1.5 0 0,1 14,4.5V5H22V20H14V20.5A1.5,1.5 0 0,1 12.5,22H3.5A1.5,1.5 0 0,1 2,20.5V4.5A1.5,1.5 0 0,1 3.5,3M18,7V9H20V7H18M14,7V9H16V7H14M10,7V9H12V7H10M14,16V18H16V16H14M18,16V18H20V16H18M10,16V18H12V16H10Z\";\r\nvar mdiFilmstrip = \"M18,9H16V7H18M18,13H16V11H18M18,17H16V15H18M8,9H6V7H8M8,13H6V11H8M8,17H6V15H8M18,3V5H16V3H8V5H6V3H4V21H6V19H8V21H16V19H18V21H20V3H18Z\";\r\nvar mdiFilmstripBox = \"M19 3C20.1 3 21 3.9 21 5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H19M7 18V16H5V18H7M7 13V11H5V13H7M7 8V6H5V8H7M19 18V16H17V18H19M19 13V11H17V13H19M19 8V6H17V8H19Z\";\r\nvar mdiFilmstripBoxMultiple = \"M4,6H2V20A2,2 0 0,0 4,22H18V20H4V6M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M10,15H8V13H10V15M10,11H8V9H10V11M10,7H8V5H10V7M20,15H18V13H20V15M20,11H18V9H20V11M20,7H18V5H20V7Z\";\r\nvar mdiFilmstripOff = \"M1,4.27L2.28,3L21,21.72L19.73,23L16,19.27V21H8V19H6V21H4V7.27L1,4.27M18,9V7H16V9H18M18,13V11H16V13H18M18,15H16.82L6.82,5H8V3H16V5H18V3H20V18.18L18,16.18V15M8,13V11.27L7.73,11H6V13H8M8,17V15H6V17H8M6,3V4.18L4.82,3H6Z\";\r\nvar mdiFilter = \"M14,12V19.88C14.04,20.18 13.94,20.5 13.71,20.71C13.32,21.1 12.69,21.1 12.3,20.71L10.29,18.7C10.06,18.47 9.96,18.16 10,17.87V12H9.97L4.21,4.62C3.87,4.19 3.95,3.56 4.38,3.22C4.57,3.08 4.78,3 5,3V3H19V3C19.22,3 19.43,3.08 19.62,3.22C20.05,3.56 20.13,4.19 19.79,4.62L14.03,12H14Z\";\r\nvar mdiFilterMenu = \"M11 11L16.76 3.62A1 1 0 0 0 16.59 2.22A1 1 0 0 0 16 2H2A1 1 0 0 0 1.38 2.22A1 1 0 0 0 1.21 3.62L7 11V16.87A1 1 0 0 0 7.29 17.7L9.29 19.7A1 1 0 0 0 10.7 19.7A1 1 0 0 0 11 18.87V11M13 16L18 21L23 16Z\";\r\nvar mdiFilterMenuOutline = \"M12 18.88A1 1 0 0 1 11.71 19.71A1 1 0 0 1 10.3 19.71L6.3 15.71A1 1 0 0 1 6 14.87V9.75L1.21 3.62A1 1 0 0 1 1.38 2.22A1 1 0 0 1 2 2H16A1 1 0 0 1 16.62 2.22A1 1 0 0 1 16.79 3.62L12 9.75V18.88M4 4L8 9.06V14.58L10 16.58V9.05L14 4M13 16L18 21L23 16Z\";\r\nvar mdiFilterMinus = \"M12 12V19.88C12.04 20.18 11.94 20.5 11.71 20.71C11.32 21.1 10.69 21.1 10.3 20.71L8.29 18.7C8.06 18.47 7.96 18.16 8 17.86V12H7.97L2.21 4.62C1.87 4.19 1.95 3.56 2.38 3.22C2.57 3.08 2.78 3 3 3V3H17V3C17.22 3 17.43 3.08 17.62 3.22C18.05 3.56 18.13 4.19 17.79 4.62L12.03 12H12M15 17H23V19H15V17Z\";\r\nvar mdiFilterMinusOutline = \"M15 17H23V19H15V17M13 19.88C13.04 20.18 12.94 20.5 12.72 20.71C12.32 21.1 11.69 21.1 11.3 20.71L7.29 16.7C7.06 16.47 6.96 16.16 7 15.87V10.75L2.21 4.62C1.87 4.19 1.95 3.56 2.38 3.22C2.57 3.08 2.78 3 3 3V3H17V3C17.22 3 17.43 3.08 17.62 3.22C18.05 3.56 18.13 4.19 17.79 4.62L13 10.75V19.88M5.04 5L9 10.07V15.58L11 17.58V10.05L14.96 5H5.04Z\";\r\nvar mdiFilterOff = \"M2.39 1.73L1.11 3L9.5 11.37L9.97 12H10V17.87C9.96 18.16 10.06 18.47 10.29 18.7L12.3 20.71C12.69 21.1 13.32 21.1 13.71 20.71C13.94 20.5 14.04 20.18 14 19.88V15.89L20.84 22.73L22.11 21.46L14 13.35L9.41 8.76L4.15 3.5L2.39 1.73M6.21 3L14.54 11.34L19.79 4.62C20.13 4.19 20.05 3.56 19.62 3.22C19.43 3.08 19.22 3 19 3H6.21Z\";\r\nvar mdiFilterOffOutline = \"M2.39 1.73L1.11 3L9 10.89V15.87C8.96 16.16 9.06 16.47 9.29 16.7L13.3 20.71C13.69 21.1 14.32 21.1 14.71 20.71C14.94 20.5 15.04 20.18 15 19.88V16.89L20.84 22.73L22.11 21.46L15 14.35V14.34L13 12.35L11 10.34L4.15 3.5L2.39 1.73M6.21 3L8.2 5H16.96L13.11 9.91L15 11.8V10.75L19.79 4.62C20.13 4.19 20.05 3.56 19.62 3.22C19.43 3.08 19.22 3 19 3H6.21M11 12.89L13 14.89V17.58L11 15.58V12.89Z\";\r\nvar mdiFilterOutline = \"M15,19.88C15.04,20.18 14.94,20.5 14.71,20.71C14.32,21.1 13.69,21.1 13.3,20.71L9.29,16.7C9.06,16.47 8.96,16.16 9,15.87V10.75L4.21,4.62C3.87,4.19 3.95,3.56 4.38,3.22C4.57,3.08 4.78,3 5,3V3H19V3C19.22,3 19.43,3.08 19.62,3.22C20.05,3.56 20.13,4.19 19.79,4.62L15,10.75V19.88M7.04,5L11,10.06V15.58L13,17.58V10.05L16.96,5H7.04Z\";\r\nvar mdiFilterPlus = \"M12 12V19.88C12.04 20.18 11.94 20.5 11.71 20.71C11.32 21.1 10.69 21.1 10.3 20.71L8.29 18.7C8.06 18.47 7.96 18.16 8 17.87V12H7.97L2.21 4.62C1.87 4.19 1.95 3.56 2.38 3.22C2.57 3.08 2.78 3 3 3H17C17.22 3 17.43 3.08 17.62 3.22C18.05 3.56 18.13 4.19 17.79 4.62L12.03 12H12M15 17H18V14H20V17H23V19H20V22H18V19H15V17Z\";\r\nvar mdiFilterPlusOutline = \"M15 17H18V14H20V17H23V19H20V22H18V19H15V17M13 19.88C13.04 20.18 12.94 20.5 12.72 20.71C12.32 21.1 11.69 21.1 11.3 20.71L7.29 16.7C7.06 16.47 6.96 16.16 7 15.87V10.75L2.21 4.62C1.87 4.19 1.95 3.56 2.38 3.22C2.57 3.08 2.78 3 3 3V3H17V3C17.22 3 17.43 3.08 17.62 3.22C18.05 3.56 18.13 4.19 17.79 4.62L13 10.75V19.88M5.04 5L9 10.07V15.58L11 17.58V10.05L14.96 5H5.04Z\";\r\nvar mdiFilterRemove = \"M14.76,20.83L17.6,18L14.76,15.17L16.17,13.76L19,16.57L21.83,13.76L23.24,15.17L20.43,18L23.24,20.83L21.83,22.24L19,19.4L16.17,22.24L14.76,20.83M12,12V19.88C12.04,20.18 11.94,20.5 11.71,20.71C11.32,21.1 10.69,21.1 10.3,20.71L8.29,18.7C8.06,18.47 7.96,18.16 8,17.87V12H7.97L2.21,4.62C1.87,4.19 1.95,3.56 2.38,3.22C2.57,3.08 2.78,3 3,3V3H17V3C17.22,3 17.43,3.08 17.62,3.22C18.05,3.56 18.13,4.19 17.79,4.62L12.03,12H12Z\";\r\nvar mdiFilterRemoveOutline = \"M14.73,20.83L17.58,18L14.73,15.17L16.15,13.76L19,16.57L21.8,13.76L23.22,15.17L20.41,18L23.22,20.83L21.8,22.24L19,19.4L16.15,22.24L14.73,20.83M13,19.88C13.04,20.18 12.94,20.5 12.71,20.71C12.32,21.1 11.69,21.1 11.3,20.71L7.29,16.7C7.06,16.47 6.96,16.16 7,15.87V10.75L2.21,4.62C1.87,4.19 1.95,3.56 2.38,3.22C2.57,3.08 2.78,3 3,3V3H17V3C17.22,3 17.43,3.08 17.62,3.22C18.05,3.56 18.13,4.19 17.79,4.62L13,10.75V19.88M5.04,5L9,10.06V15.58L11,17.58V10.05L14.96,5H5.04Z\";\r\nvar mdiFilterVariant = \"M6,13H18V11H6M3,6V8H21V6M10,18H14V16H10V18Z\";\r\nvar mdiFilterVariantMinus = \"M21 8H3V6H21V8M13.81 16H10V18H13.09C13.21 17.28 13.46 16.61 13.81 16M18 11H6V13H18V11M23 18H15V20H23V18Z\";\r\nvar mdiFilterVariantPlus = \"M21 8H3V6H21V8M13.81 16H10V18H13.09C13.21 17.28 13.46 16.61 13.81 16M18 11H6V13H18V11M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiFilterVariantRemove = \"M21 8H3V6H21V8M13.81 16H10V18H13.09C13.21 17.28 13.46 16.61 13.81 16M18 11H6V13H18V11M21.12 15.46L19 17.59L16.88 15.46L15.47 16.88L17.59 19L15.47 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88L21.12 15.46Z\";\r\nvar mdiFinance = \"M6,16.5L3,19.44V11H6M11,14.66L9.43,13.32L8,14.64V7H11M16,13L13,16V3H16M18.81,12.81L17,11H22V16L20.21,14.21L13,21.36L9.53,18.34L5.75,22H3L9.47,15.66L13,18.64\";\r\nvar mdiFindReplace = \"M11,6C12.38,6 13.63,6.56 14.54,7.46L12,10H18V4L15.95,6.05C14.68,4.78 12.93,4 11,4C7.47,4 4.57,6.61 4.08,10H6.1C6.56,7.72 8.58,6 11,6M16.64,15.14C17.3,14.24 17.76,13.17 17.92,12H15.9C15.44,14.28 13.42,16 11,16C9.62,16 8.37,15.44 7.46,14.54L10,12H4V18L6.05,15.95C7.32,17.22 9.07,18 11,18C12.55,18 14,17.5 15.14,16.64L20,21.5L21.5,20L16.64,15.14Z\";\r\nvar mdiFingerprint = \"M17.81,4.47C17.73,4.47 17.65,4.45 17.58,4.41C15.66,3.42 14,3 12,3C10.03,3 8.15,3.47 6.44,4.41C6.2,4.54 5.9,4.45 5.76,4.21C5.63,3.97 5.72,3.66 5.96,3.53C7.82,2.5 9.86,2 12,2C14.14,2 16,2.47 18.04,3.5C18.29,3.65 18.38,3.95 18.25,4.19C18.16,4.37 18,4.47 17.81,4.47M3.5,9.72C3.4,9.72 3.3,9.69 3.21,9.63C3,9.47 2.93,9.16 3.09,8.93C4.08,7.53 5.34,6.43 6.84,5.66C10,4.04 14,4.03 17.15,5.65C18.65,6.42 19.91,7.5 20.9,8.9C21.06,9.12 21,9.44 20.78,9.6C20.55,9.76 20.24,9.71 20.08,9.5C19.18,8.22 18.04,7.23 16.69,6.54C13.82,5.07 10.15,5.07 7.29,6.55C5.93,7.25 4.79,8.25 3.89,9.5C3.81,9.65 3.66,9.72 3.5,9.72M9.75,21.79C9.62,21.79 9.5,21.74 9.4,21.64C8.53,20.77 8.06,20.21 7.39,19C6.7,17.77 6.34,16.27 6.34,14.66C6.34,11.69 8.88,9.27 12,9.27C15.12,9.27 17.66,11.69 17.66,14.66A0.5,0.5 0 0,1 17.16,15.16A0.5,0.5 0 0,1 16.66,14.66C16.66,12.24 14.57,10.27 12,10.27C9.43,10.27 7.34,12.24 7.34,14.66C7.34,16.1 7.66,17.43 8.27,18.5C8.91,19.66 9.35,20.15 10.12,20.93C10.31,21.13 10.31,21.44 10.12,21.64C10,21.74 9.88,21.79 9.75,21.79M16.92,19.94C15.73,19.94 14.68,19.64 13.82,19.05C12.33,18.04 11.44,16.4 11.44,14.66A0.5,0.5 0 0,1 11.94,14.16A0.5,0.5 0 0,1 12.44,14.66C12.44,16.07 13.16,17.4 14.38,18.22C15.09,18.7 15.92,18.93 16.92,18.93C17.16,18.93 17.56,18.9 17.96,18.83C18.23,18.78 18.5,18.96 18.54,19.24C18.59,19.5 18.41,19.77 18.13,19.82C17.56,19.93 17.06,19.94 16.92,19.94M14.91,22C14.87,22 14.82,22 14.78,22C13.19,21.54 12.15,20.95 11.06,19.88C9.66,18.5 8.89,16.64 8.89,14.66C8.89,13.04 10.27,11.72 11.97,11.72C13.67,11.72 15.05,13.04 15.05,14.66C15.05,15.73 16,16.6 17.13,16.6C18.28,16.6 19.21,15.73 19.21,14.66C19.21,10.89 15.96,7.83 11.96,7.83C9.12,7.83 6.5,9.41 5.35,11.86C4.96,12.67 4.76,13.62 4.76,14.66C4.76,15.44 4.83,16.67 5.43,18.27C5.53,18.53 5.4,18.82 5.14,18.91C4.88,19 4.59,18.87 4.5,18.62C4,17.31 3.77,16 3.77,14.66C3.77,13.46 4,12.37 4.45,11.42C5.78,8.63 8.73,6.82 11.96,6.82C16.5,6.82 20.21,10.33 20.21,14.65C20.21,16.27 18.83,17.59 17.13,17.59C15.43,17.59 14.05,16.27 14.05,14.65C14.05,13.58 13.12,12.71 11.97,12.71C10.82,12.71 9.89,13.58 9.89,14.65C9.89,16.36 10.55,17.96 11.76,19.16C12.71,20.1 13.62,20.62 15.03,21C15.3,21.08 15.45,21.36 15.38,21.62C15.33,21.85 15.12,22 14.91,22Z\";\r\nvar mdiFingerprintOff = \"M1.5,4.77L2.78,3.5L20.5,21.22L19.23,22.5L16.67,19.94C15.58,19.9 14.62,19.6 13.82,19.05C12.34,18.05 11.46,16.43 11.44,14.71L10.27,13.53C10.03,13.85 9.89,14.23 9.89,14.65C9.89,16.36 10.55,17.96 11.76,19.16C12.71,20.1 13.62,20.62 15.03,21C15.3,21.08 15.45,21.36 15.38,21.62C15.33,21.85 15.12,22 14.91,22H14.78C13.19,21.54 12.15,20.95 11.06,19.88C9.66,18.5 8.89,16.64 8.89,14.66C8.89,13.97 9.14,13.33 9.56,12.83L8.5,11.77C7.78,12.54 7.34,13.55 7.34,14.66C7.34,16.1 7.66,17.43 8.27,18.5C8.91,19.66 9.35,20.15 10.12,20.93C10.31,21.13 10.31,21.44 10.12,21.64C10,21.74 9.88,21.79 9.75,21.79C9.62,21.79 9.5,21.74 9.4,21.64C8.53,20.77 8.06,20.21 7.39,19C6.7,17.77 6.34,16.27 6.34,14.66C6.34,13.28 6.89,12 7.79,11.06L6.7,9.97C6.15,10.5 5.69,11.15 5.35,11.86C4.96,12.67 4.76,13.62 4.76,14.66C4.76,15.44 4.83,16.67 5.43,18.27C5.53,18.53 5.4,18.82 5.14,18.91C4.88,19 4.59,18.87 4.5,18.62C4,17.31 3.77,16 3.77,14.66C3.77,13.46 4,12.37 4.45,11.42C4.84,10.61 5.36,9.88 6,9.26L4.97,8.24C4.58,8.63 4.22,9.05 3.89,9.5C3.81,9.65 3.66,9.72 3.5,9.72L3.21,9.63C3,9.47 2.93,9.16 3.09,8.93C3.45,8.43 3.84,7.96 4.27,7.53L1.5,4.77M17.81,4.47L17.58,4.41C15.66,3.42 14,3 12,3C10.03,3 8.15,3.47 6.44,4.41L6.29,4.46L5.71,3.89C5.73,3.74 5.82,3.61 5.96,3.53C7.82,2.5 9.86,2 12,2C14.14,2 16,2.47 18.04,3.5C18.29,3.65 18.38,3.95 18.25,4.19C18.16,4.37 18,4.47 17.81,4.47M17.15,5.65C18.65,6.42 19.91,7.5 20.9,8.9C21.06,9.12 21,9.44 20.78,9.6C20.55,9.76 20.24,9.71 20.08,9.5C19.18,8.22 18.04,7.23 16.69,6.54C14.06,5.19 10.76,5.08 8.03,6.21L7.27,5.45C10.34,4.04 14.14,4.1 17.15,5.65M12,9.27C15.12,9.27 17.66,11.69 17.66,14.66A0.5,0.5 0 0,1 17.16,15.16L16.93,15.11L16.72,14.89L16.66,14.66C16.66,12.27 14.62,10.32 12.09,10.27L11.15,9.33L12,9.27M14.38,18.22C14.71,18.45 15.07,18.62 15.47,18.73L12.63,15.9C12.92,16.82 13.53,17.65 14.38,18.22M19.21,14.66C19.21,10.89 15.96,7.83 11.96,7.83C11.26,7.83 10.58,7.93 9.93,8.11L9.12,7.3C10,7 10.97,6.82 11.96,6.82C16.5,6.82 20.21,10.33 20.21,14.65C20.21,15.65 19.69,16.53 18.89,17.06L18.17,16.34C18.79,16 19.21,15.38 19.21,14.66Z\";\r\nvar mdiFire = \"M17.66 11.2C17.43 10.9 17.15 10.64 16.89 10.38C16.22 9.78 15.46 9.35 14.82 8.72C13.33 7.26 13 4.85 13.95 3C13 3.23 12.17 3.75 11.46 4.32C8.87 6.4 7.85 10.07 9.07 13.22C9.11 13.32 9.15 13.42 9.15 13.55C9.15 13.77 9 13.97 8.8 14.05C8.57 14.15 8.33 14.09 8.14 13.93C8.08 13.88 8.04 13.83 8 13.76C6.87 12.33 6.69 10.28 7.45 8.64C5.78 10 4.87 12.3 5 14.47C5.06 14.97 5.12 15.47 5.29 15.97C5.43 16.57 5.7 17.17 6 17.7C7.08 19.43 8.95 20.67 10.96 20.92C13.1 21.19 15.39 20.8 17.03 19.32C18.86 17.66 19.5 15 18.56 12.72L18.43 12.46C18.22 12 17.66 11.2 17.66 11.2M14.5 17.5C14.22 17.74 13.76 18 13.4 18.1C12.28 18.5 11.16 17.94 10.5 17.28C11.69 17 12.4 16.12 12.61 15.23C12.78 14.43 12.46 13.77 12.33 13C12.21 12.26 12.23 11.63 12.5 10.94C12.69 11.32 12.89 11.7 13.13 12C13.9 13 15.11 13.44 15.37 14.8C15.41 14.94 15.43 15.08 15.43 15.23C15.46 16.05 15.1 16.95 14.5 17.5H14.5Z\";\r\nvar mdiFireAlert = \"M15.66 11.2C15.43 10.9 15.15 10.64 14.89 10.38C14.22 9.78 13.46 9.35 12.82 8.72C11.33 7.26 11 4.85 11.95 3C11 3.23 10.17 3.75 9.46 4.32C6.87 6.4 5.85 10.07 7.07 13.22C7.11 13.32 7.15 13.42 7.15 13.55C7.15 13.77 7 13.97 6.8 14.05C6.57 14.15 6.33 14.09 6.14 13.93C6.08 13.88 6.04 13.83 6 13.76C4.87 12.33 4.69 10.28 5.45 8.64C3.78 10 2.87 12.3 3 14.47C3.06 14.97 3.12 15.47 3.29 15.97C3.43 16.57 3.7 17.17 4 17.7C5.08 19.43 6.95 20.67 8.96 20.92C11.1 21.19 13.39 20.8 15.03 19.32C16.86 17.66 17.5 15 16.56 12.72L16.43 12.46C16.22 12 15.66 11.2 15.66 11.2M12.5 17.5C12.22 17.74 11.76 18 11.4 18.1C10.28 18.5 9.16 17.94 8.5 17.28C9.69 17 10.4 16.12 10.61 15.23C10.78 14.43 10.46 13.77 10.33 13C10.21 12.26 10.23 11.63 10.5 10.94C10.69 11.32 10.89 11.7 11.13 12C11.9 13 13.11 13.44 13.37 14.8C13.41 14.94 13.43 15.08 13.43 15.23C13.46 16.05 13.1 16.95 12.5 17.5H12.5M21 13H19V7H21V13M21 17H19V15H21V17Z\";\r\nvar mdiFireExtinguisher = \"M10.5,7H11.75L12,5H10.25L6,7.5V9H4V6.5L10,3H12V2H14V3H16L17,2.5V5.5L16,5H14L14.25,7H15.5A1.5,1.5 0 0,1 17,8.5V22H9V8.5A1.5,1.5 0 0,1 10.5,7Z\";\r\nvar mdiFireHydrant = \"M5 15V14H4V12H5V11H7V15H5M19 12V11H17V15H19V14H20V12H19M18 6H15.86C15.5 4.6 14.4 3.5 13 3.14V2H11V3.14C9.6 3.5 8.5 4.6 8.14 6H6V8H18V6M18 22H6C6 20.9 6.9 20 8 20V9H16V20C17.11 20 18 20.9 18 22M10 13C10 14.11 10.9 15 12 15S14 14.11 14 13 13.11 11 12 11 10 11.9 10 13Z\";\r\nvar mdiFireHydrantAlert = \"M22 7H20V13H22V7M22 15H20V17H22V15M3 15V14H2V12H3V11H5V15H3M17 12V11H15V15H17V14H18V12H17M16 6H13.86C13.5 4.6 12.4 3.5 11 3.14V2H9V3.14C7.6 3.5 6.5 4.6 6.14 6H4V8H16V6M16 22H4C4 20.9 4.89 20 6 20V9H14V20C15.11 20 16 20.9 16 22M8 13C8 14.11 8.9 15 10 15S12 14.11 12 13 11.11 11 10 11 8 11.9 8 13Z\";\r\nvar mdiFireHydrantOff = \"M20.84 22.73L22.11 21.46L2.39 1.73L1.11 3L8 9.89V20C6.9 20 6 20.9 6 22H18C18 20.9 17.11 20 16 20V17.89L20.84 22.73M10.22 12.11L12.89 14.78C12.62 14.92 12.32 15 12 15C10.9 15 10 14.11 10 13C10 12.68 10.08 12.38 10.22 12.11M11.2 8L8.44 5.24C8.94 4.21 9.87 3.43 11 3.14V2H13V3.14C14.4 3.5 15.5 4.6 15.86 6H18V8H11.2M19 11V12H20V14H19V15H18.2L17 13.8V11H19M5 15V14H4V12H5V11H7V15H5M16 12.8L12.2 9H16V12.8Z\";\r\nvar mdiFireTruck = \"M17.04,2C16.85,2 16.66,2.04 16.5,2.14L5.59,8.5H9.55L17.5,3.86C18,3.58 18.13,2.97 17.85,2.5C17.68,2.2 17.38,2 17.04,2M16,8V10H3A2,2 0 0,0 1,12H2V15H1V19H3A3,3 0 0,0 6,22A3,3 0 0,0 9,19H15A3,3 0 0,0 18,22A3,3 0 0,0 21,19H23V12.5L19.5,8H16M18,9.5H19L21.5,12.5V13.5H18V9.5M4,12H7V15H4V12M9,12H12V15H9V12M14,12H16V15H14V12M6,17.5A1.5,1.5 0 0,1 7.5,19A1.5,1.5 0 0,1 6,20.5A1.5,1.5 0 0,1 4.5,19A1.5,1.5 0 0,1 6,17.5M18,17.5A1.5,1.5 0 0,1 19.5,19A1.5,1.5 0 0,1 18,20.5A1.5,1.5 0 0,1 16.5,19A1.5,1.5 0 0,1 18,17.5Z\";\r\nvar mdiFirebase = \"M20,18.69L12.7,22.74C12.2,23 11.7,23 11.2,22.74L4,18.69L17.05,5.54L17.4,5.44C17.7,5.44 17.87,5.57 17.9,5.84L20,18.69M9.35,5.74L4.8,13.29L6.7,1.34C6.73,1.07 6.9,0.94 7.2,0.94C7.4,0.94 7.53,1 7.6,1.19L9.75,5.14L9.35,5.74M13.85,7L4.3,16.59L11.55,4.29C11.65,4.09 11.8,4 12,4C12.2,4 12.33,4.09 12.4,4.29L13.85,7Z\";\r\nvar mdiFirefox = \"M9.27 7.94C9.27 7.94 9.27 7.94 9.27 7.94M6.85 6.74C6.86 6.74 6.86 6.74 6.85 6.74M21.28 8.6C20.85 7.55 19.96 6.42 19.27 6.06C19.83 7.17 20.16 8.28 20.29 9.1L20.29 9.12C19.16 6.3 17.24 5.16 15.67 2.68C15.59 2.56 15.5 2.43 15.43 2.3C15.39 2.23 15.36 2.16 15.32 2.09C15.26 1.96 15.2 1.83 15.17 1.69C15.17 1.68 15.16 1.67 15.15 1.67H15.13L15.12 1.67L15.12 1.67L15.12 1.67C12.9 2.97 11.97 5.26 11.74 6.71C11.05 6.75 10.37 6.92 9.75 7.22C9.63 7.27 9.58 7.41 9.62 7.53C9.67 7.67 9.83 7.74 9.96 7.68C10.5 7.42 11.1 7.27 11.7 7.23L11.75 7.23C11.83 7.22 11.92 7.22 12 7.22C12.5 7.21 12.97 7.28 13.44 7.42L13.5 7.44C13.6 7.46 13.67 7.5 13.75 7.5C13.8 7.54 13.86 7.56 13.91 7.58L14.05 7.64C14.12 7.67 14.19 7.7 14.25 7.73C14.28 7.75 14.31 7.76 14.34 7.78C14.41 7.82 14.5 7.85 14.54 7.89C14.58 7.91 14.62 7.94 14.66 7.96C15.39 8.41 16 9.03 16.41 9.77C15.88 9.4 14.92 9.03 14 9.19C17.6 11 16.63 17.19 11.64 16.95C11.2 16.94 10.76 16.85 10.34 16.7C10.24 16.67 10.14 16.63 10.05 16.58C10 16.56 9.93 16.53 9.88 16.5C8.65 15.87 7.64 14.68 7.5 13.23C7.5 13.23 8 11.5 10.83 11.5C11.14 11.5 12 10.64 12.03 10.4C12.03 10.31 10.29 9.62 9.61 8.95C9.24 8.59 9.07 8.42 8.92 8.29C8.84 8.22 8.75 8.16 8.66 8.1C8.43 7.3 8.42 6.45 8.63 5.65C7.6 6.12 6.8 6.86 6.22 7.5H6.22C5.82 7 5.85 5.35 5.87 5C5.86 5 5.57 5.16 5.54 5.18C5.19 5.43 4.86 5.71 4.56 6C4.21 6.37 3.9 6.74 3.62 7.14C3 8.05 2.5 9.09 2.28 10.18C2.28 10.19 2.18 10.59 2.11 11.1L2.08 11.33C2.06 11.5 2.04 11.65 2 11.91L2 11.94L2 12.27L2 12.32C2 17.85 6.5 22.33 12 22.33C16.97 22.33 21.08 18.74 21.88 14C21.9 13.89 21.91 13.76 21.93 13.63C22.13 11.91 21.91 10.11 21.28 8.6Z\";\r\nvar mdiFireplace = \"M22,22H2V20H22V22M22,6H2V3H22V6M20,7V19H17V11C17,11 14.5,10 12,10C9.5,10 7,11 7,11V19H4V7H20M14.5,14.67H14.47L14.81,15.22L14.87,15.34C15.29,16.35 15,17.5 14.21,18.24C13.5,18.9 12.5,19.07 11.58,18.95C10.71,18.84 9.9,18.29 9.45,17.53C9.3,17.3 9.19,17.03 9.13,16.77L9,16.11C8.96,15.15 9.34,14.14 10.06,13.54C9.73,14.26 9.81,15.16 10.3,15.79L10.36,15.87C10.44,15.94 10.55,15.97 10.64,15.92C10.73,15.89 10.8,15.8 10.8,15.7L10.76,15.56C10.23,14.17 10.68,12.55 11.79,11.63C12.1,11.38 12.5,11.15 12.87,11.05C12.46,11.87 12.61,12.93 13.25,13.57L14.14,14.3L14.5,14.67M13.11,17.44V17.44C13.37,17.2 13.53,16.8 13.5,16.44V16.25C13.38,15.65 12.85,15.46 12.5,15L12.26,14.55C12.13,14.85 12.12,15.13 12.17,15.46C12.23,15.8 12.37,16.09 12.29,16.44C12.2,16.83 11.9,17.22 11.37,17.35C11.67,17.64 12.15,17.87 12.64,17.71L13.11,17.44Z\";\r\nvar mdiFireplaceOff = \"M22,22H2V20H22V22M22,6H2V3H22V6M20,7V19H17V11C17,11 14.5,10 12,10C9.5,10 7,11 7,11V19H4V7H20Z\";\r\nvar mdiFirework = \"M5.8,16.59L4.5,15.28L12.26,7.5L16.5,11.74L8.72,19.5L7.29,18.09C7.04,18.16 6.8,18.28 6.63,18.5C6.57,18.57 6.5,18.65 6.5,18.74C6.42,18.88 6.38,19 6.32,19.15C6.21,19.42 6.09,19.69 5.93,19.93C5.81,20.1 5.68,20.26 5.53,20.39C5.42,20.5 5.29,20.59 5.16,20.66C5.08,20.71 5,20.76 4.9,20.79C4.3,21.04 3.63,21 3,21V19C3.23,19 3.83,19 3.9,19C4,19 4.08,19 4.16,18.94C4.18,18.92 4.19,18.91 4.21,18.89C4.28,18.81 4.34,18.7 4.39,18.6C4.47,18.42 4.53,18.24 4.6,18.06L4.64,17.96C4.76,17.69 4.9,17.45 5.08,17.23C5.18,17.1 5.3,17 5.42,16.87C5.54,16.77 5.66,16.67 5.8,16.59M21,3L19.88,11.19L12.81,4.12L21,3Z\";\r\nvar mdiFish = \"M12,20L12.76,17C9.5,16.79 6.59,15.4 5.75,13.58C5.66,14.06 5.53,14.5 5.33,14.83C4.67,16 3.33,16 2,16C3.1,16 3.5,14.43 3.5,12.5C3.5,10.57 3.1,9 2,9C3.33,9 4.67,9 5.33,10.17C5.53,10.5 5.66,10.94 5.75,11.42C6.4,10 8.32,8.85 10.66,8.32L9,5C11,5 13,5 14.33,5.67C15.46,6.23 16.11,7.27 16.69,8.38C19.61,9.08 22,10.66 22,12.5C22,14.38 19.5,16 16.5,16.66C15.67,17.76 14.86,18.78 14.17,19.33C13.33,20 12.67,20 12,20M17,11A1,1 0 0,0 16,12A1,1 0 0,0 17,13A1,1 0 0,0 18,12A1,1 0 0,0 17,11Z\";\r\nvar mdiFishOff = \"M20.8 22.7L15.7 17.6C15.1 18.3 14.6 18.9 14.1 19.3C13.3 20 12.7 20 12 20L12.8 17C9.5 16.8 6.6 15.4 5.8 13.6C5.7 14.1 5.6 14.5 5.4 14.8C4.7 16 3.3 16 2 16C3.1 16 3.5 14.4 3.5 12.5S3.1 9 2 9C3.3 9 4.7 9 5.3 10.2C5.5 10.5 5.6 11 5.7 11.4C6 10.7 6.7 10 7.6 9.5L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M9.8 6.6L9 5C11 5 13 5 14.3 5.7C15.4 6.3 16.1 7.3 16.7 8.4C19.6 9.1 22 10.7 22 12.5C22 13.8 20.8 15 19 15.8L9.8 6.6M16 12C16 12.6 16.4 13 17 13S18 12.6 18 12 17.6 11 17 11 16 11.4 16 12Z\";\r\nvar mdiFishbowl = \"M19.11,5H21V3H3V5H4.89C3.11,6.8 2,9.27 2,12C2,15.97 4.31,19.39 7.66,21H16.34C19.69,19.39 22,15.97 22,12C22,9.27 20.89,6.8 19.11,5M13.25,17C12.09,17 11.06,16.64 10.33,16.17C9.67,17 8.33,17 7,17C8.1,17 8.5,15.88 8.5,14.5C8.5,13.12 8.1,12 7,12C8.33,12 9.67,12 10.37,12.91C11.06,12.36 12.09,12 13.25,12C15.32,12 17,13.12 17,14.5C17,15.88 15.32,17 13.25,17M16,7C13.56,8.71 10.44,8.71 8,7C7.06,7.66 6,8.09 4.95,8.25C5.31,7.58 5.77,6.96 6.32,6.41L7.7,5H16.3L17.68,6.41C18.23,6.96 18.69,7.58 19.05,8.25C18,8.09 16.94,7.66 16,7Z\";\r\nvar mdiFishbowlOutline = \"M19.11,5H21V3H3V5H4.89C3.11,6.8 2,9.27 2,12C2,15.97 4.31,19.39 7.66,21H16.34C19.69,19.39 22,15.97 22,12C22,9.27 20.89,6.8 19.11,5M6.32,6.41L7.7,5H16.3L17.68,6.41C18.23,6.96 18.69,7.58 19.05,8.25C18,8.09 16.94,7.66 16,7C13.56,8.71 10.44,8.71 8,7C7.06,7.66 6,8.09 4.95,8.25C5.31,7.58 5.77,6.96 6.32,6.41M15.85,19H8.15C5.58,17.59 4,14.95 4,12C4,11.43 4.07,10.86 4.19,10.32C5.5,10.29 6.8,9.95 8,9.33C10.5,10.63 13.5,10.63 16,9.33C17.2,9.95 18.5,10.29 19.81,10.32C19.93,10.86 20,11.43 20,12C20,14.95 18.42,17.59 15.85,19M17,14.5C17,15.88 15.32,17 13.25,17C12.09,17 11.06,16.64 10.33,16.16C9.67,17 8.33,17 7,17C8.1,17 8.5,15.88 8.5,14.5C8.5,13.12 8.1,12 7,12C8.33,12 9.67,12 10.37,12.91C11.06,12.36 12.09,12 13.25,12C15.32,12 17,13.12 17,14.5Z\";\r\nvar mdiFitToPage = \"M20,2H4C2.89,2 2,2.89 2,4V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.11,2 20,2M12,4L15,7H13V9H11V7H9M7,15L4,12L7,9V11H9V13H7M12,20L9,17H11V15H13V17H15M17,15V13H15V11H17V9L20,12\";\r\nvar mdiFitToPageOutline = \"M20,2H4C2.89,2 2,2.89 2,4V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.11,2 20,2M20,20H4V4H20M13,8V10H11V8H9L12,5L15,8M16,15V13H14V11H16V9L19,12M10,13H8V15L5,12L8,9V11H10M15,16L12,19L9,16H11V14H13V16\";\r\nvar mdiFlag = \"M14.4,6L14,4H5V21H7V14H12.6L13,16H20V6H14.4Z\";\r\nvar mdiFlagCheckered = \"M14.4,6H20V16H13L12.6,14H7V21H5V4H14L14.4,6M14,14H16V12H18V10H16V8H14V10L13,8V6H11V8H9V6H7V8H9V10H7V12H9V10H11V12H13V10L14,12V14M11,10V8H13V10H11M14,10H16V12H14V10Z\";\r\nvar mdiFlagMinus = \"M12.4,5H18V15H11L10.6,13H5V20H3V3H12L12.4,5M14,17H22V19H14V17Z\";\r\nvar mdiFlagMinusOutline = \"M12.36 6L12.76 8H18V14H14.64L14.24 12H7V6H12.36M14 4H5V21H7V14H12.6L13 16H20V6H14.4M23 18H15V20H23V18Z\";\r\nvar mdiFlagOutline = \"M12.36,6L12.76,8H18V14H14.64L14.24,12H7V6H12.36M14,4H5V21H7V14H12.6L13,16H20V6H14.4\";\r\nvar mdiFlagPlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M12.4,5H18V12C15.78,12 13.84,13.21 12.8,15H11L10.6,13H5V20H3V3H12L12.4,5Z\";\r\nvar mdiFlagPlusOutline = \"M13 16L12.6 14H7V21H5V4H14L14.4 6H20V13.09C19.67 13.04 19.34 13 19 13C18.66 13 18.33 13.04 18 13.09V8H12.76L12.36 6H7V12H14.24L14.64 14H15.69C14.92 14.5 14.27 15.2 13.81 16H13M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiFlagRemove = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M12.4,5H18V12C15.78,12 13.84,13.21 12.8,15H11L10.6,13H5V20H3V3H12L12.4,5Z\";\r\nvar mdiFlagRemoveOutline = \"M13 16L12.6 14H7V21H5V4H14L14.4 6H20V13.09C19.67 13.04 19.34 13 19 13C18.66 13 18.33 13.04 18 13.09V8H12.76L12.36 6H7V12H14.24L14.64 14H15.69C14.92 14.5 14.27 15.2 13.81 16H13M21.12 15.46L19 17.59L16.88 15.46L15.47 16.88L17.59 19L15.47 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88L21.12 15.46Z\";\r\nvar mdiFlagTriangle = \"M7,2H9V22H7V2M19,9L11,14.6V3.4L19,9Z\";\r\nvar mdiFlagVariant = \"M6,3A1,1 0 0,1 7,4V4.88C8.06,4.44 9.5,4 11,4C14,4 14,6 16,6C19,6 20,4 20,4V12C20,12 19,14 16,14C13,14 13,12 11,12C8,12 7,14 7,14V21H5V4A1,1 0 0,1 6,3Z\";\r\nvar mdiFlagVariantOutline = \"M6,3A1,1 0 0,1 7,4V4.88C8.06,4.44 9.5,4 11,4C14,4 14,6 16,6C19,6 20,4 20,4V12C20,12 19,14 16,14C13,14 13,12 11,12C8,12 7,14 7,14V21H5V4A1,1 0 0,1 6,3M7,7.25V11.5C7,11.5 9,10 11,10C13,10 14,12 16,12C18,12 18,11 18,11V7.5C18,7.5 17,8 16,8C14,8 13,6 11,6C9,6 7,7.25 7,7.25Z\";\r\nvar mdiFlare = \"M7,11H1V13H7V11M9.17,7.76L7.05,5.64L5.64,7.05L7.76,9.17L9.17,7.76M13,1H11V7H13V1M18.36,7.05L16.95,5.64L14.83,7.76L16.24,9.17L18.36,7.05M17,11V13H23V11H17M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M14.83,16.24L16.95,18.36L18.36,16.95L16.24,14.83L14.83,16.24M5.64,16.95L7.05,18.36L9.17,16.24L7.76,14.83L5.64,16.95M11,23H13V17H11V23Z\";\r\nvar mdiFlash = \"M7,2V13H10V22L17,10H13L17,2H7Z\";\r\nvar mdiFlashAlert = \"M5,2V13H8V22L15,10H11L15,2M17,15H19V17H17V15M17,7H19V13H17V7Z\";\r\nvar mdiFlashAlertOutline = \"M5,2H15L11.5,9H15L8,22V14H5V2M7,4V12H10V14.66L12,11H8.24L11.76,4M17,15H19V17H17V15M17,7H19V13H17V7Z\";\r\nvar mdiFlashAuto = \"M16.85,7.65L18,4L19.15,7.65M19,2H17L13.8,11H15.7L16.4,9H19.6L20.3,11H22.2M3,2V14H6V23L13,11H9L13,2H3Z\";\r\nvar mdiFlashCircle = \"M11.5,20L16.36,10.27H13V4L8,13.73H11.5V20M12,2C14.75,2 17.1,3 19.05,4.95C21,6.9 22,9.25 22,12C22,14.75 21,17.1 19.05,19.05C17.1,21 14.75,22 12,22C9.25,22 6.9,21 4.95,19.05C3,17.1 2,14.75 2,12C2,9.25 3,6.9 4.95,4.95C6.9,3 9.25,2 12,2Z\";\r\nvar mdiFlashOff = \"M17,10H13L17,2H7V4.18L15.46,12.64M3.27,3L2,4.27L7,9.27V13H10V22L13.58,15.86L17.73,20L19,18.73L3.27,3Z\";\r\nvar mdiFlashOutline = \"M7,2H17L13.5,9H17L10,22V14H7V2M9,4V12H12V14.66L14,11H10.24L13.76,4H9Z\";\r\nvar mdiFlashRedEye = \"M16,5C15.44,5 15,5.44 15,6C15,6.56 15.44,7 16,7C16.56,7 17,6.56 17,6C17,5.44 16.56,5 16,5M16,2C13.27,2 10.94,3.66 10,6C10.94,8.34 13.27,10 16,10C18.73,10 21.06,8.34 22,6C21.06,3.66 18.73,2 16,2M16,3.5A2.5,2.5 0 0,1 18.5,6A2.5,2.5 0 0,1 16,8.5A2.5,2.5 0 0,1 13.5,6A2.5,2.5 0 0,1 16,3.5M3,2V14H6V23L13,11H9L10.12,8.5C9.44,7.76 8.88,6.93 8.5,6C9.19,4.29 10.5,2.88 12.11,2H3Z\";\r\nvar mdiFlashlight = \"M9,10L6,5H18L15,10H9M18,4H6V2H18V4M9,22V11H15V22H9M12,13A1,1 0 0,0 11,14A1,1 0 0,0 12,15A1,1 0 0,0 13,14A1,1 0 0,0 12,13Z\";\r\nvar mdiFlashlightOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L15,18.27V22H9V12.27L2,5.27M18,5L15,10H11.82L6.82,5H18M18,4H6V2H18V4M15,11V13.18L12.82,11H15Z\";\r\nvar mdiFlask = \"M6,22A3,3 0 0,1 3,19C3,18.4 3.18,17.84 3.5,17.37L9,7.81V6A1,1 0 0,1 8,5V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V5A1,1 0 0,1 15,6V7.81L20.5,17.37C20.82,17.84 21,18.4 21,19A3,3 0 0,1 18,22H6M5,19A1,1 0 0,0 6,20H18A1,1 0 0,0 19,19C19,18.79 18.93,18.59 18.82,18.43L16.53,14.47L14,17L8.93,11.93L5.18,18.43C5.07,18.59 5,18.79 5,19M13,10A1,1 0 0,0 12,11A1,1 0 0,0 13,12A1,1 0 0,0 14,11A1,1 0 0,0 13,10Z\";\r\nvar mdiFlaskEmpty = \"M6,22A3,3 0 0,1 3,19C3,18.4 3.18,17.84 3.5,17.37L9,7.81V6A1,1 0 0,1 8,5V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V5A1,1 0 0,1 15,6V7.81L20.5,17.37C20.82,17.84 21,18.4 21,19A3,3 0 0,1 18,22H6Z\";\r\nvar mdiFlaskEmptyMinus = \"M23 17V19H15V17H23M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C14.92 12.84 13 15.2 13 18C13 19.54 13.58 20.94 14.53 22H6Z\";\r\nvar mdiFlaskEmptyMinusOutline = \"M23 17V19H15V17H23M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19Z\";\r\nvar mdiFlaskEmptyOff = \"M20.8 22.7L19.6 21.5C19.1 21.8 18.6 22 18 22H6C4.3 22 3 20.7 3 19C3 18.4 3.2 17.8 3.5 17.4L7.9 9.8L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M15 7.8V6C15.6 6 16 5.6 16 5V4C16 2.9 15.1 2 14 2H10C8.9 2 8 2.9 8 4V4.8L20.4 17.2L15 7.8Z\";\r\nvar mdiFlaskEmptyOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L7.9 9.8L3.5 17.4C3.2 17.8 3 18.4 3 19C3 20.7 4.3 22 6 22H18C18.6 22 19.2 21.8 19.6 21.5L20.8 22.7L22.1 21.5M18 20H6C5.4 20 5 19.6 5 19C5 18.8 5.1 18.6 5.2 18.4L9.4 11.2L18 20C18.1 20 18 20 18 20M11 7.8L8 4.8V4C8 2.9 8.9 2 10 2H14C15.1 2 16 2.9 16 4V5C16 5.6 15.6 6 15 6V7.8L20.4 17.2L15 11.8L13 8.4V4H11V7.8Z\";\r\nvar mdiFlaskEmptyOutline = \"M5,19A1,1 0 0,0 6,20H18A1,1 0 0,0 19,19C19,18.79 18.93,18.59 18.82,18.43L13,8.35V4H11V8.35L5.18,18.43C5.07,18.59 5,18.79 5,19M6,22A3,3 0 0,1 3,19C3,18.4 3.18,17.84 3.5,17.37L9,7.81V6A1,1 0 0,1 8,5V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V5A1,1 0 0,1 15,6V7.81L20.5,17.37C20.82,17.84 21,18.4 21,19A3,3 0 0,1 18,22H6Z\";\r\nvar mdiFlaskEmptyPlus = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C14.92 12.84 13 15.2 13 18C13 19.54 13.58 20.94 14.53 22H6Z\";\r\nvar mdiFlaskEmptyPlusOutline = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19Z\";\r\nvar mdiFlaskEmptyRemove = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C14.92 12.84 13 15.2 13 18C13 19.54 13.58 20.94 14.53 22H6Z\";\r\nvar mdiFlaskEmptyRemoveOutline = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19Z\";\r\nvar mdiFlaskMinus = \"M23 17V19H15V17H23M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C15.5 12.7 13.86 14.26 13.26 16.26L8.93 11.93L5.18 18.43C5.07 18.59 5 18.79 5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6M13 10C12.45 10 12 10.45 12 11C12 11.55 12.45 12 13 12C13.55 12 14 11.55 14 11C14 10.45 13.55 10 13 10Z\";\r\nvar mdiFlaskMinusOutline = \"M23 17V19H15V17H23M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19M13 16L13.58 15.42C13.21 16.2 13 17.08 13 18H7.73L10.39 13.39L13 16M12.5 12C12.78 12 13 12.22 13 12.5C13 12.78 12.78 13 12.5 13C12.22 13 12 12.78 12 12.5C12 12.22 12.22 12 12.5 12Z\";\r\nvar mdiFlaskOff = \"M22.1 21.5L2.4 1.7L1.1 3L7.9 9.8L3.5 17.4C3.2 17.8 3 18.4 3 19C3 20.7 4.3 22 6 22H18C18.6 22 19.2 21.8 19.6 21.5L20.8 22.7L22.1 21.5M18 20H6C5.4 20 5 19.6 5 19C5 18.8 5.1 18.6 5.2 18.4L9 11.9L14 17L14.6 16.4L18 20C18.1 20 18 20 18 20M8 4.8V4C8 2.9 8.9 2 10 2H14C15.1 2 16 2.9 16 4V5C16 5.6 15.6 6 15 6V7.8L20.4 17.2L8 4.8Z\";\r\nvar mdiFlaskOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L7.9 9.8L3.5 17.4C3.2 17.8 3 18.4 3 19C3 20.7 4.3 22 6 22H18C18.6 22 19.2 21.8 19.6 21.5L20.8 22.7L22.1 21.5M18 20H6C5.4 20 5 19.6 5 19C5 18.8 5.1 18.6 5.2 18.4L9.4 11.2L13.6 15.4L13 16L10.4 13.4L7.7 18H16.1L18 20C18.1 20 18 20 18 20M11 7.8L8 4.8V4C8 2.9 8.9 2 10 2H14C15.1 2 16 2.9 16 4V5C16 5.6 15.6 6 15 6V7.8L20.4 17.2L15 11.8L13 8.4V4H11V7.8Z\";\r\nvar mdiFlaskOutline = \"M5,19A1,1 0 0,0 6,20H18A1,1 0 0,0 19,19C19,18.79 18.93,18.59 18.82,18.43L13,8.35V4H11V8.35L5.18,18.43C5.07,18.59 5,18.79 5,19M6,22A3,3 0 0,1 3,19C3,18.4 3.18,17.84 3.5,17.37L9,7.81V6A1,1 0 0,1 8,5V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V5A1,1 0 0,1 15,6V7.81L20.5,17.37C20.82,17.84 21,18.4 21,19A3,3 0 0,1 18,22H6M13,16L14.34,14.66L16.27,18H7.73L10.39,13.39L13,16M12.5,12A0.5,0.5 0 0,1 13,12.5A0.5,0.5 0 0,1 12.5,13A0.5,0.5 0 0,1 12,12.5A0.5,0.5 0 0,1 12.5,12Z\";\r\nvar mdiFlaskPlus = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C15.5 12.7 13.86 14.26 13.26 16.26L8.93 11.93L5.18 18.43C5.07 18.59 5 18.79 5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6M13 10C12.45 10 12 10.45 12 11C12 11.55 12.45 12 13 12C13.55 12 14 11.55 14 11C14 10.45 13.55 10 13 10Z\";\r\nvar mdiFlaskPlusOutline = \"M18 14H20V17H23V19H20V22H18V19H15V17H18V14M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19M13 16L13.58 15.42C13.21 16.2 13 17.08 13 18H7.73L10.39 13.39L13 16M12.5 12C12.78 12 13 12.22 13 12.5C13 12.78 12.78 13 12.5 13C12.22 13 12 12.78 12 12.5C12 12.22 12.22 12 12.5 12Z\";\r\nvar mdiFlaskRemove = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M6 22C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C15.5 12.7 13.86 14.26 13.26 16.26L8.93 11.93L5.18 18.43C5.07 18.59 5 18.79 5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6M13 10C12.45 10 12 10.45 12 11C12 11.55 12.45 12 13 12C13.55 12 14 11.55 14 11C14 10.45 13.55 10 13 10Z\";\r\nvar mdiFlaskRemoveOutline = \"M15.46 15.88L16.88 14.46L19 16.59L21.12 14.47L22.53 15.88L20.41 18L22.54 20.12L21.12 21.54L19 19.41L16.88 21.53L15.47 20.12L17.59 18L15.46 15.88M5 19C5 19.55 5.45 20 6 20H13.34C13.61 20.75 14 21.42 14.53 22H6C4.34 22 3 20.66 3 19C3 18.4 3.18 17.84 3.5 17.36L9 7.81V6C8.45 6 8 5.55 8 5V4C8 2.9 8.9 2 10 2H14C15.11 2 16 2.9 16 4V5C16 5.55 15.55 6 15 6V7.81L17.5 12.18C16.86 12.35 16.24 12.63 15.69 13L13 8.35V4H11V8.35L5.18 18.43C5.07 18.59 5 18.79 5 19M13 16L13.58 15.42C13.21 16.2 13 17.08 13 18H7.73L10.39 13.39L13 16M12.5 12C12.78 12 13 12.22 13 12.5C13 12.78 12.78 13 12.5 13C12.22 13 12 12.78 12 12.5C12 12.22 12.22 12 12.5 12Z\";\r\nvar mdiFlaskRoundBottom = \"M19 15C19 18.87 15.87 22 12 22C8.13 22 5 18.87 5 15C5 12.21 6.64 9.8 9 8.67V5C9 4.45 9.45 4 10 4H10.5L9.5 2H14.5L13.5 4H14C14.55 4 15 4.45 15 5V8.67C17.36 9.8 19 12.21 19 15M11 6V10.1C8.72 10.56 7 12.58 7 15L7.08 15.91L9 13.93L13.07 18L16.93 14.14C16.58 12.12 15 10.5 13 10.1V6H11M13.07 12C13.62 12 14.07 12.45 14.07 13C14.07 13.55 13.62 14 13.07 14C12.5 14 12.07 13.55 12.07 13C12.07 12.45 12.5 12 13.07 12Z\";\r\nvar mdiFlaskRoundBottomEmpty = \"M19 15C19 18.87 15.87 22 12 22C8.13 22 5 18.87 5 15C5 12.21 6.64 9.8 9 8.67V5C9 4.45 9.45 4 10 4H10.5L9.5 2H14.5L13.5 4H14C14.55 4 15 4.45 15 5V8.67C17.36 9.8 19 12.21 19 15Z\";\r\nvar mdiFlaskRoundBottomEmptyOutline = \"M19 15C19 18.87 15.87 22 12 22C8.13 22 5 18.87 5 15C5 12.21 6.64 9.8 9 8.67V5C9 4.45 9.45 4 10 4H10.5L9.5 2H14.5L13.5 4H14C14.55 4 15 4.45 15 5V8.67C17.36 9.8 19 12.21 19 15M11 6V10.1C8.72 10.56 7 12.58 7 15C7 17.76 9.24 20 12 20C14.76 20 17 17.76 17 15C17 12.58 15.28 10.56 13 10.1V6H11Z\";\r\nvar mdiFlaskRoundBottomOutline = \"M15 15C15 16.66 13.66 18 12 18C10.34 18 9 16.66 9 15V14H11V15C11 15.55 11.45 16 12 16C12.55 16 13 15.55 13 15V14H15V15M19 15C19 18.87 15.87 22 12 22C8.13 22 5 18.87 5 15C5 12.21 6.64 9.8 9 8.67V5C9 4.45 9.45 4 10 4H10.5L9.5 2H14.5L13.5 4H14C14.55 4 15 4.45 15 5V8.67C17.36 9.8 19 12.21 19 15M11 6V10.1C8.72 10.56 7 12.58 7 15C7 17.76 9.24 20 12 20C14.76 20 17 17.76 17 15C17 12.58 15.28 10.56 13 10.1V6H11Z\";\r\nvar mdiFleurDeLis = \"M12 2S9 4 9 7 11 12 11 16H10S10 14 9 12C7 8 3 10 3 13S5 16 5 16C5 13 8.5 13 8.5 16H7V18H10.5L9 20S10 21 11 20L12 22L13 20C14 21 15 20 15 20L13.5 18H17V16H15.5C15.5 13 19 13 19 16C19 16 21 16 21 13S17 8 15 12C14 14 14 16 14 16H13C13 12 15 10 15 7S12 2 12 2Z\";\r\nvar mdiFlipHorizontal = \"M15 21H17V19H15M19 9H21V7H19M3 5V19C3 20.1 3.9 21 5 21H9V19H5V5H9V3H5C3.9 3 3 3.9 3 5M19 3V5H21C21 3.9 20.1 3 19 3M11 23H13V1H11M19 17H21V15H19M15 5H17V3H15M19 13H21V11H19M19 21C20.1 21 21 20.1 21 19H19Z\";\r\nvar mdiFlipToBack = \"M15,17H17V15H15M15,5H17V3H15M5,7H3V19A2,2 0 0,0 5,21H17V19H5M19,17A2,2 0 0,0 21,15H19M19,9H21V7H19M19,13H21V11H19M9,17V15H7A2,2 0 0,0 9,17M13,3H11V5H13M19,3V5H21C21,3.89 20.1,3 19,3M13,15H11V17H13M9,3C7.89,3 7,3.89 7,5H9M9,11H7V13H9M9,7H7V9H9V7Z\";\r\nvar mdiFlipToFront = \"M7,21H9V19H7M11,21H13V19H11M19,15H9V5H19M19,3H9C7.89,3 7,3.89 7,5V15A2,2 0 0,0 9,17H14L18,17H19A2,2 0 0,0 21,15V5C21,3.89 20.1,3 19,3M15,21H17V19H15M3,9H5V7H3M5,21V19H3A2,2 0 0,0 5,21M3,17H5V15H3M3,13H5V11H3V13Z\";\r\nvar mdiFlipVertical = \"M3 15V17H5V15M15 19V21H17V19M19 3H5C3.9 3 3 3.9 3 5V9H5V5H19V9H21V5C21 3.9 20.1 3 19 3M21 19H19V21C20.1 21 21 20.1 21 19M1 11V13H23V11M7 19V21H9V19M19 15V17H21V15M11 19V21H13V19M3 19C3 20.1 3.9 21 5 21V19Z\";\r\nvar mdiFloorLamp = \"M15,2L17,9H7L9,2M11,10H13V20H16V22H8V20H11V10Z\";\r\nvar mdiFloorLampDual = \"M11.73 10.06L10.17 11.24L11 12.2V20H8V22H16V20H13V12.3L13.85 11.26L12.27 10.07L11.73 10.06M9.08 10.82L3 6.81L9.39 2L11.55 8.93L9.08 10.82M14.61 2L21 6.81L14.92 10.82L12.44 8.95L14.61 2Z\";\r\nvar mdiFloorLampVariant = \"M7 2L10 9H14L17 2H7M15.92 22L13 15V22H11V15L8.08 22H5.92L10.92 10H13.08L18.08 22H15.92Z\";\r\nvar mdiFloorPlan = \"M10,5V10H9V5H5V13H9V12H10V17H9V14H5V19H12V17H13V19H19V17H21V21H3V3H21V15H19V10H13V15H12V9H19V5H10Z\";\r\nvar mdiFloppy = \"M5,3A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5.5L18.5,3H17V9A1,1 0 0,1 16,10H8A1,1 0 0,1 7,9V3H5M12,4V9H15V4H12M7,12H17A1,1 0 0,1 18,13V19H6V13A1,1 0 0,1 7,12Z\";\r\nvar mdiFloppyVariant = \"M3,3V21H21V3H3M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M12,15A1,1 0 0,1 13,16V19A1,1 0 0,1 12,20A1,1 0 0,1 11,19V16A1,1 0 0,1 12,15Z\";\r\nvar mdiFlower = \"M3,13A9,9 0 0,0 12,22C12,17 7.97,13 3,13M12,5.5A2.5,2.5 0 0,1 14.5,8A2.5,2.5 0 0,1 12,10.5A2.5,2.5 0 0,1 9.5,8A2.5,2.5 0 0,1 12,5.5M5.6,10.25A2.5,2.5 0 0,0 8.1,12.75C8.63,12.75 9.12,12.58 9.5,12.31C9.5,12.37 9.5,12.43 9.5,12.5A2.5,2.5 0 0,0 12,15A2.5,2.5 0 0,0 14.5,12.5C14.5,12.43 14.5,12.37 14.5,12.31C14.88,12.58 15.37,12.75 15.9,12.75C17.28,12.75 18.4,11.63 18.4,10.25C18.4,9.25 17.81,8.4 16.97,8C17.81,7.6 18.4,6.74 18.4,5.75C18.4,4.37 17.28,3.25 15.9,3.25C15.37,3.25 14.88,3.41 14.5,3.69C14.5,3.63 14.5,3.56 14.5,3.5A2.5,2.5 0 0,0 12,1A2.5,2.5 0 0,0 9.5,3.5C9.5,3.56 9.5,3.63 9.5,3.69C9.12,3.41 8.63,3.25 8.1,3.25A2.5,2.5 0 0,0 5.6,5.75C5.6,6.74 6.19,7.6 7.03,8C6.19,8.4 5.6,9.25 5.6,10.25M12,22A9,9 0 0,0 21,13C16,13 12,17 12,22Z\";\r\nvar mdiFlowerOutline = \"M8.66,13.07C6.92,13.07 5.5,11.66 5.5,9.93C5.5,9.22 5.76,8.54 6.19,8C5.77,7.46 5.5,6.78 5.5,6.07C5.5,4.34 6.93,2.93 8.66,2.93L9.09,2.96C9.56,1.81 10.69,1 12,1C13.31,1 14.44,1.81 14.91,2.96L15.34,2.93C17.07,2.93 18.5,4.34 18.5,6.07C18.5,6.78 18.24,7.46 17.81,8C18.23,8.54 18.5,9.22 18.5,9.93C18.5,11.66 17.07,13.07 15.34,13.07L14.91,13.04C14.44,14.19 13.31,15 12,15C10.69,15 9.56,14.19 9.09,13.04L8.66,13.07M12,13C12.62,13 13.12,12.5 13.14,11.9L13.03,10.81C12.71,10.93 12.36,11 12,11C11.64,11 11.3,10.93 11,10.81L10.86,11.9C10.88,12.5 11.38,13 12,13M15.34,11.07C15.97,11.07 16.5,10.56 16.5,9.92C16.5,9.5 16.23,9.08 15.83,8.89L14.95,8.47C14.83,9.21 14.44,9.85 13.89,10.3L14.7,10.87C14.88,11 15.1,11.07 15.34,11.07M14.69,5.13L13.87,5.69C14.43,6.14 14.82,6.78 14.94,7.5L15.82,7.1C16.23,6.9 16.5,6.5 16.5,6.07C16.5,5.44 15.97,4.93 15.34,4.93C15.11,4.93 14.89,5 14.69,5.13M12,3C11.38,3 10.88,3.5 10.86,4.1L11,5.19C11.3,5.07 11.64,5 12,5C12.36,5 12.71,5.07 13.03,5.19L13.14,4.1C13.12,3.5 12.62,3 12,3M8.66,4.93C8.03,4.93 7.5,5.44 7.5,6.07C7.5,6.5 7.77,6.9 8.17,7.1L9.05,7.5C9.17,6.78 9.56,6.14 10.11,5.69L9.3,5.13C9.12,5 8.9,4.93 8.66,4.93M8.17,8.9C7.77,9.1 7.5,9.5 7.5,9.92C7.5,10.55 8.03,11.06 8.66,11.06C8.89,11.06 9.11,11 9.31,10.86L10.12,10.31C9.56,9.86 9.17,9.22 9.05,8.5L8.17,8.9M12,22A9,9 0 0,1 3,13A9,9 0 0,1 12,22A9,9 0 0,1 21,13A9,9 0 0,1 12,22M14.44,19.56C16.34,18.85 17.85,17.34 18.56,15.44C16.66,16.14 15.15,17.66 14.44,19.56M5.44,15.44C6.15,17.34 7.66,18.85 9.56,19.56C8.86,17.66 7.34,16.15 5.44,15.44Z\";\r\nvar mdiFlowerPoppy = \"M18.5,12A3.5,3.5 0 0,0 22,8.5A6.5,6.5 0 0,0 15.5,2A3.5,3.5 0 0,0 12,5.5A3.5,3.5 0 0,0 8.5,2A6.5,6.5 0 0,0 2,8.5A3.5,3.5 0 0,0 5.5,12A3.5,3.5 0 0,0 2,15.5A6.5,6.5 0 0,0 8.5,22A3.5,3.5 0 0,0 12,18.5A3.5,3.5 0 0,0 15.5,22A6.5,6.5 0 0,0 22,15.5A3.5,3.5 0 0,0 18.5,12M12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16M14.5,12A2.5,2.5 0 0,1 12,14.5A2.5,2.5 0 0,1 9.5,12A2.5,2.5 0 0,1 12,9.5A2.5,2.5 0 0,1 14.5,12Z\";\r\nvar mdiFlowerTulip = \"M3,13A9,9 0 0,0 12,22A9,9 0 0,0 3,13M12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,22M18,3V8A6,6 0 0,1 12,14A6,6 0 0,1 6,8V3C6.74,3 7.47,3.12 8.16,3.39C8.71,3.62 9.2,3.96 9.61,4.39L12,2L14.39,4.39C14.8,3.96 15.29,3.62 15.84,3.39C16.53,3.12 17.26,3 18,3Z\";\r\nvar mdiFlowerTulipOutline = \"M3,13A9,9 0 0,0 12,22A9,9 0 0,0 3,13M5.44,15.44C7.35,16.15 8.85,17.65 9.56,19.56C7.65,18.85 6.15,17.35 5.44,15.44M12,22A9,9 0 0,0 21,13A9,9 0 0,0 12,22M14.42,19.57C15.11,17.64 16.64,16.11 18.57,15.42C17.86,17.34 16.34,18.86 14.42,19.57M12,14A6,6 0 0,0 18,8V3C17.26,3 16.53,3.12 15.84,3.39C15.29,3.62 14.8,3.96 14.39,4.39L12,2L9.61,4.39C9.2,3.96 8.71,3.62 8.16,3.39C7.47,3.12 6.74,3 6,3V8A6,6 0 0,0 12,14M8,5.61L9.57,7.26L12,4.83L14.43,7.26L16,5.61V8A4,4 0 0,1 12,12A4,4 0 0,1 8,8V5.61Z\";\r\nvar mdiFocusAuto = \"M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5V15M8 7C6.9 7 6 7.9 6 9V17H8V13H10V17H12V9C12 7.9 11.1 7 10 7H8M8 9H10V11H8V9M13 7V17H15V13H17V11H15V9H18V7H13Z\";\r\nvar mdiFocusField = \"M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5V15M7 11H9V13H7V11M11 11H13V13H11V11M15 11H17V13H15V11M7 7H9V9H7V7M11 7H13V9H11V7M15 7H17V9H15V7M7 15H9V17H7V15M11 15H13V17H11V15M15 15H17V17H15V15Z\";\r\nvar mdiFocusFieldHorizontal = \"M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5V15M7 11H9V13H7V11M11 11H13V13H11V11M15 11H17V13H15V11Z\";\r\nvar mdiFocusFieldVertical = \"M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5V15M11 11H13V13H11V11M11 7H13V9H11V7M11 15H13V17H11V15Z\";\r\nvar mdiFolder = \"M10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6H12L10,4Z\";\r\nvar mdiFolderAccount = \"M19,17H11V16C11,14.67 13.67,14 15,14C16.33,14 19,14.67 19,16M15,9A2,2 0 0,1 17,11A2,2 0 0,1 15,13A2,2 0 0,1 13,11C13,9.89 13.9,9 15,9M20,6H12L10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6Z\";\r\nvar mdiFolderAccountOutline = \"M15 14C16.33 14 19 14.67 19 16V17H11V16C11 14.67 13.67 14 15 14M15 13C16.11 13 17 12.11 17 11S16.11 9 15 9C13.9 9 13 9.89 13 11C13 12.11 13.9 13 15 13M22 8V18C22 19.11 21.11 20 20 20H4C2.9 20 2 19.11 2 18V6C2 4.89 2.9 4 4 4H10L12 6H20C21.11 6 22 6.9 22 8M20 8H4V18H20V8Z\";\r\nvar mdiFolderAlert = \"M15,12H17V17H15V12M15,18H17V20H15V18M23,16A7,7 0 0,1 16,23C13.62,23 11.5,21.81 10.25,20H3C1.89,20 1,19.1 1,18V6C1,4.89 1.89,4 3,4H9L11,6H19A2,2 0 0,1 21,8V11.1C22.24,12.36 23,14.09 23,16M16,11A5,5 0 0,0 11,16A5,5 0 0,0 16,21A5,5 0 0,0 21,16A5,5 0 0,0 16,11Z\";\r\nvar mdiFolderAlertOutline = \"M15,12H17V17H15V12M15,18H17V20H15V18M16,9C17.07,9 18.09,9.24 19,9.67V8H3V18H9.29C9.1,17.36 9,16.69 9,16A7,7 0 0,1 16,9M23,16A7,7 0 0,1 16,23C13.62,23 11.5,21.81 10.25,20H3C1.89,20 1,19.1 1,18V6C1,4.89 1.89,4 3,4H9L11,6H19A2,2 0 0,1 21,8V11.1C22.24,12.36 23,14.09 23,16M16,11A5,5 0 0,0 11,16A5,5 0 0,0 16,21A5,5 0 0,0 21,16A5,5 0 0,0 16,11Z\";\r\nvar mdiFolderClock = \"M3,4C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H10.26C11.57,21.88 13.71,23 16,23A7,7 0 0,0 23,16C23,14.17 22.28,12.42 21,11.11V8C21,6.89 20.1,6 19,6H11L9,4H3M16,11A5,5 0 0,1 21,16A5,5 0 0,1 16,21A5,5 0 0,1 11,16A5,5 0 0,1 16,11M15,12V17L18.61,19.16L19.36,17.94L16.5,16.25V12H15Z\";\r\nvar mdiFolderClockOutline = \"M15,12H16.5V16.25L19.36,17.94L18.61,19.16L15,17V12M19,8H3V18H9.29C9.1,17.37 9,16.7 9,16A7,7 0 0,1 16,9C17.07,9 18.09,9.24 19,9.67V8M3,20C1.89,20 1,19.1 1,18V6A2,2 0 0,1 3,4H9L11,6H19A2,2 0 0,1 21,8V11.1C22.24,12.36 23,14.09 23,16A7,7 0 0,1 16,23C13.62,23 11.5,21.81 10.25,20H3M16,11A5,5 0 0,0 11,16A5,5 0 0,0 16,21A5,5 0 0,0 21,16A5,5 0 0,0 16,11Z\";\r\nvar mdiFolderCog = \"M4 4C2.89 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H12.08A7 7 0 0 1 12 19A7 7 0 0 1 19 12A7 7 0 0 1 22 12.69V8C22 6.89 21.1 6 20 6H12L10 4H4M18 14C17.87 14 17.76 14.09 17.74 14.21L17.55 15.53C17.25 15.66 16.96 15.82 16.7 16L15.46 15.5C15.35 15.5 15.22 15.5 15.15 15.63L14.15 17.36C14.09 17.47 14.11 17.6 14.21 17.68L15.27 18.5C15.25 18.67 15.24 18.83 15.24 19C15.24 19.17 15.25 19.33 15.27 19.5L14.21 20.32C14.12 20.4 14.09 20.53 14.15 20.64L15.15 22.37C15.21 22.5 15.34 22.5 15.46 22.5L16.7 22C16.96 22.18 17.24 22.35 17.55 22.47L17.74 23.79C17.76 23.91 17.86 24 18 24H20C20.11 24 20.22 23.91 20.24 23.79L20.43 22.47C20.73 22.34 21 22.18 21.27 22L22.5 22.5C22.63 22.5 22.76 22.5 22.83 22.37L23.83 20.64C23.89 20.53 23.86 20.4 23.77 20.32L22.7 19.5C22.72 19.33 22.74 19.17 22.74 19C22.74 18.83 22.73 18.67 22.7 18.5L23.76 17.68C23.85 17.6 23.88 17.47 23.82 17.36L22.82 15.63C22.76 15.5 22.63 15.5 22.5 15.5L21.27 16C21 15.82 20.73 15.65 20.42 15.53L20.23 14.21C20.22 14.09 20.11 14 20 14H18M19 17.5C19.83 17.5 20.5 18.17 20.5 19C20.5 19.83 19.83 20.5 19 20.5C18.16 20.5 17.5 19.83 17.5 19C17.5 18.17 18.17 17.5 19 17.5Z\";\r\nvar mdiFolderCogOutline = \"M4 4C2.89 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H12V18H4V8H20V12H22V8C22 6.89 21.1 6 20 6H12L10 4M18 14C17.87 14 17.76 14.09 17.74 14.21L17.55 15.53C17.25 15.66 16.96 15.82 16.7 16L15.46 15.5C15.35 15.5 15.22 15.5 15.15 15.63L14.15 17.36C14.09 17.47 14.11 17.6 14.21 17.68L15.27 18.5C15.25 18.67 15.24 18.83 15.24 19C15.24 19.17 15.25 19.33 15.27 19.5L14.21 20.32C14.12 20.4 14.09 20.53 14.15 20.64L15.15 22.37C15.21 22.5 15.34 22.5 15.46 22.5L16.7 22C16.96 22.18 17.24 22.35 17.55 22.47L17.74 23.79C17.76 23.91 17.86 24 18 24H20C20.11 24 20.22 23.91 20.24 23.79L20.43 22.47C20.73 22.34 21 22.18 21.27 22L22.5 22.5C22.63 22.5 22.76 22.5 22.83 22.37L23.83 20.64C23.89 20.53 23.86 20.4 23.77 20.32L22.7 19.5C22.72 19.33 22.74 19.17 22.74 19C22.74 18.83 22.73 18.67 22.7 18.5L23.76 17.68C23.85 17.6 23.88 17.47 23.82 17.36L22.82 15.63C22.76 15.5 22.63 15.5 22.5 15.5L21.27 16C21 15.82 20.73 15.65 20.42 15.53L20.23 14.21C20.22 14.09 20.11 14 20 14M19 17.5C19.83 17.5 20.5 18.17 20.5 19C20.5 19.83 19.83 20.5 19 20.5C18.16 20.5 17.5 19.83 17.5 19C17.5 18.17 18.17 17.5 19 17.5Z\";\r\nvar mdiFolderDownload = \"M20,6A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10L12,6H20M19.25,13H16V9H14V13H10.75L15,17.25\";\r\nvar mdiFolderDownloadOutline = \"M20 18H4V8H20M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M14 9H16V13H19L15 17L11 13H14Z\";\r\nvar mdiFolderEdit = \"M3,4C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H11V18.11L21,8.11V8C21,6.89 20.1,6 19,6H11L9,4H3M21.04,11.13C20.9,11.13 20.76,11.19 20.65,11.3L19.65,12.3L21.7,14.35L22.7,13.35C22.92,13.14 22.92,12.79 22.7,12.58L21.42,11.3C21.31,11.19 21.18,11.13 21.04,11.13M19.07,12.88L13,18.94V21H15.06L21.12,14.93L19.07,12.88Z\";\r\nvar mdiFolderEditOutline = \"M21,11.11C20.92,11.11 20.72,11.21 20.62,11.31L19.62,12.31L21.72,14.42L22.72,13.41C22.92,13.21 22.92,12.81 22.72,12.61L21.42,11.31C21.32,11.21 21.22,11.11 21,11.11M19.12,12.91L13,18.92V21H15.12L21.22,14.92L19.12,12.91M21,8V8.11L19,10.11V8H3V18H11V20H3A2,2 0 0,1 1,18V6C1,4.91 1.9,4 3,4H9L11,6H19C20.12,6 21,6.91 21,8Z\";\r\nvar mdiFolderGoogleDrive = \"M13.75,9H16.14L19,14H16.05L13.5,9.46M18.3,17H12.75L14.15,14.5H19.27L19.53,14.96M11.5,17L10.4,14.86L13.24,9.9L14.74,12.56L12.25,17M20,6H12L10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6Z\";\r\nvar mdiFolderHeart = \"M20 6H12L10 4H4C2.89 4 2 4.89 2 6V18C2 19.1 2.89 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6M18.42 13.5L15 17L11.59 13.5C11.22 13.12 11 12.62 11 12.05C11 10.92 11.9 10 13 10C13.54 10 14.05 10.23 14.42 10.61L15 11.2L15.59 10.6C15.95 10.23 16.46 10 17 10C18.1 10 19 10.92 19 12.05C19 12.61 18.78 13.13 18.42 13.5Z\";\r\nvar mdiFolderHeartOutline = \"M20 18H4V8H20M20 6H12L10 4H4C2.89 4 2 4.89 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.89 21.1 6 20 6M13 10C11.9 10 11 10.92 11 12.05C11 12.62 11.22 13.12 11.59 13.5L15 17L18.42 13.5C18.78 13.13 19 12.61 19 12.05C19 10.92 18.1 10 17 10C16.46 10 15.95 10.23 15.59 10.6L15 11.2L14.42 10.61C14.05 10.23 13.54 10 13 10Z\";\r\nvar mdiFolderHome = \"M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M17 13V17H15V14H13V17H11V13H9L14 9L19 13Z\";\r\nvar mdiFolderHomeOutline = \"M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M20 18H4V8H20M13 17V14H15V17H17V13H19L14 9L9 13H11V17Z\";\r\nvar mdiFolderImage = \"M5,17L9.5,11L13,15.5L15.5,12.5L19,17M20,6H12L10,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8A2,2 0 0,0 20,6Z\";\r\nvar mdiFolderInformation = \"M21 11.1V8C21 6.9 20.1 6 19 6H11L9 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H10.3C11.6 21.9 13.8 23 16 23C19.9 23 23 19.9 23 16C23 14.2 22.3 12.4 21 11.1M16 21C13.2 21 11 18.8 11 16S13.2 11 16 11 21 13.2 21 16 18.8 21 16 21M17 20H15V15H17V20M17 14H15V12H17V14Z\";\r\nvar mdiFolderInformationOutline = \"M21 11.1V8C21 6.9 20.1 6 19 6H11L9 4H3C1.9 4 1 4.9 1 6V18C1 19.1 1.9 20 3 20H10.2C11.4 21.8 13.6 23 16 23C19.9 23 23 19.9 23 16C23 14.1 22.2 12.4 21 11.1M9.3 18H3V8H19V9.7C18.1 9.2 17.1 9 16 9C12.1 9 9 12.1 9 16C9 16.7 9.1 17.4 9.3 18M16 21C13.2 21 11 18.8 11 16S13.2 11 16 11 21 13.2 21 16 18.8 21 16 21M17 14H15V12H17V14M17 20H15V15H17V20Z\";\r\nvar mdiFolderKey = \"M4,4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8A2,2 0 0,0 20,6H12L10,4M11,10C12.31,10 13.42,10.84 13.83,12H19V14H18V16H16V14H13.83C13.42,15.17 12.31,16 11,16A3,3 0 0,1 8,13A3,3 0 0,1 11,10M11,12A1,1 0 0,0 10,13C10,13.56 10.45,14 11,14A1,1 0 0,0 12,13A1,1 0 0,0 11,12Z\";\r\nvar mdiFolderKeyNetwork = \"M6,5C4.89,5 4,5.89 4,7V15A2,2 0 0,0 6,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15A1,1 0 0,0 14,19H13V17H18A2,2 0 0,0 20,15V9A2,2 0 0,0 18,7H12L10,5H6M9,9C10.31,9 11.42,9.83 11.83,11H17V13H16V15H14V13H11.83C11.42,14.17 10.31,15 9,15A3,3 0 0,1 6,12A3,3 0 0,1 9,9M9,11A1,1 0 0,0 8,12C8,12.56 8.45,13 9,13A1,1 0 0,0 10,12A1,1 0 0,0 9,11Z\";\r\nvar mdiFolderKeyNetworkOutline = \"M9 8C7.34 8 6 9.34 6 11S7.34 14 9 14C10.31 14 11.42 13.17 11.83 12H14V14H16V12H17V10H11.83C11.42 8.83 10.31 8 9 8M9 12C8.45 12 8 11.55 8 11S8.45 10 9 10 10 10.45 10 11 9.55 12 9 12M15 20C15 19.45 14.55 19 14 19H13V17H19C20.11 17 21 16.11 21 15V7C21 5.9 20.11 5 19 5H13L11 3H5C3.9 3 3 3.9 3 5V15C3 16.11 3.9 17 5 17H11V19H10C9.45 19 9 19.45 9 20H2V22H9C9 22.55 9.45 23 10 23H14C14.55 23 15 22.55 15 22H22V20H15M5 15V7H19V15H5Z\";\r\nvar mdiFolderKeyOutline = \"M20 18H4V8H20M20 6H12L10 4H4C2.89 4 2 4.89 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.89 21.1 6 20 6M13.83 12C13.42 10.84 12.31 10 11 10C9.34 10 8 11.34 8 13S9.34 16 11 16C12.31 16 13.42 15.17 13.83 14H16V16H18V14H19V12H13.83M11 14C10.45 14 10 13.56 10 13C10 12.45 10.45 12 11 12S12 12.45 12 13 11.55 14 11 14Z\";\r\nvar mdiFolderLock = \"M20,6A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10L12,6H20M19,17V13H18V12A3,3 0 0,0 15,9A3,3 0 0,0 12,12V13H11V17H19M15,11A1,1 0 0,1 16,12V13H14V12A1,1 0 0,1 15,11Z\";\r\nvar mdiFolderLockOpen = \"M20,6A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10L12,6H20M19,17V13H18L16,13H14V11A1,1 0 0,1 15,10A1,1 0 0,1 16,11H18A3,3 0 0,0 15,8A3,3 0 0,0 12,11V13H11V17H19Z\";\r\nvar mdiFolderMarker = \"M10 4L12 6H20C21.1 6 22 6.89 22 8V11.34C21.04 10.5 19.82 10 18.5 10C15.5 10 13 12.65 13 15.5C13 16.97 13.65 18.55 14.5 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10M18.5 12C20.4 12 22 13.6 22 15.5C22 18.1 18.5 22 18.5 22C18.5 22 15 18.1 15 15.5C15 13.6 16.6 12 18.5 12M18.5 16.8C19.2 16.8 19.8 16.2 19.7 15.6C19.7 15 19.1 14.4 18.5 14.4C17.9 14.4 17.3 14.9 17.3 15.6C17.3 16.2 17.8 16.8 18.5 16.8Z\";\r\nvar mdiFolderMarkerOutline = \"M18.5 12C20.4 12 22 13.6 22 15.5C22 18.1 18.5 22 18.5 22C18.5 22 15 18.1 15 15.5C15 13.6 16.6 12 18.5 12M18.5 16.8C19.2 16.8 19.8 16.2 19.7 15.6C19.7 15 19.1 14.4 18.5 14.4C17.9 14.4 17.3 14.9 17.3 15.6C17.3 16.2 17.8 16.8 18.5 16.8M20 8H4V18H13.5C13.79 18.68 14.13 19.35 14.5 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10L12 6H20C21.1 6 22 6.89 22 8V11.34C21.42 10.84 20.74 10.45 20 10.23V8Z\";\r\nvar mdiFolderMove = \"M14,18V15H10V11H14V8L19,13M20,6H12L10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6Z\";\r\nvar mdiFolderMoveOutline = \"M20 18H4V8H20V18M12 6L10 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H20C21.11 20 22 19.11 22 18V8C22 6.9 21.11 6 20 6H12M11 14V12H15V9L19 13L15 17V14H11Z\";\r\nvar mdiFolderMultiple = \"M22,4H14L12,2H6A2,2 0 0,0 4,4V16A2,2 0 0,0 6,18H22A2,2 0 0,0 24,16V6A2,2 0 0,0 22,4M2,6H0V11H0V20A2,2 0 0,0 2,22H20V20H2V6Z\";\r\nvar mdiFolderMultipleImage = \"M7,15L11.5,9L15,13.5L17.5,10.5L21,15M22,4H14L12,2H6A2,2 0 0,0 4,4V16A2,2 0 0,0 6,18H22A2,2 0 0,0 24,16V6A2,2 0 0,0 22,4M2,6H0V11H0V20A2,2 0 0,0 2,22H20V20H2V6Z\";\r\nvar mdiFolderMultipleOutline = \"M22,4A2,2 0 0,1 24,6V16A2,2 0 0,1 22,18H6A2,2 0 0,1 4,16V4A2,2 0 0,1 6,2H12L14,4H22M2,6V20H20V22H2A2,2 0 0,1 0,20V11H0V6H2M6,6V16H22V6H6Z\";\r\nvar mdiFolderMultiplePlus = \"M2 20V6H0V20C0 21.1 .9 22 2 22H20V20H2M22 4H14L12 2H6C5.6 2 5.2 2.1 4.9 2.3L4.3 2.9C4.1 3.2 4 3.6 4 4V16C4 16.4 4.1 16.8 4.3 17.1C4.4 17.2 4.5 17.3 4.5 17.4C5 17.8 5.5 18 6 18H22C23.1 18 24 17.1 24 16V6C24 4.9 23.1 4 22 4M22 12H19V15H17V12H14V10H17V7H19V10H22V12Z\";\r\nvar mdiFolderMultiplePlusOutline = \"M22 4C23.1 4 24 4.9 24 6V16C24 17.1 23.1 18 22 18H6C4.9 18 4 17.1 4 16V4C4 2.9 4.9 2 6 2H12L14 4H22M2 6V20H20V22H2C.9 22 0 21.1 0 20V6H2M6 6V16H22V6H6M14 10H16V8H18V10H20V12H18V14H16V12H14V10Z\";\r\nvar mdiFolderMusic = \"M10 4L12 6H20C21.1 6 22 6.89 22 8V18C22 19.1 21.1 20 20 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10M19 9H15.5V13.06L15 13C13.9 13 13 13.9 13 15C13 16.11 13.9 17 15 17C16.11 17 17 16.11 17 15V11H19V9Z\";\r\nvar mdiFolderMusicOutline = \"M20 18V8H4V18H20M20 6C21.1 6 22 6.89 22 8V18C22 19.1 21.1 20 20 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10L12 6H20M18 9V11H16V15C16 16.11 15.11 17 14 17C12.9 17 12 16.11 12 15C12 13.9 12.9 13 14 13C14.17 13 14.34 13 14.5 13.06V9H18Z\";\r\nvar mdiFolderNetwork = \"M3,15V5A2,2 0 0,1 5,3H11L13,5H19A2,2 0 0,1 21,7V15A2,2 0 0,1 19,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H5A2,2 0 0,1 3,15Z\";\r\nvar mdiFolderNetworkOutline = \"M15 20C15 19.45 14.55 19 14 19H13V17H19C20.11 17 21 16.11 21 15V7C21 5.9 20.11 5 19 5H13L11 3H5C3.9 3 3 3.9 3 5V15C3 16.11 3.9 17 5 17H11V19H10C9.45 19 9 19.45 9 20H2V22H9C9 22.55 9.45 23 10 23H14C14.55 23 15 22.55 15 22H22V20H15M5 15V7H19V15H5Z\";\r\nvar mdiFolderOpen = \"M19,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10L12,6H19A2,2 0 0,1 21,8H21L4,8V18L6.14,10H23.21L20.93,18.5C20.7,19.37 19.92,20 19,20Z\";\r\nvar mdiFolderOpenOutline = \"M6.1,10L4,18V8H21A2,2 0 0,0 19,6H12L10,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H19C19.9,20 20.7,19.4 20.9,18.5L23.2,10H6.1M19,18H6L7.6,12H20.6L19,18Z\";\r\nvar mdiFolderOutline = \"M20,18H4V8H20M20,6H12L10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6Z\";\r\nvar mdiFolderPlus = \"M10,4L12,6H20A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10M15,9V12H12V14H15V17H17V14H20V12H17V9H15Z\";\r\nvar mdiFolderPlusOutline = \"M12 12H14V10H16V12H18V14H16V16H14V14H12V12M22 8V18C22 19.11 21.11 20 20 20H4C2.89 20 2 19.11 2 18V6C2 4.89 2.89 4 4 4H10L12 6H20C21.11 6 22 6.89 22 8M20 8H4V18H20V8Z\";\r\nvar mdiFolderPound = \"M15.25,13H17.25L16.75,15H14.75L15.25,13M22,8V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6C2,4.89 2.89,4 4,4H10L12,6H20A2,2 0 0,1 22,8M20,12H18.5L19,10H18L17.5,12H15.5L16,10H15L14.5,12H13V13H14.25L13.75,15H12V16H13.5L13,18H14L14.5,16H16.5L16,18H17L17.5,16H19V15H17.75L18.25,13H20V12Z\";\r\nvar mdiFolderPoundOutline = \"M20,18H4V8H20M20,6H12L10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6M19,12V11H17.5L18,9H17L16.5,11H14.5L15,9H14L13.5,11H12V12H13.25L12.75,14H11V15H12.5L12,17H13L13.5,15H15.5L15,17H16L16.5,15H18V14H16.75L17.25,12H19M15.75,14H13.75L14.25,12H16.25L15.75,14Z\";\r\nvar mdiFolderRefresh = \"M18 14.5C19.11 14.5 20.11 14.95 20.83 15.67L22 14.5V18.5H18L19.77 16.73C19.32 16.28 18.69 16 18 16C16.62 16 15.5 17.12 15.5 18.5C15.5 19.88 16.62 21 18 21C18.82 21 19.54 20.61 20 20H21.71C21.12 21.47 19.68 22.5 18 22.5C15.79 22.5 14 20.71 14 18.5C14 16.29 15.79 14.5 18 14.5M10 4L12 6H20C21.1 6 22 6.89 22 8V13C21 12.38 19.79 12 18.5 12C14.91 12 12 14.91 12 18.5C12 19 12.06 19.5 12.17 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10Z\";\r\nvar mdiFolderRefreshOutline = \"M18 14.5C19.11 14.5 20.11 14.95 20.83 15.67L22 14.5V18.5H18L19.77 16.73C19.32 16.28 18.69 16 18 16C16.62 16 15.5 17.12 15.5 18.5C15.5 19.88 16.62 21 18 21C18.82 21 19.54 20.61 20 20H21.71C21.12 21.47 19.68 22.5 18 22.5C15.79 22.5 14 20.71 14 18.5C14 16.29 15.79 14.5 18 14.5M20 8H4V18H12L12 18.5C12 19 12.06 19.5 12.17 20H4C2.89 20 2 19.1 2 18L2 6C2 4.89 2.89 4 4 4H10L12 6H20C21.1 6 22 6.89 22 8V13C21.39 12.63 20.72 12.34 20 12.17V8Z\";\r\nvar mdiFolderRemove = \"M10,4L12,6H20A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10M12.46,10.88L14.59,13L12.46,15.12L13.88,16.54L16,14.41L18.12,16.54L19.54,15.12L17.41,13L19.54,10.88L18.12,9.46L16,11.59L13.88,9.46L12.46,10.88Z\";\r\nvar mdiFolderRemoveOutline = \"M11.46 10.88L12.88 9.46L15 11.59L17.12 9.46L18.54 10.88L16.41 13L18.54 15.12L17.12 16.54L15 14.41L12.88 16.54L11.46 15.12L13.59 13L11.46 10.88M22 8V18C22 19.11 21.11 20 20 20H4C2.9 20 2 19.11 2 18V6C2 4.89 2.9 4 4 4H10L12 6H20C21.11 6 22 6.9 22 8M20 8H4V18H20V8Z\";\r\nvar mdiFolderSearch = \"M16.5,12C19,12 21,14 21,16.5C21,17.38 20.75,18.21 20.31,18.9L23.39,22L22,23.39L18.88,20.32C18.19,20.75 17.37,21 16.5,21C14,21 12,19 12,16.5C12,14 14,12 16.5,12M16.5,14A2.5,2.5 0 0,0 14,16.5A2.5,2.5 0 0,0 16.5,19A2.5,2.5 0 0,0 19,16.5A2.5,2.5 0 0,0 16.5,14M9,4L11,6H19A2,2 0 0,1 21,8V11.81C19.83,10.69 18.25,10 16.5,10A6.5,6.5 0 0,0 10,16.5C10,17.79 10.37,19 11,20H3C1.89,20 1,19.1 1,18V6C1,4.89 1.89,4 3,4H9Z\";\r\nvar mdiFolderSearchOutline = \"M16.5,12C19,12 21,14 21,16.5C21,17.38 20.75,18.21 20.31,18.9L23.39,22L22,23.39L18.88,20.32C18.19,20.75 17.37,21 16.5,21C14,21 12,19 12,16.5C12,14 14,12 16.5,12M16.5,14A2.5,2.5 0 0,0 14,16.5A2.5,2.5 0 0,0 16.5,19A2.5,2.5 0 0,0 19,16.5A2.5,2.5 0 0,0 16.5,14M19,8H3V18H10.17C10.34,18.72 10.63,19.39 11,20H3C1.89,20 1,19.1 1,18V6C1,4.89 1.89,4 3,4H9L11,6H19A2,2 0 0,1 21,8V11.81C20.42,11.26 19.75,10.81 19,10.5V8Z\";\r\nvar mdiFolderSettings = \"M4 4C2.89 4 2 4.89 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8C22 6.89 21.1 6 20 6H12L10 4H4M7 22V24H9V22H7M11 22V24H13V22H11M15 22V24H17V22H15Z\";\r\nvar mdiFolderSettingsOutline = \"M4 4C2.89 4 2 4.89 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8C22 6.89 21.1 6 20 6H12L10 4H4M4 8H20V18H4V8M7 22V24H9V22H7M11 22V24H13V22H11M15 22V24H17V22H15\";\r\nvar mdiFolderStar = \"M20,6H12L10,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8A2,2 0 0,0 20,6M17.94,17L15,15.28L12.06,17L12.84,13.67L10.25,11.43L13.66,11.14L15,8L16.34,11.14L19.75,11.43L17.16,13.67L17.94,17Z\";\r\nvar mdiFolderStarMultiple = \"M2 6H0V20C0 21.11 .895 22 2 22H20V20H2V6M22 4H14L12 2H6C4.89 2 4 2.89 4 4V16C4 17.1 4.89 18 6 18H22C23.11 18 24 17.1 24 16V6C24 4.89 23.11 4 22 4M19.94 15L17 13.27L14.06 15L14.84 11.66L12.25 9.42L15.66 9.13L17 6L18.34 9.13L21.75 9.42L19.16 11.66L19.94 15Z\";\r\nvar mdiFolderStarMultipleOutline = \"M2 6V20H20V22H2C.895 22 0 21.11 0 20V6H2M12.78 10.05L15.81 9.79L17 7L18.19 9.79L21.22 10.05L18.92 12.04L19.61 15L17 13.47L14.39 15L15.08 12.04L12.78 10.05M24 6V16C24 17.11 23.11 18 22 18H6C4.9 18 4 17.11 4 16V4C4 2.89 4.9 2 6 2H12L14 4H22C23.11 4 24 4.9 24 6M22 6H6V16H22V6Z\";\r\nvar mdiFolderStarOutline = \"M10.78 12.05L13.81 11.79L15 9L16.19 11.79L19.22 12.05L16.92 14.04L17.61 17L15 15.47L12.39 17L13.08 14.04L10.78 12.05M22 8V18C22 19.11 21.11 20 20 20H4C2.9 20 2 19.11 2 18V6C2 4.89 2.9 4 4 4H10L12 6H20C21.11 6 22 6.9 22 8M20 8H4V18H20V8Z\";\r\nvar mdiFolderSwap = \"M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M15 16V14H9V16L6 13L9 10V12H15V10L18 13Z\";\r\nvar mdiFolderSwapOutline = \"M20 18H4V8H20M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M18 13L15 10V12H9V10L6 13L9 16V14H15V16Z\";\r\nvar mdiFolderSync = \"M10,4L12,6H20A2,2 0 0,1 22,8V11.5C21.23,11.18 20.39,11 19.5,11A6.5,6.5 0 0,0 13,17.5C13,18.39 13.18,19.23 13.5,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10M19,12V13.5A4,4 0 0,1 23,17.5C23,18.32 22.75,19.08 22.33,19.71L21.24,18.62C21.41,18.28 21.5,17.9 21.5,17.5A2.5,2.5 0 0,0 19,15V16.5L16.75,14.25L19,12M19,23V21.5A4,4 0 0,1 15,17.5C15,16.68 15.25,15.92 15.67,15.29L16.76,16.38C16.59,16.72 16.5,17.1 16.5,17.5A2.5,2.5 0 0,0 19,20V18.5L21.25,20.75L19,23Z\";\r\nvar mdiFolderSyncOutline = \"M10,4L12,6H20A2,2 0 0,1 22,8V11.5C21.38,11.24 20.7,11.07 20,11V8H4V18H13C13.07,18.7 13.24,19.38 13.5,20H4C2.89,20 2,19.1 2,18V6C2,4.89 2.89,4 4,4H10M19,12V13.5A4,4 0 0,1 23,17.5C23,18.32 22.75,19.08 22.33,19.71L21.24,18.62C21.41,18.28 21.5,17.9 21.5,17.5A2.5,2.5 0 0,0 19,15V16.5L16.75,14.25L16.72,14.22C16.78,14.17 16.85,14.13 19,12M19,23V21.5A4,4 0 0,1 15,17.5C15,16.68 15.25,15.92 15.67,15.29L16.76,16.38C16.59,16.72 16.5,17.1 16.5,17.5A2.5,2.5 0 0,0 19,20V18.5L21.25,20.75L21.28,20.78C21.22,20.83 21.15,20.87 19,23Z\";\r\nvar mdiFolderTable = \"M4 4C2.89 4 2 4.89 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8C22 6.89 21.1 6 20 6H12L10 4H4M12 9H15V11H12V9M16 9H19V11H16V9M12 12H15V14H12V12M16 12H19V14H16V12M12 15H15V17H12V15M16 15H19V17H16V15Z\";\r\nvar mdiFolderTableOutline = \"M4 4C2.89 4 2 4.89 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8C22 6.89 21.1 6 20 6H12L10 4H4M4 8H20V18H4V8M12 9V11H15V9H12M16 9V11H19V9H16M12 12V14H15V12H12M16 12V14H19V12H16M12 15V17H15V15H12M16 15V17H19V15H16Z\";\r\nvar mdiFolderText = \"M20,6H12L10,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8A2,2 0 0,0 20,6M15,16H6V14H15V16M18,12H6V10H18V12Z\";\r\nvar mdiFolderTextOutline = \"M20,18H4V8H20M20,6H12L10,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8A2,2 0 0,0 20,6M15,16H6V14H15V16M18,12H6V10H18V12Z\";\r\nvar mdiFolderUpload = \"M20,6A2,2 0 0,1 22,8V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H10L12,6H20M10.75,13H14V17H16V13H19.25L15,8.75\";\r\nvar mdiFolderUploadOutline = \"M20 18H4V8H20M20 6H12L10 4H4A2 2 0 0 0 2 6V18A2 2 0 0 0 4 20H20A2 2 0 0 0 22 18V8A2 2 0 0 0 20 6M16 17H14V13H11L15 9L19 13H16Z\";\r\nvar mdiFolderZip = \"M20 6H12L10 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6M18 12H16V14H18V16H16V18H14V16H16V14H14V12H16V10H14V8H16V10H18V12Z\";\r\nvar mdiFolderZipOutline = \"M20 6H12L10 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6M20 18H16V16H14V18H4V8H14V10H16V8H20V18M16 12V10H18V12H16M14 12H16V14H14V12M18 16H16V14H18V16Z\";\r\nvar mdiFontAwesome = \"M19.76 2H4.24C3 2 2 3 2 4.24V19.76C2 21 3 22 4.24 22H19.76C21 22 22 21 22 19.76V4.24C22 3 21 2 19.76 2M17.73 14.69C17.73 14.88 17.57 14.96 17.38 15.04C16.64 15.36 15.84 15.65 15 15.65C13.78 15.65 13.22 14.91 11.78 14.91C10.74 14.91 9.65 15.28 8.77 15.68C8.71 15.71 8.66 15.71 8.61 15.73V17.76C8.61 17.84 8.61 17.92 8.58 17.97V18.03C8.47 18.4 8.13 18.67 7.73 18.67C7.22 18.67 6.82 18.26 6.82 17.76V8C6.47 7.73 6.24 7.31 6.24 6.83C6.24 6 6.9 5.33 7.73 5.33C8.56 5.33 9.23 6 9.23 6.83C9.23 7.31 9 7.73 8.64 8V8.83C8.72 8.8 8.8 8.77 8.88 8.72C9.71 8.37 10.7 8.08 11.63 8.08C12.64 8.08 13.44 8.35 14.35 8.69C14.54 8.77 14.72 8.8 14.93 8.8C15.95 8.8 17.07 8.08 17.34 8.08C17.55 8.08 17.74 8.24 17.74 8.43V14.69H17.73Z\";\r\nvar mdiFood = \"M15.5,21L14,8H16.23L15.1,3.46L16.84,3L18.09,8H22L20.5,21H15.5M5,11H10A3,3 0 0,1 13,14H2A3,3 0 0,1 5,11M13,18A3,3 0 0,1 10,21H5A3,3 0 0,1 2,18H13M3,15H8L9.5,16.5L11,15H12A1,1 0 0,1 13,16A1,1 0 0,1 12,17H3A1,1 0 0,1 2,16A1,1 0 0,1 3,15Z\";\r\nvar mdiFoodApple = \"M20,10C22,13 17,22 15,22C13,22 13,21 12,21C11,21 11,22 9,22C7,22 2,13 4,10C6,7 9,7 11,8V5C5.38,8.07 4.11,3.78 4.11,3.78C4.11,3.78 6.77,0.19 11,5V3H13V8C15,7 18,7 20,10Z\";\r\nvar mdiFoodAppleOutline = \"M20,10C18.58,7.57 15.5,6.69 13,8V3H11V8C8.5,6.69 5.42,7.57 4,10C2,13 7,22 9,22C11,22 11,21 12,21C13,21 13,22 15,22C17,22 22,13 20,10M18.25,13.38C17.63,15.85 16.41,18.12 14.7,20C14.5,20 14.27,19.9 14.1,19.75C12.87,18.76 11.13,18.76 9.9,19.75C9.73,19.9 9.5,20 9.3,20C7.59,18.13 6.36,15.85 5.75,13.39C5.5,12.66 5.45,11.87 5.66,11.12C6.24,10.09 7.32,9.43 8.5,9.4C9.06,9.41 9.61,9.54 10.11,9.79L11,10.24H13L13.89,9.79C14.39,9.54 14.94,9.41 15.5,9.4C16.68,9.43 17.76,10.08 18.34,11.11C18.55,11.86 18.5,12.65 18.25,13.38M11,5C5.38,8.07 4.11,3.78 4.11,3.78C4.11,3.78 6.77,0.19 11,5Z\";\r\nvar mdiFoodCroissant = \"M22,19L19,17L22,15V19M15,15L19,9L22,13L18,16L15,15M5,17L2,19V15L5,17M9,15L6,16L2,13L5,9L9,15M14,6L18,8L13,15H11L6,8L10,6H14Z\";\r\nvar mdiFoodDrumstick = \"M20.16 12.73C22.93 9.96 22.57 5.26 19.09 3C17.08 1.67 14.39 1.66 12.36 2.97C10.6 4.1 9.63 5.86 9.46 7.68C9.33 9 8.83 10.23 7.91 11.15L7.88 11.18C6.72 12.34 6.72 14.11 7.81 15.19L8.8 16.18C9.89 17.27 11.66 17.27 12.75 16.18C13.72 15.21 15 14.68 16.39 14.53C17.76 14.38 19.1 13.78 20.16 12.73M6.26 19.86C6.53 20.42 6.44 21.1 5.97 21.56C5.39 22.15 4.44 22.15 3.85 21.56C3.58 21.29 3.44 20.94 3.42 20.58C3.06 20.56 2.71 20.42 2.44 20.15C1.85 19.56 1.85 18.61 2.44 18.03C2.9 17.57 3.59 17.47 4.14 17.74L6.62 15.31C6.76 15.5 6.92 15.72 7.1 15.9L8.09 16.89C8.3 17.09 8.5 17.26 8.76 17.41L6.26 19.86Z\";\r\nvar mdiFoodDrumstickOff = \"M20.8 22.7L13.6 15.5C13.3 15.7 13 15.9 12.7 16.2C11.6 17.3 9.8 17.3 8.7 16.2L7.7 15.2C6.6 14.1 6.6 12.3 7.8 11.2C8 11 8.2 10.7 8.4 10.4L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M8.1 16.9L7.1 15.9C6.9 15.7 6.8 15.5 6.6 15.3L4.1 17.7C3.5 17.4 2.9 17.5 2.4 18C1.8 18.6 1.8 19.5 2.4 20.1C2.7 20.4 3 20.5 3.4 20.5C3.4 20.9 3.6 21.2 3.8 21.5C4.4 22.1 5.3 22.1 5.9 21.5C6.4 21 6.5 20.4 6.2 19.8L8.7 17.4C8.5 17.3 8.3 17.1 8.1 16.9M20.2 12.7C23 9.9 22.6 5.2 19.1 3C17.1 1.7 14.4 1.7 12.4 3C11 3.9 10.1 5.1 9.7 6.5L17.5 14.3C18.5 14 19.4 13.5 20.2 12.7Z\";\r\nvar mdiFoodDrumstickOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L8.5 10.4C8.3 10.7 8.1 10.9 7.9 11.2C6.7 12.4 6.7 14.1 7.8 15.2L8.8 16.2C9.3 16.7 10.1 17 10.8 17C11.5 17 12.2 16.7 12.8 16.2C13.1 15.9 13.4 15.7 13.7 15.5L20.9 22.7L22.1 21.5M11.3 14.8C11.1 15 10.9 15 10.8 15S10.4 15 10.2 14.8L9.2 13.8C9 13.6 9 13.4 9 13.2C9 13 9.1 12.7 9.3 12.5C9.5 12.3 9.7 12 9.9 11.8L12.1 14C11.9 14.3 11.6 14.5 11.3 14.8M11.4 8.2L9.7 6.5C10.1 5.1 11 3.9 12.4 3C13.4 2.4 14.6 2 15.7 2C16.9 2 18.1 2.3 19.1 3C22.6 5.3 22.9 10 20.2 12.7C19.4 13.5 18.5 14 17.5 14.3L15.8 12.6C15.9 12.6 16 12.5 16.2 12.5C17.2 12.4 18.1 12 18.8 11.3C19.7 10.4 20.2 9.1 20 7.8C19.9 6.5 19.2 5.4 18 4.6C17.3 4.2 16.5 4 15.7 4C14.9 4 14.1 4.2 13.4 4.7C12.2 5.4 11.5 6.6 11.4 7.9V8.2M8.8 17.4L6.3 19.8C6.6 20.4 6.5 21 6 21.5C5.4 22.1 4.5 22.1 3.9 21.5C3.6 21.2 3.5 20.9 3.5 20.5C3.1 20.5 2.8 20.3 2.5 20.1C1.9 19.5 1.9 18.6 2.5 18C3 17.5 3.6 17.4 4.2 17.7L6.7 15.3C6.8 15.5 7 15.7 7.2 15.9L8.2 16.9C8.3 17.1 8.5 17.3 8.8 17.4\";\r\nvar mdiFoodDrumstickOutline = \"M15.71 4C16.54 4 17.33 4.22 18 4.66C19.14 5.4 19.84 6.53 20 7.84C20.11 9.13 19.66 10.4 18.75 11.31C18.05 12 17.16 12.44 16.18 12.54C14.27 12.74 12.59 13.5 11.34 14.77C11.13 14.97 10.9 15 10.77 15C10.65 15 10.42 14.97 10.21 14.77L9.22 13.78C9.04 13.6 9 13.39 9 13.25C9 13 9.11 12.78 9.32 12.57C10.53 11.35 11.27 9.73 11.45 7.87C11.58 6.54 12.29 5.4 13.45 4.65C14.11 4.22 14.89 4 15.71 4M15.71 2C14.54 2 13.37 2.32 12.36 2.97C10.6 4.1 9.63 5.86 9.46 7.68C9.33 9 8.83 10.23 7.91 11.15L7.88 11.18C6.72 12.34 6.72 14.11 7.81 15.19L8.8 16.18C9.35 16.73 10.06 17 10.77 17S12.2 16.73 12.75 16.18C13.72 15.21 15 14.68 16.39 14.53C17.76 14.38 19.1 13.78 20.16 12.73C22.93 9.96 22.57 5.26 19.09 3C18.08 2.33 16.9 2 15.71 2M6.26 19.86C6.53 20.42 6.44 21.1 5.97 21.56C5.39 22.15 4.44 22.15 3.85 21.56C3.58 21.29 3.44 20.94 3.42 20.58C3.06 20.56 2.71 20.42 2.44 20.15C1.85 19.56 1.85 18.61 2.44 18.03C2.9 17.57 3.59 17.47 4.14 17.74L6.62 15.31C6.76 15.5 6.92 15.72 7.1 15.9L8.09 16.89C8.3 17.09 8.5 17.26 8.76 17.41L6.26 19.86Z\";\r\nvar mdiFoodForkDrink = \"M3,3A1,1 0 0,0 2,4V8L2,9.5C2,11.19 3.03,12.63 4.5,13.22V19.5A1.5,1.5 0 0,0 6,21A1.5,1.5 0 0,0 7.5,19.5V13.22C8.97,12.63 10,11.19 10,9.5V8L10,4A1,1 0 0,0 9,3A1,1 0 0,0 8,4V8A0.5,0.5 0 0,1 7.5,8.5A0.5,0.5 0 0,1 7,8V4A1,1 0 0,0 6,3A1,1 0 0,0 5,4V8A0.5,0.5 0 0,1 4.5,8.5A0.5,0.5 0 0,1 4,8V4A1,1 0 0,0 3,3M19.88,3C19.75,3 19.62,3.09 19.5,3.16L16,5.25V9H12V11H13L14,21H20L21,11H22V9H18V6.34L20.5,4.84C21,4.56 21.13,4 20.84,3.5C20.63,3.14 20.26,2.95 19.88,3Z\";\r\nvar mdiFoodHalal = \"M7 5V15C7 16.11 6.11 17 5 17H4C3.45 17 3 16.55 3 16V13H1V16C1 17.66 2.34 19 4 19H5C7.21 19 9 17.21 9 15V5M23 13.38L21.77 12.15C21.03 11.41 20.04 11 19 11H17V13H19C19.5 13 20 13.2 20.35 13.56L20.7 13.91L19.5 14.6C19.04 14.86 18.53 15 18 15H17C16.44 15 16 14.56 16 14V6H14V9.81L13.38 9.12C12.7 8.37 11.6 8 10.59 8H10V10H10.59C11.23 10 11.84 10.25 12.29 10.71L14 12.41V14C14 15.12 13.12 16 12 16H10V18H12C13.37 18 14.5 17.3 15.17 16.24C15.63 16.71 16.25 17 17 17H18C18.88 17 19.74 16.77 20.5 16.33L23 14.89Z\";\r\nvar mdiFoodKosher = \"M1 7V9H3C3.57 9 4 9.43 4 10V17H6V10C6 8.36 4.64 7 3 7H1M7 7V14C7 15.65 8.36 17 10 17H14C15.65 17 17 15.65 17 14V7H15V14C15 14.57 14.57 15 14 15H10C9.43 15 9 14.57 9 14V13H10C11.65 13 13 11.65 13 10V7H11V10C11 10.57 10.57 11 10 11H9V7H7M18 7V9H20C20.57 9 21 9.43 21 10V14C21 14.57 20.57 15 20 15H18V17H20C21.65 17 23 15.65 23 14V10C23 8.36 21.65 7 20 7H18Z\";\r\nvar mdiFoodOff = \"M2,5.27L3.28,4L21,21.72L19.73,23L17.73,21H15.5L15.21,18.5L12.97,16.24C12.86,16.68 12.47,17 12,17H3A1,1 0 0,1 2,16A1,1 0 0,1 3,15H8L9.5,16.5L11,15H11.73L10.73,14H2A3,3 0 0,1 5,11H7.73L2,5.27M14,8H16.23L15.1,3.46L16.84,3L18.09,8H22L20.74,18.92L14.54,12.72L14,8M13,18A3,3 0 0,1 10,21H5A3,3 0 0,1 2,18H13Z\";\r\nvar mdiFoodSteak = \"M11.9 2C8 2 4.9 5.4 5 9.3C5.1 11.9 6.6 14.1 8.7 15.2C10.1 15.9 11 17.3 11 18.8V19C11 20.7 12.3 22 14 22C18 22 19 17 19 9C19 9 19 2 11.9 2M14 20C13.4 20 13 19.6 13 19V18.8C13 16.6 11.7 14.5 9.7 13.4C8.1 12.6 7.1 11 7 9.2C7 7.9 7.5 6.5 8.4 5.5C9.3 4.5 10.6 4 11.8 4C16.7 4 17 8.2 17 9C17 18.9 15.3 20 14 20M15.8 7.6L8.3 10.3C8.1 10 8 9.6 8 9.1C8 8.4 8.2 7.8 8.5 7.1L13.7 5.2C14.9 5.8 15.5 6.7 15.8 7.6M12.9 15.1L15.7 14.1C15.6 15.6 15.3 16.7 15.1 17.4L13.8 17.9C13.8 16.9 13.5 16 12.9 15.1M16 9.2C16 10.4 16 11.5 15.9 12.4L11.9 13.9C11.4 13.4 10.8 12.9 10.1 12.6C9.7 12.4 9.3 12.1 9 11.8L16 9.2Z\";\r\nvar mdiFoodSteakOff = \"M2.39 1.73L1.11 3L5.27 7.16C5.08 7.83 5 8.53 5 9.26C5.1 11.83 6.59 14.05 8.74 15.19C10.1 15.9 11 17.25 11 18.79V19C11 20.66 12.34 22 14 22C15.68 22 16.83 21.11 17.6 19.5L20.84 22.73L22.11 21.46L2.39 1.73M14 20C13.45 20 13 19.55 13 19V18.79C13 16.56 11.72 14.5 9.67 13.42C8.09 12.58 7.07 10.96 7 9.18C7 9.09 7 9 7 8.9L8.16 10.05C8.19 10.15 8.21 10.25 8.24 10.35L8.4 10.29L9.62 11.5L9.08 11.71C9.38 12.04 9.73 12.32 10.14 12.53C10.81 12.89 11.4 13.34 11.91 13.85L11.95 13.84L13.17 15.06L12.95 15.14C13.46 15.96 13.8 16.89 13.93 17.85L15.2 17.39C15.22 17.32 15.25 17.24 15.27 17.16L16.07 17.96C15.47 19.68 14.68 20 14 20M15.79 7.6L12.14 8.94L9.88 6.68L13.69 5.3C14.94 5.77 15.53 6.72 15.79 7.6M8.59 5.39L7.17 3.97C8.41 2.77 10.07 2 11.88 2H11.88C19 2 19 9 19 9C19 11.46 18.9 13.63 18.66 15.46L16.84 13.64C16.94 12.36 17 10.83 17 9C17 8.18 16.69 4 11.88 4H11.88C10.67 4 9.5 4.5 8.59 5.39M15.68 12.5L13.36 10.15L16 9.19C16 10.41 15.97 11.46 15.92 12.4L15.68 12.5Z\";\r\nvar mdiFoodVariant = \"M22,18A4,4 0 0,1 18,22H15A4,4 0 0,1 11,18V16H17.79L20.55,11.23L22.11,12.13L19.87,16H22V18M9,22H2C2,19 2,16 2.33,12.83C2.6,10.3 3.08,7.66 3.6,5H3V3H4L7,3H8V5H7.4C7.92,7.66 8.4,10.3 8.67,12.83C9,16 9,19 9,22Z\";\r\nvar mdiFoodVariantOff = \"M2.28 3L1 4.27L3.31 6.58C2.91 8.7 2.55 10.8 2.33 12.83C2 16 2 19 2 22H9C9 19 9 16 8.67 12.83C8.63 12.5 8.58 12.15 8.54 11.81L12.73 16H11V18C11 20.21 12.79 22 15 22H18C18.23 22 18.45 22 18.67 21.94L19.73 23L21 21.72M4.82 3L7.53 5.71C7.5 5.47 7.45 5.24 7.4 5H8V3H7M20.55 11.23L17.8 16L21.59 19.76C21.86 19.21 22 18.61 22 18V16H19.87L22.11 12.13Z\";\r\nvar mdiFootPrint = \"M16 2A2 2 0 1 1 14 4A2 2 0 0 1 16 2M12.04 3A1.5 1.5 0 1 1 10.54 4.5A1.5 1.5 0 0 1 12.04 3M9.09 4.5A1 1 0 1 1 8.09 5.5A1 1 0 0 1 9.09 4.5M7.04 6A1 1 0 1 1 6.04 7A1 1 0 0 1 7.04 6M14.53 12A2.5 2.5 0 0 0 17 9.24A2.6 2.6 0 0 0 14.39 7H11.91A6 6 0 0 0 6.12 11.4A2 2 0 0 0 6.23 12.8A6.8 6.8 0 0 1 6.91 15.76A6.89 6.89 0 0 1 6.22 18.55A1.92 1.92 0 0 0 6.3 20.31A3.62 3.62 0 0 0 10.19 21.91A3.5 3.5 0 0 0 12.36 16.63A2.82 2.82 0 0 1 11.91 15S11.68 12 14.53 12Z\";\r\nvar mdiFootball = \"M7.5,7.5C9.17,5.87 11.29,4.69 13.37,4.18C15.46,3.67 17.5,3.83 18.6,4C19.71,4.15 19.87,4.31 20.03,5.41C20.18,6.5 20.33,8.55 19.82,10.63C19.31,12.71 18.13,14.83 16.5,16.5C14.83,18.13 12.71,19.31 10.63,19.82C8.55,20.33 6.5,20.18 5.41,20.03C4.31,19.87 4.15,19.71 4,18.6C3.83,17.5 3.67,15.46 4.18,13.37C4.69,11.29 5.87,9.17 7.5,7.5M7.3,15.79L8.21,16.7L9.42,15.5L10.63,16.7L11.54,15.79L10.34,14.58L12,12.91L13.21,14.12L14.12,13.21L12.91,12L14.58,10.34L15.79,11.54L16.7,10.63L15.5,9.42L16.7,8.21L15.79,7.3L14.58,8.5L13.37,7.3L12.46,8.21L13.66,9.42L12,11.09L10.79,9.88L9.88,10.79L11.09,12L9.42,13.66L8.21,12.46L7.3,13.37L8.5,14.58L7.3,15.79Z\";\r\nvar mdiFootballAustralian = \"M7.5,7.5C9.17,5.87 11.29,4.69 13.37,4.18C18,3 21,6 19.82,10.63C19.31,12.71 18.13,14.83 16.5,16.5C14.83,18.13 12.71,19.31 10.63,19.82C6,21 3,18 4.18,13.37C4.69,11.29 5.87,9.17 7.5,7.5M10.62,11.26L10.26,11.62L12.38,13.74L12.74,13.38L10.62,11.26M11.62,10.26L11.26,10.62L13.38,12.74L13.74,12.38L11.62,10.26M9.62,12.26L9.26,12.62L11.38,14.74L11.74,14.38L9.62,12.26M12.63,9.28L12.28,9.63L14.4,11.75L14.75,11.4L12.63,9.28M8.63,13.28L8.28,13.63L10.4,15.75L10.75,15.4L8.63,13.28M13.63,8.28L13.28,8.63L15.4,10.75L15.75,10.4L13.63,8.28Z\";\r\nvar mdiFootballHelmet = \"M13.5,12A1.5,1.5 0 0,0 12,13.5A1.5,1.5 0 0,0 13.5,15A1.5,1.5 0 0,0 15,13.5A1.5,1.5 0 0,0 13.5,12M13.5,3C18.19,3 22,6.58 22,11C22,12.62 22,14 21.09,16C17,16 16,20 12.5,20C10.32,20 9.27,18.28 9.05,16H9L8.24,16L6.96,20.3C6.81,20.79 6.33,21.08 5.84,21H3A1,1 0 0,1 2,20A1,1 0 0,1 3,19V16A1,1 0 0,1 2,15A1,1 0 0,1 3,14H6.75L7.23,12.39C6.72,12.14 6.13,12 5.5,12H5.07L5,11C5,6.58 8.81,3 13.5,3M5,16V19H5.26L6.15,16H5Z\";\r\nvar mdiForklift = \"M6,4V11H4C2.89,11 2,11.89 2,13V17A3,3 0 0,0 5,20A3,3 0 0,0 8,17H10A3,3 0 0,0 13,20A3,3 0 0,0 16,17V13L12,4H6M17,5V19H22V17.5H18.5V5H17M7.5,5.5H11.2L14.5,13H7.5V5.5M5,15.5A1.5,1.5 0 0,1 6.5,17A1.5,1.5 0 0,1 5,18.5A1.5,1.5 0 0,1 3.5,17A1.5,1.5 0 0,1 5,15.5M13,15.5A1.5,1.5 0 0,1 14.5,17A1.5,1.5 0 0,1 13,18.5A1.5,1.5 0 0,1 11.5,17A1.5,1.5 0 0,1 13,15.5Z\";\r\nvar mdiFormDropdown = \"M17 5H20L18.5 7L17 5M3 2H21C22.11 2 23 2.9 23 4V8C23 9.11 22.11 10 21 10H16V20C16 21.11 15.11 22 14 22H3C1.9 22 1 21.11 1 20V4C1 2.9 1.9 2 3 2M3 4V8H14V4H3M21 8V4H16V8H21M3 20H14V10H3V20M5 12H12V14H5V12M5 16H12V18H5V16Z\";\r\nvar mdiFormSelect = \"M15 5H18L16.5 7L15 5M5 2H19C20.11 2 21 2.9 21 4V20C21 21.11 20.11 22 19 22H5C3.9 22 3 21.11 3 20V4C3 2.9 3.9 2 5 2M5 4V8H19V4H5M5 20H19V10H5V20M7 12H17V14H7V12M7 16H17V18H7V16Z\";\r\nvar mdiFormTextarea = \"M13 9H4V23H2V7H13M23 9V7H17V5A1 1 0 0 1 18 4H20V2H17.5C17 2 16 2.45 16 3C16 2.45 15.05 2 14.5 2H12V4H14A1 1 0 0 1 15 5V19A1 1 0 0 1 14 20H12V22H14.5C15.05 22 16 21.55 16 21C16 21.55 16.95 22 17.5 22H20V20H18A1 1 0 0 1 17 19V9Z\";\r\nvar mdiFormTextbox = \"M17,7H22V17H17V19A1,1 0 0,0 18,20H20V22H17.5C16.95,22 16,21.55 16,21C16,21.55 15.05,22 14.5,22H12V20H14A1,1 0 0,0 15,19V5A1,1 0 0,0 14,4H12V2H14.5C15.05,2 16,2.45 16,3C16,2.45 16.95,2 17.5,2H20V4H18A1,1 0 0,0 17,5V7M2,7H13V9H4V15H13V17H2V7M20,15V9H17V15H20Z\";\r\nvar mdiFormTextboxLock = \"M2 7H6V9H4V15H6V17H2V7M10 7H22V12C21.42 11.56 20.74 11.25 20 11.1V9H10V15H14.25C13.56 15 13 15.56 13 16.25V17H10V19C10 19.55 10.45 20 11 20H13V22H10.5C9.95 22 9 21.55 9 21C9 21.55 8.05 22 7.5 22H5V20H7C7.55 20 8 19.55 8 19V5C8 4.45 7.55 4 7 4H5V2H7.5C8.05 2 9 2.45 9 3C9 2.45 9.95 2 10.5 2H13V4H11C10.45 4 10 4.45 10 5V7M21.8 17C22.4 17 23 17.6 23 18.3V21.8C23 22.4 22.4 23 21.7 23H16.2C15.6 23 15 22.4 15 21.7V18.2C15 17.6 15.6 17 16.2 17V15.5C16.2 14.1 17.6 13 19 13C20.4 13 21.8 14.1 21.8 15.5V17M20.5 17V15.5C20.5 14.7 19.8 14.2 19 14.2C18.2 14.2 17.5 14.7 17.5 15.5V17H20.5Z\";\r\nvar mdiFormTextboxPassword = \"M17,7H22V17H17V19A1,1 0 0,0 18,20H20V22H17.5C16.95,22 16,21.55 16,21C16,21.55 15.05,22 14.5,22H12V20H14A1,1 0 0,0 15,19V5A1,1 0 0,0 14,4H12V2H14.5C15.05,2 16,2.45 16,3C16,2.45 16.95,2 17.5,2H20V4H18A1,1 0 0,0 17,5V7M2,7H13V9H4V15H13V17H2V7M20,15V9H17V15H20M8.5,12A1.5,1.5 0 0,0 7,10.5A1.5,1.5 0 0,0 5.5,12A1.5,1.5 0 0,0 7,13.5A1.5,1.5 0 0,0 8.5,12M13,10.89C12.39,10.33 11.44,10.38 10.88,11C10.32,11.6 10.37,12.55 11,13.11C11.55,13.63 12.43,13.63 13,13.11V10.89Z\";\r\nvar mdiFormatAlignBottom = \"M13,9L15.5,6.5L16.92,7.92L12,12.84L7.08,7.92L8.5,6.5L11,9V3H13V9M3,15H21V17H3V15M3,19H13V21H3V19Z\";\r\nvar mdiFormatAlignCenter = \"M3,3H21V5H3V3M7,7H17V9H7V7M3,11H21V13H3V11M7,15H17V17H7V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatAlignJustify = \"M3,3H21V5H3V3M3,7H21V9H3V7M3,11H21V13H3V11M3,15H21V17H3V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatAlignLeft = \"M3,3H21V5H3V3M3,7H15V9H3V7M3,11H21V13H3V11M3,15H15V17H3V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatAlignMiddle = \"M13,6L15,4L16.42,5.42L12,9.84L7.58,5.42L9,4L11,6V2H13V6M3,11H21V13H3V11M13,18V22H11V18L9,20L7.58,18.58L12,14.16L16.42,18.58L15,20L13,18Z\";\r\nvar mdiFormatAlignRight = \"M3,3H21V5H3V3M9,7H21V9H9V7M3,11H21V13H3V11M9,15H21V17H9V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatAlignTop = \"M13,15L15.5,17.5L16.92,16.08L12,11.16L7.08,16.08L8.5,17.5L11,15V21H13V15M3,3H21V5H3V3M3,7H13V9H3V7Z\";\r\nvar mdiFormatAnnotationMinus = \"M10.5,7H8.5L3,21H5.2L6.3,18H12.5L13.6,21H16L10.5,7M7.1,16L9.5,9.7L11.9,16H7.1M22,7H14V5H22V7Z\";\r\nvar mdiFormatAnnotationPlus = \"M8.5,7H10.5L16,21H13.6L12.5,18H6.3L5.2,21H3L8.5,7M7.1,16H11.9L9.5,9.7L7.1,16M22,5V7H19V10H17V7H14V5H17V2H19V5H22Z\";\r\nvar mdiFormatBold = \"M13.5,15.5H10V12.5H13.5A1.5,1.5 0 0,1 15,14A1.5,1.5 0 0,1 13.5,15.5M10,6.5H13A1.5,1.5 0 0,1 14.5,8A1.5,1.5 0 0,1 13,9.5H10M15.6,10.79C16.57,10.11 17.25,9 17.25,8C17.25,5.74 15.5,4 13.25,4H7V18H14.04C16.14,18 17.75,16.3 17.75,14.21C17.75,12.69 16.89,11.39 15.6,10.79Z\";\r\nvar mdiFormatClear = \"M6,5V5.18L8.82,8H11.22L10.5,9.68L12.6,11.78L14.21,8H20V5H6M3.27,5L2,6.27L8.97,13.24L6.5,19H9.5L11.07,15.34L16.73,21L18,19.73L3.55,5.27L3.27,5Z\";\r\nvar mdiFormatColorFill = \"M19,11.5C19,11.5 17,13.67 17,15A2,2 0 0,0 19,17A2,2 0 0,0 21,15C21,13.67 19,11.5 19,11.5M5.21,10L10,5.21L14.79,10M16.56,8.94L7.62,0L6.21,1.41L8.59,3.79L3.44,8.94C2.85,9.5 2.85,10.47 3.44,11.06L8.94,16.56C9.23,16.85 9.62,17 10,17C10.38,17 10.77,16.85 11.06,16.56L16.56,11.06C17.15,10.47 17.15,9.5 16.56,8.94Z\";\r\nvar mdiFormatColorHighlight = \"M4,17L6.75,14.25L6.72,14.23C6.14,13.64 6.14,12.69 6.72,12.11L11.46,7.37L15.7,11.61L10.96,16.35C10.39,16.93 9.46,16.93 8.87,16.37L8.24,17H4M15.91,2.91C16.5,2.33 17.45,2.33 18.03,2.91L20.16,5.03C20.74,5.62 20.74,6.57 20.16,7.16L16.86,10.45L12.62,6.21L15.91,2.91Z\";\r\nvar mdiFormatColorMarkerCancel = \"M16.5 8C14 8 12 10 12 12.5S14 17 16.5 17 21 15 21 12.5 19 8 16.5 8M16.5 15.5C14.8 15.5 13.5 14.2 13.5 12.5C13.5 11.9 13.7 11.4 13.9 11L18 15.1C17.6 15.3 17.1 15.5 16.5 15.5M19.1 14L15 9.9C15.4 9.6 15.9 9.5 16.5 9.5C18.2 9.5 19.5 10.8 19.5 12.5C19.5 13.1 19.3 13.6 19.1 14M12.1 7.7L10.6 6.2L13.9 2.9C14.5 2.3 15.4 2.3 16 2.9L18.2 5C18.6 5.4 18.7 5.8 18.6 6.3C18 6.1 17.3 6 16.6 6C14.8 6 13.3 6.7 12.1 7.7M10.5 14.9L9 16.3C8.4 16.9 7.5 16.9 6.9 16.3L6.2 17H2L4.8 14.2C4.2 13.6 4.2 12.7 4.8 12.1L9.5 7.4L11.1 9C10.4 10 10 11.2 10 12.5C10 13.3 10.2 14.1 10.5 14.9Z\";\r\nvar mdiFormatColorText = \"M9.62,12L12,5.67L14.37,12M11,3L5.5,17H7.75L8.87,14H15.12L16.25,17H18.5L13,3H11Z\";\r\nvar mdiFormatColumns = \"M3,3H11V5H3V3M13,3H21V5H13V3M3,7H11V9H3V7M13,7H21V9H13V7M3,11H11V13H3V11M13,11H21V13H13V11M3,15H11V17H3V15M13,15H21V17H13V15M3,19H11V21H3V19M13,19H21V21H13V19Z\";\r\nvar mdiFormatFloatCenter = \"M9,7H15V13H9V7M3,3H21V5H3V3M3,15H21V17H3V15M3,19H17V21H3V19Z\";\r\nvar mdiFormatFloatLeft = \"M3,7H9V13H3V7M3,3H21V5H3V3M21,7V9H11V7H21M21,11V13H11V11H21M3,15H17V17H3V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatFloatNone = \"M3,7H9V13H3V7M3,3H21V5H3V3M21,11V13H11V11H21M3,15H17V17H3V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatFloatRight = \"M15,7H21V13H15V7M3,3H21V5H3V3M13,7V9H3V7H13M9,11V13H3V11H9M3,15H17V17H3V15M3,19H21V21H3V19Z\";\r\nvar mdiFormatFont = \"M17,8H20V20H21V21H17V20H18V17H14L12.5,20H14V21H10V20H11L17,8M18,9L14.5,16H18V9M5,3H10C11.11,3 12,3.89 12,5V16H9V11H6V16H3V5C3,3.89 3.89,3 5,3M6,5V9H9V5H6Z\";\r\nvar mdiFormatFontSizeDecrease = \"M5.12,14L7.5,7.67L9.87,14M6.5,5L1,19H3.25L4.37,16H10.62L11.75,19H14L8.5,5H6.5M18,17L23,11.93L21.59,10.5L19,13.1V7H17V13.1L14.41,10.5L13,11.93L18,17Z\";\r\nvar mdiFormatFontSizeIncrease = \"M5.12,14L7.5,7.67L9.87,14M6.5,5L1,19H3.25L4.37,16H10.62L11.75,19H14L8.5,5H6.5M18,7L13,12.07L14.41,13.5L17,10.9V17H19V10.9L21.59,13.5L23,12.07L18,7Z\";\r\nvar mdiFormatHeader1 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M14,18V16H16V6.31L13.5,7.75V5.44L16,4H18V16H20V18H14Z\";\r\nvar mdiFormatHeader2 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M21,18H15A2,2 0 0,1 13,16C13,15.47 13.2,15 13.54,14.64L18.41,9.41C18.78,9.05 19,8.55 19,8A2,2 0 0,0 17,6A2,2 0 0,0 15,8H13A4,4 0 0,1 17,4A4,4 0 0,1 21,8C21,9.1 20.55,10.1 19.83,10.83L15,16H21V18Z\";\r\nvar mdiFormatHeader3 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M15,4H19A2,2 0 0,1 21,6V16A2,2 0 0,1 19,18H15A2,2 0 0,1 13,16V15H15V16H19V12H15V10H19V6H15V7H13V6A2,2 0 0,1 15,4Z\";\r\nvar mdiFormatHeader4 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M18,18V13H13V11L18,4H20V11H21V13H20V18H18M18,11V7.42L15.45,11H18Z\";\r\nvar mdiFormatHeader5 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M15,4H20V6H15V10H17A4,4 0 0,1 21,14A4,4 0 0,1 17,18H15A2,2 0 0,1 13,16V15H15V16H17A2,2 0 0,0 19,14A2,2 0 0,0 17,12H15A2,2 0 0,1 13,10V6A2,2 0 0,1 15,4Z\";\r\nvar mdiFormatHeader6 = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M15,4H19A2,2 0 0,1 21,6V7H19V6H15V10H19A2,2 0 0,1 21,12V16A2,2 0 0,1 19,18H15A2,2 0 0,1 13,16V6A2,2 0 0,1 15,4M15,12V16H19V12H15Z\";\r\nvar mdiFormatHeaderDecrease = \"M4,4H6V10H10V4H12V18H10V12H6V18H4V4M20.42,7.41L16.83,11L20.42,14.59L19,16L14,11L19,6L20.42,7.41Z\";\r\nvar mdiFormatHeaderEqual = \"M4,4H6V10H10V4H12V18H10V12H6V18H4V4M14,10V8H21V10H14M14,12H21V14H14V12Z\";\r\nvar mdiFormatHeaderIncrease = \"M4,4H6V10H10V4H12V18H10V12H6V18H4V4M14.59,7.41L18.17,11L14.59,14.59L16,16L21,11L16,6L14.59,7.41Z\";\r\nvar mdiFormatHeaderPound = \"M3,4H5V10H9V4H11V18H9V12H5V18H3V4M13,8H15.31L15.63,5H17.63L17.31,8H19.31L19.63,5H21.63L21.31,8H23V10H21.1L20.9,12H23V14H20.69L20.37,17H18.37L18.69,14H16.69L16.37,17H14.37L14.69,14H13V12H14.9L15.1,10H13V8M17.1,10L16.9,12H18.9L19.1,10H17.1Z\";\r\nvar mdiFormatHorizontalAlignCenter = \"M19,16V13H23V11H19V8L15,12L19,16M5,8V11H1V13H5V16L9,12L5,8M11,20H13V4H11V20Z\";\r\nvar mdiFormatHorizontalAlignLeft = \"M11,16V13H21V11H11V8L7,12L11,16M3,20H5V4H3V20Z\";\r\nvar mdiFormatHorizontalAlignRight = \"M13,8V11H3V13H13V16L17,12L13,8M19,20H21V4H19V20Z\";\r\nvar mdiFormatIndentDecrease = \"M11,13H21V11H11M11,9H21V7H11M3,3V5H21V3M3,21H21V19H3M3,12L7,16V8M11,17H21V15H11V17Z\";\r\nvar mdiFormatIndentIncrease = \"M11,13H21V11H11M11,9H21V7H11M3,3V5H21V3M11,17H21V15H11M3,8V16L7,12M3,21H21V19H3V21Z\";\r\nvar mdiFormatItalic = \"M10,4V7H12.21L8.79,15H6V18H14V15H11.79L15.21,7H18V4H10Z\";\r\nvar mdiFormatLetterCase = \"M20.06,18C20,17.83 19.91,17.54 19.86,17.11C19.19,17.81 18.38,18.16 17.45,18.16C16.62,18.16 15.93,17.92 15.4,17.45C14.87,17 14.6,16.39 14.6,15.66C14.6,14.78 14.93,14.1 15.6,13.61C16.27,13.12 17.21,12.88 18.43,12.88H19.83V12.24C19.83,11.75 19.68,11.36 19.38,11.07C19.08,10.78 18.63,10.64 18.05,10.64C17.53,10.64 17.1,10.76 16.75,11C16.4,11.25 16.23,11.54 16.23,11.89H14.77C14.77,11.46 14.92,11.05 15.22,10.65C15.5,10.25 15.93,9.94 16.44,9.71C16.95,9.5 17.5,9.36 18.13,9.36C19.11,9.36 19.87,9.6 20.42,10.09C20.97,10.58 21.26,11.25 21.28,12.11V16C21.28,16.8 21.38,17.42 21.58,17.88V18H20.06M17.66,16.88C18.11,16.88 18.54,16.77 18.95,16.56C19.35,16.35 19.65,16.07 19.83,15.73V14.16H18.7C16.93,14.16 16.04,14.63 16.04,15.57C16.04,16 16.19,16.3 16.5,16.53C16.8,16.76 17.18,16.88 17.66,16.88M5.46,13.71H9.53L7.5,8.29L5.46,13.71M6.64,6H8.36L13.07,18H11.14L10.17,15.43H4.82L3.86,18H1.93L6.64,6Z\";\r\nvar mdiFormatLetterCaseLower = \"M20.06,18C20,17.83 19.91,17.54 19.86,17.11C19.19,17.81 18.38,18.16 17.45,18.16C16.62,18.16 15.93,17.92 15.4,17.45C14.87,17 14.6,16.39 14.6,15.66C14.6,14.78 14.93,14.1 15.6,13.61C16.27,13.12 17.21,12.88 18.43,12.88H19.83V12.24C19.83,11.75 19.68,11.36 19.38,11.07C19.08,10.78 18.63,10.64 18.05,10.64C17.53,10.64 17.1,10.76 16.75,11C16.4,11.25 16.23,11.54 16.23,11.89H14.77C14.77,11.46 14.92,11.05 15.22,10.65C15.5,10.25 15.93,9.94 16.44,9.71C16.95,9.5 17.5,9.36 18.13,9.36C19.11,9.36 19.87,9.6 20.42,10.09C20.97,10.58 21.26,11.25 21.28,12.11V16C21.28,16.8 21.38,17.42 21.58,17.88V18H20.06M17.66,16.88C18.11,16.88 18.54,16.77 18.95,16.56C19.35,16.35 19.65,16.07 19.83,15.73V14.16H18.7C16.93,14.16 16.04,14.63 16.04,15.57C16.04,16 16.19,16.3 16.5,16.53C16.8,16.76 17.18,16.88 17.66,16.88M5.46,13.71H9.53L7.5,8.29L5.46,13.71M6.64,6H8.36L13.07,18H11.14L10.17,15.43H4.82L3.86,18H1.93L6.64,6M22,20V22H14.5V20H22Z\";\r\nvar mdiFormatLetterCaseUpper = \"M20.06,18C20,17.83 19.91,17.54 19.86,17.11C19.19,17.81 18.38,18.16 17.45,18.16C16.62,18.16 15.93,17.92 15.4,17.45C14.87,17 14.6,16.39 14.6,15.66C14.6,14.78 14.93,14.1 15.6,13.61C16.27,13.12 17.21,12.88 18.43,12.88H19.83V12.24C19.83,11.75 19.68,11.36 19.38,11.07C19.08,10.78 18.63,10.64 18.05,10.64C17.53,10.64 17.1,10.76 16.75,11C16.4,11.25 16.23,11.54 16.23,11.89H14.77C14.77,11.46 14.92,11.05 15.22,10.65C15.5,10.25 15.93,9.94 16.44,9.71C16.95,9.5 17.5,9.36 18.13,9.36C19.11,9.36 19.87,9.6 20.42,10.09C20.97,10.58 21.26,11.25 21.28,12.11V16C21.28,16.8 21.38,17.42 21.58,17.88V18H20.06M17.66,16.88C18.11,16.88 18.54,16.77 18.95,16.56C19.35,16.35 19.65,16.07 19.83,15.73V14.16H18.7C16.93,14.16 16.04,14.63 16.04,15.57C16.04,16 16.19,16.3 16.5,16.53C16.8,16.76 17.18,16.88 17.66,16.88M5.46,13.71H9.53L7.5,8.29L5.46,13.71M6.64,6H8.36L13.07,18H11.14L10.17,15.43H4.82L3.86,18H1.93L6.64,6M2,20H13V22H2V20Z\";\r\nvar mdiFormatLetterEndsWith = \"M11.14 4L6.43 16H8.36L9.32 13.43H14.67L15.64 16H17.57L12.86 4M12 6.29L14.03 11.71H9.96M20 14V18H2V20H22V14Z\";\r\nvar mdiFormatLetterMatches = \"M11.14 4L6.43 16H8.36L9.32 13.43H14.67L15.64 16H17.57L12.86 4M12 6.29L14.03 11.71H9.96M20 14V18H4V15H2V20H22V14Z\";\r\nvar mdiFormatLetterStartsWith = \"M11.14 4L6.43 16H8.36L9.32 13.43H14.67L15.64 16H17.57L12.86 4M12 6.29L14.03 11.71H9.96M4 18V15H2V20H22V18Z\";\r\nvar mdiFormatLineSpacing = \"M10,13H22V11H10M10,19H22V17H10M10,7H22V5H10M6,7H8.5L5,3.5L1.5,7H4V17H1.5L5,20.5L8.5,17H6V7Z\";\r\nvar mdiFormatLineStyle = \"M3,16H8V14H3V16M9.5,16H14.5V14H9.5V16M16,16H21V14H16V16M3,20H5V18H3V20M7,20H9V18H7V20M11,20H13V18H11V20M15,20H17V18H15V20M19,20H21V18H19V20M3,12H11V10H3V12M13,12H21V10H13V12M3,4V8H21V4H3Z\";\r\nvar mdiFormatLineWeight = \"M3,17H21V15H3V17M3,20H21V19H3V20M3,13H21V10H3V13M3,4V8H21V4H3Z\";\r\nvar mdiFormatListBulleted = \"M7,5H21V7H7V5M7,13V11H21V13H7M4,4.5A1.5,1.5 0 0,1 5.5,6A1.5,1.5 0 0,1 4,7.5A1.5,1.5 0 0,1 2.5,6A1.5,1.5 0 0,1 4,4.5M4,10.5A1.5,1.5 0 0,1 5.5,12A1.5,1.5 0 0,1 4,13.5A1.5,1.5 0 0,1 2.5,12A1.5,1.5 0 0,1 4,10.5M7,19V17H21V19H7M4,16.5A1.5,1.5 0 0,1 5.5,18A1.5,1.5 0 0,1 4,19.5A1.5,1.5 0 0,1 2.5,18A1.5,1.5 0 0,1 4,16.5Z\";\r\nvar mdiFormatListBulletedSquare = \"M3,4H7V8H3V4M9,5V7H21V5H9M3,10H7V14H3V10M9,11V13H21V11H9M3,16H7V20H3V16M9,17V19H21V17H9\";\r\nvar mdiFormatListBulletedTriangle = \"M5,15.5L7.5,20H2.5L5,15.5M9,19H21V17H9V19M5,9.5L7.5,14H2.5L5,9.5M9,13H21V11H9V13M5,3.5L7.5,8H2.5L5,3.5M9,7H21V5H9V7Z\";\r\nvar mdiFormatListBulletedType = \"M5,9.5L7.5,14H2.5L5,9.5M3,4H7V8H3V4M5,20A2,2 0 0,0 7,18A2,2 0 0,0 5,16A2,2 0 0,0 3,18A2,2 0 0,0 5,20M9,5V7H21V5H9M9,19H21V17H9V19M9,13H21V11H9V13Z\";\r\nvar mdiFormatListCheckbox = \"M21,19V17H8V19H21M21,13V11H8V13H21M8,7H21V5H8V7M4,5V7H6V5H4M3,5A1,1 0 0,1 4,4H6A1,1 0 0,1 7,5V7A1,1 0 0,1 6,8H4A1,1 0 0,1 3,7V5M4,11V13H6V11H4M3,11A1,1 0 0,1 4,10H6A1,1 0 0,1 7,11V13A1,1 0 0,1 6,14H4A1,1 0 0,1 3,13V11M4,17V19H6V17H4M3,17A1,1 0 0,1 4,16H6A1,1 0 0,1 7,17V19A1,1 0 0,1 6,20H4A1,1 0 0,1 3,19V17Z\";\r\nvar mdiFormatListChecks = \"M3,5H9V11H3V5M5,7V9H7V7H5M11,7H21V9H11V7M11,15H21V17H11V15M5,20L1.5,16.5L2.91,15.09L5,17.17L9.59,12.59L11,14L5,20Z\";\r\nvar mdiFormatListNumbered = \"M7,13V11H21V13H7M7,19V17H21V19H7M7,7V5H21V7H7M3,8V5H2V4H4V8H3M2,17V16H5V20H2V19H4V18.5H3V17.5H4V17H2M4.25,10A0.75,0.75 0 0,1 5,10.75C5,10.95 4.92,11.14 4.79,11.27L3.12,13H5V14H2V13.08L4,11H2V10H4.25Z\";\r\nvar mdiFormatListNumberedRtl = \"M3,13V11H17V13H3M3,19V17H17V19H3M3,7V5H17V7H3M20,8V5H19V4H21V8H20M19,17V16H22V20H19V19H21V18.5H20V17.5H21V17H19M21.25,10C21.67,10 22,10.34 22,10.75C22,10.95 21.92,11.14 21.79,11.27L20.12,13H22V14H19V13.08L21,11H19V10H21.25Z\";\r\nvar mdiFormatListText = \"M2 14H8V20H2M16 8H10V10H16M2 10H8V4H2M10 4V6H22V4M10 20H16V18H10M10 16H22V14H10\";\r\nvar mdiFormatOverline = \"M5,5H19V3H5V5M9.62,16L12,9.67L14.37,16M11,7L5.5,21H7.75L8.87,18H15.12L16.25,21H18.5L13,7H11Z\";\r\nvar mdiFormatPageBreak = \"M18,20H6V18H4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V18H18V20M14,2H6A2,2 0 0,0 4,4V12H6V4H14V8H18V12H20V8L14,2M11,16H8V14H11V16M16,16H13V14H16V16M3,14H6V16H3V14M21,16H18V14H21V16Z\";\r\nvar mdiFormatPaint = \"M18,4V3A1,1 0 0,0 17,2H5A1,1 0 0,0 4,3V7A1,1 0 0,0 5,8H17A1,1 0 0,0 18,7V6H19V10H9V21A1,1 0 0,0 10,22H12A1,1 0 0,0 13,21V12H21V4H18Z\";\r\nvar mdiFormatParagraph = \"M13,4A4,4 0 0,1 17,8A4,4 0 0,1 13,12H11V18H9V4H13M13,10A2,2 0 0,0 15,8A2,2 0 0,0 13,6H11V10H13Z\";\r\nvar mdiFormatPilcrow = \"M10,11A4,4 0 0,1 6,7A4,4 0 0,1 10,3H18V5H16V21H14V5H12V21H10V11Z\";\r\nvar mdiFormatQuoteClose = \"M14,17H17L19,13V7H13V13H16M6,17H9L11,13V7H5V13H8L6,17Z\";\r\nvar mdiFormatQuoteCloseOutline = \"M13 6V14H14.88L12.88 18H18.62L21 13.24V6M15 8H19V12.76L17.38 16H16.12L18.12 12H15M3 6V14H4.88L2.88 18H8.62L11 13.24V6M5 8H9V12.76L7.38 16H6.12L8.12 12H5Z\";\r\nvar mdiFormatQuoteOpen = \"M10,7L8,11H11V17H5V11L7,7H10M18,7L16,11H19V17H13V11L15,7H18Z\";\r\nvar mdiFormatQuoteOpenOutline = \"M11 18V10H9.12L11.12 6H5.38L3 10.76V18M9 16H5V11.24L6.62 8H7.88L5.88 12H9M21 18V10H19.12L21.12 6H15.38L13 10.76V18M19 16H15V11.24L16.62 8H17.88L15.88 12H19Z\";\r\nvar mdiFormatRotate90 = \"M7.34,6.41L0.86,12.9L7.35,19.38L13.84,12.9L7.34,6.41M3.69,12.9L7.35,9.24L11,12.9L7.34,16.56L3.69,12.9M19.36,6.64C17.61,4.88 15.3,4 13,4V0.76L8.76,5L13,9.24V6C14.79,6 16.58,6.68 17.95,8.05C20.68,10.78 20.68,15.22 17.95,17.95C16.58,19.32 14.79,20 13,20C12.03,20 11.06,19.79 10.16,19.39L8.67,20.88C10,21.62 11.5,22 13,22C15.3,22 17.61,21.12 19.36,19.36C22.88,15.85 22.88,10.15 19.36,6.64Z\";\r\nvar mdiFormatSection = \"M15.67,4.42C14.7,3.84 13.58,3.54 12.45,3.56C10.87,3.56 9.66,4.34 9.66,5.56C9.66,6.96 11,7.47 13,8.14C15.5,8.95 17.4,9.97 17.4,12.38C17.36,13.69 16.69,14.89 15.6,15.61C16.25,16.22 16.61,17.08 16.6,17.97C16.6,20.79 14,21.97 11.5,21.97C10.04,22.03 8.59,21.64 7.35,20.87L8,19.34C9.04,20.05 10.27,20.43 11.53,20.44C13.25,20.44 14.53,19.66 14.53,18.24C14.53,17 13.75,16.31 11.25,15.45C8.5,14.5 6.6,13.5 6.6,11.21C6.67,9.89 7.43,8.69 8.6,8.07C7.97,7.5 7.61,6.67 7.6,5.81C7.6,3.45 9.77,2 12.53,2C13.82,2 15.09,2.29 16.23,2.89L15.67,4.42M11.35,13.42C12.41,13.75 13.44,14.18 14.41,14.71C15.06,14.22 15.43,13.45 15.41,12.64C15.41,11.64 14.77,10.76 13,10.14C11.89,9.77 10.78,9.31 9.72,8.77C8.97,9.22 8.5,10.03 8.5,10.91C8.5,11.88 9.23,12.68 11.35,13.42Z\";\r\nvar mdiFormatSize = \"M2 4V7H7V19H10V7H15V4H2M21 9H12V12H15V19H18V12H21V9Z\";\r\nvar mdiFormatStrikethrough = \"M3,14H21V12H3M5,4V7H10V10H14V7H19V4M10,19H14V16H10V19Z\";\r\nvar mdiFormatStrikethroughVariant = \"M23,12V14H18.61C19.61,16.14 19.56,22 12.38,22C4.05,22.05 4.37,15.5 4.37,15.5L8.34,15.55C8.37,18.92 11.5,18.92 12.12,18.88C12.76,18.83 15.15,18.84 15.34,16.5C15.42,15.41 14.32,14.58 13.12,14H1V12H23M19.41,7.89L15.43,7.86C15.43,7.86 15.6,5.09 12.15,5.08C8.7,5.06 9,7.28 9,7.56C9.04,7.84 9.34,9.22 12,9.88H5.71C5.71,9.88 2.22,3.15 10.74,2C19.45,0.8 19.43,7.91 19.41,7.89Z\";\r\nvar mdiFormatSubscript = \"M16,7.41L11.41,12L16,16.59L14.59,18L10,13.41L5.41,18L4,16.59L8.59,12L4,7.41L5.41,6L10,10.59L14.59,6L16,7.41M21.85,21.03H16.97V20.03L17.86,19.23C18.62,18.58 19.18,18.04 19.56,17.6C19.93,17.16 20.12,16.75 20.13,16.36C20.14,16.08 20.05,15.85 19.86,15.66C19.68,15.5 19.39,15.38 19,15.38C18.69,15.38 18.42,15.44 18.16,15.56L17.5,15.94L17.05,14.77C17.32,14.56 17.64,14.38 18.03,14.24C18.42,14.1 18.85,14 19.32,14C20.1,14.04 20.7,14.25 21.1,14.66C21.5,15.07 21.72,15.59 21.72,16.23C21.71,16.79 21.53,17.31 21.18,17.78C20.84,18.25 20.42,18.7 19.91,19.14L19.27,19.66V19.68H21.85V21.03Z\";\r\nvar mdiFormatSuperscript = \"M16,7.41L11.41,12L16,16.59L14.59,18L10,13.41L5.41,18L4,16.59L8.59,12L4,7.41L5.41,6L10,10.59L14.59,6L16,7.41M21.85,9H16.97V8L17.86,7.18C18.62,6.54 19.18,6 19.56,5.55C19.93,5.11 20.12,4.7 20.13,4.32C20.14,4.04 20.05,3.8 19.86,3.62C19.68,3.43 19.39,3.34 19,3.33C18.69,3.34 18.42,3.4 18.16,3.5L17.5,3.89L17.05,2.72C17.32,2.5 17.64,2.33 18.03,2.19C18.42,2.05 18.85,2 19.32,2C20.1,2 20.7,2.2 21.1,2.61C21.5,3 21.72,3.54 21.72,4.18C21.71,4.74 21.53,5.26 21.18,5.73C20.84,6.21 20.42,6.66 19.91,7.09L19.27,7.61V7.63H21.85V9Z\";\r\nvar mdiFormatText = \"M18.5,4L19.66,8.35L18.7,8.61C18.25,7.74 17.79,6.87 17.26,6.43C16.73,6 16.11,6 15.5,6H13V16.5C13,17 13,17.5 13.33,17.75C13.67,18 14.33,18 15,18V19H9V18C9.67,18 10.33,18 10.67,17.75C11,17.5 11,17 11,16.5V6H8.5C7.89,6 7.27,6 6.74,6.43C6.21,6.87 5.75,7.74 5.3,8.61L4.34,8.35L5.5,4H18.5Z\";\r\nvar mdiFormatTextRotationAngleDown = \"M14.25 21H10.03L11.44 19.59L2.58 10.73L4.03 9.33L12.84 18.19L14.25 16.78M12.61 8L15.23 10.64L17.43 5.77M19.41 4.92L14.95 16.03L13.5 14.58L14.39 12.38L10.88 8.81L8.68 9.75L7.22 8.25L18.33 3.84Z\";\r\nvar mdiFormatTextRotationAngleUp = \"M20.58 9.33V13.55L19.17 12.14L10.31 21L8.91 19.59L17.72 10.73L16.31 9.33M7.59 11L10.22 8.39L5.34 6.14M4.5 4.22L15.61 8.63L14.16 10.13L11.96 9.19L8.39 12.75L9.33 14.91L7.83 16.41L3.42 5.25Z\";\r\nvar mdiFormatTextRotationDown = \"M6,19.73L3,16.73H5V4.27H7V16.73H9L6,19.73M14,9.38V13.13L19.03,11.25L14,9.38M21,12L10,16.73V14.67L12.19,13.73V8.77L10,7.83V5.77L21,10.5V12Z\";\r\nvar mdiFormatTextRotationDownVertical = \"M15.25 4H13.75L9 15H11.1L12 12.8H17L17.9 15H20L15.25 4M12.63 11L14.5 6L16.37 11H12.63M5 17.5L8 14.5H6V2H4V14.5H2L5 17.5M22 20L19 17V19H6.5V21H19V23L22 20Z\";\r\nvar mdiFormatTextRotationNone = \"M20.5,18L17.5,21V19H5V17H17.5V15L20.5,18M10.13,10H13.88L12,4.97L10.13,10M12.75,3L17.5,14H15.42L14.5,11.81H9.5L8.58,14H6.5L11.25,3H12.75Z\";\r\nvar mdiFormatTextRotationUp = \"M3 12V13.5L14 18.25V16.15L11.8 15.25V10.25L14 9.35V7.25L3 12M10 14.62L5 12.75L10 10.88V14.62M18 4.25L15 7.25H17V19.75H19V7.25H21L18 4.25Z\";\r\nvar mdiFormatTextRotationVertical = \"M15.75 5H14.25L9.5 16H11.6L12.5 13.8H17.5L18.4 16H20.5L15.75 5M13.13 12L15 7L16.87 12H13.13M6 19.75L9 16.75H7V4.25H5V16.75H3L6 19.75Z\";\r\nvar mdiFormatTextVariant = \"M9.6,14L12,7.7L14.4,14M11,5L5.5,19H7.7L8.8,16H15L16.1,19H18.3L13,5H11Z\";\r\nvar mdiFormatTextVariantOutline = \"M11 3C10.18 3 9.44 3.5 9.14 4.27L3.64 18.27C3.12 19.58 4.09 21 5.5 21H7.75C8.59 21 9.33 20.5 9.62 19.7L10.26 18H13.74L14.38 19.7C14.67 20.5 15.42 21 16.25 21H18.5C19.91 21 20.88 19.58 20.36 18.27L14.86 4.27C14.56 3.5 13.82 3 13 3M11 5H13L18.5 19H16.25L15.12 16H8.87L7.75 19H5.5M12 7.67L9.62 14H14.37Z\";\r\nvar mdiFormatTextWrappingClip = \"M7,21H5V3H7V21M17,3V11H9V13H17V21H19V3H17Z\";\r\nvar mdiFormatTextWrappingOverflow = \"M7,21H5V3H7V21M14,3H12V9H14V3M14,15H12V21H14V15M19,12L16,9V11H9V13H16V15L19,12Z\";\r\nvar mdiFormatTextWrappingWrap = \"M7,21H5V3H7V21M19,3H17V21H19V3M13,8H9V10H12.97C13.14,10 14,10.16 14,12C14,13.84 13.14,14 13,14H11V12L8,15L11,18V16H13C14.04,16 16,15.16 16,12C16,8.84 14.04,8 13,8Z\";\r\nvar mdiFormatTextbox = \"M21,7V3H17V4H7V3H3V7H4V17H3V21H7V20H17V21H21V17H20V7H21M18,4H20V6H18V4M4,4H6V6H4V4M6,20H4V18H6V20M20,20H18V18H20V20M18,17H17V18H7V17H6V7H7V6H17V7H18V17M16,8V10H13V16H11V10H8V8H16Z\";\r\nvar mdiFormatTextdirectionLToR = \"M21,18L17,14V17H5V19H17V22M9,10V15H11V4H13V15H15V4H17V2H9A4,4 0 0,0 5,6A4,4 0 0,0 9,10Z\";\r\nvar mdiFormatTextdirectionRToL = \"M8,17V14L4,18L8,22V19H20V17M10,10V15H12V4H14V15H16V4H18V2H10A4,4 0 0,0 6,6A4,4 0 0,0 10,10Z\";\r\nvar mdiFormatTitle = \"M5,4V7H10.5V19H13.5V7H19V4H5Z\";\r\nvar mdiFormatUnderline = \"M5,21H19V19H5V21M12,17A6,6 0 0,0 18,11V3H15.5V11A3.5,3.5 0 0,1 12,14.5A3.5,3.5 0 0,1 8.5,11V3H6V11A6,6 0 0,0 12,17Z\";\r\nvar mdiFormatVerticalAlignBottom = \"M16,13H13V3H11V13H8L12,17L16,13M4,19V21H20V19H4Z\";\r\nvar mdiFormatVerticalAlignCenter = \"M8,19H11V23H13V19H16L12,15L8,19M16,5H13V1H11V5H8L12,9L16,5M4,11V13H20V11H4Z\";\r\nvar mdiFormatVerticalAlignTop = \"M8,11H11V21H13V11H16L12,7L8,11M4,3V5H20V3H4Z\";\r\nvar mdiFormatWrapInline = \"M8,7L13,17H3L8,7M3,3H21V5H3V3M21,15V17H14V15H21M3,19H21V21H3V19Z\";\r\nvar mdiFormatWrapSquare = \"M12,7L17,17H7L12,7M3,3H21V5H3V3M3,7H6V9H3V7M21,7V9H18V7H21M3,11H6V13H3V11M21,11V13H18V11H21M3,15H6V17H3V15M21,15V17H18V15H21M3,19H21V21H3V19Z\";\r\nvar mdiFormatWrapTight = \"M12,7L17,17H7L12,7M3,3H21V5H3V3M3,7H9V9H3V7M21,7V9H15V7H21M3,11H7V13H3V11M21,11V13H17V11H21M3,15H6V17H3V15M21,15V17H18V15H21M3,19H21V21H3V19Z\";\r\nvar mdiFormatWrapTopBottom = \"M12,7L17,17H7L12,7M3,3H21V5H3V3M3,19H21V21H3V19Z\";\r\nvar mdiForum = \"M17,12V3A1,1 0 0,0 16,2H3A1,1 0 0,0 2,3V17L6,13H16A1,1 0 0,0 17,12M21,6H19V15H6V17A1,1 0 0,0 7,18H18L22,22V7A1,1 0 0,0 21,6Z\";\r\nvar mdiForumOutline = \"M15,4V11H5.17L4,12.17V4H15M16,2H3A1,1 0 0,0 2,3V17L6,13H16A1,1 0 0,0 17,12V3A1,1 0 0,0 16,2M21,6H19V15H6V17A1,1 0 0,0 7,18H18L22,22V7A1,1 0 0,0 21,6Z\";\r\nvar mdiForward = \"M12,8V4L20,12L12,20V16H4V8H12Z\";\r\nvar mdiForwardburger = \"M19,13H3V11H19L15,7L16.4,5.6L22.8,12L16.4,18.4L15,17L19,13M3,6H13V8H3V6M13,16V18H3V16H13Z\";\r\nvar mdiFountain = \"M7.5,2C4.47,2 2,4.46 2,7.5V7.5L2,8H4V7.5A3.5,3.5 0 0,1 7.5,4C9,4 10.26,4.93 10.76,6.24C10.37,6.08 9.95,6 9.5,6C8.11,6 6.9,6.82 6.34,8L8.08,9C8.29,8.42 8.85,8 9.5,8A1.5,1.5 0 0,1 11,9.5V11H13V9.5A1.5,1.5 0 0,1 14.5,8C15.16,8 15.71,8.42 15.92,9L17.66,8C17.1,6.82 15.9,6 14.5,6C14.05,6 13.63,6.08 13.24,6.24C13.74,4.93 15,4 16.5,4A3.5,3.5 0 0,1 20,7.5V8H22V7.5H22A5.5,5.5 0 0,0 16.5,2C14.64,2 13,2.93 12,4.34C11,2.93 9.36,2 7.5,2M6,12V14H7.42C7.92,15.15 8.85,16.07 10,16.57C10,17.38 10,18.19 10,19H2C2,19 2.82,20.23 3.41,21.11C3.78,21.67 4.4,22 5.07,22H18.93C19.6,22 20.22,21.67 20.59,21.11L22,19H14C14,18.19 14,17.38 14,16.57C15.15,16.07 16.08,15.15 16.58,14H18V12H6Z\";\r\nvar mdiFountainPen = \"M6.95,14.93L11.19,9.27L19.68,2.2C20.07,1.81 20.72,1.81 21.09,2.2L21.8,2.91C22.19,3.28 22.19,3.93 21.8,4.32L14.73,12.81L9.07,17.05L6.95,14.93M8.36,17.76L6.24,15.64L3.41,17.05L2,21.29L4.12,19.17C4.32,19 4.63,19 4.83,19.17C5,19.37 5,19.68 4.83,19.88L2.71,22L6.95,20.59L8.36,17.76Z\";\r\nvar mdiFountainPenTip = \"M15.54,3.5L20.5,8.47L19.07,9.88L14.12,4.93L15.54,3.5M3.5,19.78L10,13.31C9.9,13 9.97,12.61 10.23,12.35C10.62,11.96 11.26,11.96 11.65,12.35C12.04,12.75 12.04,13.38 11.65,13.77C11.39,14.03 11,14.1 10.69,14L4.22,20.5L14.83,16.95L18.36,10.59L13.42,5.64L7.05,9.17L3.5,19.78Z\";\r\nvar mdiFreebsd = \"M2.69,2C3.54,1.95 6.08,3.16 6.13,3.19C4.84,4 3.74,5.09 2.91,6.38C2.09,4.81 1.34,2.91 2,2.25C2.17,2.08 2.4,2 2.69,2M20.84,2.13C21.25,2.08 21.58,2.14 21.78,2.34C22.85,3.42 19.88,8.15 19.38,8.66C18.87,9.16 17.57,8.7 16.5,7.63C15.43,6.55 14.97,5.26 15.47,4.75C15.88,4.34 19.09,2.3 20.84,2.13M12,2.56C13.29,2.56 14.53,2.82 15.66,3.28C15.17,3.6 14.81,3.85 14.69,3.97C13.7,4.96 14.14,6.83 15.72,8.41C16.7,9.38 17.84,9.97 18.78,9.97C19.46,9.97 19.92,9.68 20.16,9.44C20.33,9.27 20.6,8.88 20.91,8.41C21.42,9.59 21.69,10.88 21.69,12.25C21.69,17.61 17.36,21.97 12,21.97C6.64,21.97 2.31,17.61 2.31,12.25C2.31,6.89 6.64,2.56 12,2.56Z\";\r\nvar mdiFrequentlyAskedQuestions = \"M18,15H6L2,19V3A1,1 0 0,1 3,2H18A1,1 0 0,1 19,3V14A1,1 0 0,1 18,15M23,9V23L19,19H8A1,1 0 0,1 7,18V17H21V8H22A1,1 0 0,1 23,9M8.19,4C7.32,4 6.62,4.2 6.08,4.59C5.56,5 5.3,5.57 5.31,6.36L5.32,6.39H7.25C7.26,6.09 7.35,5.86 7.53,5.7C7.71,5.55 7.93,5.47 8.19,5.47C8.5,5.47 8.76,5.57 8.94,5.75C9.12,5.94 9.2,6.2 9.2,6.5C9.2,6.82 9.13,7.09 8.97,7.32C8.83,7.55 8.62,7.75 8.36,7.91C7.85,8.25 7.5,8.55 7.31,8.82C7.11,9.08 7,9.5 7,10H9C9,9.69 9.04,9.44 9.13,9.26C9.22,9.08 9.39,8.9 9.64,8.74C10.09,8.5 10.46,8.21 10.75,7.81C11.04,7.41 11.19,7 11.19,6.5C11.19,5.74 10.92,5.13 10.38,4.68C9.85,4.23 9.12,4 8.19,4M7,11V13H9V11H7M13,13H15V11H13V13M13,4V10H15V4H13Z\";\r\nvar mdiFridge = \"M7,2H17A2,2 0 0,1 19,4V9H5V4A2,2 0 0,1 7,2M19,19A2,2 0 0,1 17,21V22H15V21H9V22H7V21A2,2 0 0,1 5,19V10H19V19M8,5V7H10V5H8M8,12V15H10V12H8Z\";\r\nvar mdiFridgeAlert = \"M5 2H15C16.11 2 17 2.9 17 4V9H3V4C3 2.9 3.9 2 5 2M17 19C17 20.11 16.11 21 15 21V22H13V21H7V22H5V21C3.9 21 3 20.11 3 19V10H17V19M6 5V7H8V5H6M6 12V15H8V12H6M19 15H21V17H19V15M19 7H21V13H19V7Z\";\r\nvar mdiFridgeAlertOutline = \"M7 21V22H5V21C3.9 21 3 20.11 3 19V4C3 2.9 3.9 2 5 2H15C16.11 2 17 2.9 17 4V19C17 20.11 16.11 21 15 21V22H13V21H7M5 4V9H15V4H5M5 19H15V11H5V19M6 12H8V15H6V12M6 6H8V8H6V6M19 15H21V17H19V15M19 7H21V13H19V7Z\";\r\nvar mdiFridgeBottom = \"M7,2A2,2 0 0,0 5,4V19A2,2 0 0,0 7,21V22H9V21H15V22H17V21A2,2 0 0,0 19,19V4A2,2 0 0,0 17,2H7M8,6H10V8H8V6M7,11H17V19H7V11M8,12V15H10V12H8Z\";\r\nvar mdiFridgeIndustrial = \"M17 2H7C5.9 2 5 2.9 5 4V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C18.11 21 19 20.11 19 19V4C19 2.9 18.11 2 17 2M10 15H8V10H10V15Z\";\r\nvar mdiFridgeIndustrialAlert = \"M15 2H5C3.9 2 3 2.9 3 4V19C3 20.11 3.9 21 5 21V22H7V21H13V22H15V21C16.11 21 17 20.11 17 19V4C17 2.9 16.11 2 15 2M8 15H6V10H8V15M21 7V13H19V7H21M19 15H21V17H19V15Z\";\r\nvar mdiFridgeIndustrialAlertOutline = \"M8 15H6V10H8V15M17 4V19C17 20.11 16.11 21 15 21V22H13V21H7V22H5V21C3.9 21 3 20.11 3 19V4C3 2.9 3.9 2 5 2H15C16.11 2 17 2.9 17 4M15 4H5V19H15V4M19 17H21V15H19V17M19 7V13H21V7H19Z\";\r\nvar mdiFridgeIndustrialOff = \"M19 15.8L5.7 2.5C6.05 2.19 6.5 2 7 2H17C18.11 2 19 2.9 19 4V15.8M22.11 21.46L20.84 22.73L18.46 20.35C18.1 20.75 17.58 21 17 21V22H15V21H9V22H7V21C5.9 21 5 20.11 5 19V6.89L1.11 3L2.39 1.73L22.11 21.46M10 11.89L8.11 10H8V15H10V11.89Z\";\r\nvar mdiFridgeIndustrialOffOutline = \"M7.2 4L5.7 2.5C6.05 2.19 6.5 2 7 2H17C18.11 2 19 2.9 19 4V15.8L17 13.8V4H7.2M22.11 21.46L20.84 22.73L18.46 20.35C18.1 20.75 17.58 21 17 21V22H15V21H9V22H7V21C5.9 21 5 20.11 5 19V6.89L1.11 3L2.39 1.73L22.11 21.46M17 18.89L10 11.89V15H8V10H8.11L7 8.89V19H17V18.89Z\";\r\nvar mdiFridgeIndustrialOutline = \"M17 2H7C5.9 2 5 2.9 5 4V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C18.11 21 19 20.11 19 19V4C19 2.9 18.11 2 17 2M17 19H7V4H17V19M10 15H8V10H10V15Z\";\r\nvar mdiFridgeOff = \"M22.11 21.46L2.39 1.73L1.11 3L5 6.89V9H7.11L8.11 10H5V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C17.58 21 18.1 20.75 18.46 20.35L20.84 22.73L22.11 21.46M10 15H8V12H10V15M19 15.8L13.2 10H19V15.8M8.2 5L5.7 2.5C6.05 2.19 6.5 2 7 2H17C18.11 2 19 2.9 19 4V9H12.2L10 6.8V5H8.2Z\";\r\nvar mdiFridgeOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L5 6.89V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C17.58 21 18.1 20.75 18.46 20.35L20.84 22.73L22.11 21.46M17 19H7V11H9.11L17 18.89V19M7.2 4L5.7 2.5C6.05 2.19 6.5 2 7 2H17C18.11 2 19 2.9 19 4V15.8L17 13.8V11H14.2L12.2 9H17V4H7.2M8 12H10V15H8V12Z\";\r\nvar mdiFridgeOutline = \"M9,21V22H7V21A2,2 0 0,1 5,19V4A2,2 0 0,1 7,2H17A2,2 0 0,1 19,4V19A2,2 0 0,1 17,21V22H15V21H9M7,4V9H17V4H7M7,19H17V11H7V19M8,12H10V15H8V12M8,6H10V8H8V6Z\";\r\nvar mdiFridgeTop = \"M8,8V6H10V8H8M7,2H17A2,2 0 0,1 19,4V19A2,2 0 0,1 17,21V22H15V21H9V22H7V21A2,2 0 0,1 5,19V4A2,2 0 0,1 7,2M7,4V9H17V4H7M8,12V15H10V12H8Z\";\r\nvar mdiFridgeVariant = \"M19 4V19C19 20.11 18.11 21 17 21V22H15V21H12.5V2H17C18.11 2 19 2.9 19 4M7 2H11.5V21H9V22H7V21C5.9 21 5 20.11 5 19V4C5 2.9 5.9 2 7 2M10 10H7V14H10V10Z\";\r\nvar mdiFridgeVariantAlert = \"M17 4V19C17 20.11 16.11 21 15 21V22H13V21H10.5V2H15C16.11 2 17 2.9 17 4M5 2H9.5V21H7V22H5V21C3.9 21 3 20.11 3 19V4C3 2.9 3.9 2 5 2M8 10H5V14H8V10M19 7V13H21V7H19M19 17H21V15H19V17Z\";\r\nvar mdiFridgeVariantAlertOutline = \"M15 2H5C3.9 2 3 2.9 3 4V19C3 20.11 3.9 21 5 21V22H7V21H13V22H15V21C16.11 21 17 20.11 17 19V4C17 2.9 16.11 2 15 2M9 19H5V14H8V10H5V4H9V19M15 19H11V4H15V19M19 15H21V17H19V15M21 7V13H19V7H21Z\";\r\nvar mdiFridgeVariantOff = \"M2.39 1.73L1.11 3L5 6.89V19C5 20.11 5.9 21 7 21V22H9V21H11.5V13.39L12.5 14.39V21H15V22H17V21C17.58 21 18.1 20.75 18.46 20.35L20.84 22.73L22.11 21.46L2.39 1.73M10 14H7V10H8.11L10 11.89V14M19 15.8L12.5 9.3V2H17C18.11 2 19 2.9 19 4V15.8M11.5 8.3L5.7 2.5C6.05 2.19 6.5 2 7 2H11.5V8.3Z\";\r\nvar mdiFridgeVariantOffOutline = \"M7.2 4L5.7 2.5C6.05 2.19 6.5 2 7 2H17C18.11 2 19 2.9 19 4V15.8L17 13.8V4H13V9.8L11 7.8V4H7.2M22.11 21.46L20.84 22.73L18.46 20.35C18.1 20.75 17.58 21 17 21V22H15V21H9V22H7V21C5.9 21 5 20.11 5 19V6.89L1.11 3L2.39 1.73L22.11 21.46M7 10H8.11L7 8.89V10M11 12.89L10 11.89V14H7V19H11V12.89M17 18.89L13 14.89V19H17V18.89Z\";\r\nvar mdiFridgeVariantOutline = \"M17 2H7C5.9 2 5 2.9 5 4V19C5 20.11 5.9 21 7 21V22H9V21H15V22H17V21C18.11 21 19 20.11 19 19V4C19 2.9 18.11 2 17 2M7 19V14H10V10H7V4H11V19H7M17 19H13V4H17V19Z\";\r\nvar mdiFruitCherries = \"M16 13H15.5C14.8 11.7 14.3 10 13.8 8.3L14.7 9.2C17.4 11.3 19.8 10.9 19.8 10.9S20.5 7.1 17.8 5.1C15.5 3.3 13.4 3.3 12.8 3.4C12.7 2.8 12.7 2.3 12.6 1.9L11.2 2C11.2 5.2 8.5 11.1 7.6 13C5.6 13.2 4 14.9 4 17C4 19.2 5.8 21 8 21C9.1 21 10 20.6 10.7 19.9C10.3 19 10 18 10 17S10.3 15 10.7 14.1C10.3 13.7 9.7 13.4 9.2 13.2C9.9 11.7 11.1 9 11.9 6.4C12.3 8.7 13.1 11.4 14.1 13.5C12.9 14.2 12 15.5 12 17C12 19.2 13.8 21 16 21S20 19.2 20 17 18.2 13 16 13M8 15.5C7.2 15.5 6.5 16.2 6.5 17H5.5C5.5 15.6 6.6 14.5 8 14.5V15.5M16 15.5C15.2 15.5 14.5 16.2 14.5 17H13.5C13.5 15.6 14.6 14.5 16 14.5V15.5Z\";\r\nvar mdiFruitCherriesOff = \"M22.1 21.5L2.4 1.7L1.1 3L8.7 10.6C8.3 11.6 7.9 12.5 7.6 13C5.6 13.2 4 14.9 4 17C4 19.2 5.8 21 8 21C9.1 21 10 20.6 10.7 19.9C10.3 19 10 18 10 17S10.3 15 10.7 14.1C10.3 13.7 9.7 13.4 9.2 13.2C9.4 12.8 9.6 12.3 9.9 11.7L12.8 14.6C12.3 15.3 12 16.1 12 17C12 19.2 13.8 21 16 21C16.9 21 17.7 20.7 18.3 20.2L20.8 22.7L22.1 21.5M8 15.5C7.2 15.5 6.5 16.2 6.5 17H5.5C5.5 15.6 6.6 14.5 8 14.5V15.5M14.5 17H13.5C13.5 16.5 13.6 16.1 13.8 15.7L14.6 16.5C14.5 16.7 14.5 16.8 14.5 17M20 16.8L16.2 13C18.2 13.1 19.9 14.8 20 16.8M11.3 8.1L10.1 6.9C10.7 5.1 11.2 3.3 11.2 2L12.6 1.9C12.7 2.3 12.7 2.8 12.8 3.4C13.4 3.3 15.5 3.3 17.8 5.1C20.5 7.1 19.8 10.9 19.8 10.9S17.4 11.3 14.7 9.2L13.8 8.3C14.1 9.5 14.5 10.7 14.9 11.7L12.6 9.4C12.3 8.4 12.1 7.4 11.9 6.4C11.7 7 11.5 7.6 11.3 8.1Z\";\r\nvar mdiFruitCitrus = \"M9 15.9C6.9 15.7 5.1 14.9 4 13.6C3.2 13.6 2.4 13.1 2.1 12.3C1.8 11.5 2.1 10.7 2.8 10.2C2.9 7.2 5.6 4.1 9.7 2.7C13.8 1.3 18 2.1 20 4.4C20.8 4.4 21.6 4.9 21.9 5.7C22.2 6.5 21.9 7.3 21.2 7.8C21.2 8.6 21 9.4 20.6 10.2C19.4 9.5 18 9 16.5 9C12.6 9 9.3 12 9 15.9M22 16.5C22 19.5 19.5 22 16.5 22S11 19.5 11 16.5 13.5 11 16.5 11 22 13.5 22 16.5M13.3 18L15.6 16.5L13.3 15C13.1 15.5 13 16 13 16.5S13.1 17.5 13.3 18M16 17.4L13.9 18.8C14.4 19.4 15.2 19.8 16 20V17.4M16 13.1C15.2 13.2 14.4 13.6 13.9 14.3L16 15.7V13.1M17 15.6L19.1 14.2C18.6 13.6 17.8 13.2 17 13V15.6M19.1 18.8L17 17.4V19.9C17.8 19.8 18.6 19.4 19.1 18.8M20 16.5C20 16 19.9 15.5 19.7 15L17.4 16.5L19.7 18C19.9 17.5 20 17 20 16.5Z\";\r\nvar mdiFruitCitrusOff = \"M22.1 21.5L2.4 1.7L1.1 3L4.4 6.3C3.4 7.5 2.9 8.9 2.8 10.2C2.1 10.7 1.8 11.5 2.1 12.3C2.4 13.1 3.2 13.6 4 13.6C5.1 14.9 6.9 15.7 9 15.9C9.1 14.5 9.6 13.3 10.3 12.2L11.8 13.7C11.3 14.5 11 15.5 11 16.5C11 19.5 13.5 22 16.5 22C17.5 22 18.5 21.7 19.3 21.2L20.8 22.7L22.1 21.5M13 16.5C13 16 13.1 15.6 13.3 15.1L15 16.8L13.3 18C13.1 17.5 13 17 13 16.5M13.9 18.8L15.7 17.6L16 17.9V20C15.2 19.8 14.4 19.4 13.9 18.8M17 19.9V18.9L17.8 19.7C17.5 19.8 17.3 19.9 17 19.9M20 16.8V16.5C20 16 19.9 15.5 19.7 15L18.8 15.6L18.1 14.9L19.1 14.2C18.6 13.6 17.8 13.2 17 13V13.8L14.6 11.4C15.2 11.2 15.9 11 16.5 11C19.5 11 22 13.5 22 16.5C22 17.2 21.9 17.8 21.6 18.4L20 16.8M13 9.8L7.1 3.9C7.9 3.4 8.8 3 9.7 2.7C13.8 1.3 18 2.1 20 4.4C20.8 4.4 21.6 4.9 21.9 5.7C22.2 6.5 21.9 7.3 21.2 7.8C21.2 8.6 21 9.4 20.6 10.2C19.4 9.5 18 9 16.5 9C15.3 9 14.1 9.3 13 9.8Z\";\r\nvar mdiFruitGrapes = \"M14 12C14 13.1 13.1 14 12 14S10 13.1 10 12 10.9 10 12 10 14 10.9 14 12M7 10C5.9 10 5 10.9 5 12S5.9 14 7 14 9 13.1 9 12 8.1 10 7 10M17 10C15.9 10 15 10.9 15 12S15.9 14 17 14 19 13.1 19 12 18.1 10 17 10M14.5 6C13.4 6 12.5 6.9 12.5 8S13.4 10 14.5 10 16.5 9.1 16.5 8 15.6 6 14.5 6M9.5 6C8.4 6 7.5 6.9 7.5 8S8.4 10 9.5 10 11.5 9.1 11.5 8 10.6 6 9.5 6M14.5 14C13.4 14 12.5 14.9 12.5 16S13.4 18 14.5 18 16.5 17.1 16.5 16 15.6 14 14.5 14M9.5 14C8.4 14 7.5 14.9 7.5 16S8.4 18 9.5 18 11.5 17.1 11.5 16 10.6 14 9.5 14M12 18C10.9 18 10 18.9 10 20S10.9 22 12 22 14 21.1 14 20 13.1 18 12 18M14.4 2.2L13.6 1C11.4 2 11.2 5.6 11.2 6H12.7C12.8 5.2 13.1 2.7 14.4 2.2Z\";\r\nvar mdiFruitGrapesOutline = \"M19 12C19 10.61 18.05 9.47 16.78 9.12C16.92 8.78 17 8.4 17 8C17 6.34 15.66 5 14 5C13.57 5 13.17 5.1 12.81 5.26C13 4.19 13.39 2.59 14.4 2.2L13.6 1C11.9 1.77 11.4 4.09 11.26 5.29C10.87 5.11 10.45 5 10 5C8.34 5 7 6.34 7 8C7 8.4 7.08 8.77 7.22 9.12C5.94 9.46 5 10.62 5 12C5 13.39 5.95 14.54 7.23 14.88C7.09 15.22 7 15.6 7 16C7 17.39 7.94 18.54 9.22 18.88C9.08 19.23 9 19.61 9 20C9 21.66 10.34 23 12 23S15 21.66 15 20C15 19.61 14.92 19.23 14.78 18.88C16.06 18.54 17 17.39 17 16C17 15.6 16.92 15.23 16.77 14.88C18.05 14.54 19 13.39 19 12M16.31 9.88V9.9H16.3L16.31 9.88M14 6.5C14.83 6.5 15.5 7.17 15.5 8S14.83 9.5 14 9.5 12.5 8.83 12.5 8 13.17 6.5 14 6.5M13.5 12C13.5 12.83 12.83 13.5 12 13.5S10.5 12.83 10.5 12 11.17 10.5 12 10.5 13.5 11.17 13.5 12M10 6.5C10.83 6.5 11.5 7.17 11.5 8S10.83 9.5 10 9.5 8.5 8.83 8.5 8 9.17 6.5 10 6.5M6.5 12C6.5 11.17 7.17 10.5 8 10.5S9.5 11.17 9.5 12 8.83 13.5 8 13.5 6.5 12.83 6.5 12M8.5 16C8.5 15.17 9.17 14.5 10 14.5S11.5 15.17 11.5 16 10.83 17.5 10 17.5 8.5 16.83 8.5 16M12 21.5C11.17 21.5 10.5 20.83 10.5 20S11.17 18.5 12 18.5 13.5 19.17 13.5 20 12.83 21.5 12 21.5M14 17.5C13.17 17.5 12.5 16.83 12.5 16S13.17 14.5 14 14.5 15.5 15.17 15.5 16 14.83 17.5 14 17.5M16 13.5C15.17 13.5 14.5 12.83 14.5 12S15.17 10.5 16 10.5 17.5 11.17 17.5 12 16.83 13.5 16 13.5Z\";\r\nvar mdiFruitPineapple = \"M14.4 7.7C16.4 6.4 19 7 19 7C17.2 4.6 15.1 4.7 13.6 5.2V5C14.7 3.4 16.9 3.5 16.9 3.5C15.3 2.1 13.9 2.5 13 3C12.5 1.8 12 1 12 1C11.6 1.7 11.3 2.4 11 3.1C10.1 2.5 8.6 2.1 7 3.5C7 3.5 9.3 3.5 10.4 5.2C8.9 4.7 6.8 4.6 5 7C5 7 7.6 6.4 9.6 7.7C7.5 8.9 6 11.7 6 15C6 19.4 8.7 23 12 23S18 19.4 18 15C18 11.7 16.5 8.9 14.4 7.7M15.8 16.8C15.7 17.2 15.6 17.6 15.4 18L14 16L12.5 18L14.1 20.1C13.8 20.3 13.6 20.5 13.3 20.7L12 19L10.7 20.7C10.4 20.6 10.1 20.4 9.9 20.1L11.5 18L10 16L8.5 17.9C8.4 17.5 8.2 17.1 8.1 16.7L9.5 15L8.2 13.2C8.3 12.8 8.4 12.4 8.6 12L10 14L11.5 12L9.9 9.9C10.2 9.7 10.4 9.5 10.7 9.3L12 11L13.3 9.3C13.6 9.4 13.9 9.6 14.1 9.9L12.5 12L14 14L15.5 12.1C15.6 12.5 15.8 12.9 15.9 13.3L14.5 15L15.8 16.8M12 13L13.5 15L12 17L10.5 15L12 13Z\";\r\nvar mdiFruitWatermelon = \"M16.4 16.4C19.8 13 19.8 7.5 16.4 4.2L4.2 16.4C7.5 19.8 13 19.8 16.4 16.4M16 7C16.6 7 17 7.4 17 8C17 8.6 16.6 9 16 9S15 8.6 15 8C15 7.4 15.4 7 16 7M16 11C16.6 11 17 11.4 17 12C17 12.6 16.6 13 16 13S15 12.6 15 12C15 11.4 15.4 11 16 11M12 11C12.6 11 13 11.4 13 12C13 12.6 12.6 13 12 13S11 12.6 11 12C11 11.4 11.4 11 12 11M12 15C12.6 15 13 15.4 13 16C13 16.6 12.6 17 12 17S11 16.6 11 16C11 15.4 11.4 15 12 15M8 17C7.4 17 7 16.6 7 16C7 15.4 7.4 15 8 15S9 15.4 9 16C9 16.6 8.6 17 8 17M18.6 18.6C14 23.2 6.6 23.2 2 18.6L3.4 17.2C7.2 21 13.3 21 17.1 17.2C20.9 13.4 20.9 7.3 17.1 3.5L18.6 2C23.1 6.6 23.1 14 18.6 18.6Z\";\r\nvar mdiFuel = \"M3,2H6C6.28,2 6.53,2.11 6.71,2.29L8.79,4.38L9.59,3.59C10,3.2 10.5,3 11,3H17C17.5,3 18,3.2 18.41,3.59L19.41,4.59C19.8,5 20,5.5 20,6V19A2,2 0 0,1 18,21H8A2,2 0 0,1 6,19V13L6,12V8C6,7.5 6.2,7 6.59,6.59L7.38,5.79L5.59,4H3V2M11,5V7H17V5H11M11.41,11L9.41,9H8V10.41L10,12.41V15.59L8,17.59V19H9.41L11.41,17H14.59L16.59,19H18V17.59L16,15.59V12.41L18,10.41V9H16.59L14.59,11H11.41M12,13H14V15H12V13Z\";\r\nvar mdiFullscreen = \"M5,5H10V7H7V10H5V5M14,5H19V10H17V7H14V5M17,14H19V19H14V17H17V14M10,17V19H5V14H7V17H10Z\";\r\nvar mdiFullscreenExit = \"M14,14H19V16H16V19H14V14M5,14H10V19H8V16H5V14M8,5H10V10H5V8H8V5M19,8V10H14V5H16V8H19Z\";\r\nvar mdiFunction = \"M15.6,5.29C14.5,5.19 13.53,6 13.43,7.11L13.18,10H16V12H13L12.56,17.07C12.37,19.27 10.43,20.9 8.23,20.7C6.92,20.59 5.82,19.86 5.17,18.83L6.67,17.33C6.91,18.07 7.57,18.64 8.4,18.71C9.5,18.81 10.47,18 10.57,16.89L11,12H8V10H11.17L11.44,6.93C11.63,4.73 13.57,3.1 15.77,3.3C17.08,3.41 18.18,4.14 18.83,5.17L17.33,6.67C17.09,5.93 16.43,5.36 15.6,5.29Z\";\r\nvar mdiFunctionVariant = \"M12.42,5.29C11.32,5.19 10.35,6 10.25,7.11L10,10H12.82V12H9.82L9.38,17.07C9.18,19.27 7.24,20.9 5.04,20.7C3.79,20.59 2.66,19.9 2,18.83L3.5,17.33C3.83,18.38 4.96,18.97 6,18.63C6.78,18.39 7.33,17.7 7.4,16.89L7.82,12H4.82V10H8L8.27,6.93C8.46,4.73 10.39,3.1 12.6,3.28C13.86,3.39 15,4.09 15.66,5.17L14.16,6.67C13.91,5.9 13.23,5.36 12.42,5.29M22,13.65L20.59,12.24L17.76,15.07L14.93,12.24L13.5,13.65L16.35,16.5L13.5,19.31L14.93,20.72L17.76,17.89L20.59,20.72L22,19.31L19.17,16.5L22,13.65Z\";\r\nvar mdiFuriganaHorizontal = \"M8.5 2C7.12 2 6 3.12 6 4.5S7.12 7 8.5 7 11 5.88 11 4.5 9.88 2 8.5 2M15.5 2C14.12 2 13 3.12 13 4.5S14.12 7 15.5 7 18 5.88 18 4.5 16.88 2 15.5 2M11 8V10H5V12H14.95C14.53 13.13 13.5 14.5 12.16 15.67C11.12 14.74 10.35 13.82 9.82 13H7.5C8.08 14.25 9.13 15.62 10.62 16.96L6.55 20.22L5.76 20.84L7 22.41L7.8 21.78L12.17 18.28L16.55 21.78L17.33 22.41L18.58 20.84L17.8 20.22L13.73 16.97C15.34 15.5 16.7 13.85 17.07 12H19V10H13V8H11Z\";\r\nvar mdiFuriganaVertical = \"M8 5V7H2V9H11.95C11.53 10.13 10.5 11.5 9.16 12.67C8.12 11.74 7.35 10.82 6.82 10H4.5C5.08 11.25 6.13 12.62 7.62 13.96L3.55 17.22L2.76 17.84L4 19.41L4.8 18.78L9.17 15.28L13.55 18.78L14.33 19.41L15.58 17.84L14.8 17.22L10.73 13.97C12.34 12.5 13.7 10.85 14.07 9H16V7H10V5H8M19.5 6C18.12 6 17 7.12 17 8.5S18.12 11 19.5 11 22 9.88 22 8.5 20.88 6 19.5 6M19.47 13C18.09 13 16.97 14.12 16.97 15.5S18.09 18 19.47 18 21.97 16.88 21.97 15.5 20.85 13 19.47 13Z\";\r\nvar mdiFuse = \"M8,7V17H15V7H8M11.16,16V12.87H9.41L11.91,8V11.14H13.59L11.16,16M16,2V6H7V2A1,1 0 0,1 8,1H15A1,1 0 0,1 16,2M16,18V22A1,1 0 0,1 15,23H8A1,1 0 0,1 7,22V18H16Z\";\r\nvar mdiFuseAlert = \"M6 7V17H13V7H6M9.16 16V12.87H7.41L9.91 8V11.14H11.59L9.16 16M14 2V6H5V2C5 1.45 5.45 1 6 1H13C13.55 1 14 1.45 14 2M14 18V22C14 22.55 13.55 23 13 23H6C5.45 23 5 22.55 5 22V18H14M19 13H17V7H19V13M19 17H17V15H19V17Z\";\r\nvar mdiFuseBlade = \"M10,21H8L6,19V16H10V21M18,16H14V21H16L18,19V16M3,3V4A1,1 0 0,0 4,5V14A1,1 0 0,0 5,15H19A1,1 0 0,0 20,14V5H20A1,1 0 0,0 21,4V3H3M11.83,13V9.73H10L12.61,4.66V7.93H14.36L11.83,13Z\";\r\nvar mdiFuseOff = \"M15 11.8L10.2 7H15V11.8M16 6V2C16 1.45 15.55 1 15 1H8C7.45 1 7 1.45 7 2V3.8L9.2 6H16M2.39 1.73L1.11 3L8 9.89V17H15.11L20.84 22.73L22.11 21.46L2.39 1.73M7 22C7 22.55 7.45 23 8 23H15C15.55 23 16 22.55 16 22V18H7V22Z\";\r\nvar mdiGamepad = \"M16.5,9L13.5,12L16.5,15H22V9M9,16.5V22H15V16.5L12,13.5M7.5,9H2V15H7.5L10.5,12M15,7.5V2H9V7.5L12,10.5L15,7.5Z\";\r\nvar mdiGamepadCircle = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8Z\";\r\nvar mdiGamepadCircleDown = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8M12,3A2,2 0 0,0 10,5A2,2 0 0,0 12,7A2,2 0 0,0 14,5A2,2 0 0,0 12,3M5,10A2,2 0 0,0 3,12A2,2 0 0,0 5,14A2,2 0 0,0 7,12A2,2 0 0,0 5,10M19,10A2,2 0 0,0 17,12A2,2 0 0,0 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10Z\";\r\nvar mdiGamepadCircleLeft = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8M19,10A2,2 0 0,0 17,12A2,2 0 0,0 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10M12,17A2,2 0 0,0 10,19A2,2 0 0,0 12,21A2,2 0 0,0 14,19A2,2 0 0,0 12,17M12,3A2,2 0 0,0 10,5A2,2 0 0,0 12,7A2,2 0 0,0 14,5A2,2 0 0,0 12,3Z\";\r\nvar mdiGamepadCircleOutline = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M5,10A2,2 0 0,0 3,12A2,2 0 0,0 5,14A2,2 0 0,0 7,12A2,2 0 0,0 5,10M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,3A2,2 0 0,0 10,5A2,2 0 0,0 12,7A2,2 0 0,0 14,5A2,2 0 0,0 12,3M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M12,17A2,2 0 0,0 10,19A2,2 0 0,0 12,21A2,2 0 0,0 14,19A2,2 0 0,0 12,17M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8M19,10A2,2 0 0,0 17,12A2,2 0 0,0 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10Z\";\r\nvar mdiGamepadCircleRight = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8M12,3A2,2 0 0,0 10,5A2,2 0 0,0 12,7A2,2 0 0,0 14,5A2,2 0 0,0 12,3M5,10A2,2 0 0,0 3,12A2,2 0 0,0 5,14A2,2 0 0,0 7,12A2,2 0 0,0 5,10M12,17A2,2 0 0,0 10,19A2,2 0 0,0 12,21A2,2 0 0,0 14,19A2,2 0 0,0 12,17Z\";\r\nvar mdiGamepadCircleUp = \"M5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8M12,1A4,4 0 0,1 16,5A4,4 0 0,1 12,9A4,4 0 0,1 8,5A4,4 0 0,1 12,1M12,15A4,4 0 0,1 16,19A4,4 0 0,1 12,23A4,4 0 0,1 8,19A4,4 0 0,1 12,15M19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A4,4 0 0,1 15,12A4,4 0 0,1 19,8M5,10A2,2 0 0,0 3,12A2,2 0 0,0 5,14A2,2 0 0,0 7,12A2,2 0 0,0 5,10M19,10A2,2 0 0,0 17,12A2,2 0 0,0 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10M12,17A2,2 0 0,0 10,19A2,2 0 0,0 12,21A2,2 0 0,0 14,19A2,2 0 0,0 12,17Z\";\r\nvar mdiGamepadDown = \"M9,2V7.5L12,10.5L15,7.5V2H9M2,9V15H7.5L10.5,12L7.5,9H2M16.5,9L13.5,12L16.5,15H22V9H16.5M12,13.5L9,16.5V22H15V16.5L12,13.5M11,18H13V20H11V18Z\";\r\nvar mdiGamepadLeft = \"M9,2V7.5L12,10.5L15,7.5V2H9M2,9V15H7.5L10.5,12L7.5,9H2M16.5,9L13.5,12L16.5,15H22V9H16.5M4,11H6V13H4V11M12,13.5L9,16.5V22H15V16.5L12,13.5Z\";\r\nvar mdiGamepadRight = \"M9,2V7.5L12,10.5L15,7.5V2H9M2,9V15H7.5L10.5,12L7.5,9H2M16.5,9L13.5,12L16.5,15H22V9H16.5M18,11H20V13H18V11M12,13.5L9,16.5V22H15V16.5L12,13.5Z\";\r\nvar mdiGamepadRound = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8Z\";\r\nvar mdiGamepadRoundDown = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8M10,16V20H14V16H10Z\";\r\nvar mdiGamepadRoundLeft = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8M4,10V14H8V10H4Z\";\r\nvar mdiGamepadRoundOutline = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8M4,10V14H10V20H14V14H20V10H14V4H10V10H4Z\";\r\nvar mdiGamepadRoundRight = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8M16,10V14H20V10H16Z\";\r\nvar mdiGamepadRoundUp = \"M4,8H8V4A2,2 0 0,1 10,2H14A2,2 0 0,1 16,4V8H20A2,2 0 0,1 22,10V14A2,2 0 0,1 20,16H16V20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8M10,4V8H14V4H10Z\";\r\nvar mdiGamepadSquare = \"M21,6H3A2,2 0 0,0 1,8V16A2,2 0 0,0 3,18H21A2,2 0 0,0 23,16V8A2,2 0 0,0 21,6M11,13H8V16H6V13H3V11H6V8H8V11H11M15.5,15A1.5,1.5 0 0,1 14,13.5A1.5,1.5 0 0,1 15.5,12A1.5,1.5 0 0,1 17,13.5A1.5,1.5 0 0,1 15.5,15M19.5,12A1.5,1.5 0 0,1 18,10.5A1.5,1.5 0 0,1 19.5,9A1.5,1.5 0 0,1 21,10.5A1.5,1.5 0 0,1 19.5,12Z\";\r\nvar mdiGamepadSquareOutline = \"M21,6H3A2,2 0 0,0 1,8V16A2,2 0 0,0 3,18H21A2,2 0 0,0 23,16V8A2,2 0 0,0 21,6M21,16H3V8H21M6,15H8V13H10V11H8V9H6V11H4V13H6M14.5,12A1.5,1.5 0 0,1 16,13.5A1.5,1.5 0 0,1 14.5,15A1.5,1.5 0 0,1 13,13.5A1.5,1.5 0 0,1 14.5,12M18.5,9A1.5,1.5 0 0,1 20,10.5A1.5,1.5 0 0,1 18.5,12A1.5,1.5 0 0,1 17,10.5A1.5,1.5 0 0,1 18.5,9Z\";\r\nvar mdiGamepadUp = \"M9,2V7.5L12,10.5L15,7.5V2H9M11,4H13V6H11V4M2,9V15H7.5L10.5,12L7.5,9H2M16.5,9L13.5,12L16.5,15H22V9H16.5M12,13.5L9,16.5V22H15V16.5L12,13.5Z\";\r\nvar mdiGamepadVariant = \"M7,6H17A6,6 0 0,1 23,12A6,6 0 0,1 17,18C15.22,18 13.63,17.23 12.53,16H11.47C10.37,17.23 8.78,18 7,18A6,6 0 0,1 1,12A6,6 0 0,1 7,6M6,9V11H4V13H6V15H8V13H10V11H8V9H6M15.5,12A1.5,1.5 0 0,0 14,13.5A1.5,1.5 0 0,0 15.5,15A1.5,1.5 0 0,0 17,13.5A1.5,1.5 0 0,0 15.5,12M18.5,9A1.5,1.5 0 0,0 17,10.5A1.5,1.5 0 0,0 18.5,12A1.5,1.5 0 0,0 20,10.5A1.5,1.5 0 0,0 18.5,9Z\";\r\nvar mdiGamepadVariantOutline = \"M6,9H8V11H10V13H8V15H6V13H4V11H6V9M18.5,9A1.5,1.5 0 0,1 20,10.5A1.5,1.5 0 0,1 18.5,12A1.5,1.5 0 0,1 17,10.5A1.5,1.5 0 0,1 18.5,9M15.5,12A1.5,1.5 0 0,1 17,13.5A1.5,1.5 0 0,1 15.5,15A1.5,1.5 0 0,1 14,13.5A1.5,1.5 0 0,1 15.5,12M17,5A7,7 0 0,1 24,12A7,7 0 0,1 17,19C15.04,19 13.27,18.2 12,16.9C10.73,18.2 8.96,19 7,19A7,7 0 0,1 0,12A7,7 0 0,1 7,5H17M7,7A5,5 0 0,0 2,12A5,5 0 0,0 7,17C8.64,17 10.09,16.21 11,15H13C13.91,16.21 15.36,17 17,17A5,5 0 0,0 22,12A5,5 0 0,0 17,7H7Z\";\r\nvar mdiGamma = \"M11.76 19C12.92 19 13.58 18 13.58 16.29C13.58 15.2 13.5 13.88 13.3 12.67L18 5H15.28L12.71 9.82L12.55 9.33C11.83 7.19 10.82 5 8.68 5C8 5 7.45 5.18 7 5.54C6 6.39 6 8 6 8.5H6.91C6.97 8.06 7.21 6.83 8.25 6.83C10 6.83 10.8 10 11.4 12.42C10.5 14.58 10 16.14 10 16.97C10 17.95 10.56 19 11.76 19\";\r\nvar mdiGantryCrane = \"M21,6H22V4H21V3H18V4H6V3H3V4H2V6H3V20H2V22H7V20H6V6H11V7H11.5V10.62C11,10.79 10.69,11.25 10.69,11.76C10.69,12.2 10.92,12.6 11.3,12.82V14H11.92C12.26,14 12.54,14.27 12.55,14.61C12.55,14.96 12.28,15.24 11.93,15.24C11.71,15.24 11.5,15.12 11.39,14.93C11.22,14.64 10.84,14.54 10.55,14.71C10.26,14.87 10.15,15.25 10.32,15.55C10.65,16.12 11.26,16.47 11.92,16.47C12.94,16.46 13.76,15.62 13.75,14.6C13.74,13.83 13.26,13.14 12.53,12.88V12.82C13.12,12.5 13.34,11.78 13.03,11.2C12.92,11 12.74,10.81 12.53,10.7V7H13V6H18V20H17V22H22V20H21V6M5,15.29V16.71L4,17.71V16.29L5,15.29M4,20V19.24L5,18.24V19.66L4.66,20H4M4,7.29L5,6.29V7.71L4,8.71V7.29M4,10.29L5,9.29V10.71L4,11.71V10.29M4,13.29L5,12.29V13.71L4,14.71V13.24L4,13.29M20,15.29V16.71L19,17.71V16.29L20,15.29M19,20V19.24L20,18.24V19.66L19.66,20H19M19,7.29L20,6.29V7.71L19,8.71V7.29M19,10.29L20,9.29V10.71L19,11.71V10.29M19,13.29L20,12.29V13.71L19,14.71V13.24L19,13.29Z\";\r\nvar mdiGarage = \"M19,20H17V11H7V20H5V9L12,5L19,9V20M8,12H16V14H8V12M8,15H16V17H8V15M16,18V20H8V18H16Z\";\r\nvar mdiGarageAlert = \"M17,20H15V11H5V20H3V9L10,5L17,9V20M6,12H14V14H6V12M6,15H14V17H6V15M19,15V10H21V15H19M19,19V17H21V19H19Z\";\r\nvar mdiGarageAlertVariant = \"M20 9V20H18V11H2V20H0V9L10 5L20 9M17 12H3V14H17V12M17 15H3V17H17V15M22 15V10H24V15H22M22 19V17H24V19H22Z\";\r\nvar mdiGarageOpen = \"M19,20H17V11H7V20H5V9L12,5L19,9V20M8,12H16V14H8V12Z\";\r\nvar mdiGarageOpenVariant = \"M22 9V20H20V11H4V20H2V9L12 5L22 9M19 12H5V14H19V12Z\";\r\nvar mdiGarageVariant = \"M22 9V20H20V11H4V20H2V9L12 5L22 9M19 12H5V14H19V12M19 18H5V20H19V18M19 15H5V17H19V15Z\";\r\nvar mdiGasCylinder = \"M16,9V14L16,20A2,2 0 0,1 14,22H10A2,2 0 0,1 8,20V14L8,9C8,7.14 9.27,5.57 11,5.13V4H9V2H15V4H13V5.13C14.73,5.57 16,7.14 16,9Z\";\r\nvar mdiGasStation = \"M18,10A1,1 0 0,1 17,9A1,1 0 0,1 18,8A1,1 0 0,1 19,9A1,1 0 0,1 18,10M12,10H6V5H12M19.77,7.23L19.78,7.22L16.06,3.5L15,4.56L17.11,6.67C16.17,7 15.5,7.93 15.5,9A2.5,2.5 0 0,0 18,11.5C18.36,11.5 18.69,11.42 19,11.29V18.5A1,1 0 0,1 18,19.5A1,1 0 0,1 17,18.5V14C17,12.89 16.1,12 15,12H14V5C14,3.89 13.1,3 12,3H6C4.89,3 4,3.89 4,5V21H14V13.5H15.5V18.5A2.5,2.5 0 0,0 18,21A2.5,2.5 0 0,0 20.5,18.5V9C20.5,8.31 20.22,7.68 19.77,7.23Z\";\r\nvar mdiGasStationOff = \"M1 4.27L2.28 3L21 21.72L19.73 23L17.71 21C16.56 20.85 15.65 19.94 15.5 18.78L14 17.27V21H4V7.27L1 4.27M18 10C18.55 10 19 9.55 19 9C19 8.45 18.55 8 18 8C17.45 8 17 8.45 17 9C17 9.55 17.45 10 18 10M12 10V5H6.82L5.06 3.23C5.34 3.08 5.66 3 6 3H12C13.1 3 14 3.89 14 5V12H15C16.1 12 17 12.89 17 14V15.18L11.82 10H12M6 10H6.73L6 9.27V10M19.77 7.23C20.22 7.68 20.5 8.31 20.5 9L20.5 18.67L19 17.18V11.29C18.69 11.42 18.36 11.5 18 11.5C16.62 11.5 15.5 10.38 15.5 9C15.5 7.93 16.17 7.03 17.11 6.67L15 4.56L16.06 3.5L19.78 7.22L19.77 7.23Z\";\r\nvar mdiGasStationOffOutline = \"M1 4.27L2.28 3L6 6.72L21 21.72L19.73 23L17.72 21C16.56 20.85 15.65 19.94 15.5 18.78L14 17.27V21H4V7.27L1 4.27M19.77 7.23C20.22 7.68 20.5 8.31 20.5 9L20.5 18.67L19 17.18V11.29C18.69 11.42 18.36 11.5 18 11.5C16.62 11.5 15.5 10.38 15.5 9C15.5 7.93 16.17 7.03 17.11 6.67L15 4.56L16.06 3.5L19.78 7.22L19.77 7.23M11.82 10H12V5H6.82L5.06 3.24C5.34 3.09 5.66 3 6 3H12C13.1 3 14 3.9 14 5V12H15C16.1 12 17 12.9 17 14V15.18L11.82 10M6 10H6.73L6 9.27V10M6 12V19H12V15.27L8.73 12H6M18 10C18.55 10 19 9.55 19 9C19 8.45 18.55 8 18 8C17.45 8 17 8.45 17 9C17 9.55 17.45 10 18 10Z\";\r\nvar mdiGasStationOutline = \"M19.77,7.23L19.78,7.22L16.06,3.5L15,4.56L17.11,6.67C16.17,7.03 15.5,7.93 15.5,9A2.5,2.5 0 0,0 18,11.5C18.36,11.5 18.69,11.42 19,11.29V18.5A1,1 0 0,1 18,19.5A1,1 0 0,1 17,18.5V14A2,2 0 0,0 15,12H14V5A2,2 0 0,0 12,3H6A2,2 0 0,0 4,5V21H14V13.5H15.5V18.5A2.5,2.5 0 0,0 18,21A2.5,2.5 0 0,0 20.5,18.5V9C20.5,8.31 20.22,7.68 19.77,7.23M12,13.5V19H6V12H12V13.5M12,10H6V5H12V10M18,10A1,1 0 0,1 17,9A1,1 0 0,1 18,8A1,1 0 0,1 19,9A1,1 0 0,1 18,10Z\";\r\nvar mdiGate = \"M9,5V10H7V6H5V10H3V8H1V20H3V18H5V20H7V18H9V20H11V18H13V20H15V18H17V20H19V18H21V20H23V8H21V10H19V6H17V10H15V5H13V10H11V5H9M3,12H5V16H3V12M7,12H9V16H7V12M11,12H13V16H11V12M15,12H17V16H15V12M19,12H21V16H19V12Z\";\r\nvar mdiGateAnd = \"M2,4V20H14A8,8 0 0,0 22,12A8,8 0 0,0 14,4H2M4,6H14A6,6 0 0,1 20,12A6,6 0 0,1 14,18H4V6Z\";\r\nvar mdiGateArrowRight = \"M15 5V10H13V6H11V10H9V8H7V20H9V18H11V20H12.09A6 6 0 0 1 12 19A6 6 0 0 1 13 15.69V12H15V13.81A6 6 0 0 1 17 13.09V12H19V13.09A6 6 0 0 1 21 13.81V12H22V10H21V5H19V10H17V5H15M9 12H11V16H9V12M19 16V18H15V20H19V22L22 19L19 16Z\";\r\nvar mdiGateNand = \"M2,4V20H10C13.43,20 16.5,17.84 17.6,14.6C18,14.8 18.5,15 19,15A3,3 0 0,0 22,12A3,3 0 0,0 19,9C18.5,9 18.03,9.15 17.6,9.4C16.5,6.16 13.43,4 10,4H2M4,6H10A6,6 0 0,1 16,12A6,6 0 0,1 10,18H4V6M19,11C19.5,11 20,11.5 20,12C20,12.5 19.5,13 19,13A1,1 0 0,1 18,12C18,11.5 18.5,11 19,11Z\";\r\nvar mdiGateNor = \"M2,4C5,10 5,14 2,20H5C9.4,20 13,17.7 16.6,13.7C17.15,14.5 18.04,15 19,15A3,3 0 0,0 22,12A3,3 0 0,0 19,9C18.04,9 17.15,9.5 16.6,10.3C13,6.3 9.4,4 5,4H2M5,6C8.8,6 12,8.1 15.3,12C12,15.9 8.8,18 5,18C6.5,14 6.5,10 5,6M19,11C19.5,11 20,11.5 20,12C20,12.5 19.5,13 19,13A1,1 0 0,1 18,12C18,11.5 18.5,11 19,11Z\";\r\nvar mdiGateNot = \"M2,4V20L16.2,13C16.62,14.19 17.74,15 19,15A3,3 0 0,0 22,12A3,3 0 0,0 19,9C17.74,9 16.62,9.81 16.2,11L2,4M4,7.3L13.7,12L4,16.7V7.3M19,11C19.5,11 20,11.5 20,12C20,12.5 19.5,13 19,13A1,1 0 0,1 18,12C18,11.5 18.5,11 19,11Z\";\r\nvar mdiGateOpen = \"M7 20V6H5V10H3V8H1V20H3V18H5V20H7M3 16V12H5V16H3M21 8V10H19V6H17V20H19V18H21V20H23V8H21M21 16H19V12H21V16Z\";\r\nvar mdiGateOr = \"M2,4C5,10 5,14 2,20H8C13,20 19,16 22,12C19,8 13,4 8,4H2M5,6H8C11.5,6 16.3,9 19.3,12C16.3,15 11.5,18 8,18H5C6.4,13.9 6.4,10.1 5,6Z\";\r\nvar mdiGateXnor = \"M2,4C5,10 5,14 2,20H4C7,14 7,10 4.1,4H2M6,4C9,10 9,14 6,20H9C12.2,20 14.8,16.8 16.7,14C17.28,14.65 18.12,15 19,15A3,3 0 0,0 22,12A3,3 0 0,0 19,9C18.12,9 17.28,9.35 16.7,10C14.7,7.2 12.2,4 9,4H6M9,6C12,6 14,10 15.5,12C14,14 12,18 9,18C10.6,14 10.6,10 9,6M19,11C19.5,11 20,11.5 20,12C20,12.5 19.5,13 19,13A1,1 0 0,1 18,12C18,11.5 18.5,11 19,11Z\";\r\nvar mdiGateXor = \"M2,4C5,10 5,14 2,20H4C7,14 7,10 4.1,4H2M6,4C9,10 9,14 6,20H9C14,20 18,17 22,12C18,7 14,4 9,4H6M9,6C12.8,6 16,8.1 19.3,12C15.9,15.9 12.8,18 9,18C10.5,14 10.5,10 9,6Z\";\r\nvar mdiGatsby = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4C8.27,4 5.14,6.55 4.25,10L14,19.75C17.45,18.86 20,15.73 20,12H14.75V13.5H18.2C17.71,15.54 16.24,17.19 14.31,17.94L6.06,9.69C7,7.31 9.3,5.63 12,5.63C14.13,5.63 16,6.67 17.18,8.28L18.41,7.22C16.95,5.26 14.63,4 12,4M4,12A8,8 0 0,0 12,20C12.04,20 12.09,20 4,12Z\";\r\nvar mdiGauge = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12C20,14.4 19,16.5 17.3,18C15.9,16.7 14,16 12,16C10,16 8.2,16.7 6.7,18C5,16.5 4,14.4 4,12A8,8 0 0,1 12,4M14,5.89C13.62,5.9 13.26,6.15 13.1,6.54L11.81,9.77L11.71,10C11,10.13 10.41,10.6 10.14,11.26C9.73,12.29 10.23,13.45 11.26,13.86C12.29,14.27 13.45,13.77 13.86,12.74C14.12,12.08 14,11.32 13.57,10.76L13.67,10.5L14.96,7.29L14.97,7.26C15.17,6.75 14.92,6.17 14.41,5.96C14.28,5.91 14.15,5.89 14,5.89M10,6A1,1 0 0,0 9,7A1,1 0 0,0 10,8A1,1 0 0,0 11,7A1,1 0 0,0 10,6M7,9A1,1 0 0,0 6,10A1,1 0 0,0 7,11A1,1 0 0,0 8,10A1,1 0 0,0 7,9M17,9A1,1 0 0,0 16,10A1,1 0 0,0 17,11A1,1 0 0,0 18,10A1,1 0 0,0 17,9Z\";\r\nvar mdiGaugeEmpty = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12C4,14.4 5,16.5 6.7,18C8.1,16.7 10,16 12,16C14,16 15.8,16.7 17.3,18C19,16.5 20,14.4 20,12A8,8 0 0,0 12,4M14,6A1,1 0 0,1 15,7A1,1 0 0,1 14,8A1,1 0 0,1 13,7A1,1 0 0,1 14,6M10,6A1,1 0 0,1 11,7A1,1 0 0,1 10,8A1,1 0 0,1 9,7A1,1 0 0,1 10,6M6.91,8.94C7.04,8.94 7.16,8.97 7.3,9L10.5,10.32L10.77,10.43C11.33,10 12.09,9.88 12.75,10.15C13.77,10.56 14.27,11.73 13.85,12.75C13.44,13.77 12.27,14.27 11.25,13.85C10.59,13.59 10.12,13 10,12.28L9.77,12.18L6.55,10.88L6.53,10.87C6,10.66 5.77,10.08 5.97,9.56C6.13,9.18 6.5,8.93 6.91,8.94V8.94M17,9A1,1 0 0,1 18,10A1,1 0 0,1 17,11A1,1 0 0,1 16,10A1,1 0 0,1 17,9Z\";\r\nvar mdiGaugeFull = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12C20,14.4 19,16.5 17.3,18C15.9,16.7 14,16 12,16C10,16 8.2,16.7 6.7,18C5,16.5 4,14.4 4,12A8,8 0 0,1 12,4M10,6A1,1 0 0,0 9,7A1,1 0 0,0 10,8A1,1 0 0,0 11,7A1,1 0 0,0 10,6M14,6A1,1 0 0,0 13,7A1,1 0 0,0 14,8A1,1 0 0,0 15,7A1,1 0 0,0 14,6M17.09,8.94C16.96,8.94 16.84,8.97 16.7,9L13.5,10.32L13.23,10.43C12.67,10 11.91,9.88 11.25,10.15C10.23,10.56 9.73,11.73 10.15,12.75C10.56,13.77 11.73,14.27 12.75,13.85C13.41,13.59 13.88,13 14,12.28L14.23,12.18L17.45,10.88L17.47,10.87C18,10.66 18.23,10.08 18.03,9.56C17.87,9.18 17.5,8.93 17.09,8.94M7,9A1,1 0 0,0 6,10A1,1 0 0,0 7,11A1,1 0 0,0 8,10A1,1 0 0,0 7,9Z\";\r\nvar mdiGaugeLow = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12C4,14.4 5,16.5 6.7,18C8.1,16.7 10,16 12,16C14,16 15.8,16.7 17.3,18C19,16.5 20,14.4 20,12A8,8 0 0,0 12,4M10,5.89C10.38,5.9 10.74,6.15 10.9,6.54L12.19,9.77L12.29,10C13,10.13 13.59,10.6 13.86,11.26C14.27,12.29 13.77,13.45 12.74,13.86C11.71,14.27 10.55,13.77 10.14,12.74C9.88,12.08 10,11.32 10.43,10.76L10.33,10.5L9.04,7.29L9.03,7.26C8.83,6.75 9.08,6.17 9.59,5.96C9.72,5.91 9.85,5.89 10,5.89V5.89M14,6A1,1 0 0,1 15,7A1,1 0 0,1 14,8A1,1 0 0,1 13,7A1,1 0 0,1 14,6M17,9A1,1 0 0,1 18,10A1,1 0 0,1 17,11A1,1 0 0,1 16,10A1,1 0 0,1 17,9M7,9A1,1 0 0,1 8,10A1,1 0 0,1 7,11A1,1 0 0,1 6,10A1,1 0 0,1 7,9Z\";\r\nvar mdiGavel = \"M2.3,20.28L11.9,10.68L10.5,9.26L9.78,9.97C9.39,10.36 8.76,10.36 8.37,9.97L7.66,9.26C7.27,8.87 7.27,8.24 7.66,7.85L13.32,2.19C13.71,1.8 14.34,1.8 14.73,2.19L15.44,2.9C15.83,3.29 15.83,3.92 15.44,4.31L14.73,5L16.15,6.43C16.54,6.04 17.17,6.04 17.56,6.43C17.95,6.82 17.95,7.46 17.56,7.85L18.97,9.26L19.68,8.55C20.07,8.16 20.71,8.16 21.1,8.55L21.8,9.26C22.19,9.65 22.19,10.29 21.8,10.68L16.15,16.33C15.76,16.72 15.12,16.72 14.73,16.33L14.03,15.63C13.63,15.24 13.63,14.6 14.03,14.21L14.73,13.5L13.32,12.09L3.71,21.7C3.32,22.09 2.69,22.09 2.3,21.7C1.91,21.31 1.91,20.67 2.3,20.28M20,19A2,2 0 0,1 22,21V22H12V21A2,2 0 0,1 14,19H20Z\";\r\nvar mdiGenderFemale = \"M12,4A6,6 0 0,1 18,10C18,12.97 15.84,15.44 13,15.92V18H15V20H13V22H11V20H9V18H11V15.92C8.16,15.44 6,12.97 6,10A6,6 0 0,1 12,4M12,6A4,4 0 0,0 8,10A4,4 0 0,0 12,14A4,4 0 0,0 16,10A4,4 0 0,0 12,6Z\";\r\nvar mdiGenderMale = \"M9,9C10.29,9 11.5,9.41 12.47,10.11L17.58,5H13V3H21V11H19V6.41L13.89,11.5C14.59,12.5 15,13.7 15,15A6,6 0 0,1 9,21A6,6 0 0,1 3,15A6,6 0 0,1 9,9M9,11A4,4 0 0,0 5,15A4,4 0 0,0 9,19A4,4 0 0,0 13,15A4,4 0 0,0 9,11Z\";\r\nvar mdiGenderMaleFemale = \"M17.58,4H14V2H21V9H19V5.41L15.17,9.24C15.69,10.03 16,11 16,12C16,14.42 14.28,16.44 12,16.9V19H14V21H12V23H10V21H8V19H10V16.9C7.72,16.44 6,14.42 6,12A5,5 0 0,1 11,7C12,7 12.96,7.3 13.75,7.83L17.58,4M11,9A3,3 0 0,0 8,12A3,3 0 0,0 11,15A3,3 0 0,0 14,12A3,3 0 0,0 11,9Z\";\r\nvar mdiGenderMaleFemaleVariant = \"M7 3A5 5 0 0 0 9 7A5 5 0 0 0 7 11A5 5 0 0 0 11 15.9V18H9V20H11V22H13V20H15V18H13V15.9A5 5 0 0 0 17 11A5 5 0 0 0 15 7A5 5 0 0 0 17 3H15A3 3 0 0 1 12 6A3 3 0 0 1 9 3M12 8A3 3 0 0 1 15 11A3 3 0 0 1 12 14A3 3 0 0 1 9 11A3 3 0 0 1 12 8Z\";\r\nvar mdiGenderNonBinary = \"M13 3H11V5.27L9.04 4.13L8.04 5.87L10 7L8.04 8.13L9.04 9.87L11 8.73V12.1C8.72 12.56 7 14.58 7 17C7 19.76 9.24 22 12 22S17 19.76 17 17C17 14.58 15.28 12.56 13 12.1V8.73L14.96 9.87L15.96 8.13L14 7L15.96 5.87L14.96 4.13L13 5.27V3M12 20C10.35 20 9 18.65 9 17S10.35 14 12 14 15 15.35 15 17 13.65 20 12 20Z\";\r\nvar mdiGenderTransgender = \"M19.58,3H15V1H23V9H21V4.41L16.17,9.24C16.69,10.03 17,11 17,12C17,14.42 15.28,16.44 13,16.9V19H15V21H13V23H11V21H9V19H11V16.9C8.72,16.44 7,14.42 7,12C7,11 7.3,10.04 7.82,9.26L6.64,8.07L5.24,9.46L3.83,8.04L5.23,6.65L3,4.42V8H1V1H8V3H4.41L6.64,5.24L8.08,3.81L9.5,5.23L8.06,6.66L9.23,7.84C10,7.31 11,7 12,7C13,7 13.96,7.3 14.75,7.83L19.58,3M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiGentoo = \"M10.28,2C9.93,2 9.57,2.03 9.23,2.1C5.61,2.76 3.06,5.89 2.85,7.96C2.74,8.97 3.29,9.73 3.59,10.06C4.4,10.97 6.03,11.66 7.07,12.23C5.56,13.5 4.87,14.14 4.19,14.86C3.17,15.93 2.45,17.1 2.45,17.95C2.45,18.22 2.4,19.09 2.76,19.77C2.89,20.03 3.27,20.89 4.41,21.53C5.14,21.94 6.17,22.09 7.19,21.95C10.33,21.5 14.54,18.83 17.55,16.35C19.46,14.77 20.86,13.23 21.26,12.5C21.59,11.87 21.63,10.78 21.44,10.09C20.9,8.14 16.53,4.15 12.96,2.55C12.14,2.18 11.2,2 10.28,2M11.34,4.91C11.59,4.91 11.81,4.94 12,5C13.15,5.3 15.08,6.68 14.91,7.94C14.68,9.6 13.23,10.27 11.56,10.03C10.58,9.9 8.63,8.8 8.78,6.89C8.89,5.4 10.3,4.9 11.34,4.91M11.32,6.65C11.05,6.65 10.84,6.71 10.74,6.87C10.27,7.59 10.5,8.09 10.92,8.42C11.07,8.04 12.71,8.45 12.75,8.79C14.17,7.72 12.36,6.66 11.32,6.65Z\";\r\nvar mdiGesture = \"M4.59,6.89C5.29,6.18 6,5.54 6.3,5.67C6.8,5.87 6.3,6.7 6,7.19C5.75,7.61 3.14,11.08 3.14,13.5C3.14,14.78 3.62,15.84 4.5,16.5C5.23,17.04 6.22,17.21 7.12,16.94C8.19,16.63 9.07,15.54 10.18,14.17C11.39,12.68 13,10.73 14.26,10.73C15.89,10.73 15.91,11.74 16,12.5C12.24,13.16 10.64,16.19 10.64,17.89C10.64,19.59 12.08,21 13.85,21C15.5,21 18.14,19.65 18.54,14.88H21V12.38H18.53C18.38,10.73 17.44,8.18 14.5,8.18C12.25,8.18 10.32,10.09 9.56,11C9,11.75 7.5,13.5 7.27,13.74C7,14.04 6.59,14.58 6.16,14.58C5.71,14.58 5.44,13.75 5.8,12.66C6.15,11.57 7.2,9.8 7.65,9.14C8.43,8 8.95,7.22 8.95,5.86C8.95,3.69 7.31,3 6.44,3C5.12,3 3.97,4 3.72,4.25C3.36,4.61 3.06,4.91 2.84,5.18L4.59,6.89M13.88,18.55C13.57,18.55 13.14,18.29 13.14,17.83C13.14,17.23 13.87,15.63 16,15.07C15.71,17.76 14.58,18.55 13.88,18.55Z\";\r\nvar mdiGestureDoubleTap = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M11,5A4,4 0 0,1 15,9C15,10.5 14.2,11.77 13,12.46V11.24C13.61,10.69 14,9.89 14,9A3,3 0 0,0 11,6A3,3 0 0,0 8,9C8,9.89 8.39,10.69 9,11.24V12.46C7.8,11.77 7,10.5 7,9A4,4 0 0,1 11,5M11,3A6,6 0 0,1 17,9C17,10.7 16.29,12.23 15.16,13.33L14.16,12.88C15.28,11.96 16,10.56 16,9A5,5 0 0,0 11,4A5,5 0 0,0 6,9C6,11.05 7.23,12.81 9,13.58V14.66C6.67,13.83 5,11.61 5,9A6,6 0 0,1 11,3Z\";\r\nvar mdiGesturePinch = \"M13,9A1,1 0 0,1 14,8A1,1 0 0,1 15,9V13.47L16.21,13.6L21.15,15.8C21.67,16.04 22,16.56 22,17.14V21.5C21.97,22.32 21.32,22.97 20.5,23H14C13.62,23 13.26,22.85 13,22.57L8.1,18.37L8.84,17.6C9.03,17.39 9.3,17.28 9.58,17.28H9.8L13,19V9M14,5C15.42,5 16.74,5.76 17.45,7C18.56,8.9 17.91,11.35 16,12.46V11.23C16.64,10.67 17,9.85 17,9A3,3 0 0,0 14,6A3,3 0 0,0 11,9C11,9.85 11.36,10.67 12,11.23V12.46C10.77,11.75 10,10.43 10,9A4,4 0 0,1 14,5M4,9L7,12H5V15H3V12H1L4,9M4,7L1,4H3V1H5V4H7L4,7M9,14C9.73,14 10.41,14.19 11,14.54V15.76C10.47,15.29 9.77,15 9,15A3,3 0 0,0 6,18C6,19 6.5,19.87 7.22,20.42L9.31,22H9A4,4 0 0,1 5,18A4,4 0 0,1 9,14Z\";\r\nvar mdiGestureSpread = \"M4,1L7,4H5V7H3V4H1L4,1M4,15L1,12H3V9H5V12H7L4,15M13,9A1,1 0 0,1 14,8A1,1 0 0,1 15,9V13.47L16.21,13.6L21.15,15.8C21.67,16.04 22,16.56 22,17.14V21.5C21.97,22.32 21.32,22.97 20.5,23H14C13.62,23 13.26,22.85 13,22.57L8.1,18.37L8.84,17.6C9.03,17.39 9.3,17.28 9.58,17.28H9.8L13,19V9M14,5C15.42,5 16.74,5.76 17.45,7C18.56,8.9 17.91,11.35 16,12.46V11.23C16.64,10.67 17,9.85 17,9A3,3 0 0,0 14,6A3,3 0 0,0 11,9C11,9.85 11.36,10.67 12,11.23V12.46C10.77,11.75 10,10.43 10,9A4,4 0 0,1 14,5M9,14C9.73,14 10.41,14.19 11,14.54V15.76C10.47,15.29 9.77,15 9,15A3,3 0 0,0 6,18C6,19 6.5,19.87 7.22,20.42L9.31,22H9A4,4 0 0,1 5,18A4,4 0 0,1 9,14Z\";\r\nvar mdiGestureSwipe = \"M20.11,3.89L22,2V7H17L19.08,4.92C18.55,4.23 17.64,3.66 16.36,3.19C15.08,2.72 13.63,2.5 12,2.5C10.38,2.5 8.92,2.72 7.64,3.19C6.36,3.66 5.45,4.23 4.92,4.92L7,7H2V2L3.89,3.89C4.64,3 5.74,2.31 7.2,1.78C8.65,1.25 10.25,1 12,1C13.75,1 15.35,1.25 16.8,1.78C18.26,2.31 19.36,3 20.11,3.89M19.73,16.27V16.45L19,21.7C18.92,22.08 18.76,22.39 18.5,22.64C18.23,22.89 17.91,23 17.53,23H10.73C10.36,23 10,22.86 9.7,22.55L4.73,17.63L5.53,16.83C5.75,16.61 6,16.5 6.33,16.5H6.56L10,17.25V6.5C10,6.11 10.13,5.76 10.43,5.46C10.73,5.16 11.08,5 11.5,5C11.89,5 12.24,5.16 12.54,5.46C12.84,5.76 13,6.11 13,6.5V12.5H13.78C13.88,12.5 14.05,12.55 14.3,12.61L18.84,14.86C19.44,15.14 19.73,15.61 19.73,16.27Z\";\r\nvar mdiGestureSwipeDown = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M1,9L4,12L7,9H5V3H3V9H1Z\";\r\nvar mdiGestureSwipeHorizontal = \"M6,1L3,4L6,7V5H9V7L12,4L9,1V3H6V1M11,8A1,1 0 0,0 10,9V19L6.8,17.28H6.58C6.3,17.28 6.03,17.39 5.84,17.6L5.1,18.37L10,22.57C10.26,22.85 10.62,23 11,23H17.5A1.5,1.5 0 0,0 19,21.5V17.14C19,16.56 18.68,16.03 18.15,15.79L13.21,13.6L12,13.47V9A1,1 0 0,0 11,8Z\";\r\nvar mdiGestureSwipeLeft = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M3,4L6,7V5H12V3H6V1L3,4Z\";\r\nvar mdiGestureSwipeRight = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M12,4L9,1V3H3V5H9V7L12,4Z\";\r\nvar mdiGestureSwipeUp = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M7,6L4,3L1,6H3V12H5V6H7Z\";\r\nvar mdiGestureSwipeVertical = \"M4,3L1,6H3V9H1L4,12L7,9H5V6H7L4,3M11,8A1,1 0 0,0 10,9V19L6.8,17.28H6.58C6.3,17.28 6.03,17.39 5.84,17.6L5.1,18.37L10,22.57C10.26,22.85 10.62,23 11,23H17.5A1.5,1.5 0 0,0 19,21.5V17.14C19,16.56 18.68,16.03 18.15,15.79L13.21,13.6L12,13.47V9A1,1 0 0,0 11,8Z\";\r\nvar mdiGestureTap = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M11,5A4,4 0 0,1 15,9C15,10.5 14.2,11.77 13,12.46V11.24C13.61,10.69 14,9.89 14,9A3,3 0 0,0 11,6A3,3 0 0,0 8,9C8,9.89 8.39,10.69 9,11.24V12.46C7.8,11.77 7,10.5 7,9A4,4 0 0,1 11,5Z\";\r\nvar mdiGestureTapBox = \"M20 2H4C2.89 2 2 2.89 2 4V20C2 21.11 2.89 22 4 22H20C21.11 22 22 21.11 22 20V4C22 2.89 21.11 2 20 2M11 4C13.21 4 15 5.79 15 8C15 9.5 14.2 10.77 13 11.46V10.24C13.61 9.69 14 8.89 14 8C14 6.34 12.66 5 11 5S8 6.34 8 8C8 8.89 8.39 9.69 9 10.24V11.46C7.8 10.77 7 9.5 7 8C7 5.79 8.79 4 11 4M18 18.5C17.97 19.32 17.32 19.97 16.5 20H11C10.62 20 10.26 19.85 10 19.57L6 15.37L6.74 14.6C6.93 14.39 7.2 14.28 7.5 14.28H7.7L10 16V8C10 7.45 10.45 7 11 7S12 7.45 12 8V12.47L13.21 12.6L17.15 14.79C17.68 15.03 18 15.56 18 16.14V18.5Z\";\r\nvar mdiGestureTapButton = \"M13 5C15.21 5 17 6.79 17 9C17 10.5 16.2 11.77 15 12.46V11.24C15.61 10.69 16 9.89 16 9C16 7.34 14.66 6 13 6S10 7.34 10 9C10 9.89 10.39 10.69 11 11.24V12.46C9.8 11.77 9 10.5 9 9C9 6.79 10.79 5 13 5M20 20.5C19.97 21.32 19.32 21.97 18.5 22H13C12.62 22 12.26 21.85 12 21.57L8 17.37L8.74 16.6C8.93 16.39 9.2 16.28 9.5 16.28H9.7L12 18V9C12 8.45 12.45 8 13 8S14 8.45 14 9V13.47L15.21 13.6L19.15 15.79C19.68 16.03 20 16.56 20 17.14V20.5M20 2H4C2.9 2 2 2.9 2 4V12C2 13.11 2.9 14 4 14H8V12L4 12L4 4H20L20 12H18V14H20V13.96L20.04 14C21.13 14 22 13.09 22 12V4C22 2.9 21.11 2 20 2Z\";\r\nvar mdiGestureTapHold = \"M10,9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V13.47L13.21,13.6L18.15,15.79C18.68,16.03 19,16.56 19,17.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9M9,12.44V9A2,2 0 0,1 11,7A2,2 0 0,1 13,9V12.44C14.19,11.75 15,10.47 15,9A4,4 0 0,0 11,5A4,4 0 0,0 7,9C7,10.47 7.81,11.75 9,12.44Z\";\r\nvar mdiGestureTwoDoubleTap = \"M19,15.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V7A1,1 0 0,1 13,6A1,1 0 0,1 14,7V12L18.15,13.84C18.66,14.07 19,14.58 19,15.14M13,3A4,4 0 0,1 17,7C17,8.5 16.2,9.77 15,10.46V9.24C15.61,8.69 16,7.89 16,7A3,3 0 0,0 13,4C11.65,4 10.5,4.9 10.13,6.13C8.9,6.5 8,7.65 8,9C8,9.89 8.39,10.69 9,11.24V12.46C7.8,11.77 7,10.5 7,9C7,7.38 7.97,6 9.35,5.35C10,3.97 11.38,3 13,3M13,1A6,6 0 0,1 19,7C19,9.06 17.96,10.88 16.38,11.96L15.26,11.46C16.89,10.64 18,8.95 18,7A5,5 0 0,0 13,2C11.11,2 9.46,3.05 8.61,4.61C7.05,5.46 6,7.11 6,9C6,11.05 7.23,12.81 9,13.58V14.66C6.67,13.83 5,11.61 5,9C5,6.83 6.15,4.93 7.88,3.88C8.93,2.15 10.83,1 13,1Z\";\r\nvar mdiGestureTwoTap = \"M19,15.14V21.5C18.97,22.32 18.32,22.97 17.5,23H11C10.62,23 10.26,22.85 10,22.57L5.1,18.37L5.84,17.6C6.03,17.39 6.3,17.28 6.58,17.28H6.8L10,19V9A1,1 0 0,1 11,8A1,1 0 0,1 12,9V7A1,1 0 0,1 13,6A1,1 0 0,1 14,7V12L18.15,13.84C18.66,14.07 19,14.58 19,15.14M15,10.45V9.24L15,9.23C15.23,9.03 15.42,8.79 15.57,8.54C15.84,8.09 16,7.56 16,7A3,3 0 0,0 13,4C12.21,4 11.5,4.31 10.95,4.81L10.81,4.95C10.68,5.09 10.56,5.24 10.46,5.4C10.36,5.56 10.27,5.74 10.2,5.92C10.17,6 10.15,6.06 10.13,6.13C8.9,6.5 8,7.65 8,9C8,9.7 8.24,10.34 8.64,10.85C8.74,11 8.87,11.11 9,11.23V11.24L9,12.46V12.46C7.8,11.77 7,10.5 7,9C7,7.38 7.97,6 9.35,5.35C10,3.97 11.38,3 13,3A4,4 0 0,1 17,7C17,8.5 16.2,9.77 15,10.46V10.45Z\";\r\nvar mdiGhost = \"M12,2A9,9 0 0,0 3,11V22L6,19L9,22L12,19L15,22L18,19L21,22V11A9,9 0 0,0 12,2M9,8A2,2 0 0,1 11,10A2,2 0 0,1 9,12A2,2 0 0,1 7,10A2,2 0 0,1 9,8M15,8A2,2 0 0,1 17,10A2,2 0 0,1 15,12A2,2 0 0,1 13,10A2,2 0 0,1 15,8Z\";\r\nvar mdiGhostOff = \"M2,3.27L3.28,2L22,20.72L20.73,22L17.87,19.13L15,22L12,19L9,22L6,19L3,22V11C3,9.09 3.59,7.33 4.6,5.87L2,3.27M12,2A9,9 0 0,1 21,11V17.18L15.7,11.88C16.46,11.59 17,10.86 17,10A2,2 0 0,0 15,8C14.14,8 13.41,8.54 13.13,9.3L7.2,3.38C8.59,2.5 10.24,2 12,2M7,10A2,2 0 0,0 9,12C9.5,12 9.93,11.83 10.27,11.54L7.46,8.73C7.17,9.07 7,9.5 7,10Z\";\r\nvar mdiGif = \"M11,8H13V16H11V8M7.67,8H4.33C3.53,8 3,8.67 3,9.33V14.67C3,15.33 3.53,16 4.33,16H7.67C8.47,16 9,15.33 9,14.67V12H7V14H5V10H9V9.33C9,8.67 8.47,8 7.67,8M21,10V8H15V16H17V14H19.5V12H17V10H21Z\";\r\nvar mdiGift = \"M9.06,1.93C7.17,1.92 5.33,3.74 6.17,6H3A2,2 0 0,0 1,8V10A1,1 0 0,0 2,11H11V8H13V11H22A1,1 0 0,0 23,10V8A2,2 0 0,0 21,6H17.83C19,2.73 14.6,0.42 12.57,3.24L12,4L11.43,3.22C10.8,2.33 9.93,1.94 9.06,1.93M9,4C9.89,4 10.34,5.08 9.71,5.71C9.08,6.34 8,5.89 8,5A1,1 0 0,1 9,4M15,4C15.89,4 16.34,5.08 15.71,5.71C15.08,6.34 14,5.89 14,5A1,1 0 0,1 15,4M2,12V20A2,2 0 0,0 4,22H20A2,2 0 0,0 22,20V12H13V20H11V12H2Z\";\r\nvar mdiGiftOutline = \"M22,12V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V12A1,1 0 0,1 1,11V8A2,2 0 0,1 3,6H6.17C6.06,5.69 6,5.35 6,5A3,3 0 0,1 9,2C10,2 10.88,2.5 11.43,3.24V3.23L12,4L12.57,3.23V3.24C13.12,2.5 14,2 15,2A3,3 0 0,1 18,5C18,5.35 17.94,5.69 17.83,6H21A2,2 0 0,1 23,8V11A1,1 0 0,1 22,12M4,20H11V12H4V20M20,20V12H13V20H20M9,4A1,1 0 0,0 8,5A1,1 0 0,0 9,6A1,1 0 0,0 10,5A1,1 0 0,0 9,4M15,4A1,1 0 0,0 14,5A1,1 0 0,0 15,6A1,1 0 0,0 16,5A1,1 0 0,0 15,4M3,8V10H11V8H3M13,8V10H21V8H13Z\";\r\nvar mdiGit = \"M2.6,10.59L8.38,4.8L10.07,6.5C9.83,7.35 10.22,8.28 11,8.73V14.27C10.4,14.61 10,15.26 10,16A2,2 0 0,0 12,18A2,2 0 0,0 14,16C14,15.26 13.6,14.61 13,14.27V9.41L15.07,11.5C15,11.65 15,11.82 15,12A2,2 0 0,0 17,14A2,2 0 0,0 19,12A2,2 0 0,0 17,10C16.82,10 16.65,10 16.5,10.07L13.93,7.5C14.19,6.57 13.71,5.55 12.78,5.16C12.35,5 11.9,4.96 11.5,5.07L9.8,3.38L10.59,2.6C11.37,1.81 12.63,1.81 13.41,2.6L21.4,10.59C22.19,11.37 22.19,12.63 21.4,13.41L13.41,21.4C12.63,22.19 11.37,22.19 10.59,21.4L2.6,13.41C1.81,12.63 1.81,11.37 2.6,10.59Z\";\r\nvar mdiGithub = \"M12,2A10,10 0 0,0 2,12C2,16.42 4.87,20.17 8.84,21.5C9.34,21.58 9.5,21.27 9.5,21C9.5,20.77 9.5,20.14 9.5,19.31C6.73,19.91 6.14,17.97 6.14,17.97C5.68,16.81 5.03,16.5 5.03,16.5C4.12,15.88 5.1,15.9 5.1,15.9C6.1,15.97 6.63,16.93 6.63,16.93C7.5,18.45 8.97,18 9.54,17.76C9.63,17.11 9.89,16.67 10.17,16.42C7.95,16.17 5.62,15.31 5.62,11.5C5.62,10.39 6,9.5 6.65,8.79C6.55,8.54 6.2,7.5 6.75,6.15C6.75,6.15 7.59,5.88 9.5,7.17C10.29,6.95 11.15,6.84 12,6.84C12.85,6.84 13.71,6.95 14.5,7.17C16.41,5.88 17.25,6.15 17.25,6.15C17.8,7.5 17.45,8.54 17.35,8.79C18,9.5 18.38,10.39 18.38,11.5C18.38,15.32 16.04,16.16 13.81,16.41C14.17,16.72 14.5,17.33 14.5,18.26C14.5,19.6 14.5,20.68 14.5,21C14.5,21.27 14.66,21.59 15.17,21.5C19.14,20.16 22,16.42 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiGitlab = \"M21.94 13.11L20.89 9.89C20.89 9.86 20.88 9.83 20.87 9.8L18.76 3.32C18.65 3 18.33 2.75 17.96 2.75C17.6 2.75 17.28 3 17.17 3.33L15.17 9.5H8.84L6.83 3.33C6.72 3 6.4 2.75 6.04 2.75H6.04C5.67 2.75 5.35 3 5.24 3.33L3.13 9.82C3.13 9.82 3.13 9.83 3.13 9.83L2.06 13.11C1.9 13.61 2.07 14.15 2.5 14.45L11.72 21.16C11.89 21.28 12.11 21.28 12.28 21.15L21.5 14.45C21.93 14.15 22.1 13.61 21.94 13.11M8.15 10.45L10.72 18.36L4.55 10.45M13.28 18.37L15.75 10.78L15.85 10.45H19.46L13.87 17.61M17.97 3.94L19.78 9.5H16.16M14.86 10.45L13.07 15.96L12 19.24L9.14 10.45M6.03 3.94L7.84 9.5H4.23M3.05 13.69C2.96 13.62 2.92 13.5 2.96 13.4L3.75 10.97L9.57 18.42M20.95 13.69L14.44 18.42L14.46 18.39L20.25 10.97L21.04 13.4C21.08 13.5 21.04 13.62 20.95 13.69\";\r\nvar mdiGlassCocktail = \"M7.5,7L5.5,5H18.5L16.5,7M11,13V19H6V21H18V19H13V13L21,5V3H3V5L11,13Z\";\r\nvar mdiGlassCocktailOff = \"M13.33 12.67L7.66 7L6.13 5.47L2.39 1.73L1.11 3L3 4.89V5L11 13V19H6V21H18V19.89L20.84 22.73L22.11 21.46L13.33 12.67M13 19V14.89L17.11 19H13M8.2 5L6.2 3H21V5L14.6 11.4L10.2 7H16.5L18.5 5H8.2Z\";\r\nvar mdiGlassFlute = \"M8,2H16C15.67,5 15.33,8 14.75,9.83C14.17,11.67 13.33,12.33 12.92,14.08C12.5,15.83 12.5,18.67 13.08,20C13.67,21.33 14.83,21.17 15.42,21.25C16,21.33 16,21.67 16,22H8C8,21.67 8,21.33 8.58,21.25C9.17,21.17 10.33,21.33 10.92,20C11.5,18.67 11.5,15.83 11.08,14.08C10.67,12.33 9.83,11.67 9.25,9.83C8.67,8 8.33,5 8,2M10,4C10.07,5.03 10.15,6.07 10.24,7H13.76C13.85,6.07 13.93,5.03 14,4H10Z\";\r\nvar mdiGlassMug = \"M10,4V7H18V4H10M8,2H20L21,2V3L20,4V20L21,21V22H20L8,22H7V21L8,20V18.6L4.2,16.83C3.5,16.5 3,15.82 3,15V8A2,2 0 0,1 5,6H8V4L7,3V2H8M5,15L8,16.39V8H5V15Z\";\r\nvar mdiGlassMugOff = \"M20 19.35V19.34L6.66 6L6.07 5.41L2.39 1.73L1.11 3L4.26 6.15C3.5 6.44 3 7.16 3 8V15C3 15.82 3.5 16.5 4.2 16.83L8 18.6V20L7 21V22H20.11L20.84 22.73L22.11 21.46L20 19.35M8 16.39L5 15V8H6.11L8 9.89V16.39M8 4L7 3V2H21V3L20 4V16.8L10.2 7H18V4H10V6.8L8 4.8V4Z\";\r\nvar mdiGlassMugVariant = \"M9.5 3C7.56 3 5.85 4.24 5.23 6.08C3.36 6.44 2 8.09 2 10C2 12.21 3.79 14 6 14V22H17V20H20C20.55 20 21 19.55 21 19V11C21 10.45 20.55 10 20 10H18V8C18 5.79 16.21 4 14 4H12.32C11.5 3.35 10.53 3 9.5 3M9.5 5C10.29 5 11.03 5.37 11.5 6H14C15.11 6 16 6.9 16 8H12C10 8 9.32 9.13 8.5 10.63C7.68 12.13 6 12 6 12C4.89 12 4 11.11 4 10C4 8.9 4.89 8 6 8H7V7.5C7 6.12 8.12 5 9.5 5M17 12H19V18H17Z\";\r\nvar mdiGlassMugVariantOff = \"M8.44 5.24L7 3.79C7.71 3.29 8.57 3 9.5 3C10.53 3 11.5 3.35 12.32 4H14C16.21 4 18 5.79 18 8V10H20C20.55 10 21 10.45 21 11V17.8L19 15.8V12H17V13.8L11.26 8.06C11.5 8 11.73 8 12 8H16C16 6.9 15.11 6 14 6H11.5C11.03 5.37 10.29 5 9.5 5C9.12 5 8.76 5.09 8.44 5.24M22.11 21.46L20.84 22.73L18.11 20H17V22H6V14C3.79 14 2 12.21 2 10C2 8.37 3 6.94 4.44 6.33L1.11 3L2.39 1.73L7.19 6.54L9.61 8.96L17 16.34V16.35L18.65 18H18.66L20.5 19.84V19.85L22.11 21.46M8.59 10.5L6.11 8H6C4.89 8 4 8.9 4 10C4 11.11 4.89 12 6 12C6 12 7.68 12.13 8.5 10.63L8.59 10.5Z\";\r\nvar mdiGlassPintOutline = \"M4 2L6 22H17L19 2H4M6.2 4H16.8L15.2 20H7.8L6.2 4Z\";\r\nvar mdiGlassStange = \"M8,2H16V22H8V2M10,4V7H14V4H10Z\";\r\nvar mdiGlassTulip = \"M8,2H16C15.67,2.67 15.33,3.33 15.58,5C15.83,6.67 16.67,9.33 16.25,10.74C15.83,12.14 14.17,12.28 13.33,13.86C12.5,15.44 12.5,18.47 13.08,19.9C13.67,21.33 14.83,21.17 15.42,21.25C16,21.33 16,21.67 16,22H8C8,21.67 8,21.33 8.58,21.25C9.17,21.17 10.33,21.33 10.92,19.9C11.5,18.47 11.5,15.44 10.67,13.86C9.83,12.28 8.17,12.14 7.75,10.74C7.33,9.33 8.17,6.67 8.42,5C8.67,3.33 8.33,2.67 8,2M10,4C10,5.19 9.83,6.17 9.64,7H14.27C14.13,6.17 14,5.19 14,4H10Z\";\r\nvar mdiGlassWine = \"M15.5,21.27L14.66,21.18C13.9,21.11 13.25,20.6 13,19.87C12.47,17.91 12.47,15.83 13,13.87C15.32,13.4 17,11.37 17,9C17,7 15,2 15,2H9C9,2 7,7 7,9C7,11.38 8.67,13.42 11,13.9C11.53,15.86 11.53,17.94 11,19.9C10.76,20.62 10.12,21.13 9.37,21.21L8.5,21.3C8.5,21.3 8,21.28 8,22H16C16,21.28 15.5,21.27 15.5,21.27M9.44,7L10.44,4H13.56L14.56,7H9.44Z\";\r\nvar mdiGlasses = \"M3,10C2.76,10 2.55,10.09 2.41,10.25C2.27,10.4 2.21,10.62 2.24,10.86L2.74,13.85C2.82,14.5 3.4,15 4,15H7C7.64,15 8.36,14.44 8.5,13.82L9.56,10.63C9.6,10.5 9.57,10.31 9.5,10.19C9.39,10.07 9.22,10 9,10H3M7,17H4C2.38,17 0.96,15.74 0.76,14.14L0.26,11.15C0.15,10.3 0.39,9.5 0.91,8.92C1.43,8.34 2.19,8 3,8H9C9.83,8 10.58,8.35 11.06,8.96C11.17,9.11 11.27,9.27 11.35,9.45C11.78,9.36 12.22,9.36 12.64,9.45C12.72,9.27 12.82,9.11 12.94,8.96C13.41,8.35 14.16,8 15,8H21C21.81,8 22.57,8.34 23.09,8.92C23.6,9.5 23.84,10.3 23.74,11.11L23.23,14.18C23.04,15.74 21.61,17 20,17H17C15.44,17 13.92,15.81 13.54,14.3L12.64,11.59C12.26,11.31 11.73,11.31 11.35,11.59L10.43,14.37C10.07,15.82 8.56,17 7,17M15,10C14.78,10 14.61,10.07 14.5,10.19C14.42,10.31 14.4,10.5 14.45,10.7L15.46,13.75C15.64,14.44 16.36,15 17,15H20C20.59,15 21.18,14.5 21.25,13.89L21.76,10.82C21.79,10.62 21.73,10.4 21.59,10.25C21.45,10.09 21.24,10 21,10H15Z\";\r\nvar mdiGlobeLight = \"M13 8.08V2H11V8.08C7.61 8.57 5 11.47 5 15C5 18.87 8.13 22 12 22S19 18.87 19 15C19 11.47 16.39 8.57 13 8.08M12 20C9.24 20 7 17.76 7 15C7 13.87 7.39 12.84 8.03 12H15.97C16.61 12.84 17 13.87 17 15C17 17.76 14.76 20 12 20Z\";\r\nvar mdiGlobeModel = \"M17.36,2.64L15.95,4.06C17.26,5.37 18,7.14 18,9A7,7 0 0,1 11,16C9.15,16 7.37,15.26 6.06,13.95L4.64,15.36C6.08,16.8 7.97,17.71 10,17.93V20H6V22H16V20H12V17.94C16.55,17.43 20,13.58 20,9C20,6.62 19.05,4.33 17.36,2.64M11,3.5A5.5,5.5 0 0,0 5.5,9A5.5,5.5 0 0,0 11,14.5A5.5,5.5 0 0,0 16.5,9A5.5,5.5 0 0,0 11,3.5M11,5.5C12.94,5.5 14.5,7.07 14.5,9A3.5,3.5 0 0,1 11,12.5A3.5,3.5 0 0,1 7.5,9A3.5,3.5 0 0,1 11,5.5Z\";\r\nvar mdiGmail = \"M20,18H18V9.25L12,13L6,9.25V18H4V6H5.2L12,10.25L18.8,6H20M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiGnome = \"M18.42,2C14.26,2 13.5,7.93 15.82,7.93C18.16,7.93 22.58,2 18.42,2M12,2.73C11.92,2.73 11.85,2.73 11.78,2.74C9.44,3.04 10.26,7.12 11.5,7.19C12.72,7.27 14.04,2.73 12,2.73M7.93,4.34C7.81,4.34 7.67,4.37 7.53,4.43C5.65,5.21 7.24,8.41 8.3,8.2C9.27,8 9.39,4.3 7.93,4.34M4.93,6.85C4.77,6.84 4.59,6.9 4.41,7.03C2.9,8.07 4.91,10.58 5.8,10.19C6.57,9.85 6.08,6.89 4.93,6.85M13.29,8.77C10.1,8.8 6.03,10.42 5.32,13.59C4.53,17.11 8.56,22 12.76,22C14.83,22 17.21,20.13 17.66,17.77C18,15.97 13.65,16.69 13.81,17.88C14,19.31 12.76,20 11.55,19.1C7.69,16.16 17.93,14.7 17.25,10.69C17.03,9.39 15.34,8.76 13.29,8.77Z\";\r\nvar mdiGoKart = \"M18,10H15.53L14.38,8.28L15.8,7.33L14.7,5.67L10.2,8.67L11.3,10.33L12.73,9.38L13.88,11.12L13,12H10.2L5.83,5.45L4.17,6.55L5.87,9.11C3.04,9.65 1,12.12 1,15V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V15A5,5 0 0,0 18,10M6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5M18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5Z\";\r\nvar mdiGoKartTrack = \"M22,5.5A3.5,3.5 0 0,0 18.5,2A3.5,3.5 0 0,0 15,5.5V6A3,3 0 0,1 12,9C10,9 9,6 6,6A4,4 0 0,0 2,10V11H4V10A2,2 0 0,1 6,8C6.86,8 7.42,8.45 8.32,9.24C9.28,10.27 10.6,10.9 12,11A5,5 0 0,0 17,6V5.5A1.5,1.5 0 0,1 18.5,4A1.5,1.5 0 0,1 20,5.5C19.86,6.35 19.58,7.18 19.17,7.94C18.5,9.2 18.11,10.58 18,12C18.09,13.37 18.5,14.71 19.21,15.89C19.6,16.54 19.87,17.25 20,18A2,2 0 0,1 18,20A2,2 0 0,1 16,18A3.75,3.75 0 0,0 12.25,14.25A3.75,3.75 0 0,0 8.5,18V18.5A1.5,1.5 0 0,1 7,20A3,3 0 0,1 4,17V15H6V13H0V15H2V17A5,5 0 0,0 7,22A3.5,3.5 0 0,0 10.5,18.5V18A1.75,1.75 0 0,1 12.25,16.25A1.75,1.75 0 0,1 14,18A4,4 0 0,0 18,22A4,4 0 0,0 22,18C22,16 20,14 20,12C20,10 22,7.5 22,5.5Z\";\r\nvar mdiGog = \"M4,3H20A2,2 0 0,1 22,5V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V5A2,2 0 0,1 4,3M10.46,5.54C9.95,5.54 9.54,5.95 9.54,6.46V9.54A0.92,0.92 0 0,0 10.46,10.46H13.54A0.92,0.92 0 0,0 14.46,9.54V6.46C14.46,5.95 14.05,5.54 13.54,5.54H10.46M11.08,6.77H12.92A0.31,0.31 0 0,1 13.23,7.08V8.92A0.31,0.31 0 0,1 12.92,9.23H11.08A0.31,0.31 0 0,1 10.77,8.92V7.08A0.31,0.31 0 0,1 11.08,6.77M4.92,5.54A0.92,0.92 0 0,0 4,6.46V9.54C4,10.05 4.41,10.46 4.92,10.46H7.08V9.23H5.54C5.37,9.23 5.23,9.09 5.23,8.92V7.08C5.23,6.91 5.37,6.77 5.54,6.77H7.38A0.31,0.31 0 0,1 7.69,7.08V10.77A0.31,0.31 0 0,1 7.38,11.08H4V12.31H8C8.5,12.31 8.92,11.89 8.92,11.38V6.46A0.92,0.92 0 0,0 8,5.54H4.92M16,5.54C15.5,5.54 15.08,5.95 15.08,6.46V9.54C15.08,10.05 15.5,10.46 16,10.46H18.15V9.23H16.62C16.45,9.23 16.31,9.09 16.31,8.92V7.08C16.31,6.91 16.45,6.77 16.62,6.77H18.46C18.63,6.77 18.77,6.91 18.77,7.08V10.77C18.77,10.94 18.63,11.08 18.46,11.08H15.08V12.31H19.08C19.59,12.31 20,11.89 20,11.38V6.46C20,5.95 19.59,5.54 19.08,5.54H16M9.85,13.54C9.34,13.54 8.92,13.95 8.92,14.46V17.54C8.92,18.05 9.34,18.46 9.85,18.46H12.92C13.43,18.46 13.85,18.05 13.85,17.54V14.46C13.85,13.95 13.43,13.54 12.92,13.54H9.85M10.46,14.77H12.31C12.5,14.77 12.62,14.91 12.62,15.08V16.92A0.31,0.31 0 0,1 12.31,17.23H10.46C10.29,17.23 10.15,17.09 10.15,16.92V15.08A0.31,0.31 0 0,1 10.46,14.77M4.92,13.54C4.41,13.54 4,13.95 4,14.46V17.54C4,18.05 4.41,18.46 4.92,18.46H8.31V17.23H5.54C5.37,17.23 5.23,17.09 5.23,16.92V15.08C5.23,14.91 5.37,14.77 5.54,14.77H8.31V13.54H4.92M15.38,13.54C14.87,13.54 14.46,13.95 14.46,14.46V18.46H15.69V15.08A0.31,0.31 0 0,1 16,14.77H16.62V18.46H17.85V14.77H18.77V18.46H20V13.54H15.38Z\";\r\nvar mdiGold = \"M1 22L2.5 17H9.5L11 22H1M13 22L14.5 17H21.5L23 22H13M6 15L7.5 10H14.5L16 15H6M23 6.05L19.14 7.14L18.05 11L16.96 7.14L13.1 6.05L16.96 4.96L18.05 1.1L19.14 4.96L23 6.05Z\";\r\nvar mdiGolf = \"M19.5,18A1.5,1.5 0 0,1 21,19.5A1.5,1.5 0 0,1 19.5,21A1.5,1.5 0 0,1 18,19.5A1.5,1.5 0 0,1 19.5,18M17,5.92L11,9V18.03C13.84,18.19 16,19 16,20C16,21.1 13.31,22 10,22C6.69,22 4,21.1 4,20C4,19.26 5.21,18.62 7,18.27V20H9V2L17,5.92Z\";\r\nvar mdiGolfCart = \"M19.89 12.37L18.25 5H19V3H3V7H1V9H3V12.54A6 6 0 0 0 1 17V19H3A3 3 0 0 0 9 19H15A3 3 0 0 0 21 19H23V17A5 5 0 0 0 19.89 12.37M6 20.5A1.5 1.5 0 1 1 7.5 19A1.5 1.5 0 0 1 6 20.5M15.53 12L14.38 10.28L15.8 9.33L14.7 7.67L10.2 10.67L11.3 12.33L12.73 11.38L13.88 13.12L13 14H10.2L5 7V5H16.2L17.75 12M18 20.5A1.5 1.5 0 1 1 19.5 19A1.5 1.5 0 0 1 18 20.5Z\";\r\nvar mdiGolfTee = \"M7 19V17H17V19H15C14.5 19 14 19.2 13.6 19.6S13 20.5 13 21V22H11V21C11 20.5 10.8 20 10.4 19.6S9.5 19 9 19H7M11 6C11 5.7 11.1 5.5 11.3 5.3S11.7 5 12 5 12.5 5.1 12.7 5.3 13 5.7 13 6 12.9 6.5 12.7 6.7 12.3 7 12 7 11.5 6.9 11.3 6.7 11 6.3 11 6M13 8C13 7.7 13.1 7.5 13.3 7.3S13.7 7 14 7 14.5 7.1 14.7 7.3 15 7.7 15 8 14.9 8.5 14.7 8.7 14.3 9 14 9 13.5 8.9 13.3 8.7 13 8.3 13 8M9 8C9 7.7 9.1 7.5 9.3 7.3S9.7 7 10 7 10.5 7.1 10.7 7.3 11 7.7 11 8 10.9 8.5 10.7 8.7 10.3 9 10 9 9.5 8.9 9.3 8.7 9 8.3 9 8M16.9 4.1C15.5 2.7 13.9 2.1 12 2.1S8.4 2.8 7.1 4.1 5 7.1 5 9 5.7 12.6 7 13.9 10 15.9 11.9 15.9 15.5 15.2 16.8 13.9 18.8 10.9 18.8 9 18.3 5.4 16.9 4.1M15.5 12.5C14.5 13.5 13.3 14 12 14S9.4 13.5 8.5 12.5 7 10.4 7 9 7.5 6.4 8.5 5.5 10.6 4 12 4 14.6 4.5 15.5 5.5 17 7.6 17 9 16.5 11.6 15.5 12.5Z\";\r\nvar mdiGondola = \"M18,10H13V7.59L22.12,6.07L21.88,4.59L16.41,5.5C16.46,5.35 16.5,5.18 16.5,5A1.5,1.5 0 0,0 15,3.5A1.5,1.5 0 0,0 13.5,5C13.5,5.35 13.63,5.68 13.84,5.93L13,6.07V5H11V6.41L10.41,6.5C10.46,6.35 10.5,6.18 10.5,6A1.5,1.5 0 0,0 9,4.5A1.5,1.5 0 0,0 7.5,6C7.5,6.36 7.63,6.68 7.83,6.93L1.88,7.93L2.12,9.41L11,7.93V10H6C4.89,10 4,10.9 4,12V18A2,2 0 0,0 6,20H18A2,2 0 0,0 20,18V12A2,2 0 0,0 18,10M6,12H8.25V16H6V12M9.75,16V12H14.25V16H9.75M18,16H15.75V12H18V16Z\";\r\nvar mdiGoodreads = \"M17,12.77C15.96,14.42 14.22,15.5 12.25,15.5C9.07,15.5 6.5,12.7 6.5,9.25C6.5,5.8 9.07,3 12.25,3C14.22,3 15.96,4.08 17,5.73V3H18V15.25C18,20.71 14.54,21 11.5,21C9,21 7.55,19.31 7.13,17H8.14C8.5,18.75 9.54,20 11.5,20C13.72,20 17,20.05 17,15.25V15.25L17,12.77M12.25,4C9.63,4 7.5,6.35 7.5,9.25C7.5,12.15 9.63,14.5 12.25,14.5C14.87,14.5 17,12.15 17,9.25C17,6.35 14.87,4 12.25,4Z\";\r\nvar mdiGoogle = \"M21.35,11.1H12.18V13.83H18.69C18.36,17.64 15.19,19.27 12.19,19.27C8.36,19.27 5,16.25 5,12C5,7.9 8.2,4.73 12.2,4.73C15.29,4.73 17.1,6.7 17.1,6.7L19,4.72C19,4.72 16.56,2 12.1,2C6.42,2 2.03,6.8 2.03,12C2.03,17.05 6.16,22 12.25,22C17.6,22 21.5,18.33 21.5,12.91C21.5,11.76 21.35,11.1 21.35,11.1V11.1Z\";\r\nvar mdiGoogleAds = \"M12.25 1.47C11.55 1.42 10.82 1.58 10.17 1.96C8.41 2.97 7.81 5.21 8.82 6.96L16.16 19.66C17.17 21.42 19.41 22 21.17 21C22.92 20 23.5 17.75 22.5 16L15.18 3.3C14.54 2.2 13.43 1.56 12.25 1.47M6.82 6.76L1.5 16A3.67 3.67 0 0 0 1 17.83A3.67 3.67 0 0 0 4.67 21.5A3.67 3.67 0 0 0 7.84 19.66V19.67L11 14.19C9.65 11.89 8.27 9.6 7.03 7.23C6.95 7.08 6.88 6.92 6.83 6.76ZL16.4 5Z\";\r\nvar mdiGoogleAnalytics = \"M15.86 4.39V19.39C15.86 21.06 17 22 18.25 22C19.39 22 20.64 21.21 20.64 19.39V4.5C20.64 2.96 19.5 2 18.25 2S15.86 3.06 15.86 4.39M9.61 12V19.39C9.61 21.07 10.77 22 12 22C13.14 22 14.39 21.21 14.39 19.39V12.11C14.39 10.57 13.25 9.61 12 9.61S9.61 10.67 9.61 12M5.75 17.23C7.07 17.23 8.14 18.3 8.14 19.61C8.14 20.93 7.07 22 5.75 22S3.36 20.93 3.36 19.61C3.36 18.3 4.43 17.23 5.75 17.23Z\";\r\nvar mdiGoogleAssistant = \"M7,2A6,6 0 0,0 1,8A6,6 0 0,0 7,14A6,6 0 0,0 13,8A6,6 0 0,0 7,2M21.5,6A1.5,1.5 0 0,0 20,7.5A1.5,1.5 0 0,0 21.5,9A1.5,1.5 0 0,0 23,7.5A1.5,1.5 0 0,0 21.5,6M17,8A3,3 0 0,0 14,11A3,3 0 0,0 17,14A3,3 0 0,0 20,11A3,3 0 0,0 17,8M17,15A3.5,3.5 0 0,0 13.5,18.5A3.5,3.5 0 0,0 17,22A3.5,3.5 0 0,0 20.5,18.5A3.5,3.5 0 0,0 17,15Z\";\r\nvar mdiGoogleCardboard = \"M20.74,6H3.2C2.55,6 2,6.57 2,7.27V17.73C2,18.43 2.55,19 3.23,19H8C8.54,19 9,18.68 9.16,18.21L10.55,14.74C10.79,14.16 11.35,13.75 12,13.75C12.65,13.75 13.21,14.16 13.45,14.74L14.84,18.21C15.03,18.68 15.46,19 15.95,19H20.74C21.45,19 22,18.43 22,17.73V7.27C22,6.57 21.45,6 20.74,6M7.22,14.58C6,14.58 5,13.55 5,12.29C5,11 6,10 7.22,10C8.44,10 9.43,11 9.43,12.29C9.43,13.55 8.44,14.58 7.22,14.58M16.78,14.58C15.56,14.58 14.57,13.55 14.57,12.29C14.57,11.03 15.56,10 16.78,10C18,10 19,11.03 19,12.29C19,13.55 18,14.58 16.78,14.58Z\";\r\nvar mdiGoogleChrome = \"M12,20L15.46,14H15.45C15.79,13.4 16,12.73 16,12C16,10.8 15.46,9.73 14.62,9H19.41C19.79,9.93 20,10.94 20,12A8,8 0 0,1 12,20M4,12C4,10.54 4.39,9.18 5.07,8L8.54,14H8.55C9.24,15.19 10.5,16 12,16C12.45,16 12.88,15.91 13.29,15.77L10.89,19.91C7,19.37 4,16.04 4,12M15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9A3,3 0 0,1 15,12M12,4C14.96,4 17.54,5.61 18.92,8H12C10.06,8 8.45,9.38 8.08,11.21L5.7,7.08C7.16,5.21 9.44,4 12,4M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiGoogleCircles = \"M16.66,15H17C18,15 19,14.8 19.87,14.46C19.17,18.73 15.47,22 11,22C6,22 2,17.97 2,13C2,8.53 5.27,4.83 9.54,4.13C9.2,5 9,6 9,7V7.34C6.68,8.16 5,10.38 5,13A6,6 0 0,0 11,19C13.62,19 15.84,17.32 16.66,15M17,10A3,3 0 0,0 20,7A3,3 0 0,0 17,4A3,3 0 0,0 14,7A3,3 0 0,0 17,10M17,1A6,6 0 0,1 23,7A6,6 0 0,1 17,13A6,6 0 0,1 11,7C11,3.68 13.69,1 17,1Z\";\r\nvar mdiGoogleCirclesCommunities = \"M15,12C13.89,12 13,12.89 13,14A2,2 0 0,0 15,16A2,2 0 0,0 17,14C17,12.89 16.1,12 15,12M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M14,9C14,7.89 13.1,7 12,7C10.89,7 10,7.89 10,9A2,2 0 0,0 12,11A2,2 0 0,0 14,9M9,12A2,2 0 0,0 7,14A2,2 0 0,0 9,16A2,2 0 0,0 11,14C11,12.89 10.1,12 9,12Z\";\r\nvar mdiGoogleCirclesExtended = \"M18,19C16.89,19 16,18.1 16,17C16,15.89 16.89,15 18,15A2,2 0 0,1 20,17A2,2 0 0,1 18,19M18,13A4,4 0 0,0 14,17A4,4 0 0,0 18,21A4,4 0 0,0 22,17A4,4 0 0,0 18,13M12,11.1A1.9,1.9 0 0,0 10.1,13A1.9,1.9 0 0,0 12,14.9A1.9,1.9 0 0,0 13.9,13A1.9,1.9 0 0,0 12,11.1M6,19C4.89,19 4,18.1 4,17C4,15.89 4.89,15 6,15A2,2 0 0,1 8,17A2,2 0 0,1 6,19M6,13A4,4 0 0,0 2,17A4,4 0 0,0 6,21A4,4 0 0,0 10,17A4,4 0 0,0 6,13M12,4A2,2 0 0,1 14,6A2,2 0 0,1 12,8C10.89,8 10,7.1 10,6C10,4.89 10.89,4 12,4M12,10A4,4 0 0,0 16,6A4,4 0 0,0 12,2A4,4 0 0,0 8,6A4,4 0 0,0 12,10Z\";\r\nvar mdiGoogleCirclesGroup = \"M5,10A2,2 0 0,0 3,12C3,13.11 3.9,14 5,14C6.11,14 7,13.11 7,12A2,2 0 0,0 5,10M5,16A4,4 0 0,1 1,12A4,4 0 0,1 5,8A4,4 0 0,1 9,12A4,4 0 0,1 5,16M10.5,11H14V8L18,12L14,16V13H10.5V11M5,6C4.55,6 4.11,6.05 3.69,6.14C5.63,3.05 9.08,1 13,1C19.08,1 24,5.92 24,12C24,18.08 19.08,23 13,23C9.08,23 5.63,20.95 3.69,17.86C4.11,17.95 4.55,18 5,18C5.8,18 6.56,17.84 7.25,17.56C8.71,19.07 10.74,20 13,20A8,8 0 0,0 21,12A8,8 0 0,0 13,4C10.74,4 8.71,4.93 7.25,6.44C6.56,6.16 5.8,6 5,6Z\";\r\nvar mdiGoogleClassroom = \"M23,2H1A1,1 0 0,0 0,3V21A1,1 0 0,0 1,22H23A1,1 0 0,0 24,21V3A1,1 0 0,0 23,2M22,20H20V19H15V20H2V4H22V20M10.29,9.71A1.71,1.71 0 0,1 12,8C12.95,8 13.71,8.77 13.71,9.71C13.71,10.66 12.95,11.43 12,11.43C11.05,11.43 10.29,10.66 10.29,9.71M5.71,11.29C5.71,10.58 6.29,10 7,10A1.29,1.29 0 0,1 8.29,11.29C8.29,12 7.71,12.57 7,12.57C6.29,12.57 5.71,12 5.71,11.29M15.71,11.29A1.29,1.29 0 0,1 17,10A1.29,1.29 0 0,1 18.29,11.29C18.29,12 17.71,12.57 17,12.57C16.29,12.57 15.71,12 15.71,11.29M20,15.14V16H16L14,16H10L8,16H4V15.14C4,14.2 5.55,13.43 7,13.43C7.55,13.43 8.11,13.54 8.6,13.73C9.35,13.04 10.7,12.57 12,12.57C13.3,12.57 14.65,13.04 15.4,13.73C15.89,13.54 16.45,13.43 17,13.43C18.45,13.43 20,14.2 20,15.14Z\";\r\nvar mdiGoogleCloud = \"M23 14.75C23 18.2 20.2 21 16.75 21H7.25C3.8 21 1 18.2 1 14.75C1 12.61 2.08 10.72 3.71 9.6C4.58 5.82 7.96 3 12 3C16.04 3 19.42 5.82 20.29 9.6C21.93 10.72 23 12.61 23 14.75M16.63 17C17.94 17 19 15.94 19 14.63C19 13.35 18 12.3 16.72 12.25L16.75 11.75C16.75 9.13 14.62 7 12 7C10.58 7 9.3 7.62 8.43 8.61C9.93 8.9 11.23 9.72 12.14 10.86L9.5 13.5C9.08 12.77 8.29 12.25 7.38 12.25C6.06 12.25 5 13.31 5 14.63C5 15.9 6 16.93 7.25 17V17H16.63Z\";\r\nvar mdiGoogleController = \"M7.97,16L5,19C4.67,19.3 4.23,19.5 3.75,19.5A1.75,1.75 0 0,1 2,17.75V17.5L3,10.12C3.21,7.81 5.14,6 7.5,6H16.5C18.86,6 20.79,7.81 21,10.12L22,17.5V17.75A1.75,1.75 0 0,1 20.25,19.5C19.77,19.5 19.33,19.3 19,19L16.03,16H7.97M7,8V10H5V11H7V13H8V11H10V10H8V8H7M16.5,8A0.75,0.75 0 0,0 15.75,8.75A0.75,0.75 0 0,0 16.5,9.5A0.75,0.75 0 0,0 17.25,8.75A0.75,0.75 0 0,0 16.5,8M14.75,9.75A0.75,0.75 0 0,0 14,10.5A0.75,0.75 0 0,0 14.75,11.25A0.75,0.75 0 0,0 15.5,10.5A0.75,0.75 0 0,0 14.75,9.75M18.25,9.75A0.75,0.75 0 0,0 17.5,10.5A0.75,0.75 0 0,0 18.25,11.25A0.75,0.75 0 0,0 19,10.5A0.75,0.75 0 0,0 18.25,9.75M16.5,11.5A0.75,0.75 0 0,0 15.75,12.25A0.75,0.75 0 0,0 16.5,13A0.75,0.75 0 0,0 17.25,12.25A0.75,0.75 0 0,0 16.5,11.5Z\";\r\nvar mdiGoogleControllerOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L12.73,16H7.97L5,19C4.67,19.3 4.23,19.5 3.75,19.5A1.75,1.75 0 0,1 2,17.75V17.5L3,10.12C3.1,9.09 3.53,8.17 4.19,7.46L2,5.27M5,10V11H7V13H8V11.27L6.73,10H5M16.5,6C18.86,6 20.79,7.81 21,10.12L22,17.5V17.75C22,18.41 21.64,19 21.1,19.28L7.82,6H16.5M16.5,8A0.75,0.75 0 0,0 15.75,8.75A0.75,0.75 0 0,0 16.5,9.5A0.75,0.75 0 0,0 17.25,8.75A0.75,0.75 0 0,0 16.5,8M14.75,9.75A0.75,0.75 0 0,0 14,10.5A0.75,0.75 0 0,0 14.75,11.25A0.75,0.75 0 0,0 15.5,10.5A0.75,0.75 0 0,0 14.75,9.75M18.25,9.75A0.75,0.75 0 0,0 17.5,10.5A0.75,0.75 0 0,0 18.25,11.25A0.75,0.75 0 0,0 19,10.5A0.75,0.75 0 0,0 18.25,9.75M16.5,11.5A0.75,0.75 0 0,0 15.75,12.25A0.75,0.75 0 0,0 16.5,13A0.75,0.75 0 0,0 17.25,12.25A0.75,0.75 0 0,0 16.5,11.5Z\";\r\nvar mdiGoogleDownasaur = \"M13 2V3H12V9H11V10H9V11H8V12H7V13H5V12H4V11H3V9H2V15H3V16H4V17H5V18H6V22H8V21H7V20H8V19H9V18H10V19H11V22H13V21H12V17H13V16H14V15H15V12H16V13H17V11H15V9H20V8H17V7H22V3H21V2M14 3H15V4H14Z\";\r\nvar mdiGoogleDrive = \"M7.71,3.5L1.15,15L4.58,21L11.13,9.5M9.73,15L6.3,21H19.42L22.85,15M22.28,14L15.42,2H8.58L8.57,2L15.43,14H22.28Z\";\r\nvar mdiGoogleEarth = \"M12,12.14C11.09,10.77 10.14,9.78 9.14,9.19C8.14,8.59 7.27,8.38 6.5,8.55C5.77,8.73 5.14,9.14 4.64,9.8C4.2,10.39 4,11.06 4,11.81V12C4,12.78 4.11,13.58 4.36,14.39C4.45,14.64 4.5,14.64 4.55,14.39C4.67,13.77 4.96,13.31 5.41,13.03C5.87,12.75 6.47,12.76 7.22,13.05C7.97,13.35 8.7,14 9.42,14.95C10.7,16.67 12.2,17.72 13.92,18.09C16.14,18.41 17.81,17.7 18.94,16C19.25,15.39 19.5,14.86 19.64,14.39C19.73,14.08 19.69,14.05 19.5,14.3C19.03,14.92 18.4,15.33 17.6,15.5C16.8,15.7 15.89,15.5 14.86,15C13.83,14.43 12.88,13.5 12,12.14M16.97,8.16C15.41,5.81 13.72,4.5 11.91,4.17C10.47,3.95 8.91,4.45 7.22,5.67C7,5.83 6.9,5.91 6.91,5.93C6.93,5.95 7.06,5.89 7.31,5.77C9.81,4.55 12.22,5.83 14.53,9.61C15.03,10.45 15.55,11.11 16.1,11.58C16.65,12.05 17.16,12.33 17.65,12.42C18.13,12.5 18.57,12.5 18.96,12.38C19.35,12.25 19.7,12.05 20,11.77C20,11.17 19.91,10.5 19.69,9.8C19.19,9.92 18.74,9.88 18.35,9.68C17.96,9.5 17.5,8.97 16.97,8.16M12,2C14.75,2 17.1,3 19.05,4.95C21,6.9 22,9.25 22,12C22,14.75 21,17.1 19.05,19.05C17.1,21 14.75,22 12,22C9.25,22 6.9,21 4.95,19.05C3,17.1 2,14.75 2,12C2,9.25 3,6.9 4.95,4.95C6.9,3 9.25,2 12,2Z\";\r\nvar mdiGoogleFit = \"M17,4A5,5 0 0,1 22,9C22,10.38 21.44,11.63 20.54,12.54L12,21.07L3.46,12.54C2.56,11.63 2,10.38 2,9A5,5 0 0,1 7,4C8.38,4 9.63,4.56 10.54,5.46L12,6.93L13.46,5.46C14.37,4.56 15.62,4 17,4M15.59,7.59L9.17,14L12,16.83L18.41,10.41C18.78,10.05 19,9.55 19,9A2,2 0 0,0 17,7C16.45,7 15.95,7.22 15.59,7.59M8.41,7.59C8.05,7.22 7.55,7 7,7A2,2 0 0,0 5,9C5,9.55 5.22,10.05 5.59,10.41L7.05,11.88L9.88,9.05L8.41,7.59Z\";\r\nvar mdiGoogleGlass = \"M20 2H4C2.9 2 2 2.9 2 4V20C2 21.1 2.9 22 4 22H20C21.1 22 22 21.1 22 20V4C22 2.9 21.1 2 20 2M16.75 18H15.25V8.9L6.72 18H4.66L15.45 6.5C15.66 6.26 16 6.19 16.27 6.3C16.56 6.42 16.75 6.69 16.75 7V18Z\";\r\nvar mdiGoogleHangouts = \"M15,11L14,13H12.5L13.5,11H12V8H15M11,11L10,13H8.5L9.5,11H8V8H11M11.5,2A8.5,8.5 0 0,0 3,10.5A8.5,8.5 0 0,0 11.5,19H12V22.5C16.86,20.15 20,15 20,10.5C20,5.8 16.19,2 11.5,2Z\";\r\nvar mdiGoogleHome = \"M8.06,7.78C7.5,7.78 7.17,7.73 7.08,7.64L6.66,13.73C7.19,14.05 7.88,14.3 8.72,14.5C9.56,14.71 10.78,14.77 12.38,14.67C13.97,14.58 15.63,14.23 17.34,13.64L16.55,4.22C15.67,5.09 14.38,5.91 12.66,6.66C11.13,7.31 9.81,7.69 8.72,7.78H8.06M7.97,5.34C7.28,5.94 7,6.34 7.13,6.56C7.22,6.78 7.7,6.84 8.58,6.75C9.67,6.66 10.91,6.31 12.28,5.72C13.22,5.31 14.03,4.88 14.72,4.41C15.41,3.94 15.88,3.55 16.13,3.23C16.38,2.92 16.47,2.7 16.41,2.58C16.34,2.42 16.03,2.34 15.47,2.34C14.34,2.34 12.94,2.7 11.25,3.42C9.81,4.05 8.72,4.69 7.97,5.34M17.34,2.2C17.41,2.33 17.44,2.47 17.44,2.63L18.61,17C18.61,18.73 18,20.09 16.83,21.07C15.64,22.05 14.03,22.55 12,22.55C10,22.55 8.4,22.04 7.2,21C6,20 5.39,18.64 5.39,16.92L6.09,6.47C6.09,6.22 6.2,5.94 6.42,5.63C6.64,5.31 6.84,5.06 7.03,4.88L7.36,4.59C8.33,3.78 9.5,3.08 10.88,2.5C11.81,2.08 12.73,1.77 13.62,1.57C14.5,1.37 15.3,1.3 16,1.38C16.71,1.46 17.16,1.73 17.34,2.2Z\";\r\nvar mdiGoogleKeep = \"M4 2H20C21.11 2 22 2.9 22 4V17.33L17.33 22H4C2.9 22 2 21.11 2 20V4C2 2.9 2.9 2 4 2M17 17V20.25L20.25 17H17M10 19H14V18H15V13C16.21 12.09 17 10.64 17 9C17 6.24 14.76 4 12 4S7 6.24 7 9C7 10.64 7.79 12.09 9 13V18H10V19M14 17H10V15H14V17M12 5C14.21 5 16 6.79 16 9C16 10.5 15.2 11.77 14 12.46V14H10V12.46C8.8 11.77 8 10.5 8 9C8 6.79 9.79 5 12 5Z\";\r\nvar mdiGoogleLens = \"M6,2H18A4,4 0 0,1 22,6V12H20V6A2,2 0 0,0 18,4H6A2,2 0 0,0 4,6V18A2,2 0 0,0 6,20H12V22H6A4,4 0 0,1 2,18V6A4,4 0 0,1 6,2M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8M18,16A2,2 0 0,1 20,18A2,2 0 0,1 18,20A2,2 0 0,1 16,18A2,2 0 0,1 18,16Z\";\r\nvar mdiGoogleMaps = \"M18.27 6C19.28 8.17 19.05 10.73 17.94 12.81C17 14.5 15.65 15.93 14.5 17.5C14 18.2 13.5 18.95 13.13 19.76C13 20.03 12.91 20.31 12.81 20.59C12.71 20.87 12.62 21.15 12.53 21.43C12.44 21.69 12.33 22 12 22H12C11.61 22 11.5 21.56 11.42 21.26C11.18 20.53 10.94 19.83 10.57 19.16C10.15 18.37 9.62 17.64 9.08 16.93L18.27 6M9.12 8.42L5.82 12.34C6.43 13.63 7.34 14.73 8.21 15.83C8.42 16.08 8.63 16.34 8.83 16.61L13 11.67L12.96 11.68C11.5 12.18 9.88 11.44 9.3 10C9.22 9.83 9.16 9.63 9.12 9.43C9.07 9.06 9.06 8.79 9.12 8.43L9.12 8.42M6.58 4.62L6.57 4.63C4.95 6.68 4.67 9.53 5.64 11.94L9.63 7.2L9.58 7.15L6.58 4.62M14.22 2.36L11 6.17L11.04 6.16C12.38 5.7 13.88 6.28 14.56 7.5C14.71 7.78 14.83 8.08 14.87 8.38C14.93 8.76 14.95 9.03 14.88 9.4L14.88 9.41L18.08 5.61C17.24 4.09 15.87 2.93 14.23 2.37L14.22 2.36M9.89 6.89L13.8 2.24L13.76 2.23C13.18 2.08 12.59 2 12 2C10.03 2 8.17 2.85 6.85 4.31L6.83 4.32L9.89 6.89Z\";\r\nvar mdiGoogleMyBusiness = \"M22 8.5C22 9.87 20.88 11 19.5 11S17 9.87 17 8.5C17 9.87 15.88 11 14.5 11C13.12 11 12 9.87 12 8.5C12 9.87 10.88 11 9.5 11S7 9.87 7 8.5C7 9.87 5.88 11 4.5 11S2 9.87 2 8.5L3.39 3.08C3.39 3.08 3.68 2 4.7 2H19.3C20.32 2 20.61 3.08 20.61 3.08L22 8.5M21 12.2V20C21 21.1 20.1 22 19 22H5C3.9 22 3 21.1 3 20V12.2C3.46 12.39 3.97 12.5 4.5 12.5C5.45 12.5 6.32 12.17 7 11.62C7.69 12.17 8.56 12.5 9.5 12.5C10.45 12.5 11.32 12.17 12 11.62C12.69 12.17 13.56 12.5 14.5 12.5C15.45 12.5 16.32 12.17 17 11.62C17.68 12.17 18.56 12.5 19.5 12.5C20.03 12.5 20.54 12.39 21 12.2M19 17.33C19 17.13 19 16.92 18.95 16.7L18.92 16.54H15.95V17.71H17.76C17.7 17.93 17.62 18.15 17.45 18.33C17.12 18.66 16.67 18.84 16.19 18.84C15.69 18.84 15.2 18.63 14.84 18.28C14.15 17.57 14.15 16.42 14.86 15.7C15.55 15 16.69 15 17.41 15.67L17.55 15.8L18.39 14.95L18.23 14.81C17.67 14.29 16.93 14 16.15 14H16.14C15.33 14 14.57 14.31 14 14.87C13.41 15.45 13.08 16.21 13.08 17C13.08 17.8 13.39 18.54 13.96 19.09H13.96C14.54 19.66 15.35 20 16.18 20H16.2C17 20 17.71 19.71 18.23 19.2C18.7 18.72 19 18 19 17.33Z\";\r\nvar mdiGoogleNearby = \"M21.36,10.46L13.54,2.64C12.69,1.79 11.31,1.79 10.46,2.64L2.64,10.46C1.79,11.31 1.79,12.69 2.64,13.54L10.46,21.36C11.31,22.21 12.69,22.21 13.54,21.36L21.36,13.54C22.21,12.69 22.21,11.31 21.36,10.46M12,19L5,12L12,5L19,12L12,19M16.5,12L12,16.5L7.5,12L12,7.5L16.5,12Z\";\r\nvar mdiGooglePhotos = \"M10,13C10.55,13 11,13.18 11.41,13.57C11.8,13.96 12,14.44 12,15V22C12,22.17 11.91,22.27 11.72,22.27C11.66,22.27 11.58,22.22 11.5,22.13L7,17.67V13H10M12.5,1.88L17,6.33V11H14C13.45,11 13,10.82 12.59,10.43C12.2,10.04 12,9.56 12,9V2C12,1.83 12.09,1.73 12.28,1.73C12.34,1.73 12.42,1.78 12.5,1.88M22,12C22.17,12 22.27,12.09 22.27,12.28C22.27,12.34 22.22,12.42 22.13,12.5L17.67,17H13V14C13,13.45 13.18,13 13.57,12.59C13.96,12.2 14.44,12 15,12H22M6.33,7H11V10C11,10.55 10.82,11 10.43,11.41C10.04,11.8 9.56,12 9,12H2C1.83,12 1.73,11.91 1.73,11.72C1.73,11.66 1.78,11.58 1.88,11.5L6.33,7Z\";\r\nvar mdiGooglePlay = \"M3,20.5V3.5C3,2.91 3.34,2.39 3.84,2.15L13.69,12L3.84,21.85C3.34,21.6 3,21.09 3,20.5M16.81,15.12L6.05,21.34L14.54,12.85L16.81,15.12M20.16,10.81C20.5,11.08 20.75,11.5 20.75,12C20.75,12.5 20.53,12.9 20.18,13.18L17.89,14.5L15.39,12L17.89,9.5L20.16,10.81M6.05,2.66L16.81,8.88L14.54,11.15L6.05,2.66Z\";\r\nvar mdiGooglePlus = \"M23,11H21V9H19V11H17V13H19V15H21V13H23M8,11V13.4H12C11.8,14.4 10.8,16.4 8,16.4C5.6,16.4 3.7,14.4 3.7,12C3.7,9.6 5.6,7.6 8,7.6C9.4,7.6 10.3,8.2 10.8,8.7L12.7,6.9C11.5,5.7 9.9,5 8,5C4.1,5 1,8.1 1,12C1,15.9 4.1,19 8,19C12,19 14.7,16.2 14.7,12.2C14.7,11.7 14.7,11.4 14.6,11H8Z\";\r\nvar mdiGooglePodcast = \"M17.68,7.22V8.62C17.68,9.3 17.13,9.86 16.43,9.86C15.74,9.86 15.18,9.3 15.18,8.62V7.22A1.25,1.25 0 0,1 16.43,5.97C17.13,5.97 17.68,6.53 17.68,7.22M13.25,8.36V15.63C13.25,16.32 12.69,16.88 12,16.88C11.31,16.88 10.75,16.32 10.75,15.63V8.36C10.75,7.68 11.31,7.11 12,7.11C12.69,7.11 13.25,7.68 13.25,8.36M22,11.3V12.7C22,13.38 21.44,13.94 20.75,13.94C20.06,13.94 19.5,13.38 19.5,12.7V11.3C19.5,10.61 20.06,10.06 20.75,10.06C21.44,10.06 22,10.61 22,11.3M4.5,11.3V12.7C4.5,13.38 3.94,13.94 3.25,13.94C2.55,13.94 2,13.38 2,12.7V11.3C2,10.61 2.55,10.06 3.25,10.06C3.94,10.06 4.5,10.61 4.5,11.3M8.82,15.38V16.77C8.82,17.45 8.26,18 7.57,18C6.88,18 6.32,17.45 6.32,16.77V15.38C6.32,14.68 6.88,14.13 7.57,14.13A1.25,1.25 0 0,1 8.82,15.38M13.25,19.36V20.75A1.25,1.25 0 0,1 12,22A1.25,1.25 0 0,1 10.75,20.75V19.36A1.25,1.25 0 0,1 12,18.11A1.25,1.25 0 0,1 13.25,19.36M13.25,3.25V4.64A1.25,1.25 0 0,1 12,5.89A1.25,1.25 0 0,1 10.75,4.64V3.25C10.75,2.55 11.31,2 12,2A1.25,1.25 0 0,1 13.25,3.25M17.68,12.34V16.77C17.68,17.46 17.13,18 16.43,18C15.74,18 15.18,17.46 15.18,16.77V12.34C15.18,11.64 15.74,11.09 16.43,11.09C17.13,11.09 17.68,11.64 17.68,12.34M8.82,7.22V11.65C8.82,12.35 8.26,12.9 7.57,12.9A1.25,1.25 0 0,1 6.32,11.65V7.22A1.25,1.25 0 0,1 7.57,5.97A1.25,1.25 0 0,1 8.82,7.22Z\";\r\nvar mdiGoogleSpreadsheet = \"M19,11V9H11V5H9V9H5V11H9V19H11V11H19M19,3C19.5,3 20,3.2 20.39,3.61C20.8,4 21,4.5 21,5V19C21,19.5 20.8,20 20.39,20.39C20,20.8 19.5,21 19,21H5C4.5,21 4,20.8 3.61,20.39C3.2,20 3,19.5 3,19V5C3,4.5 3.2,4 3.61,3.61C4,3.2 4.5,3 5,3H19Z\";\r\nvar mdiGoogleStreetView = \"M11.95,9.27C13.96,9.27 15.59,7.64 15.59,5.63C15.59,3.63 13.96,2 11.95,2C9.94,2 8.32,3.63 8.32,5.63C8.32,7.64 9.94,9.27 11.95,9.27M9.36,12.97C9.36,12.97 8.27,15.94 7.96,16.5C7.85,16.71 7.87,16.77 7.6,16.77C7.33,16.77 6.91,16.5 6.91,16.5C6.91,16.5 6.71,16.37 6.79,16.14C7.03,15.4 8.12,11.08 8.35,10.25C8.6,9.36 9.28,9.39 9.28,9.39H9.93L12.03,13.04L14.14,9.39H14.92C14.92,9.39 15.23,9.43 15.46,9.7C15.7,9.97 15.75,10.44 15.75,10.44L17.14,15.84C17.14,15.84 17.24,16.22 17.21,16.33C17.17,16.5 17.08,16.5 17.08,16.5C17.08,16.5 16.69,16.62 16.47,16.69C16.07,16.82 16,16.44 16,16.44L14.7,13.04L14.55,22H12.6L12.27,16.89C12.27,16.89 12.21,16.76 12.03,16.76C11.86,16.76 11.8,16.89 11.8,16.89L11.45,22H9.5L9.37,12.97H9.36Z\";\r\nvar mdiGoogleTranslate = \"M20,5H10.88L10,2H4A2,2 0 0,0 2,4V17A2,2 0 0,0 4,19H11L12,22H20A2,2 0 0,0 22,20V7A2,2 0 0,0 20,5M7.17,14.59A4.09,4.09 0 0,1 3.08,10.5A4.09,4.09 0 0,1 7.17,6.41C8.21,6.41 9.16,6.78 9.91,7.5L10,7.54L8.75,8.72L8.69,8.67C8.4,8.4 7.91,8.08 7.17,8.08C5.86,8.08 4.79,9.17 4.79,10.5C4.79,11.83 5.86,12.92 7.17,12.92C8.54,12.92 9.13,12.05 9.29,11.46H7.08V9.91H11.03L11.04,10C11.08,10.19 11.09,10.38 11.09,10.59C11.09,12.94 9.5,14.59 7.17,14.59M13.2,12.88C13.53,13.5 13.94,14.06 14.39,14.58L13.85,15.11L13.2,12.88M13.97,12.12H13L12.67,11.08H16.66C16.66,11.08 16.32,12.39 15.1,13.82C14.58,13.2 14.21,12.59 13.97,12.12M21,20A1,1 0 0,1 20,21H13L15,19L14.19,16.23L15.11,15.31L17.79,18L18.5,17.27L15.81,14.59C16.71,13.56 17.41,12.34 17.73,11.08H19V10.04H15.36V9H14.32V10.04H12.36L11.18,6H20A1,1 0 0,1 21,7V20Z\";\r\nvar mdiGradient = \"M11,9H13V11H11V9M9,11H11V13H9V11M13,11H15V13H13V11M15,9H17V11H15V9M7,9H9V11H7V9M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M9,18H7V16H9V18M13,18H11V16H13V18M17,18H15V16H17V18M19,11H17V13H19V15H17V13H15V15H13V13H11V15H9V13H7V15H5V13H7V11H5V5H19V11Z\";\r\nvar mdiGrain = \"M10,12A2,2 0 0,0 8,14A2,2 0 0,0 10,16A2,2 0 0,0 12,14A2,2 0 0,0 10,12M6,8A2,2 0 0,0 4,10A2,2 0 0,0 6,12A2,2 0 0,0 8,10A2,2 0 0,0 6,8M6,16A2,2 0 0,0 4,18A2,2 0 0,0 6,20A2,2 0 0,0 8,18A2,2 0 0,0 6,16M18,8A2,2 0 0,0 20,6A2,2 0 0,0 18,4A2,2 0 0,0 16,6A2,2 0 0,0 18,8M14,16A2,2 0 0,0 12,18A2,2 0 0,0 14,20A2,2 0 0,0 16,18A2,2 0 0,0 14,16M18,12A2,2 0 0,0 16,14A2,2 0 0,0 18,16A2,2 0 0,0 20,14A2,2 0 0,0 18,12M14,8A2,2 0 0,0 12,10A2,2 0 0,0 14,12A2,2 0 0,0 16,10A2,2 0 0,0 14,8M10,4A2,2 0 0,0 8,6A2,2 0 0,0 10,8A2,2 0 0,0 12,6A2,2 0 0,0 10,4Z\";\r\nvar mdiGraph = \"M19.5 17C19.37 17 19.24 17 19.11 17.04L17.5 13.79C17.95 13.34 18.25 12.71 18.25 12C18.25 10.62 17.13 9.5 15.75 9.5C15.62 9.5 15.5 9.5 15.36 9.54L13.73 6.29C14.21 5.84 14.5 5.21 14.5 4.5C14.5 3.12 13.38 2 12 2S9.5 3.12 9.5 4.5C9.5 5.21 9.79 5.84 10.26 6.29L8.64 9.54C8.5 9.5 8.38 9.5 8.25 9.5C6.87 9.5 5.75 10.62 5.75 12C5.75 12.71 6.05 13.34 6.5 13.79L4.89 17.04C4.76 17 4.63 17 4.5 17C3.12 17 2 18.12 2 19.5C2 20.88 3.12 22 4.5 22S7 20.88 7 19.5C7 18.8 6.71 18.16 6.24 17.71L7.86 14.46C8 14.5 8.12 14.5 8.25 14.5C8.38 14.5 8.5 14.5 8.64 14.46L10.27 17.71C9.8 18.16 9.5 18.8 9.5 19.5C9.5 20.88 10.62 22 12 22S14.5 20.88 14.5 19.5C14.5 18.12 13.38 17 12 17C11.87 17 11.74 17 11.61 17.04L10 13.79C10.46 13.34 10.75 12.71 10.75 12S10.46 10.66 10 10.21L11.61 6.96C11.74 7 11.87 7 12 7S12.26 7 12.39 6.96L14 10.21C13.55 10.66 13.25 11.3 13.25 12C13.25 13.38 14.37 14.5 15.75 14.5C15.88 14.5 16 14.5 16.14 14.46L17.77 17.71C17.3 18.16 17 18.8 17 19.5C17 20.88 18.12 22 19.5 22S22 20.88 22 19.5C22 18.12 20.88 17 19.5 17Z\";\r\nvar mdiGraphOutline = \"M19.5 17C19.36 17 19.24 17 19.11 17.04L17.5 13.8C17.95 13.35 18.25 12.71 18.25 12C18.25 10.62 17.13 9.5 15.75 9.5C15.61 9.5 15.5 9.5 15.35 9.54L13.74 6.3C14.21 5.84 14.5 5.21 14.5 4.5C14.5 3.12 13.38 2 12 2S9.5 3.12 9.5 4.5C9.5 5.2 9.79 5.84 10.26 6.29L8.65 9.54C8.5 9.5 8.39 9.5 8.25 9.5C6.87 9.5 5.75 10.62 5.75 12C5.75 12.71 6.04 13.34 6.5 13.79L4.89 17.04C4.76 17 4.64 17 4.5 17C3.12 17 2 18.12 2 19.5C2 20.88 3.12 22 4.5 22S7 20.88 7 19.5C7 18.8 6.71 18.16 6.24 17.71L7.86 14.46C8 14.5 8.12 14.5 8.25 14.5C8.38 14.5 8.5 14.5 8.63 14.46L10.26 17.71C9.79 18.16 9.5 18.8 9.5 19.5C9.5 20.88 10.62 22 12 22S14.5 20.88 14.5 19.5C14.5 18.12 13.38 17 12 17C11.87 17 11.74 17 11.61 17.04L10 13.8C10.45 13.35 10.75 12.71 10.75 12C10.75 11.3 10.46 10.67 10 10.21L11.61 6.96C11.74 7 11.87 7 12 7C12.13 7 12.26 7 12.39 6.96L14 10.21C13.54 10.66 13.25 11.3 13.25 12C13.25 13.38 14.37 14.5 15.75 14.5C15.88 14.5 16 14.5 16.13 14.46L17.76 17.71C17.29 18.16 17 18.8 17 19.5C17 20.88 18.12 22 19.5 22S22 20.88 22 19.5C22 18.12 20.88 17 19.5 17M4.5 20.5C3.95 20.5 3.5 20.05 3.5 19.5S3.95 18.5 4.5 18.5 5.5 18.95 5.5 19.5 5.05 20.5 4.5 20.5M13 19.5C13 20.05 12.55 20.5 12 20.5S11 20.05 11 19.5 11.45 18.5 12 18.5 13 18.95 13 19.5M7.25 12C7.25 11.45 7.7 11 8.25 11S9.25 11.45 9.25 12 8.8 13 8.25 13 7.25 12.55 7.25 12M11 4.5C11 3.95 11.45 3.5 12 3.5S13 3.95 13 4.5 12.55 5.5 12 5.5 11 5.05 11 4.5M14.75 12C14.75 11.45 15.2 11 15.75 11S16.75 11.45 16.75 12 16.3 13 15.75 13 14.75 12.55 14.75 12M19.5 20.5C18.95 20.5 18.5 20.05 18.5 19.5S18.95 18.5 19.5 18.5 20.5 18.95 20.5 19.5 20.05 20.5 19.5 20.5Z\";\r\nvar mdiGraphql = \"M12,5.37L11.56,5.31L6,14.9C6.24,15.11 6.4,15.38 6.47,15.68H17.53C17.6,15.38 17.76,15.11 18,14.9L12.44,5.31L12,5.37M6.6,16.53L10.88,19.06C11.17,18.79 11.57,18.63 12,18.63C12.43,18.63 12.83,18.79 13.12,19.06L17.4,16.53H6.6M12,22A1.68,1.68 0 0,1 10.32,20.32L10.41,19.76L6.11,17.21C5.8,17.57 5.35,17.79 4.84,17.79A1.68,1.68 0 0,1 3.16,16.11C3.16,15.32 3.69,14.66 4.42,14.47V9.36C3.59,9.25 2.95,8.54 2.95,7.68A1.68,1.68 0 0,1 4.63,6C5.18,6 5.66,6.26 5.97,6.66L10.38,4.13L10.32,3.68C10.32,2.75 11.07,2 12,2C12.93,2 13.68,2.75 13.68,3.68L13.62,4.13L18.03,6.66C18.34,6.26 18.82,6 19.37,6A1.68,1.68 0 0,1 21.05,7.68C21.05,8.54 20.41,9.25 19.58,9.36V14.47C20.31,14.66 20.84,15.32 20.84,16.11A1.68,1.68 0 0,1 19.16,17.79C18.65,17.79 18.2,17.57 17.89,17.21L13.59,19.76L13.68,20.32A1.68,1.68 0 0,1 12,22M10.8,4.86L6.3,7.44L6.32,7.68C6.32,8.39 5.88,9 5.26,9.25L5.29,14.5L10.8,4.86M13.2,4.86L18.71,14.5L18.74,9.25C18.12,9 17.68,8.39 17.68,7.68L17.7,7.44L13.2,4.86Z\";\r\nvar mdiGrass = \"M12 20H2V18H7.75C7 15.19 4.81 13 2 12.26C2.64 12.1 3.31 12 4 12C8.42 12 12 15.58 12 20M22 12.26C21.36 12.1 20.69 12 20 12C17.07 12 14.5 13.58 13.12 15.93C13.41 16.59 13.65 17.28 13.79 18C13.92 18.65 14 19.32 14 20H22V18H16.24C17 15.19 19.19 13 22 12.26M15.64 11C16.42 8.93 17.87 7.18 19.73 6C15.44 6.16 12 9.67 12 14V14C12.95 12.75 14.2 11.72 15.64 11M11.42 8.85C10.58 6.66 8.88 4.89 6.7 4C8.14 5.86 9 8.18 9 10.71C9 10.92 8.97 11.12 8.96 11.32C9.39 11.56 9.79 11.84 10.18 12.14C10.39 10.96 10.83 9.85 11.42 8.85Z\";\r\nvar mdiGraveStone = \"M10,2H14C17.31,2 19,4.69 19,8V18.66C16.88,17.63 15.07,17 12,17C8.93,17 7.12,17.63 5,18.66V8C5,4.69 6.69,2 10,2M8,8V9.5H16V8H8M9,12V13.5H15V12H9M3,22V21.31C5.66,19.62 13.23,15.84 21,21.25V22H3Z\";\r\nvar mdiGreasePencil = \"M18.62,1.5C18.11,1.5 17.6,1.69 17.21,2.09L10.75,8.55L14.95,12.74L21.41,6.29C22.2,5.5 22.2,4.24 21.41,3.46L20.04,2.09C19.65,1.69 19.14,1.5 18.62,1.5M9.8,9.5L3.23,16.07L3.93,16.77C3.4,17.24 2.89,17.78 2.38,18.29C1.6,19.08 1.6,20.34 2.38,21.12C3.16,21.9 4.42,21.9 5.21,21.12C5.72,20.63 6.25,20.08 6.73,19.58L7.43,20.27L14,13.7\";\r\nvar mdiGreaterThan = \"M5.5,4.14L4.5,5.86L15,12L4.5,18.14L5.5,19.86L19,12L5.5,4.14Z\";\r\nvar mdiGreaterThanOrEqual = \"M6.5,2.27L20,10.14L6.5,18L5.5,16.27L16.03,10.14L5.5,4L6.5,2.27M20,20V22H5V20H20Z\";\r\nvar mdiGrid = \"M10,4V8H14V4H10M16,4V8H20V4H16M16,10V14H20V10H16M16,16V20H20V16H16M14,20V16H10V20H14M8,20V16H4V20H8M8,14V10H4V14H8M8,8V4H4V8H8M10,14H14V10H10V14M4,2H20A2,2 0 0,1 22,4V20A2,2 0 0,1 20,22H4C2.92,22 2,21.1 2,20V4A2,2 0 0,1 4,2Z\";\r\nvar mdiGridLarge = \"M4,2H20A2,2 0 0,1 22,4V20A2,2 0 0,1 20,22H4C2.92,22 2,21.1 2,20V4A2,2 0 0,1 4,2M4,4V11H11V4H4M4,20H11V13H4V20M20,20V13H13V20H20M20,4H13V11H20V4Z\";\r\nvar mdiGridOff = \"M0,2.77L1.28,1.5L22.5,22.72L21.23,24L19.23,22H4C2.92,22 2,21.1 2,20V4.77L0,2.77M10,4V7.68L8,5.68V4H6.32L4.32,2H20A2,2 0 0,1 22,4V19.7L20,17.7V16H18.32L16.32,14H20V10H16V13.68L14,11.68V10H12.32L10.32,8H14V4H10M16,4V8H20V4H16M16,20H17.23L16,18.77V20M4,8H5.23L4,6.77V8M10,14H11.23L10,12.77V14M14,20V16.77L13.23,16H10V20H14M8,20V16H4V20H8M8,14V10.77L7.23,10H4V14H8Z\";\r\nvar mdiGrill = \"M8.06,2C7.88,3.17 8.17,4.16 8.95,4.97C9.45,5.47 9.61,6.14 9.42,7H10.41C10.53,6.45 10.55,6 10.45,5.55C10.36,5.13 10.05,4.63 9.5,4.03C9.05,3.47 8.89,2.8 9.05,2H8.06M10.55,2C10.36,3.17 10.66,4.16 11.44,4.97C11.94,5.47 12.09,6.14 11.91,7H12.89C13,6.45 13.03,6 12.94,5.55C12.84,5.13 12.53,4.63 12,4.03C11.53,3.47 11.38,2.8 11.53,2H10.55M13.08,2C12.89,3.17 13.19,4.16 13.97,4.97C14.47,5.47 14.61,6.14 14.39,7H15.42C15.55,6.45 15.56,6 15.47,5.55C15.38,5.13 15.06,4.63 14.53,4.03C14.06,3.47 13.91,2.8 14.06,2H13.08M5,8C5,9.42 5.39,10.7 6.14,11.84C6.87,12.96 7.91,13.85 9.14,14.39L5.16,20.44C5.06,20.56 5,20.75 5,21C5,21.41 5.16,21.69 5.44,21.84C5.56,21.94 5.75,22 6,22C6.41,22 6.69,21.84 6.84,21.56L7.83,19.97H14.2C14.41,20.55 14.79,21.05 15.28,21.42C15.78,21.8 16.36,22 17,22C17.83,22 18.53,21.69 19.13,21.09C19.72,20.5 20,19.8 20,19C20,18.17 19.72,17.47 19.13,16.88C18.53,16.28 17.83,16 17,16C16.36,16 15.78,16.17 15.28,16.55C14.78,16.92 14.42,17.41 14.2,18H9.14L11.11,14.95C11.27,15 11.56,15 12,15C12.44,15 12.73,15 12.89,14.95L13.88,16.5C14.29,15.96 14.84,15.54 15.47,15.28L14.91,14.39C16.03,13.89 17,13 17.79,11.77C18.59,10.5 19,9.27 19,8H5M17,18C17.3,18 17.53,18.09 17.72,18.28C17.91,18.47 18,18.72 18,19C18,19.27 17.91,19.5 17.72,19.71C17.54,19.91 17.28,20 17,20C16.74,20 16.5,19.91 16.29,19.71C16.09,19.5 16,19.26 16,19C16,18.7 16.09,18.47 16.29,18.28C16.5,18.09 16.73,18 17,18Z\";\r\nvar mdiGrillOutline = \"M17 22A3 3 0 1 0 14.18 18H9.14L11.13 14.94A6.36 6.36 0 0 0 12.87 14.94L13.89 16.5C14.31 16 14.85 15.56 15.5 15.3L14.89 14.37A7 7 0 0 0 19 8H5A7 7 0 0 0 9.12 14.37L5.17 20.45A1 1 0 0 0 6.84 21.54L7.84 20H14.18A3 3 0 0 0 17 22M17 18A1 1 0 0 1 18 19C18 19.55 17.55 20 17 20S16 19.55 16 19A1 1 0 0 1 17 18M7.42 10H16.58A5 5 0 0 1 7.42 10M9.41 7H10.41C10.56 5.85 10.64 5.36 9.5 4.04C9.1 3.54 8.84 3.27 9.06 2H8.07A3.14 3.14 0 0 0 8.96 4.96C9.18 5.2 9.75 5.63 9.41 7M11.89 7H12.89C13.04 5.85 13.12 5.36 12 4.04C11.58 3.54 11.32 3.26 11.54 2H10.55A3.14 3.14 0 0 0 11.44 4.96C11.67 5.2 12.24 5.63 11.89 7M14.41 7H15.41C15.56 5.85 15.64 5.36 14.5 4.04C14.1 3.54 13.84 3.27 14.06 2H13.07A3.14 3.14 0 0 0 13.96 4.96C14.18 5.2 14.75 5.63 14.41 7Z\";\r\nvar mdiGroup = \"M1,1V5H2V19H1V23H5V22H19V23H23V19H22V5H23V1H19V2H5V1M5,4H19V5H20V19H19V20H5V19H4V5H5M6,6V14H9V18H18V9H14V6M8,8H12V12H8M14,11H16V16H11V14H14\";\r\nvar mdiGuitarAcoustic = \"M19.59,3H22V5H20.41L16.17,9.24C15.8,8.68 15.32,8.2 14.76,7.83L19.59,3M12,8A4,4 0 0,1 16,12C16,13.82 14.77,15.42 13,15.87V16A5,5 0 0,1 8,21A5,5 0 0,1 3,16A5,5 0 0,1 8,11H8.13C8.58,9.24 10.17,8 12,8M12,10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 12,13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 12,10.5M6.94,14.24L6.23,14.94L9.06,17.77L9.77,17.06L6.94,14.24Z\";\r\nvar mdiGuitarElectric = \"M19.59,3H22V5H20.41L15.12,10.29L13.71,8.9L19.59,3M12,9C12.26,9 12.5,9.1 12.71,9.3L14.71,11.3C14.89,11.5 15,11.73 15,12L14.9,12.4L10.9,20.4C10.71,20.75 10.36,20.93 10,20.93C9.65,20.93 9.29,20.75 9.11,20.4L7.25,16.7L3.55,14.9C3.18,14.7 3,14.35 3,14C3,13.65 3.18,13.3 3.55,13.1L11.55,9.1C11.69,9 11.84,9 12,9M9.35,11.82L8.65,12.5L11.5,15.35L12.18,14.65L9.35,11.82M7.94,13.23L7.23,13.94L10.06,16.77L10.77,16.06L7.94,13.23Z\";\r\nvar mdiGuitarPick = \"M19,4.1C18.1,3.3 17,2.8 15.8,2.5C15.5,2.4 13.6,2 12.2,2C12.2,2 12.1,2 12,2C12,2 11.9,2 11.8,2C10.4,2 8.4,2.4 8.1,2.5C7,2.8 5.9,3.3 5,4.1C3,5.9 3,8.7 4,11C5,13.5 6.1,15.7 7.6,17.9C8.8,19.6 10.1,22 12,22C13.9,22 15.2,19.6 16.5,17.9C18,15.8 19.1,13.5 20.1,11C21,8.7 21,5.9 19,4.1Z\";\r\nvar mdiGuitarPickOutline = \"M19,4.1C18.1,3.3 17,2.8 15.8,2.5C15.5,2.4 13.6,2 12.2,2C12.2,2 12.1,2 12,2C12,2 11.9,2 11.8,2C10.4,2 8.4,2.4 8.1,2.5C7,2.8 5.9,3.3 5,4.1C3,5.9 3,8.7 4,11C5,13.5 6.1,15.7 7.6,17.9C8.8,19.6 10.1,22 12,22C13.9,22 15.2,19.6 16.5,17.9C18,15.8 19.1,13.5 20.1,11C21,8.7 21,5.9 19,4.1M18.2,10.2C17.1,12.9 16.1,14.9 14.8,16.7C14.6,16.9 14.5,17.2 14.3,17.4C13.8,18.2 12.6,20 12,20C12,20 12,20 12,20C11.3,20 10.2,18.3 9.6,17.4C9.4,17.2 9.3,16.9 9.1,16.7C7.9,14.9 6.8,12.9 5.7,10.2C5.5,9.5 4.7,7 6.3,5.5C6.8,5 7.6,4.7 8.6,4.4C9,4.4 10.7,4 11.8,4C11.8,4 12.1,4 12.1,4C13.2,4 14.9,4.3 15.3,4.4C16.3,4.7 17.1,5 17.6,5.5C19.3,7 18.5,9.5 18.2,10.2Z\";\r\nvar mdiGuyFawkesMask = \"M21,13A9,9 0 0,1 12,22A9,9 0 0,1 3,13L3.03,4.43C5.68,2.88 8.76,2 12.05,2C15.3,2 18.36,2.87 21,4.38V13M13,19.93C16.39,19.44 19,16.5 19,13V5.59C16.9,4.57 14.54,4 12.05,4C9.5,4 7.08,4.6 4.94,5.66L5,13C5,16.5 7.63,19.44 11,19.93V18H13V19.93M11,16H8L6,13L9,14H10L11,13H13L14,14H15L18,13L16,16H13L12,15L11,16M6,9.03C6.64,8.4 7.5,8.05 8.5,8.05C9.45,8.05 10.34,8.4 11,9.03C10.34,9.65 9.45,10 8.5,10C7.5,10 6.64,9.65 6,9.03M13,9.03C13.64,8.4 14.5,8.05 15.5,8.05C16.45,8.05 17.34,8.4 18,9.03C17.34,9.65 16.45,10 15.5,10C14.5,10 13.64,9.65 13,9.03Z\";\r\nvar mdiHail = \"M4,16H7V22H4V16M19,2.39C18.92,3.86 18.55,5.13 17.86,6.21C17.17,7.29 16.22,8 15,8.39V22H13V16H11V22H9V10.08C8.72,10.17 8.5,10.28 8.39,10.41C7.45,11.16 7,12.19 7,13.5V14H5V13.5C5,11.53 5.72,9.94 7.13,8.72C8.53,7.56 10.16,7 12,7C13.41,7 14.56,6.64 15.47,5.95C16.5,5.11 17,3.95 17,2.5V2H19V2.39M12,2A2,2 0 0,1 14,4A2,2 0 0,1 12,6A2,2 0 0,1 10,4A2,2 0 0,1 12,2Z\";\r\nvar mdiHairDryer = \"M22 9A4.32 4.32 0 0 1 19.78 8.45A3.4 3.4 0 0 0 18 8V7A4.32 4.32 0 0 1 20.22 7.55A3.4 3.4 0 0 0 22 8M22 6A3.4 3.4 0 0 1 20.22 5.55A4.32 4.32 0 0 0 18 5V6A3.4 3.4 0 0 1 19.78 6.45A4.32 4.32 0 0 0 22 7M22 10A3.4 3.4 0 0 1 20.22 9.55A4.32 4.32 0 0 0 18 9V10A3.4 3.4 0 0 1 19.78 10.45A4.32 4.32 0 0 0 22 11M10 12.73A70.39 70.39 0 0 0 17 11V4S10.5 2 7.5 2A5.5 5.5 0 0 0 6.12 12.82L7 19H8A3 3 0 0 0 9.46 21.33A3.15 3.15 0 0 1 11 24H12A4.12 4.12 0 0 0 10.09 20.55C9.39 20 9 19.63 9 19H10M7.5 10A2.5 2.5 0 1 1 10 7.5A2.5 2.5 0 0 1 7.5 10Z\";\r\nvar mdiHairDryerOutline = \"M10 12.73A70.39 70.39 0 0 0 17 11V4S10.5 2 7.5 2A5.5 5.5 0 0 0 6.12 12.82L7 19H8A3 3 0 0 0 9.46 21.33A3.15 3.15 0 0 1 11 24H12A4.12 4.12 0 0 0 10.09 20.55C9.39 20 9 19.63 9 19H10M4 7.5A3.5 3.5 0 0 1 7.5 4A37.08 37.08 0 0 1 15 5.5V9.5A37.08 37.08 0 0 1 7.5 11A3.5 3.5 0 0 1 4 7.5M22 9A4.32 4.32 0 0 1 19.78 8.45A3.4 3.4 0 0 0 18 8V7A4.32 4.32 0 0 1 20.22 7.55A3.4 3.4 0 0 0 22 8M22 6A3.4 3.4 0 0 1 20.22 5.55A4.32 4.32 0 0 0 18 5V6A3.4 3.4 0 0 1 19.78 6.45A4.32 4.32 0 0 0 22 7M22 10A3.4 3.4 0 0 1 20.22 9.55A4.32 4.32 0 0 0 18 9V10A3.4 3.4 0 0 1 19.78 10.45A4.32 4.32 0 0 0 22 11M9 7.5A1.5 1.5 0 1 1 7.5 6A1.5 1.5 0 0 1 9 7.5Z\";\r\nvar mdiHalloween = \"M6.5,6C7.47,6 8.37,6.5 9.11,7.38C9.66,6.79 10.31,6.36 11,6.15V4A2,2 0 0,1 13,2H15V4H13V6.15C13.69,6.36 14.34,6.79 14.89,7.38C15.63,6.5 16.53,6 17.5,6C20,6 22,9.36 22,13.5C22,17.64 20,21 17.5,21C16.53,21 15.63,20.5 14.89,19.62C14.08,20.5 13.08,21 12,21C10.92,21 9.92,20.5 9.11,19.62C8.37,20.5 7.47,21 6.5,21C4,21 2,17.64 2,13.5C2,9.36 4,6 6.5,6M9,10L7.75,12.25H10.25L9,10M15,10L13.75,12.25H16.25L15,10M8,17H10L11,16L12,17H14L15,16L16,17L17.5,14L13.92,14.62L13,16L12,15H10L9,16L8,15L6,14L8,17Z\";\r\nvar mdiHamburger = \"M2,16H22V18C22,19.11 21.11,20 20,20H4C2.89,20 2,19.11 2,18V16M6,4H18C20.22,4 22,5.78 22,8V10H2V8C2,5.78 3.78,4 6,4M4,11H15L17,13L19,11H20C21.11,11 22,11.89 22,13C22,14.11 21.11,15 20,15H4C2.89,15 2,14.11 2,13C2,11.89 2.89,11 4,11Z\";\r\nvar mdiHammer = \"M2 19.63L13.43 8.2L12.72 7.5L14.14 6.07L12 3.89C13.2 2.7 15.09 2.7 16.27 3.89L19.87 7.5L18.45 8.91H21.29L22 9.62L18.45 13.21L17.74 12.5V9.62L16.27 11.04L15.56 10.33L4.13 21.76L2 19.63Z\";\r\nvar mdiHammerScrewdriver = \"M16.06 13.09L21.69 18.68L18.37 21.96L12.78 16.37V15.45L15.14 13.09H16.06M16.97 10.56L16 9.6L11.21 14.4V16.37L5.58 22L2.3 18.68L7.89 13.09H9.86L10.64 12.31L6.8 8.46H5.5L2.69 5.62L5.31 3L8.11 5.8V7.11L12 10.95L14.66 8.29L13.7 7.28L15 5.97H12.34L11.69 5.32L15 2L15.66 2.66V5.32L16.97 4L20.25 7.28C21.34 8.38 21.34 10.17 20.25 11.26L18.28 9.25L16.97 10.56Z\";\r\nvar mdiHammerWrench = \"M13.78 15.3L19.78 21.3L21.89 19.14L15.89 13.14L13.78 15.3M17.5 10.1C17.11 10.1 16.69 10.05 16.36 9.91L4.97 21.25L2.86 19.14L10.27 11.74L8.5 9.96L7.78 10.66L6.33 9.25V12.11L5.63 12.81L2.11 9.25L2.81 8.55H5.62L4.22 7.14L7.78 3.58C8.95 2.41 10.83 2.41 12 3.58L9.89 5.74L11.3 7.14L10.59 7.85L12.38 9.63L14.2 7.75C14.06 7.42 14 7 14 6.63C14 4.66 15.56 3.11 17.5 3.11C18.09 3.11 18.61 3.25 19.08 3.53L16.41 6.2L17.91 7.7L20.58 5.03C20.86 5.5 21 6 21 6.63C21 8.55 19.45 10.1 17.5 10.1Z\";\r\nvar mdiHand = \"M6.58,19H14.58V22H6.58V19M19.74,11.6C19.55,11.4 19.29,11.28 19,11.28L18.78,11.31L15.58,13V11.83L16.09,2.9C16.12,2.35 15.7,1.87 15.15,1.84C14.6,1.81 14.12,2.23 14.09,2.78L13.82,7.47H13.58L12.54,7.58V2A1,1 0 0,0 11.54,1C11,1 10.54,1.45 10.54,2V8.41L9.72,8.78L9.03,3.32C8.96,2.77 8.46,2.38 7.91,2.45C7.36,2.5 6.97,3 7.04,3.57L7.81,9.63L7.43,9.8C7.3,9.85 7.18,9.93 7.07,10L5.97,6.11C5.81,5.54 5.25,5.2 4.71,5.34C4.18,5.5 3.88,6.08 4.04,6.65L6.61,15.77C6.61,15.8 6.63,15.84 6.64,15.87L6.67,16H6.68C6.9,16.57 7.47,17 8.08,17H14.58C14.97,17 15.32,16.84 15.58,16.57L20.5,12.37L19.74,11.6Z\";\r\nvar mdiHandHeart = \"M20 17Q20.86 17 21.45 17.6T22.03 19L14 22L7 20V11H8.95L16.22 13.69Q17 14 17 14.81 17 15.28 16.66 15.63T15.8 16H13L11.25 15.33L10.92 16.27L13 17H20M16 3.23Q17.06 2 18.7 2 20.06 2 21 3T22 5.3Q22 6.33 21 7.76T19.03 10.15 16 13Q13.92 11.11 12.94 10.15T10.97 7.76 10 5.3Q10 3.94 10.97 3T13.31 2Q14.91 2 16 3.23M.984 11H5V22H.984V11Z\";\r\nvar mdiHandHeartOutline = \"M16 3.23C16.71 2.41 17.61 2 18.7 2C19.61 2 20.37 2.33 21 3C21.63 3.67 21.96 4.43 22 5.3C22 6 21.67 6.81 21 7.76S19.68 9.5 19.03 10.15C18.38 10.79 17.37 11.74 16 13C14.61 11.74 13.59 10.79 12.94 10.15S11.63 8.71 10.97 7.76C10.31 6.81 10 6 10 5.3C10 4.39 10.32 3.63 10.97 3C11.62 2.37 12.4 2.04 13.31 2C14.38 2 15.27 2.41 16 3.23M22 19V20L14 22.5L7 20.56V22H1V11H8.97L15.13 13.3C16.25 13.72 17 14.8 17 16H19C20.66 16 22 17.34 22 19M5 20V13H3V20H5M19.9 18.57C19.74 18.24 19.39 18 19 18H13.65C13.11 18 12.58 17.92 12.07 17.75L9.69 16.96L10.32 15.06L12.7 15.85C13 15.95 15 16 15 16C15 15.63 14.77 15.3 14.43 15.17L8.61 13H7V18.5L13.97 20.41L19.9 18.57Z\";\r\nvar mdiHandLeft = \"M3,6.58V18.67C3,20.5 4.5,22 6.33,22H12.42C13.32,22 14.17,21.64 14.79,21L21.33,14.36C21.33,14.36 20.28,13.33 20.25,13.32C20.07,13.16 19.84,13.07 19.59,13.07C19.41,13.07 19.24,13.12 19.09,13.21C19.06,13.22 15.5,15.26 15.5,15.26V5.33A1.25,1.25 0 0,0 14.25,4.08A1.25,1.25 0 0,0 13,5.33V11.17H12.17V3.25A1.25,1.25 0 0,0 10.92,2A1.25,1.25 0 0,0 9.67,3.25V11.17H8.83V4.08A1.25,1.25 0 0,0 7.58,2.83A1.25,1.25 0 0,0 6.33,4.08V11.17H5.5V6.58A1.25,1.25 0 0,0 4.25,5.33A1.25,1.25 0 0,0 3,6.58Z\";\r\nvar mdiHandOkay = \"M13.3,19.26L18.96,13.61L21.08,15.73L15.42,21.38L13.3,19.26M16.5,11.13L13.4,8.05C13.27,7.92 13.13,7.83 13,7.76L11.88,3.47C11.74,2.93 11.2,2.61 10.66,2.75C10.13,2.88 9.81,3.43 9.94,3.96L11,8.03V8.03L8.67,3.19C8.44,2.69 7.84,2.5 7.34,2.71C6.84,2.95 6.63,3.55 6.87,4.05L8.56,7.59L5.19,4.25C4.8,3.86 4.16,3.86 3.77,4.25C3.38,4.65 3.39,5.28 3.78,5.67L7.5,9.37L6.8,9.64L5.72,10.07L3.81,11.39C3.81,11.39 3,12.44 2.93,12.89C2.85,13.34 3.72,15.6 3.72,15.6H3.73C3.89,15.94 4.23,16.18 4.63,16.18A1,1 0 0,0 5.63,15.18C5.63,15.08 5.6,15 5.57,14.91L5.59,14.9L5,13.17L6.23,12.19C6.7,12.21 7.71,12.29 8.2,12.32C10.93,14.77 8.35,15.73 8.35,15.73L4.89,16.79L4.72,16.93C4.5,17.13 4.41,17.4 4.42,17.68L4.44,18.75L10.87,18.25C11.25,18.26 11.61,18.12 11.89,17.85L16.5,13.25C17.03,12.71 17.05,11.7 16.5,11.13Z\";\r\nvar mdiHandPeace = \"M7,19H15V22H7V19M16.15,12V12L12.97,10.34C12.82,10.34 12.69,10.4 12.6,10.5L12.3,10.81L12.89,13.23L11.91,13.47L10.72,8.5L9.25,9.18L10.29,13.47L9.32,13.7L8.32,9.59L7.85,9.8C7.35,10 7,10.53 7,11.14V15.5C7,16.3 7.73,17 8.5,17H15C15.39,17 15.74,16.84 16,16.57L16.5,16.16C16.5,16.16 17,15.78 17,15.36V13.7C17,13.7 17,12.56 16.15,12M16.94,1C16.4,0.91 15.87,1.25 15.76,1.8L14.69,7.97C14.47,7.94 14.38,7.86 14.08,7.83L13.65,7.88L12.41,1.8C12.3,1.26 11.78,0.91 11.24,1C10.69,1.13 10.34,1.66 10.45,2.2L11.65,8.11V8.11L12,9.67C12.28,9.47 12.61,9.34 12.97,9.34H13.31L16.31,10.95L17.72,2.2C17.83,1.66 17.5,1.13 16.94,1Z\";\r\nvar mdiHandPeaceVariant = \"M7,19H15V22H7V19M16.94,1C16.4,0.91 15.87,1.25 15.76,1.8L14.75,7.57C14.53,7.54 14.29,7.5 14,7.47L13.57,7.5L12.41,1.8C12.31,1.26 11.78,0.91 11.24,1C10.7,1.13 10.35,1.66 10.45,2.2L11.65,8.11L7.85,9.8C7.35,10 7,10.53 7,11.14V15.5C7,16.3 7.73,17 8.5,17H15C15.39,17 15.74,16.84 16,16.57L16.5,16.16C16.5,16.16 17,15.78 17,15.36V13C17,13 17,11.86 16.13,11.3L17.71,2.2C17.83,1.66 17.5,1.13 16.94,1Z\";\r\nvar mdiHandPointingDown = \"M9.9,21V11L6.7,12.69L6.5,12.72C6.19,12.72 5.93,12.6 5.74,12.4L5,11.63L9.9,7.43C10.16,7.16 10.5,7 10.9,7H17.4C18.17,7 18.9,7.7 18.9,8.5V12.86C18.9,13.47 18.55,14 18.05,14.2L13.11,16.4L11.9,16.53V21A1,1 0 0,1 10.9,22A1,1 0 0,1 9.9,21M18.9,5H10.9V2H18.9V5Z\";\r\nvar mdiHandPointingLeft = \"M3,9H13L11.31,5.8L11.28,5.58C11.28,5.29 11.4,5.03 11.6,4.84L12.37,4.1L16.57,9C16.84,9.26 17,9.61 17,10V16.5C17,17.27 16.3,18 15.5,18H11.14C10.53,18 10,17.65 9.8,17.15L7.6,12.21L7.47,11H3A1,1 0 0,1 2,10A1,1 0 0,1 3,9M19,18V10H22V18H19Z\";\r\nvar mdiHandPointingRight = \"M21,9A1,1 0 0,1 22,10A1,1 0 0,1 21,11H16.53L16.4,12.21L14.2,17.15C14,17.65 13.47,18 12.86,18H8.5C7.7,18 7,17.27 7,16.5V10C7,9.61 7.16,9.26 7.43,9L11.63,4.1L12.4,4.84C12.6,5.03 12.72,5.29 12.72,5.58L12.69,5.8L11,9H21M2,18V10H5V18H2Z\";\r\nvar mdiHandPointingUp = \"M14,3V13L17.2,11.31L17.42,11.28C17.71,11.28 17.97,11.4 18.16,11.6L18.9,12.37L14,16.57C13.74,16.84 13.39,17 13,17H6.5C5.73,17 5,16.3 5,15.5V11.14C5,10.53 5.35,10 5.85,9.8L10.79,7.6L12,7.47V3A1,1 0 0,1 13,2A1,1 0 0,1 14,3M5,19H13V22H5V19Z\";\r\nvar mdiHandRight = \"M21,6.58V18.67A3.33,3.33 0 0,1 17.67,22H11.58C10.68,22 9.83,21.64 9.21,21L2.67,14.36C2.67,14.36 3.72,13.33 3.75,13.32C3.93,13.16 4.16,13.07 4.41,13.07C4.59,13.07 4.76,13.12 4.91,13.21C4.94,13.22 8.5,15.26 8.5,15.26V5.33A1.25,1.25 0 0,1 9.75,4.08A1.25,1.25 0 0,1 11,5.33V11.17H11.83V3.25A1.25,1.25 0 0,1 13.08,2C13.78,2 14.33,2.56 14.33,3.25V11.17H15.17V4.08C15.17,3.39 15.72,2.83 16.42,2.83A1.25,1.25 0 0,1 17.67,4.08V11.17H18.5V6.58A1.25,1.25 0 0,1 19.75,5.33A1.25,1.25 0 0,1 21,6.58Z\";\r\nvar mdiHandSaw = \"M9.8,17L5.9,11.6L20,2L22,5V8H19V11H16V14H13V17M9.7,18.7L9.2,21.5L7.6,22.7C6.7,23.3 5.5,23.1 4.8,22.2L1.3,17.3C0.7,16.4 0.9,15.2 1.8,14.5L5.1,12.2L9.7,18.7M4.6,15L3,16.1L6.5,21L8.1,19.8L4.6,15Z\";\r\nvar mdiHandWash = \"M17 5L17.62 6.37L19 7L17.62 7.63L17 9L16.36 7.63L15 7L16.36 6.37L17 5M11 6.13V4H13C13.57 4 14.1 4.17 14.55 4.45L16 3C15.15 2.39 14.13 2 13 2H7.5V4H9V6.14C7.23 6.5 5.81 7.8 5.26 9.5H9.24L15 11.65V11.03C15 8.61 13.28 6.59 11 6.13M1 22H5V11H1V22M20 17H13L10.91 16.27L11.24 15.33L13 16H15.82C16.47 16 17 15.47 17 14.82C17 14.33 16.69 13.89 16.23 13.71L8.97 11H7V20L14 22L22 19C22 17.9 21.11 17 20 17M20 14C21.1 14 22 13.1 22 12S20 8 20 8 18 10.9 18 12 18.9 14 20 14Z\";\r\nvar mdiHandWashOutline = \"M17 5L17.62 6.37L19 7L17.62 7.63L17 9L16.36 7.63L15 7L16.36 6.37L17 5M20 14C21.1 14 22 13.1 22 12S20 8 20 8 18 10.9 18 12 18.9 14 20 14M11 6.1V4H13C13.57 4 14.1 4.17 14.55 4.45L16 3C15.15 2.39 14.13 2 13 2H7.5V4H9V6.11C7.22 6.5 5.8 7.79 5.25 9.5H7.41C7.94 8.61 8.89 8 10 8C11.62 8 12.94 9.29 13 10.9L15 11.65V11C15 8.58 13.28 6.56 11 6.1M22 19V20L14 22.5L7 20.56V22H1V11H8.97L15.13 13.3C16.25 13.72 17 14.8 17 16H19C20.66 16 22 17.34 22 19M5 20V13H3V20H5M19.9 18.57C19.74 18.24 19.39 18 19 18H13.65C13.11 18 12.58 17.92 12.07 17.75L9.69 16.96L10.32 15.06L12.7 15.85C13 15.95 15 16 15 16C15 15.63 14.77 15.3 14.43 15.17L8.61 13H7V18.5L13.97 20.41L19.9 18.57Z\";\r\nvar mdiHandWater = \"M17.42 22.5H5.33C3.5 22.5 2 21 2 19.17V13.08C2 12.18 2.36 11.33 3 10.71L8.63 5.17C8.63 5.17 9.66 6.22 9.67 6.25C9.83 6.43 9.92 6.66 9.92 6.91C9.92 7.09 9.87 7.26 9.78 7.41C9.77 7.44 8 10 8 10H18.67C19.36 10 19.92 10.56 19.92 11.25C19.92 11.94 19.36 12.5 18.67 12.5H12.83V13.33H20.75C21.44 13.33 22 13.89 22 14.58C22 15.28 21.44 15.83 20.75 15.83H12.83V16.67H19.92C20.61 16.67 21.17 17.22 21.17 17.92C21.17 18.61 20.61 19.17 19.92 19.17H12.83V20H17.42C18.11 20 18.67 20.56 18.67 21.25C18.67 21.94 18.11 22.5 17.42 22.5M13.5 4.8C13.5 4.8 12 6.46 12 7.5C12 9.5 15 9.5 15 7.5C15 6.46 13.5 4.8 13.5 4.8M18.5 1C18.5 1 16 3.76 16 5.5C16 8.83 21 8.83 21 5.5C21 3.76 18.5 1 18.5 1Z\";\r\nvar mdiHandball = \"M15.83 10.43A6.93 6.93 0 0 1 18.39 14.86A6.64 6.64 0 0 1 17.5 19.5L15.78 18.5A5 5 0 0 0 16.44 16A5.22 5.22 0 0 0 15.46 13.06L9.18 23.93L7.44 22.95L10.44 17.75L8.71 16.76L7.21 19.34L5.5 18.36L10.63 9.45A7 7 0 0 1 8.8 5.46A6.91 6.91 0 0 1 9.69 1.1L11.43 2.13A4.84 4.84 0 0 0 10.91 5.9A4.74 4.74 0 0 0 13.21 8.93M16 5A2 2 0 1 0 18 7A2 2 0 0 0 16 5M13.5 1A1.5 1.5 0 1 0 15 2.5A1.5 1.5 0 0 0 13.5 1Z\";\r\nvar mdiHandcuffs = \"M20.24 6.76C18.4 4.91 15.65 4.53 13.42 5.59L12.46 4.63C12.07 4.24 11.44 4.24 11.05 4.63L10.97 4.72C10.83 3.75 10 3 9 3C7.9 3 7 3.9 7 5C7 5.09 7 5.18 7.03 5.26C6.42 5.61 6 6.25 6 7C6 7.46 6.16 7.87 6.42 8.21C6.17 8.39 6 8.67 6 9V10.35C3.67 11.17 2 13.39 2 16C2 19.31 4.69 22 8 22S14 19.31 14 16C14 13.39 12.33 11.17 10 10.35V9C10 8.67 9.83 8.39 9.58 8.21C9.84 7.87 10 7.46 10 7C10 6.91 10 6.82 9.97 6.74C10.15 6.64 10.3 6.5 10.43 6.38C11.36 6.88 12 7.86 12 9V9.08C12.13 9.15 12.25 9.25 12.38 9.33C12.57 8.91 12.83 8.5 13.17 8.17C14.73 6.61 17.27 6.61 18.83 8.17C20.39 9.73 20.39 12.27 18.83 13.83C18.03 14.63 17 15 15.93 15C16 15.32 16 15.66 16 16C16 16.34 15.97 16.67 15.93 17C17.5 17 19.05 16.43 20.24 15.24C22.59 12.9 22.59 9.1 20.24 6.76M9 4C9.55 4 10 4.45 10 5C10 5.33 9.83 5.61 9.58 5.79C9.22 5.31 8.65 5 8 5C8 4.45 8.45 4 9 4M7.42 6.21C7.78 6.69 8.35 7 9 7C9 7.55 8.55 8 8 8S7 7.55 7 7C7 6.67 7.17 6.39 7.42 6.21M12 16C12 18.21 10.21 20 8 20S4 18.21 4 16C4 13.79 5.79 12 8 12S12 13.79 12 16Z\";\r\nvar mdiHandshake = \"M11 6H14L17.29 2.7A1 1 0 0 1 18.71 2.7L21.29 5.29A1 1 0 0 1 21.29 6.7L19 9H11V11A1 1 0 0 1 10 12A1 1 0 0 1 9 11V8A2 2 0 0 1 11 6M5 11V15L2.71 17.29A1 1 0 0 0 2.71 18.7L5.29 21.29A1 1 0 0 0 6.71 21.29L11 17H15A1 1 0 0 0 16 16V15H17A1 1 0 0 0 18 14V13H19A1 1 0 0 0 20 12V11H13V12A2 2 0 0 1 11 14H9A2 2 0 0 1 7 12V9Z\";\r\nvar mdiHandshakeOutline = \"M21.71 8.71C22.96 7.46 22.39 6 21.71 5.29L18.71 2.29C17.45 1.04 16 1.61 15.29 2.29L13.59 4H11C9.1 4 8 5 7.44 6.15L3 10.59V14.59L2.29 15.29C1.04 16.55 1.61 18 2.29 18.71L5.29 21.71C5.83 22.25 6.41 22.45 6.96 22.45C7.67 22.45 8.32 22.1 8.71 21.71L11.41 19H15C16.7 19 17.56 17.94 17.87 16.9C19 16.6 19.62 15.74 19.87 14.9C21.42 14.5 22 13.03 22 12V9H21.41L21.71 8.71M20 12C20 12.45 19.81 13 19 13L18 13L18 14C18 14.45 17.81 15 17 15L16 15L16 16C16 16.45 15.81 17 15 17H10.59L7.31 20.28C7 20.57 6.82 20.4 6.71 20.29L3.72 17.31C3.43 17 3.6 16.82 3.71 16.71L5 15.41V11.41L7 9.41V11C7 12.21 7.8 14 10 14S13 12.21 13 11H20V12M20.29 7.29L18.59 9H11V11C11 11.45 10.81 12 10 12S9 11.45 9 11V8C9 7.54 9.17 6 11 6H14.41L16.69 3.72C17 3.43 17.18 3.6 17.29 3.71L20.28 6.69C20.57 7 20.4 7.18 20.29 7.29Z\";\r\nvar mdiHanger = \"M12 4A3.5 3.5 0 0 0 8.5 7.5H10.5A1.5 1.5 0 0 1 12 6A1.5 1.5 0 0 1 13.5 7.5A1.5 1.5 0 0 1 12 9C11.45 9 11 9.45 11 10V11.75L2.4 18.2A1 1 0 0 0 3 20H21A1 1 0 0 0 21.6 18.2L13 11.75V10.85A3.5 3.5 0 0 0 15.5 7.5A3.5 3.5 0 0 0 12 4M12 13.5L18 18H6Z\";\r\nvar mdiHardHat = \"M9.87,12.15L9,6.46C10.95,5.84 13.05,5.84 15,6.46L14.13,12.15C14.06,12.64 13.63,13 13.13,13H10.86C10.37,13 9.94,12.64 9.87,12.15M22,16V16C22,15.21 21.53,14.5 20.8,14.17C20.32,11.86 18.96,9.83 17,8.5L15.24,13.34C15.1,13.74 14.72,14 14.3,14H9.7C9.28,14 8.9,13.74 8.76,13.34L7,8.5C5.04,9.83 3.68,11.86 3.2,14.16C2.47,14.5 2,15.2 2,16L8.45,17.84C8.81,17.94 9.18,18 9.55,18H14.43C14.8,18 15.17,17.94 15.53,17.84L22,16Z\";\r\nvar mdiHarddisk = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M12,4A6,6 0 0,0 6,10C6,13.31 8.69,16 12.1,16L11.22,13.77C10.95,13.29 11.11,12.68 11.59,12.4L12.45,11.9C12.93,11.63 13.54,11.79 13.82,12.27L15.74,14.69C17.12,13.59 18,11.9 18,10A6,6 0 0,0 12,4M12,9A1,1 0 0,1 13,10A1,1 0 0,1 12,11A1,1 0 0,1 11,10A1,1 0 0,1 12,9M7,18A1,1 0 0,0 6,19A1,1 0 0,0 7,20A1,1 0 0,0 8,19A1,1 0 0,0 7,18M12.09,13.27L14.58,19.58L17.17,18.08L12.95,12.77L12.09,13.27Z\";\r\nvar mdiHarddiskPlus = \"M12 9A1 1 0 1 0 13 10A1 1 0 0 0 12 9M12 9A1 1 0 1 0 13 10A1 1 0 0 0 12 9M18 2H6A2 2 0 0 0 4 4V13.09A5.47 5.47 0 0 1 5 13A5.71 5.71 0 0 1 7 13.36A6 6 0 1 1 15.71 14.69L13.79 12.27A1 1 0 0 0 12.42 11.9L11.56 12.4A1 1 0 0 0 11.19 13.77L12.1 16A6.12 6.12 0 0 1 10 15.62A6 6 0 0 1 10.19 22H18A2 2 0 0 0 20 20V4A2 2 0 0 0 18 2M14.58 19.58L12.09 13.27L12.95 12.77L17.17 18.08M12 11A1 1 0 1 0 11 10A1 1 0 0 0 12 11M9 20H6V23H4V20H1V18H4V15H6V18H9Z\";\r\nvar mdiHarddiskRemove = \"M12 9A1 1 0 1 0 13 10A1 1 0 0 0 12 9M12 9A1 1 0 1 0 13 10A1 1 0 0 0 12 9M18 2H6A2 2 0 0 0 4 4V13.09A5.47 5.47 0 0 1 5 13A5.71 5.71 0 0 1 7 13.36A6 6 0 1 1 15.71 14.69L13.79 12.27A1 1 0 0 0 12.42 11.9L11.56 12.4A1 1 0 0 0 11.19 13.77L12.1 16A6.12 6.12 0 0 1 10 15.62A6 6 0 0 1 10.19 22H18A2 2 0 0 0 20 20V4A2 2 0 0 0 18 2M14.58 19.58L12.09 13.27L12.95 12.77L17.17 18.08M12 11A1 1 0 1 0 11 10A1 1 0 0 0 12 11M7.12 22.54L5 20.41L2.88 22.54L1.46 21.12L3.59 19L1.46 16.88L2.88 15.46L5 17.59L7.12 15.46L8.54 16.88L6.41 19L8.54 21.12Z\";\r\nvar mdiHatFedora = \"M19.11,11.92C19.13,11.71 19.14,11.5 19.14,11.29C19.14,7.86 17.71,4.14 16.28,4.14C14.85,4.14 13.42,5.57 12,5.57C10.57,5.57 9.14,4.14 7.71,4.14C6.28,4.14 4.86,7.79 4.86,11.29C4.86,11.5 4.86,11.71 4.88,11.92C7.22,12.45 9.6,12.72 12,12.71C14.45,12.71 16.83,12.44 19.11,11.92M3.45,18.18C9,19.85 14.96,19.86 20.54,18.18C20.96,18.04 21.33,17.77 21.59,17.41C21.85,17.05 22,16.61 22,16.17C22,15.72 21.86,15.29 21.61,14.92C21.35,14.56 21,14.29 20.56,14.14C17.86,15 15,15.45 12,15.45C9,15.45 6.13,15 3.43,14.14C3,14.29 2.65,14.57 2.39,14.93C2.14,15.29 2,15.72 2,16.17C2,17.11 2.61,17.9 3.45,18.18V18.18Z\";\r\nvar mdiHazardLights = \"M12,12L14.33,16H9.68L12,12M12,8L6.21,18H17.8L12,8M12,2L1,21H23L12,2M12,6L19.53,19H4.47L12,6Z\";\r\nvar mdiHdr = \"M21,11.5V10.5C21,9.7 20.3,9 19.5,9H16V15H17.5V13H18.6L19.5,15H21L20.1,12.9C20.6,12.6 21,12.1 21,11.5M19.5,11.5H17.5V10.5H19.5V11.5M6.5,11H4.5V9H3V15H4.5V12.5H6.5V15H8V9H6.5V11M13,9H9.5V15H13C13.8,15 14.5,14.3 14.5,13.5V10.5C14.5,9.7 13.8,9 13,9M13,13.5H11V10.5H13V13.5Z\";\r\nvar mdiHdrOff = \"M17.5,15V13H18.6L19.5,15H21L20.1,12.9C20.6,12.7 21,12.1 21,11.5V10.5C21,9.7 20.3,9 19.5,9H16V13.9L17.1,15H17.5M17.5,10.5H19.5V11.5H17.5V10.5M13,10.5V10.9L14.5,12.4V10.5C14.5,9.7 13.8,9 13,9H11.1L12.6,10.5H13M9.5,9.5L2.5,2.5L1.4,3.5L6.9,9H6.5V11H4.5V9H3V15H4.5V12.5H6.5V15H8V10.1L9.5,11.6V15H12.9L20.5,22.6L21.6,21.5L9.5,9.5Z\";\r\nvar mdiHead = \"M13 3C9.2 3 6.2 5.9 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3\";\r\nvar mdiHeadAlert = \"M13 3C9.2 3 6.2 5.9 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3M14 15H12V13H14V14M14 11H12V5H14V11Z\";\r\nvar mdiHeadAlertOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.8 1.9 12.8 2.3 13.6C2.7 14.3 3.3 14.8 4 14.9V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.8 22 13.1 22 10C22 5 18 1 13 1M14 15H12V13H14V15M14 11H12V5H14\";\r\nvar mdiHeadCheck = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M12.47 13L9 9.5L10.4 8.09L12.47 10.17L16.6 6L18 7.41L12.47 13Z\";\r\nvar mdiHeadCheckOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M13 1C8.42 1 4.61 4.43 4.06 8.91L2.5 11C1.92 11.72 1.82 12.72 2.24 13.59C2.6 14.31 3.24 14.8 4 14.95V16C4 17.86 5.28 19.43 7 19.87V23H18V17.47C20.5 15.83 22 13.06 22 10C22 5.04 17.96 1 13 1M12.47 13L9 9.5L10.4 8.09L12.47 10.17L16.6 6L18 7.41L12.47 13Z\";\r\nvar mdiHeadCog = \"M13 8.58C13.78 8.58 14.44 9.19 14.44 10S13.78 11.44 13 11.44 11.58 10.78 11.58 10 12.19 8.58 13 8.58M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M16 10C16 9.84 16 9.75 15.94 9.61L16.83 8.95C16.88 8.91 16.92 8.77 16.88 8.67L16.08 7.31C16.03 7.22 15.89 7.17 15.8 7.22L14.81 7.64C14.63 7.45 14.39 7.31 14.16 7.22L14 6.19C13.97 6.05 13.92 6 13.78 6H12.19C12.09 6 12 6.05 12 6.19L11.86 7.22C11.63 7.31 11.39 7.45 11.2 7.64L10.17 7.22C10.08 7.17 10 7.22 9.94 7.31L9.14 8.67C9.09 8.81 9.09 8.91 9.19 8.95L10.03 9.61C10.03 9.75 10 9.89 10 10C10 10.13 10.03 10.27 10.03 10.41L9.19 11.06C9.09 11.11 9.09 11.2 9.14 11.3L9.94 12.7C10 12.8 10.08 12.8 10.17 12.8L11.16 12.37C11.39 12.56 11.58 12.66 11.86 12.75L12 13.83C12 13.92 12.09 14 12.19 14H13.78C13.92 14 13.97 13.92 14 13.83L14.16 12.75C14.39 12.66 14.63 12.56 14.81 12.38L15.8 12.8C15.89 12.8 16.03 12.8 16.08 12.7L16.88 11.3C16.92 11.2 16.88 11.11 16.83 11.06L16 10.41V10Z\";\r\nvar mdiHeadCogOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M13 1C8.42 1 4.61 4.43 4.06 8.91L2.5 11C1.92 11.72 1.82 12.72 2.24 13.59C2.6 14.31 3.24 14.8 4 14.95V16C4 17.86 5.28 19.43 7 19.87V23H18V17.47C20.5 15.83 22 13.06 22 10C22 5.04 17.96 1 13 1M16.1 9.42V9C16.1 8.85 16.1 8.76 16.04 8.62L16.93 7.96C17 7.92 17 7.78 17 7.68L16.18 6.32C16.13 6.23 16 6.18 15.9 6.23L14.91 6.65C14.73 6.46 14.5 6.32 14.26 6.23L14.1 5.2C14.07 5.06 14 5 13.88 5H12.29C12.19 5 12.1 5.06 12.1 5.2L11.96 6.23C11.73 6.32 11.5 6.46 11.3 6.65L10.27 6.23C10.18 6.18 10.1 6.23 10.04 6.32L9.24 7.68C9.19 7.82 9.19 7.92 9.29 7.96L10.13 8.62C10.13 8.76 10.1 8.9 10.1 9C10.1 9.14 10.13 9.28 10.13 9.42L9.29 10.07C9.19 10.12 9.19 10.21 9.24 10.31L10.04 11.71C10.1 11.81 10.18 11.81 10.27 11.81L11.26 11.38C11.5 11.57 11.68 11.67 11.96 11.76L12.1 12.84C12.1 12.93 12.19 13 12.29 13H13.88C14 13 14.07 12.93 14.1 12.84L14.26 11.76C14.5 11.67 14.73 11.57 14.91 11.39L15.9 11.81C16 11.81 16.13 11.81 16.18 11.71L17 10.31C17 10.21 17 10.12 16.93 10.07L16.1 9.42M13.1 10.45C12.32 10.45 11.68 9.79 11.68 9S12.29 7.59 13.1 7.59C13.88 7.59 14.54 8.2 14.54 9S13.88 10.45 13.1 10.45Z\";\r\nvar mdiHeadDotsHorizontal = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M10 11C9.45 11 9 10.55 9 10S9.45 9 10 9 11 9.45 11 10 10.55 11 10 11M13 11C12.45 11 12 10.55 12 10S12.45 9 13 9 14 9.45 14 10 13.55 11 13 11M16 11C15.45 11 15 10.55 15 10S15.45 9 16 9 17 9.45 17 10 16.55 11 16 11Z\";\r\nvar mdiHeadDotsHorizontalOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.8 1.9 12.8 2.3 13.6C2.7 14.3 3.3 14.8 4 14.9V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.8 22 13.1 22 10C22 5 18 1 13 1M10 10C9.4 10 9 9.6 9 9S9.4 8 10 8 11 8.4 11 9 10.6 10 10 10M13 10C12.4 10 12 9.6 12 9S12.4 8 13 8 14 8.4 14 9 13.6 10 13 10M16 10C15.5 10 15 9.6 15 9S15.5 8 16 8 17 8.4 17 9 16.5 10 16 10Z\";\r\nvar mdiHeadFlash = \"M13 3C9.2 3 6.2 6 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3M15 9L11.9 15L12.5 11H10.5L12.5 6H15L13.5 9H15Z\";\r\nvar mdiHeadFlashOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.8 1.9 12.8 2.3 13.6C2.7 14.3 3.3 14.8 4 14.9V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.8 22 13.1 22 10C22 5 18 1 13 1M15 9L11.9 15L12.5 11H10.4L12.5 6H15L13.5 9H15Z\";\r\nvar mdiHeadHeart = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M17 8.83C17 10.37 15.64 11.6 13.58 13.47L13 14L12.42 13.47C10.36 11.6 9 10.37 9 8.83C9 7.63 9.96 6.64 11.16 6.63H11.2C11.89 6.63 12.55 6.94 13 7.46C13.45 6.94 14.11 6.63 14.8 6.63C16 6.62 17 7.59 17 8.79V8.83Z\";\r\nvar mdiHeadHeartOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M13 1C8.41 1 4.61 4.42 4.06 8.9L2.5 11L2.47 11L2.45 11.03C1.9 11.79 1.83 12.79 2.26 13.62C2.62 14.31 3.26 14.79 4 14.94V16C4 17.85 5.28 19.42 7 19.87V23H18V17.5C20.5 15.83 22 13.06 22 10C22 5.03 17.96 1 13 1M17 8.83C17 10.37 15.64 11.6 13.58 13.47L13 14L12.42 13.47C10.36 11.6 9 10.37 9 8.83C9 7.63 9.96 6.64 11.16 6.63H11.2C11.89 6.63 12.55 6.94 13 7.46C13.45 6.94 14.11 6.63 14.8 6.63C16 6.62 17 7.59 17 8.79V8.83Z\";\r\nvar mdiHeadLightbulb = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M14 14H12V13H14V14M15.6 9.5C15.34 9.94 14.96 10.32 14.5 10.58V12H11.5V10.58C10.07 9.75 9.57 7.92 10.4 6.5S13.07 4.56 14.5 5.38 16.43 8.05 15.6 9.5Z\";\r\nvar mdiHeadLightbulbOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.8 1.9 12.8 2.3 13.6C2.7 14.3 3.3 14.8 4 14.9V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.8 22 13.1 22 10C22 5 18 1 13 1M14 14H12V13H14V14M15.6 9.5C15.3 9.9 15 10.3 14.5 10.6V12H11.5V10.6C10.1 9.8 9.6 7.9 10.4 6.5S13.1 4.6 14.5 5.4 16.4 8.1 15.6 9.5Z\";\r\nvar mdiHeadMinus = \"M13 3C9.2 3 6.2 5.9 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3M17 10H9V8H17V10Z\";\r\nvar mdiHeadMinusOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.7 1.8 12.7 2.2 13.6C2.6 14.3 3.2 14.8 4 15V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.9 22 13.1 22 10C22 5 18 1 13 1M17 10H9V8H17V10Z\";\r\nvar mdiHeadOutline = \"M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C2 11.8 1.9 12.8 2.3 13.6C2.7 14.3 3.3 14.8 4 14.9V16C4 17.8 5.3 19.4 7 19.9V23H18V17.5C20.5 15.8 22 13.1 22 10C22 5 18 1 13 1M16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 6 9.2 3 13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3Z\";\r\nvar mdiHeadPlus = \"M13 3C9.2 3 6.2 5.9 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3M17 10H14V13H12V10H9V8H12V5H14V8H17V10Z\";\r\nvar mdiHeadPlusOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.7 1.8 12.7 2.2 13.6C2.6 14.3 3.2 14.8 4 15V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.9 22 13.1 22 10C22 5 18 1 13 1M17 10H14V13H12V10H9V8H12V5H14V8H17V10Z\";\r\nvar mdiHeadQuestion = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M14 14H12V12H14V14M15.75 8.81C15.46 9.21 15.09 9.5 14.64 9.74C14.39 9.9 14.22 10.07 14.13 10.26C14.04 10.44 14 10.69 14 11H12C12 10.5 12.11 10.08 12.31 9.82C12.5 9.55 12.85 9.25 13.36 8.91C13.62 8.75 13.83 8.55 13.97 8.32C14.13 8.09 14.2 7.82 14.2 7.5C14.2 7.2 14.12 6.94 13.94 6.75C13.76 6.57 13.5 6.47 13.19 6.47C12.93 6.47 12.71 6.55 12.53 6.7C12.35 6.86 12.26 7.09 12.25 7.39H10.32L10.31 7.36C10.3 6.57 10.56 6 11.08 5.59C11.62 5.2 12.32 5 13.19 5C14.12 5 14.85 5.23 15.38 5.68C15.92 6.13 16.19 6.74 16.19 7.5C16.19 8 16.04 8.41 15.75 8.81Z\";\r\nvar mdiHeadQuestionOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M10.32 7.39H12.25C12.26 7.09 12.35 6.86 12.53 6.7C12.71 6.55 12.93 6.47 13.19 6.47C13.5 6.47 13.76 6.57 13.94 6.75C14.12 6.94 14.2 7.2 14.2 7.5C14.2 7.82 14.13 8.09 13.97 8.32C13.83 8.55 13.62 8.75 13.36 8.91C12.85 9.25 12.5 9.55 12.31 9.82C12.11 10.08 12 10.5 12 11H14C14 10.69 14.04 10.44 14.13 10.26C14.22 10.07 14.39 9.9 14.64 9.74C15.09 9.5 15.46 9.21 15.75 8.81C16.04 8.41 16.19 8 16.19 7.5C16.19 6.74 15.92 6.13 15.38 5.68C14.85 5.23 14.12 5 13.19 5C12.32 5 11.62 5.2 11.08 5.59C10.56 6 10.3 6.57 10.31 7.36L10.32 7.39M12 14H14V12H12V14M13 1C8.41 1 4.61 4.42 4.06 8.9L2.5 11L2.47 11L2.45 11.03C1.9 11.79 1.83 12.79 2.26 13.62C2.62 14.31 3.26 14.79 4 14.94V16C4 17.85 5.28 19.42 7 19.87V23H18V17.5C20.5 15.83 22 13.06 22 10C22 5.03 17.96 1 13 1Z\";\r\nvar mdiHeadRemove = \"M13 3C9.2 3 6.2 5.9 6 9.7L4.1 12.2C3.9 12.5 4.1 13 4.5 13H6V16C6 17.1 6.9 18 8 18H9V21H16V16.3C18.4 15.2 20 12.8 20 10C20 6.1 16.9 3 13 3M15.1 12.5L13 10.4L10.9 12.5L9.5 11.1L11.6 9L9.5 6.9L10.9 5.5L13 7.6L15.1 5.5L16.5 6.9L14.4 9L16.5 11.1L15.1 12.5Z\";\r\nvar mdiHeadRemoveOutline = \"M13 3C16.9 3 20 6.1 20 10C20 12.8 18.4 15.2 16 16.3V21H9V18H8C6.9 18 6 17.1 6 16V13H4.5C4.1 13 3.8 12.5 4.1 12.2L6 9.7C6.2 5.9 9.2 3 13 3M13 1C8.4 1 4.6 4.4 4.1 8.9L2.5 11C1.9 11.7 1.8 12.7 2.2 13.6C2.6 14.3 3.2 14.8 4 15V16C4 17.9 5.3 19.4 7 19.9V23H18V17.5C20.5 15.9 22 13.1 22 10C22 5 18 1 13 1M16.5 6.9L14.4 9L16.5 11.1L15.1 12.5L13 10.4L10.9 12.5L9.5 11.1L11.6 9L9.5 6.9L10.9 5.5L13 7.6L15.1 5.5L16.5 6.9Z\";\r\nvar mdiHeadSnowflake = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M17.06 9.57L15.1 10.09L16.54 11.54C16.89 11.88 16.89 12.46 16.54 12.81C16.19 13.16 15.61 13.16 15.27 12.81L13.81 11.37L13.3 13.33C13.18 13.82 12.68 14.1 12.21 13.97C11.72 13.84 11.44 13.35 11.57 12.87L12.1 10.9L10.13 11.43C9.65 11.56 9.15 11.28 9.03 10.79C8.9 10.32 9.18 9.82 9.67 9.7L11.63 9.19L10.19 7.73C9.84 7.39 9.84 6.82 10.19 6.46C10.54 6.11 11.12 6.11 11.46 6.46L12.91 7.9L13.43 5.94C13.55 5.46 14.04 5.18 14.5 5.3C15 5.43 15.28 5.92 15.16 6.41L14.63 8.37L16.59 7.84C17.08 7.72 17.57 8 17.7 8.5C17.82 8.96 17.54 9.45 17.06 9.57Z\";\r\nvar mdiHeadSnowflakeOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M13 1C8.41 1 4.61 4.42 4.06 8.9L2.5 11L2.47 11L2.45 11.03C1.9 11.79 1.83 12.79 2.26 13.62C2.62 14.31 3.26 14.79 4 14.94V16C4 17.85 5.28 19.42 7 19.87V23H18V17.5C20.5 15.83 22 13.06 22 10C22 5.03 17.96 1 13 1M17.33 9.3L15.37 9.81L16.81 11.27C17.16 11.61 17.16 12.19 16.81 12.54S15.88 12.89 15.54 12.54L14.09 11.1L13.57 13.06C13.45 13.55 12.96 13.82 12.5 13.7C12 13.57 11.72 13.08 11.84 12.59L12.37 10.63L10.41 11.16C9.92 11.28 9.43 11 9.3 10.5C9.18 10.05 9.46 9.55 9.94 9.43L11.9 8.91L10.46 7.46C10.11 7.12 10.11 6.55 10.46 6.19C10.81 5.84 11.39 5.84 11.73 6.19L13.19 7.63L13.7 5.67C13.82 5.18 14.32 4.9 14.79 5.03C15.28 5.16 15.56 5.65 15.43 6.13L14.9 8.1L16.87 7.57C17.35 7.44 17.84 7.72 17.97 8.21C18.1 8.68 17.82 9.18 17.33 9.3Z\";\r\nvar mdiHeadSync = \"M13 3C9.23 3 6.19 5.95 6 9.66L4.08 12.19C3.84 12.5 4.08 13 4.5 13H6V16C6 17.11 6.89 18 8 18H9V21H16V16.31C18.37 15.19 20 12.8 20 10C20 6.14 16.88 3 13 3M13 15V13.5C10.79 13.5 9 11.71 9 9.5C9 8.68 9.25 7.92 9.67 7.29L10.76 8.38C10.59 8.72 10.5 9.1 10.5 9.5C10.5 10.88 11.62 12 13 12V10.5L15.25 12.75L13 15M16.33 11.71L15.24 10.62C15.41 10.28 15.5 9.9 15.5 9.5C15.5 8.12 14.38 7 13 7V8.5L10.75 6.25L13 4V5.5C15.21 5.5 17 7.29 17 9.5C17 10.32 16.75 11.08 16.33 11.71Z\";\r\nvar mdiHeadSyncOutline = \"M13 3C16.88 3 20 6.14 20 10C20 12.8 18.37 15.19 16 16.31V21H9V18H8C6.89 18 6 17.11 6 16V13H4.5C4.08 13 3.84 12.5 4.08 12.19L6 9.66C6.19 5.95 9.23 3 13 3M13 1C8.41 1 4.61 4.42 4.06 8.9L2.5 11L2.47 11L2.45 11.03C1.9 11.79 1.83 12.79 2.26 13.62C2.62 14.31 3.26 14.79 4 14.94V16C4 17.85 5.28 19.42 7 19.87V23H18V17.5C20.5 15.83 22 13.06 22 10C22 5.03 17.96 1 13 1M14 15V13.5C11.79 13.5 10 11.71 10 9.5C10 8.68 10.25 7.92 10.67 7.29L11.76 8.38C11.59 8.72 11.5 9.1 11.5 9.5C11.5 10.88 12.62 12 14 12V10.5L16.25 12.75L14 15M17.33 11.71L16.24 10.62C16.41 10.28 16.5 9.9 16.5 9.5C16.5 8.12 15.38 7 14 7V8.5L11.75 6.25L14 4V5.5C16.21 5.5 18 7.29 18 9.5C18 10.32 17.75 11.08 17.33 11.71Z\";\r\nvar mdiHeadphones = \"M12,1C7,1 3,5 3,10V17A3,3 0 0,0 6,20H9V12H5V10A7,7 0 0,1 12,3A7,7 0 0,1 19,10V12H15V20H18A3,3 0 0,0 21,17V10C21,5 16.97,1 12,1Z\";\r\nvar mdiHeadphonesBluetooth = \"M8,6A6,6 0 0,0 2,12V16.8C2,17.46 2.54,18 3.2,18H6V14H4V12A4,4 0 0,1 8,8A4,4 0 0,1 12,12V14H10V18H12.8A1.2,1.2 0 0,0 14,16.8V12A6,6 0 0,0 8,6M19,7V10.79L16.71,8.5L16,9.21L18.79,12L16,14.79L16.71,15.5L19,13.21V17H19.5L22.35,14.14L20.21,12L22.35,9.85L19.5,7H19M20,8.91L20.94,9.85L20,10.79V8.91M20,13.21L20.94,14.14L20,15.08V13.21Z\";\r\nvar mdiHeadphonesBox = \"M7.2,18C6.54,18 6,17.46 6,16.8V13.2L6,12A6,6 0 0,1 12,6A6,6 0 0,1 18,12V13.2L18,16.8A1.2,1.2 0 0,1 16.8,18H14V14H16V12A4,4 0 0,0 12,8A4,4 0 0,0 8,12V14H10V18M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiHeadphonesOff = \"M12,1A9,9 0 0,1 21,10V17C21,17.62 20.81,18.19 20.5,18.67L15,13.18V12H19V10A7,7 0 0,0 12,3C10,3 8.23,3.82 6.96,5.14L5.55,3.72C7.18,2.04 9.47,1 12,1M2.78,3.5L20.5,21.22L19.23,22.5L16.73,20H15V18.27L9,12.27V20H6A3,3 0 0,1 3,17V10C3,8.89 3.2,7.82 3.57,6.84L1.5,4.77L2.78,3.5M5.17,8.44C5.06,8.94 5,9.46 5,10V12H8.73L5.17,8.44Z\";\r\nvar mdiHeadphonesSettings = \"M12,1A9,9 0 0,1 21,10V17A3,3 0 0,1 18,20H15V12H19V10A7,7 0 0,0 12,3A7,7 0 0,0 5,10V12H9V20H6A3,3 0 0,1 3,17V10A9,9 0 0,1 12,1M15,24V22H17V24H15M11,24V22H13V24H11M7,24V22H9V24H7Z\";\r\nvar mdiHeadset = \"M12,1C7,1 3,5 3,10V17A3,3 0 0,0 6,20H9V12H5V10A7,7 0 0,1 12,3A7,7 0 0,1 19,10V12H15V20H19V21H12V23H18A3,3 0 0,0 21,20V10C21,5 16.97,1 12,1Z\";\r\nvar mdiHeadsetDock = \"M2,18H9V6.13C7.27,6.57 6,8.14 6,10V11H8V17H6A2,2 0 0,1 4,15V10A6,6 0 0,1 10,4H11A6,6 0 0,1 17,10V12H18V9H20V12A2,2 0 0,1 18,14H17V15A2,2 0 0,1 15,17H13V11H15V10C15,8.14 13.73,6.57 12,6.13V18H22V20H2V18Z\";\r\nvar mdiHeadsetOff = \"M1.5,4.77L3.57,6.84C3.2,7.82 3,8.89 3,10V20A3,3 0 0,0 6,23H12V21H5V20H9V12.27L15,18.27V20H16.73L19.23,22.5L20.5,21.22L2.78,3.5L1.5,4.77M12,1C9.47,1 7.18,2.04 5.55,3.72L6.96,5.14C8.23,3.82 10,3 12,3A7,7 0 0,1 19,10V12H15V13.18L20.5,18.67C20.81,18.19 21,17.62 21,17V10A9,9 0 0,0 12,1M5,12V10C5,9.46 5.06,8.94 5.17,8.44L8.73,12H5Z\";\r\nvar mdiHeart = \"M12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C9.24,3 10.91,3.81 12,5.08C13.09,3.81 14.76,3 16.5,3C19.58,3 22,5.41 22,8.5C22,12.27 18.6,15.36 13.45,20.03L12,21.35Z\";\r\nvar mdiHeartBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M12,17L12.72,16.34C15.3,14 17,12.46 17,10.57C17,9.03 15.79,7.82 14.25,7.82C13.38,7.82 12.55,8.23 12,8.87C11.45,8.23 10.62,7.82 9.75,7.82C8.21,7.82 7,9.03 7,10.57C7,12.46 8.7,14 11.28,16.34L12,17Z\";\r\nvar mdiHeartBoxOutline = \"M12,17L11.28,16.34C8.7,14 7,12.46 7,10.57C7,9.03 8.21,7.82 9.75,7.82C10.62,7.82 11.45,8.23 12,8.87C12.55,8.23 13.38,7.82 14.25,7.82C15.79,7.82 17,9.03 17,10.57C17,12.46 15.3,14 12.72,16.34L12,17M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M5,5V19H19V5H5Z\";\r\nvar mdiHeartBroken = \"M12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C8.17,3 8.82,3.12 9.44,3.33L13,9.35L9,14.35L12,21.35V21.35M16.5,3C19.58,3 22,5.41 22,8.5C22,12.27 18.6,15.36 13.45,20.03L12,21.35L11,14.35L15.5,9.35L12.85,4.27C13.87,3.47 15.17,3 16.5,3Z\";\r\nvar mdiHeartBrokenOutline = \"M7.5,5C7.7,5 7.9,5 8.1,5.1L10.5,9.2L6.8,13.8C5.1,11.8 4,10.2 4,8.5C4,6.5 5.5,5 7.5,5M7.5,3C4.4,3 2,5.4 2,8.5C2,12.3 5.4,15.4 10.6,20L12,21.3L9,14.3L13,9.3L9.4,3.3C8.8,3.1 8.2,3 7.5,3M16.5,5C18.5,5 20,6.5 20,8.5C20,11.1 17.4,13.7 13.4,17.3L13.1,15L17.9,9.7L15.6,5.2C15.9,5 16.2,5 16.5,5M16.5,3C15.2,3 13.9,3.5 12.9,4.3L15.5,9.4L11,14.4L12,21.4L13.4,20.1C18.6,15.4 22,12.3 22,8.6C22,5.4 19.6,3 16.5,3Z\";\r\nvar mdiHeartCircle = \"M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M9.75,7.82C10.62,7.82 11.45,8.23 12,8.87C12.55,8.23 13.38,7.82 14.25,7.82C15.79,7.82 17,9.03 17,10.57C17,12.46 15.3,14 12.72,16.34L12,17L11.28,16.34C8.7,14 7,12.46 7,10.57C7,9.03 8.21,7.82 9.75,7.82Z\";\r\nvar mdiHeartCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M9.75,7.82C8.21,7.82 7,9.03 7,10.57C7,12.46 8.7,14 11.28,16.34L12,17L12.72,16.34C15.3,14 17,12.46 17,10.57C17,9.03 15.79,7.82 14.25,7.82C13.38,7.82 12.55,8.23 12,8.87C11.45,8.23 10.62,7.82 9.75,7.82Z\";\r\nvar mdiHeartFlash = \"M16.5,2.83C14.76,2.83 13.09,3.64 12,4.9C10.91,3.64 9.24,2.83 7.5,2.83C4.42,2.83 2,5.24 2,8.33C2,12.1 5.4,15.19 10.55,19.86L12,21.17L13.45,19.86C18.6,15.19 22,12.1 22,8.33C22,5.24 19.58,2.83 16.5,2.83M12,17.83V13.83H9L12,6.83V10.83H15\";\r\nvar mdiHeartHalf = \"M13,7.2V17.74L13,20.44L12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C10,3 13,5 13,7.2Z\";\r\nvar mdiHeartHalfFull = \"M16.5,5C15,5 13.58,5.91 13,7.2V17.74C17.25,13.87 20,11.2 20,8.5C20,6.5 18.5,5 16.5,5M16.5,3C19.58,3 22,5.41 22,8.5C22,12.27 18.6,15.36 13.45,20.03L12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C9.24,3 10.91,3.81 12,5.08C13.09,3.81 14.76,3 16.5,3Z\";\r\nvar mdiHeartHalfOutline = \"M4,8.5C4,11.2 6.75,13.87 11,17.74V7.2C10.42,5.91 9,5 7.5,5C5.5,5 4,6.5 4,8.5M13,7.2V17.74L13,20.44L12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,5.41 4.42,3 7.5,3C10,3 13,5 13,7.2Z\";\r\nvar mdiHeartMinus = \"M12 18C12 19 12.25 19.92 12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C19.83 12.23 18.94 12 18 12C14.69 12 12 14.69 12 18M14 17V19H22V17H14Z\";\r\nvar mdiHeartMinusOutline = \"M12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C20 12.31 19.31 12.11 18.59 12.04C19.5 10.8 20 9.65 20 8.5C20 6.5 18.5 5 16.5 5C14.96 5 13.46 6 12.93 7.36H11.07C10.54 6 9.04 5 7.5 5C5.5 5 4 6.5 4 8.5C4 11.39 7.14 14.24 11.89 18.55L12 18.65L12.04 18.61C12.12 19.37 12.34 20.09 12.67 20.74M14 17V19H22V17H14Z\";\r\nvar mdiHeartMultiple = \"M13.5,20C6.9,13.9 3.5,10.8 3.5,7.1C3.5,4 5.9,1.6 9,1.6C10.7,1.6 12.4,2.4 13.5,3.7C14.6,2.4 16.3,1.6 18,1.6C21.1,1.6 23.5,4 23.5,7.1C23.5,10.9 20.1,14 13.5,20M12,21.1C5.4,15.2 1.5,11.7 1.5,7C1.5,6.8 1.5,6.6 1.5,6.4C0.9,7.3 0.5,8.4 0.5,9.6C0.5,13.4 3.9,16.5 10.5,22.4L12,21.1Z\";\r\nvar mdiHeartMultipleOutline = \"M12,21.1L10.5,22.4C3.9,16.5 0.5,13.4 0.5,9.6C0.5,8.4 0.9,7.3 1.5,6.4C1.5,6.6 1.5,6.8 1.5,7C1.5,11.7 5.4,15.2 12,21.1M13.6,17C18.3,12.7 21.5,9.9 21.6,7C21.6,5 20.1,3.5 18.1,3.5C16.5,3.5 15,4.5 14.5,5.9H12.6C12,4.5 10.5,3.5 9,3.5C7,3.5 5.5,5 5.5,7C5.5,9.9 8.6,12.7 13.4,17L13.5,17.1M18,1.5C21.1,1.5 23.5,3.9 23.5,7C23.5,10.7 20.1,13.8 13.5,19.8C6.9,13.9 3.5,10.8 3.5,7C3.5,3.9 5.9,1.5 9,1.5C10.7,1.5 12.4,2.3 13.5,3.6C14.6,2.3 16.3,1.5 18,1.5Z\";\r\nvar mdiHeartOff = \"M1,4.27L2.28,3L20,20.72L18.73,22L15.18,18.44L13.45,20.03L12,21.35L10.55,20.03C5.4,15.36 2,12.27 2,8.5C2,7.55 2.23,6.67 2.63,5.9L1,4.27M7.5,3C9.24,3 10.91,3.81 12,5.08C13.09,3.81 14.76,3 16.5,3C19.58,3 22,5.41 22,8.5C22,11.07 20.42,13.32 17.79,15.97L5.27,3.45C5.95,3.16 6.7,3 7.5,3Z\";\r\nvar mdiHeartOffOutline = \"M2.39 1.73L1.11 3L3.19 5.08C2.45 6 2 7.19 2 8.5C2 12.27 5.4 15.36 10.55 20.03L12 21.35L13.45 20.03C14.32 19.24 15.14 18.5 15.9 17.79L20 22L21.27 20.73M12.1 18.55L12 18.65L11.89 18.55C7.14 14.24 4 11.39 4 8.5C4 7.74 4.22 7.06 4.61 6.5L14.5 16.37C13.74 17.06 12.95 17.78 12.1 18.55M8.3 5.1L6.33 3.13C6.7 3.05 7.1 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 10.84 20.69 12.92 18.47 15.27L17.06 13.86C18.91 11.88 20 10.2 20 8.5C20 6.5 18.5 5 16.5 5C15.1 5 13.74 5.83 13.11 7H10.89C10.38 6.06 9.39 5.34 8.3 5.1Z\";\r\nvar mdiHeartOutline = \"M12.1,18.55L12,18.65L11.89,18.55C7.14,14.24 4,11.39 4,8.5C4,6.5 5.5,5 7.5,5C9.04,5 10.54,6 11.07,7.36H12.93C13.46,6 14.96,5 16.5,5C18.5,5 20,6.5 20,8.5C20,11.39 16.86,14.24 12.1,18.55M16.5,3C14.76,3 13.09,3.81 12,5.08C10.91,3.81 9.24,3 7.5,3C4.42,3 2,5.41 2,8.5C2,12.27 5.4,15.36 10.55,20.03L12,21.35L13.45,20.03C18.6,15.36 22,12.27 22,8.5C22,5.41 19.58,3 16.5,3Z\";\r\nvar mdiHeartPlus = \"M12 18C12 19 12.25 19.92 12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C19.83 12.23 18.94 12 18 12C14.69 12 12 14.69 12 18M19 14H17V17H14V19H17V22H19V19H22V17H19V14Z\";\r\nvar mdiHeartPlusOutline = \"M12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C20 12.31 19.31 12.11 18.59 12.04C19.5 10.8 20 9.65 20 8.5C20 6.5 18.5 5 16.5 5C14.96 5 13.46 6 12.93 7.36H11.07C10.54 6 9.04 5 7.5 5C5.5 5 4 6.5 4 8.5C4 11.39 7.14 14.24 11.89 18.55L12 18.65L12.04 18.61C12.12 19.37 12.34 20.09 12.67 20.74M17 14V17H14V19H17V22H19V19H22V17H19V14H17Z\";\r\nvar mdiHeartPulse = \"M7.5,4A5.5,5.5 0 0,0 2,9.5C2,10 2.09,10.5 2.22,11H6.3L7.57,7.63C7.87,6.83 9.05,6.75 9.43,7.63L11.5,13L12.09,11.58C12.22,11.25 12.57,11 13,11H21.78C21.91,10.5 22,10 22,9.5A5.5,5.5 0 0,0 16.5,4C14.64,4 13,4.93 12,6.34C11,4.93 9.36,4 7.5,4V4M3,12.5A1,1 0 0,0 2,13.5A1,1 0 0,0 3,14.5H5.44L11,20C12,20.9 12,20.9 13,20L18.56,14.5H21A1,1 0 0,0 22,13.5A1,1 0 0,0 21,12.5H13.4L12.47,14.8C12.07,15.81 10.92,15.67 10.55,14.83L8.5,9.5L7.54,11.83C7.39,12.21 7.05,12.5 6.6,12.5H3Z\";\r\nvar mdiHeartRemove = \"M12 18C12 19 12.25 19.92 12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C19.83 12.23 18.94 12 18 12C14.69 12 12 14.69 12 18M21.54 15.88L20.12 14.47L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.54L18 19.41L20.12 21.54L21.54 20.12L19.41 18L21.54 15.88Z\";\r\nvar mdiHeartRemoveOutline = \"M12.67 20.74L12 21.35L10.55 20.03C5.4 15.36 2 12.27 2 8.5C2 5.41 4.42 3 7.5 3C9.24 3 10.91 3.81 12 5.08C13.09 3.81 14.76 3 16.5 3C19.58 3 22 5.41 22 8.5C22 9.93 21.5 11.26 20.62 12.61C20 12.31 19.31 12.11 18.59 12.04C19.5 10.8 20 9.65 20 8.5C20 6.5 18.5 5 16.5 5C14.96 5 13.46 6 12.93 7.36H11.07C10.54 6 9.04 5 7.5 5C5.5 5 4 6.5 4 8.5C4 11.39 7.14 14.24 11.89 18.55L12 18.65L12.04 18.61C12.12 19.37 12.34 20.09 12.67 20.74M20.12 14.46L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.54L18 19.41L20.12 21.54L21.54 20.12L19.41 18L21.54 15.88L20.12 14.46Z\";\r\nvar mdiHelicopter = \"M3,3H17V5H3V3M23,6V10.5L14.75,12.2C14.91,12.6 15,13.04 15,13.5C15,14.9 14.18,16.1 13,16.66V17L13,19H16V21H4A3,3 0 0,1 1,18V17H3V18A1,1 0 0,0 4,19H5V16.74C3.25,16.13 2,14.46 2,12.5C2,10 4,8 6.5,8H9V6H11V8H21V6H23M11,19V17H7V19H11M7.5,10C6.12,10 5,10.9 5,12C5,13.1 6.12,14 7.5,14C8.88,14 10,13.1 10,12C10,10.9 8.88,10 7.5,10Z\";\r\nvar mdiHelp = \"M10,19H13V22H10V19M12,2C17.35,2.22 19.68,7.62 16.5,11.67C15.67,12.67 14.33,13.33 13.67,14.17C13,15 13,16 13,17H10C10,15.33 10,13.92 10.67,12.92C11.33,11.92 12.67,11.33 13.5,10.67C15.92,8.43 15.32,5.26 12,5A3,3 0 0,0 9,8H6A6,6 0 0,1 12,2Z\";\r\nvar mdiHelpBox = \"M11,18H13V16H11V18M12,6A4,4 0 0,0 8,10H10A2,2 0 0,1 12,8A2,2 0 0,1 14,10C14,12 11,11.75 11,15H13C13,12.75 16,12.5 16,10A4,4 0 0,0 12,6M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3Z\";\r\nvar mdiHelpCircle = \"M15.07,11.25L14.17,12.17C13.45,12.89 13,13.5 13,15H11V14.5C11,13.39 11.45,12.39 12.17,11.67L13.41,10.41C13.78,10.05 14,9.55 14,9C14,7.89 13.1,7 12,7A2,2 0 0,0 10,9H8A4,4 0 0,1 12,5A4,4 0 0,1 16,9C16,9.88 15.64,10.67 15.07,11.25M13,19H11V17H13M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2Z\";\r\nvar mdiHelpCircleOutline = \"M11,18H13V16H11V18M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,6A4,4 0 0,0 8,10H10A2,2 0 0,1 12,8A2,2 0 0,1 14,10C14,12 11,11.75 11,15H13C13,12.75 16,12.5 16,10A4,4 0 0,0 12,6Z\";\r\nvar mdiHelpNetwork = \"M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17M12.19,5C11.32,5 10.62,5.2 10.08,5.59C9.56,6 9.3,6.57 9.31,7.36L9.32,7.39H11.25C11.26,7.09 11.35,6.86 11.53,6.7C11.71,6.55 11.93,6.47 12.19,6.47C12.5,6.47 12.76,6.57 12.94,6.75C13.12,6.94 13.2,7.2 13.2,7.5C13.2,7.82 13.13,8.09 12.97,8.32C12.83,8.55 12.62,8.75 12.36,8.91C11.85,9.25 11.5,9.55 11.31,9.82C11.11,10.08 11,10.5 11,11H13C13,10.69 13.04,10.44 13.13,10.26C13.22,10.07 13.39,9.9 13.64,9.74C14.09,9.5 14.46,9.21 14.75,8.81C15.04,8.41 15.19,8 15.19,7.5C15.19,6.74 14.92,6.13 14.38,5.68C13.85,5.23 13.12,5 12.19,5M11,12V14H13V12H11Z\";\r\nvar mdiHelpNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M11.95,6C11.17,6 10.55,6.18 10.07,6.5C9.61,6.89 9.38,7.4 9.39,8.1L9.4,8.13H11.11C11.12,7.86 11.2,7.65 11.36,7.5C11.5,7.38 11.72,7.31 11.95,7.31C12.22,7.31 12.45,7.4 12.61,7.56C12.77,7.73 12.85,7.96 12.85,8.22C12.85,8.5 12.78,8.75 12.64,8.95C12.5,9.16 12.33,9.33 12.1,9.5C11.65,9.78 11.34,10.05 11.17,10.29C11,10.5 10.89,10.89 10.89,11.33H12.67C12.67,11.06 12.7,10.84 12.78,10.68C12.86,10.5 13,10.36 13.24,10.21C13.64,10 13.97,9.74 14.22,9.39C14.5,9.03 14.62,8.67 14.62,8.22C14.62,7.55 14.38,7 13.9,6.61C13.42,6.2 12.77,6 11.95,6M10.89,12.22V14H12.67V12.22H10.89Z\";\r\nvar mdiHelpRhombus = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 6.95C14.7 7.06 15.87 9.78 14.28 11.81C13.86 12.31 13.19 12.64 12.85 13.07C12.5 13.5 12.5 14 12.5 14.5H11C11 13.65 11 12.94 11.35 12.44C11.68 11.94 12.35 11.64 12.77 11.31C14 10.18 13.68 8.59 12 8.46C11.18 8.46 10.5 9.13 10.5 9.97H9C9 8.3 10.35 6.95 12 6.95M11 15.5H12.5V17H11V15.5Z\";\r\nvar mdiHelpRhombusOutline = \"M11 15.5H12.5V17H11V15.5M12 6.95C14.7 7.06 15.87 9.78 14.28 11.81C13.86 12.31 13.19 12.64 12.85 13.07C12.5 13.5 12.5 14 12.5 14.5H11C11 13.65 11 12.94 11.35 12.44C11.68 11.94 12.35 11.64 12.77 11.31C14 10.18 13.68 8.59 12 8.46C11.18 8.46 10.5 9.13 10.5 9.97H9C9 8.3 10.35 6.95 12 6.95M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L20 12L12 20L4 12Z\";\r\nvar mdiHexadecimal = \"M7 7C5.9 7 5 7.9 5 9V15C5 16.11 5.9 17 7 17H9C10.11 17 11 16.11 11 15V9C11 7.9 10.11 7 9 7H7M7 9H9V15H7V9M17.6 17L15.5 14.9L13.4 17L12 15.6L14.1 13.5L12 11.4L13.4 10L15.5 12.1L17.6 10L19 11.4L16.9 13.5L19 15.6L17.6 17Z\";\r\nvar mdiHexagon = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5Z\";\r\nvar mdiHexagonMultiple = \"M10.25,2C10.44,2 10.61,2.11 10.69,2.26L12.91,6.22L13,6.5L12.91,6.78L10.69,10.74C10.61,10.89 10.44,11 10.25,11H5.75C5.56,11 5.39,10.89 5.31,10.74L3.09,6.78L3,6.5L3.09,6.22L5.31,2.26C5.39,2.11 5.56,2 5.75,2H10.25M10.25,13C10.44,13 10.61,13.11 10.69,13.26L12.91,17.22L13,17.5L12.91,17.78L10.69,21.74C10.61,21.89 10.44,22 10.25,22H5.75C5.56,22 5.39,21.89 5.31,21.74L3.09,17.78L3,17.5L3.09,17.22L5.31,13.26C5.39,13.11 5.56,13 5.75,13H10.25M19.5,7.5C19.69,7.5 19.86,7.61 19.94,7.76L22.16,11.72L22.25,12L22.16,12.28L19.94,16.24C19.86,16.39 19.69,16.5 19.5,16.5H15C14.81,16.5 14.64,16.39 14.56,16.24L12.34,12.28L12.25,12L12.34,11.72L14.56,7.76C14.64,7.61 14.81,7.5 15,7.5H19.5Z\";\r\nvar mdiHexagonMultipleOutline = \"M9.37 4L10.78 6.5L9.37 9H6.63L5.23 6.5L6.63 4H9.37M10.25 2H5.75C5.56 2 5.39 2.11 5.31 2.26L3.09 6.22L3 6.5L3.09 6.78L5.31 10.74C5.39 10.89 5.56 11 5.75 11H10.25C10.44 11 10.61 10.89 10.69 10.74L12.91 6.78L13 6.5L12.91 6.22L10.69 2.26C10.61 2.11 10.44 2 10.25 2M18.62 9.5L20 12L18.62 14.5H15.88L14.5 12L15.88 9.5H18.62M19.5 7.5H15C14.81 7.5 14.64 7.61 14.56 7.76L12.34 11.72L12.25 12L12.34 12.28L14.56 16.24C14.64 16.39 14.81 16.5 15 16.5H19.5C19.69 16.5 19.86 16.39 19.94 16.24L22.16 12.28L22.25 12L22.16 11.72L19.94 7.76C19.86 7.61 19.69 7.5 19.5 7.5M9.37 15L10.78 17.5L9.37 20H6.63L5.23 17.5L6.63 15H9.37M10.25 13H5.75C5.56 13 5.39 13.11 5.31 13.26L3.09 17.22L3 17.5L3.09 17.78L5.31 21.74C5.39 21.89 5.56 22 5.75 22H10.25C10.44 22 10.61 21.89 10.69 21.74L12.91 17.78L13 17.5L12.91 17.22L10.69 13.26C10.61 13.11 10.44 13 10.25 13Z\";\r\nvar mdiHexagonOutline = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagonSlice1 = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15M12,12V5.32L17.94,8.66L12,12Z\";\r\nvar mdiHexagonSlice2 = \"M18,15.38L12,12V5.32L18,8.69V15.38M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagonSlice3 = \"M12,5.32L18,8.69V15.31L12,18.68V5.32M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagonSlice4 = \"M12,5.32L18,8.69V15.31L12,18.68L6.06,15.34L12,12V5.32M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagonSlice5 = \"M12,5.32L18,8.69V15.31L12,18.68L6,15.31V8.69L12,12V5.32M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagonSlice6 = \"M12,5.32L18,8.69V15.31L12,18.68L6,15.31V8.69L12,5.32M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L5,8.09V15.91L12,19.85L19,15.91V8.09L12,4.15Z\";\r\nvar mdiHexagram = \"M14.5,7.66L20.64,6.97L17,12L20.68,16.97L14.5,16.32L12.03,22L9.5,16.34L3.36,17.03L7,12L3.32,7.03L9.5,7.68L11.97,2L14.5,7.66Z\";\r\nvar mdiHexagramOutline = \"M12,7L13.3,9.8L16.5,9.4L14.5,12L16.4,14.5L13.2,14.1L12,17L10.7,14.2L7.5,14.6L9.5,12L7.6,9.5L10.8,9.9L12,7M12,2L9.5,7.7L3.3,7L7,12L3.4,17L9.6,16.3L12,22L14.5,16.3L20.7,16.9L17,12L20.6,7L14.4,7.7L12,2Z\";\r\nvar mdiHighDefinition = \"M5,7H7V11H9V7H11V17H9V13H7V17H5V7M13,7H16A3,3 0 0,1 19,10V14A3,3 0 0,1 16,17H13V7M16,15A1,1 0 0,0 17,14V10A1,1 0 0,0 16,9H15V15H16Z\";\r\nvar mdiHighDefinitionBox = \"M19,3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M11,15H9.5V13H7.5V15H6V9H7.5V11.5H9.5V9H11V15M13,9H17A1,1 0 0,1 18,10V14A1,1 0 0,1 17,15H13V9M14.5,13.5H16.5V10.5H14.5V13.5Z\";\r\nvar mdiHighway = \"M10,2L8,8H11V2H10M13,2V8H16L14,2H13M2,9V10H4V11H6V10H18L18.06,11H20V10H22V9H2M7,11L3.34,22H11V11H7M13,11V22H20.66L17,11H13Z\";\r\nvar mdiHiking = \"M9.8,8.9L7,23H9.1L10.9,15L13,17V23H15V15.5L12.9,13.5L13.5,10.5C14.63,11.81 16.29,12.73 18.15,12.95L16,23H17L20,9L19.04,8.8L18.58,11C16.86,10.85 15.44,9.89 14.7,8.6L13.7,7C13.5,6.65 13.2,6.37 12.84,6.2C12.5,6 12.08,5.96 11.68,6C11.28,6.09 10.92,6.27 10.63,6.55C10.34,6.83 10.14,7.19 10.06,7.58L9.8,8.9M7.08,6.92L9.4,7.38L8.4,12.46L6.08,12L7.08,6.92M13.5,5.5A2,2 0 0,0 15.5,3.5A2,2 0 0,0 13.5,1.5A2,2 0 0,0 11.5,3.5A2,2 0 0,0 13.5,5.5Z\";\r\nvar mdiHinduism = \"M15,2L13.5,3.5L15,5L16.5,3.5L15,2M11,3C10,9 17,10 20,6L18,4.5C17,6 13,8 11,3M9,7C7,7 4.5,8.5 4.5,8.5L6,11C7,10 9,9.5 10,10C12,11 9,13 7,12V15.5C10,14 12,16 11,17.5C8,22 3,16 3,13C1,19 6,22 9,22C12,22 14,20 12.5,15H14C12.5,19.5 18,24 21,18C22,16 22,9.5 17,9.5C13,9.5 14,15 10.5,13.5C14,10 12,7 9,7M19,12C22,15 15,21 15,15C15,13 17,10.5 19,12Z\";\r\nvar mdiHistory = \"M13.5,8H12V13L16.28,15.54L17,14.33L13.5,12.25V8M13,3A9,9 0 0,0 4,12H1L4.96,16.03L9,12H6A7,7 0 0,1 13,5A7,7 0 0,1 20,12A7,7 0 0,1 13,19C11.07,19 9.32,18.21 8.06,16.94L6.64,18.36C8.27,20 10.5,21 13,21A9,9 0 0,0 22,12A9,9 0 0,0 13,3\";\r\nvar mdiHockeyPuck = \"M12,5C6.5,5 2,6.57 2,8.5C2,10.43 6.5,12 12,12C17.5,12 22,10.43 22,8.5C22,6.57 17.5,5 12,5M2,11.76V16.5C2,18.43 6.5,20 12,20C17.5,20 22,18.43 22,16.5V11.76C21.33,12.22 20.58,12.57 19.73,12.86C17.62,13.6 14.95,14 12,14C9.05,14 6.38,13.6 4.27,12.86C3.42,12.57 2.67,12.22 2,11.76Z\";\r\nvar mdiHockeySticks = \"M7.58,3L5.05,4.61L9.04,10.87L10.82,8.08L7.58,3M16.43,3L7.5,17H2V21H8.5L18.96,4.61L16.43,3M14.97,14.59L13.19,17.38L15.5,21H22V17H16.5L14.97,14.59Z\";\r\nvar mdiHololens = \"M12,8C12,8 22,8 22,11C22,11 22.09,14.36 21.75,14.25C21,11 12,11 12,11C12,11 3,11 2.25,14.25C1.91,14.36 2,11 2,11C2,8 12,8 12,8M12,12C20,12 20.75,14.25 20.75,14.25C19.75,17.25 19,18 15,18C12,18 13,16.5 12,16.5C11,16.5 12,18 9,18C5,18 4.25,17.25 3.25,14.25C3.25,14.25 4,12 12,12Z\";\r\nvar mdiHome = \"M10,20V14H14V20H19V12H22L12,3L2,12H5V20H10Z\";\r\nvar mdiHomeAccount = \"M12,3L2,12H5V20H19V12H22L12,3M12,8.75A2.25,2.25 0 0,1 14.25,11A2.25,2.25 0 0,1 12,13.25A2.25,2.25 0 0,1 9.75,11A2.25,2.25 0 0,1 12,8.75M12,15C13.5,15 16.5,15.75 16.5,17.25V18H7.5V17.25C7.5,15.75 10.5,15 12,15Z\";\r\nvar mdiHomeAlert = \"M12 3L2 12H5V20H19V12H22L12 3M13 18H11V16H13V18M13 14H11V8H13V14Z\";\r\nvar mdiHomeAlertOutline = \"M12 5.7L17 10.2V18H7V10.2L12 5.7M19 20V12H22L12 3L2 12H5V20M13 8H11V13H13V8M13 15H11V17H13V15\";\r\nvar mdiHomeAnalytics = \"M12,3L2,12H5V20H19V12H22M9,18H7V12H9M13,18H11V10H13M17,18H15V14H17\";\r\nvar mdiHomeAssistant = \"M21.8,13H20V21H13V17.67L15.79,14.88L16.5,15C17.66,15 18.6,14.06 18.6,12.9C18.6,11.74 17.66,10.8 16.5,10.8A2.1,2.1 0 0,0 14.4,12.9L14.5,13.61L13,15.13V9.65C13.66,9.29 14.1,8.6 14.1,7.8A2.1,2.1 0 0,0 12,5.7A2.1,2.1 0 0,0 9.9,7.8C9.9,8.6 10.34,9.29 11,9.65V15.13L9.5,13.61L9.6,12.9A2.1,2.1 0 0,0 7.5,10.8A2.1,2.1 0 0,0 5.4,12.9A2.1,2.1 0 0,0 7.5,15L8.21,14.88L11,17.67V21H4V13H2.25C1.83,13 1.42,13 1.42,12.79C1.43,12.57 1.85,12.15 2.28,11.72L11,3C11.33,2.67 11.67,2.33 12,2.33C12.33,2.33 12.67,2.67 13,3L17,7V6H19V9L21.78,11.78C22.18,12.18 22.59,12.59 22.6,12.8C22.6,13 22.2,13 21.8,13M7.5,12A0.9,0.9 0 0,1 8.4,12.9A0.9,0.9 0 0,1 7.5,13.8A0.9,0.9 0 0,1 6.6,12.9A0.9,0.9 0 0,1 7.5,12M16.5,12C17,12 17.4,12.4 17.4,12.9C17.4,13.4 17,13.8 16.5,13.8A0.9,0.9 0 0,1 15.6,12.9A0.9,0.9 0 0,1 16.5,12M12,6.9C12.5,6.9 12.9,7.3 12.9,7.8C12.9,8.3 12.5,8.7 12,8.7C11.5,8.7 11.1,8.3 11.1,7.8C11.1,7.3 11.5,6.9 12,6.9Z\";\r\nvar mdiHomeAutomation = \"M12,3L2,12H5V20H19V12H22L12,3M12,8.5C14.34,8.5 16.46,9.43 18,10.94L16.8,12.12C15.58,10.91 13.88,10.17 12,10.17C10.12,10.17 8.42,10.91 7.2,12.12L6,10.94C7.54,9.43 9.66,8.5 12,8.5M12,11.83C13.4,11.83 14.67,12.39 15.6,13.3L14.4,14.47C13.79,13.87 12.94,13.5 12,13.5C11.06,13.5 10.21,13.87 9.6,14.47L8.4,13.3C9.33,12.39 10.6,11.83 12,11.83M12,15.17C12.94,15.17 13.7,15.91 13.7,16.83C13.7,17.75 12.94,18.5 12,18.5C11.06,18.5 10.3,17.75 10.3,16.83C10.3,15.91 11.06,15.17 12,15.17Z\";\r\nvar mdiHomeCircle = \"M19.07,4.93C17.22,3 14.66,1.96 12,2C9.34,1.96 6.79,3 4.94,4.93C3,6.78 1.96,9.34 2,12C1.96,14.66 3,17.21 4.93,19.06C6.78,21 9.34,22.04 12,22C14.66,22.04 17.21,21 19.06,19.07C21,17.22 22.04,14.66 22,12C22.04,9.34 21,6.78 19.07,4.93M17,12V18H13.5V13H10.5V18H7V12H5L12,5L19.5,12H17Z\";\r\nvar mdiHomeCircleOutline = \"M12 20C7.6 20 4 16.4 4 12S7.6 4 12 4 20 7.6 20 12 16.4 20 12 20M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M11 14H13V17H16V12H18L12 7L6 12H8V17H11V14\";\r\nvar mdiHomeCity = \"M0,21V10L7.5,5L15,10V21H10V14H5V21H0M24,2V21H17V8.93L16,8.27V6H14V6.93L10,4.27V2H24M21,14H19V16H21V14M21,10H19V12H21V10M21,6H19V8H21V6Z\";\r\nvar mdiHomeCityOutline = \"M10,2V4.26L12,5.59V4H22V19H17V21H24V2H10M7.5,5L0,10V21H15V10L7.5,5M14,6V6.93L15.61,8H16V6H14M18,6V8H20V6H18M7.5,7.5L13,11V19H10V13H5V19H2V11L7.5,7.5M18,10V12H20V10H18M18,14V16H20V14H18Z\";\r\nvar mdiHomeCurrencyUsd = \"M12,3L22,12H19V20H5V12H2L12,3M9.22,8.93C8.75,9.4 8.5,10.03 8.5,10.75C8.5,12.43 10.54,13.07 11.76,13.46C13.26,13.93 13.47,14.21 13.5,14.25C13.5,15 12.15,15 12,15V15C11.37,15 11.03,14.88 10.86,14.78C10.67,14.67 10.5,14.5 10.5,14H8.5C8.5,15.43 9.24,16.16 9.85,16.5C10.18,16.7 10.57,16.84 11,16.92V18H13V16.91C14.53,16.61 15.5,15.62 15.5,14.25C15.5,12.67 13.88,12.03 12.36,11.55C10.8,11.06 10.53,10.77 10.5,10.75C10.5,10.5 10.57,10.41 10.64,10.34C10.85,10.13 11.36,10 12,10V10C12.68,10 13.5,10.13 13.5,10.75H15.5C15.5,9.34 14.56,8.37 13,8.09V7H11V8.08C10.26,8.21 9.65,8.5 9.22,8.93Z\";\r\nvar mdiHomeEdit = \"M12 3L2 12H5V20H10V14H14V15.11L19.43 9.68L12 3M21.04 11.14C20.9 11.14 20.76 11.2 20.65 11.3L19.65 12.3L21.7 14.35L22.7 13.35C22.91 13.14 22.91 12.79 22.7 12.58L21.42 11.3C21.32 11.2 21.18 11.14 21.04 11.14M19.06 12.88L13 18.94V21H15.06L21.11 14.93L19.06 12.88Z\";\r\nvar mdiHomeEditOutline = \"M12 3L2 12H5V20H11V14H13V16.11L15 14.11V12H9V18H7V10.19L12 5.69L17 10.19V12.11L19.43 9.68L12 3M21.04 11.14C20.9 11.14 20.76 11.2 20.65 11.3L19.65 12.3L21.7 14.35L22.7 13.35C22.91 13.14 22.91 12.79 22.7 12.58L21.42 11.3C21.32 11.2 21.18 11.14 21.04 11.14M19.06 12.88L13 18.94V21H15.06L21.11 14.93L19.06 12.88Z\";\r\nvar mdiHomeExportOutline = \"M24 13L20 9V12H11V14H20V17M18 16V21H2V12H0L10 2L18 10H15L10 5L4 11V19H16V16H18Z\";\r\nvar mdiHomeFlood = \"M5,11H2L12,2L22,11H19V15.92C17.95,15.75 16.93,15.32 16,14.67C15.37,15.11 14.7,15.43 14,15.65V13H10V15.65C9.3,15.43 8.63,15.11 8,14.67C7.07,15.32 6.05,15.75 5,15.92M20,18C18.61,18 17.22,17.53 16,16.67C13.56,18.38 10.44,18.38 8,16.67C6.78,17.53 5.39,18 4,18H2V22H22V18\";\r\nvar mdiHomeFloor0 = \"M11,10H13V16H11V10M22,12H19V20H5V12H2L12,3L22,12M15,10A2,2 0 0,0 13,8H11A2,2 0 0,0 9,10V16A2,2 0 0,0 11,18H13A2,2 0 0,0 15,16V10Z\";\r\nvar mdiHomeFloor1 = \"M12,3L2,12H5V20H19V12H22L12,3M10,8H14V18H12V10H10V8Z\";\r\nvar mdiHomeFloor2 = \"M12,3L2,12H5V20H19V12H22L12,3M9,8H13A2,2 0 0,1 15,10V12A2,2 0 0,1 13,14H11V16H15V18H9V14A2,2 0 0,1 11,12H13V10H9V8Z\";\r\nvar mdiHomeFloor3 = \"M12,3L22,12H19V20H5V12H2L12,3M15,11.5V10C15,8.89 14.1,8 13,8H9V10H13V12H11V14H13V16H9V18H13A2,2 0 0,0 15,16V14.5A1.5,1.5 0 0,0 13.5,13A1.5,1.5 0 0,0 15,11.5Z\";\r\nvar mdiHomeFloorA = \"M12,3L2,12H5V20H19V12H22L12,3M11,8H13A2,2 0 0,1 15,10V18H13V15H11V18H9V10C9,8.89 9.9,8 11,8M11,10V13H13V10H11Z\";\r\nvar mdiHomeFloorB = \"M12,3L2,12H5V20H19V12H22L12,3M9,8H13A2,2 0 0,1 15,10V11.5A1.5,1.5 0 0,1 13.5,13A1.5,1.5 0 0,1 15,14.5V16A2,2 0 0,1 13,18H9V8M11,10V12H13V10H11M11,14V16H13V14H11Z\";\r\nvar mdiHomeFloorG = \"M12,3L2,12H5V20H19V12H22L12,3M11,8H15V10H11V16H13V12H15V16C15,17.11 14.1,18 13,18H11A2,2 0 0,1 9,16V10C9,8.89 9.9,8 11,8Z\";\r\nvar mdiHomeFloorL = \"M12,3L2,12H5V20H19V12H22L12,3M9,8H11V16H15V18H9V8Z\";\r\nvar mdiHomeFloorNegative1 = \"M12,3L2,12H5V20H19V12H22L12,3M11,15H7V13H11V15M15,18H13V10H11V8H15V18Z\";\r\nvar mdiHomeGroup = \"M17,16H15V22H12V17H8V22H5V16H3L10,10L17,16M6,2L10,6H9V9H7V6H5V9H3V6H2L6,2M18,3L23,8H22V12H19V9H17V12H15.34L14,10.87V8H13L18,3Z\";\r\nvar mdiHomeHeart = \"M2,12L12,3L22,12H19V20H5V12H2M12,18L12.72,17.34C15.3,15 17,13.46 17,11.57C17,10.03 15.79,8.82 14.25,8.82C13.38,8.82 12.55,9.23 12,9.87C11.45,9.23 10.62,8.82 9.75,8.82C8.21,8.82 7,10.03 7,11.57C7,13.46 8.7,15 11.28,17.34L12,18Z\";\r\nvar mdiHomeImportOutline = \"M15 13L11 9V12H2V14H11V17M22 12H20V21H4V16H6V19H18V11L12 5L7 10H4L12 2L22 12Z\";\r\nvar mdiHomeLightbulb = \"M12 3L2 12H5V20H19V12H22M13 18H11V17H13M13.5 14.58V16H10.5V14.58A3 3 0 1 1 13.5 14.58Z\";\r\nvar mdiHomeLightbulbOutline = \"M12 2L2 12H4V21H20V12H22M12 5L18 11V19H6V11M13.5 14.58V16H10.5V14.58C9.07 13.75 8.57 11.92 9.4 10.5C10.23 9.05 12.07 8.56 13.5 9.38S15.43 12.05 14.6 13.5C14.34 13.94 13.96 14.32 13.5 14.58M13 17H11V18H13V17Z\";\r\nvar mdiHomeLock = \"M12,3L2,12H5V20H19V12H22L12,3M12,9A3,3 0 0,1 15,12V13H16V17H8V13H9V12A3,3 0 0,1 12,9M12,11A1,1 0 0,0 11,12V13H13V12C13,11.5 12.6,11 12,11Z\";\r\nvar mdiHomeLockOpen = \"M12,3L2,12H5V20H19V12H22L12,3M12,8A3,3 0 0,1 15,11H13A1,1 0 0,0 12,10A1,1 0 0,0 11,11V13H16V17H8V13H9V11A3,3 0 0,1 12,8Z\";\r\nvar mdiHomeMapMarker = \"M12,3L2,12H5V20H19V12H22L12,3M12,7.7C14.1,7.7 15.8,9.4 15.8,11.5C15.8,14.5 12,18 12,18C12,18 8.2,14.5 8.2,11.5C8.2,9.4 9.9,7.7 12,7.7M12,10A1.5,1.5 0 0,0 10.5,11.5A1.5,1.5 0 0,0 12,13A1.5,1.5 0 0,0 13.5,11.5A1.5,1.5 0 0,0 12,10Z\";\r\nvar mdiHomeMinus = \"M12,3L2,12H5V20H19V12H22L12,3M16,13V15H8V13H16Z\";\r\nvar mdiHomeMinusOutline = \"M12 2L2 12H4V21H20V12H22M12 5L18 11V19H6V11M16 13V15H8V13H16Z\";\r\nvar mdiHomeModern = \"M6,21V8A2,2 0 0,1 8,6L16,3V6A2,2 0 0,1 18,8V21H12V16H8V21H6M14,19H16V16H14V19M8,13H10V9H8V13M12,13H16V9H12V13Z\";\r\nvar mdiHomeOutline = \"M12 5.69L17 10.19V18H15V12H9V18H7V10.19L12 5.69M12 3L2 12H5V20H11V14H13V20H19V12H22L12 3Z\";\r\nvar mdiHomePlus = \"M12,3L2,12H5V20H19V12H22L12,3M11,10H13V13H16V15H13V18H11V15H8V13H11V10Z\";\r\nvar mdiHomePlusOutline = \"M12 2L2 12H4V21H20V12H22M12 5L18 11V19H6V11M11 10H13V13H16V15H13V18H11V15H8V13H11V10Z\";\r\nvar mdiHomeRemove = \"M12 3L2 12H5V20H19V12H22L12 3M15.54 16.12L14.12 17.54L12 15.41L9.88 17.54L8.47 16.12L10.59 14L8.47 11.88L9.88 10.47L12 12.59L14.12 10.47L15.54 11.88L13.41 14L15.54 16.12Z\";\r\nvar mdiHomeRemoveOutline = \"M12 2L2 12H4V21H20V12H22M12 5L18 11V19H6V11M14.12 10.46L15.54 11.88L13.41 14L15.54 16.12L14.12 17.54L12 15.41L9.88 17.54L8.47 16.12L10.59 14L8.47 11.88L9.88 10.47L12 12.59L14.12 10.46Z\";\r\nvar mdiHomeRoof = \"M19 16H22L12 7L2 16H5L12 9.69L19 16M7 8.81V7H4V11.5L7 8.81Z\";\r\nvar mdiHomeSearch = \"M19.31 18.9C19.75 18.21 20 17.38 20 16.5C20 14 18 12 15.5 12S11 14 11 16.5 13 21 15.5 21C16.37 21 17.19 20.75 17.88 20.32L21 23.39L22.39 22L19.31 18.9M15.5 19C14.12 19 13 17.88 13 16.5S14.12 14 15.5 14 18 15.12 18 16.5 16.88 19 15.5 19M5 20V12H2L12 3L22 12H20.18C19 10.77 17.34 10 15.5 10C11.92 10 9 12.92 9 16.5C9 17.79 9.38 19 10.03 20H5Z\";\r\nvar mdiHomeSearchOutline = \"M19.31 18.9C19.75 18.21 20 17.38 20 16.5C20 14 18 12 15.5 12S11 14 11 16.5 13 21 15.5 21C16.37 21 17.19 20.75 17.88 20.32L21 23.39L22.39 22L19.31 18.9M15.5 19C14.12 19 13 17.88 13 16.5S14.12 14 15.5 14 18 15.12 18 16.5 16.88 19 15.5 19M5 20V12H2L12 3L22 12H20.18C19.33 11.11 18.23 10.47 17 10.18L12 5.69L7 10.19V18H9.18C9.35 18.72 9.64 19.39 10.03 20H5Z\";\r\nvar mdiHomeThermometer = \"M12 3L2 12H5V20H19V12H22L12 3M12 8A1 1 0 0 1 13 9V14.27A2 2 0 0 1 14 16A2 2 0 0 1 12 18A2 2 0 0 1 10 16A2 2 0 0 1 11 14.27V9A1 1 0 0 1 12 8Z\";\r\nvar mdiHomeThermometerOutline = \"M12 2L2 12H4V21H20V12H22M12 5L18 11V19H6V11M12 8C11.45 8 11 8.45 11 9V13.27C10.38 13.63 10 14.29 10 15C10 16.11 10.9 17 12 17S14 16.11 14 15C14 14.29 13.62 13.63 13 13.27V9C13 8.45 12.55 8 12 8Z\";\r\nvar mdiHomeVariant = \"M12,3L20,9V21H15V14H9V21H4V9L12,3Z\";\r\nvar mdiHomeVariantOutline = \"M9,13H15V19H18V10L12,5.5L6,10V19H9V13M4,21V9L12,3L20,9V21H4Z\";\r\nvar mdiHook = \"M18,6C18,7.82 16.76,9.41 15,9.86V17A5,5 0 0,1 10,22A5,5 0 0,1 5,17V12L10,17H7A3,3 0 0,0 10,20A3,3 0 0,0 13,17V9.86C11.23,9.4 10,7.8 10,5.97C10,3.76 11.8,2 14,2C16.22,2 18,3.79 18,6M14,8A2,2 0 0,0 16,6A2,2 0 0,0 14,4A2,2 0 0,0 12,6A2,2 0 0,0 14,8Z\";\r\nvar mdiHookOff = \"M13,9.86V11.18L15,13.18V9.86C17.14,9.31 18.43,7.13 17.87,5C17.32,2.85 15.14,1.56 13,2.11C10.86,2.67 9.57,4.85 10.13,7C10.5,8.4 11.59,9.5 13,9.86M14,4A2,2 0 0,1 16,6A2,2 0 0,1 14,8A2,2 0 0,1 12,6A2,2 0 0,1 14,4M18.73,22L14.86,18.13C14.21,20.81 11.5,22.46 8.83,21.82C6.6,21.28 5,19.29 5,17V12L10,17H7A3,3 0 0,0 10,20A3,3 0 0,0 13,17V16.27L2,5.27L3.28,4L13,13.72L15,15.72L20,20.72L18.73,22Z\";\r\nvar mdiHops = \"M21,12C21,12 12.5,10 12.5,2C12.5,2 21,2 21,12M3,12C3,2 11.5,2 11.5,2C11.5,10 3,12 3,12M12,6.5C12,6.5 13,8.66 15,10.5C14.76,14.16 12,16 12,16C12,16 9.24,14.16 9,10.5C11,8.66 12,6.5 12,6.5M20.75,13.25C20.75,13.25 20,17 18,19C18,19 15.53,17.36 14.33,14.81C15.05,13.58 15.5,12.12 15.75,11.13C17.13,12.18 18.75,13 20.75,13.25M15.5,18.25C14.5,20.25 12,21.75 12,21.75C12,21.75 9.5,20.25 8.5,18.25C8.5,18.25 9.59,17.34 10.35,15.8C10.82,16.35 11.36,16.79 12,17C12.64,16.79 13.18,16.35 13.65,15.8C14.41,17.34 15.5,18.25 15.5,18.25M3.25,13.25C5.25,13 6.87,12.18 8.25,11.13C8.5,12.12 8.95,13.58 9.67,14.81C8.47,17.36 6,19 6,19C4,17 3.25,13.25 3.25,13.25Z\";\r\nvar mdiHorizontalRotateClockwise = \"M12 14L8 10L4 14H7.1C7.56 18.56 9.58 22 12 22S16.44 18.56 16.9 14H14.91C14.57 17.45 13.4 20 12 20S9.43 17.45 9.09 14H12M12 4C13.4 4 14.57 6.55 14.91 10H16.9C16.44 5.44 14.42 2 12 2C9.84 2 8 4.74 7.3 8.58L8 7.88L9.21 9.08C9.64 6.11 10.73 4 12 4M22 13V11H11L13 13H22M2 13H3L5 11H2V13Z\";\r\nvar mdiHorizontalRotateCounterclockwise = \"M12 10H9.09C9.43 6.55 10.6 4 12 4S14.57 6.55 14.91 10H16.9C16.44 5.44 14.42 2 12 2S7.56 5.44 7.1 10H4L8 14L12 10M12 20C10.73 20 9.64 17.89 9.21 14.92L8 16.12L7.3 15.42C8 19.26 9.84 22 12 22C14.42 22 16.44 18.56 16.9 14H14.91C14.57 17.45 13.4 20 12 20M22 11H13L11 13H22V11M2 13H5L3 11H2V13\";\r\nvar mdiHorse = \"M22 6V9.5L20.5 10L18.96 7.54C18.83 7.33 18.5 7.42 18.5 7.67V11.25C18.5 12.23 18.11 13.11 17.5 13.78V21H15V15C14.92 15 14.84 15 14.75 15C14.54 15 14.33 14.97 14.13 14.94L9.69 14.2L8.57 16.21L9.53 21H7L6 16.25C5.97 15.95 6 15.65 6.16 15.39L7.18 13.58C6.2 13.03 5.53 12 5.5 10.81C5.46 10.96 5.44 11.18 5.47 11.5C5.5 11.94 5.61 12.59 5.54 13.31C5.5 14.03 5.17 14.77 4.75 15.26C4.32 15.75 3.85 16.09 3.35 16.35L2.65 15.65C2.84 15.18 3.03 14.76 3.07 14.37C3.13 14 3.06 13.7 2.95 13.43L2.42 12.3C2.21 11.79 1.95 11.05 2 10.18C2.03 9.33 2.5 8.22 3.39 7.61C4.29 7 5.26 6.92 6.05 7.08C6.55 7.18 7.06 7.42 7.5 7.76C7.87 7.59 8.3 7.5 8.75 7.5H14.5V7C14.5 4.79 16.29 3 18.5 3H22L21.11 4.34C21.65 4.7 22 5.31 22 6Z\";\r\nvar mdiHorseHuman = \"M10 3.5C10 2.67 10.67 2 11.5 2S13 2.67 13 3.5 12.33 5 11.5 5 10 4.33 10 3.5M22 8V11.5L20.97 11.85C20.8 13.06 19.76 14 18.5 14H18.42C18.28 14.68 17.95 15.29 17.5 15.78V22H15V17C14.92 17 14.84 17 14.75 17C14.54 17 14.33 16.97 14.13 16.94L9.69 16.2L8.57 18.21L9.32 22H6.78L6 18.25C5.97 17.95 6 17.65 6.16 17.39L7.18 15.58C6.2 15.03 5.53 14 5.5 12.81C5.46 12.96 5.44 13.18 5.47 13.5C5.5 13.94 5.61 14.59 5.54 15.31C5.5 16.03 5.17 16.77 4.75 17.26C4.32 17.75 3.85 18.09 3.35 18.35L2.65 17.65C2.84 17.18 3.03 16.76 3.07 16.37C3.13 16 3.06 15.7 2.95 15.43L2.42 14.3C2.21 13.79 1.95 13.05 2 12.18C2.03 11.33 2.5 10.22 3.39 9.61C4.29 9 5.26 8.91 6.05 9.08C6.55 9.18 7.06 9.42 7.5 9.76C7.87 9.59 8.3 9.5 8.75 9.5H9V8.11C9 7.11 9.68 6.19 10.66 6.03C11.92 5.82 13 6.79 13 8V9.5H14.5V9C14.5 6.79 16.29 5 18.5 5H22L21.11 6.34C21.65 6.7 22 7.31 22 8M20 11.2L18.96 9.54C18.83 9.33 18.5 9.42 18.5 9.67V13C19.33 13 20 12.33 20 11.5V11.2Z\";\r\nvar mdiHorseVariant = \"M20 8V16L17 17L13.91 11.5C13.65 11.04 12.92 11.27 13 11.81L14 21L4 17L5.15 8.94C5.64 5.53 8.56 3 12 3H20L18.42 5.37C19.36 5.88 20 6.86 20 8Z\";\r\nvar mdiHorseshoe = \"M19,4H20V1H16V4C16,4 18,8 18,12C18,16 16,19 12,19C8,19 6,16 6,12C6,8 8,4 8,4V1H4V4H5C5,4 2,8 2,14C2,19 7,23 12,23C17,23 22,19 22,14C22,8 19,4 19,4M4,13C3.4,13 3,12.6 3,12C3,11.4 3.4,11 4,11C4.6,11 5,11.4 5,12C5,12.6 4.6,13 4,13M6,19C5.4,19 5,18.6 5,18C5,17.4 5.4,17 6,17C6.6,17 7,17.4 7,18C7,18.6 6.6,19 6,19M12,22C11.4,22 11,21.6 11,21C11,20.4 11.4,20 12,20C12.6,20 13,20.4 13,21C13,21.6 12.6,22 12,22M18,19C17.4,19 17,18.6 17,18C17,17.4 17.4,17 18,17C18.6,17 19,17.4 19,18C19,18.6 18.6,19 18,19M20,13C19.4,13 19,12.6 19,12C19,11.4 19.4,11 20,11C20.6,11 21,11.4 21,12C21,12.6 20.6,13 20,13Z\";\r\nvar mdiHospital = \"M18 14H14V18H10V14H6V10H10V6H14V10H18\";\r\nvar mdiHospitalBox = \"M18,14H14V18H10V14H6V10H10V6H14V10H18M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiHospitalBoxOutline = \"M18 14H14V18H10V14H6V10H10V6H14V10H18M20 2H4C2.9 2 2 2.9 2 4V20C2 21.1 2.9 22 4 22H20C21.1 22 22 21.1 22 20V4C22 2.9 21.1 2 20 2M20 20H4V4H20V20Z\";\r\nvar mdiHospitalBuilding = \"M2,22V7A1,1 0 0,1 3,6H7V2H17V6H21A1,1 0 0,1 22,7V22H14V17H10V22H2M9,4V10H11V8H13V10H15V4H13V6H11V4H9M4,20H8V17H4V20M4,15H8V12H4V15M16,20H20V17H16V20M16,15H20V12H16V15M10,15H14V12H10V15Z\";\r\nvar mdiHospitalMarker = \"M12,2C15.86,2 19,5.13 19,9C19,14.25 12,22 12,22C12,22 5,14.25 5,9A7,7 0 0,1 12,2M9,6V12H11V10H13V12H15V6H13V8H11V6H9Z\";\r\nvar mdiHotTub = \"M7,4A2,2 0 0,1 9,6A2,2 0 0,1 7,8A2,2 0 0,1 5,6A2,2 0 0,1 7,4M11.15,12H22V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V12H5V11.25C5,10 6,9 7.25,9H7.28C7.62,9 7.95,9.09 8.24,9.23C8.5,9.35 8.74,9.5 8.93,9.73L10.33,11.28C10.56,11.54 10.84,11.78 11.15,12M7,20V14H5V20H7M11,20V14H9V20H11M15,20V14H13V20H15M19,20V14H17V20H19M18.65,5.86C19.68,6.86 20.16,8.21 19.95,9.57L19.89,10H18L18.09,9.41C18.24,8.62 18,7.83 17.42,7.21L17.35,7.15C16.32,6.14 15.85,4.79 16.05,3.43L16.11,3H18L17.91,3.59C17.76,4.38 18,5.17 18.58,5.79L18.65,5.86M14.65,5.86C15.68,6.86 16.16,8.21 15.95,9.57L15.89,10H14L14.09,9.41C14.24,8.62 14,7.83 13.42,7.21L13.35,7.15C12.32,6.14 11.85,4.79 12.05,3.43L12.11,3H14L13.91,3.59C13.76,4.38 14,5.17 14.58,5.79L14.65,5.86Z\";\r\nvar mdiHours24 = \"M13 2.05V4.07C16.95 4.56 20 7.92 20 12C20 15.21 18.08 18 15.28 19.28L13 17V22H18L16.78 20.78C19.91 19.07 22 15.76 22 12C22 6.82 18.05 2.55 13 2.05M11 2C9.05 2.2 7.2 2.96 5.68 4.21L7.1 5.63C8.23 4.75 9.58 4.2 11 4V2M4.2 5.68C2.96 7.2 2.2 9.05 2 11H4C4.19 9.58 4.75 8.23 5.63 7.1L4.2 5.68M6 8V10H9V11H8C6.9 11 6 11.9 6 13V16H11V14H8V13H9C10.11 13 11 12.11 11 11V10C11 8.9 10.11 8 9 8H6M12 8V13H15V16H17V13H18V11H17V8H15V11H14V8H12M2 13C2.2 14.95 2.97 16.8 4.22 18.32L5.64 16.9C4.76 15.77 4.2 14.42 4 13H2M7.11 18.37L5.68 19.79C7.2 21.03 9.05 21.8 11 22V20C9.58 19.81 8.24 19.25 7.11 18.37Z\";\r\nvar mdiHubspot = \"M17.1,8.6V6.2C17.7,5.9 18.2,5.3 18.2,4.6V4.5C18.2,3.5 17.4,2.7 16.4,2.7H16.3C15.3,2.7 14.5,3.5 14.5,4.5V4.6C14.5,5.3 14.9,5.9 15.6,6.2V8.6C14.7,8.7 13.8,9.1 13.1,9.7L6.5,4.6C6.8,3.5 6.1,2.3 5,2.1C3.9,1.9 2.8,2.4 2.5,3.5C2.2,4.6 2.9,5.8 4,6.1C4.5,6.2 5.1,6.2 5.6,5.9L12,10.9C10.8,12.7 10.8,15 12.1,16.8L10.1,18.8C9.9,18.8 9.8,18.7 9.6,18.7C8.7,18.7 7.9,19.5 7.9,20.4C7.9,21.3 8.7,22 9.6,22C10.5,22 11.3,21.2 11.3,20.3V20.3C11.3,20.1 11.3,20 11.2,19.8L13.1,17.9C15.4,19.6 18.7,19.2 20.4,16.9C22.1,14.6 21.7,11.3 19.4,9.6C18.8,9.1 18,8.7 17.1,8.6M16.3,16.4C14.8,16.4 13.6,15.2 13.6,13.7C13.6,12.2 14.8,11 16.3,11C17.8,11 19,12.2 19,13.7C19,15.2 17.8,16.4 16.3,16.4\";\r\nvar mdiHulu = \"M19.5,12.8V22H14.7V13.9C14.7,13.2 14.1,12.6 13.4,12.6H10.5C9.8,12.6 9.2,13.2 9.2,13.9V22H4.5V2H9.3V8.4C9.6,8.3 9.9,8.2 10.2,8.2H15C17.5,8.2 19.5,10.3 19.5,12.8Z\";\r\nvar mdiHuman = \"M21,9H15V22H13V16H11V22H9V9H3V7H21M12,2A2,2 0 0,1 14,4A2,2 0 0,1 12,6C10.89,6 10,5.1 10,4C10,2.89 10.89,2 12,2Z\";\r\nvar mdiHumanBabyChangingTable = \"M6.5 6.08C5.72 6.12 5 6.62 4.72 7.4L3 12.13V22H7V12.84L8.42 8.94L10.7 10H14V8H11.15L7.29 6.2C7.03 6.11 6.76 6.07 6.5 6.08M9 17H21V19H9M10 3.5A2 2 0 0 1 8 5.5A2 2 0 0 1 6 3.5A2 2 0 0 1 8 1.5A2 2 0 0 1 10 3.5M21 14.5A1.5 1.5 0 0 1 19.5 16A1.5 1.5 0 0 1 18 14.5A1.5 1.5 0 0 1 19.5 13A1.5 1.5 0 0 1 21 14.5M9 11V13H11V14C11 15.11 11.89 16 13 16H15C16.11 16 17 15.11 17 14V11H15V13H13V12A1 1 0 0 0 12 11Z\";\r\nvar mdiHumanCane = \"M18 12.24V22H17.06V12.24C17.06 12.09 17 12 16.93 11.89C16.84 11.8 16.74 11.76 16.62 11.76C16.47 11.76 16.36 11.8 16.27 11.89C16.18 12 16.14 12.1 16.14 12.24V13.16H15.23V12.5C14.53 12.33 13.9 12.04 13.35 11.63C12.8 11.22 12.34 10.74 11.96 10.19L11.61 11.39C11.5 11.81 11.5 12.24 11.5 12.68L11.5 13L11.5 13.33L13.35 15.94V22H11.5V17.34L9.82 15L9.65 18.25L6.86 22L5.38 20.87L7.77 17.64V12.68C7.77 12.15 7.82 11.63 7.91 11.11L8.25 9.54L6.86 10.32V13.63H5V9.23L10 6.4C10.29 6.26 10.59 6.18 10.91 6.18C11.23 6.18 11.54 6.27 11.83 6.44C12.15 6.62 12.39 6.88 12.57 7.23L13.31 8.8C13.6 9.38 14.04 9.87 14.64 10.26C15.23 10.65 15.89 10.85 16.62 10.85C17 10.85 17.32 11 17.6 11.24C17.88 11.5 18 11.83 18 12.24M12 2C13.11 2 14 2.9 14 4C14 5.11 13.11 6 12 6C10.9 6 10 5.11 10 4C10 2.9 10.9 2 12 2Z\";\r\nvar mdiHumanCapacityDecrease = \"M16 4C16 2.9 16.9 2 18 2S20 2.9 20 4 19.1 6 18 6 16 5.1 16 4M20.78 7.58C19.93 7.21 19 7 18 7C17.33 7 16.69 7.1 16.08 7.28C16.66 7.83 17 8.6 17 9.43V10H22V9.43C22 8.62 21.5 7.9 20.78 7.58M6 6C7.1 6 8 5.1 8 4S7.1 2 6 2 4 2.9 4 4 4.9 6 6 6M7.92 7.28C7.31 7.1 6.67 7 6 7C5 7 4.07 7.21 3.22 7.58C2.5 7.9 2 8.62 2 9.43V10H7V9.43C7 8.6 7.34 7.83 7.92 7.28M10 4C10 2.9 10.9 2 12 2S14 2.9 14 4 13.1 6 12 6 10 5.1 10 4M16 10H8V9.43C8 8.62 8.5 7.9 9.22 7.58C10.07 7.21 11 7 12 7C13 7 13.93 7.21 14.78 7.58C15.5 7.9 16 8.62 16 9.43V10M15 16C15 14.9 15.9 14 17 14S19 14.9 19 16 18.1 18 17 18 15 17.1 15 16M21 22H13V21.43C13 20.62 13.5 19.9 14.22 19.58C15.07 19.21 16 19 17 19C18 19 18.93 19.21 19.78 19.58C20.5 19.9 21 20.62 21 21.43V22M5 16C5 14.9 5.9 14 7 14S9 14.9 9 16 8.1 18 7 18 5 17.1 5 16M11 22H3V21.43C3 20.62 3.5 19.9 4.22 19.58C5.07 19.21 6 19 7 19C8 19 8.93 19.21 9.78 19.58C10.5 19.9 11 20.62 11 21.43V22M12.75 13V11H11.25V13H9L12 16L15 13H12.75Z\";\r\nvar mdiHumanCapacityIncrease = \"M16 4C16 2.9 16.9 2 18 2C19.1 2 20 2.9 20 4C20 5.1 19.1 6 18 6C16.9 6 16 5.1 16 4M20.78 7.58C19.93 7.21 19 7 18 7C17.33 7 16.69 7.1 16.08 7.28C16.66 7.83 17 8.6 17 9.43V10H22V9.43C22 8.62 21.5 7.9 20.78 7.58M6 6C7.1 6 8 5.1 8 4C8 2.9 7.1 2 6 2C4.9 2 4 2.9 4 4C4 5.1 4.9 6 6 6M7.92 7.28C7.31 7.1 6.67 7 6 7C5 7 4.07 7.21 3.22 7.58C2.5 7.9 2 8.62 2 9.43V10H7V9.43C7 8.6 7.34 7.83 7.92 7.28M10 4C10 2.9 10.9 2 12 2C13.1 2 14 2.9 14 4C14 5.1 13.1 6 12 6C10.9 6 10 5.1 10 4M16 10H8V9.43C8 8.62 8.5 7.9 9.22 7.58C10.07 7.21 11 7 12 7C13 7 13.93 7.21 14.78 7.58C15.5 7.9 16 8.62 16 9.43M15 16C15 14.9 15.9 14 17 14C18.1 14 19 14.9 19 16C19 17.1 18.1 18 17 18C15.9 18 15 17.1 15 16M21 22H13V21.43C13 20.62 13.5 19.9 14.22 19.58C15.07 19.21 16 19 17 19C18 19 18.93 19.21 19.78 19.58C20.5 19.9 21 20.62 21 21.43M5 16C5 14.9 5.9 14 7 14C8.1 14 9 14.9 9 16C9 17.1 8.1 18 7 18C5.9 18 5 17.1 5 16M11 22H3V21.43C3 20.62 3.5 19.9 4.22 19.58C5.07 19.21 6 19 7 19C8 19 8.93 19.21 9.78 19.58C10.5 19.9 11 20.62 11 21.43M12.75 14V16H11.25V14H9L12 11L15 14Z\";\r\nvar mdiHumanChild = \"M12,2A3,3 0 0,1 15,5A3,3 0 0,1 12,8A3,3 0 0,1 9,5A3,3 0 0,1 12,2M11,22H8V16H6V9H18V16H16V22H13V18H11V22Z\";\r\nvar mdiHumanEdit = \"M19.07 14.88L21.12 16.93L15.06 23H13V20.94L19.07 14.88M21.04 13.13C21.18 13.13 21.31 13.19 21.42 13.3L22.7 14.58C22.92 14.79 22.92 15.14 22.7 15.35L21.7 16.35L19.65 14.3L20.65 13.3C20.76 13.19 20.9 13.13 21.04 13.13M21 9H15V16L13 18V16H11V22H9V9H3V7H21V9M12 2C13.1 2 14 2.9 14 4C14 5.1 13.1 6 12 6C10.9 6 10 5.1 10 4C10 2.9 10.9 2 12 2Z\";\r\nvar mdiHumanFemale = \"M12,2A2,2 0 0,1 14,4A2,2 0 0,1 12,6A2,2 0 0,1 10,4A2,2 0 0,1 12,2M10.5,22V16H7.5L10.09,8.41C10.34,7.59 11.1,7 12,7C12.9,7 13.66,7.59 13.91,8.41L16.5,16H13.5V22H10.5Z\";\r\nvar mdiHumanFemaleBoy = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,22V16H3L5.6,8.4C5.9,7.6 6.6,7 7.5,7C8.4,7 9.2,7.6 9.4,8.4L12,16H9V22H6M14.5,12A2,2 0 0,1 16.5,10A2,2 0 0,1 18.5,12A2,2 0 0,1 16.5,14A2,2 0 0,1 14.5,12M13.5,15H19.5V19H18V22H15V19H13.5V15Z\";\r\nvar mdiHumanFemaleDance = \"M17 17H15V23H13V17H10.88L9.34 18.93L11.71 21.29L10.29 22.71L7.93 20.34C7.58 20 7.38 19.53 7.35 19.04C7.32 18.55 7.47 18.06 7.78 17.68L8.32 17H7L9 13V10C8.38 10.47 7.88 11.07 7.53 11.76C7.18 12.46 7 13.22 7 14H5C5 12.14 5.74 10.36 7.05 9.05C8.36 7.74 10.14 7 12 7C13.33 7 14.6 6.47 15.54 5.54C16.47 4.6 17 3.33 17 2H19C19 3.32 18.62 4.62 17.91 5.73C17.2 6.85 16.2 7.74 15 8.31V13L17 17M14 4C14 4.4 13.88 4.78 13.66 5.11C13.44 5.44 13.13 5.7 12.77 5.85C12.4 6 12 6.04 11.61 5.96C11.22 5.88 10.87 5.69 10.59 5.41C10.31 5.13 10.12 4.78 10.04 4.39C9.96 4 10 3.6 10.15 3.24C10.3 2.87 10.56 2.56 10.89 2.34C11.22 2.12 11.6 2 12 2C12.53 2 13.04 2.21 13.41 2.59C13.79 2.96 14 3.47 14 4Z\";\r\nvar mdiHumanFemaleFemale = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,22V16H3L5.6,8.4C5.9,7.6 6.6,7 7.5,7C8.4,7 9.2,7.6 9.4,8.4L12,16L14.6,8.4C14.9,7.6 15.6,7 16.5,7C17.4,7 18.2,7.6 18.4,8.4L21,16H18V22H15V16H12L9,16V22H6M16.5,2A2,2 0 0,1 18.5,4A2,2 0 0,1 16.5,6A2,2 0 0,1 14.5,4A2,2 0 0,1 16.5,2Z\";\r\nvar mdiHumanFemaleGirl = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,22V16H3L5.6,8.4C5.9,7.6 6.6,7 7.5,7C8.4,7 9.2,7.6 9.4,8.4L12,16H9V22H6M14.5,12A2,2 0 0,1 16.5,10A2,2 0 0,1 18.5,12A2,2 0 0,1 16.5,14A2,2 0 0,1 14.5,12M15,15H18L19.5,19H18V22H15V19H13.5L15,15Z\";\r\nvar mdiHumanGreeting = \"M1.5,4V5.5C1.5,9.65 3.71,13.28 7,15.3V20H22V18C22,15.34 16.67,14 14,14C14,14 13.83,14 13.75,14C9,14 5,10 5,5.5V4M14,4A4,4 0 0,0 10,8A4,4 0 0,0 14,12A4,4 0 0,0 18,8A4,4 0 0,0 14,4Z\";\r\nvar mdiHumanGreetingProximity = \"M11 14H9C9 9.03 13.03 5 18 5V7C14.13 7 11 10.13 11 14M18 11V9C15.24 9 13 11.24 13 14H15C15 12.34 16.34 11 18 11M7 4C7 2.89 6.11 2 5 2S3 2.89 3 4 3.89 6 5 6 7 5.11 7 4M11.45 4.5H9.45C9.21 5.92 8 7 6.5 7H3.5C2.67 7 2 7.67 2 8.5V11H8V8.74C9.86 8.15 11.25 6.5 11.45 4.5M19 17C20.11 17 21 16.11 21 15S20.11 13 19 13 17 13.89 17 15 17.89 17 19 17M20.5 18H17.5C16 18 14.79 16.92 14.55 15.5H12.55C12.75 17.5 14.14 19.15 16 19.74V22H22V19.5C22 18.67 21.33 18 20.5 18Z\";\r\nvar mdiHumanHandsdown = \"M12,1C10.89,1 10,1.9 10,3C10,4.11 10.89,5 12,5C13.11,5 14,4.11 14,3A2,2 0 0,0 12,1M10,6C9.73,6 9.5,6.11 9.31,6.28H9.3L4,11.59L5.42,13L9,9.41V22H11V15H13V22H15V9.41L18.58,13L20,11.59L14.7,6.28C14.5,6.11 14.27,6 14,6\";\r\nvar mdiHumanHandsup = \"M5,1C5,3.7 6.56,6.16 9,7.32V22H11V15H13V22H15V7.31C17.44,6.16 19,3.7 19,1H17A5,5 0 0,1 12,6A5,5 0 0,1 7,1M12,1C10.89,1 10,1.89 10,3C10,4.11 10.89,5 12,5C13.11,5 14,4.11 14,3C14,1.89 13.11,1 12,1Z\";\r\nvar mdiHumanMale = \"M12,2A2,2 0 0,1 14,4A2,2 0 0,1 12,6A2,2 0 0,1 10,4A2,2 0 0,1 12,2M10.5,7H13.5A2,2 0 0,1 15.5,9V14.5H14V22H10V14.5H8.5V9A2,2 0 0,1 10.5,7Z\";\r\nvar mdiHumanMaleBoy = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,7H9A2,2 0 0,1 11,9V14.5H9.5V22H5.5V14.5H4V9A2,2 0 0,1 6,7M14.5,12A2,2 0 0,1 16.5,10A2,2 0 0,1 18.5,12A2,2 0 0,1 16.5,14A2,2 0 0,1 14.5,12M13.5,15H19.5V19H18V22H15V19H13.5V15Z\";\r\nvar mdiHumanMaleChild = \"M7 2C5.9 2 5 2.9 5 4S5.9 6 7 6 9 5.11 9 4 8.11 2 7 2M5 7C3.89 7 3 7.89 3 9V15H5V22H10V11.6L12.53 16H14.97L16 14.66V22H20V17H21V14C21 12.89 20.11 12 19 12H16.5C15.9 12 15.37 12.26 15 12.68C14.67 13.1 14.32 13.56 14 14H13.69L10 7.66C9.84 7.38 9.22 7 8.5 7H5M18 8C17.17 8 16.5 8.67 16.5 9.5S17.17 11 18 11 19.5 10.33 19.5 9.5 18.83 8 18 8Z\";\r\nvar mdiHumanMaleFemale = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,7H9A2,2 0 0,1 11,9V14.5H9.5V22H5.5V14.5H4V9A2,2 0 0,1 6,7M16.5,2A2,2 0 0,1 18.5,4A2,2 0 0,1 16.5,6A2,2 0 0,1 14.5,4A2,2 0 0,1 16.5,2M15,22V16H12L14.59,8.41C14.84,7.59 15.6,7 16.5,7C17.4,7 18.16,7.59 18.41,8.41L21,16H18V22H15Z\";\r\nvar mdiHumanMaleGirl = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,7H9A2,2 0 0,1 11,9V14.5H9.5V22H5.5V14.5H4V9A2,2 0 0,1 6,7M14.5,12A2,2 0 0,1 16.5,10A2,2 0 0,1 18.5,12A2,2 0 0,1 16.5,14A2,2 0 0,1 14.5,12M15,15H18L19.5,19H18V22H15V19H13.5L15,15Z\";\r\nvar mdiHumanMaleHeight = \"M7,2C8.78,2 9.67,4.16 8.42,5.42C7.16,6.67 5,5.78 5,4A2,2 0 0,1 7,2M5.5,7H8.5A2,2 0 0,1 10.5,9V14.5H9V22H5V14.5H3.5V9A2,2 0 0,1 5.5,7M21,8H15V10H21M21,11H18V13H21M21,2H15V4H21M21,5H18V7H21M21,14H15V16H21M21,20H15V22H21M21,17H18V19H21\";\r\nvar mdiHumanMaleHeightVariant = \"M7,2C8.78,2 9.67,4.16 8.42,5.42C7.16,6.67 5,5.78 5,4A2,2 0 0,1 7,2M5.5,7H8.5A2,2 0 0,1 10.5,9V14.5H9V22H5V14.5H3.5V9A2,2 0 0,1 5.5,7M19,8H21L18,4L15,8H17V16H15L18,20L21,16H19M22,2H14V4H22M22,20H14V22H22\";\r\nvar mdiHumanMaleMale = \"M7.5,2A2,2 0 0,1 9.5,4A2,2 0 0,1 7.5,6A2,2 0 0,1 5.5,4A2,2 0 0,1 7.5,2M6,7H9A2,2 0 0,1 11,9V14.5H9.5V22H5.5V14.5H4V9A2,2 0 0,1 6,7M16.5,2A2,2 0 0,1 18.5,4A2,2 0 0,1 16.5,6A2,2 0 0,1 14.5,4A2,2 0 0,1 16.5,2M15,7H18A2,2 0 0,1 20,9V14.5H18.5V22H14.5V14.5H13V9A2,2 0 0,1 15,7Z\";\r\nvar mdiHumanPregnant = \"M9,4C9,2.89 9.89,2 11,2C12.11,2 13,2.89 13,4C13,5.11 12.11,6 11,6C9.89,6 9,5.11 9,4M16,13C16,11.66 15.17,10.5 14,10A3,3 0 0,0 11,7A3,3 0 0,0 8,10V17H10V22H13V17H16V13Z\";\r\nvar mdiHumanQueue = \"M5 6C3.9 6 3 6.9 3 8S3.9 10 5 10 7 9.11 7 8 6.11 6 5 6M12 4C10.9 4 10 4.89 10 6S10.9 8 12 8 14 7.11 14 6 13.11 4 12 4M19 2C17.9 2 17 2.9 17 4S17.9 6 19 6 21 5.11 21 4 20.11 2 19 2M3.5 11C2.67 11 2 11.67 2 12.5V17H3V22H7V17H8V12.5C8 11.67 7.33 11 6.5 11H3.5M10.5 9C9.67 9 9 9.67 9 10.5V15H10V20H14V15H15V10.5C15 9.67 14.33 9 13.5 9H10.5M17.5 7C16.67 7 16 7.67 16 8.5V13H17V18H21V13H22V8.5C22 7.67 21.33 7 20.5 7H17.5Z\";\r\nvar mdiHumanScooter = \"M16.5 2.25C17.33 2.25 18 2.92 18 3.75C18 4.58 17.33 5.25 16.5 5.25C15.67 5.25 15 4.58 15 3.75C15 2.92 15.67 2.25 16.5 2.25M20 18C21.11 18 22 18.9 22 20C22 21.11 21.11 22 20 22C19.26 22 18.61 21.6 18.27 21H8.73C8.39 21.6 7.74 22 7 22C5.9 22 5 21.11 5 20C5 18.9 5.9 18 7 18C7.74 18 8.39 18.4 8.73 19H13V13.5L9.73 11.23L6.77 14C6.36 14.37 5.73 14.34 5.35 13.94L2.28 10.65C1.91 10.24 1.93 9.61 2.33 9.23C2.74 8.86 3.37 8.88 3.74 9.28L6.13 11.84L13.26 5.2L13.3 5.18C13.72 4.82 14.35 4.88 14.71 5.3L16.97 8H20C20.55 8 21 8.45 21 9C21 9.55 20.55 10 20 10H16.5C16.15 10 15.85 9.82 15.67 9.56L14.17 7.77L11.64 10.13L14.57 12.18H14.57C14.83 12.36 15 12.66 15 13V19H15.61C16.04 17.13 17.63 15.7 19.58 15.5L18.81 11H20.31L21.39 17.34C20.97 17.12 20.5 17 20 17C18.69 17 17.58 17.84 17.17 19H18.27C18.61 18.4 19.26 18 20 18Z\";\r\nvar mdiHumanWheelchair = \"M8.5 4A2 2 0 0 1 6.5 6A2 2 0 0 1 4.5 4A2 2 0 0 1 6.5 2A2 2 0 0 1 8.5 4M5 7C3.89 7 3 7.89 3 9V15H5V22H8.61A7 7 0 0 1 6.5 17A7 7 0 0 1 10 10.95V9C10 7.89 9.11 7 8 7M13 8V16H18.5L21.2 19.6L22.8 18.4L19.5 14H15V8M12 12.23A5 5 0 0 0 8.5 17A5 5 0 0 0 13.5 22A5 5 0 0 0 18.5 17H16.5A3 3 0 0 1 13.5 20A3 3 0 0 1 10.5 17A3 3 0 0 1 12 14.41Z\";\r\nvar mdiHumbleBundle = \"M16.91,18.12C14.09,18.12 18.43,2.13 18.43,2.13H15.53C15.53,2.13 14.34,5.89 13.55,10.07H11.05C11.11,9.21 11.15,8.34 11.13,7.5C11,0.59 7,1.87 5.18,3.45C3.47,4.95 2.03,7.8 2,10C2.27,10 3.35,10 3.35,10C3.35,10 4.25,5.88 7.07,5.88C9.89,5.88 5.54,21.87 5.54,21.87H8.45C8.45,21.87 9.95,17.59 10.7,12.81L13.09,12.8C12.95,14.04 12.91,15.4 12.93,16.67C13.04,23.56 17.06,22.08 18.86,20.5C20.67,18.92 22,15.58 22,14H20.61C20.62,14.12 19.73,18.12 16.91,18.12V18.12Z\";\r\nvar mdiHvac = \"M8.58 14C8.3 13.55 8.11 13.03 8.06 12.5H15.94C15.89 13.03 15.7 13.55 15.47 14H8.58M12 16C10.97 16 10.08 15.61 9.38 15H14.63C13.92 15.61 13.03 16 12 16M12 8C13.03 8 13.92 8.39 14.63 9H9.38C10.08 8.39 10.97 8 12 8M8.58 10H15.42C15.7 10.45 15.89 10.97 15.94 11.5H8.06C8.11 10.97 8.3 10.45 8.58 10M3 3V21H21V3H3M12 18C8.67 18 6 15.33 6 12S8.67 6 12 6 18 8.67 18 12 15.33 18 12 18Z\";\r\nvar mdiHvacOff = \"M22.11 21.46L2.39 1.73L1.11 3L3 4.89V21H19.11L20.84 22.73L22.11 21.46M12 18C8.67 18 6 15.33 6 12C6 10.82 6.34 9.73 6.92 8.81L8.43 10.32C8.24 10.69 8.1 11.09 8.06 11.5H9.61L10.61 12.5H8.06C8.11 13.03 8.3 13.55 8.58 14H12.11L13.11 15H9.38C10.08 15.61 10.97 16 12 16C12.63 16 13.19 15.84 13.7 15.59L15.19 17.08C14.27 17.66 13.18 18 12 18M12 8C13.03 8 13.92 8.39 14.63 9H12.2L11.27 8.07C11.5 8.03 11.75 8 12 8M9.67 6.47L6.2 3H21V17.8L17.53 14.33C17.83 13.62 18 12.83 18 12C18 8.67 15.33 6 12 6C11.17 6 10.38 6.17 9.67 6.47M15.94 11.5H14.7L13.2 10H15.42C15.7 10.45 15.89 10.97 15.94 11.5Z\";\r\nvar mdiHydraulicOilLevel = \"M15 18C13.34 18 12 16.66 12 15C12 13 15 9.63 15 9.63S18 13 18 15C18 16.66 16.66 18 15 18M20 4V20H10V4H8V20C8 21.11 8.89 22 10 22H20C21.11 22 22 21.11 22 20V4H20M2 19L7 14L2 9V19M16 6V2H14V6H11V8H19V6H16Z\";\r\nvar mdiHydraulicOilTemperature = \"M9 18C7.34 18 6 16.66 6 15C6 13 9 9.63 9 9.63S12 13 12 15C12 16.66 10.66 18 9 18M14 4V20H4V4H2V20C2 21.11 2.89 22 4 22H14C15.11 22 16 21.11 16 20V4H14M10 6V2H8V6H5V8H13V6H10M21 17.5V5.5C21 4.67 20.33 4 19.5 4S18 4.67 18 5.5V17.5C17.37 17.97 17 18.71 17 19.5C17 20.88 18.12 22 19.5 22S22 20.88 22 19.5C22 18.71 21.63 18 21 17.5M20 13H19V6H20V13Z\";\r\nvar mdiHydroPower = \"M17.12 3.55A2 2 0 0 0 15.2 4.95L14.4 7.5A3 3 0 0 0 13.33 7.74L11.5 5.77L10.17 4.29A2 2 0 0 0 10.05 7.12L11.86 9.09A3 3 0 0 0 11.64 9.6A3 3 0 0 0 11.53 10.13L8.92 10.71L6.96 11.15A2 2 0 0 0 9.35 12.67L11.96 12.08A3 3 0 0 0 12.7 12.89L11.9 15.44L11.3 17.35A2 2 0 0 0 13.8 16.04L14.61 13.5A3 3 0 0 0 15.68 13.26L17.5 15.23L18.83 16.7A2 2 0 0 0 18.96 13.88L17.15 11.91A3 3 0 0 0 17.36 11.4A3 3 0 0 0 17.5 10.86L20.09 10.28L22.04 9.85A2 2 0 0 0 19.66 8.33L17.05 8.91A3 3 0 0 0 16.31 8.11L17.11 5.55L17.71 3.65A2 2 0 0 0 17.12 3.55M14.56 9A1.5 1.5 0 0 1 14.95 9.07A1.5 1.5 0 0 1 15.93 10.95A1.5 1.5 0 0 1 14.05 11.93A1.5 1.5 0 0 1 13.07 10.05A1.5 1.5 0 0 1 14.55 9M8 13.67C6.78 14.53 5.39 15 4 15H2V17H4C5.37 17 6.74 16.65 8 16C8.77 16.4 9.58 16.66 10.41 16.81L10.94 15.14L11.03 14.88C9.97 14.73 8.93 14.32 8 13.67M20.45 15C20.5 15.7 20.33 16.41 19.91 17C19.93 17 19.97 17 20 17H22V15H20.45M8 17.67C6.78 18.53 5.39 19 4 19H2V21H4C5.37 21 6.74 20.65 8 20C10.5 21.3 13.5 21.3 16 20C17.26 20.65 18.62 21 20 21H22V19H20C18.61 19 17.22 18.53 16 17.67C13.56 19.38 10.44 19.38 8 17.67Z\";\r\nvar mdiIceCream = \"M17.5 6.05C17.25 3.22 14.89 1 12 1S6.75 3.22 6.5 6.05C5.09 6.28 4 7.5 4 9C4 10.66 5.34 12 7 12L12 22L17 12C18.66 12 20 10.66 20 9C20 7.5 18.91 6.28 17.5 6.05M12 17.53L8.89 11.31C8.95 11.26 9 11.21 9.08 11.16C9.93 11.69 10.93 12 12 12S14.07 11.69 14.92 11.16C15 11.21 15.05 11.26 15.11 11.31L12 17.53Z\";\r\nvar mdiIceCreamOff = \"M22.11 21.46L2.39 1.73L1.11 3L4.95 6.84C4.37 7.38 4 8.14 4 9C4 10.66 5.34 12 7 12L12 22L14.7 16.59L20.84 22.73L22.11 21.46M12 17.53L8.89 11.31C8.95 11.26 9 11.21 9.08 11.16C9.21 11.24 9.35 11.3 9.5 11.37L13.21 15.1L12 17.53M7.15 3.95C8.07 2.2 9.89 1 12 1C14.89 1 17.25 3.22 17.5 6.05C18.91 6.28 20 7.5 20 9C20 10.66 18.66 12 17 12L16.4 13.2L7.15 3.95Z\";\r\nvar mdiIcePop = \"M18.15 14.96L9.95 18.65L5.85 9.65C7.21 9.13 8.12 7.82 8.15 6.36C8.14 5 7.36 3.76 6.15 3.15C6.54 2.8 7 2.5 7.45 2.25C9.71 1.25 12.37 2.23 13.45 4.46M13.15 18.36L14.75 21.86L17.45 20.65L15.85 17.15\";\r\nvar mdiIdCard = \"M4 4C2.89 4 2 4.89 2 6V18C2 19.11 2.89 20 4 20H20C21.11 20 22 19.11 22 18V6C22 4.89 21.11 4 20 4H4M4 6H20V10H4V6M4 12H8V14H4V12M10 12H20V14H10V12M4 16H14V18H4V16M16 16H20V18H16V16Z\";\r\nvar mdiIdentifier = \"M6,18V8H8V18H6M6,4.5H8V6.5H6V4.5M17,4H19V18H17V17.75C17,17.75 15.67,18 15,18A5,5 0 0,1 10,13A5,5 0 0,1 15,8C15.67,8 17,8.25 17,8.25V4M17,10.25C17,10.25 15.67,10 15,10A3,3 0 0,0 12,13A3,3 0 0,0 15,16C15.67,16 17,15.75 17,15.75V10.25Z\";\r\nvar mdiIdeogramCjk = \"M11 4V6H4V10H6V8H18V10H20V6H13V4M8 10V12H13.59L11.59 14H4V16H11V18H10V20H13V16H20V14H14.21L16 12.21V10Z\";\r\nvar mdiIdeogramCjkVariant = \"M11 4V6H4V8H15.36C15.13 8.87 14.63 9.77 13.88 10.69C13.35 11.35 12.71 12 12 12.67C11.29 12 10.65 11.35 10.12 10.69C9.65 10.12 9.3 9.55 9.03 9H6.85C7.21 10.05 7.82 11.03 8.56 11.95C9.13 12.66 9.79 13.34 10.5 14L5.36 18.23L6.64 19.77L12 15.34L17.36 19.77L18.64 18.23L13.5 14C14.21 13.34 14.87 12.66 15.44 11.95C16.41 10.74 17.16 9.43 17.4 8H20V6H13V4Z\";\r\nvar mdiIframe = \"M21,2H3A2,2 0 0,0 1,4V20A2,2 0 0,0 3,22H21A2,2 0 0,0 23,20V4A2,2 0 0,0 21,2M11,17.5L9.5,19L5,14.5L9.5,10L11,11.5L8,14.5L11,17.5M14.5,19L13,17.5L16,14.5L13,11.5L14.5,10L19,14.5L14.5,19M21,7H3V4H21V7Z\";\r\nvar mdiIframeArray = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M10 11H8V18H10V20H6V9H10V11M18 20H14V18H16V11H14V9H18V20M21 7H3V4H21V7Z\";\r\nvar mdiIframeArrayOutline = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M21 20H3V6H21V20M6 8V18H10V16H8V10H10V8H6M16 16H14V18H18V8H14V10H16V16\";\r\nvar mdiIframeBraces = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M11 11H9V12.5C9 13.6 8.1 14.5 7 14.5C8.1 14.5 9 15.4 9 16.5V18H11V20H9C7.9 20 7 19.1 7 18V17.5C7 16.4 6.1 15.5 5 15.5V13.5C6.1 13.5 7 12.6 7 11.5V11C7 9.9 7.9 9 9 9H11V11M19 15.5C17.9 15.5 17 16.4 17 17.5V18C17 19.1 16.1 20 15 20H13V18H15V16.5C15 15.4 15.9 14.5 17 14.5C15.9 14.5 15 13.6 15 12.5V11H13V9H15C16.1 9 17 9.9 17 11V11.5C17 12.6 17.9 13.5 19 13.5V15.5M21 7H3V4H21V7Z\";\r\nvar mdiIframeBracesOutline = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M21 20H3V6H21V20M9 8C7.9 8 7 8.9 7 10C7 11.1 6.1 12 5 12V14C6.1 14 7 14.9 7 16C7 17.1 7.9 18 9 18H11V16H9V15C9 13.9 8.1 13 7 13C8.1 13 9 12.1 9 11V10H11V8M15 8C16.1 8 17 8.9 17 10C17 11.1 17.9 12 19 12V14C17.9 14 17 14.9 17 16C17 17.1 16.1 18 15 18H13V16H15V15C15 13.9 15.9 13 17 13C15.9 13 15 12.1 15 11V10H13V8H15Z\";\r\nvar mdiIframeOutline = \"M9.5,8.5L11,10L8,13L11,16L9.5,17.5L5,13L9.5,8.5M14.5,17.5L13,16L16,13L13,10L14.5,8.5L19,13L14.5,17.5M21,2H3A2,2 0 0,0 1,4V20A2,2 0 0,0 3,22H21A2,2 0 0,0 23,20V4A2,2 0 0,0 21,2M21,20H3V6H21V20Z\";\r\nvar mdiIframeParentheses = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M10 19.4L8.4 20C6.9 18.6 6 16.6 6 14.5S6.9 10.4 8.4 9L10 9.6C8.7 10.7 8 12.6 8 14.5S8.7 18.2 10 19.4M15.6 20L14 19.4C15.3 18.2 16 16.4 16 14.5S15.3 10.8 14 9.6L15.6 9C17.1 10.4 18 12.4 18 14.5C18 16.6 17.1 18.6 15.6 20M21 7H3V4H21V7Z\";\r\nvar mdiIframeParenthesesOutline = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M21 20H3V6H21V20M15.6 8C17.1 9.3 18 11.1 18 13C18 14.9 17.1 16.7 15.6 18L14 17.4C15.3 16.4 16 14.7 16 13S15.3 9.6 14 8.6L15.6 8M8.4 8L10 8.6C8.7 9.6 8 11.3 8 13S8.7 16.4 10 17.4L8.4 18C6.9 16.7 6 14.9 6 13S6.9 9.3 8.4 8Z\";\r\nvar mdiIframeVariable = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M7.4 20C5.9 18.6 5 16.6 5 14.5S5.9 10.4 7.4 9L9 9.6C7.7 10.7 7 12.6 7 14.5S7.7 18.2 9 19.4L7.4 20M12.7 18L11.9 16L10.5 18H9L11.3 14.9L10 12H11.3L12.1 14L13.5 12H15L12.8 15L14.1 18H12.7M16.6 20L15 19.4C16.3 18.2 17 16.4 17 14.5S16.3 10.8 15 9.6L16.6 9C18.1 10.4 19 12.4 19 14.5C19 16.6 18.1 18.6 16.6 20M21 7H3V4H21V7Z\";\r\nvar mdiIframeVariableOutline = \"M21 2H3C1.9 2 1 2.9 1 4V20C1 21.1 1.9 22 3 22H21C22.1 22 23 21.1 23 20V4C23 2.9 22.1 2 21 2M21 20H3V6H21V20M16.6 8C18.1 9.3 19 11.1 19 13C19 14.9 18.1 16.7 16.6 18L15 17.4C16.3 16.4 17 14.7 17 13S16.3 9.6 15 8.6L16.6 8M7.4 8L9 8.6C7.7 9.6 7 11.3 7 13S7.7 16.4 9 17.4L7.4 18C5.9 16.7 5 14.9 5 13S5.9 9.3 7.4 8M12.1 12L13.5 10H15L12.8 13L14.1 16H12.8L12 14L10.6 16H9L11.3 12.9L10 10H11.3L12.1 12Z\";\r\nvar mdiImage = \"M8.5,13.5L11,16.5L14.5,12L19,18H5M21,19V5C21,3.89 20.1,3 19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19Z\";\r\nvar mdiImageAlbum = \"M6,19L9,15.14L11.14,17.72L14.14,13.86L18,19H6M6,4H11V12L8.5,10.5L6,12M18,2H6A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2Z\";\r\nvar mdiImageArea = \"M20,5A2,2 0 0,1 22,7V17A2,2 0 0,1 20,19H4C2.89,19 2,18.1 2,17V7C2,5.89 2.89,5 4,5H20M5,16H19L14.5,10L11,14.5L8.5,11.5L5,16Z\";\r\nvar mdiImageAreaClose = \"M12,23L8,19H16L12,23M20,3A2,2 0 0,1 22,5V15A2,2 0 0,1 20,17H4A2,2 0 0,1 2,15V5A2,2 0 0,1 4,3H20M5,14H19L14.5,8L11,12.5L8.5,9.5L5,14Z\";\r\nvar mdiImageAutoAdjust = \"M19 10V19H5V5H14V3H5C3.92 3 3 3.9 3 5V19C3 20.1 3.92 21 5 21H19C20.12 21 21 20.1 21 19V10H19M17 10L17.94 7.94L20 7L17.94 6.06L17 4L16.06 6.06L14 7L16.06 7.94L17 10M13.25 10.75L12 8L10.75 10.75L8 12L10.75 13.25L12 16L13.25 13.25L16 12L13.25 10.75Z\";\r\nvar mdiImageBroken = \"M19,3A2,2 0 0,1 21,5V11H19V13H19L17,13V15H15V17H13V19H11V21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3H19M21,15V19A2,2 0 0,1 19,21H19L15,21V19H17V17H19V15H21M19,8.5A0.5,0.5 0 0,0 18.5,8H5.5A0.5,0.5 0 0,0 5,8.5V15.5A0.5,0.5 0 0,0 5.5,16H11V15H13V13H15V11H17V9H19V8.5Z\";\r\nvar mdiImageBrokenVariant = \"M21,5V11.59L18,8.58L14,12.59L10,8.59L6,12.59L3,9.58V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5M18,11.42L21,14.43V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V12.42L6,15.41L10,11.41L14,15.41\";\r\nvar mdiImageEdit = \"M22.7 14.3L21.7 15.3L19.7 13.3L20.7 12.3C20.8 12.2 20.9 12.1 21.1 12.1C21.2 12.1 21.4 12.2 21.5 12.3L22.8 13.6C22.9 13.8 22.9 14.1 22.7 14.3M13 19.9V22H15.1L21.2 15.9L19.2 13.9L13 19.9M21 5C21 3.9 20.1 3 19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H11V19.1L12.1 18H5L8.5 13.5L11 16.5L14.5 12L16.1 14.1L21 9.1V5Z\";\r\nvar mdiImageEditOutline = \"M22.7 14.3L21.7 15.3L19.7 13.3L20.7 12.3C20.8 12.2 20.9 12.1 21.1 12.1C21.2 12.1 21.4 12.2 21.5 12.3L22.8 13.6C22.9 13.8 22.9 14.1 22.7 14.3M13 19.9V22H15.1L21.2 15.9L19.2 13.9L13 19.9M11.21 15.83L9.25 13.47L6.5 17H13.12L15.66 14.55L13.96 12.29L11.21 15.83M11 19.9V19.05L11.05 19H5V5H19V11.31L21 9.38V5C21 3.9 20.11 3 19 3H5C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H11V19.9Z\";\r\nvar mdiImageFilterBlackWhite = \"M19,19L12,11V19H5L12,11V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiImageFilterCenterFocus = \"M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M19,19H15V21H19A2,2 0 0,0 21,19V15H19M19,3H15V5H19V9H21V5A2,2 0 0,0 19,3M5,5H9V3H5A2,2 0 0,0 3,5V9H5M5,15H3V19A2,2 0 0,0 5,21H9V19H5V15Z\";\r\nvar mdiImageFilterCenterFocusStrong = \"M12 8C8.44 8 6.65 12.31 9.17 14.83C11.69 17.35 16 15.56 16 12C16 9.79 14.21 8 12 8M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19\";\r\nvar mdiImageFilterCenterFocusStrongOutline = \"M17 12C17 7.55 11.62 5.31 8.46 8.46C5.31 11.61 7.55 17 12 17C14.76 17 17 14.76 17 12M12 15C9.33 15 8 11.77 9.88 9.88C11.77 8 15 9.33 15 12C15 13.66 13.66 15 12 15M5 15H3V19C3 20.1 3.9 21 5 21H9V19H5M5 5H9V3H5C3.9 3 3 3.9 3 5V9H5M19 3H15V5H19V9H21V5C21 3.9 20.1 3 19 3M19 19H15V21H19C20.1 21 21 20.1 21 19V15H19\";\r\nvar mdiImageFilterCenterFocusWeak = \"M5,15H3V19A2,2 0 0,0 5,21H9V19H5M5,5H9V3H5A2,2 0 0,0 3,5V9H5M19,3H15V5H19V9H21V5A2,2 0 0,0 19,3M19,19H15V21H19A2,2 0 0,0 21,19V15H19M12,8A4,4 0 0,0 8,12A4,4 0 0,0 12,16A4,4 0 0,0 16,12A4,4 0 0,0 12,8M12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14Z\";\r\nvar mdiImageFilterDrama = \"M19,18H6A4,4 0 0,1 2,14A4,4 0 0,1 6,10A4,4 0 0,1 10,14H12C12,11.24 10.14,8.92 7.6,8.22C8.61,6.88 10.2,6 12,6C15.03,6 17.5,8.47 17.5,11.5V12H19A3,3 0 0,1 22,15A3,3 0 0,1 19,18M19.35,10.04C18.67,6.59 15.64,4 12,4C9.11,4 6.61,5.64 5.36,8.04C2.35,8.36 0,10.9 0,14A6,6 0 0,0 6,20H19A5,5 0 0,0 24,15C24,12.36 21.95,10.22 19.35,10.04Z\";\r\nvar mdiImageFilterFrames = \"M18,8H6V18H18M20,20H4V6H8.5L12.04,2.5L15.5,6H20M20,4H16L12,0L8,4H4A2,2 0 0,0 2,6V20A2,2 0 0,0 4,22H20A2,2 0 0,0 22,20V6A2,2 0 0,0 20,4Z\";\r\nvar mdiImageFilterHdr = \"M14,6L10.25,11L13.1,14.8L11.5,16C9.81,13.75 7,10 7,10L1,18H23L14,6Z\";\r\nvar mdiImageFilterNone = \"M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiImageFilterTiltShift = \"M5.68,19.74C7.16,20.95 9,21.75 11,21.95V19.93C9.54,19.75 8.21,19.17 7.1,18.31M13,19.93V21.95C15,21.75 16.84,20.95 18.32,19.74L16.89,18.31C15.79,19.17 14.46,19.75 13,19.93M18.31,16.9L19.74,18.33C20.95,16.85 21.75,15 21.95,13H19.93C19.75,14.46 19.17,15.79 18.31,16.9M15,12A3,3 0 0,0 12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12M4.07,13H2.05C2.25,15 3.05,16.84 4.26,18.32L5.69,16.89C4.83,15.79 4.25,14.46 4.07,13M5.69,7.1L4.26,5.68C3.05,7.16 2.25,9 2.05,11H4.07C4.25,9.54 4.83,8.21 5.69,7.1M19.93,11H21.95C21.75,9 20.95,7.16 19.74,5.68L18.31,7.1C19.17,8.21 19.75,9.54 19.93,11M18.32,4.26C16.84,3.05 15,2.25 13,2.05V4.07C14.46,4.25 15.79,4.83 16.9,5.69M11,4.07V2.05C9,2.25 7.16,3.05 5.68,4.26L7.1,5.69C8.21,4.83 9.54,4.25 11,4.07Z\";\r\nvar mdiImageFilterVintage = \"M12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16M18.7,12.4C18.42,12.24 18.13,12.11 17.84,12C18.13,11.89 18.42,11.76 18.7,11.6C20.62,10.5 21.69,8.5 21.7,6.41C19.91,5.38 17.63,5.3 15.7,6.41C15.42,6.57 15.16,6.76 14.92,6.95C14.97,6.64 15,6.32 15,6C15,3.78 13.79,1.85 12,0.81C10.21,1.85 9,3.78 9,6C9,6.32 9.03,6.64 9.08,6.95C8.84,6.75 8.58,6.56 8.3,6.4C6.38,5.29 4.1,5.37 2.3,6.4C2.3,8.47 3.37,10.5 5.3,11.59C5.58,11.75 5.87,11.88 6.16,12C5.87,12.1 5.58,12.23 5.3,12.39C3.38,13.5 2.31,15.5 2.3,17.58C4.09,18.61 6.37,18.69 8.3,17.58C8.58,17.42 8.84,17.23 9.08,17.04C9.03,17.36 9,17.68 9,18C9,20.22 10.21,22.15 12,23.19C13.79,22.15 15,20.22 15,18C15,17.68 14.97,17.36 14.92,17.05C15.16,17.25 15.42,17.43 15.7,17.59C17.62,18.7 19.9,18.62 21.7,17.59C21.69,15.5 20.62,13.5 18.7,12.4Z\";\r\nvar mdiImageFrame = \"M10,14.29L6.5,19H17.46L14.75,15.46L12.78,17.8L10,14.29M5,21V7H18.96V21H5M12,2.4L14.61,5.03H9.37L12,2.4M5,5.03C4.5,5.03 4,5.22 3.61,5.61C3.2,6 3,6.46 3,7V21C3,21.5 3.2,22 3.61,22.39C4,22.8 4.5,23 5,23H18.96C19.5,23 19.96,22.8 20.37,22.39C20.77,22 21,21.5 21,21V7C21,6.46 20.77,6 20.37,5.61C19.96,5.22 19.5,5.03 18.96,5.03H16L12,1L7.96,5.03H5Z\";\r\nvar mdiImageMinus = \"M5 3C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H14.09C14.03 20.67 14 20.34 14 20C14 19.32 14.12 18.64 14.35 18H5L8.5 13.5L11 16.5L14.5 12L16.73 14.97C17.7 14.34 18.84 14 20 14C20.34 14 20.67 14.03 21 14.09V5C21 3.89 20.1 3 19 3H5M16 19V21H24V19H16Z\";\r\nvar mdiImageMove = \"M15,3H19V0L24,5L19,10V7H15V3M21,11.94V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H12.06C12,3.33 12,3.67 12,4A8,8 0 0,0 20,12C20.33,12 20.67,12 21,11.94M19,18L14.5,12L11,16.5L8.5,13.5L5,18H19Z\";\r\nvar mdiImageMultiple = \"M22,16V4A2,2 0 0,0 20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16M11,12L13.03,14.71L16,11L20,16H8M2,6V20A2,2 0 0,0 4,22H18V20H4V6\";\r\nvar mdiImageMultipleOutline = \"M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3M15.96,10.29L13.21,13.83L11.25,11.47L8.5,15H19.5L15.96,10.29Z\";\r\nvar mdiImageOff = \"M21 17.2L6.8 3H19C20.1 3 21 3.9 21 5V17.2M20.7 22L19.7 21H5C3.9 21 3 20.1 3 19V4.3L2 3.3L3.3 2L22 20.7L20.7 22M16.8 18L12.9 14.1L11 16.5L8.5 13.5L5 18H16.8Z\";\r\nvar mdiImageOffOutline = \"M22 20.7L3.3 2L2 3.3L3 4.3V19C3 20.1 3.9 21 5 21H19.7L20.7 22L22 20.7M5 19V6.3L12.6 13.9L11.1 15.8L9 13.1L6 17H15.7L17.7 19H5M8.8 5L6.8 3H19C20.1 3 21 3.9 21 5V17.2L19 15.2V5H8.8\";\r\nvar mdiImageOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M13.96,12.29L11.21,15.83L9.25,13.47L6.5,17H17.5L13.96,12.29Z\";\r\nvar mdiImagePlus = \"M5,3A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H14.09C14.03,20.67 14,20.34 14,20C14,19.32 14.12,18.64 14.35,18H5L8.5,13.5L11,16.5L14.5,12L16.73,14.97C17.7,14.34 18.84,14 20,14C20.34,14 20.67,14.03 21,14.09V5C21,3.89 20.1,3 19,3H5M19,16V19H16V21H19V24H21V21H24V19H21V16H19Z\";\r\nvar mdiImageRemove = \"M5 3C3.9 3 3 3.9 3 5V19C3 20.11 3.9 21 5 21H14.09C14.03 20.67 14 20.34 14 20C14 19.32 14.12 18.64 14.35 18H5L8.5 13.5L11 16.5L14.5 12L16.73 14.97C17.7 14.34 18.84 14 20 14C20.34 14 20.67 14.03 21 14.09V5C21 3.89 20.1 3 19 3H5M16.47 17.88L18.59 20L16.47 22.12L17.88 23.54L20 21.41L22.12 23.54L23.54 22.12L21.41 20L23.54 17.88L22.12 16.46L20 18.59L17.88 16.47L16.46 17.88Z\";\r\nvar mdiImageSearch = \"M15.5,2C18,2 20,4 20,6.5C20,7.38 19.75,8.21 19.31,8.9L22.39,12L21,13.39L17.88,10.32C17.19,10.75 16.37,11 15.5,11C13,11 11,9 11,6.5C11,4 13,2 15.5,2M15.5,4A2.5,2.5 0 0,0 13,6.5A2.5,2.5 0 0,0 15.5,9A2.5,2.5 0 0,0 18,6.5A2.5,2.5 0 0,0 15.5,4M7.5,14.5L4,19H18L13.5,13L10,17.5L7.5,14.5M20,20A2,2 0 0,1 18,22H4A2,2 0 0,1 2,20V6A2,2 0 0,1 4,4H9.5C9.18,4.77 9,5.61 9,6.5A6.5,6.5 0 0,0 15.5,13C16.18,13 16.84,12.89 17.46,12.7L20,15.24V20Z\";\r\nvar mdiImageSearchOutline = \"M15.5,9C16.2,9 16.79,8.76 17.27,8.27C17.76,7.79 18,7.2 18,6.5C18,5.83 17.76,5.23 17.27,4.73C16.79,4.23 16.2,4 15.5,4C14.83,4 14.23,4.23 13.73,4.73C13.23,5.23 13,5.83 13,6.5C13,7.2 13.23,7.79 13.73,8.27C14.23,8.76 14.83,9 15.5,9M19.31,8.91L22.41,12L21,13.41L17.86,10.31C17.08,10.78 16.28,11 15.47,11C14.22,11 13.16,10.58 12.3,9.7C11.45,8.83 11,7.77 11,6.5C11,5.27 11.45,4.2 12.33,3.33C13.2,2.45 14.27,2 15.5,2C16.77,2 17.83,2.45 18.7,3.33C19.58,4.2 20,5.27 20,6.5C20,7.33 19.78,8.13 19.31,8.91M16.5,18H5.5L8.25,14.5L10.22,16.83L12.94,13.31L16.5,18M18,13L20,15V20C20,20.55 19.81,21 19.41,21.4C19,21.79 18.53,22 18,22H4C3.45,22 3,21.79 2.6,21.4C2.21,21 2,20.55 2,20V6C2,5.47 2.21,5 2.6,4.59C3,4.19 3.45,4 4,4H9.5C9.2,4.64 9.03,5.31 9,6H4V20H18V13Z\";\r\nvar mdiImageSizeSelectActual = \"M21,3H3C2,3 1,4 1,5V19A2,2 0 0,0 3,21H21C22,21 23,20 23,19V5C23,4 22,3 21,3M5,17L8.5,12.5L11,15.5L14.5,11L19,17H5Z\";\r\nvar mdiImageSizeSelectLarge = \"M21,15H23V17H21V15M21,11H23V13H21V11M23,19H21V21C22,21 23,20 23,19M13,3H15V5H13V3M21,7H23V9H21V7M21,3V5H23C23,4 22,3 21,3M1,7H3V9H1V7M17,3H19V5H17V3M17,19H19V21H17V19M3,3C2,3 1,4 1,5H3V3M9,3H11V5H9V3M5,3H7V5H5V3M1,11V19A2,2 0 0,0 3,21H15V11H1M3,19L5.5,15.79L7.29,17.94L9.79,14.72L13,19H3Z\";\r\nvar mdiImageSizeSelectSmall = \"M23,15H21V17H23V15M23,11H21V13H23V11M23,19H21V21C22,21 23,20 23,19M15,3H13V5H15V3M23,7H21V9H23V7M21,3V5H23C23,4 22,3 21,3M3,21H11V15H1V19A2,2 0 0,0 3,21M3,7H1V9H3V7M15,19H13V21H15V19M19,3H17V5H19V3M19,19H17V21H19V19M3,3C2,3 1,4 1,5H3V3M3,11H1V13H3V11M11,3H9V5H11V3M7,3H5V5H7V3Z\";\r\nvar mdiImageText = \"M22 13H14V11H22V13M22 7H14V9H22V7M14 17H22V15H14V17M12 9V15C12 16.1 11.1 17 10 17H4C2.9 17 2 16.1 2 15V9C2 7.9 2.9 7 4 7H10C11.1 7 12 7.9 12 9M10.5 15L8.3 12L6.5 14.3L5.3 12.8L3.5 15H10.5Z\";\r\nvar mdiImport = \"M14,12L10,8V11H2V13H10V16M20,18V6C20,4.89 19.1,4 18,4H6A2,2 0 0,0 4,6V9H6V6H18V18H6V15H4V18A2,2 0 0,0 6,20H18A2,2 0 0,0 20,18Z\";\r\nvar mdiInbox = \"M19,15H15A3,3 0 0,1 12,18A3,3 0 0,1 9,15H5V5H19M19,3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiInboxArrowDown = \"M16,10H14V7H10V10H8L12,14M19,15H15A3,3 0 0,1 12,18A3,3 0 0,1 9,15H5V5H19M19,3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiInboxArrowDownOutline = \"M19 3H5A2 2 0 0 0 3 5V19A2 2 0 0 0 5 21H19A2 2 0 0 0 21 19V5A2 2 0 0 0 19 3M5 19V17H8.13A4.13 4.13 0 0 0 9.4 19M19 19H14.6A4.13 4.13 0 0 0 15.87 17H19M19 15H14V16A2 2 0 0 1 10 16V15H5V5H19M16 10H14V7H10V10H8L12 14\";\r\nvar mdiInboxArrowUp = \"M14,14H10V11H8L12,7L16,11H14V14M16,11M5,15V5H19V15H15A3,3 0 0,1 12,18A3,3 0 0,1 9,15H5M19,3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3\";\r\nvar mdiInboxArrowUpOutline = \"M19 3H5A2 2 0 0 0 3 5V19A2 2 0 0 0 5 21H19A2 2 0 0 0 21 19V5A2 2 0 0 0 19 3M5 19V17H8.13A4.13 4.13 0 0 0 9.4 19M19 19H14.6A4.13 4.13 0 0 0 15.87 17H19M19 15H14V16A2 2 0 0 1 10 16V15H5V5H19M8 11H10V14H14V11H16L12 7\";\r\nvar mdiInboxFull = \"M19 15V5H5V15H9C9 16.66 10.34 18 12 18C13.66 18 15 16.66 15 15H19M19 3C20.1 3 21 3.9 21 5V19C21 20.1 20.1 21 19 21H5C3.89 21 3 20.1 3 19L3 5C3 3.9 3.89 3 5 3H19M7 13V11H17V13H7M7 9V7H17V9H7Z\";\r\nvar mdiInboxFullOutline = \"M19 3C20.1 3 21 3.9 21 5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H19M5 19H9.4C8.79 18.47 8.35 17.78 8.13 17H5V19M19 19V17H15.87C15.65 17.78 15.21 18.47 14.6 19H19M19 15V5H5V15H10V16C10 18.67 14 18.67 14 16V15H19M7 7H17V9H7V7M17 11V13H7V11H17Z\";\r\nvar mdiInboxMultiple = \"M19,8V5H5V8H9A3,3 0 0,0 12,11A3,3 0 0,0 15,8H19M19,3A2,2 0 0,1 21,5V12A2,2 0 0,1 19,14H5A2,2 0 0,1 3,12V5A2,2 0 0,1 5,3H19M3,15H9A3,3 0 0,0 12,18A3,3 0 0,0 15,15H21V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V15Z\";\r\nvar mdiInboxMultipleOutline = \"M19,3A2,2 0 0,1 21,5V12A2,2 0 0,1 19,14H5A2,2 0 0,1 3,12V5A2,2 0 0,1 5,3H19M5,10V12H9.4C8.8,11.47 8.34,10.78 8.13,10H5M19,12V10H15.87C15.66,10.78 15.2,11.47 14.6,12H19M19,8V5H5V8H10V9C10,10.07 10.93,11 12,11C13.07,11 14,10.07 14,9V8H19M21,19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V15H10V16C10,17.07 10.93,18 12,18C13.07,18 14,17.07 14,16V15H21V19M5,17V19H9.4C8.8,18.47 8.34,17.78 8.13,17H5M19,19V17H15.87C15.66,17.78 15.2,18.47 14.6,19H19Z\";\r\nvar mdiInboxOutline = \"M19 3H5A2 2 0 0 0 3 5V19A2 2 0 0 0 5 21H19A2 2 0 0 0 21 19V5A2 2 0 0 0 19 3M5 19V17H8.13A4.13 4.13 0 0 0 9.4 19M19 19H14.6A4.13 4.13 0 0 0 15.87 17H19M19 15H14V16A2 2 0 0 1 10 16V15H5V5H19Z\";\r\nvar mdiInboxRemove = \"M19 15H15C15 16.7 13.7 18 12 18S9 16.7 9 15H5V5H19M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M14.1 6.5L15.5 7.9L13.4 10L15.5 12.1L14.1 13.5L12 11.4L9.9 13.5L8.5 12.1L10.6 10L8.5 7.9L9.9 6.5L12 8.6L14.1 6.5Z\";\r\nvar mdiInboxRemoveOutline = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M5 19V17H8.1C8.3 17.8 8.8 18.5 9.4 19M19 19H14.6C15.2 18.5 15.7 17.8 15.9 17H19M19 15H14V16C14 17.1 13.1 18 12 18S10 17.1 10 16V15H5V5H19V15M14.1 6.5L15.5 7.9L13.4 10L15.5 12.1L14.1 13.5L12 11.4L9.9 13.5L8.5 12.1L10.6 10L8.5 7.9L9.9 6.5L12 8.6L14.1 6.5Z\";\r\nvar mdiIncognito = \"M17.06 13C15.2 13 13.64 14.33 13.24 16.1C12.29 15.69 11.42 15.8 10.76 16.09C10.35 14.31 8.79 13 6.94 13C4.77 13 3 14.79 3 17C3 19.21 4.77 21 6.94 21C9 21 10.68 19.38 10.84 17.32C11.18 17.08 12.07 16.63 13.16 17.34C13.34 19.39 15 21 17.06 21C19.23 21 21 19.21 21 17C21 14.79 19.23 13 17.06 13M6.94 19.86C5.38 19.86 4.13 18.58 4.13 17S5.39 14.14 6.94 14.14C8.5 14.14 9.75 15.42 9.75 17S8.5 19.86 6.94 19.86M17.06 19.86C15.5 19.86 14.25 18.58 14.25 17S15.5 14.14 17.06 14.14C18.62 14.14 19.88 15.42 19.88 17S18.61 19.86 17.06 19.86M22 10.5H2V12H22V10.5M15.53 2.63C15.31 2.14 14.75 1.88 14.22 2.05L12 2.79L9.77 2.05L9.72 2.04C9.19 1.89 8.63 2.17 8.43 2.68L6 9H18L15.56 2.68L15.53 2.63Z\";\r\nvar mdiIncognitoCircle = \"M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22 2 17.5 2 12 6.5 2 12 2M14.92 12.81C13.84 12.81 12.95 13.56 12.71 14.56C12.17 14.33 11.66 14.39 11.29 14.55C11.05 13.55 10.15 12.81 9.08 12.81C7.83 12.81 6.82 13.82 6.82 15.07C6.82 16.32 7.83 17.33 9.08 17.33C10.28 17.33 11.24 16.42 11.33 15.25C11.53 15.12 12.04 14.86 12.67 15.26C12.77 16.42 13.73 17.33 14.92 17.33C16.17 17.33 17.18 16.32 17.18 15.07C17.18 13.82 16.17 12.81 14.92 12.81M9.08 13.45C10 13.45 10.7 14.18 10.7 15.07C10.7 15.96 10 16.69 9.08 16.69C8.19 16.69 7.46 15.96 7.46 15.07C7.46 14.18 8.19 13.45 9.08 13.45M14.92 13.45C15.81 13.45 16.54 14.18 16.54 15.07C16.54 15.96 15.81 16.69 14.92 16.69C14 16.69 13.3 15.96 13.3 15.07C13.3 14.18 14 13.45 14.92 13.45M17.83 11.5H6.17V12.17H17.83V11.5M14.15 6.89C14 6.59 13.67 6.43 13.35 6.53L12 7L10.65 6.53L10.61 6.5C10.29 6.43 9.95 6.61 9.84 6.92L8.36 10.83H15.64L14.16 6.92L14.15 6.89Z\";\r\nvar mdiIncognitoCircleOff = \"M22.11 21.46L2.39 1.73L1.11 3L4.06 5.95C2.77 7.63 2 9.72 2 12C2 17.5 6.5 22 12 22C14.28 22 16.37 21.23 18.05 19.94L20.84 22.73L22.11 21.46M8.94 10.83H8.36L8.5 10.41L8.94 10.83M6.17 11.5H9.61L10.28 12.17H6.17V11.5M14.92 17.33C13.73 17.33 12.77 16.42 12.67 15.26C12.04 14.86 11.53 15.12 11.33 15.25C11.24 16.42 10.28 17.33 9.08 17.33C7.83 17.33 6.82 16.32 6.82 15.07C6.82 13.82 7.83 12.81 9.08 12.81C10.15 12.81 11.05 13.55 11.29 14.55C11.65 14.4 12.13 14.34 12.65 14.54L13.31 15.2C13.37 16 14 16.61 14.78 16.67L15.38 17.27C15.23 17.3 15.08 17.33 14.92 17.33M9.94 6.74L6.72 3.5C8.25 2.56 10.06 2 12 2C17.5 2 22 6.5 22 12C22 13.94 21.44 15.75 20.5 17.28L15.37 12.17H17.83V11.5H14.7L14.03 10.83H15.64L14.16 6.92L14.15 6.89C14 6.59 13.67 6.43 13.35 6.53L12 7L10.65 6.53L10.61 6.5C10.36 6.45 10.1 6.55 9.94 6.74M10.7 15.07C10.7 15.96 10 16.69 9.08 16.69C8.19 16.69 7.46 15.96 7.46 15.07S8.19 13.45 9.08 13.45C10 13.45 10.7 14.18 10.7 15.07Z\";\r\nvar mdiIncognitoOff = \"M22.11 21.46L2.39 1.73L1.11 3L6.31 8.2L6 9H7.11L8.61 10.5H2V12H10.11L13.5 15.37C13.38 15.61 13.3 15.85 13.24 16.1C12.29 15.69 11.41 15.8 10.76 16.09C10.35 14.31 8.79 13 6.94 13C4.77 13 3 14.79 3 17C3 19.21 4.77 21 6.94 21C9 21 10.68 19.38 10.84 17.32C11.18 17.08 12.07 16.63 13.16 17.34C13.34 19.39 15 21 17.06 21C17.66 21 18.22 20.86 18.72 20.61L20.84 22.73L22.11 21.46M6.94 19.86C5.38 19.86 4.13 18.58 4.13 17C4.13 15.42 5.39 14.14 6.94 14.14C8.5 14.14 9.75 15.42 9.75 17C9.75 18.58 8.5 19.86 6.94 19.86M17.06 19.86C15.5 19.86 14.25 18.58 14.25 17C14.25 16.74 14.29 16.5 14.36 16.25L17.84 19.73C17.59 19.81 17.34 19.86 17.06 19.86M22 12H15.2L13.7 10.5H22V12M17.06 13C19.23 13 21 14.79 21 17C21 17.25 20.97 17.5 20.93 17.73L19.84 16.64C19.68 15.34 18.66 14.32 17.38 14.17L16.29 13.09C16.54 13.03 16.8 13 17.06 13M12.2 9L7.72 4.5L8.43 2.68C8.63 2.17 9.19 1.89 9.72 2.04L9.77 2.05L12 2.79L14.22 2.05C14.75 1.88 15.32 2.14 15.54 2.63L15.56 2.68L18 9H12.2Z\";\r\nvar mdiInfinity = \"M18.6,6.62C21.58,6.62 24,9 24,12C24,14.96 21.58,17.37 18.6,17.37C17.15,17.37 15.8,16.81 14.78,15.8L12,13.34L9.17,15.85C8.2,16.82 6.84,17.38 5.4,17.38C2.42,17.38 0,14.96 0,12C0,9.04 2.42,6.62 5.4,6.62C6.84,6.62 8.2,7.18 9.22,8.2L12,10.66L14.83,8.15C15.8,7.18 17.16,6.62 18.6,6.62M7.8,14.39L10.5,12L7.84,9.65C7.16,8.97 6.31,8.62 5.4,8.62C3.53,8.62 2,10.13 2,12C2,13.87 3.53,15.38 5.4,15.38C6.31,15.38 7.16,15.03 7.8,14.39M16.2,9.61L13.5,12L16.16,14.35C16.84,15.03 17.7,15.38 18.6,15.38C20.47,15.38 22,13.87 22,12C22,10.13 20.47,8.62 18.6,8.62C17.69,8.62 16.84,8.97 16.2,9.61Z\";\r\nvar mdiInformation = \"M13,9H11V7H13M13,17H11V11H13M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiInformationOutline = \"M11,9H13V7H11M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M11,17H13V11H11V17Z\";\r\nvar mdiInformationVariant = \"M13.5,4A1.5,1.5 0 0,0 12,5.5A1.5,1.5 0 0,0 13.5,7A1.5,1.5 0 0,0 15,5.5A1.5,1.5 0 0,0 13.5,4M13.14,8.77C11.95,8.87 8.7,11.46 8.7,11.46C8.5,11.61 8.56,11.6 8.72,11.88C8.88,12.15 8.86,12.17 9.05,12.04C9.25,11.91 9.58,11.7 10.13,11.36C12.25,10 10.47,13.14 9.56,18.43C9.2,21.05 11.56,19.7 12.17,19.3C12.77,18.91 14.38,17.8 14.54,17.69C14.76,17.54 14.6,17.42 14.43,17.17C14.31,17 14.19,17.12 14.19,17.12C13.54,17.55 12.35,18.45 12.19,17.88C12,17.31 13.22,13.4 13.89,10.71C14,10.07 14.3,8.67 13.14,8.77Z\";\r\nvar mdiInstagram = \"M7.8,2H16.2C19.4,2 22,4.6 22,7.8V16.2A5.8,5.8 0 0,1 16.2,22H7.8C4.6,22 2,19.4 2,16.2V7.8A5.8,5.8 0 0,1 7.8,2M7.6,4A3.6,3.6 0 0,0 4,7.6V16.4C4,18.39 5.61,20 7.6,20H16.4A3.6,3.6 0 0,0 20,16.4V7.6C20,5.61 18.39,4 16.4,4H7.6M17.25,5.5A1.25,1.25 0 0,1 18.5,6.75A1.25,1.25 0 0,1 17.25,8A1.25,1.25 0 0,1 16,6.75A1.25,1.25 0 0,1 17.25,5.5M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiInstrumentTriangle = \"M11.5 2H10.5V6.2C10.4 6.3 10.3 6.3 10.2 6.5L2.1 20.7C1.8 21.3 2.2 22 2.9 22H16V20H4.8L11 9.2L16.7 19.2L18.4 18.2L11.8 6.4L11.5 6.1V2M21 6H20V18L19.5 22H21.5L21 18V6Z\";\r\nvar mdiInvertColors = \"M12,19.58V19.58C10.4,19.58 8.89,18.96 7.76,17.83C6.62,16.69 6,15.19 6,13.58C6,12 6.62,10.47 7.76,9.34L12,5.1M17.66,7.93L12,2.27V2.27L6.34,7.93C3.22,11.05 3.22,16.12 6.34,19.24C7.9,20.8 9.95,21.58 12,21.58C14.05,21.58 16.1,20.8 17.66,19.24C20.78,16.12 20.78,11.05 17.66,7.93Z\";\r\nvar mdiInvertColorsOff = \"M20.65,20.87L18.3,18.5L12,12.23L8.44,8.66L7,7.25L4.27,4.5L3,5.77L5.78,8.55C3.23,11.69 3.42,16.31 6.34,19.24C7.9,20.8 9.95,21.58 12,21.58C13.79,21.58 15.57,21 17.03,19.8L19.73,22.5L21,21.23L20.65,20.87M12,19.59C10.4,19.59 8.89,18.97 7.76,17.83C6.62,16.69 6,15.19 6,13.59C6,12.27 6.43,11 7.21,10L12,14.77V19.59M12,5.1V9.68L19.25,16.94C20.62,14 20.09,10.37 17.65,7.93L12,2.27L8.3,5.97L9.71,7.38L12,5.1Z\";\r\nvar mdiIobroker = \"M12 2C11.5 2 11 2.04 10.5 2.11V4.85C11 4.75 11.5 4.7 12 4.7C12.5 4.7 13 4.75 13.5 4.85V2.12C13 2.04 12.5 2 12 2M9.82 2.25C5.4 3.25 2.11 7.24 2.11 12C2.11 17.5 6.53 22 12 22C17.47 22 21.89 17.5 21.89 12C21.89 7.24 18.6 3.25 14.19 2.25V5.03C17.17 5.96 19.34 8.73 19.34 12C19.34 16 16.05 19.3 12 19.3C7.96 19.3 4.67 16 4.67 12C4.67 8.73 6.84 5.96 9.82 5.03M12 5.45C11.5 5.45 11 5.5 10.5 5.62V18.27C11 18.38 11.5 18.44 12 18.44C12.5 18.44 13 18.39 13.5 18.27V5.62C13 5.5 12.5 5.45 12 5.45Z\";\r\nvar mdiIp = \"M16,11H14V9H16V11M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M10,7H8V17H10V7M12,17H14V13H16A2,2 0 0,0 18,11V9A2,2 0 0,0 16,7H12V17Z\";\r\nvar mdiIpNetwork = \"M15,9H13V7H15V9M22,20V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7A2,2 0 0,1 5,15V5A2,2 0 0,1 7,3H17A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22M9,5H7V15H9V5M11,15H13V11H15A2,2 0 0,0 17,9V7A2,2 0 0,0 15,5H11V15Z\";\r\nvar mdiIpNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M10,6H8V14H10V6M14,6H11V14H13V12H14A2,2 0 0,0 16,10V8A2,2 0 0,0 14,6M14,10H13V8H14V10Z\";\r\nvar mdiIpod = \"M7,2A2,2 0 0,0 5,4V20A2,2 0 0,0 7,22H17A2,2 0 0,0 19,20V4A2,2 0 0,0 17,2H7M7,4H17V10H7V4M12,12A4,4 0 0,1 16,16A4,4 0 0,1 12,20A4,4 0 0,1 8,16A4,4 0 0,1 12,12M12,14A2,2 0 0,0 10,16A2,2 0 0,0 12,18A2,2 0 0,0 14,16A2,2 0 0,0 12,14Z\";\r\nvar mdiIslam = \"M12.3,2C12.2,2 12.1,2 12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22C15,22 16.7,21 18.5,19.5C13,21 8,17 8,12C8,7 13,3 18.5,4.5C16.86,2.86 14.62,1.96 12.3,2M16.8,6.2L15.3,9.7L11.6,10L14.5,12.5L13.6,16L16.8,14L20,16L19,12.5L22,10L18.3,9.7L16.8,6.2Z\";\r\nvar mdiIsland = \"M20 20C18.61 20 17.22 19.53 16 18.67C13.56 20.38 10.44 20.38 8 18.67C6.78 19.53 5.39 20 4 20H2V22H4C5.37 22 6.74 21.65 8 21C10.5 22.3 13.5 22.3 16 21C17.26 21.65 18.62 22 20 22H22V20H20M20.78 19H20C18.82 19 17.64 18.6 16.58 17.85L16 17.45L15.42 17.85C14.39 18.57 13.21 18.95 12 18.95C10.77 18.95 9.59 18.57 8.56 17.85L8 17.45L7.43 17.85C6.36 18.6 5.18 19 4 19H3.22C3.75 17.54 5.58 15 12 15C14 15 15 15.24 15 15.24C15.68 13.87 16.83 10.77 16 6.82L17.06 7.53C17.39 8.96 18 11.75 16.8 15.65C19.43 16.5 20.42 18 20.78 19M22 7.59C21.21 6.5 20 5.71 18.58 5.53C18.7 5.67 18.81 5.83 18.92 6C20.12 7.91 19.87 10.32 18.47 11.95C19.06 10.5 19 8.79 18.08 7.36C18 7.28 17.96 7.2 17.9 7.11C17.5 6.53 16.96 6.06 16.38 5.72C14.35 6.37 12.88 8.27 12.88 10.5C12.88 11.03 12.96 11.53 13.1 12C12.5 11.17 12.16 10.17 12.16 9.07C12.16 7.41 12.96 5.95 14.2 5.03C13.16 4.95 12.09 5.18 11.14 5.78C10.7 6.05 10.32 6.38 10 6.76C10.39 5.82 11.05 5 12 4.4C13.04 3.74 14.25 3.5 15.39 3.69C15.1 3.29 14.75 2.92 14.33 2.6C13.92 2.29 13.47 2.05 13 1.88C14 1.91 15.04 2.24 15.91 2.89C16.35 3.22 16.7 3.62 17 4.05C17.06 4.05 17.12 4.04 17.19 4.04C19.45 4.04 21.37 5.53 22 7.59Z\";\r\nvar mdiIvBag = \"M14 1H10C5 1 5 3 5 3V15C5 15 5 17 10 17V19H11V20C11 21.21 11.8 23 14 23H18V21H14C13.19 21 13 20.45 13 20V19H14V17C19 17 19 15 19 15V3C19 3 19 1 14 1M17 12H14V11H17V12M17 5H14V6H17V8H14V9H17V10H7V3.5C7.3 3.32 8.13 3 10 3H14C15.88 3 16.7 3.32 17 3.5V5Z\";\r\nvar mdiJabber = \"M5.23,5.72C4.61,5.55 5,3.19 5,3.17C5,3.19 12.58,-0.71 16.7,5.73C20.8,12.15 15.86,14.86 13.97,16.06C12.08,17.27 12.73,19.72 12.73,20.13C12.73,20.53 12.16,20.97 12,20.41C11.88,19.84 11.25,16.55 13.33,15.16C17.13,12.61 17.9,10.1 16,6.42C14.2,3 8.28,3.41 7.03,4.08C5.78,4.75 5.86,5.89 5.23,5.72M9.33,12.63L9.11,12.16C9.23,10.28 7.63,10.39 8.08,13.33C8.21,14.16 7.47,13.8 7.45,13.73C6.89,11.44 7.42,10.22 8.55,10.45C9.62,10.68 9.53,11.83 9.53,11.83C9.56,11.78 11,10.17 11.5,10.92C12.58,12.5 10.53,14.47 10.41,14.63C10.28,14.78 10.14,15.05 9.92,14.84C9.7,14.64 9.72,14.5 9.89,14.27C12.77,10 9.59,12.22 9.33,12.63M6.5,15.33V15.31C6.5,15.31 8,18.13 10.61,17.08C11,16.92 11.17,17.14 11.2,17.27C11.27,17.53 11.13,17.64 10.86,17.73C7.86,18.72 5.89,16.63 5.63,16.13C5.39,15.68 5.5,15.38 5.75,15.22C6,15.06 6.5,15.33 6.5,15.33M6,17.5C6,17.5 7.67,19.5 10.8,19C11.09,18.94 11.2,19.13 11.25,19.38C11.3,19.63 11.22,19.84 10.92,19.94C10.63,20.03 7.08,20.5 5.13,17.72C5,17.56 5.3,17.36 5.47,17.36C5.64,17.36 6.03,17.5 6,17.5M5.95,19.39C7.53,21.5 10.33,21.55 11.28,20.88C11.5,20.73 11.7,21.05 11.56,21.19C9.64,23.16 5.67,21 5.27,20.33C5.09,20.05 5.13,19.66 5.31,19.45C5.5,19.25 5.93,19.38 5.95,19.39Z\";\r\nvar mdiJeepney = \"M19,13V7H20V4H4V7H5V13H2C2,13.93 2.5,14.71 3.5,14.93V20A1,1 0 0,0 4.5,21H5.5A1,1 0 0,0 6.5,20V19H17.5V20A1,1 0 0,0 18.5,21H19.5A1,1 0 0,0 20.5,20V14.93C21.5,14.7 22,13.93 22,13H19M8,15A1.5,1.5 0 0,1 6.5,13.5A1.5,1.5 0 0,1 8,12A1.5,1.5 0 0,1 9.5,13.5A1.5,1.5 0 0,1 8,15M16,15A1.5,1.5 0 0,1 14.5,13.5A1.5,1.5 0 0,1 16,12A1.5,1.5 0 0,1 17.5,13.5A1.5,1.5 0 0,1 16,15M17.5,10.5C15.92,10.18 14.03,10 12,10C9.97,10 8,10.18 6.5,10.5V7H17.5V10.5Z\";\r\nvar mdiJellyfish = \"M19.5,14.5C18.92,14.43 18.43,14.92 18.5,15.5C18.5,16.17 17.5,16.17 17.5,15.5V13.2L19.2,12.7C19.92,12.36 20.41,11.68 20.5,10.9C20.5,5.5 16.7,2 12,2C7.3,2 3.5,5.5 3.5,10.9C3.56,11.7 4.06,12.4 4.8,12.7L6.5,13.2V15.5A0.5,0.5 0 0,1 6,16A0.5,0.5 0 0,1 5.5,15.5C5.57,14.92 5.08,14.43 4.5,14.5C3.92,14.43 3.43,14.92 3.5,15.5C3.44,16.91 4.59,18.06 6,18C7.41,18.06 8.56,16.91 8.5,15.5V13.7H9.5V19.4C9.5,20.07 8.5,20.07 8.5,19.4C8.57,18.82 8.08,18.33 7.5,18.4C6.92,18.33 6.43,18.82 6.5,19.4C6.38,20.84 7.55,22.07 9,22C10.41,22.06 11.56,20.91 11.5,19.5V14H12.5V19.5C12.44,20.91 13.59,22.06 15,22C16.41,22.06 17.56,20.91 17.5,19.5C17.5,18.17 15.5,18.17 15.5,19.5C15.5,20.17 14.5,20.17 14.5,19.5V13.8H15.5V15.6C15.5,16.96 16.63,18.06 18,18C19.41,18.06 20.56,16.91 20.5,15.5C20.57,14.92 20.08,14.43 19.5,14.5M10.6,4.7C9.09,5.03 7.79,5.97 7,7.3C6.83,7.5 6.5,7.57 6.3,7.4C6.08,7.23 6.04,6.92 6.2,6.7C7.16,5.19 8.67,4.12 10.4,3.7C10.67,3.68 10.91,3.85 11,4.1C11.06,4.37 10.88,4.65 10.6,4.7Z\";\r\nvar mdiJellyfishOutline = \"M12,4C15.8,4 18.5,6.8 18.5,10.8C14.31,12.39 9.69,12.39 5.5,10.8C5.5,6.8 8.2,4 12,4M12,2C7.3,2 3.5,5.5 3.5,10.9C3.56,11.7 4.06,12.4 4.8,12.7L6.5,13.2V15.5A0.5,0.5 0 0,1 6,16A0.5,0.5 0 0,1 5.5,15.5C5.57,14.92 5.08,14.43 4.5,14.5C3.92,14.43 3.43,14.92 3.5,15.5C3.44,16.86 4.54,18 5.9,18H6C7.41,18.06 8.56,16.91 8.5,15.5V13.7H9.5V19.4C9.5,20.07 8.5,20.07 8.5,19.4C8.57,18.82 8.08,18.33 7.5,18.4C6.92,18.33 6.43,18.82 6.5,19.4C6.39,20.8 7.5,22 8.9,22H9C10.41,22.06 11.56,20.91 11.5,19.5V14H12.5V19.5C12.44,20.91 13.59,22.06 15,22H15.1C16.47,22 17.56,20.86 17.5,19.5C17.5,18.17 15.5,18.17 15.5,19.5C15.5,20.17 14.5,20.17 14.5,19.5V13.8H15.5V15.6C15.5,16.96 16.63,18.06 18,18H18.1C19.47,18 20.56,16.86 20.5,15.5C20.5,14.17 18.5,14.17 18.5,15.5C18.5,16.17 17.5,16.17 17.5,15.5V13.2L19.2,12.7C19.92,12.36 20.41,11.68 20.5,10.9C20.5,5.5 16.7,2 12,2M12,6.2C10.53,6.6 9.24,7.53 8.4,8.8C8,9.33 7.2,8.73 7.6,8.2C8.6,6.73 10.09,5.67 11.8,5.2C12.08,5.14 12.35,5.32 12.4,5.6C12.5,5.9 12.3,6.1 12,6.2Z\";\r\nvar mdiJira = \"M11.53,2C11.53,4.4 13.5,6.35 15.88,6.35H17.66V8.05C17.66,10.45 19.6,12.39 22,12.4V2.84A0.84,0.84 0 0,0 21.16,2H11.53M6.77,6.8C6.78,9.19 8.72,11.13 11.11,11.14H12.91V12.86C12.92,15.25 14.86,17.19 17.25,17.2V7.63C17.24,7.17 16.88,6.81 16.42,6.8H6.77M2,11.6C2,14 3.95,15.94 6.35,15.94H8.13V17.66C8.14,20.05 10.08,22 12.47,22V12.43A0.84,0.84 0 0,0 11.63,11.59L2,11.6Z\";\r\nvar mdiJquery = \"M22.88,10.41C20.77,12.18 17.61,11.9 15.84,9.79C14.06,7.67 14.34,4.5 16.45,2.75L16.96,2.37C15.27,4.19 15.16,7.03 16.8,9C18.43,10.94 21.25,11.32 23.34,9.97L22.88,10.41M21.1,14.5C17.93,17.17 13.2,16.76 10.54,13.58C7.87,10.41 8.29,5.68 11.46,3L12.38,2.36C9.96,5.09 9.84,9.26 12.26,12.14C14.68,15 18.8,15.63 21.91,13.72L21.1,14.5M19.97,19.38C15.53,23.11 8.9,22.53 5.17,18.08C1.45,13.64 2.03,7 6.47,3.29L7.58,2.5C4.07,6.3 3.85,12.23 7.28,16.32C10.71,20.4 16.59,21.22 20.96,18.43L19.97,19.38Z\";\r\nvar mdiJsfiddle = \"M17.34 13.7C17.34 15 16.23 16.04 14.86 16.04C13.65 16.04 12.64 15 11.75 14.04L11.5 13.79C11.5 13.76 11.47 13.73 11.45 13.7C10.74 12.96 9.96 12.22 9.21 12.22C8.32 12.22 7.6 12.88 7.6 13.69C7.6 14.5 8.32 15.17 9.21 15.17C9.97 15.17 10.35 14.75 10.63 14.45L10.7 14.37C10.86 14.2 11.14 14.19 11.31 14.35C11.5 14.5 11.5 14.79 11.33 14.96L11.27 15.03C10.94 15.38 10.35 16.03 9.21 16.03C7.84 16.03 6.73 15 6.73 13.69C6.73 12.4 7.84 11.35 9.21 11.35C10.42 11.35 11.43 12.41 12.32 13.35L12.56 13.6C12.58 13.63 12.6 13.66 12.62 13.69C13.33 14.43 14.11 15.17 14.86 15.17C15.75 15.17 16.47 14.5 16.47 13.69C16.47 12.88 15.75 12.22 14.86 12.22C14.11 12.22 13.72 12.64 13.44 12.94L13.37 13C13.21 13.19 12.94 13.2 12.76 13.04C12.59 12.87 12.58 12.6 12.74 12.42L12.81 12.36C13.13 12 13.73 11.36 14.86 11.36C16.23 11.36 17.34 12.4 17.34 13.7M22 14.85C22 15.96 21.57 17 20.78 17.79C20 18.57 18.95 19 17.84 19H6.28C3.96 18.96 2.07 17.06 2.07 14.75C2.07 13.37 2.76 12.07 3.89 11.28C3.85 11.09 3.83 10.9 3.83 10.7C3.83 9.03 5.2 7.67 6.88 7.67C7.39 7.67 7.88 7.79 8.32 8.03C9.41 6.17 11.43 5 13.6 5C16.97 5 19.7 7.72 19.7 11.07L19.7 11.14C21.11 11.84 22 13.27 22 14.85M21.13 14.85C21.13 13.5 20.33 12.32 19.09 11.81C18.92 11.74 18.81 11.57 18.82 11.38L18.83 11.29C18.83 11.22 18.84 11.14 18.84 11.07C18.84 8.2 16.5 5.87 13.6 5.87C11.6 5.87 9.74 7.03 8.87 8.83C8.82 8.95 8.71 9.04 8.58 9.07C8.46 9.1 8.32 9.07 8.22 9C7.83 8.69 7.37 8.53 6.88 8.53C5.68 8.53 4.7 9.5 4.7 10.7C4.7 10.92 4.73 11.14 4.8 11.34C4.86 11.54 4.78 11.75 4.61 11.85C3.56 12.47 2.94 13.55 2.94 14.75C2.94 16.59 4.44 18.1 6.29 18.13H17.83C18.72 18.13 19.54 17.79 20.16 17.17C20.79 16.55 21.13 15.73 21.13 14.85Z\";\r\nvar mdiJudaism = \"M12,2L9.1,7H3.3L6.3,12L3.3,17H9.1L12,22L14.9,17H20.7L17.7,12L20.7,7H14.9L12,2M12,5L13.2,7H10.8L12,5M8.2,8.5L7.1,10.5L5.9,8.5H8.2M10,8.5H14L16,12L14,15.5H10L8,12L10,8.5M18,8.5L16.8,10.5L15.7,8.5H18M7.1,13.5L8.2,15.5H6L7.1,13.5M16.9,13.5L18.1,15.5H15.8L16.9,13.5M13.3,17L12,19L10.8,17H13.3Z\";\r\nvar mdiJumpRope = \"M21 4.5V10.5C21 11.2 20.5 11.9 19.8 12V17.3C19.8 18.6 19 21.1 16 21.1H14.5C14.9 20.7 15.3 20.2 15.5 19.6H16C18.1 19.6 18.2 17.7 18.2 17.4V12C17.5 11.9 17 11.3 17 10.5V4.5C17 3.7 17.7 3 18.5 3H19.5C20.3 3 21 3.7 21 4.5M14.8 18.2C14.8 19.7 13.6 21 12 21H8C5 21 4.2 18.5 4.2 17.2V12C3.5 11.9 3 11.2 3 10.5V4.5C3 3.7 3.7 3 4.5 3H5.5C6.3 3 7 3.7 7 4.5V10.5C7 11.2 6.5 11.9 5.8 12V17.3C5.8 17.7 5.9 19.5 8 19.5H9.6C9.4 19.1 9.3 18.7 9.3 18.3V8.3C9.3 6.8 10.5 5.5 12.1 5.5S14.8 6.7 14.8 8.3M13.2 8.2C13.2 7.6 12.7 7 12 7S10.8 7.6 10.8 8.2V18.2C10.8 18.9 11.4 19.4 12 19.4S13.2 18.8 13.2 18.2V8.2Z\";\r\nvar mdiKabaddi = \"M11.2 10.6C12.2 11.6 13.4 12.1 14.8 12.1L14.9 14.2C13 14.2 11.3 13.5 9.8 12.1L9.1 11.4L6.8 13.8L9 15.9V21.9H7V16.7L5.7 15.5V17.7L1.5 22L.1 20.6L3.7 17L2.5 13.5C2.3 12.9 2.6 12.4 3.1 12L6.4 8.7C6.8 8.2 7.3 8 7.8 8C8.3 8 8.6 8.1 8.9 8.3L11.2 10.6M24 11.9H22V8.5L20.2 7.8L21.1 12.2L22.1 17.4L23 21.8H20.9L19.1 13.8L17 15.8V21.8H15V14.3L17.1 12.3L16.5 9.3C15.9 9.9 15.2 10.5 14.4 10.9C13.5 10.8 12.6 10.4 11.9 9.7C13.5 9.4 14.6 8.6 15.3 7.4L16.3 5.8C16.9 4.8 17.8 4.5 18.9 5L24 7.2V11.9M11.4 4.4C12.5 4.4 13.4 5.3 13.4 6.4C13.4 7.5 12.5 8.4 11.4 8.4C10.3 8.4 9.4 7.5 9.4 6.4C9.4 5.3 10.3 4.4 11.4 4.4M16.5 .3C17.6 .3 18.5 1.2 18.5 2.3C18.5 3.4 17.6 4.3 16.5 4.3C15.4 4.3 14.5 3.4 14.5 2.3C14.5 1.2 15.4 .3 16.5 .3Z\";\r\nvar mdiKangaroo = \"M19.8 6.59L19 7.97V10.04L17.69 11.61L17.31 13.25L16 14L15.5 13.12L16.44 12.59L16.7 11.45L16.7 11.45L16.77 11.15L16.77 11.15V11.15L17.47 10.31C17.65 10.1 17.62 9.78 17.41 9.61C17.2 9.43 16.88 9.46 16.7 9.67L15.85 10.69L15.56 11.93C15.38 11.96 15.2 12 15 12C14.31 12 13.68 11.76 13.23 11.4C13.15 12.7 12.73 13.81 12.13 14.43L10.5 16.19L9.96 19.79L8.07 21L7.53 20.17L9.04 19.19L9.5 15.92L9.5 15.91L10 14.54C9.47 14.08 9.08 13.28 8.88 12.3L8.71 12.61C8.35 13.25 8 13.9 7.56 14.56C7.11 15.2 6.66 15.9 5.78 16.44C5.34 16.72 4.7 16.84 4.17 16.73C3.61 16.61 3.14 16.26 2.86 15.89C2.31 15.13 2.15 14.35 2 13.62L2.97 13.36C3.2 14 3.5 14.65 3.88 15C4.26 15.33 4.57 15.26 4.84 15C5.16 14.73 5.47 14.15 5.73 13.55C6 12.94 6.22 12.28 6.45 11.6C6.93 10.24 7.39 8.82 8.2 7.36C8.62 6.64 9.13 5.89 9.92 5.22C10.7 4.55 11.73 4 13 4S15.7 5.22 16.58 6.34C17 6.89 17.87 6.82 18.22 6.21L19.14 4.63C19 4.58 18.89 4.5 18.79 4.4C18.4 4 18.4 3.38 18.79 3L19.93 4.13C19.96 4.13 20 4.11 20 4.11C20.41 4.11 20.75 4.35 20.91 4.69L22 7L21 7.5L19.8 6.59Z\";\r\nvar mdiKarate = \"M19,1.27C18.04,0.72 16.82,1.04 16.27,2C15.71,2.95 16.04,4.18 17,4.73C17.95,5.28 19.17,4.96 19.73,4C20.28,3.04 19.95,1.82 19,1.27M21.27,9.34L18.7,13.79L16.96,12.79L18.69,9.79L17.14,8.5L14,13.92V22H12V13.39L2.47,7.89L3.47,6.16L11.27,10.66L13.67,6.5L7.28,4.17L8,2.29L14.73,4.74L15,4.84C15.39,5 15.76,5.15 16.12,5.35L16.96,5.84C17.31,6.04 17.65,6.28 17.96,6.54L18.19,6.74L21.27,9.34Z\";\r\nvar mdiKeg = \"M5,22V20H6V16H5V14H6V11H5V7H11V3H10V2H11L13,2H14V3H13V7H19V11H18V14H19V16H18V20H19V22H5M17,9A1,1 0 0,0 16,8H14A1,1 0 0,0 13,9A1,1 0 0,0 14,10H16A1,1 0 0,0 17,9Z\";\r\nvar mdiKettle = \"M12.5,3C7.81,3 4,5.69 4,9V9C4,10.19 4.5,11.34 5.44,12.33C4.53,13.5 4,14.96 4,16.5C4,17.64 4,18.83 4,20C4,21.11 4.89,22 6,22H19C20.11,22 21,21.11 21,20C21,18.85 21,17.61 21,16.5C21,15.28 20.66,14.07 20,13L22,11L19,8L16.9,10.1C15.58,9.38 14.05,9 12.5,9C10.65,9 8.95,9.53 7.55,10.41C7.19,9.97 7,9.5 7,9C7,7.21 9.46,5.75 12.5,5.75V5.75C13.93,5.75 15.3,6.08 16.33,6.67L18.35,4.65C16.77,3.59 14.68,3 12.5,3M12.5,11C12.84,11 13.17,11.04 13.5,11.09C10.39,11.57 8,14.25 8,17.5V20H6V17.5A6.5,6.5 0 0,1 12.5,11Z\";\r\nvar mdiKettleAlert = \"M9.5 3C4.8 3 1 5.7 1 9C1 10.2 1.5 11.3 2.4 12.3C1.5 13.5 1 15 1 16.5V20C1 21.1 1.9 22 3 22H16C17.1 22 18 21.1 18 20V16.5C18 15.3 17.7 14.1 17 13L19 11L16 8L13.9 10.1C12.6 9.4 11.1 9 9.5 9C7.7 9 5.9 9.5 4.6 10.4C4.2 10 4 9.5 4 9C4 7.2 6.5 5.8 9.5 5.8C10.9 5.8 12.3 6.1 13.3 6.7L15.3 4.7C13.8 3.6 11.7 3 9.5 3M9.5 11C9.8 11 10.2 11 10.5 11.1C7.4 11.6 5 14.2 5 17.5V20H3V17.5C3 13.9 5.9 11 9.5 11M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiKettleAlertOutline = \"M9.5 3C4.8 3 1 5.7 1 9C1 10.2 1.5 11.3 2.4 12.3C1.5 13.5 1 15 1 16.5V20C1 21.1 1.9 22 3 22H16C17.1 22 18 21.1 18 20V16.5C18 15.3 17.7 14.1 17 13L19 11L16 8L13.9 10.1C11 8.5 7.4 8.6 4.6 10.4C4.2 10 4 9.5 4 9C4 7.2 6.5 5.7 9.5 5.7C10.9 5.7 12.3 6.1 13.3 6.7L15.3 4.7C13.6 3.5 11.6 3 9.5 3M9.5 11C13 11 16 14 16 16.5V20H3V16.5C3 14 6 11 9.5 11M10 12.5C7 12.5 5 14 5 17V18H7V17C7 16 7 13.5 10 12.5M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiKettleOff = \"M22.1 21.5L2.4 1.7L1.1 3L4.7 6.6C4.3 7.3 4 8.1 4 9C4 10.2 4.5 11.3 5.4 12.3C4.5 13.5 4 15 4 16.5V20C4 21.1 4.9 22 6 22H19C19.3 22 19.6 21.9 19.9 21.8L20.8 22.7L22.1 21.5M8.2 10.1L7.6 10.4C7.2 10 7 9.5 7 9V8.9L8.2 10.1M8 17.5V20H6V17.5C6 14.9 7.5 12.7 9.7 11.6L10.5 12.4C9 13.6 8 15.4 8 17.5M16.9 10.1L19 8L22 11L20 13C20.7 14.1 21 15.3 21 16.5V17.8L12.2 9H12.5C14 9 15.6 9.4 16.9 10.1M9.5 6.3L7.4 4.2C8.8 3.5 10.6 3 12.5 3C14.7 3 16.8 3.6 18.3 4.7L16.3 6.7C15.3 6.1 13.9 5.8 12.5 5.8C11.4 5.8 10.4 5.9 9.5 6.3Z\";\r\nvar mdiKettleOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L4.7 6.6C4.3 7.3 4 8.1 4 9C4 10.2 4.5 11.3 5.4 12.3C4.5 13.5 4 15 4 16.5V20C4 21.1 4.9 22 6 22H19C19.3 22 19.6 21.9 19.9 21.8L20.8 22.7L22.1 21.5M8.2 10.1L7.6 10.4C7.2 10 7 9.5 7 9V8.9L8.2 10.1M6 20V16.5C6 14.7 7.6 12.6 9.7 11.6L10.9 12.8C9.1 13.4 8 14.8 8 17V18H10V17C10 16.2 10 14.5 11.4 13.3L18.1 20H6M16.9 10.1L19 8L22 11L20 13C20.7 14.1 21 15.3 21 16.5V17.8L18.9 15.7C18.5 13.9 16.8 12.1 14.6 11.4L12.2 9C13.8 8.9 15.4 9.3 16.9 10.1M9.5 6.3L7.4 4.2C8.8 3.5 10.6 3 12.5 3C14.6 3 16.6 3.5 18.3 4.7L16.3 6.7C15.3 6.1 13.9 5.7 12.5 5.7C11.4 5.7 10.3 5.9 9.5 6.3Z\";\r\nvar mdiKettleOutline = \"M12.5 3C7.8 3 4 5.7 4 9C4 10.2 4.5 11.3 5.4 12.3A6.8 6.8 0 0 0 4 16.5V20C4 21.1 4.9 22 6 22H19A2 2 0 0 0 21 20V16.5C21 15.3 20.7 14.1 20 13L22 11L19 8L16.9 10.1A9.2 9.2 0 0 0 7.6 10.4A2 2 0 0 1 7 9C7 7.2 9.5 5.7 12.5 5.7C13.9 5.7 15.3 6.1 16.3 6.7L18.3 4.7A10 10 0 0 0 12.5 3M12.5 11C16 11 19 14 19 16.5V20H6V16.5C6 14 9 11 12.5 11M13 12.5C10 12.5 8 14 8 17V18H10V17C10 16 10 13.5 13 12.5Z\";\r\nvar mdiKettleSteam = \"M19 11L16 8L13.9 10.1C12.58 9.38 11.05 9 9.5 9C7.65 9 5.95 9.53 4.55 10.41C4.19 9.97 4 9.5 4 9C4 7.21 6.46 5.75 9.5 5.75C10.93 5.75 12.3 6.08 13.33 6.67L15.35 4.65C13.77 3.59 11.68 3 9.5 3C4.81 3 1 5.69 1 9C1 10.19 1.5 11.34 2.44 12.33C1.53 13.5 1 14.96 1 16.5V20C1 21.11 1.89 22 3 22H16C17.11 22 18 21.11 18 20V16.5C18 15.28 17.66 14.07 17 13L19 11M5 17.5V20H3V17.5C3 13.91 5.91 11 9.5 11C9.84 11 10.17 11.04 10.5 11.09C7.39 11.57 5 14.25 5 17.5M23 7.3C23 8.93 21.91 10.6 20.38 10.97L19.71 10.29L19 9.6H19.75C20.75 9.6 21.5 8.22 21.5 7.2C21.5 6.18 20.65 5.14 19.65 5.14V3.64C21.5 3.64 23 5.45 23 7.3M17.65 6.73C17.03 6.12 16.65 5.28 16.65 4.35C16.65 2.5 18.15 1 20 1V2.5C19 2.5 18.15 3.33 18.15 4.35C18.15 5.37 19 6.2 20 6.2V7.7C19.18 7.7 18.42 7.95 17.79 8.38L16.72 7.31C17 7.09 17.32 6.89 17.65 6.73Z\";\r\nvar mdiKettleSteamOutline = \"M9.5 3C4.8 3 1 5.7 1 9C1 10.2 1.5 11.3 2.4 12.3C1.5 13.5 .985 15 1 16.5V20C1 21.1 1.9 22 3 22H16C17.11 22 18 21.11 18 20V16.5C18 15.3 17.7 14.1 17 13L19 11L16 8L13.9 10.1C10.97 8.5 7.42 8.63 4.6 10.4C4.22 10.03 4 9.53 4 9C4 7.2 6.5 5.7 9.5 5.7C10.9 5.7 12.3 6.1 13.3 6.7L15.3 4.7C13.59 3.55 11.56 2.96 9.5 3M9.5 11C13 11 16 14 16 16.5V20H3V16.5C3 14 6 11 9.5 11M10 12.5C7 12.5 5 14 5 17V18H7V17C7 16 7 13.5 10 12.5M23 7.3C23 8.93 21.91 10.6 20.38 10.97L19.71 10.29L19 9.6H19.75C20.75 9.6 21.5 8.22 21.5 7.2C21.5 6.18 20.65 5.14 19.65 5.14V3.64C21.5 3.64 23 5.45 23 7.3M17.65 6.73C17.03 6.12 16.65 5.28 16.65 4.35C16.65 2.5 18.15 1 20 1V2.5C19 2.5 18.15 3.33 18.15 4.35C18.15 5.37 19 6.2 20 6.2V7.7C19.18 7.7 18.42 7.95 17.79 8.38L16.72 7.31C17 7.09 17.32 6.89 17.65 6.73Z\";\r\nvar mdiKettlebell = \"M16.2 10.7L16.8 8.3C16.9 8 17.3 6.6 16.5 5.4C15.9 4.5 14.7 4 13 4H11C9.3 4 8.1 4.5 7.5 5.4C6.7 6.6 7.1 7.9 7.2 8.3L7.8 10.7C6.7 11.8 6 13.3 6 15C6 17.1 7.1 18.9 8.7 20H15.3C16.9 18.9 18 17.1 18 15C18 13.3 17.3 11.8 16.2 10.7M9.6 9.5L9.1 7.8V7.7C9.1 7.7 8.9 7 9.2 6.6C9.4 6.2 10 6 11 6H13C13.9 6 14.6 6.2 14.9 6.5C15.2 6.9 15 7.6 15 7.6L14.5 9.5C13.7 9.2 12.9 9 12 9C11.1 9 10.3 9.2 9.6 9.5Z\";\r\nvar mdiKey = \"M7,14A2,2 0 0,1 5,12A2,2 0 0,1 7,10A2,2 0 0,1 9,12A2,2 0 0,1 7,14M12.65,10C11.83,7.67 9.61,6 7,6A6,6 0 0,0 1,12A6,6 0 0,0 7,18C9.61,18 11.83,16.33 12.65,14H17V18H21V14H23V10H12.65Z\";\r\nvar mdiKeyArrowRight = \"M10.7 6C10.1 4.2 8.4 3 6.5 3C4 3 2 5 2 7.5S4 12 6.5 12C8.5 12 10.1 10.8 10.7 9H15V12H18V9H22V6H10.7M6.5 9C5.7 9 5 8.3 5 7.5S5.7 6 6.5 6 8 6.7 8 7.5 7.3 9 6.5 9M13 21V19H8V17H13V15L16 18L13 21\";\r\nvar mdiKeyChain = \"M12.67 13.67C12.2 14.13 11.63 14.5 11 14.73V23H8V21H5V18H8V14.72C6.26 14.1 5 12.46 5 10.5C5 8 7 6 9.5 6C9.54 6 9.57 6 9.6 6C9.13 6.95 8.92 8 9.03 9.08C8.44 9.28 8 9.84 8 10.5C8 11.33 8.67 12 9.5 12C9.73 12 9.95 11.94 10.15 11.85C10.79 12.69 11.67 13.32 12.67 13.67M20.73 19.44L17.97 20.6L17.19 18.76L14.43 19.93L13.26 17.16L16.03 16L14.76 13C12.91 13.08 11.11 12.05 10.35 10.25C9.39 7.96 10.47 5.32 12.76 4.35C13 4.25 13.26 4.18 13.5 4.12C12.84 2.87 11.5 2 10 2C7.79 2 6 3.79 6 6C6 6.08 6 6.16 6 6.24C5.7 6.5 5.4 6.82 5.15 7.15C5.06 6.78 5 6.4 5 6C5 3.24 7.24 1 10 1S15 3.24 15 6C15 7.42 14.4 8.67 13.45 9.57C13.87 10 14.5 10.13 15.08 9.88C15.85 9.56 16.2 8.68 15.88 7.92C15.85 7.83 15.8 7.74 15.74 7.66C15.9 7.13 16 6.58 16 6C16 5.37 15.9 4.76 15.72 4.19C17 4.55 18.1 5.44 18.65 6.76C19.41 8.56 18.89 10.57 17.5 11.81L20.73 19.44M13 8.6C13.37 8.19 13.65 7.71 13.82 7.18C13.28 7.45 12.97 8 13 8.6Z\";\r\nvar mdiKeyChainVariant = \"M12.66 13.67C12.32 14 11.93 14.29 11.5 14.5V21L9.5 23L7.5 21L9.5 19.29L8 18L9.5 16.71L7.5 15V14.5C6 13.77 5 12.26 5 10.5C5 8 7 6 9.5 6C9.54 6 9.58 6 9.61 6C9.59 6.07 9.54 6.12 9.5 6.18C9.23 6.79 9.08 7.43 9.03 8.08C8.43 8.28 8 8.84 8 9.5C8 10.33 8.67 11 9.5 11C9.53 11 9.57 11 9.6 11C10.24 12.25 11.34 13.2 12.66 13.67M16 6C16 5.37 15.9 4.75 15.72 4.18C17.06 4.56 18.21 5.55 18.73 6.96C19.33 8.62 18.89 10.39 17.75 11.59L20 17.68L18.78 20.25L16.22 19.05L17.5 16.76L15.66 16.06L16.63 14.34L14.16 13.41L14 12.95C12.36 12.77 10.88 11.7 10.27 10.04C9.42 7.71 10.63 5.12 12.96 4.27C13.14 4.21 13.33 4.17 13.5 4.13C12.84 2.87 11.53 2 10 2C7.79 2 6 3.79 6 6C6 6.09 6 6.17 6.03 6.26C5.7 6.53 5.4 6.82 5.15 7.15C5.06 6.78 5 6.4 5 6C5 3.24 7.24 1 10 1S15 3.24 15 6C15 7.16 14.6 8.21 13.94 9.06C16.08 8.88 16 6 16 6M12.81 8.1C12.87 8.27 12.96 8.41 13.06 8.54C13.62 7.88 13.97 7.04 14 6.11C13.89 6.13 13.8 6.15 13.7 6.18C12.92 6.47 12.5 7.33 12.81 8.1Z\";\r\nvar mdiKeyChange = \"M6.5,2C8.46,2 10.13,3.25 10.74,5H22V8H18V11H15V8H10.74C10.13,9.75 8.46,11 6.5,11C4,11 2,9 2,6.5C2,4 4,2 6.5,2M6.5,5A1.5,1.5 0 0,0 5,6.5A1.5,1.5 0 0,0 6.5,8A1.5,1.5 0 0,0 8,6.5A1.5,1.5 0 0,0 6.5,5M6.5,13C8.46,13 10.13,14.25 10.74,16H22V19H20V22H18V19H16V22H13V19H10.74C10.13,20.75 8.46,22 6.5,22C4,22 2,20 2,17.5C2,15 4,13 6.5,13M6.5,16A1.5,1.5 0 0,0 5,17.5A1.5,1.5 0 0,0 6.5,19A1.5,1.5 0 0,0 8,17.5A1.5,1.5 0 0,0 6.5,16Z\";\r\nvar mdiKeyLink = \"M6.5 3C4 3 2 5 2 7.5S4 12 6.5 12C8.46 12 10.13 10.75 10.74 9H15V12H18V9H22V6H10.74C10.13 4.25 8.46 3 6.5 3M6.5 6C7.33 6 8 6.67 8 7.5S7.33 9 6.5 9 5 8.33 5 7.5 5.67 6 6.5 6M10 14C8.39 14 6 15.07 6 18C6 20.94 8.39 22 10 22H11V20H10C9.67 20 8 19.9 8 18C8 16.17 9.54 16 10 16H11V14M13 14V16H14C14.33 16 16 16.1 16 18C16 19.83 14.46 20 14 20H13V22H14C15.61 22 18 20.94 18 18C18 15.07 15.61 14 14 14M9 17V19H15V17Z\";\r\nvar mdiKeyMinus = \"M6.5,3C8.46,3 10.13,4.25 10.74,6H22V9H18V12H15V9H10.74C10.13,10.75 8.46,12 6.5,12C4,12 2,10 2,7.5C2,5 4,3 6.5,3M6.5,6A1.5,1.5 0 0,0 5,7.5A1.5,1.5 0 0,0 6.5,9A1.5,1.5 0 0,0 8,7.5A1.5,1.5 0 0,0 6.5,6M8,17H16V19H8V17Z\";\r\nvar mdiKeyOutline = \"M22,19H16V15H13.32C12.18,17.42 9.72,19 7,19C3.14,19 0,15.86 0,12C0,8.14 3.14,5 7,5C9.72,5 12.17,6.58 13.32,9H24V15H22V19M18,17H20V13H22V11H11.94L11.71,10.33C11,8.34 9.11,7 7,7A5,5 0 0,0 2,12A5,5 0 0,0 7,17C9.11,17 11,15.66 11.71,13.67L11.94,13H18V17M7,15A3,3 0 0,1 4,12A3,3 0 0,1 7,9A3,3 0 0,1 10,12A3,3 0 0,1 7,15M7,11A1,1 0 0,0 6,12A1,1 0 0,0 7,13A1,1 0 0,0 8,12A1,1 0 0,0 7,11Z\";\r\nvar mdiKeyPlus = \"M6.5,3C8.46,3 10.13,4.25 10.74,6H22V9H18V12H15V9H10.74C10.13,10.75 8.46,12 6.5,12C4,12 2,10 2,7.5C2,5 4,3 6.5,3M6.5,6A1.5,1.5 0 0,0 5,7.5A1.5,1.5 0 0,0 6.5,9A1.5,1.5 0 0,0 8,7.5A1.5,1.5 0 0,0 6.5,6M8,17H11V14H13V17H16V19H13V22H11V19H8V17Z\";\r\nvar mdiKeyRemove = \"M6.5,3C8.46,3 10.13,4.25 10.74,6H22V9H18V12H15V9H10.74C10.13,10.75 8.46,12 6.5,12C4,12 2,10 2,7.5C2,5 4,3 6.5,3M6.5,6A1.5,1.5 0 0,0 5,7.5A1.5,1.5 0 0,0 6.5,9A1.5,1.5 0 0,0 8,7.5A1.5,1.5 0 0,0 6.5,6M14.59,14L16,15.41L13.41,18L16,20.59L14.59,22L12,19.41L9.41,22L8,20.59L10.59,18L8,15.41L9.41,14L12,16.59L14.59,14Z\";\r\nvar mdiKeyStar = \"M6.5 3C4 3 2 5 2 7.5S4 12 6.5 12C8.46 12 10.13 10.75 10.74 9H15V12H18V9H22V6H10.74C10.13 4.25 8.46 3 6.5 3M6.5 6C7.33 6 8 6.67 8 7.5S7.33 9 6.5 9 5 8.33 5 7.5 5.67 6 6.5 6M12 14L10.87 16.64L8 16.89L10.18 18.77L9.5 21.58L12 20.09L14.45 21.58L13.8 18.77L16 16.89L13.11 16.64Z\";\r\nvar mdiKeyVariant = \"M22,18V22H18V19H15V16H12L9.74,13.74C9.19,13.91 8.61,14 8,14A6,6 0 0,1 2,8A6,6 0 0,1 8,2A6,6 0 0,1 14,8C14,8.61 13.91,9.19 13.74,9.74L22,18M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5Z\";\r\nvar mdiKeyWireless = \"M4.93 5.92L6.34 7.33A8 8 0 0 1 17.66 7.33L19.07 5.92A10 10 0 0 0 4.93 5.92M7.76 8.75L9.17 10.16A4 4 0 0 1 14.83 10.16L16.24 8.75A6 6 0 0 0 7.76 8.75M10.76 15A4.5 4.5 0 1 0 10.76 18H15V21H18V18H22V15M6.5 18A1.5 1.5 0 1 1 8 16.5A1.5 1.5 0 0 1 6.5 18Z\";\r\nvar mdiKeyboard = \"M19,10H17V8H19M19,13H17V11H19M16,10H14V8H16M16,13H14V11H16M16,17H8V15H16M7,10H5V8H7M7,13H5V11H7M8,11H10V13H8M8,8H10V10H8M11,11H13V13H11M11,8H13V10H11M20,5H4C2.89,5 2,5.89 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7C22,5.89 21.1,5 20,5Z\";\r\nvar mdiKeyboardBackspace = \"M21,11H6.83L10.41,7.41L9,6L3,12L9,18L10.41,16.58L6.83,13H21V11Z\";\r\nvar mdiKeyboardCaps = \"M6,18H18V16H6M12,8.41L16.59,13L18,11.58L12,5.58L6,11.58L7.41,13L12,8.41Z\";\r\nvar mdiKeyboardClose = \"M12,23L16,19H8M19,8H17V6H19M19,11H17V9H19M16,8H14V6H16M16,11H14V9H16M16,15H8V13H16M7,8H5V6H7M7,11H5V9H7M8,9H10V11H8M8,6H10V8H8M11,9H13V11H11M11,6H13V8H11M20,3H4C2.89,3 2,3.89 2,5V15A2,2 0 0,0 4,17H20A2,2 0 0,0 22,15V5C22,3.89 21.1,3 20,3Z\";\r\nvar mdiKeyboardEsc = \"M1 7H7V9H3V11H7V13H3V15H7V17H1V7M11 7H15V9H11V11H13C14.11 11 15 11.9 15 13V15C15 16.11 14.11 17 13 17H9V15H13V13H11C9.9 13 9 12.11 9 11V9C9 7.9 9.9 7 11 7M19 7H21C22.11 7 23 7.9 23 9V10H21V9H19V15H21V14H23V15C23 16.11 22.11 17 21 17H19C17.9 17 17 16.11 17 15V9C17 7.9 17.9 7 19 7Z\";\r\nvar mdiKeyboardF1 = \"M6 7H12V9H8V11H11V13H8V17H6V7M14 7H18V17H16V9H14V7Z\";\r\nvar mdiKeyboardF10 = \"M2 7H8V9H4V11H7V13H4V17H2V7M10 7H14V17H12V9H10V7M18 7H20C21.11 7 22 7.9 22 9V15C22 16.11 21.11 17 20 17H18C16.9 17 16 16.11 16 15V9C16 7.9 16.9 7 18 7M18 9V15H20V9H18Z\";\r\nvar mdiKeyboardF11 = \"M3 7H9V9H5V11H8V13H5V17H3V7M11 7H15V17H13V9H11V7M17 7H21V17H19V9H17V7Z\";\r\nvar mdiKeyboardF12 = \"M2 7H8V9H4V11H7V13H4V17H2V7M16 7H20C21.11 7 22 7.9 22 9V11C22 12.11 21.11 13 20 13H18V15H22V17H16V13C16 11.9 16.9 11 18 11H20V9H16V7M10 7H14V17H12V9H10V7Z\";\r\nvar mdiKeyboardF2 = \"M5 7H11V9H7V11H10V13H7V17H5V7M13 7H17C18.11 7 19 7.9 19 9V11C19 12.11 18.11 13 17 13H15V15H19V17H13V13C13 11.9 13.9 11 15 11H17V9H13V7Z\";\r\nvar mdiKeyboardF3 = \"M5 7H11V9H7V11H10V13H7V17H5V7M19 15C19 16.11 18.11 17 17 17H13V15H17V13H15V11H17V9H13V7H17C18.1 7 19 7.89 19 9V10.5C19 11.33 18.33 12 17.5 12C18.33 12 19 12.67 19 13.5V15Z\";\r\nvar mdiKeyboardF4 = \"M5 7H11V9H7V11H10V13H7V17H5V7M13 7H15V11H17V7H19V17H17V13H13V7Z\";\r\nvar mdiKeyboardF5 = \"M5 7H11V9H7V11H10V13H7V17H5V7M13 7H19V9H15V11H17C18.11 11 19 11.9 19 13V15C19 16.11 18.11 17 17 17H13V15H17V13H13V7Z\";\r\nvar mdiKeyboardF6 = \"M5 7H11V9H7V11H10V13H7V17H5V7M15 7H19V9H15V11H17C18.11 11 19 11.9 19 13V15C19 16.11 18.11 17 17 17H15C13.9 17 13 16.11 13 15V9C13 7.9 13.9 7 15 7M15 13V15H17V13H15Z\";\r\nvar mdiKeyboardF7 = \"M5 7H11V9H7V11H10V13H7V17H5V7M15 17H13L17 9H13V7H19V9L15 17Z\";\r\nvar mdiKeyboardF8 = \"M5 7H11V9H7V11H10V13H7V17H5V7M15 13V15H17V13H15M15 9V11H17V9H15M15 17C13.9 17 13 16.11 13 15V13.5C13 12.67 13.67 12 14.5 12C13.67 12 13 11.33 13 10.5V9C13 7.9 13.9 7 15 7H17C18.1 7 19 7.89 19 9V10.5C19 11.33 18.33 12 17.5 12C18.33 12 19 12.67 19 13.5V15C19 16.11 18.11 17 17 17H15Z\";\r\nvar mdiKeyboardF9 = \"M5 7H11V9H7V11H10V13H7V17H5V7M17 17H13V15H17V13H15C13.9 13 13 12.11 13 11V9C13 7.9 13.9 7 15 7H17C18.11 7 19 7.9 19 9V15C19 16.11 18.11 17 17 17M17 11V9H15V11H17Z\";\r\nvar mdiKeyboardOff = \"M1,4.27L2.28,3L20,20.72L18.73,22L15.73,19H4C2.89,19 2,18.1 2,17V7C2,6.5 2.18,6.07 2.46,5.73L1,4.27M19,10V8H17V10H19M19,13V11H17V13H19M16,10V8H14V10H16M16,13V11H14V12.18L11.82,10H13V8H11V9.18L9.82,8L6.82,5H20A2,2 0 0,1 22,7V17C22,17.86 21.46,18.59 20.7,18.87L14.82,13H16M8,15V17H13.73L11.73,15H8M5,10H6.73L5,8.27V10M7,13V11H5V13H7M8,13H9.73L8,11.27V13Z\";\r\nvar mdiKeyboardOffOutline = \"M1,4.27L2.47,5.74C2.18,6.08 2,6.5 2,7V17A2,2 0 0,0 4,19H15.73L18.73,22L20,20.72L2.28,3L1,4.27M4,17V7.27L5,8.27V10H6.73L8,11.27V13H9.73L10.73,14H8V16H12.73L13.73,17H4M5,11H7V13H5V11M17,11H19V13H17V11M19,10H17V8H19V10M14,11H16V13H14.83L14,12.17V11M13,10H11.83L11,9.17V8H13V10M22,7V17C22,17.86 21.45,18.58 20.7,18.87L18.83,17H20V7H8.83L6.83,5H20A2,2 0 0,1 22,7M16,10H14V8H16V10Z\";\r\nvar mdiKeyboardOutline = \"M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M4,7H20V17H4V7M5,8V10H7V8H5M8,8V10H10V8H8M11,8V10H13V8H11M14,8V10H16V8H14M17,8V10H19V8H17M5,11V13H7V11H5M8,11V13H10V11H8M11,11V13H13V11H11M14,11V13H16V11H14M17,11V13H19V11H17M8,14V16H16V14H8Z\";\r\nvar mdiKeyboardReturn = \"M19,7V11H5.83L9.41,7.41L8,6L2,12L8,18L9.41,16.58L5.83,13H21V7H19Z\";\r\nvar mdiKeyboardSettings = \"M19,10H17V8H19M19,13H17V11H19M16,10H14V8H16M16,13H14V11H16M16,17H8V15H16M7,10H5V8H7M7,13H5V11H7M8,11H10V13H8M8,8H10V10H8M11,11H13V13H11M11,8H13V10H11M20,5H4A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiKeyboardSettingsOutline = \"M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M4,7H20V17H4V7M5,8V10H7V8H5M8,8V10H10V8H8M11,8V10H13V8H11M14,8V10H16V8H14M17,8V10H19V8H17M5,11V13H7V11H5M8,11V13H10V11H8M11,11V13H13V11H11M14,11V13H16V11H14M17,11V13H19V11H17M8,14V16H16V14H8Z\";\r\nvar mdiKeyboardSpace = \"M3 15H5V19H19V15H21V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V15Z\";\r\nvar mdiKeyboardTab = \"M20,18H22V6H20M11.59,7.41L15.17,11H1V13H15.17L11.59,16.58L13,18L19,12L13,6L11.59,7.41Z\";\r\nvar mdiKeyboardVariant = \"M6,16H18V18H6V16M6,13V15H2V13H6M7,15V13H10V15H7M11,15V13H13V15H11M14,15V13H17V15H14M18,15V13H22V15H18M2,10H5V12H2V10M19,12V10H22V12H19M18,12H16V10H18V12M8,12H6V10H8V12M12,12H9V10H12V12M15,12H13V10H15V12M2,9V7H4V9H2M5,9V7H7V9H5M8,9V7H10V9H8M11,9V7H13V9H11M14,9V7H16V9H14M17,9V7H22V9H17Z\";\r\nvar mdiKhanda = \"M16 20C19.72 18 22 15.27 22 12C22 9.34 20.46 6.9 17.89 5H17.82C19 6.35 19.68 8.09 19.68 10C19.68 13 18 15 15.5 16.83C15.5 16.84 14.38 17.54 13 18.41V17.33L15 16C15 16 14.8 15.4 14.58 14.46C16.6 13.58 18 11.69 18 9.5C18 7.34 16.64 5.47 14.65 4.57C14.84 3.63 15 3 15 3L12 1L9 3C9 3 9.16 3.63 9.35 4.57C7.37 5.47 6 7.34 6 9.5C6 11.69 7.4 13.58 9.42 14.46C9.2 15.4 9 16 9 16L11 17.33V18.41C9.62 17.54 8.5 16.84 8.5 16.83C6 15 4.32 13 4.32 10C4.32 8.09 5 6.35 6.18 5H6.12C3.54 6.9 2 9.34 2 12C2 15.27 4.29 18 8 20L9 18.5L10.92 19.73L7.34 22L8 23L11 21.07V23H13V21.07L16 23L16.66 22L13.08 19.73L15 18.5L16 20M16.75 9.5C16.75 11.09 15.76 12.46 14.31 13.19C14.14 12.23 14 11.12 14 10C14 8.67 14.2 7.15 14.42 5.86C15.81 6.6 16.75 7.95 16.75 9.5M7.25 9.5C7.25 7.95 8.19 6.6 9.59 5.86C9.8 7.15 10 8.67 10 10C10 11.12 9.86 12.23 9.69 13.19C8.24 12.46 7.25 11.09 7.25 9.5Z\";\r\nvar mdiKickstarter = \"M19.3 10.2L17.5 12L19.3 13.8C21.19 15.67 21.19 18.72 19.3 20.59C17.42 22.46 14.35 22.46 12.47 20.59L11.8 19.93C10.93 21.19 9.5 22 7.83 22C5.16 22 3 19.85 3 17.2V6.8C3 4.15 5.16 2 7.83 2C9.5 2 10.93 2.82 11.8 4.07L12.47 3.41C14.35 1.54 17.42 1.54 19.3 3.41C21.19 5.28 21.19 8.33 19.3 10.2Z\";\r\nvar mdiKlingon = \"M4.79 21.5L4.71 21.24C4.53 20.65 4.47 20.08 4.5 19.4C4.6 18.17 5.14 17.31 5.82 16.59C5.64 16 5.53 15.39 5.53 14.74C5.53 13 6.26 11.44 7.45 10.3C8.33 9.46 9.46 8.86 10.71 8.6C11.37 6.23 11.8 3.8 12 1.5C12.24 3.5 12.65 6.12 13.3 8.58C14.6 8.82 15.76 9.43 16.67 10.3C17.85 11.44 18.59 13 18.59 14.74C18.59 15.35 18.5 15.93 18.33 16.5C19.21 16.92 20.2 17.17 21.5 17.29L21.44 17.44C21.32 17.77 21 18 20.71 18.18L20.69 18.19C20.13 18.57 19.18 19 17.85 19C17.7 19 17.56 19 17.41 19C17.23 19 17.06 18.97 16.9 18.95C16.83 19 16.75 19.1 16.67 19.18C15.5 20.31 13.86 21 12.06 21C10.27 21 8.64 20.31 7.46 19.18C7.42 19.14 7.38 19.1 7.34 19.06C6.34 19.59 5.54 20.33 4.94 21.27L4.8 21.5M6.5 15.94C6.65 15.82 8.2 14.5 8.63 13.78L8.73 13.61C9.65 15 10.4 16.28 11.43 18.08L11.22 18.09C10.08 18.16 9.05 18.37 8.15 18.7C9.17 19.62 10.55 20.19 12.06 20.19C13.54 20.19 14.88 19.65 15.89 18.77C15.64 18.72 15.39 18.65 15.15 18.59C14.38 18.41 13.65 18.22 12.81 18.19L12.62 18.18L12.7 18C13.1 17.2 14.8 14.41 15.23 13.63L15.34 13.81C16 14.77 16.73 15.5 17.58 16.07C17.69 15.64 17.75 15.2 17.75 14.75C17.75 13.25 17.11 11.89 16.09 10.9C15.4 10.24 14.53 9.74 13.55 9.5C13.85 10.5 14.2 11.5 14.59 12.35L14.62 12.4L14.59 12.46C14.2 13.22 13.76 13.95 13.33 14.66C12.94 15.3 12.54 15.96 12.18 16.64L12.08 16.83L11.96 16.65C11.39 15.82 9.75 13.06 9.41 12.5C9.81 11.5 10.15 10.5 10.45 9.5C9.5 9.78 8.7 10.26 8.03 10.9C7 11.88 6.37 13.25 6.37 14.74C6.37 15.16 6.42 15.56 6.5 15.95\";\r\nvar mdiKnife = \"M20.62,2C23.97,7.61 12.47,20.15 12.47,20.15L9.6,17.28L4.91,22L2.77,19.86L20.62,2Z\";\r\nvar mdiKnifeMilitary = \"M22,2L17.39,3.75L10.46,10.68L14,14.22L20.92,7.29C22.43,5.78 22,2 22,2M8.33,10L6.92,11.39L8.33,12.8L2.68,18.46L6.21,22L11.87,16.34L13.28,17.76L14.7,16.34L8.33,10Z\";\r\nvar mdiKodi = \"M12.03,1C11.82,1 11.6,1.11 11.41,1.31C10.56,2.16 9.72,3 8.88,3.84C8.66,4.06 8.6,4.18 8.38,4.38C8.09,4.62 7.96,4.91 7.97,5.28C8,6.57 8,7.84 8,9.13C8,10.46 8,11.82 8,13.16C8,13.26 8,13.34 8.03,13.44C8.11,13.75 8.31,13.82 8.53,13.59C9.73,12.39 10.8,11.3 12,10.09C13.36,8.73 14.73,7.37 16.09,6C16.5,5.6 16.5,5.15 16.09,4.75C14.94,3.6 13.77,2.47 12.63,1.31C12.43,1.11 12.24,1 12.03,1M18.66,7.66C18.45,7.66 18.25,7.75 18.06,7.94C16.91,9.1 15.75,10.24 14.59,11.41C14.2,11.8 14.2,12.23 14.59,12.63C15.74,13.78 16.88,14.94 18.03,16.09C18.43,16.5 18.85,16.5 19.25,16.09C20.36,15 21.5,13.87 22.59,12.75C22.76,12.58 22.93,12.42 23,12.19V11.88C22.93,11.64 22.76,11.5 22.59,11.31C21.47,10.19 20.37,9.06 19.25,7.94C19.06,7.75 18.86,7.66 18.66,7.66M4.78,8.09C4.65,8.04 4.58,8.14 4.5,8.22C3.35,9.39 2.34,10.43 1.19,11.59C0.93,11.86 0.93,12.24 1.19,12.5C1.81,13.13 2.44,13.75 3.06,14.38C3.6,14.92 4,15.33 4.56,15.88C4.72,16.03 4.86,16 4.94,15.81C5,15.71 5,15.58 5,15.47C5,14.29 5,13.37 5,12.19C5,11 5,9.81 5,8.63C5,8.55 5,8.45 4.97,8.38C4.95,8.25 4.9,8.14 4.78,8.09M12.09,14.25C11.89,14.25 11.66,14.34 11.47,14.53C10.32,15.69 9.18,16.87 8.03,18.03C7.63,18.43 7.63,18.85 8.03,19.25C9.14,20.37 10.26,21.47 11.38,22.59C11.54,22.76 11.71,22.93 11.94,23H12.22C12.44,22.94 12.62,22.79 12.78,22.63C13.9,21.5 15.03,20.38 16.16,19.25C16.55,18.85 16.5,18.4 16.13,18C14.97,16.84 13.84,15.69 12.69,14.53C12.5,14.34 12.3,14.25 12.09,14.25Z\";\r\nvar mdiKubernetes = \"M13.95 13.5H13.72C13.54 13.61 13.46 13.82 13.54 14L14.4 16.11C15.23 15.58 15.86 14.79 16.19 13.86L13.96 13.5H13.95M10.5 13.79C10.44 13.62 10.29 13.5 10.12 13.5H10.04L7.82 13.87C8.15 14.79 8.78 15.57 9.61 16.1L10.46 14.03V14C10.5 13.95 10.5 13.86 10.5 13.79M12.33 14.6C12.23 14.42 12 14.35 11.82 14.45C11.75 14.5 11.7 14.53 11.67 14.6H11.66L10.57 16.57C11.35 16.83 12.19 16.88 13 16.69C13.14 16.66 13.29 16.62 13.43 16.57L12.34 14.6H12.33M15.78 10.03L14.1 11.5L14.11 11.53C13.95 11.67 13.93 11.91 14.07 12.06C14.12 12.12 14.18 12.16 14.25 12.18L14.26 12.19L16.43 12.81C16.5 11.84 16.29 10.86 15.78 10.03M12.67 10.19C12.68 10.4 12.85 10.56 13.06 10.55C13.14 10.55 13.21 10.53 13.27 10.5H13.28L15.11 9.19C14.41 8.5 13.5 8.07 12.54 7.95L12.67 10.19M10.73 10.5C10.9 10.61 11.13 10.58 11.25 10.41C11.3 10.35 11.32 10.28 11.33 10.2H11.34L11.46 7.95C11.31 7.97 11.16 8 11 8.03C10.2 8.21 9.46 8.61 8.88 9.19L10.72 10.5H10.73M9.74 12.19C9.94 12.14 10.06 11.93 10 11.73C10 11.65 9.95 11.59 9.89 11.54V11.53L8.21 10C7.69 10.86 7.47 11.84 7.58 12.82L9.74 12.2V12.19M11.38 12.85L12 13.15L12.62 12.85L12.77 12.18L12.34 11.65H11.65L11.22 12.18L11.38 12.85M22.27 14.17L20.5 6.5C20.41 6.08 20.13 5.74 19.76 5.56L12.59 2.13C12.22 1.96 11.78 1.96 11.4 2.13L4.24 5.56C3.87 5.74 3.59 6.08 3.5 6.5L1.73 14.17C1.68 14.37 1.68 14.57 1.73 14.76C1.74 14.82 1.76 14.88 1.78 14.94C1.81 15.03 1.86 15.13 1.91 15.21C1.94 15.25 1.96 15.29 2 15.32L6.95 21.5C6.97 21.5 7 21.54 7 21.56C7.1 21.65 7.19 21.72 7.28 21.78C7.4 21.86 7.54 21.92 7.68 21.95C7.79 22 7.91 22 8 22H16.12C16.19 22 16.26 21.97 16.32 21.95C16.37 21.94 16.42 21.92 16.46 21.91C16.5 21.89 16.53 21.88 16.57 21.86C16.62 21.84 16.67 21.81 16.72 21.78C16.84 21.7 16.95 21.6 17.05 21.5L17.2 21.3L22 15.32C22.1 15.2 22.17 15.07 22.22 14.94C22.24 14.88 22.26 14.82 22.27 14.76C22.32 14.57 22.32 14.36 22.27 14.17M14.84 17.16C14.86 17.22 14.88 17.28 14.91 17.33C14.87 17.41 14.85 17.5 14.88 17.59C15 17.83 15.11 18.05 15.26 18.27C15.34 18.38 15.42 18.5 15.5 18.61C15.5 18.64 15.53 18.69 15.54 18.73C15.66 18.93 15.6 19.19 15.39 19.32S14.92 19.37 14.8 19.17C14.79 19.14 14.78 19.12 14.77 19.09C14.75 19.06 14.73 19 14.71 19C14.66 18.85 14.62 18.72 14.59 18.59C14.5 18.34 14.42 18.1 14.29 17.87C14.24 17.8 14.16 17.75 14.08 17.73L14 17.57C12.71 18.05 11.3 18.05 10.03 17.56L9.93 17.74C9.86 17.75 9.79 17.78 9.74 17.83C9.6 18.07 9.5 18.32 9.41 18.6C9.38 18.73 9.34 18.86 9.29 19C9.27 19 9.25 19.07 9.23 19.1C9.15 19.32 8.91 19.44 8.68 19.36C8.46 19.28 8.34 19.04 8.42 18.81C8.43 18.78 8.45 18.76 8.46 18.73C8.5 18.7 8.5 18.65 8.5 18.62C8.59 18.5 8.66 18.39 8.74 18.27C8.9 18.06 9.03 17.82 9.13 17.58C9.14 17.5 9.13 17.41 9.1 17.33L9.17 17.15C8 16.45 7.12 15.36 6.7 14.06L6.5 14.09C6.44 14.04 6.35 14 6.27 14C6 14.05 5.76 14.13 5.5 14.22C5.39 14.28 5.26 14.33 5.13 14.37C5.1 14.38 5.06 14.39 5 14.4C4.78 14.47 4.54 14.35 4.46 14.13C4.39 13.9 4.5 13.66 4.74 13.58C4.76 13.58 4.79 13.57 4.82 13.57V13.56H4.83L4.94 13.54C5.08 13.5 5.22 13.5 5.35 13.5C5.61 13.5 5.87 13.44 6.12 13.38C6.2 13.33 6.26 13.27 6.31 13.19L6.5 13.14C6.29 11.78 6.6 10.41 7.36 9.27L7.22 9.15C7.22 9.06 7.19 8.97 7.14 8.9C6.94 8.73 6.73 8.58 6.5 8.45C6.38 8.39 6.26 8.32 6.14 8.24C6.12 8.22 6.08 8.19 6.06 8.17L6.05 8.16C5.85 8 5.8 7.74 5.94 7.53C6.03 7.43 6.15 7.38 6.29 7.38C6.4 7.39 6.5 7.43 6.59 7.5L6.68 7.57C6.78 7.66 6.87 7.77 6.96 7.87C7.14 8.06 7.33 8.24 7.54 8.39C7.62 8.43 7.71 8.44 7.8 8.42L7.95 8.53C8.7 7.73 9.68 7.17 10.75 6.93C11 6.87 11.27 6.83 11.53 6.81L11.54 6.63C11.61 6.57 11.65 6.5 11.68 6.4C11.69 6.14 11.67 5.88 11.63 5.63C11.6 5.5 11.58 5.36 11.57 5.22V5.1C11.55 4.86 11.72 4.65 11.96 4.62S12.4 4.77 12.43 5V5.22C12.42 5.36 12.4 5.5 12.37 5.63C12.33 5.88 12.31 6.14 12.32 6.4C12.34 6.5 12.39 6.57 12.46 6.62L12.47 6.81C13.83 6.93 15.09 7.54 16.03 8.53L16.19 8.41C16.28 8.43 16.37 8.42 16.45 8.38C16.66 8.23 16.86 8.05 17.03 7.86C17.12 7.76 17.21 7.66 17.31 7.56C17.34 7.54 17.38 7.5 17.41 7.5C17.58 7.32 17.85 7.32 18 7.5C18.19 7.66 18.18 7.93 18 8.1C18 8.12 17.97 8.14 17.94 8.16C17.92 8.18 17.88 8.21 17.85 8.23C17.74 8.31 17.62 8.38 17.5 8.44C17.27 8.57 17.05 8.72 16.86 8.89C16.8 8.96 16.77 9.04 16.78 9.13L16.62 9.27C17.39 10.4 17.7 11.78 17.5 13.13L17.69 13.18C17.73 13.26 17.8 13.32 17.88 13.36C18.13 13.43 18.39 13.47 18.65 13.5H19.06C19.09 13.53 19.14 13.54 19.18 13.55C19.42 13.58 19.58 13.8 19.55 14.04C19.5 14.27 19.31 14.44 19.07 14.41C19.04 14.4 19 14.4 19 14.39V14.38C18.94 14.38 18.9 14.37 18.86 14.36C18.73 14.32 18.61 14.27 18.5 14.21C18.24 14.11 18 14.04 17.73 14C17.64 14 17.56 14 17.5 14.08C17.43 14.07 17.37 14.06 17.31 14.05C16.9 15.36 16 16.46 14.84 17.16Z\";\r\nvar mdiLabel = \"M17.63,5.84C17.27,5.33 16.67,5 16,5H5A2,2 0 0,0 3,7V17A2,2 0 0,0 5,19H16C16.67,19 17.27,18.66 17.63,18.15L22,12L17.63,5.84Z\";\r\nvar mdiLabelMultiple = \"M4 19H13L11 21H4C3.5 21 2.97 20.79 2.59 20.41C2.21 20.03 2 19.5 2 19V9H4V19M17.63 5.84C17.27 5.33 16.67 5 16 5H8C6.9 5 6 5.9 6 7V15C6 16.1 6.9 17 8 17H16C16.67 17 17.27 16.66 17.63 16.15L22 11L17.63 5.84Z\";\r\nvar mdiLabelMultipleOutline = \"M4 18H13L11 20H4C3.5 20 2.97 19.79 2.59 19.41C2.21 19.03 2 18.5 2 18V8H4V18M17.63 4.84C17.27 4.33 16.67 4 16 4H8C6.9 4 6 4.9 6 6V14C6 15.1 6.9 16 8 16H16C16.67 16 17.27 15.66 17.63 15.15L22 10L17.63 4.84M16 14H8V6H16L19.55 10Z\";\r\nvar mdiLabelOff = \"M2,4.27L3.28,3L20,19.72L18.73,21L16.63,18.9C16.43,18.96 16.22,19 16,19H5A2,2 0 0,1 3,17V7C3,6.5 3.17,6.07 3.46,5.73L2,4.27M17.63,5.84L22,12L19,16.2L7.83,5H16C16.67,5 17.27,5.33 17.63,5.84Z\";\r\nvar mdiLabelOffOutline = \"M2,4.27L3.28,3L20,19.72L18.73,21L16.63,18.9C16.43,18.96 16.22,19 16,19H5A2,2 0 0,1 3,17V7C3,6.5 3.17,6.07 3.46,5.73L2,4.27M5,17H14.73L5,7.27V17M19.55,12L16,7H9.82L7.83,5H16C16.67,5 17.27,5.33 17.63,5.84L22,12L19,16.2L17.59,14.76L19.55,12Z\";\r\nvar mdiLabelOutline = \"M16,17H5V7H16L19.55,12M17.63,5.84C17.27,5.33 16.67,5 16,5H5A2,2 0 0,0 3,7V17A2,2 0 0,0 5,19H16C16.67,19 17.27,18.66 17.63,18.15L22,12L17.63,5.84Z\";\r\nvar mdiLabelPercent = \"M17.63 5.84C17.27 5.33 16.67 5 16 5H5C3.9 5 3 5.9 3 7V17C3 18.11 3.9 19 5 19H16C16.67 19 17.27 18.66 17.63 18.15L22 12L17.63 5.84M8.45 8.03C9.23 8.03 9.87 8.67 9.87 9.45S9.23 10.87 8.45 10.87 7.03 10.23 7.03 9.45 7.67 8.03 8.45 8.03M13.55 15.97C12.77 15.97 12.13 15.33 12.13 14.55S12.77 13.13 13.55 13.13 14.97 13.77 14.97 14.55 14.33 15.97 13.55 15.97M8.2 16L7 14.8L13.8 8L15 9.2L8.2 16Z\";\r\nvar mdiLabelPercentOutline = \"M16 17H5V7H16L19.55 12M17.63 5.84C17.27 5.33 16.67 5 16 5H5C3.9 5 3 5.9 3 7V17C3 18.11 3.9 19 5 19H16C16.67 19 17.27 18.66 17.63 18.15L22 12L17.63 5.84M13.8 8L15 9.2L8.2 16L7 14.8M8.45 8.03C9.23 8.03 9.87 8.67 9.87 9.45S9.23 10.87 8.45 10.87 7.03 10.23 7.03 9.45 7.67 8.03 8.45 8.03M13.55 13.13C14.33 13.13 14.97 13.77 14.97 14.55C14.97 15.33 14.33 15.97 13.55 15.97C12.77 15.97 12.13 15.33 12.13 14.55C12.13 13.77 12.77 13.13 13.55 13.13Z\";\r\nvar mdiLabelVariant = \"M3.5,19L8.34,12L3.5,5H14.5C15.17,5 15.72,5.3 16.13,5.86L20.5,12L16.13,18.14C15.72,18.7 15.17,19 14.5,19H3.5Z\";\r\nvar mdiLabelVariantOutline = \"M6.5,17H15L18.5,12L15,7H6.5L10,12L6.5,17M15,19H3L7.5,12L3,5H15C15.69,5 16.23,5.3 16.64,5.86L21,12L16.64,18.14C16.23,18.7 15.69,19 15,19Z\";\r\nvar mdiLadder = \"M14 1V3H10V1H8V22H10V20H14V22H16V1H14M14 5V8H10V5H14M14 10V13H10V10H14M10 18V15H14V18H10Z\";\r\nvar mdiLadybug = \"M12,5C12.74,5 13.47,5.1 14.15,5.29L15.78,2.46C16.06,2 16.67,1.82 17.15,2.1C17.63,2.37 17.79,3 17.5,3.46L16,6.07C17.22,6.78 18.23,7.79 18.93,9H5.07C5.77,7.79 6.78,6.78 8,6.07L6.5,3.46C6.21,3 6.37,2.37 6.85,2.1C7.33,1.82 7.94,2 8.22,2.46L9.85,5.29C10.53,5.1 11.26,5 12,5M20,13C20,17.17 16.82,20.59 12.75,20.97V10.5H19.6C19.86,11.29 20,12.13 20,13M4,13C4,12.13 4.14,11.29 4.4,10.5H11.25V20.97C7.18,20.59 4,17.17 4,13Z\";\r\nvar mdiLambda = \"M6,20L10.16,7.91L9.34,6H8V4H10C10.42,4 10.78,4.26 10.93,4.63L16.66,18H18V20H16C15.57,20 15.21,19.73 15.07,19.36L11.33,10.65L8.12,20H6Z\";\r\nvar mdiLamp = \"M8,2H16L20,14H4L8,2M11,15H13V20H18V22H6V20H11V15Z\";\r\nvar mdiLamps = \"M10 2L12 9H2L4 2M6 10H8V20H11V22H3V20H6V10M20 8L22 15H12L14 8M16 16H18V20H21V22H13V20H16V16Z\";\r\nvar mdiLan = \"M10,2C8.89,2 8,2.89 8,4V7C8,8.11 8.89,9 10,9H11V11H2V13H6V15H5C3.89,15 3,15.89 3,17V20C3,21.11 3.89,22 5,22H9C10.11,22 11,21.11 11,20V17C11,15.89 10.11,15 9,15H8V13H16V15H15C13.89,15 13,15.89 13,17V20C13,21.11 13.89,22 15,22H19C20.11,22 21,21.11 21,20V17C21,15.89 20.11,15 19,15H18V13H22V11H13V9H14C15.11,9 16,8.11 16,7V4C16,2.89 15.11,2 14,2H10M10,4H14V7H10V4M5,17H9V20H5V17M15,17H19V20H15V17Z\";\r\nvar mdiLanCheck = \"M4 1C2.89 1 2 1.89 2 3V7C2 8.11 2.89 9 4 9H1V11H13V9H10C11.11 9 12 8.11 12 7V3C12 1.89 11.11 1 10 1H4M4 3H10V7H4V3M14 13C12.89 13 12 13.89 12 15V19C12 20.11 12.89 21 14 21H11V23H23V21H20C21.11 21 22 20.11 22 19V15C22 13.89 21.11 13 20 13H14M14 15H20V19H14V15M5.5 20.5L10.5 15.5L9 14L5.5 17.5L3.5 15.5L2 17L5.5 20.5Z\";\r\nvar mdiLanConnect = \"M4,1C2.89,1 2,1.89 2,3V7C2,8.11 2.89,9 4,9H1V11H13V9H10C11.11,9 12,8.11 12,7V3C12,1.89 11.11,1 10,1H4M4,3H10V7H4V3M3,13V18L3,20H10V18H5V13H3M14,13C12.89,13 12,13.89 12,15V19C12,20.11 12.89,21 14,21H11V23H23V21H20C21.11,21 22,20.11 22,19V15C22,13.89 21.11,13 20,13H14M14,15H20V19H14V15Z\";\r\nvar mdiLanDisconnect = \"M4,1C2.89,1 2,1.89 2,3V7C2,8.11 2.89,9 4,9H1V11H13V9H10C11.11,9 12,8.11 12,7V3C12,1.89 11.11,1 10,1H4M4,3H10V7H4V3M14,13C12.89,13 12,13.89 12,15V19C12,20.11 12.89,21 14,21H11V23H23V21H20C21.11,21 22,20.11 22,19V15C22,13.89 21.11,13 20,13H14M3.88,13.46L2.46,14.88L4.59,17L2.46,19.12L3.88,20.54L6,18.41L8.12,20.54L9.54,19.12L7.41,17L9.54,14.88L8.12,13.46L6,15.59L3.88,13.46M14,15H20V19H14V15Z\";\r\nvar mdiLanPending = \"M4,1C2.89,1 2,1.89 2,3V7C2,8.11 2.89,9 4,9H1V11H13V9H10C11.11,9 12,8.11 12,7V3C12,1.89 11.11,1 10,1H4M4,3H10V7H4V3M3,12V14H5V12H3M14,13C12.89,13 12,13.89 12,15V19C12,20.11 12.89,21 14,21H11V23H23V21H20C21.11,21 22,20.11 22,19V15C22,13.89 21.11,13 20,13H14M3,15V17H5V15H3M14,15H20V19H14V15M3,18V20H5V18H3M6,18V20H8V18H6M9,18V20H11V18H9Z\";\r\nvar mdiLanguageC = \"M15.45,15.97L15.87,18.41C15.61,18.55 15.19,18.68 14.63,18.8C14.06,18.93 13.39,19 12.62,19C10.41,18.96 8.75,18.3 7.64,17.04C6.5,15.77 5.96,14.16 5.96,12.21C6,9.9 6.68,8.13 8,6.89C9.28,5.64 10.92,5 12.9,5C13.65,5 14.3,5.07 14.84,5.19C15.38,5.31 15.78,5.44 16.04,5.59L15.44,8.08L14.4,7.74C14,7.64 13.53,7.59 13,7.59C11.85,7.58 10.89,7.95 10.14,8.69C9.38,9.42 9,10.54 8.96,12.03C8.97,13.39 9.33,14.45 10.04,15.23C10.75,16 11.74,16.4 13.03,16.41L14.36,16.29C14.79,16.21 15.15,16.1 15.45,15.97Z\";\r\nvar mdiLanguageCpp = \"M10.5,15.97L10.91,18.41C10.65,18.55 10.23,18.68 9.67,18.8C9.1,18.93 8.43,19 7.66,19C5.45,18.96 3.79,18.3 2.68,17.04C1.56,15.77 1,14.16 1,12.21C1.05,9.9 1.72,8.13 3,6.89C4.32,5.64 5.96,5 7.94,5C8.69,5 9.34,5.07 9.88,5.19C10.42,5.31 10.82,5.44 11.08,5.59L10.5,8.08L9.44,7.74C9.04,7.64 8.58,7.59 8.05,7.59C6.89,7.58 5.93,7.95 5.18,8.69C4.42,9.42 4.03,10.54 4,12.03C4,13.39 4.37,14.45 5.08,15.23C5.79,16 6.79,16.4 8.07,16.41L9.4,16.29C9.83,16.21 10.19,16.1 10.5,15.97M11,11H13V9H15V11H17V13H15V15H13V13H11V11M18,11H20V9H22V11H24V13H22V15H20V13H18V11Z\";\r\nvar mdiLanguageCsharp = \"M11.5,15.97L11.91,18.41C11.65,18.55 11.23,18.68 10.67,18.8C10.1,18.93 9.43,19 8.66,19C6.45,18.96 4.79,18.3 3.68,17.04C2.56,15.77 2,14.16 2,12.21C2.05,9.9 2.72,8.13 4,6.89C5.32,5.64 6.96,5 8.94,5C9.69,5 10.34,5.07 10.88,5.19C11.42,5.31 11.82,5.44 12.08,5.59L11.5,8.08L10.44,7.74C10.04,7.64 9.58,7.59 9.05,7.59C7.89,7.58 6.93,7.95 6.18,8.69C5.42,9.42 5.03,10.54 5,12.03C5,13.39 5.37,14.45 6.08,15.23C6.79,16 7.79,16.4 9.07,16.41L10.4,16.29C10.83,16.21 11.19,16.1 11.5,15.97M13.89,19L14.5,15H13L13.34,13H14.84L15.16,11H13.66L14,9H15.5L16.11,5H18.11L17.5,9H18.5L19.11,5H21.11L20.5,9H22L21.66,11H20.16L19.84,13H21.34L21,15H19.5L18.89,19H16.89L17.5,15H16.5L15.89,19H13.89M16.84,13H17.84L18.16,11H17.16L16.84,13Z\";\r\nvar mdiLanguageCss3 = \"M5,3L4.35,6.34H17.94L17.5,8.5H3.92L3.26,11.83H16.85L16.09,15.64L10.61,17.45L5.86,15.64L6.19,14H2.85L2.06,18L9.91,21L18.96,18L20.16,11.97L20.4,10.76L21.94,3H5Z\";\r\nvar mdiLanguageFortran = \"M5 4V6H6C6.55 6 7 6.45 7 7V17C7 17.55 6.55 18 6 18H5V20H14V18H12C11.45 18 11 17.55 11 17V13H13C13.55 13 14 13.45 14 14V16H16V8H14V10C14 10.55 13.55 11 13 11H11V6H16C17.11 6 18 7.34 18 9V10H20V4Z\";\r\nvar mdiLanguageGo = \"M2.64,10.33L2.62,10.27L2.84,10L2.96,9.92H6.8L6.83,10L6.65,10.26L6.54,10.32L2.64,10.33M1.03,11.31L1,11.26L1.22,10.97L1.34,10.91H6.24L6.29,11L6.21,11.24L6.11,11.31H1.03M3.63,12.3L3.59,12.24L3.75,11.96L3.85,11.9H6L6.07,11.97L6.05,12.22L5.97,12.3H3.63M14.78,10.14L13,10.61C12.81,10.65 12.8,10.66 12.66,10.5C12.5,10.32 12.39,10.21 12.16,10.1C11.5,9.76 10.83,9.86 10.22,10.25C9.5,10.73 9.11,11.42 9.12,12.3C9.13,13.16 9.72,13.87 10.57,14C11.3,14.09 11.91,13.83 12.4,13.28L12.69,12.89H10.62C10.4,12.89 10.35,12.75 10.42,12.57L10.97,11.39C11,11.33 11.08,11.22 11.24,11.22H14.68C14.83,10.72 15.09,10.26 15.43,9.81C16.21,8.78 17.16,8.24 18.43,8C19.5,7.82 20.56,7.93 21.5,8.57C22.34,9.15 22.87,9.93 23,10.96C23.19,12.41 22.76,13.59 21.76,14.61C21.05,15.33 20.18,15.78 19.19,16L18.33,16.08C17.35,16.06 16.46,15.78 15.71,15.13C15.19,14.68 14.83,14.14 14.65,13.5C14.5,13.74 14.38,13.97 14.21,14.2C13.44,15.22 12.43,15.85 11.15,16C10.1,16.16 9.12,15.95 8.26,15.31C7.47,14.71 7,13.91 6.9,12.92C6.76,11.75 7.1,10.7 7.81,9.78C8.57,8.78 9.58,8.15 10.82,7.92C11.82,7.74 12.79,7.86 13.66,8.44C14.23,8.82 14.63,9.34 14.9,9.96C14.94,10.05 14.9,10.11 14.78,10.14M20.89,11.74L20.86,11.38C20.67,10.32 19.69,9.72 18.67,9.95C17.66,10.17 17,10.8 16.79,11.81C16.6,12.65 17,13.5 17.77,13.84C18.36,14.1 18.96,14.06 19.53,13.78C20.37,13.35 20.84,12.66 20.89,11.74Z\";\r\nvar mdiLanguageHaskell = \"M2.08,19L6.75,12L2.08,5H5.58L10.25,12L5.58,19H2.08M6.75,19L11.42,12L6.75,5H10.25L19.59,19H16.09L13.17,14.63L10.25,19H6.75M18.03,14.92L16.5,12.58H21.92V14.92H18.03M15.7,11.42L14.14,9.08H21.92V11.42H15.7Z\";\r\nvar mdiLanguageHtml5 = \"M12,17.56L16.07,16.43L16.62,10.33H9.38L9.2,8.3H16.8L17,6.31H7L7.56,12.32H14.45L14.22,14.9L12,15.5L9.78,14.9L9.64,13.24H7.64L7.93,16.43L12,17.56M4.07,3H19.93L18.5,19.2L12,21L5.5,19.2L4.07,3Z\";\r\nvar mdiLanguageJava = \"M16.5,6.08C16.5,6.08 9.66,7.79 12.94,11.56C13.91,12.67 12.69,13.67 12.69,13.67C12.69,13.67 15.14,12.42 14,10.82C12.94,9.35 12.14,8.62 16.5,6.08M12.03,7.28C16.08,4.08 14,2 14,2C14.84,5.3 11.04,6.3 9.67,8.36C8.73,9.76 10.13,11.27 12,13C11.29,11.3 8.78,9.84 12.03,7.28M9.37,17.47C6.29,18.33 11.25,20.1 15.16,18.43C14.78,18.28 14.41,18.1 14.06,17.89C12.7,18.2 11.3,18.26 9.92,18.07C8.61,17.91 9.37,17.47 9.37,17.47M14.69,15.79C12.94,16.17 11.13,16.26 9.35,16.05C8.04,15.92 8.9,15.28 8.9,15.28C5.5,16.41 10.78,17.68 15.5,16.3C15.21,16.19 14.93,16 14.69,15.79M18.11,19.09C18.11,19.09 18.68,19.56 17.5,19.92C15.22,20.6 8.07,20.81 6.09,19.95C5.38,19.64 6.72,19.21 7.14,19.12C7.37,19.06 7.6,19.04 7.83,19.04C7.04,18.5 2.7,20.14 5.64,20.6C13.61,21.9 20.18,20 18.11,19.09M15.37,14.23C15.66,14.04 15.97,13.88 16.29,13.74C16.29,13.74 14.78,14 13.27,14.14C11.67,14.3 10.06,14.32 8.46,14.2C6.11,13.89 9.75,13 9.75,13C8.65,13 7.57,13.26 6.59,13.75C4.54,14.75 11.69,15.2 15.37,14.23M16.27,16.65C16.25,16.69 16.23,16.72 16.19,16.75C21.2,15.44 19.36,12.11 16.96,12.94C16.83,13 16.72,13.08 16.65,13.19C16.79,13.14 16.93,13.1 17.08,13.07C18.28,12.83 20,14.7 16.27,16.65M16.4,21.26C13.39,21.78 10.31,21.82 7.28,21.4C7.28,21.4 7.74,21.78 10.09,21.93C13.69,22.16 19.22,21.8 19.35,20.1C19.38,20.11 19.12,20.75 16.4,21.26Z\";\r\nvar mdiLanguageJavascript = \"M3,3H21V21H3V3M7.73,18.04C8.13,18.89 8.92,19.59 10.27,19.59C11.77,19.59 12.8,18.79 12.8,17.04V11.26H11.1V17C11.1,17.86 10.75,18.08 10.2,18.08C9.62,18.08 9.38,17.68 9.11,17.21L7.73,18.04M13.71,17.86C14.21,18.84 15.22,19.59 16.8,19.59C18.4,19.59 19.6,18.76 19.6,17.23C19.6,15.82 18.79,15.19 17.35,14.57L16.93,14.39C16.2,14.08 15.89,13.87 15.89,13.37C15.89,12.96 16.2,12.64 16.7,12.64C17.18,12.64 17.5,12.85 17.79,13.37L19.1,12.5C18.55,11.54 17.77,11.17 16.7,11.17C15.19,11.17 14.22,12.13 14.22,13.4C14.22,14.78 15.03,15.43 16.25,15.95L16.67,16.13C17.45,16.47 17.91,16.68 17.91,17.26C17.91,17.74 17.46,18.09 16.76,18.09C15.93,18.09 15.45,17.66 15.09,17.06L13.71,17.86Z\";\r\nvar mdiLanguageKotlin = \"M2 2H22L12 12L22 22H2Z\";\r\nvar mdiLanguageLua = \"M10.5,5A8.5,8.5 0 0,0 2,13.5A8.5,8.5 0 0,0 10.5,22A8.5,8.5 0 0,0 19,13.5A8.5,8.5 0 0,0 10.5,5M13.5,13A2.5,2.5 0 0,1 11,10.5A2.5,2.5 0 0,1 13.5,8A2.5,2.5 0 0,1 16,10.5A2.5,2.5 0 0,1 13.5,13M19.5,2A2.5,2.5 0 0,0 17,4.5A2.5,2.5 0 0,0 19.5,7A2.5,2.5 0 0,0 22,4.5A2.5,2.5 0 0,0 19.5,2\";\r\nvar mdiLanguageMarkdown = \"M20.56 18H3.44C2.65 18 2 17.37 2 16.59V7.41C2 6.63 2.65 6 3.44 6H20.56C21.35 6 22 6.63 22 7.41V16.59C22 17.37 21.35 18 20.56 18M6.81 15.19V11.53L8.73 13.88L10.65 11.53V15.19H12.58V8.81H10.65L8.73 11.16L6.81 8.81H4.89V15.19H6.81M19.69 12H17.77V8.81H15.85V12H13.92L16.81 15.28L19.69 12Z\";\r\nvar mdiLanguageMarkdownOutline = \"M20.56 18H3.44C2.65 18 2 17.37 2 16.59V7.41C2 6.63 2.65 6 3.44 6H20.56C21.35 6 22 6.63 22 7.41V16.59C22 17.37 21.35 18 20.56 18M3.44 6.94C3.18 6.94 2.96 7.15 2.96 7.41V16.6C2.96 16.85 3.18 17.06 3.44 17.06H20.56C20.82 17.06 21.04 16.85 21.04 16.6V7.41C21.04 7.15 20.82 6.94 20.56 6.94H3.44M4.89 15.19V8.81H6.81L8.73 11.16L10.65 8.81H12.58V15.19H10.65V11.53L8.73 13.88L6.81 11.53V15.19H4.89M16.9 15.19L14 12.09H15.94V8.81H17.86V12.09H19.79L16.9 15.19\";\r\nvar mdiLanguagePhp = \"M12,18.08C5.37,18.08 0,15.36 0,12C0,8.64 5.37,5.92 12,5.92C18.63,5.92 24,8.64 24,12C24,15.36 18.63,18.08 12,18.08M6.81,10.13C7.35,10.13 7.72,10.23 7.9,10.44C8.08,10.64 8.12,11 8.03,11.47C7.93,12 7.74,12.34 7.45,12.56C7.17,12.78 6.74,12.89 6.16,12.89H5.29L5.82,10.13H6.81M3.31,15.68H4.75L5.09,13.93H6.32C6.86,13.93 7.3,13.87 7.65,13.76C8,13.64 8.32,13.45 8.61,13.18C8.85,12.96 9.04,12.72 9.19,12.45C9.34,12.19 9.45,11.89 9.5,11.57C9.66,10.79 9.55,10.18 9.17,9.75C8.78,9.31 8.18,9.1 7.35,9.1H4.59L3.31,15.68M10.56,7.35L9.28,13.93H10.7L11.44,10.16H12.58C12.94,10.16 13.18,10.22 13.29,10.34C13.4,10.46 13.42,10.68 13.36,11L12.79,13.93H14.24L14.83,10.86C14.96,10.24 14.86,9.79 14.56,9.5C14.26,9.23 13.71,9.1 12.91,9.1H11.64L12,7.35H10.56M18,10.13C18.55,10.13 18.91,10.23 19.09,10.44C19.27,10.64 19.31,11 19.22,11.47C19.12,12 18.93,12.34 18.65,12.56C18.36,12.78 17.93,12.89 17.35,12.89H16.5L17,10.13H18M14.5,15.68H15.94L16.28,13.93H17.5C18.05,13.93 18.5,13.87 18.85,13.76C19.2,13.64 19.5,13.45 19.8,13.18C20.04,12.96 20.24,12.72 20.38,12.45C20.53,12.19 20.64,11.89 20.7,11.57C20.85,10.79 20.74,10.18 20.36,9.75C20,9.31 19.37,9.1 18.54,9.1H15.79L14.5,15.68Z\";\r\nvar mdiLanguagePython = \"M19.14,7.5A2.86,2.86 0 0,1 22,10.36V14.14A2.86,2.86 0 0,1 19.14,17H12C12,17.39 12.32,17.96 12.71,17.96H17V19.64A2.86,2.86 0 0,1 14.14,22.5H9.86A2.86,2.86 0 0,1 7,19.64V15.89C7,14.31 8.28,13.04 9.86,13.04H15.11C16.69,13.04 17.96,11.76 17.96,10.18V7.5H19.14M14.86,19.29C14.46,19.29 14.14,19.59 14.14,20.18C14.14,20.77 14.46,20.89 14.86,20.89A0.71,0.71 0 0,0 15.57,20.18C15.57,19.59 15.25,19.29 14.86,19.29M4.86,17.5C3.28,17.5 2,16.22 2,14.64V10.86C2,9.28 3.28,8 4.86,8H12C12,7.61 11.68,7.04 11.29,7.04H7V5.36C7,3.78 8.28,2.5 9.86,2.5H14.14C15.72,2.5 17,3.78 17,5.36V9.11C17,10.69 15.72,11.96 14.14,11.96H8.89C7.31,11.96 6.04,13.24 6.04,14.82V17.5H4.86M9.14,5.71C9.54,5.71 9.86,5.41 9.86,4.82C9.86,4.23 9.54,4.11 9.14,4.11C8.75,4.11 8.43,4.23 8.43,4.82C8.43,5.41 8.75,5.71 9.14,5.71Z\";\r\nvar mdiLanguageR = \"M12,4.29C6.5,4.29 2,7.29 2,11C2,14.28 5.56,17 10.24,17.58V19.71H13.65V17.59C14.5,17.5 15.29,17.34 16.04,17.11L17.42,19.71H21.28L18.96,15.8C20.83,14.58 22,12.87 22,11C22,7.29 17.5,4.29 12,4.29V4.29M13.53,6.91C17.73,6.91 20.83,8.31 20.83,11.5C20.83,13.21 19.91,14.41 18.41,15.15C18.32,15.1 18.24,15.05 18.19,15C17.83,14.84 17.23,14.66 17.23,14.66C17.23,14.66 20.21,14.44 20.21,11.47C20.21,8.5 17.09,8.45 17.09,8.45H10.24V15.61C7.69,14.87 5.93,13.3 5.93,11.5C5.93,8.96 9.33,6.91 13.53,6.91M13.68,10.89H15.75C15.75,10.89 16.7,10.84 16.7,11.83C16.7,12.8 15.75,12.8 15.75,12.8H13.68V10.89M13.65,15.3H14.57C14.75,15.3 14.84,15.35 15,15.5C15.13,15.6 15.27,15.79 15.39,15.96C14.84,16.03 14.26,16.06 13.65,16.06V15.3Z\";\r\nvar mdiLanguageRuby = \"M18.8,2.07C21.32,2.5 22.04,4.23 22,6.04V6L20.86,20.93L6.08,21.94H6.09C4.86,21.89 2.13,21.77 2,17.95L3.37,15.45L6.14,21.91L8.5,14.29L8.45,14.3L8.47,14.28L16.18,16.74L14.19,8.96L21.54,8.5L15.75,3.76L18.8,2.06V2.07M2,17.91V17.93L2,17.91V17.91M6.28,6.23C9.24,3.28 13.07,1.54 14.54,3.03C16,4.5 14.46,8.12 11.5,11.06C8.5,14 4.73,15.84 3.26,14.36C1.79,12.87 3.3,9.17 6.27,6.23H6.28Z\";\r\nvar mdiLanguageRubyOnRails = \"M19.8,16.7C19.8,16.7 21.6,16.5 21.6,14.3C21.6,12.1 19.5,11.8 19.5,11.8H15.7V19H17.6V17.3L19.3,19H22L19.8,16.7M19,15.3H17.5V13.7H19C19,13.7 19.4,13.9 19.4,14.5C19.5,15.1 19,15.3 19,15.3M21.3,8.2V8.4C13.2,6.1 10,13.2 10.6,18.7C10.6,18.7 4.9,18.7 4.3,18.7C5,13.3 11.8,2.6 21.3,8.2M20.5,6.9C19.8,6.6 19.1,6.3 18.4,6.1L18.5,4.8L20.6,5.6L20.5,6.9M18.5,8.7C19.2,8.7 19.9,8.8 20.6,9L20.5,10.2L18.7,10L18.5,8.7M13.9,5.8L13.5,4.6L15.6,4.4L16,5.7C15.8,5.7 14.1,5.8 13.9,5.8M15.2,9.5C15.6,9.3 16.3,9 17.2,8.8L17.6,10L15.8,10.7L15.2,9.5M11.8,6.5C11.2,6.8 10.6,7.1 10,7.5L9.2,6.2L11,5.2L11.8,6.5M14.3,10.1L15.1,11.3L14,12.6L12.9,11.6C13.2,11 13.7,10.5 14.3,10.1M11.6,15C11.7,14.2 11.9,13.5 12.2,12.7L13.4,13.7L13.1,15.6L11.6,15M7.9,9.3C7.4,9.8 6.9,10.4 6.5,10.9L5.2,9.8L6.7,8.2L7.9,9.3M4.8,13.7C4.4,14.5 4.1,15.3 3.8,16L2,15.3L2.9,13L4.8,13.7M11.5,16.3L13.3,16.9L13.6,18.9L11.6,18.4C11.6,18.2 11.5,17.5 11.5,16.3Z\";\r\nvar mdiLanguageRust = \"M21.9 11.7L21 11.2V11L21.7 10.3C21.8 10.2 21.8 10 21.7 9.9L21.6 9.8L20.7 9.5C20.7 9.4 20.7 9.3 20.6 9.3L21.2 8.5C21.3 8.4 21.3 8.2 21.1 8.1C21.1 8.1 21 8.1 21 8L20 7.8C20 7.7 19.9 7.7 19.9 7.6L20.3 6.7V6.4C20.2 6.3 20.1 6.3 20 6.3H19C19 6.3 19 6.2 18.9 6.2L19.1 5.2C19.1 5 19 4.9 18.9 4.9H18.8L17.8 5.1C17.8 5 17.7 5 17.6 4.9V3.9C17.6 3.7 17.5 3.6 17.3 3.6H17.2L16.3 4H16.2L16 3C16 2.8 15.8 2.7 15.7 2.8H15.6L14.8 3.4C14.7 3.4 14.6 3.4 14.6 3.3L14.3 2.4C14.2 2.3 14.1 2.2 13.9 2.2C13.9 2.2 13.8 2.2 13.8 2.3L13 3H12.8L12.3 2.2C12.2 2 12 2 11.8 2L11.7 2.1L11.2 3H11L10.3 2.3C10.2 2.2 10 2.2 9.9 2.3L9.8 2.4L9.5 3.3C9.4 3.3 9.3 3.3 9.3 3.4L8.5 2.8C8.3 2.7 8.1 2.7 8 2.9V3L7.8 4C7.8 4 7.7 4 7.6 4.1L6.7 3.7C6.6 3.6 6.4 3.7 6.3 3.8V4.9C6.3 5 6.2 5 6.2 5.1L5.2 4.9C5 4.8 4.9 4.9 4.9 5.1V5.2L5.1 6.2C5 6.2 5 6.3 4.9 6.3H3.9C3.7 6.3 3.6 6.4 3.6 6.6V6.7L4 7.6V7.8L3 8C2.8 8 2.7 8.2 2.7 8.3V8.4L3.3 9.2C3.3 9.3 3.3 9.4 3.2 9.4L2.4 9.8C2.3 9.9 2.2 10 2.2 10.2C2.2 10.2 2.2 10.3 2.3 10.3L3 11V11.2L2.2 11.7C2 11.8 2 12 2 12.1L2.1 12.2L3 12.8V13L2.3 13.7C2.2 13.8 2.2 14 2.3 14.1L2.4 14.2L3.3 14.5C3.3 14.6 3.3 14.7 3.4 14.7L2.8 15.5C2.7 15.6 2.7 15.8 2.9 15.9C2.9 15.9 3 15.9 3 16L4 16.2C4 16.3 4.1 16.3 4.1 16.4L3.7 17.3C3.6 17.4 3.7 17.6 3.8 17.7H4.9C5 17.7 5 17.8 5.1 17.8L4.9 18.8C4.9 19 5 19.1 5.1 19.1H5.2L6.2 18.9C6.2 19 6.3 19 6.4 19.1V20.1C6.4 20.3 6.5 20.4 6.7 20.4H6.8L7.7 20H7.8L8 21C8 21.2 8.2 21.3 8.3 21.2H8.4L9.2 20.6C9.3 20.6 9.4 20.6 9.4 20.7L9.7 21.6C9.8 21.7 9.9 21.8 10.1 21.8C10.1 21.8 10.2 21.8 10.2 21.7L11 21H11.2L11.7 21.8C11.8 21.9 12 22 12.1 21.9L12.2 21.8L12.7 21H12.9L13.6 21.7C13.7 21.8 13.9 21.8 14 21.7L14.1 21.6L14.4 20.7C14.5 20.7 14.6 20.7 14.6 20.6L15.4 21.2C15.5 21.3 15.7 21.3 15.8 21.1C15.8 21.1 15.8 21 15.9 21L16.1 20C16.2 20 16.2 19.9 16.3 19.9L17.2 20.3C17.3 20.4 17.5 20.3 17.6 20.2V19.1L17.8 18.9L18.8 19.1C19 19.1 19.1 19 19.1 18.9V18.8L18.9 17.8L19.1 17.6H20.1C20.3 17.6 20.4 17.5 20.4 17.3V17.2L20 16.3C20 16.2 20.1 16.2 20.1 16.1L21.1 15.9C21.3 15.9 21.4 15.7 21.3 15.6V15.5L20.7 14.7L20.8 14.5L21.7 14.2C21.8 14.1 21.9 14 21.9 13.8C21.9 13.8 21.9 13.7 21.8 13.7L21 13V12.8L21.8 12.3C22 12.2 22 12 21.9 11.7C21.9 11.8 21.9 11.8 21.9 11.7M16.2 18.7C15.9 18.6 15.7 18.3 15.7 18C15.8 17.7 16.1 17.5 16.4 17.5C16.7 17.6 16.9 17.9 16.9 18.2C16.9 18.6 16.6 18.8 16.2 18.7M16 16.8C15.7 16.7 15.4 16.9 15.4 17.2L15 18.6C14.1 19 13.1 19.2 12 19.2C10.9 19.2 9.9 19 8.9 18.5L8.6 17.1C8.5 16.8 8.3 16.6 8 16.7L6.8 17C6.6 16.8 6.4 16.5 6.2 16.3H12.2C12.3 16.3 12.3 16.3 12.3 16.2V14.1C12.3 14 12.3 14 12.2 14H10.5V12.7H12.4C12.6 12.7 13.3 12.7 13.6 13.7C13.7 14 13.8 15 14 15.3C14.1 15.6 14.6 16.3 15.1 16.3H18.2C18 16.6 17.8 16.8 17.5 17.1L16 16.8M7.7 18.7C7.4 18.8 7.1 18.6 7 18.2C6.9 17.9 7.1 17.6 7.5 17.5S8.1 17.6 8.2 18C8.2 18.3 8 18.6 7.7 18.7M5.4 9.5C5.5 9.8 5.4 10.2 5.1 10.3C4.8 10.4 4.4 10.3 4.3 10C4.2 9.7 4.3 9.3 4.6 9.2C5 9.1 5.3 9.2 5.4 9.5M4.7 11.1L6 10.6C6.3 10.5 6.4 10.2 6.3 9.9L6 9.3H7V14H5C4.7 13 4.6 12.1 4.7 11.1M10.3 10.7V9.3H12.8C12.9 9.3 13.7 9.4 13.7 10C13.7 10.5 13.1 10.7 12.6 10.7H10.3M19.3 11.9V12.4H18.5C18.4 12.4 18.4 12.4 18.4 12.5V12.8C18.4 13.6 17.9 13.8 17.5 13.8C17.1 13.8 16.7 13.6 16.6 13.4C16.4 12.1 16 11.9 15.4 11.4C16.1 10.9 16.9 10.2 16.9 9.3C16.9 8.3 16.2 7.7 15.8 7.4C15.1 7 14.4 6.9 14.2 6.9H6.6C7.7 5.7 9.1 4.9 10.7 4.6L11.6 5.6C11.8 5.8 12.1 5.8 12.4 5.6L13.4 4.6C15.5 5 17.3 6.3 18.4 8.2L17.7 9.8C17.6 10.1 17.7 10.4 18 10.5L19.3 11.1V11.9M11.6 3.9C11.8 3.7 12.2 3.7 12.4 3.9C12.6 4.1 12.6 4.5 12.4 4.7C12.1 5 11.8 5 11.5 4.7C11.3 4.5 11.4 4.2 11.6 3.9M18.5 9.5C18.6 9.2 19 9.1 19.3 9.2C19.6 9.3 19.7 9.7 19.6 10C19.5 10.3 19.1 10.4 18.8 10.3C18.5 10.2 18.4 9.8 18.5 9.5Z\";\r\nvar mdiLanguageSwift = \"M17.09,19.72C14.73,21.08 11.5,21.22 8.23,19.82C5.59,18.7 3.4,16.74 2,14.5C2.67,15.05 3.46,15.5 4.3,15.9C7.67,17.47 11.03,17.36 13.4,15.9C10.03,13.31 7.16,9.94 5.03,7.19C4.58,6.74 4.25,6.18 3.91,5.68C12.19,11.73 11.83,13.27 6.32,4.67C11.21,9.61 15.75,12.41 15.75,12.41C15.91,12.5 16,12.57 16.11,12.63C16.21,12.38 16.3,12.12 16.37,11.85C17.16,9 16.26,5.73 14.29,3.04C18.84,5.79 21.54,10.95 20.41,15.28C20.38,15.39 20.35,15.5 20.36,15.67C22.6,18.5 22,21.45 21.71,20.89C20.5,18.5 18.23,19.24 17.09,19.72V19.72Z\";\r\nvar mdiLanguageTypescript = \"M3,3H21V21H3V3M13.71,17.86C14.21,18.84 15.22,19.59 16.8,19.59C18.4,19.59 19.6,18.76 19.6,17.23C19.6,15.82 18.79,15.19 17.35,14.57L16.93,14.39C16.2,14.08 15.89,13.87 15.89,13.37C15.89,12.96 16.2,12.64 16.7,12.64C17.18,12.64 17.5,12.85 17.79,13.37L19.1,12.5C18.55,11.54 17.77,11.17 16.7,11.17C15.19,11.17 14.22,12.13 14.22,13.4C14.22,14.78 15.03,15.43 16.25,15.95L16.67,16.13C17.45,16.47 17.91,16.68 17.91,17.26C17.91,17.74 17.46,18.09 16.76,18.09C15.93,18.09 15.45,17.66 15.09,17.06L13.71,17.86M13,11.25H8V12.75H9.5V20H11.25V12.75H13V11.25Z\";\r\nvar mdiLanguageXaml = \"M16.93 7.9L19.31 12L16.95 16.09L16.33 15L17.8 12.5C17.97 12.19 17.97 11.83 17.8 11.54L16.32 9L16.93 7.9M16.92 6.57C16.89 6.57 16.85 6.59 16.83 6.62L15.56 8.87C15.5 8.94 15.5 9 15.56 9.09L17.18 11.9C17.22 11.97 17.22 12.05 17.18 12.12L15.57 14.91C15.53 14.97 15.53 15.06 15.57 15.13L16.85 17.36C16.87 17.4 16.91 17.42 16.94 17.42C17 17.42 17 17.4 17.04 17.36L20 12.23C20.08 12.09 20.08 11.92 20 11.79L17 6.62C17 6.59 16.96 6.57 16.92 6.57M21.91 11.67L17.23 3.58C17.11 3.38 16.89 3.25 16.66 3.25H7.28C7.05 3.25 6.83 3.38 6.71 3.58L2 11.67C1.91 11.87 1.91 12.13 2 12.33L6.71 20.42C6.83 20.62 7.05 20.75 7.28 20.75H16.66C16.89 20.75 17.11 20.62 17.23 20.42L21.91 12.33C22.03 12.13 22.03 11.88 21.91 11.67M7.3 3.95H16.12L11.76 11.65H6.93L10.87 4.82C10.91 4.75 10.86 4.66 10.78 4.66L8.21 4.65C8.13 4.65 8.06 4.7 8 4.76L4.04 11.65H2.84L7.3 3.95M6.17 12.46L9.74 18.63L8.5 18.63L4.87 12.35L4.67 12L4.87 11.65L8.5 5.37L9.73 5.37L6.17 11.53C6.15 11.57 6.13 11.61 6.11 11.65C6.03 11.88 6.03 12.13 6.12 12.35C6.13 12.39 6.15 12.43 6.17 12.46M7.3 20.05L2.85 12.35H4.05L8.03 19.23C8.07 19.3 8.14 19.34 8.22 19.34L10.79 19.34C10.87 19.34 10.92 19.25 10.88 19.18L6.94 12.35H11.77L16.17 20.05H7.3M16.8 19.75L12.37 12L16.78 4.21L21.29 12L16.8 19.75Z\";\r\nvar mdiLaptop = \"M4,6H20V16H4M20,18A2,2 0 0,0 22,16V6C22,4.89 21.1,4 20,4H4C2.89,4 2,4.89 2,6V16A2,2 0 0,0 4,18H0V20H24V18H20Z\";\r\nvar mdiLaptopChromebook = \"M20,15H4V5H20M14,18H10V17H14M22,18V3H2V18H0V20H24V18H22Z\";\r\nvar mdiLaptopMac = \"M12,19A1,1 0 0,1 11,18A1,1 0 0,1 12,17A1,1 0 0,1 13,18A1,1 0 0,1 12,19M4,5H20V16H4M20,18A2,2 0 0,0 22,16V5C22,3.89 21.1,3 20,3H4C2.89,3 2,3.89 2,5V16A2,2 0 0,0 4,18H0A2,2 0 0,0 2,20H22A2,2 0 0,0 24,18H20Z\";\r\nvar mdiLaptopOff = \"M1,4.27L2.28,3L20,20.72L18.73,22L16.73,20H0V18H4C2.89,18 2,17.1 2,16V6C2,5.78 2.04,5.57 2.1,5.37L1,4.27M4,16H12.73L4,7.27V16M20,16V6H7.82L5.82,4H20A2,2 0 0,1 22,6V16A2,2 0 0,1 20,18H24V20H21.82L17.82,16H20Z\";\r\nvar mdiLaptopWindows = \"M3,4H21A1,1 0 0,1 22,5V16A1,1 0 0,1 21,17H22L24,20V21H0V20L2,17H3A1,1 0 0,1 2,16V5A1,1 0 0,1 3,4M4,6V15H20V6H4Z\";\r\nvar mdiLaravel = \"M21.7 6.53C21.71 6.55 21.71 6.58 21.71 6.61V10.9C21.71 11 21.65 11.12 21.56 11.17L17.95 13.25V17.36C17.95 17.47 17.9 17.57 17.8 17.63L10.28 21.96C10.26 21.97 10.24 22 10.22 22L10.2 22C10.15 22 10.09 22 10.04 22C10.03 22 10 22 10 22C10 22 10 21.97 9.96 21.96L2.44 17.63C2.35 17.58 2.29 17.47 2.29 17.36V4.5C2.29 4.45 2.29 4.42 2.3 4.4C2.3 4.39 2.31 4.38 2.31 4.37C2.31 4.35 2.32 4.34 2.33 4.32C2.33 4.31 2.34 4.3 2.35 4.29C2.36 4.28 2.37 4.27 2.38 4.26C2.39 4.25 2.4 4.24 2.41 4.23C2.42 4.22 2.43 4.21 2.44 4.21L6.2 2.04C6.3 2 6.42 2 6.5 2.04L10.28 4.21H10.28C10.29 4.22 10.3 4.22 10.31 4.23C10.32 4.24 10.33 4.25 10.34 4.26C10.35 4.27 10.36 4.28 10.37 4.29C10.38 4.3 10.39 4.31 10.39 4.32C10.4 4.34 10.41 4.35 10.41 4.37C10.41 4.38 10.42 4.39 10.42 4.4C10.43 4.43 10.43 4.45 10.43 4.5V12.5L13.57 10.72V6.61C13.57 6.58 13.57 6.55 13.58 6.53L13.59 6.5C13.59 6.5 13.6 6.47 13.61 6.45C13.61 6.44 13.62 6.43 13.63 6.42C13.64 6.41 13.65 6.4 13.66 6.39C13.67 6.38 13.68 6.37 13.69 6.36C13.7 6.35 13.71 6.34 13.72 6.34L17.5 4.17C17.58 4.11 17.7 4.11 17.8 4.17L21.56 6.34C21.57 6.34 21.58 6.35 21.59 6.36L21.62 6.39C21.63 6.4 21.64 6.41 21.65 6.42C21.66 6.43 21.66 6.44 21.67 6.45C21.68 6.47 21.68 6.5 21.69 6.5C21.7 6.5 21.7 6.5 21.7 6.53M21.09 10.72V7.15L17.95 8.95V12.5L21.09 10.72M17.33 17.18V13.6L10.43 17.54V21.15L17.33 17.18M2.91 5V17.18L9.81 21.15V17.54L6.21 15.5L6.2 15.5L6.2 15.5C6.19 15.5 6.18 15.5 6.17 15.47C6.16 15.47 6.15 15.46 6.14 15.45V15.45C6.13 15.44 6.12 15.43 6.11 15.42C6.1 15.41 6.1 15.4 6.09 15.39V15.39C6.08 15.37 6.08 15.36 6.07 15.35C6.07 15.33 6.06 15.32 6.06 15.31C6.05 15.3 6.05 15.28 6.05 15.27C6.05 15.25 6.05 15.24 6.05 15.23V6.82L2.91 5M6.36 2.68L3.23 4.5L6.36 6.28L9.5 4.5L6.36 2.68M9.81 12.88V5L6.67 6.82V14.69L9.81 12.88M17.64 4.8L14.5 6.61L17.64 8.41L20.77 6.61L17.64 4.8M17.33 8.95L14.19 7.15V10.72L17.33 12.5V8.95M10.12 17L17 13.06L13.88 11.26L7 15.23L10.12 17Z\";\r\nvar mdiLaserPointer = \"M9 13L5 16C4 16.88 3.86 18.12 4 19C4.13 20 4.91 21.22 6 21.68C7.57 22.35 9.09 21.9 10.04 20.92L19 13C20.86 11.62 20 9 18 9H12L19.46 4.61C19.9 4.29 20.08 3.82 20.06 3.37C20 2.67 19.46 2 18.6 2H18.54C18.19 2 17.86 2.11 17.56 2.29L5 9C4.19 9.46 3.94 10.24 4 11C4.05 12.03 4.74 13 6 13M5 18.5C5 17.12 6.12 16 7.5 16S10 17.12 10 18.5 8.88 21 7.5 21 5 19.88 5 18.5Z\";\r\nvar mdiLasso = \"M12 2C17.5 2 22 5.13 22 9C22 12.26 18.81 15 14.5 15.78L14.5 15.5C14.5 14.91 14.4 14.34 14.21 13.81C17.55 13.21 20 11.28 20 9C20 6.24 16.42 4 12 4C7.58 4 4 6.24 4 9C4 10.19 4.67 11.29 5.79 12.15C5.35 12.64 5 13.21 4.78 13.85C3.06 12.59 2 10.88 2 9C2 5.13 6.5 2 12 2M9.5 12C11.43 12 13 13.57 13 15.5C13 17.4 11.5 18.95 9.6 19C9.39 19.36 9.18 20 9.83 20.68C11 21.88 13.28 19.72 16.39 19.71C18.43 19.7 20.03 19.97 20.03 19.97C20.03 19.97 21.08 20.1 20.97 21.04C20.86 21.97 19.91 21.97 19.91 21.97C19.53 21.93 18.03 21.58 16.22 21.68C14.41 21.77 13.47 22.41 12.56 22.69C11.66 22.97 9.91 23.38 8.3 22.05C6.97 20.96 7.46 19.11 7.67 18.5C6.67 17.87 6 16.76 6 15.5C6 13.57 7.57 12 9.5 12M9.5 14C8.67 14 8 14.67 8 15.5C8 16.33 8.67 17 9.5 17C10.33 17 11 16.33 11 15.5C11 14.67 10.33 14 9.5 14Z\";\r\nvar mdiLastpass = \"M14,12A2,2 0 0,1 16,10A2,2 0 0,1 18,12A2,2 0 0,1 16,14A2,2 0 0,1 14,12M8,12A2,2 0 0,1 10,10A2,2 0 0,1 12,12A2,2 0 0,1 10,14A2,2 0 0,1 8,12M2,12A2,2 0 0,1 4,10A2,2 0 0,1 6,12A2,2 0 0,1 4,14A2,2 0 0,1 2,12M22,5H20V19H22V5Z\";\r\nvar mdiLatitude = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 4C15 4 17.5 5.6 18.9 8H5.1C6.5 5.6 9 4 12 4M12 20C9 20 6.5 18.4 5.1 16H18.9C17.5 18.4 15 20 12 20M4.3 14C4.1 13.4 4 12.7 4 12S4.1 10.6 4.3 10H19.8C20 10.6 20.1 11.3 20.1 12S20 13.4 19.8 14H4.3Z\";\r\nvar mdiLaunch = \"M14,3V5H17.59L7.76,14.83L9.17,16.24L19,6.41V10H21V3M19,19H5V5H12V3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V12H19V19Z\";\r\nvar mdiLavaLamp = \"M10,3L8,16H16L14,3H10M11.5,5.75A0.75,0.75 0 0,1 12.25,6.5A0.75,0.75 0 0,1 11.5,7.25A0.75,0.75 0 0,1 10.75,6.5A0.75,0.75 0 0,1 11.5,5.75M12.5,8.5A1,1 0 0,1 13.5,9.5A1,1 0 0,1 12.5,10.5A1,1 0 0,1 11.5,9.5A1,1 0 0,1 12.5,8.5M11.5,12A1.5,1.5 0 0,1 13,13.5A1.5,1.5 0 0,1 11.5,15A1.5,1.5 0 0,1 10,13.5A1.5,1.5 0 0,1 11.5,12M8,17L10,19L8,21H16L14,19L16,17H8Z\";\r\nvar mdiLayers = \"M12,16L19.36,10.27L21,9L12,2L3,9L4.63,10.27M12,18.54L4.62,12.81L3,14.07L12,21.07L21,14.07L19.37,12.8L12,18.54Z\";\r\nvar mdiLayersMinus = \"M22,17V19H14V17H22M11,16L2,9L11,2L20,9L11,16M11,18.54L12,17.75V18C12,18.71 12.12,19.39 12.35,20L11,21.07L2,14.07L3.62,12.81L11,18.54Z\";\r\nvar mdiLayersOff = \"M3.27,1L2,2.27L6.22,6.5L3,9L4.63,10.27L12,16L14.1,14.37L15.53,15.8L12,18.54L4.63,12.81L3,14.07L12,21.07L16.95,17.22L20.73,21L22,19.73L3.27,1M19.36,10.27L21,9L12,2L9.09,4.27L16.96,12.15L19.36,10.27M19.81,15L21,14.07L19.57,12.64L18.38,13.56L19.81,15Z\";\r\nvar mdiLayersOffOutline = \"M12,4.53L10.83,5.44L9.41,4L12,2L21,9L17.28,11.89L15.85,10.47L17.74,9L12,4.53M21,14.07L20.13,14.75L18.7,13.32L19.37,12.8L21,14.07M3.41,0.86L22.14,19.59L20.73,21L16.95,17.22L12,21.07L3,14.07L4.62,12.81L12,18.54L15.5,15.79L14.1,14.37L12,16L3,9L6.22,6.5L2,2.27L3.41,0.86M12,13.47L12.67,12.94L7.65,7.92L6.26,9L12,13.47Z\";\r\nvar mdiLayersOutline = \"M12,18.54L19.37,12.8L21,14.07L12,21.07L3,14.07L4.62,12.81L12,18.54M12,16L3,9L12,2L21,9L12,16M12,4.53L6.26,9L12,13.47L17.74,9L12,4.53Z\";\r\nvar mdiLayersPlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M11,16L2,9L11,2L20,9L11,16M11,18.54L12,17.75V18C12,18.71 12.12,19.39 12.35,20L11,21.07L2,14.07L3.62,12.81L11,18.54Z\";\r\nvar mdiLayersRemove = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M11,16L2,9L11,2L20,9L11,16M11,18.54L12,17.75V18C12,18.71 12.12,19.39 12.35,20L11,21.07L2,14.07L3.62,12.81L11,18.54Z\";\r\nvar mdiLayersSearch = \"M19.31 18.9C19.75 18.21 20 17.38 20 16.5C20 14 18 12 15.5 12S11 14 11 16.5 13 21 15.5 21C16.37 21 17.19 20.75 17.88 20.32L21 23.39L22.39 22L19.31 18.9M15.5 19C14.12 19 13 17.88 13 16.5S14.12 14 15.5 14 18 15.12 18 16.5 16.88 19 15.5 19M9.59 19.2L3 14.07L4.62 12.81L9 16.22C9 16.32 9 16.41 9 16.5C9 17.46 9.22 18.38 9.59 19.2M4.63 10.27L3 9L12 2L21 9L19.36 10.27L18.65 10.82C17.72 10.3 16.64 10 15.5 10C12.79 10 10.46 11.68 9.5 14.05L4.63 10.27Z\";\r\nvar mdiLayersSearchOutline = \"M19.31 18.9C19.75 18.21 20 17.38 20 16.5C20 14 18 12 15.5 12S11 14 11 16.5 13 21 15.5 21C16.37 21 17.19 20.75 17.88 20.32L21 23.39L22.39 22L19.31 18.9M15.5 19C14.12 19 13 17.88 13 16.5S14.12 14 15.5 14 18 15.12 18 16.5 16.88 19 15.5 19M9.59 19.2L3 14.07L4.62 12.81L9 16.22C9 16.32 9 16.41 9 16.5C9 17.46 9.22 18.38 9.59 19.2M9.5 14.04L3 9L12 2L21 9L18.66 10.82C17.96 10.44 17.19 10.18 16.37 10.07L17.74 9L12 4.53L6.26 9L10.53 12.32C10.1 12.84 9.74 13.42 9.5 14.04Z\";\r\nvar mdiLayersTriple = \"M12 0L3 7L4.63 8.27L12 14L19.36 8.27L21 7L12 0M19.37 10.73L12 16.47L4.62 10.74L3 12L12 19L21 12L19.37 10.73M19.37 15.73L12 21.47L4.62 15.74L3 17L12 24L21 17L19.37 15.73Z\";\r\nvar mdiLayersTripleOutline = \"M12 16.54L19.37 10.8L21 12.07L12 19.07L3 12.07L4.62 10.81L12 16.54M12 14L3 7L12 0L21 7L12 14M12 2.53L6.26 7L12 11.47L17.74 7L12 2.53M12 21.47L19.37 15.73L21 17L12 24L3 17L4.62 15.74L12 21.47\";\r\nvar mdiLeadPencil = \"M16.84,2.73C16.45,2.73 16.07,2.88 15.77,3.17L13.65,5.29L18.95,10.6L21.07,8.5C21.67,7.89 21.67,6.94 21.07,6.36L17.9,3.17C17.6,2.88 17.22,2.73 16.84,2.73M12.94,6L4.84,14.11L7.4,14.39L7.58,16.68L9.86,16.85L10.15,19.41L18.25,11.3M4.25,15.04L2.5,21.73L9.2,19.94L8.96,17.78L6.65,17.61L6.47,15.29\";\r\nvar mdiLeaf = \"M17,8C8,10 5.9,16.17 3.82,21.34L5.71,22L6.66,19.7C7.14,19.87 7.64,20 8,20C19,20 22,3 22,3C21,5 14,5.25 9,6.25C4,7.25 2,11.5 2,13.5C2,15.5 3.75,17.25 3.75,17.25C7,8 17,8 17,8Z\";\r\nvar mdiLeafMaple = \"M21.79,13L16,16L17,18L13,17.25V21H11V17.25L7,18L8,16L2.21,13L3.21,11.27L1.61,8L5.21,7.77L6.21,6L9.63,9.9L8,5H10L12,2L14,5H16L14.37,9.9L17.79,6L18.79,7.73L22.39,7.96L20.79,11.19L21.79,13Z\";\r\nvar mdiLeafMapleOff = \"M18.11 14.91L8.2 5H10L12 2L14 5H16L14.37 9.9L17.79 6L18.79 7.73L22.39 7.96L20.79 11.19L21.79 13L18.11 14.91M2.39 1.73L1.11 3L5.45 7.34L5.21 7.77L1.61 8L3.21 11.27L2.21 13L8 16L7 18L11 17.25V21H13V17.25L15.91 17.8L20.84 22.73L22.11 21.46L2.39 1.73Z\";\r\nvar mdiLeafOff = \"M20.84 22.73L15.14 17.03C13.26 18.79 10.92 20 8 20C7.64 20 7.14 19.87 6.66 19.7L5.71 22L3.82 21.34C5.15 18.03 6.5 14.32 9.66 11.55L8.77 10.66C6.76 12.03 4.86 14.1 3.75 17.25C3.75 17.25 2 15.5 2 13.5C2 12 3.12 9.32 5.72 7.61L1.11 3L2.39 1.73C2.39 1.73 16.39 15.74 16.39 15.74L22.11 21.46L20.84 22.73M17 8C15.35 8.37 13.93 8.88 12.7 9.5L17.5 14.29C20.87 9.35 22 3 22 3C21.03 4.95 14.35 5.24 9.38 6.18L12.15 8.95C14.81 8 17 8 17 8Z\";\r\nvar mdiLeak = \"M6,3H3V6A3,3 0 0,0 6,3M14,3H12A9,9 0 0,1 3,12V14C9.08,14 14,9.07 14,3M10,3H8A5,5 0 0,1 3,8V10A7,7 0 0,0 10,3M10,21H12A9,9 0 0,1 21,12V10A11,11 0 0,0 10,21M18,21H21V18A3,3 0 0,0 18,21M14,21H16A5,5 0 0,1 21,16V14A7,7 0 0,0 14,21Z\";\r\nvar mdiLeakOff = \"M10,3H8C8,3.37 7.96,3.72 7.88,4.06L9.47,5.65C9.81,4.84 10,3.94 10,3M3,4.27L5.84,7.11C5.03,7.67 4.06,8 3,8V10C4.61,10 6.09,9.45 7.27,8.54L8.7,9.97C7.14,11.24 5.16,12 3,12V14C5.71,14 8.19,13 10.11,11.38L12.61,13.88C11,15.81 10,18.29 10,21H12C12,18.84 12.76,16.86 14.03,15.31L15.46,16.74C14.55,17.91 14,19.39 14,21H16C16,19.94 16.33,18.97 16.89,18.16L19.73,21L21,19.73L4.27,3L3,4.27M14,3H12C12,4.5 11.63,5.91 11,7.16L12.44,8.62C13.42,7 14,5.06 14,3M19.94,16.12C20.28,16.04 20.63,16 21,16V14C20.06,14 19.16,14.19 18.34,14.5L19.94,16.12M15.38,11.56L16.84,13C18.09,12.37 19.5,12 21,12V10C18.94,10 17,10.58 15.38,11.56Z\";\r\nvar mdiLedOff = \"M12,6A4,4 0 0,0 8,10V16H6V18H9V23H11V18H13V23H15V18H18V16H16V10A4,4 0 0,0 12,6Z\";\r\nvar mdiLedOn = \"M11,0V4H13V0H11M18.3,2.29L15.24,5.29L16.64,6.71L19.7,3.71L18.3,2.29M5.71,2.29L4.29,3.71L7.29,6.71L8.71,5.29L5.71,2.29M12,6A4,4 0 0,0 8,10V16H6V18H9V23H11V18H13V23H15V18H18V16H16V10A4,4 0 0,0 12,6M2,9V11H6V9H2M18,9V11H22V9H18Z\";\r\nvar mdiLedOutline = \"M12,6A4,4 0 0,0 8,10V16H6V18H9V23H11V18H13V23H15V18H18V16H16V10A4,4 0 0,0 12,6M12,8A2,2 0 0,1 14,10V15H10V10A2,2 0 0,1 12,8Z\";\r\nvar mdiLedStrip = \"M2.81,8.46L14.83,20.5L15.54,19.78L16.95,21.19L18.36,19.78L16.95,18.36L18.36,16.95L19.78,18.36L21.19,16.95L19.78,15.54L20.5,14.83L8.46,2.81L2.81,8.46M5.64,8.46L8.46,5.64L17.66,14.83L14.83,17.66L5.64,8.46M7.05,8.46L8.46,9.88L9.88,8.46L8.46,7.05L7.05,8.46M9.17,10.59L10.59,12L12,10.59L10.59,9.17L9.17,10.59M11.29,12.71L12.71,14.12L14.12,12.71L12.71,11.29L11.29,12.71M13.41,14.83L14.83,16.24L16.24,14.83L14.83,13.41L13.41,14.83Z\";\r\nvar mdiLedStripVariant = \"M2.95 3L2 6.91L19.34 11.25L20.29 7.34L2.95 3M6.09 6.89L4.16 6.41L4.64 4.46L6.57 4.94L6.09 6.89M9.94 7.86L8 7.38L8.5 5.42L10.42 5.91L9.94 7.86M13.8 8.82L11.87 8.34L12.35 6.39L14.27 6.87L13.8 8.82M17.65 9.79L15.72 9.31L16.2 7.35L18.13 7.84L17.65 9.79M4.66 12.75L3.71 16.66L21.05 21L22 17.1L4.66 12.75M7.8 16.65L5.88 16.16L6.35 14.21L8.28 14.69L7.8 16.65M11.65 17.61L9.73 17.13L10.2 15.18L12.13 15.66L11.65 17.61M15.5 18.58L13.58 18.09L14.06 16.14L16 16.62L15.5 18.58M19.36 19.54L17.43 19.06L17.91 17.11L19.84 17.59L19.36 19.54M6.25 12.11L11 10.2L17.75 11.89L13 13.8L6.25 12.11Z\";\r\nvar mdiLedVariantOff = \"M12,3C10.05,3 8.43,4.4 8.08,6.25L16.82,15H18V13H16V7A4,4 0 0,0 12,3M3.28,4L2,5.27L8,11.27V13H6V15H9V21H11V15H11.73L13,16.27V21H15V18.27L18.73,22L20,20.72L15,15.72L8,8.72L3.28,4Z\";\r\nvar mdiLedVariantOn = \"M12,3A4,4 0 0,0 8,7V13H6V15H9V21H11V15H13V21H15V15H18V13H16V7A4,4 0 0,0 12,3Z\";\r\nvar mdiLedVariantOutline = \"M12,3A4,4 0 0,0 8,7V13H6V15H9V21H11V15H13V21H15V15H18V13H16V7A4,4 0 0,0 12,3M12,5A2,2 0 0,1 14,7V12H10V7A2,2 0 0,1 12,5Z\";\r\nvar mdiLeek = \"M10 2V5.55L12 7.55L14 5.55V2H10M6.34 4L3.87 6.5L15 17.62V12.67L6.34 4M17.66 4L13.06 8.61L15.54 11.09L20.13 6.5L17.66 4M9 13.74V20A2 2 0 0 0 11 22H13A2 2 0 0 0 15 20V19.74L13 17.74V20H11V15.74L9 13.74Z\";\r\nvar mdiLessThan = \"M18.5,4.14L19.5,5.86L8.97,12L19.5,18.14L18.5,19.86L5,12L18.5,4.14Z\";\r\nvar mdiLessThanOrEqual = \"M18.5,2.27L5,10.14L18.5,18L19.5,16.27L8.97,10.14L19.5,4L18.5,2.27M5,20V22H20V20H5Z\";\r\nvar mdiLibrary = \"M12,8A3,3 0 0,0 15,5A3,3 0 0,0 12,2A3,3 0 0,0 9,5A3,3 0 0,0 12,8M12,11.54C9.64,9.35 6.5,8 3,8V19C6.5,19 9.64,20.35 12,22.54C14.36,20.35 17.5,19 21,19V8C17.5,8 14.36,9.35 12,11.54Z\";\r\nvar mdiLibraryShelves = \"M19.5,9V1.5H16.5V9H13.5V1.5H10.5V9H7.5V1.5H4.65V9H3V10.5H21V9H19.5M19.5,13.5H16.5V21H13.5V13.5H10.5V21H7.5V13.5H4.65V21H3V22.5H21V21H19.5V13.5Z\";\r\nvar mdiLicense = \"M9 10A3.04 3.04 0 0 1 12 7A3.04 3.04 0 0 1 15 10A3.04 3.04 0 0 1 12 13A3.04 3.04 0 0 1 9 10M12 19L16 20V16.92A7.54 7.54 0 0 1 12 18A7.54 7.54 0 0 1 8 16.92V20M12 4A5.78 5.78 0 0 0 7.76 5.74A5.78 5.78 0 0 0 6 10A5.78 5.78 0 0 0 7.76 14.23A5.78 5.78 0 0 0 12 16A5.78 5.78 0 0 0 16.24 14.23A5.78 5.78 0 0 0 18 10A5.78 5.78 0 0 0 16.24 5.74A5.78 5.78 0 0 0 12 4M20 10A8.04 8.04 0 0 1 19.43 12.8A7.84 7.84 0 0 1 18 15.28V23L12 21L6 23V15.28A7.9 7.9 0 0 1 4 10A7.68 7.68 0 0 1 6.33 4.36A7.73 7.73 0 0 1 12 2A7.73 7.73 0 0 1 17.67 4.36A7.68 7.68 0 0 1 20 10Z\";\r\nvar mdiLifebuoy = \"M19.79,15.41C20.74,13.24 20.74,10.75 19.79,8.59L17.05,9.83C17.65,11.21 17.65,12.78 17.06,14.17L19.79,15.41M15.42,4.21C13.25,3.26 10.76,3.26 8.59,4.21L9.83,6.94C11.22,6.35 12.79,6.35 14.18,6.95L15.42,4.21M4.21,8.58C3.26,10.76 3.26,13.24 4.21,15.42L6.95,14.17C6.35,12.79 6.35,11.21 6.95,9.82L4.21,8.58M8.59,19.79C10.76,20.74 13.25,20.74 15.42,19.78L14.18,17.05C12.8,17.65 11.22,17.65 9.84,17.06L8.59,19.79M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,8A4,4 0 0,0 8,12A4,4 0 0,0 12,16A4,4 0 0,0 16,12A4,4 0 0,0 12,8Z\";\r\nvar mdiLightSwitch = \"M7,1A2,2 0 0,0 5,3V21A2,2 0 0,0 7,23H17A2,2 0 0,0 19,21V3A2,2 0 0,0 17,1H7M7,3H17V21H7V3M9,6V18H15V6H9M10,7H14V11H10V7M10,13H14V17H10V13Z\";\r\nvar mdiLightbulb = \"M12,2A7,7 0 0,0 5,9C5,11.38 6.19,13.47 8,14.74V17A1,1 0 0,0 9,18H15A1,1 0 0,0 16,17V14.74C17.81,13.47 19,11.38 19,9A7,7 0 0,0 12,2M9,21A1,1 0 0,0 10,22H14A1,1 0 0,0 15,21V20H9V21Z\";\r\nvar mdiLightbulbCfl = \"M10.5 2C11.88 2 13 3.12 13 4.5V14H14V4.47C14 3.56 13.63 2.7 13 2.05C13.17 2 13.33 2 13.5 2C14.88 2 16 3.12 16 4.5V14H17V17C17 17.55 16.55 18 16 18H8C7.45 18 7 17.55 7 17V14H8V4.5C8 3.12 9.12 2 10.5 2M10.5 4C10.22 4 10 4.22 10 4.5V14H11V4.5C11 4.22 10.78 4 10.5 4M9 20H15V21C15 21.55 14.55 22 14 22H10C9.45 22 9 21.55 9 21V20Z\";\r\nvar mdiLightbulbCflOff = \"M14 4.47C14 3.56 13.63 2.7 13 2.05C13.17 2 13.33 2 13.5 2C14.88 2 16 3.12 16 4.5V14H17V15.18L14 12.18V4.5L14 4.47M10 4.5C10 4.22 10.22 4 10.5 4S11 4.22 11 4.5V9.18L13 11.18V4.5C13 3.12 11.88 2 10.5 2S8 3.12 8 4.5V6.18L10 8.18V4.5M9 21C9 21.55 9.45 22 10 22H14C14.55 22 15 21.55 15 21V20H9V21M20 20.72L18.73 22L14.73 18H8C7.45 18 7 17.55 7 17V14H8V11.27L2 5.27L3.28 4L20 20.72Z\";\r\nvar mdiLightbulbCflSpiral = \"M11 2C10.84 2 10.69 2.03 10.55 2.1L8.55 3.1C7.56 3.66 8 5 9 5C9.16 5 9.32 4.95 9.45 4.9L11.45 3.9C12.43 3.36 12 2 11 2M15 4C14.83 4 14.69 4.03 14.55 4.1L8.55 7.1C7.56 7.68 8 9 9 9C9.18 9 9.32 8.95 9.45 8.9L15.45 5.9C16.41 5.43 16 4 15 4M15 8C14.84 8 14.69 8.03 14.55 8.1L8.7 11.03C8.2 11.25 8 11.6 8 12V14H7V17C7 17.55 7.44 18 8 18H16C16.55 18 17 17.55 17 17V14H16V13C16 12.44 15.55 12 15 12C14.45 12 14 12.45 14 13V14H10V12.62L15.45 9.9C16.42 9.34 16 8 15 8M9 20V21C9 21.57 9.46 22 10 22H14C14.56 22 15 21.55 15 21V20\";\r\nvar mdiLightbulbCflSpiralOff = \"M15.45 9.9L13.88 10.68L12.38 9.18L14.55 8.1C14.69 8.03 14.84 8 15 8C16 8 16.42 9.34 15.45 9.9M11.22 8L15.45 5.9C16.41 5.43 16 4 15 4C14.83 4 14.69 4.03 14.55 4.1L9.72 6.5L11.22 8M20.84 22.73L16.09 18H8C7.44 18 7 17.55 7 17V14H8V12C8 11.6 8.2 11.25 8.7 11.03L9 10.88L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M12.11 14L10.5 12.38L10 12.62V14H12.11M9 21C9 21.57 9.46 22 10 22H14C14.56 22 15 21.55 15 21V20H9V21M9 5C9.16 5 9.32 4.95 9.45 4.9L11.45 3.9C12.43 3.36 12 2 11 2C10.84 2 10.69 2.03 10.55 2.1L8.55 3.1C7.56 3.66 8 5 9 5Z\";\r\nvar mdiLightbulbGroup = \"M15 14V16A1 1 0 0 1 14 17H10A1 1 0 0 1 9 16V14A5 5 0 1 1 15 14M14 18H10V19A1 1 0 0 0 11 20H13A1 1 0 0 0 14 19M7 19V18H5V19A1 1 0 0 0 6 20H7.17A2.93 2.93 0 0 1 7 19M5 10A6.79 6.79 0 0 1 5.68 7A4 4 0 0 0 4 14.45V16A1 1 0 0 0 5 17H7V14.88A6.92 6.92 0 0 1 5 10M17 18V19A2.93 2.93 0 0 1 16.83 20H18A1 1 0 0 0 19 19V18M18.32 7A6.79 6.79 0 0 1 19 10A6.92 6.92 0 0 1 17 14.88V17H19A1 1 0 0 0 20 16V14.45A4 4 0 0 0 18.32 7Z\";\r\nvar mdiLightbulbGroupOff = \"M20.84 22.73L18.09 20C18.06 20 18.03 20 18 20H16.83C16.94 19.68 17 19.34 17 19V18.89L14.75 16.64C14.57 16.86 14.31 17 14 17H10C9.45 17 9 16.55 9 16V14C7.4 12.8 6.74 10.84 7.12 9L5.5 7.4C5.18 8.23 5 9.11 5 10C5 11.83 5.72 13.58 7 14.88V17H5C4.45 17 4 16.55 4 16V14.45C2.86 13.79 2.12 12.62 2 11.31C1.85 9.27 3.25 7.5 5.2 7.09L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M15 6C13.22 4.67 10.86 4.72 9.13 5.93L16.08 12.88C17.63 10.67 17.17 7.63 15 6M19.79 16.59C19.91 16.42 20 16.22 20 16V14.45C21.91 13.34 22.57 10.9 21.46 9C20.8 7.85 19.63 7.11 18.32 7C18.77 7.94 19 8.96 19 10C19 11.57 18.47 13.09 17.5 14.31L19.79 16.59M10 19C10 19.55 10.45 20 11 20H13C13.55 20 14 19.55 14 19V18H10V19M7 18H5V19C5 19.55 5.45 20 6 20H7.17C7.06 19.68 7 19.34 7 19V18Z\";\r\nvar mdiLightbulbGroupOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L5.2 7.09C3.25 7.5 1.85 9.27 2 11.31C2.12 12.62 2.86 13.79 4 14.45V16C4 16.55 4.45 17 5 17H7V14.88C5.72 13.58 5 11.83 5 10C5 9.11 5.18 8.23 5.5 7.4L7.12 9C6.74 10.84 7.4 12.8 9 14V16C9 16.55 9.45 17 10 17H14C14.31 17 14.57 16.86 14.75 16.64L17 18.89V19C17 19.34 16.94 19.68 16.83 20H18C18.03 20 18.06 20 18.09 20L20.84 22.73L22.11 21.46M9.23 11.12L10.87 12.76C10.11 12.46 9.53 11.86 9.23 11.12M13 15H11V12.89L13 14.89V15M10.57 7.37L9.13 5.93C10.86 4.72 13.22 4.67 15 6C16.26 6.94 17 8.43 17 10C17 11.05 16.67 12.05 16.08 12.88L14.63 11.43C14.86 11 15 10.5 15 10C15 8.34 13.67 7 12 7C11.5 7 11 7.14 10.57 7.37M17.5 14.31C18.47 13.09 19 11.57 19 10C19 8.96 18.77 7.94 18.32 7C19.63 7.11 20.8 7.85 21.46 9C22.57 10.9 21.91 13.34 20 14.45V16C20 16.22 19.91 16.42 19.79 16.59L17.5 14.31M10 18H14V19C14 19.55 13.55 20 13 20H11C10.45 20 10 19.55 10 19V18M7 19C7 19.34 7.06 19.68 7.17 20H6C5.45 20 5 19.55 5 19V18H7V19Z\";\r\nvar mdiLightbulbGroupOutline = \"M7 19A2.93 2.93 0 0 0 7.17 20H6A1 1 0 0 1 5 19V18H7M10 19A1 1 0 0 0 11 20H13A1 1 0 0 0 14 19V18H10M4 16A1 1 0 0 0 5 17H7V14.88A6.92 6.92 0 0 1 5 10A6.79 6.79 0 0 1 5.68 7A4 4 0 0 0 4 14.45M17 19A2.93 2.93 0 0 1 16.83 20H18A1 1 0 0 0 19 19V18H17M17 10A5 5 0 0 1 15 14V16A1 1 0 0 1 14 17H10A1 1 0 0 1 9 16V14A5 5 0 1 1 17 10M15 10A3 3 0 1 0 11 12.82V15H13V12.82A3 3 0 0 0 15 10M18.32 7A6.79 6.79 0 0 1 19 10A6.92 6.92 0 0 1 17 14.88V17H19A1 1 0 0 0 20 16V14.45A4 4 0 0 0 18.32 7Z\";\r\nvar mdiLightbulbMultiple = \"M17 16V18C17 18.55 16.53 19 16 19H12C11.42 19 11 18.55 11 18V16C8.77 14.34 8.32 11.21 10 9S14.77 6.34 17 8 19.63 12.79 18 15C17.69 15.38 17.35 15.72 17 16M16 20H12V21C12 21.55 12.42 22 13 22H15C15.53 22 16 21.55 16 21M7.66 15H7V16C7 16.55 7.42 17 8 17H9V16.88C8.44 16.33 8 15.7 7.66 15M13.58 5C12.46 2.47 9.5 1.33 7 2.45S3.31 6.5 4.43 9.04C4.77 9.81 5.3 10.5 6 11V13C6 13.55 6.42 14 7 14H7.28C7.07 13.35 6.97 12.68 7 12C6.97 8.29 9.87 5.21 13.58 5Z\";\r\nvar mdiLightbulbMultipleOff = \"M20.84 22.73L16.74 18.63C16.55 18.85 16.29 19 16 19H12C11.42 19 11 18.55 11 18V16C9.37 14.8 8.71 12.82 9.1 11L7.5 9.39C7.17 10.2 6.97 11.08 7 12C6.97 12.68 7.07 13.35 7.28 14H7C6.42 14 6 13.55 6 13V11C5.3 10.5 4.77 9.81 4.43 9.04C4 8.05 3.91 7 4.12 6L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M13.58 5C12.46 2.47 9.5 1.33 7 2.45C6.68 2.58 6.39 2.75 6.13 2.93L9.67 6.47C10.76 5.63 12.1 5.08 13.58 5M18.06 14.86C19.6 12.66 19.14 9.62 17 8C15.2 6.67 12.84 6.72 11.12 7.92L18.06 14.86M12 21C12 21.55 12.42 22 13 22H15C15.53 22 16 21.55 16 21V20H12V21M7 15V16C7 16.55 7.42 17 8 17H9V16.88C8.43 16.33 8 15.7 7.66 15H7Z\";\r\nvar mdiLightbulbMultipleOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L4.14 6.03C3.93 7 4 8.05 4.45 9.04C4.79 9.81 5.33 10.5 6 11V13C6 13.55 6.45 14 7 14H7.3C7.1 13.35 7 12.68 7 12C7 11.08 7.19 10.21 7.5 9.41L9.11 11C9.05 11.33 9 11.66 9 12C9 13.57 9.74 15.06 11 16V18C11 18.55 11.45 19 12 19H16C16.31 19 16.57 18.86 16.75 18.64L20.84 22.73L22.11 21.46M11.23 13.12L12.87 14.76C12.1 14.44 11.53 13.85 11.23 13.12M15 17H13V14.89L15 16.89V17M9.69 6.5L6.14 2.94C6.41 2.75 6.7 2.58 7 2.44C9.53 1.33 12.5 2.47 13.6 5C12.12 5.09 10.77 5.63 9.69 6.5M11.12 7.92C11.94 7.35 12.93 7 14 7C15.57 7 17.06 7.74 18 9C19.33 10.78 19.28 13.14 18.07 14.87L16.62 13.42C16.7 13.28 16.77 13.14 16.83 13C17.38 11.43 16.56 9.72 15 9.16C14.16 8.87 13.29 8.97 12.57 9.37L11.12 7.92M7.68 15C8 15.7 8.46 16.33 9 16.88V17H8C7.45 17 7 16.55 7 16V15H7.68M12 20H16V21C16 21.55 15.55 22 15 22H13C12.45 22 12 21.55 12 21V20Z\";\r\nvar mdiLightbulbMultipleOutline = \"M12 21C12 21.55 12.45 22 13 22H15C15.55 22 16 21.55 16 21V20H12M14 7C11.24 7 9 9.24 9 12C9 13.57 9.74 15.06 11 16V18C11 18.55 11.45 19 12 19H16C16.55 19 17 18.55 17 18V16C19.21 14.34 19.66 11.21 18 9C17.06 7.74 15.57 7 14 7M15 14.82V17H13V14.82C11.44 14.27 10.62 12.55 11.17 11C11.72 9.43 13.44 8.61 15 9.16C16.56 9.72 17.38 11.43 16.83 13C16.53 13.85 15.85 14.5 15 14.82M7.68 15H7V16C7 16.55 7.45 17 8 17H9V16.88C8.46 16.33 8 15.7 7.68 15M13.6 5C12.5 2.47 9.53 1.33 7 2.45S3.34 6.5 4.45 9.04C4.79 9.81 5.33 10.5 6 11V13C6 13.55 6.45 14 7 14H7.3C7.1 13.35 7 12.68 7 12C7 8.29 9.89 5.21 13.6 5Z\";\r\nvar mdiLightbulbOff = \"M12,2C9.76,2 7.78,3.05 6.5,4.68L16.31,14.5C17.94,13.21 19,11.24 19,9A7,7 0 0,0 12,2M3.28,4L2,5.27L5.04,8.3C5,8.53 5,8.76 5,9C5,11.38 6.19,13.47 8,14.74V17A1,1 0 0,0 9,18H14.73L18.73,22L20,20.72L3.28,4M9,20V21A1,1 0 0,0 10,22H14A1,1 0 0,0 15,21V20H9Z\";\r\nvar mdiLightbulbOffOutline = \"M12,2C9.76,2 7.78,3.05 6.5,4.68L7.93,6.11C8.84,4.84 10.32,4 12,4A5,5 0 0,1 17,9C17,10.68 16.16,12.16 14.89,13.06L16.31,14.5C17.94,13.21 19,11.24 19,9A7,7 0 0,0 12,2M3.28,4L2,5.27L5.04,8.3C5,8.53 5,8.76 5,9C5,11.38 6.19,13.47 8,14.74V17A1,1 0 0,0 9,18H14.73L18.73,22L20,20.72L3.28,4M7.23,10.5L12.73,16H10V13.58C8.68,13 7.66,11.88 7.23,10.5M9,20V21A1,1 0 0,0 10,22H14A1,1 0 0,0 15,21V20H9Z\";\r\nvar mdiLightbulbOn = \"M12,6A6,6 0 0,1 18,12C18,14.22 16.79,16.16 15,17.2V19A1,1 0 0,1 14,20H10A1,1 0 0,1 9,19V17.2C7.21,16.16 6,14.22 6,12A6,6 0 0,1 12,6M14,21V22A1,1 0 0,1 13,23H11A1,1 0 0,1 10,22V21H14M20,11H23V13H20V11M1,11H4V13H1V11M13,1V4H11V1H13M4.92,3.5L7.05,5.64L5.63,7.05L3.5,4.93L4.92,3.5M16.95,5.63L19.07,3.5L20.5,4.93L18.37,7.05L16.95,5.63Z\";\r\nvar mdiLightbulbOnOutline = \"M20,11H23V13H20V11M1,11H4V13H1V11M13,1V4H11V1H13M4.92,3.5L7.05,5.64L5.63,7.05L3.5,4.93L4.92,3.5M16.95,5.63L19.07,3.5L20.5,4.93L18.37,7.05L16.95,5.63M12,6A6,6 0 0,1 18,12C18,14.22 16.79,16.16 15,17.2V19A1,1 0 0,1 14,20H10A1,1 0 0,1 9,19V17.2C7.21,16.16 6,14.22 6,12A6,6 0 0,1 12,6M14,21V22A1,1 0 0,1 13,23H11A1,1 0 0,1 10,22V21H14M11,18H13V15.87C14.73,15.43 16,13.86 16,12A4,4 0 0,0 12,8A4,4 0 0,0 8,12C8,13.86 9.27,15.43 11,15.87V18Z\";\r\nvar mdiLightbulbOutline = \"M12,2A7,7 0 0,1 19,9C19,11.38 17.81,13.47 16,14.74V17A1,1 0 0,1 15,18H9A1,1 0 0,1 8,17V14.74C6.19,13.47 5,11.38 5,9A7,7 0 0,1 12,2M9,21V20H15V21A1,1 0 0,1 14,22H10A1,1 0 0,1 9,21M12,4A5,5 0 0,0 7,9C7,11.05 8.23,12.81 10,13.58V16H14V13.58C15.77,12.81 17,11.05 17,9A5,5 0 0,0 12,4Z\";\r\nvar mdiLighthouse = \"M8,10V8H9V4H8V3L12,1L16,3V4H15V8H16V10H14.74L8.44,13.64L9,10H8M13,8V4H11V8H13M7,23L7.04,22.76L16.15,17.5L16.67,20.88L13,23H7M8.05,16.17L15.31,12L15.83,15.37L7.43,20.22L8.05,16.17Z\";\r\nvar mdiLighthouseOn = \"M1,10V2L10,5V7L1,10M8,10V8H13V4H8V3L12,1L16,3V4H15V8H16V10H14.74L8.44,13.64L9,10H8M7,23L7.04,22.76L16.15,17.5L16.67,20.88L13,23H7M8.05,16.17L15.31,12L15.83,15.37L7.43,20.22L8.05,16.17Z\";\r\nvar mdiLightningBolt = \"M11 15H6L13 1V9H18L11 23V15Z\";\r\nvar mdiLightningBoltOutline = \"M11 9.47V11H14.76L13 14.53V13H9.24L11 9.47M13 1L6 15H11V23L18 9H13V1Z\";\r\nvar mdiLingerie = \"M22 7H20V2H18V4.34L12 6.91L6 4.34V2H4V7H2V9H4.05C4.3 11.25 6.19 13 8.5 13C9.92 13 11.18 12.33 12 11.3C12.83 12.33 14.08 13 15.5 13C17.81 13 19.7 11.25 19.95 9H22V7M8.5 11C7.12 11 6 9.88 6 8.5V6.5L11 8.65C10.9 9.96 9.83 11 8.5 11M18 8.5C18 9.88 16.88 11 15.5 11C14.17 11 13.1 9.96 13 8.65L18 6.5V8.5M2 15V17H3C5.97 17 8.43 19.17 8.91 22H15.09C15.57 19.17 18.03 17 21 17H22V15H2M13.59 20H10.41C9.94 18.84 9.21 17.82 8.29 17H15.71C14.79 17.82 14.06 18.84 13.59 20Z\";\r\nvar mdiLink = \"M3.9,12C3.9,10.29 5.29,8.9 7,8.9H11V7H7A5,5 0 0,0 2,12A5,5 0 0,0 7,17H11V15.1H7C5.29,15.1 3.9,13.71 3.9,12M8,13H16V11H8V13M17,7H13V8.9H17C18.71,8.9 20.1,10.29 20.1,12C20.1,13.71 18.71,15.1 17,15.1H13V17H17A5,5 0 0,0 22,12A5,5 0 0,0 17,7Z\";\r\nvar mdiLinkBox = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M11,16H10C8.39,16 6,14.94 6,12C6,9.07 8.39,8 10,8H11V10H10C9.54,10 8,10.17 8,12C8,13.9 9.67,14 10,14H11V16M15,11V13H9V11H15M14,16H13V14H14C14.46,14 16,13.83 16,12C16,10.1 14.33,10 14,10H13V8H14C15.61,8 18,9.07 18,12C18,14.94 15.61,16 14,16Z\";\r\nvar mdiLinkBoxOutline = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M11,16H10C8.39,16 6,14.94 6,12C6,9.07 8.39,8 10,8H11V10H10C9.54,10 8,10.17 8,12C8,13.9 9.67,14 10,14H11V16M14,16H13V14H14C14.46,14 16,13.83 16,12C16,10.1 14.33,10 14,10H13V8H14C15.61,8 18,9.07 18,12C18,14.94 15.61,16 14,16M15,13H9V11H15V13Z\";\r\nvar mdiLinkBoxVariant = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M13.94,14.81L11.73,17C11.08,17.67 10.22,18 9.36,18C8.5,18 7.64,17.67 7,17C5.67,15.71 5.67,13.58 7,12.26L8.35,10.9L8.34,11.5C8.33,12 8.41,12.5 8.57,12.94L8.62,13.09L8.22,13.5C7.91,13.8 7.74,14.21 7.74,14.64C7.74,15.07 7.91,15.47 8.22,15.78C8.83,16.4 9.89,16.4 10.5,15.78L12.7,13.59C13,13.28 13.18,12.87 13.18,12.44C13.18,12 13,11.61 12.7,11.3C12.53,11.14 12.44,10.92 12.44,10.68C12.44,10.45 12.53,10.23 12.7,10.06C13.03,9.73 13.61,9.74 13.94,10.06C14.57,10.7 14.92,11.54 14.92,12.44C14.92,13.34 14.57,14.18 13.94,14.81M17,11.74L15.66,13.1V12.5C15.67,12 15.59,11.5 15.43,11.06L15.38,10.92L15.78,10.5C16.09,10.2 16.26,9.79 16.26,9.36C16.26,8.93 16.09,8.53 15.78,8.22C15.17,7.6 14.1,7.61 13.5,8.22L11.3,10.42C11,10.72 10.82,11.13 10.82,11.56C10.82,12 11,12.39 11.3,12.7C11.47,12.86 11.56,13.08 11.56,13.32C11.56,13.56 11.47,13.78 11.3,13.94C11.13,14.11 10.91,14.19 10.68,14.19C10.46,14.19 10.23,14.11 10.06,13.94C8.75,12.63 8.75,10.5 10.06,9.19L12.27,7C13.58,5.67 15.71,5.68 17,7C17.65,7.62 18,8.46 18,9.36C18,10.26 17.65,11.1 17,11.74Z\";\r\nvar mdiLinkBoxVariantOutline = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M19,19H5V5H19V19M13.94,10.06C14.57,10.7 14.92,11.54 14.92,12.44C14.92,13.34 14.57,14.18 13.94,14.81L11.73,17C11.08,17.67 10.22,18 9.36,18C8.5,18 7.64,17.67 7,17C5.67,15.71 5.67,13.58 7,12.26L8.35,10.9L8.34,11.5C8.33,12 8.41,12.5 8.57,12.94L8.62,13.09L8.22,13.5C7.91,13.8 7.74,14.21 7.74,14.64C7.74,15.07 7.91,15.47 8.22,15.78C8.83,16.4 9.89,16.4 10.5,15.78L12.7,13.59C13,13.28 13.18,12.87 13.18,12.44C13.18,12 13,11.61 12.7,11.3C12.53,11.14 12.44,10.92 12.44,10.68C12.44,10.45 12.53,10.23 12.7,10.06C13.03,9.73 13.61,9.74 13.94,10.06M18,9.36C18,10.26 17.65,11.1 17,11.74L15.66,13.1V12.5C15.67,12 15.59,11.5 15.43,11.06L15.38,10.92L15.78,10.5C16.09,10.2 16.26,9.79 16.26,9.36C16.26,8.93 16.09,8.53 15.78,8.22C15.17,7.6 14.1,7.61 13.5,8.22L11.3,10.42C11,10.72 10.82,11.13 10.82,11.56C10.82,12 11,12.39 11.3,12.7C11.47,12.86 11.56,13.08 11.56,13.32C11.56,13.56 11.47,13.78 11.3,13.94C11.13,14.11 10.91,14.19 10.68,14.19C10.46,14.19 10.23,14.11 10.06,13.94C8.75,12.63 8.75,10.5 10.06,9.19L12.27,7C13.58,5.67 15.71,5.68 17,7C17.65,7.62 18,8.46 18,9.36Z\";\r\nvar mdiLinkLock = \"M23 16V15.5A2.5 2.5 0 0 0 18 15.5V16A1 1 0 0 0 17 17V21A1 1 0 0 0 18 22H23A1 1 0 0 0 24 21V17A1 1 0 0 0 23 16M22 16H19V15.5A1.5 1.5 0 0 1 22 15.5M7 8.9H11V7H7A5 5 0 0 0 7 17H11V15.1H7A3.1 3.1 0 0 1 7 8.9M8 11V13H16V11M13 15.1V17H15V15.1M17 7H13V8.9H17A3.09 3.09 0 0 1 19.94 11A5.12 5.12 0 0 1 20.5 11H21.9A5 5 0 0 0 17 7Z\";\r\nvar mdiLinkOff = \"M17,7H13V8.9H17C18.71,8.9 20.1,10.29 20.1,12C20.1,13.43 19.12,14.63 17.79,15L19.25,16.44C20.88,15.61 22,13.95 22,12A5,5 0 0,0 17,7M16,11H13.81L15.81,13H16V11M2,4.27L5.11,7.38C3.29,8.12 2,9.91 2,12A5,5 0 0,0 7,17H11V15.1H7C5.29,15.1 3.9,13.71 3.9,12C3.9,10.41 5.11,9.1 6.66,8.93L8.73,11H8V13H10.73L13,15.27V17H14.73L18.74,21L20,19.74L3.27,3L2,4.27Z\";\r\nvar mdiLinkPlus = \"M7,7H11V9H7A3,3 0 0,0 4,12A3,3 0 0,0 7,15H11V17H7A5,5 0 0,1 2,12A5,5 0 0,1 7,7M17,7A5,5 0 0,1 22,12H20A3,3 0 0,0 17,9H13V7H17M8,11H16V13H8V11M17,12H19V15H22V17H19V20H17V17H14V15H17V12Z\";\r\nvar mdiLinkVariant = \"M10.59,13.41C11,13.8 11,14.44 10.59,14.83C10.2,15.22 9.56,15.22 9.17,14.83C7.22,12.88 7.22,9.71 9.17,7.76V7.76L12.71,4.22C14.66,2.27 17.83,2.27 19.78,4.22C21.73,6.17 21.73,9.34 19.78,11.29L18.29,12.78C18.3,11.96 18.17,11.14 17.89,10.36L18.36,9.88C19.54,8.71 19.54,6.81 18.36,5.64C17.19,4.46 15.29,4.46 14.12,5.64L10.59,9.17C9.41,10.34 9.41,12.24 10.59,13.41M13.41,9.17C13.8,8.78 14.44,8.78 14.83,9.17C16.78,11.12 16.78,14.29 14.83,16.24V16.24L11.29,19.78C9.34,21.73 6.17,21.73 4.22,19.78C2.27,17.83 2.27,14.66 4.22,12.71L5.71,11.22C5.7,12.04 5.83,12.86 6.11,13.65L5.64,14.12C4.46,15.29 4.46,17.19 5.64,18.36C6.81,19.54 8.71,19.54 9.88,18.36L13.41,14.83C14.59,13.66 14.59,11.76 13.41,10.59C13,10.2 13,9.56 13.41,9.17Z\";\r\nvar mdiLinkVariantMinus = \"M10.6 13.4A1 1 0 0 1 9.2 14.8A4.8 4.8 0 0 1 9.2 7.8L12.7 4.2A5.1 5.1 0 0 1 19.8 4.2A5.1 5.1 0 0 1 19.8 11.3L18.3 12.8A6.4 6.4 0 0 0 17.9 10.4L18.4 9.9A3.2 3.2 0 0 0 18.4 5.6A3.2 3.2 0 0 0 14.1 5.6L10.6 9.2A2.9 2.9 0 0 0 10.6 13.4M23 18V20H15V18M16.2 13.7A4.8 4.8 0 0 0 14.8 9.2A1 1 0 0 0 13.4 10.6A2.9 2.9 0 0 1 13.4 14.8L9.9 18.4A3.2 3.2 0 0 1 5.6 18.4A3.2 3.2 0 0 1 5.6 14.1L6.1 13.7A7.3 7.3 0 0 1 5.7 11.2L4.2 12.7A5.1 5.1 0 0 0 4.2 19.8A5.1 5.1 0 0 0 11.3 19.8L13.1 18A6 6 0 0 1 16.2 13.7Z\";\r\nvar mdiLinkVariantOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L13.9,17.17L11.29,19.78C9.34,21.73 6.17,21.73 4.22,19.78C2.27,17.83 2.27,14.66 4.22,12.71L5.71,11.22C5.7,12.04 5.83,12.86 6.11,13.65L5.64,14.12C4.46,15.29 4.46,17.19 5.64,18.36C6.81,19.54 8.71,19.54 9.88,18.36L12.5,15.76L10.88,14.15C10.87,14.39 10.77,14.64 10.59,14.83C10.2,15.22 9.56,15.22 9.17,14.83C8.12,13.77 7.63,12.37 7.72,11L2,5.27M12.71,4.22C14.66,2.27 17.83,2.27 19.78,4.22C21.73,6.17 21.73,9.34 19.78,11.29L18.29,12.78C18.3,11.96 18.17,11.14 17.89,10.36L18.36,9.88C19.54,8.71 19.54,6.81 18.36,5.64C17.19,4.46 15.29,4.46 14.12,5.64L10.79,8.97L9.38,7.55L12.71,4.22M13.41,9.17C13.8,8.78 14.44,8.78 14.83,9.17C16.2,10.54 16.61,12.5 16.06,14.23L14.28,12.46C14.23,11.78 13.94,11.11 13.41,10.59C13,10.2 13,9.56 13.41,9.17Z\";\r\nvar mdiLinkVariantPlus = \"M10.6 13.4A1 1 0 0 1 9.2 14.8A4.8 4.8 0 0 1 9.2 7.8L12.7 4.2A5.1 5.1 0 0 1 19.8 4.2A5.1 5.1 0 0 1 19.8 11.3L18.3 12.8A6.4 6.4 0 0 0 17.9 10.4L18.4 9.9A3.2 3.2 0 0 0 18.4 5.6A3.2 3.2 0 0 0 14.1 5.6L10.6 9.2A2.9 2.9 0 0 0 10.6 13.4M23 18V20H20V23H18V20H15V18H18V15H20V18M16.2 13.7A4.8 4.8 0 0 0 14.8 9.2A1 1 0 0 0 13.4 10.6A2.9 2.9 0 0 1 13.4 14.8L9.9 18.4A3.2 3.2 0 0 1 5.6 18.4A3.2 3.2 0 0 1 5.6 14.1L6.1 13.7A7.3 7.3 0 0 1 5.7 11.2L4.2 12.7A5.1 5.1 0 0 0 4.2 19.8A5.1 5.1 0 0 0 11.3 19.8L13.1 18A6 6 0 0 1 16.2 13.7Z\";\r\nvar mdiLinkVariantRemove = \"M10.6 13.4A1 1 0 0 1 9.2 14.8A4.8 4.8 0 0 1 9.2 7.8L12.7 4.2A5.1 5.1 0 0 1 19.8 4.2A5.1 5.1 0 0 1 19.8 11.3L18.3 12.8A6.4 6.4 0 0 0 17.9 10.4L18.4 9.9A3.2 3.2 0 0 0 18.4 5.6A3.2 3.2 0 0 0 14.1 5.6L10.6 9.2A2.9 2.9 0 0 0 10.6 13.4M16.2 13.7A4.8 4.8 0 0 0 14.8 9.2A1 1 0 0 0 13.4 10.6A2.9 2.9 0 0 1 13.4 14.8L9.9 18.4A3.2 3.2 0 0 1 5.6 18.4A3.2 3.2 0 0 1 5.6 14.1L6.1 13.7A7.3 7.3 0 0 1 5.7 11.2L4.2 12.7A5.1 5.1 0 0 0 4.2 19.8A5.1 5.1 0 0 0 11.3 19.8L13.1 18A6 6 0 0 1 16.2 13.7M21.1 15.5L19 17.6L16.9 15.5L15.5 16.9L17.6 19L15.5 21.1L16.9 22.5L19 20.4L21.1 22.5L22.5 21.1L20.4 19L22.5 16.9Z\";\r\nvar mdiLinkedin = \"M19 3A2 2 0 0 1 21 5V19A2 2 0 0 1 19 21H5A2 2 0 0 1 3 19V5A2 2 0 0 1 5 3H19M18.5 18.5V13.2A3.26 3.26 0 0 0 15.24 9.94C14.39 9.94 13.4 10.46 12.92 11.24V10.13H10.13V18.5H12.92V13.57C12.92 12.8 13.54 12.17 14.31 12.17A1.4 1.4 0 0 1 15.71 13.57V18.5H18.5M6.88 8.56A1.68 1.68 0 0 0 8.56 6.88C8.56 5.95 7.81 5.19 6.88 5.19A1.69 1.69 0 0 0 5.19 6.88C5.19 7.81 5.95 8.56 6.88 8.56M8.27 18.5V10.13H5.5V18.5H8.27Z\";\r\nvar mdiLinux = \"M14.62,8.35C14.2,8.63 12.87,9.39 12.67,9.54C12.28,9.85 11.92,9.83 11.53,9.53C11.33,9.37 10,8.61 9.58,8.34C9.1,8.03 9.13,7.64 9.66,7.42C11.3,6.73 12.94,6.78 14.57,7.45C15.06,7.66 15.08,8.05 14.62,8.35M21.84,15.63C20.91,13.54 19.64,11.64 18,9.97C17.47,9.42 17.14,8.8 16.94,8.09C16.84,7.76 16.77,7.42 16.7,7.08C16.5,6.2 16.41,5.3 16,4.47C15.27,2.89 14,2.07 12.16,2C10.35,2.05 9,2.81 8.21,4.4C8,4.83 7.85,5.28 7.75,5.74C7.58,6.5 7.43,7.29 7.25,8.06C7.1,8.71 6.8,9.27 6.29,9.77C4.68,11.34 3.39,13.14 2.41,15.12C2.27,15.41 2.13,15.7 2.04,16C1.85,16.66 2.33,17.12 3.03,16.96C3.47,16.87 3.91,16.78 4.33,16.65C4.74,16.5 4.9,16.6 5,17C5.65,19.15 7.07,20.66 9.24,21.5C13.36,23.06 18.17,20.84 19.21,16.92C19.28,16.65 19.38,16.55 19.68,16.65C20.14,16.79 20.61,16.89 21.08,17C21.57,17.09 21.93,16.84 22,16.36C22.03,16.1 21.94,15.87 21.84,15.63\";\r\nvar mdiLinuxMint = \"M2,3.23V6.8H3.5C4.59,6.8 4.78,7.53 4.78,8.55V14.86C4.78,18.12 7.65,20.77 11.18,20.77H19.9C21,20.77 22,20.07 22,19V9.2C22,5.93 19.13,3.28 15.6,3.28H11.93V3.27L2,3.23V3.23M6.62,5.46H8.37V14.45C8.37,15.65 9.19,16.59 10.16,16.59L16.13,16.61C17.38,16.61 18.35,15.75 18.35,14.73L18.34,9.96C18.34,9.65 18.24,9.41 18,9.19C17.79,8.96 17.56,8.86 17.25,8.86C16.94,8.86 16.71,8.96 16.5,9.19C16.27,9.41 16.16,9.65 16.16,9.96V14.05H14.31V9.96C14.31,9.65 14.21,9.41 14,9.19C13.77,8.96 13.54,8.86 13.22,8.86C12.92,8.86 12.68,8.96 12.46,9.19C12.24,9.41 12.14,9.65 12.14,9.96V14.05H10.29V9.96C10.29,9.15 10.58,8.44 11.15,7.86C11.72,7.29 12.43,7 13.22,7C14,7 14.68,7.28 15.24,7.82C15.79,7.28 16.47,7 17.25,7C18.05,7 18.76,7.29 19.32,7.86C19.89,8.44 20.19,9.15 20.19,9.96L20.2,15.06C20.11,15.91 19.75,16.67 19.13,17.31V17.31C18.4,18.04 17.5,18.42 16.5,18.42H9.83C9,18.34 8.29,17.95 7.69,17.36C7,16.65 6.62,15.79 6.62,14.79V5.46H6.62Z\";\r\nvar mdiLipstick = \"M9 23C8.45 23 8 22.55 8 22V13C8 12.45 8.45 12 9 12H15C15.55 12 16 12.45 16 13V22C16 22.55 15.55 23 15 23H9M10 11C9.45 11 9 10.55 9 10V5.25C9 5.25 11 3 11.75 1C12.83 1.67 13.92 2.33 14.46 3.83C15 5.33 15 7.67 15 10C15 10.55 14.55 11 14 11H10Z\";\r\nvar mdiListStatus = \"M16.5 11L13 7.5L14.4 6.1L16.5 8.2L20.7 4L22.1 5.4L16.5 11M11 7H2V9H11V7M21 13.4L19.6 12L17 14.6L14.4 12L13 13.4L15.6 16L13 18.6L14.4 20L17 17.4L19.6 20L21 18.6L18.4 16L21 13.4M11 15H2V17H11V15Z\";\r\nvar mdiLitecoin = \"M12.55,15.92L13.16,13.78L14.81,13.19L16.25,7.63L14.56,8.31L16.25,2H8L5.38,11.77L3.72,12.34L2.22,17.91L4,17.27L2.66,22H20.16L21.78,15.92H12.55M19.39,21H4L5.46,15.65L3.72,16.3L4.58,13.11L6.24,12.54L8.74,3H15L13.13,10L14.83,9.3L14,12.42L12.33,13L11.22,16.91H20.5L19.39,21Z\";\r\nvar mdiLoading = \"M12,4V2A10,10 0 0,0 2,12H4A8,8 0 0,1 12,4Z\";\r\nvar mdiLocationEnter = \"M14 12L10 8V11H2V13H10V16M22 12A10 10 0 0 1 2.46 15H4.59A8 8 0 1 0 4.59 9H2.46A10 10 0 0 1 22 12Z\";\r\nvar mdiLocationExit = \"M22 12L18 8V11H10V13H18V16M20 18A10 10 0 1 1 20 6H17.27A8 8 0 1 0 17.27 18Z\";\r\nvar mdiLock = \"M12,17A2,2 0 0,0 14,15C14,13.89 13.1,13 12,13A2,2 0 0,0 10,15A2,2 0 0,0 12,17M18,8A2,2 0 0,1 20,10V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V10C4,8.89 4.9,8 6,8H7V6A5,5 0 0,1 12,1A5,5 0 0,1 17,6V8H18M12,3A3,3 0 0,0 9,6V8H15V6A3,3 0 0,0 12,3Z\";\r\nvar mdiLockAlert = \"M10 17C11.1 17 12 16.1 12 15C12 13.9 11.1 13 10 13C8.9 13 8 13.9 8 15S8.9 17 10 17M16 8C17.1 8 18 8.9 18 10V20C18 21.1 17.1 22 16 22H4C2.9 22 2 21.1 2 20V10C2 8.9 2.9 8 4 8H5V6C5 3.2 7.2 1 10 1S15 3.2 15 6V8H16M10 3C8.3 3 7 4.3 7 6V8H13V6C13 4.3 11.7 3 10 3M22 13H20V7H22V13M22 17H20V15H22V17Z\";\r\nvar mdiLockAlertOutline = \"M10 17C8.9 17 8 16.1 8 15C8 13.9 8.9 13 10 13C11.1 13 12 13.9 12 15S11.1 17 10 17M16 20V10H4V20H16M16 8C17.1 8 18 8.9 18 10V20C18 21.1 17.1 22 16 22H4C2.9 22 2 21.1 2 20V10C2 8.9 2.9 8 4 8H5V6C5 3.2 7.2 1 10 1S15 3.2 15 6V8H16M10 3C8.3 3 7 4.3 7 6V8H13V6C13 4.3 11.7 3 10 3M22 7H20V13H22V7M22 15H20V17H22V15Z\";\r\nvar mdiLockCheck = \"M18 8C19.1 8 20 8.89 20 10V20C20 21.1 19.1 22 18 22H6C4.89 22 4 21.1 4 20V10C4 8.89 4.89 8 6 8H7V6C7 3.24 9.24 .998 12 .998C14.76 .998 17 3.24 17 6V8H18M12 3C10.34 3 9 4.34 9 6V8H15V6C15 4.34 13.66 3 12 3M11 19L17.25 12.76L15.84 11.35L11 16.18L8.41 13.6L7 15L11 19Z\";\r\nvar mdiLockClock = \"M8.5,2C6,2 4,4 4,6.5V7C2.89,7 2,7.89 2,9V18C2,19.11 2.89,20 4,20H8.72C10.18,21.29 12.06,22 14,22A8,8 0 0,0 22,14A8,8 0 0,0 14,6C13.66,6 13.32,6.03 13,6.08C12.76,3.77 10.82,2 8.5,2M8.5,4A2.5,2.5 0 0,1 11,6.5V7H6V6.5A2.5,2.5 0 0,1 8.5,4M14,8A6,6 0 0,1 20,14A6,6 0 0,1 14,20A6,6 0 0,1 8,14A6,6 0 0,1 14,8M13,10V15L16.64,17.19L17.42,15.9L14.5,14.15V10H13Z\";\r\nvar mdiLockOpen = \"M18,8A2,2 0 0,1 20,10V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V10A2,2 0 0,1 6,8H15V6A3,3 0 0,0 12,3A3,3 0 0,0 9,6H7A5,5 0 0,1 12,1A5,5 0 0,1 17,6V8H18M12,17A2,2 0 0,0 14,15A2,2 0 0,0 12,13A2,2 0 0,0 10,15A2,2 0 0,0 12,17Z\";\r\nvar mdiLockOpenAlert = \"M16 8C17.1 8 18 8.9 18 10V20C18 21.1 17.1 22 16 22H4C2.9 22 2 21.1 2 20V10C2 8.9 2.9 8 4 8H13V6C13 4.3 11.7 3 10 3S7 4.3 7 6H5C5 3.2 7.2 1 10 1S15 3.2 15 6V8H16M10 17C11.1 17 12 16.1 12 15S11.1 13 10 13 8 13.9 8 15 8.9 17 10 17M22 13H20V7H22V13M22 17H20V15H22V17Z\";\r\nvar mdiLockOpenAlertOutline = \"M16 20V10H4V20H16M16 8C17.1 8 18 8.9 18 10V20C18 21.1 17.1 22 16 22H4C2.9 22 2 21.1 2 20V10C2 8.9 2.9 8 4 8H13V6C13 4.3 11.7 3 10 3S7 4.3 7 6H5C5 3.2 7.2 1 10 1S15 3.2 15 6V8H16M10 17C8.9 17 8 16.1 8 15S8.9 13 10 13 12 13.9 12 15 11.1 17 10 17M22 7H20V13H22V7M22 15H20V17H22V15Z\";\r\nvar mdiLockOpenCheck = \"M18 8C19.1 8 20 8.9 20 10V20C20 21.1 19.1 22 18 22H6C4.89 22 4 21.1 4 20V10C4 8.9 4.89 8 6 8H15V6C15 4.34 13.66 3 12 3C10.34 3 9 4.34 9 6H7C7 3.24 9.24 1 12 1C14.76 1 17 3.24 17 6V8H18M11 19L17.25 12.76L15.84 11.35L11 16.18L8.41 13.6L7 15L11 19Z\";\r\nvar mdiLockOpenOutline = \"M18,20V10H6V20H18M18,8A2,2 0 0,1 20,10V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V10A2,2 0 0,1 6,8H15V6A3,3 0 0,0 12,3A3,3 0 0,0 9,6H7A5,5 0 0,1 12,1A5,5 0 0,1 17,6V8H18M12,17A2,2 0 0,1 10,15A2,2 0 0,1 12,13A2,2 0 0,1 14,15A2,2 0 0,1 12,17Z\";\r\nvar mdiLockOpenVariant = \"M18 1C15.24 1 13 3.24 13 6V8H4C2.9 8 2 8.89 2 10V20C2 21.11 2.9 22 4 22H16C17.11 22 18 21.11 18 20V10C18 8.9 17.11 8 16 8H15V6C15 4.34 16.34 3 18 3C19.66 3 21 4.34 21 6V8H23V6C23 3.24 20.76 1 18 1M10 13C11.1 13 12 13.89 12 15C12 16.11 11.11 17 10 17C8.9 17 8 16.11 8 15C8 13.9 8.9 13 10 13Z\";\r\nvar mdiLockOpenVariantOutline = \"M10 13C11.1 13 12 13.89 12 15C12 16.11 11.11 17 10 17S8 16.11 8 15 8.9 13 10 13M18 1C15.24 1 13 3.24 13 6V8H4C2.9 8 2 8.9 2 10V20C2 21.1 2.9 22 4 22H16C17.1 22 18 21.1 18 20V10C18 8.9 17.1 8 16 8H15V6C15 4.34 16.34 3 18 3S21 4.34 21 6V8H23V6C23 3.24 20.76 1 18 1M16 10V20H4V10H16Z\";\r\nvar mdiLockOutline = \"M12,17C10.89,17 10,16.1 10,15C10,13.89 10.89,13 12,13A2,2 0 0,1 14,15A2,2 0 0,1 12,17M18,20V10H6V20H18M18,8A2,2 0 0,1 20,10V20A2,2 0 0,1 18,22H6C4.89,22 4,21.1 4,20V10C4,8.89 4.89,8 6,8H7V6A5,5 0 0,1 12,1A5,5 0 0,1 17,6V8H18M12,3A3,3 0 0,0 9,6V8H15V6A3,3 0 0,0 12,3Z\";\r\nvar mdiLockPattern = \"M7,3A4,4 0 0,1 11,7C11,8.86 9.73,10.43 8,10.87V13.13C8.37,13.22 8.72,13.37 9.04,13.56L13.56,9.04C13.2,8.44 13,7.75 13,7A4,4 0 0,1 17,3A4,4 0 0,1 21,7A4,4 0 0,1 17,11C16.26,11 15.57,10.8 15,10.45L10.45,15C10.8,15.57 11,16.26 11,17A4,4 0 0,1 7,21A4,4 0 0,1 3,17C3,15.14 4.27,13.57 6,13.13V10.87C4.27,10.43 3,8.86 3,7A4,4 0 0,1 7,3M17,13A4,4 0 0,1 21,17A4,4 0 0,1 17,21A4,4 0 0,1 13,17A4,4 0 0,1 17,13M17,15A2,2 0 0,0 15,17A2,2 0 0,0 17,19A2,2 0 0,0 19,17A2,2 0 0,0 17,15Z\";\r\nvar mdiLockPlus = \"M18,8H17V6A5,5 0 0,0 12,1A5,5 0 0,0 7,6V8H6A2,2 0 0,0 4,10V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V10A2,2 0 0,0 18,8M8.9,6C8.9,4.29 10.29,2.9 12,2.9C13.71,2.9 15.1,4.29 15.1,6V8H8.9V6M16,16H13V19H11V16H8V14H11V11H13V14H16V16Z\";\r\nvar mdiLockQuestion = \"M12,1A5,5 0 0,0 7,6V8H6A2,2 0 0,0 4,10V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V10A2,2 0 0,0 18,8H17V6A5,5 0 0,0 12,1M12,2.9C13.71,2.9 15.1,4.29 15.1,6V8H8.9V6C8.9,4.29 10.29,2.9 12,2.9M12.19,10.5C13.13,10.5 13.88,10.71 14.42,11.12C14.96,11.54 15.23,12.1 15.23,12.8C15.23,13.24 15.08,13.63 14.79,14C14.5,14.36 14.12,14.64 13.66,14.85C13.4,15 13.23,15.15 13.14,15.32C13.05,15.5 13,15.72 13,16H11C11,15.5 11.1,15.16 11.29,14.92C11.5,14.68 11.84,14.4 12.36,14.08C12.62,13.94 12.83,13.76 13,13.54C13.14,13.33 13.22,13.08 13.22,12.8C13.22,12.5 13.13,12.28 12.95,12.11C12.77,11.93 12.5,11.85 12.19,11.85C11.92,11.85 11.7,11.92 11.5,12.06C11.34,12.2 11.24,12.41 11.24,12.69H9.27C9.22,12 9.5,11.4 10.05,11.04C10.59,10.68 11.3,10.5 12.19,10.5M11,17H13V19H11V17Z\";\r\nvar mdiLockReset = \"M12.63,2C18.16,2 22.64,6.5 22.64,12C22.64,17.5 18.16,22 12.63,22C9.12,22 6.05,20.18 4.26,17.43L5.84,16.18C7.25,18.47 9.76,20 12.64,20A8,8 0 0,0 20.64,12A8,8 0 0,0 12.64,4C8.56,4 5.2,7.06 4.71,11H7.47L3.73,14.73L0,11H2.69C3.19,5.95 7.45,2 12.63,2M15.59,10.24C16.09,10.25 16.5,10.65 16.5,11.16V15.77C16.5,16.27 16.09,16.69 15.58,16.69H10.05C9.54,16.69 9.13,16.27 9.13,15.77V11.16C9.13,10.65 9.54,10.25 10.04,10.24V9.23C10.04,7.7 11.29,6.46 12.81,6.46C14.34,6.46 15.59,7.7 15.59,9.23V10.24M12.81,7.86C12.06,7.86 11.44,8.47 11.44,9.23V10.24H14.19V9.23C14.19,8.47 13.57,7.86 12.81,7.86Z\";\r\nvar mdiLockSmart = \"M12,2A6,6 0 0,0 6,8V16A6,6 0 0,0 12,22A6,6 0 0,0 18,16V8A6,6 0 0,0 12,2M8,6H10V8H8V6M11,6H13V8H11V6M14,6H16V8H14V6M8,9H10V11H8V9M11,9H13V11H11V9M14,9H16V11H14V9M8,12H10V14H8V12M11,12H13V14H11V12M14,12H16V14H14V12M12,16A2,2 0 0,1 14,18A2,2 0 0,1 12,20A2,2 0 0,1 10,18A2,2 0 0,1 12,16Z\";\r\nvar mdiLocker = \"M8,2H16A2,2 0 0,1 18,4V20A2,2 0 0,1 16,22H8A2,2 0 0,1 6,20V4A2,2 0 0,1 8,2M8,4V20H16V4H8M10,13H12V17H10V13M10,6H14V7.5H10V6M10,9H14V10.5H10V9Z\";\r\nvar mdiLockerMultiple = \"M3,2H21A2,2 0 0,1 23,4V20A2,2 0 0,1 21,22H3A2,2 0 0,1 1,20V4A2,2 0 0,1 3,2M13,4V20H21V4H13M3,4V20H11V4H3M5,13H7V17H5V13M5,6H9V7.5H5V6M5,9H9V10.5H5V9M15,13H17V17H15V13M15,6H19V7.5H15V6M15,9H19V10.5H15V9Z\";\r\nvar mdiLogin = \"M10,17V14H3V10H10V7L15,12L10,17M10,2H19A2,2 0 0,1 21,4V20A2,2 0 0,1 19,22H10A2,2 0 0,1 8,20V18H10V20H19V4H10V6H8V4A2,2 0 0,1 10,2Z\";\r\nvar mdiLoginVariant = \"M19,3H5C3.89,3 3,3.89 3,5V9H5V5H19V19H5V15H3V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M10.08,15.58L11.5,17L16.5,12L11.5,7L10.08,8.41L12.67,11H3V13H12.67L10.08,15.58Z\";\r\nvar mdiLogout = \"M16,17V14H9V10H16V7L21,12L16,17M14,2A2,2 0 0,1 16,4V6H14V4H5V20H14V18H16V20A2,2 0 0,1 14,22H5A2,2 0 0,1 3,20V4A2,2 0 0,1 5,2H14Z\";\r\nvar mdiLogoutVariant = \"M14.08,15.59L16.67,13H7V11H16.67L14.08,8.41L15.5,7L20.5,12L15.5,17L14.08,15.59M19,3A2,2 0 0,1 21,5V9.67L19,7.67V5H5V19H19V16.33L21,14.33V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19Z\";\r\nvar mdiLongitude = \"M12 2A10 10 0 1 0 22 12A10.03 10.03 0 0 0 12 2M9.4 19.6A8.05 8.05 0 0 1 9.4 4.4A16.45 16.45 0 0 0 7.5 12A16.45 16.45 0 0 0 9.4 19.6M12 20A13.81 13.81 0 0 1 9.5 12A13.81 13.81 0 0 1 12 4A13.81 13.81 0 0 1 14.5 12A13.81 13.81 0 0 1 12 20M14.6 19.6A16.15 16.15 0 0 0 14.6 4.4A8.03 8.03 0 0 1 20 12A7.9 7.9 0 0 1 14.6 19.6Z\";\r\nvar mdiLooks = \"M12,6A11,11 0 0,0 1,17H3C3,12.04 7.04,8 12,8C16.96,8 21,12.04 21,17H23A11,11 0 0,0 12,6M12,10C8.14,10 5,13.14 5,17H7A5,5 0 0,1 12,12A5,5 0 0,1 17,17H19C19,13.14 15.86,10 12,10Z\";\r\nvar mdiLotion = \"M15.5 6.5C15.5 5.66 17 4 17 4S18.5 5.66 18.5 6.5C18.5 7.33 17.83 8 17 8S15.5 7.33 15.5 6.5M19.5 15C20.88 15 22 13.88 22 12.5C22 10.83 19.5 8 19.5 8S17 10.83 17 12.5C17 13.88 18.12 15 19.5 15M16 12V22H4V12C4 9.03 6.16 6.57 9 6.09V4H7V2H13C14.13 2 15.15 2.39 16 3L14.56 4.44C14.1 4.17 13.57 4 13 4H11V6.09C13.84 6.57 16 9.03 16 12Z\";\r\nvar mdiLotionOutline = \"M15.5 6.5C15.5 5.66 17 4 17 4S18.5 5.66 18.5 6.5C18.5 7.33 17.83 8 17 8S15.5 7.33 15.5 6.5M19.5 15C20.88 15 22 13.88 22 12.5C22 10.83 19.5 8 19.5 8S17 10.83 17 12.5C17 13.88 18.12 15 19.5 15M16 12V20C16 21.1 15.1 22 14 22H6C4.9 22 4 21.1 4 20V12C4 9.03 6.16 6.57 9 6.09V4H7V2H13C14.13 2 15.15 2.39 16 3L14.56 4.44C14.1 4.17 13.57 4 13 4H11V6.09C13.84 6.57 16 9.03 16 12M14 12C14 9.79 12.21 8 10 8S6 9.79 6 12V20H14V12Z\";\r\nvar mdiLotionPlus = \"M15.5 6.5C15.5 5.66 17 4 17 4S18.5 5.66 18.5 6.5C18.5 7.33 17.83 8 17 8S15.5 7.33 15.5 6.5M19.5 15C20.88 15 22 13.88 22 12.5C22 10.83 19.5 8 19.5 8S17 10.83 17 12.5C17 13.88 18.12 15 19.5 15M13 14H11V12H9V14H7V16H9V18H11V16H13V14M16 12V22H4V12C4 9.03 6.16 6.57 9 6.09V4H7V2H13C14.13 2 15.15 2.39 16 3L14.56 4.44C14.1 4.17 13.57 4 13 4H11V6.09C13.84 6.57 16 9.03 16 12Z\";\r\nvar mdiLotionPlusOutline = \"M15.5 6.5C15.5 5.66 17 4 17 4S18.5 5.66 18.5 6.5C18.5 7.33 17.83 8 17 8S15.5 7.33 15.5 6.5M19.5 15C20.88 15 22 13.88 22 12.5C22 10.83 19.5 8 19.5 8S17 10.83 17 12.5C17 13.88 18.12 15 19.5 15M13 14H11V12H9V14H7V16H9V18H11V16H13V14M16 12V20C16 21.1 15.1 22 14 22H6C4.9 22 4 21.1 4 20V12C4 9.03 6.16 6.57 9 6.09V4H7V2H13C14.13 2 15.15 2.39 16 3L14.56 4.44C14.1 4.17 13.57 4 13 4H11V6.09C13.84 6.57 16 9.03 16 12M14 12C14 9.79 12.21 8 10 8S6 9.79 6 12V20H14V12Z\";\r\nvar mdiLoupe = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22H20A2,2 0 0,0 22,20V12A10,10 0 0,0 12,2M13,7H11V11H7V13H11V17H13V13H17V11H13V7Z\";\r\nvar mdiLumx = \"M12.35,1.75L20.13,9.53L13.77,15.89L12.35,14.47L17.3,9.53L10.94,3.16L12.35,1.75M15.89,9.53L14.47,10.94L10.23,6.7L5.28,11.65L3.87,10.23L10.23,3.87L15.89,9.53M10.23,8.11L11.65,9.53L6.7,14.47L13.06,20.84L11.65,22.25L3.87,14.47L10.23,8.11M8.11,14.47L9.53,13.06L13.77,17.3L18.72,12.35L20.13,13.77L13.77,20.13L8.11,14.47Z\";\r\nvar mdiLungs = \"M15.47 3.11C15 2.85 14.37 3.05 14.11 3.54C14.04 3.68 14 3.84 14 4V6.59L13.29 5.88C13.1 5.69 13 5.44 13 5.18V1H11V5.17C11 5.44 10.9 5.69 10.71 5.88L10 6.59V4C10 3.44 9.54 3 9 3C8.83 3 8.67 3.04 8.53 3.11C4.72 5 2 9.97 2 15.77C2 17.67 2.33 19.55 3 21.32C3.19 21.85 3.76 22.13 4.29 21.94C4.34 21.92 4.39 21.9 4.44 21.87L9.5 19.07C9.81 18.9 10 18.56 10 18.19V9.41L11.3 8.12C11.69 7.73 12.32 7.73 12.71 8.12L14 9.42V18.2C14 18.56 14.21 18.9 14.5 19.08L19.58 21.88C20.07 22.14 20.68 21.96 20.94 21.46C20.96 21.42 21 21.37 21 21.32C21.67 19.55 22 17.67 22 15.77C22 9.97 19.29 5 15.47 3.11Z\";\r\nvar mdiMagnet = \"M3,7V13A9,9 0 0,0 12,22A9,9 0 0,0 21,13V7H17V13A5,5 0 0,1 12,18A5,5 0 0,1 7,13V7M17,5H21V2H17M3,5H7V2H3\";\r\nvar mdiMagnetOn = \"M3,7V13A9,9 0 0,0 12,22A9,9 0 0,0 21,13V7H17V13A5,5 0 0,1 12,18A5,5 0 0,1 7,13V7M17,5H21V2H17M3,5H7V2H3M13,1.5L9,9H11V14.5L15,7H13V1.5Z\";\r\nvar mdiMagnify = \"M9.5,3A6.5,6.5 0 0,1 16,9.5C16,11.11 15.41,12.59 14.44,13.73L14.71,14H15.5L20.5,19L19,20.5L14,15.5V14.71L13.73,14.44C12.59,15.41 11.11,16 9.5,16A6.5,6.5 0 0,1 3,9.5A6.5,6.5 0 0,1 9.5,3M9.5,5C7,5 5,7 5,9.5C5,12 7,14 9.5,14C12,14 14,12 14,9.5C14,7 12,5 9.5,5Z\";\r\nvar mdiMagnifyClose = \"M9,2A7,7 0 0,1 16,9C16,10.5 15.5,12 14.61,13.19L15.41,14H16L22,20L20,22L14,16V15.41L13.19,14.61C12,15.5 10.5,16 9,16A7,7 0 0,1 2,9A7,7 0 0,1 9,2M11.12,5.46L9,7.59L6.88,5.46L5.46,6.88L7.59,9L5.46,11.12L6.88,12.54L9,10.41L11.12,12.54L12.54,11.12L10.41,9L12.54,6.88L11.12,5.46Z\";\r\nvar mdiMagnifyMinus = \"M9,2A7,7 0 0,1 16,9C16,10.57 15.5,12 14.61,13.19L15.41,14H16L22,20L20,22L14,16V15.41L13.19,14.61C12,15.5 10.57,16 9,16A7,7 0 0,1 2,9A7,7 0 0,1 9,2M5,8V10H13V8H5Z\";\r\nvar mdiMagnifyMinusCursor = \"M11,4A7,7 0 0,1 18,11C18,12.5 17.5,14 16.61,15.19L17.42,16H18L23,21L21,23L16,18V17.41L15.19,16.6C12.1,18.92 7.71,18.29 5.39,15.2C3.07,12.11 3.7,7.72 6.79,5.4C8,4.5 9.5,4 11,4M7,10V12H15V10H7M1,1V8L8,1H1Z\";\r\nvar mdiMagnifyMinusOutline = \"M15.5,14H14.71L14.43,13.73C15.41,12.59 16,11.11 16,9.5A6.5,6.5 0 0,0 9.5,3A6.5,6.5 0 0,0 3,9.5A6.5,6.5 0 0,0 9.5,16C11.11,16 12.59,15.41 13.73,14.43L14,14.71V15.5L19,20.5L20.5,19L15.5,14M9.5,14C7,14 5,12 5,9.5C5,7 7,5 9.5,5C12,5 14,7 14,9.5C14,12 12,14 9.5,14M7,9H12V10H7V9Z\";\r\nvar mdiMagnifyPlus = \"M9,2A7,7 0 0,1 16,9C16,10.57 15.5,12 14.61,13.19L15.41,14H16L22,20L20,22L14,16V15.41L13.19,14.61C12,15.5 10.57,16 9,16A7,7 0 0,1 2,9A7,7 0 0,1 9,2M8,5V8H5V10H8V13H10V10H13V8H10V5H8Z\";\r\nvar mdiMagnifyPlusCursor = \"M11,4A7,7 0 0,1 18,11C18,12.5 17.5,14 16.61,15.19L17.42,16H18L23,21L21,23L16,18V17.41L15.19,16.6C12.1,18.92 7.71,18.29 5.39,15.2C3.07,12.11 3.7,7.72 6.79,5.4C8,4.5 9.5,4 11,4M10,7V10H7V12H10V15H12V12H15V10H12V7H10M1,1V8L8,1H1Z\";\r\nvar mdiMagnifyPlusOutline = \"M15.5,14L20.5,19L19,20.5L14,15.5V14.71L13.73,14.43C12.59,15.41 11.11,16 9.5,16A6.5,6.5 0 0,1 3,9.5A6.5,6.5 0 0,1 9.5,3A6.5,6.5 0 0,1 16,9.5C16,11.11 15.41,12.59 14.43,13.73L14.71,14H15.5M9.5,14C12,14 14,12 14,9.5C14,7 12,5 9.5,5C7,5 5,7 5,9.5C5,12 7,14 9.5,14M12,10H10V12H9V10H7V9H9V7H10V9H12V10Z\";\r\nvar mdiMagnifyRemoveCursor = \"M1 1V8L8 1H1M18 16H17.42L16.61 15.19C17.5 14 18 12.5 18 11C18 7.13 14.87 4 11 4C9.5 4 8 4.5 6.79 5.4C3.7 7.72 3.07 12.11 5.39 15.2C7.71 18.29 12.1 18.92 15.19 16.6L16 17.41V18L21 23L23 21L18 16M14.6 13.16L13.18 14.58L11.06 12.45L8.94 14.58L7.5 13.16L9.65 11.04L7.5 8.92L8.94 7.5L11.06 9.63L13.18 7.5L14.6 8.92L12.47 11.04L14.6 13.16Z\";\r\nvar mdiMagnifyRemoveOutline = \"M15.5 14H14.71L14.43 13.73C15.41 12.59 16 11.11 16 9.5C16 5.91 13.09 3 9.5 3S3 5.91 3 9.5 5.91 16 9.5 16C11.11 16 12.59 15.41 13.73 14.43L14 14.71V15.5L19 20.5L20.5 19L15.5 14M9.5 14C7 14 5 12 5 9.5S7 5 9.5 5 14 7 14 9.5 12 14 9.5 14M10.91 11.62L9.5 10.21L8.09 11.62L7.38 10.91L8.79 9.5L7.38 8.09L8.09 7.38L9.5 8.79L10.91 7.38L11.62 8.09L10.21 9.5L11.62 10.91L10.91 11.62Z\";\r\nvar mdiMagnifyScan = \"M17 22V20H20V17H22V20.5C22 20.89 21.84 21.24 21.54 21.54C21.24 21.84 20.89 22 20.5 22H17M7 22H3.5C3.11 22 2.76 21.84 2.46 21.54C2.16 21.24 2 20.89 2 20.5V17H4V20H7V22M17 2H20.5C20.89 2 21.24 2.16 21.54 2.46C21.84 2.76 22 3.11 22 3.5V7H20V4H17V2M7 2V4H4V7H2V3.5C2 3.11 2.16 2.76 2.46 2.46C2.76 2.16 3.11 2 3.5 2H7M10.5 6C13 6 15 8 15 10.5C15 11.38 14.75 12.2 14.31 12.9L17.57 16.16L16.16 17.57L12.9 14.31C12.2 14.75 11.38 15 10.5 15C8 15 6 13 6 10.5C6 8 8 6 10.5 6M10.5 8C9.12 8 8 9.12 8 10.5C8 11.88 9.12 13 10.5 13C11.88 13 13 11.88 13 10.5C13 9.12 11.88 8 10.5 8Z\";\r\nvar mdiMail = \"M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4M17,17H7V15H17M17,13H7V11H17M20,9H17V6H20\";\r\nvar mdiMailbox = \"M17,4H7A5,5 0 0,0 2,9V20H20A2,2 0 0,0 22,18V9A5,5 0 0,0 17,4M10,18H4V9A3,3 0 0,1 7,6A3,3 0 0,1 10,9V18M19,15H17V13H13V11H19V15M9,11H5V9H9V11Z\";\r\nvar mdiMailboxOpen = \"M8,4A5,5 0 0,0 3,9V18H1V20H21A2,2 0 0,0 23,18V9A5,5 0 0,0 18,4H8M8,6A3,3 0 0,1 11,9V18H5V9A3,3 0 0,1 8,6M14,11H20V15H18V13H14V11Z\";\r\nvar mdiMailboxOpenOutline = \"M14,11H20V15H18V13H14V11M18,4H8A5,5 0 0,0 3,9V18H1V20H21A2,2 0 0,0 23,18V9A5,5 0 0,0 18,4M11,18H5V9A3,3 0 0,1 8,6A3,3 0 0,1 11,9V18M21,18H13V9C13,7.92 12.65,6.86 12,6H18A3,3 0 0,1 21,9V18Z\";\r\nvar mdiMailboxOpenUp = \"M8,4A5,5 0 0,0 3,9V18H1V20H21A2,2 0 0,0 23,18V9A5,5 0 0,0 18,4H8M8,6A3,3 0 0,1 11,9V18H5V9A3,3 0 0,1 8,6M13,13V7H17V9H15V13H13Z\";\r\nvar mdiMailboxOpenUpOutline = \"M14,12.85V6.85H18V8.85H16V12.85H14M18,3.85H8A5,5 0 0,0 3,8.85V17.85H1V19.85H21A2,2 0 0,0 23,17.85V8.85A5,5 0 0,0 18,3.85M11,17.85H5V8.85A3,3 0 0,1 8,5.85A3,3 0 0,1 11,8.85V17.85M21,17.85H13V8.85C13,7.76 12.65,6.71 12,5.85H18A3,3 0 0,1 21,8.85V17.85Z\";\r\nvar mdiMailboxOutline = \"M17,4H7A5,5 0 0,0 2,9V20H20A2,2 0 0,0 22,18V9A5,5 0 0,0 17,4M10,18H4V9A3,3 0 0,1 7,6A3,3 0 0,1 10,9V18M20,18H12V9C12,7.92 11.65,6.86 11,6H17A3,3 0 0,1 20,9V18M13,11V13H17V15H19V11H13M9,11H5V9H9V11Z\";\r\nvar mdiMailboxUp = \"M5,9H9V11H5V9M22,9V18A2,2 0 0,1 20,20H2V9A5,5 0 0,1 7,4H17A5,5 0 0,1 22,9M10,9A3,3 0 0,0 7,6A3,3 0 0,0 4,9V18H10V9M16,7H12V13H14V9H16V7Z\";\r\nvar mdiMailboxUpOutline = \"M17,4H7A5,5 0 0,0 2,9V20H20A2,2 0 0,0 22,18V9A5,5 0 0,0 17,4M10,18H4V9A3,3 0 0,1 7,6A3,3 0 0,1 10,9V18M20,18H12V9C12,7.92 11.65,6.86 11,6H17A3,3 0 0,1 20,9V18M13,13H15V9H17V7H13V13M9,11H5V9H9V11Z\";\r\nvar mdiManjaro = \"M2 2V22H7.6V7.6H14.8V2H2M9.2 9.2V22H14.8V9.2H9.2M16.4 2V22H22V2H16.4Z\";\r\nvar mdiMap = \"M15,19L9,16.89V5L15,7.11M20.5,3C20.44,3 20.39,3 20.34,3L15,5.1L9,3L3.36,4.9C3.15,4.97 3,5.15 3,5.38V20.5A0.5,0.5 0 0,0 3.5,21C3.55,21 3.61,21 3.66,20.97L9,18.9L15,21L20.64,19.1C20.85,19 21,18.85 21,18.62V3.5A0.5,0.5 0 0,0 20.5,3Z\";\r\nvar mdiMapCheck = \"M18.25,22L15.5,19L16.66,17.82L18.25,19.41L21.84,15.82L23,17.23M20.5,3A0.5,0.5 0 0,1 21,3.5V13.36C20.36,13.13 19.69,13 19,13C17.46,13 16.06,13.6 15,14.56V7.1L9,5V16.9L13.04,18.3C13,18.54 13,18.77 13,19C13,19.46 13.06,19.92 13.16,20.36L9,18.9L3.66,20.97C3.59,21 3.55,21 3.5,21A0.5,0.5 0 0,1 3,20.5V5.38C3,5.15 3.16,4.97 3.35,4.9L9,3L15,5.1L20.33,3\";\r\nvar mdiMapCheckOutline = \"M18.25,22L15.5,19L16.66,17.82L18.25,19.41L21.84,15.82L23,17.23L18.25,22M20.5,3A0.5,0.5 0 0,1 21,3.5V13.34C20.37,13.12 19.7,13 19,13V5.7L16,6.86V13.8C15.2,14.27 14.5,14.91 14,15.68V6.87L10,5.47V17.13L13.05,18.2L13,19C13,19.46 13.05,19.92 13.15,20.35L9,18.9L3.66,20.97L3.5,21A0.5,0.5 0 0,1 3,20.5V5.38C3,5.15 3.15,4.97 3.36,4.9L9,3L15,5.1L20.34,3.03L20.5,3M5,6.46V18.31L8,17.15V5.45L5,6.46Z\";\r\nvar mdiMapClock = \"M15,12H16.5V16.25L19.36,17.94L18.61,19.16L15,17V12M23,16A7,7 0 0,1 16,23C13,23 10.4,21.08 9.42,18.4L8,17.9L2.66,19.97L2.5,20A0.5,0.5 0 0,1 2,19.5V4.38C2,4.15 2.15,3.97 2.36,3.9L8,2L14,4.1L19.34,2H19.5A0.5,0.5 0 0,1 20,2.5V10.25C21.81,11.5 23,13.62 23,16M9,16C9,12.83 11.11,10.15 14,9.29V6.11L8,4V15.89L9,16.24C9,16.16 9,16.08 9,16M16,11A5,5 0 0,0 11,16A5,5 0 0,0 16,21A5,5 0 0,0 21,16A5,5 0 0,0 16,11Z\";\r\nvar mdiMapClockOutline = \"M15,12H16.5V16.25L19.36,17.94L18.61,19.16L15,17V12M16,9C16.69,9 17.37,9.1 18,9.29V4.7L15,5.86V9.07C15.33,9 15.66,9 16,9M23,16A7,7 0 0,1 16,23C13,23 10.4,21.08 9.42,18.4L8,17.9L2.66,19.97L2.5,20A0.5,0.5 0 0,1 2,19.5V4.38C2,4.15 2.15,3.97 2.36,3.9L8,2L14,4.1L19.34,2.03L19.5,2A0.5,0.5 0 0,1 20,2.5V10.25C21.81,11.5 23,13.62 23,16M9,16C9,13.21 10.63,10.8 13,9.67V5.87L9,4.47V16.13H9C9,16.09 9,16.04 9,16M16,11A5,5 0 0,0 11,16A5,5 0 0,0 16,21A5,5 0 0,0 21,16A5,5 0 0,0 16,11M4,5.46V17.31L7,16.15V4.45L4,5.46Z\";\r\nvar mdiMapLegend = \"M9,3L3.36,4.9C3.15,4.97 3,5.15 3,5.38V20.5A0.5,0.5 0 0,0 3.5,21L3.66,20.97L9,18.9L15,21L20.64,19.1C20.85,19.03 21,18.85 21,18.62V3.5A0.5,0.5 0 0,0 20.5,3L20.34,3.03L15,5.1L9,3M8,5.45V17.15L5,18.31V6.46L8,5.45M10,5.47L14,6.87V18.53L10,17.13V5.47M19,5.7V17.54L16,18.55V6.86L19,5.7M7.46,6.3L5.57,6.97V9.12L7.46,8.45V6.3M7.46,9.05L5.57,9.72V11.87L7.46,11.2V9.05M7.46,11.8L5.57,12.47V14.62L7.46,13.95V11.8M7.46,14.55L5.57,15.22V17.37L7.46,16.7V14.55Z\";\r\nvar mdiMapMarker = \"M12,11.5A2.5,2.5 0 0,1 9.5,9A2.5,2.5 0 0,1 12,6.5A2.5,2.5 0 0,1 14.5,9A2.5,2.5 0 0,1 12,11.5M12,2A7,7 0 0,0 5,9C5,14.25 12,22 12,22C12,22 19,14.25 19,9A7,7 0 0,0 12,2Z\";\r\nvar mdiMapMarkerAlert = \"M12 2C15.9 2 19 5.1 19 9C19 14.2 12 22 12 22S5 14.2 5 9C5 5.1 8.1 2 12 2M11 6V12H13V6H11M11 14V16H13V14H11Z\";\r\nvar mdiMapMarkerAlertOutline = \"M12,2A7,7 0 0,1 19,9C19,14.25 12,22 12,22C12,22 5,14.25 5,9A7,7 0 0,1 12,2M12,4A5,5 0 0,0 7,9C7,10 7,12 12,18.71C17,12 17,10 17,9A5,5 0 0,0 12,4M11,6H13V11H11V6M11,13H13V15H11V13Z\";\r\nvar mdiMapMarkerCheck = \"M12,2C15.86,2 19,5.14 19,9C19,14.25 12,22 12,22C12,22 5,14.25 5,9C5,5.14 8.14,2 12,2M10.47,14L17,7.41L15.6,6L10.47,11.18L8.4,9.09L7,10.5L10.47,14Z\";\r\nvar mdiMapMarkerCheckOutline = \"M12 4C14.8 4 17 6.2 17 9C17 11.9 14.1 16.2 12 18.9C9.9 16.2 7 11.9 7 9C7 6.2 9.2 4 12 4M12 2C8.1 2 5 5.1 5 9C5 14.2 12 22 12 22S19 14.2 19 9C19 5.1 15.9 2 12 2M11.3 14L16.2 9L14.8 7.6L11.3 11.2L9.7 9.6L8.3 11L11.3 14Z\";\r\nvar mdiMapMarkerCircle = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,12.5A1.5,1.5 0 0,1 10.5,11A1.5,1.5 0 0,1 12,9.5A1.5,1.5 0 0,1 13.5,11A1.5,1.5 0 0,1 12,12.5M12,7.2C9.9,7.2 8.2,8.9 8.2,11C8.2,14 12,17.5 12,17.5C12,17.5 15.8,14 15.8,11C15.8,8.9 14.1,7.2 12,7.2Z\";\r\nvar mdiMapMarkerDistance = \"M6.5,8.11C5.61,8.11 4.89,7.39 4.89,6.5A1.61,1.61 0 0,1 6.5,4.89C7.39,4.89 8.11,5.61 8.11,6.5V6.5A1.61,1.61 0 0,1 6.5,8.11M6.5,2C4,2 2,4 2,6.5C2,9.87 6.5,14.86 6.5,14.86C6.5,14.86 11,9.87 11,6.5C11,4 9,2 6.5,2M17.5,8.11A1.61,1.61 0 0,1 15.89,6.5C15.89,5.61 16.61,4.89 17.5,4.89C18.39,4.89 19.11,5.61 19.11,6.5A1.61,1.61 0 0,1 17.5,8.11M17.5,2C15,2 13,4 13,6.5C13,9.87 17.5,14.86 17.5,14.86C17.5,14.86 22,9.87 22,6.5C22,4 20,2 17.5,2M17.5,16C16.23,16 15.1,16.8 14.68,18H9.32C8.77,16.44 7.05,15.62 5.5,16.17C3.93,16.72 3.11,18.44 3.66,20C4.22,21.56 5.93,22.38 7.5,21.83C8.35,21.53 9,20.85 9.32,20H14.69C15.24,21.56 16.96,22.38 18.5,21.83C20.08,21.28 20.9,19.56 20.35,18C19.92,16.8 18.78,16 17.5,16V16M17.5,20.5A1.5,1.5 0 0,1 16,19A1.5,1.5 0 0,1 17.5,17.5A1.5,1.5 0 0,1 19,19A1.5,1.5 0 0,1 17.5,20.5Z\";\r\nvar mdiMapMarkerDown = \"M12 2A7 7 0 0 0 5 9C5 14.25 12 22 12 22S19 14.25 19 9A7 7 0 0 0 12 2M7.5 10H10V5H14V10H16.5L12 14.5Z\";\r\nvar mdiMapMarkerLeft = \"M15 11.5C13.62 11.5 12.5 10.38 12.5 9S13.62 6.5 15 6.5 17.5 7.62 17.5 9 16.38 11.5 15 11.5M8 9C8 14.25 15 22 15 22S22 14.25 22 9C22 5.13 18.87 2 15 2S8 5.13 8 9M6 7L1 12L6 17V7Z\";\r\nvar mdiMapMarkerLeftOutline = \"M15 6.5C16.38 6.5 17.5 7.62 17.5 9S16.38 11.5 15 11.5 12.5 10.38 12.5 9 13.62 6.5 15 6.5M15 2C18.87 2 22 5.13 22 9C22 14.25 15 22 15 22S8 14.25 8 9C8 5.13 11.13 2 15 2M10 9C10 10 10 12 15 18.71C20 12 20 10 20 9C20 6.24 17.76 4 15 4S10 6.24 10 9M6 7L1 12L6 17V7Z\";\r\nvar mdiMapMarkerMinus = \"M9,11.5A2.5,2.5 0 0,0 11.5,9A2.5,2.5 0 0,0 9,6.5A2.5,2.5 0 0,0 6.5,9A2.5,2.5 0 0,0 9,11.5M9,2C12.86,2 16,5.13 16,9C16,14.25 9,22 9,22C9,22 2,14.25 2,9A7,7 0 0,1 9,2M15,17H23V19H15V17Z\";\r\nvar mdiMapMarkerMinusOutline = \"M15 17H23V19H15V17M9 6.5C10.4 6.5 11.5 7.6 11.5 9S10.4 11.5 9 11.5 6.5 10.4 6.5 9 7.6 6.5 9 6.5M9 2C12.9 2 16 5.1 16 9C16 14.2 9 22 9 22S2 14.2 2 9C2 5.1 5.1 2 9 2M9 4C6.2 4 4 6.2 4 9C4 10 4 12 9 18.7C14 12 14 10 14 9C14 6.2 11.8 4 9 4Z\";\r\nvar mdiMapMarkerMultiple = \"M14,11.5A2.5,2.5 0 0,0 16.5,9A2.5,2.5 0 0,0 14,6.5A2.5,2.5 0 0,0 11.5,9A2.5,2.5 0 0,0 14,11.5M14,2C17.86,2 21,5.13 21,9C21,14.25 14,22 14,22C14,22 7,14.25 7,9A7,7 0 0,1 14,2M5,9C5,13.5 10.08,19.66 11,20.81L10,22C10,22 3,14.25 3,9C3,5.83 5.11,3.15 8,2.29C6.16,3.94 5,6.33 5,9Z\";\r\nvar mdiMapMarkerMultipleOutline = \"M11.5 9C11.5 7.62 12.62 6.5 14 6.5C15.1 6.5 16.03 7.21 16.37 8.19C16.45 8.45 16.5 8.72 16.5 9C16.5 10.38 15.38 11.5 14 11.5C12.91 11.5 12 10.81 11.64 9.84C11.55 9.58 11.5 9.29 11.5 9M5 9C5 13.5 10.08 19.66 11 20.81L10 22C10 22 3 14.25 3 9C3 5.83 5.11 3.15 8 2.29C6.16 3.94 5 6.33 5 9M14 2C17.86 2 21 5.13 21 9C21 14.25 14 22 14 22C14 22 7 14.25 7 9C7 5.13 10.14 2 14 2M14 4C11.24 4 9 6.24 9 9C9 10 9 12 14 18.71C19 12 19 10 19 9C19 6.24 16.76 4 14 4Z\";\r\nvar mdiMapMarkerOff = \"M16.37,16.1L11.75,11.47L11.64,11.36L3.27,3L2,4.27L5.18,7.45C5.06,7.95 5,8.46 5,9C5,14.25 12,22 12,22C12,22 13.67,20.15 15.37,17.65L18.73,21L20,19.72M12,6.5A2.5,2.5 0 0,1 14.5,9C14.5,9.73 14.17,10.39 13.67,10.85L17.3,14.5C18.28,12.62 19,10.68 19,9A7,7 0 0,0 12,2C10,2 8.24,2.82 6.96,4.14L10.15,7.33C10.61,6.82 11.26,6.5 12,6.5Z\";\r\nvar mdiMapMarkerOffOutline = \"M20 19.7L3.3 3L2 4.3L5.2 7.5C5.1 8 5 8.5 5 9C5 14.2 12 22 12 22S13.7 20.1 15.4 17.6L18.8 21L20 19.7M12 18.7C7.4 12.5 7 10.4 7 9.3L13.8 16.1C13.3 16.9 12.7 17.7 12 18.7M8.4 5.6L7 4.2C8.2 2.8 10 2 12 2C15.9 2 19 5.1 19 9C19 10.7 18.3 12.6 17.3 14.5L15.8 13C17 10.6 17 9.6 17 9C17 6.2 14.8 4 12 4C10.6 4 9.3 4.6 8.4 5.6M12 6.5C13.4 6.5 14.5 7.6 14.5 9C14.5 9.7 14.2 10.4 13.7 10.9L10.2 7.4C10.6 6.8 11.3 6.5 12 6.5Z\";\r\nvar mdiMapMarkerOutline = \"M12,6.5A2.5,2.5 0 0,1 14.5,9A2.5,2.5 0 0,1 12,11.5A2.5,2.5 0 0,1 9.5,9A2.5,2.5 0 0,1 12,6.5M12,2A7,7 0 0,1 19,9C19,14.25 12,22 12,22C12,22 5,14.25 5,9A7,7 0 0,1 12,2M12,4A5,5 0 0,0 7,9C7,10 7,12 12,18.71C17,12 17,10 17,9A5,5 0 0,0 12,4Z\";\r\nvar mdiMapMarkerPath = \"M18,15A3,3 0 0,1 21,18A3,3 0 0,1 18,21C16.69,21 15.58,20.17 15.17,19H14V17H15.17C15.58,15.83 16.69,15 18,15M18,17A1,1 0 0,0 17,18A1,1 0 0,0 18,19A1,1 0 0,0 19,18A1,1 0 0,0 18,17M18,8A1.43,1.43 0 0,0 19.43,6.57C19.43,5.78 18.79,5.14 18,5.14C17.21,5.14 16.57,5.78 16.57,6.57A1.43,1.43 0 0,0 18,8M18,2.57A4,4 0 0,1 22,6.57C22,9.56 18,14 18,14C18,14 14,9.56 14,6.57A4,4 0 0,1 18,2.57M8.83,17H10V19H8.83C8.42,20.17 7.31,21 6,21A3,3 0 0,1 3,18C3,16.69 3.83,15.58 5,15.17V14H7V15.17C7.85,15.47 8.53,16.15 8.83,17M6,17A1,1 0 0,0 5,18A1,1 0 0,0 6,19A1,1 0 0,0 7,18A1,1 0 0,0 6,17M6,3A3,3 0 0,1 9,6C9,7.31 8.17,8.42 7,8.83V10H5V8.83C3.83,8.42 3,7.31 3,6A3,3 0 0,1 6,3M6,5A1,1 0 0,0 5,6A1,1 0 0,0 6,7A1,1 0 0,0 7,6A1,1 0 0,0 6,5M11,19V17H13V19H11M7,13H5V11H7V13Z\";\r\nvar mdiMapMarkerPlus = \"M9,11.5A2.5,2.5 0 0,0 11.5,9A2.5,2.5 0 0,0 9,6.5A2.5,2.5 0 0,0 6.5,9A2.5,2.5 0 0,0 9,11.5M9,2C12.86,2 16,5.13 16,9C16,14.25 9,22 9,22C9,22 2,14.25 2,9A7,7 0 0,1 9,2M15,17H18V14H20V17H23V19H20V22H18V19H15V17Z\";\r\nvar mdiMapMarkerPlusOutline = \"M15 17H18V14H20V17H23V19H20V22H18V19H15V17M9 6.5C10.4 6.5 11.5 7.6 11.5 9S10.4 11.5 9 11.5 6.5 10.4 6.5 9 7.6 6.5 9 6.5M9 2C12.9 2 16 5.1 16 9C16 14.2 9 22 9 22S2 14.2 2 9C2 5.1 5.1 2 9 2M9 4C6.2 4 4 6.2 4 9C4 10 4 12 9 18.7C14 12 14 10 14 9C14 6.2 11.8 4 9 4Z\";\r\nvar mdiMapMarkerQuestion = \"M12,2C8.14,2 5,5.14 5,9C5,14.25 12,22 12,22C12,22 19,14.25 19,9C19,5.14 15.86,2 12,2M12.88,15.75H11.13V14H12.88M12.88,12.88H11.13C11.13,10.04 13.75,10.26 13.75,8.5A1.75,1.75 0 0,0 12,6.75A1.75,1.75 0 0,0 10.25,8.5H8.5A3.5,3.5 0 0,1 12,5A3.5,3.5 0 0,1 15.5,8.5C15.5,10.69 12.88,10.91 12.88,12.88Z\";\r\nvar mdiMapMarkerQuestionOutline = \"M12,1C7.59,1 4,4.59 4,9C4,14.57 10.96,22.34 11.26,22.67L12,23.5L12.74,22.67C13.04,22.34 20,14.57 20,9C20,4.59 16.41,1 12,1M12,20.47C9.82,17.86 6,12.54 6,9A6,6 0 0,1 12,3A6,6 0 0,1 18,9C18,12.83 13.75,18.36 12,20.47M11.13,14H12.88V15.75H11.13M12,5A3.5,3.5 0 0,0 8.5,8.5H10.25A1.75,1.75 0 0,1 12,6.75A1.75,1.75 0 0,1 13.75,8.5C13.75,10.26 11.13,10.04 11.13,12.88H12.88C12.88,10.91 15.5,10.69 15.5,8.5A3.5,3.5 0 0,0 12,5Z\";\r\nvar mdiMapMarkerRadius = \"M12,2C15.31,2 18,4.66 18,7.95C18,12.41 12,19 12,19C12,19 6,12.41 6,7.95C6,4.66 8.69,2 12,2M12,6A2,2 0 0,0 10,8A2,2 0 0,0 12,10A2,2 0 0,0 14,8A2,2 0 0,0 12,6M20,19C20,21.21 16.42,23 12,23C7.58,23 4,21.21 4,19C4,17.71 5.22,16.56 7.11,15.83L7.75,16.74C6.67,17.19 6,17.81 6,18.5C6,19.88 8.69,21 12,21C15.31,21 18,19.88 18,18.5C18,17.81 17.33,17.19 16.25,16.74L16.89,15.83C18.78,16.56 20,17.71 20,19Z\";\r\nvar mdiMapMarkerRadiusOutline = \"M12 4C14.2 4 16 5.8 16 8C16 10.1 13.9 13.5 12 15.9C10.1 13.4 8 10.1 8 8C8 5.8 9.8 4 12 4M12 2C8.7 2 6 4.7 6 8C6 12.5 12 19 12 19S18 12.4 18 8C18 4.7 15.3 2 12 2M12 6C10.9 6 10 6.9 10 8S10.9 10 12 10 14 9.1 14 8 13.1 6 12 6M20 19C20 21.2 16.4 23 12 23S4 21.2 4 19C4 17.7 5.2 16.6 7.1 15.8L7.7 16.7C6.7 17.2 6 17.8 6 18.5C6 19.9 8.7 21 12 21S18 19.9 18 18.5C18 17.8 17.3 17.2 16.2 16.7L16.8 15.8C18.8 16.6 20 17.7 20 19Z\";\r\nvar mdiMapMarkerRemove = \"M9,2C5.14,2 2,5.14 2,9C2,14.25 9,22 9,22C9,22 16,14.25 16,9A7,7 0 0,0 9,2M9,6.5A2.5,2.5 0 0,1 11.5,9A2.5,2.5 0 0,1 9,11.5A2.5,2.5 0 0,1 6.5,9A2.5,2.5 0 0,1 9,6.5M16.58,14.16L15.17,15.58L17.58,18L15.17,20.41L16.58,21.82L19,19.41L21.41,21.82L22.83,20.41L20.41,18L22.83,15.58L21.41,14.16L19,16.58\";\r\nvar mdiMapMarkerRemoveOutline = \"M16.6 14.2L15.2 15.6L17.6 18L15.2 20.4L16.6 21.8L19 19.4L21.4 21.8L22.8 20.4L20.4 18L22.8 15.6L21.4 14.2L19 16.6M9 6.5C10.4 6.5 11.5 7.6 11.5 9S10.4 11.5 9 11.5 6.5 10.4 6.5 9 7.6 6.5 9 6.5M9 2C12.9 2 16 5.1 16 9C16 14.2 9 22 9 22S2 14.2 2 9C2 5.1 5.1 2 9 2M9 4C6.2 4 4 6.2 4 9C4 10 4 12 9 18.7C14 12 14 10 14 9C14 6.2 11.8 4 9 4Z\";\r\nvar mdiMapMarkerRemoveVariant = \"M12,2C8.14,2 5,5.14 5,9C5,14.25 12,22 12,22C12,22 19,14.25 19,9C19,5.14 15.86,2 12,2M9.59,5.17L12,7.58L14.41,5.17L15.83,6.58L13.41,9L15.83,11.41L14.41,12.83L12,10.41L9.59,12.83L8.17,11.41L10.59,9L8.17,6.58\";\r\nvar mdiMapMarkerRight = \"M9 11.5C7.62 11.5 6.5 10.38 6.5 9S7.62 6.5 9 6.5 11.5 7.62 11.5 9 10.38 11.5 9 11.5M9 2C5.13 2 2 5.13 2 9C2 14.25 9 22 9 22S16 14.25 16 9C16 5.13 12.87 2 9 2M18 17L23 12L18 7V17Z\";\r\nvar mdiMapMarkerRightOutline = \"M9 6.5C10.38 6.5 11.5 7.62 11.5 9S10.38 11.5 9 11.5 6.5 10.38 6.5 9 7.62 6.5 9 6.5M9 2C12.87 2 16 5.13 16 9C16 14.25 9 22 9 22S2 14.25 2 9C2 5.13 5.13 2 9 2M9 4C6.24 4 4 6.24 4 9C4 10 4 12 9 18.71C14 12 14 10 14 9C14 6.24 11.76 4 9 4M18 17L23 12L18 7V17Z\";\r\nvar mdiMapMarkerStar = \"M12 2C8.1 2 5 5.1 5 9C5 14.2 12 22 12 22S19 14.2 19 9C19 5.1 15.9 2 12 2M14.5 13L12 11.5L9.5 13L10.2 10.2L8 8.3L10.9 8.1L12 5.4L13.1 8L16 8.3L13.8 10.2L14.5 13Z\";\r\nvar mdiMapMarkerStarOutline = \"M12 2C15.9 2 19 5.1 19 9C19 14.2 12 22 12 22S5 14.2 5 9C5 5.1 8.1 2 12 2M12 4C9.2 4 7 6.2 7 9C7 10 7 12 12 18.7C17 12 17 10 17 9C17 6.2 14.8 4 12 4M12 11.5L14.4 13L13.8 10.2L16 8.3L13.1 8.1L12 5.4L10.9 8L8 8.3L10.2 10.2L9.5 13L12 11.5Z\";\r\nvar mdiMapMarkerUp = \"M12 2A7 7 0 0 0 5 9C5 14.25 12 22 12 22S19 14.25 19 9A7 7 0 0 0 12 2M16.5 9H14V14H10V9H7.5L12 4.5Z\";\r\nvar mdiMapMinus = \"M15 18V20H23V18H15M13.16 20.36L9 18.9L3.66 20.97C3.6 21 3.55 21 3.5 21C3.22 21 3 20.78 3 20.5V5.38C3 5.15 3.16 4.97 3.36 4.9L9 3L15 5.1L20.34 3H20.5C20.78 3 21 3.22 21 3.5V13.35C20.37 13.13 19.7 13 19 13C17.46 13 16.06 13.58 15 14.54V7.1L9 5V16.9L13.04 18.32C13 18.54 13 18.77 13 19C13 19.47 13.06 19.92 13.16 20.36Z\";\r\nvar mdiMapOutline = \"M20.5,3L20.34,3.03L15,5.1L9,3L3.36,4.9C3.15,4.97 3,5.15 3,5.38V20.5A0.5,0.5 0 0,0 3.5,21L3.66,20.97L9,18.9L15,21L20.64,19.1C20.85,19.03 21,18.85 21,18.62V3.5A0.5,0.5 0 0,0 20.5,3M10,5.47L14,6.87V18.53L10,17.13V5.47M5,6.46L8,5.45V17.15L5,18.31V6.46M19,17.54L16,18.55V6.86L19,5.7V17.54Z\";\r\nvar mdiMapPlus = \"M9,3L3.36,4.9C3.16,4.97 3,5.15 3,5.38V20.5A0.5,0.5 0 0,0 3.5,21C3.55,21 3.6,21 3.66,20.97L9,18.9L13.16,20.36C13.06,19.92 13,19.46 13,19C13,18.77 13,18.54 13.04,18.3L9,16.9V5L15,7.1V14.56C16.07,13.6 17.47,13 19,13C19.7,13 20.37,13.13 21,13.36V3.5A0.5,0.5 0 0,0 20.5,3H20.34L15,5.1L9,3M18,15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiMapSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M14,6.11L8,4V15.89L9,16.24V16.5C9,17.14 9.09,17.76 9.26,18.34L8,17.9L2.66,19.97L2.5,20A0.5,0.5 0 0,1 2,19.5V4.38C2,4.15 2.15,3.97 2.36,3.9L8,2L14,4.1L19.34,2H19.5A0.5,0.5 0 0,1 20,2.5V11.81C18.83,10.69 17.25,10 15.5,10C15,10 14.5,10.06 14,10.17V6.11Z\";\r\nvar mdiMapSearchOutline = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.2 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M19.5,2A0.5,0.5 0 0,1 20,2.5V11.81C19.42,11.26 18.75,10.81 18,10.5V4.7L15,5.86V10C14.3,10.07 13.62,10.24 13,10.5V5.87L9,4.47V16.13H9V16.5C9,17.14 9.09,17.76 9.26,18.34L8,17.9L2.66,19.97L2.5,20A0.5,0.5 0 0,1 2,19.5V4.38C2,4.15 2.15,3.97 2.36,3.9L8,2L14,4.1L19.34,2.03L19.5,2M4,5.46V17.31L7,16.15V4.45L4,5.46Z\";\r\nvar mdiMapbox = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M16.75,14.45C18.65,12.55 18.58,9.39 16.59,7.41C14.6,5.43 11.45,5.35 9.55,7.25C6.12,10.68 7.22,16.78 7.22,16.78C7.22,16.78 13.33,17.87 16.75,14.45M13.15,7.86L14.13,9.87L16.14,10.85L14.13,11.83L13.15,13.84L12.17,11.83L10.16,10.85L12.17,9.87L13.15,7.86Z\";\r\nvar mdiMargin = \"M20,4V9L18.5,7.5L5.5,20.5L3.5,18.5L16.5,5.5L15,4H20M17,20A3,3 0 0,1 14,17V15A3,3 0 0,1 17,12A3,3 0 0,1 20,15V17A3,3 0 0,1 17,20M17,14A1,1 0 0,0 16,15V17A1,1 0 0,0 17,18A1,1 0 0,0 18,17V15A1,1 0 0,0 17,14M7,12A3,3 0 0,1 4,9V7A3,3 0 0,1 7,4A3,3 0 0,1 10,7V9A3,3 0 0,1 7,12M7,6A1,1 0 0,0 6,7V9A1,1 0 0,0 7,10A1,1 0 0,0 8,9V7A1,1 0 0,0 7,6Z\";\r\nvar mdiMarker = \"M18.5,1.15C17.97,1.15 17.46,1.34 17.07,1.73L11.26,7.55L16.91,13.2L22.73,7.39C23.5,6.61 23.5,5.35 22.73,4.56L19.89,1.73C19.5,1.34 19,1.15 18.5,1.15M10.3,8.5L4.34,14.46C3.56,15.24 3.56,16.5 4.36,17.31C3.14,18.54 1.9,19.77 0.67,21H6.33L7.19,20.14C7.97,20.9 9.22,20.89 10,20.12L15.95,14.16\";\r\nvar mdiMarkerCancel = \"M17.5,13C20,13 22,15 22,17.5C22,20 20,22 17.5,22C15,22 13,20 13,17.5C13,15 15,13 17.5,13M17.5,14.5C16.94,14.5 16.42,14.65 16,14.92L20.08,19C20.35,18.58 20.5,18.06 20.5,17.5A3,3 0 0,0 17.5,14.5M14.5,17.5A3,3 0 0,0 17.5,20.5C18.06,20.5 18.58,20.35 19,20.08L14.92,16C14.65,16.42 14.5,16.94 14.5,17.5M18.5,1.15C19,1.15 19.5,1.34 19.89,1.73L22.73,4.56C23.5,5.35 23.5,6.61 22.73,7.39L18.95,11.16C18.5,11.06 18,11 17.5,11C16.67,11 15.88,11.16 15.15,11.44L11.26,7.55L17.07,1.73C17.46,1.34 17.97,1.15 18.5,1.15M10.3,8.5L13.89,12.1C12.15,13.26 11,15.25 11,17.5C11,18 11.06,18.5 11.16,18.95L10,20.12C9.22,20.89 7.97,20.9 7.19,20.14L6.33,21H0.67L4.36,17.31C3.56,16.5 3.56,15.24 4.34,14.46L10.3,8.5Z\";\r\nvar mdiMarkerCheck = \"M10,16L5,11L6.41,9.58L10,13.17L17.59,5.58L19,7M19,1H5C3.89,1 3,1.89 3,3V15.93C3,16.62 3.35,17.23 3.88,17.59L12,23L20.11,17.59C20.64,17.23 21,16.62 21,15.93V3C21,1.89 20.1,1 19,1Z\";\r\nvar mdiMastodon = \"M20.94,14C20.66,15.41 18.5,16.96 15.97,17.26C14.66,17.41 13.37,17.56 12,17.5C9.75,17.39 8,16.96 8,16.96V17.58C8.32,19.8 10.22,19.93 12.03,20C13.85,20.05 15.47,19.54 15.47,19.54L15.55,21.19C15.55,21.19 14.27,21.87 12,22C10.75,22.07 9.19,21.97 7.38,21.5C3.46,20.45 2.78,16.26 2.68,12L2.67,8.57C2.67,4.23 5.5,2.96 5.5,2.96C6.95,2.3 9.41,2 11.97,2H12.03C14.59,2 17.05,2.3 18.5,2.96C18.5,2.96 21.33,4.23 21.33,8.57C21.33,8.57 21.37,11.78 20.94,14M18,8.91C18,7.83 17.7,7 17.15,6.35C16.59,5.72 15.85,5.39 14.92,5.39C13.86,5.39 13.05,5.8 12.5,6.62L12,7.5L11.5,6.62C10.94,5.8 10.14,5.39 9.07,5.39C8.15,5.39 7.41,5.72 6.84,6.35C6.29,7 6,7.83 6,8.91V14.17H8.1V9.06C8.1,8 8.55,7.44 9.46,7.44C10.46,7.44 10.96,8.09 10.96,9.37V12.16H13.03V9.37C13.03,8.09 13.53,7.44 14.54,7.44C15.44,7.44 15.89,8 15.89,9.06V14.17H18V8.91Z\";\r\nvar mdiMaterialDesign = \"M21,12C21,9.97 20.33,8.09 19,6.38V17.63C20.33,15.97 21,14.09 21,12M17.63,19H6.38C7.06,19.55 7.95,20 9.05,20.41C10.14,20.8 11.13,21 12,21C12.88,21 13.86,20.8 14.95,20.41C16.05,20 16.94,19.55 17.63,19M11,17L7,9V17H11M17,9L13,17H17V9M12,14.53L15.75,7H8.25L12,14.53M17.63,5C15.97,3.67 14.09,3 12,3C9.91,3 8.03,3.67 6.38,5H17.63M5,17.63V6.38C3.67,8.09 3,9.97 3,12C3,14.09 3.67,15.97 5,17.63M23,12C23,15.03 21.94,17.63 19.78,19.78C17.63,21.94 15.03,23 12,23C8.97,23 6.38,21.94 4.22,19.78C2.06,17.63 1,15.03 1,12C1,8.97 2.06,6.38 4.22,4.22C6.38,2.06 8.97,1 12,1C15.03,1 17.63,2.06 19.78,4.22C21.94,6.38 23,8.97 23,12Z\";\r\nvar mdiMaterialUi = \"M8,16.61V15.37L14,11.91V7.23L9,10.12L4,7.23V13L3,13.58L2,13V5L3.07,4.38L9,7.81L12.93,5.54L14.93,4.38L16,5V13.06L10.92,16L14.97,18.33L20,15.43V11L21,10.42L22,11V16.58L14.97,20.64L8,16.61M22,9.75L21,10.33L20,9.75V8.58L21,8L22,8.58V9.75Z\";\r\nvar mdiMathCompass = \"M20,19.88V22L18.2,20.83L13.41,11.83C14.07,11.62 14.67,11.28 15.19,10.83L20,19.88M15,7A3,3 0 0,1 12,10C11.85,10 11.71,10 11.56,10L5.8,20.83L4,22V19.88L9.79,9C8.69,7.77 8.79,5.87 10.03,4.76C10.57,4.28 11.27,4 12,4V2A1,1 0 0,1 13,3V4.18C14.2,4.6 15,5.73 15,7M13,7A1,1 0 0,0 12,6A1,1 0 0,0 11,7A1,1 0 0,0 12,8A1,1 0 0,0 13,7Z\";\r\nvar mdiMathCos = \"M4,7A2,2 0 0,0 2,9V15A2,2 0 0,0 4,17H6A2,2 0 0,0 8,15V14H6V15H4V9H6V10H8V9A2,2 0 0,0 6,7H4M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M18,7A2,2 0 0,0 16,9V11A2,2 0 0,0 18,13H20V15H16V17H20A2,2 0 0,0 22,15V13A2,2 0 0,0 20,11H18V9H22V7H18Z\";\r\nvar mdiMathIntegral = \"M11.5 19.1C11.3 20.2 10.9 21 10.2 21.5C9.5 22 8.6 22.1 7.5 21.9C7.1 21.8 6.3 21.7 6 21.5L6.5 20C6.8 20.1 7.4 20.3 7.7 20.3C8.8 20.5 9.4 20 9.6 18.8L12 5.2C12.2 4 12.7 3.2 13.4 2.6C14.1 2.1 15.1 1.9 16.2 2.1C16.6 2.2 17.4 2.3 18 2.6L17.5 4C17.3 3.9 16.6 3.8 16.3 3.7C15 3.5 14.3 4.1 14 5.6L11.5 19.1Z\";\r\nvar mdiMathIntegralBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M15.9 6.9C15.9 6.9 15.2 6.6 14.9 6.6C14.3 6.5 13.9 6.7 13.7 7.7L12 16.8C11.8 17.6 11.5 18.2 11 18.6C10.6 18.9 10.2 19 9.7 19C8.9 19 7.7 18.5 7.7 18.5L8.2 17.1C8.2 17.1 9 17.4 9.2 17.4C9.5 17.5 9.7 17.4 9.9 17.3C10.1 17.2 10.2 16.9 10.3 16.6L11.9 7.4C12 6.6 12.4 6 12.9 5.5C13.5 5.1 14.2 5 15 5.1C15.7 5.2 16.5 5.6 16.5 5.6L15.9 6.9Z\";\r\nvar mdiMathLog = \"M18 7C16.9 7 16 7.9 16 9V15C16 16.1 16.9 17 18 17H20C21.1 17 22 16.1 22 15V11H20V15H18V9H22V7H18M2 7V17H8V15H4V7H2M11 7C9.9 7 9 7.9 9 9V15C9 16.1 9.9 17 11 17H13C14.1 17 15 16.1 15 15V9C15 7.9 14.1 7 13 7H11M11 9H13V15H11V9Z\";\r\nvar mdiMathNorm = \"M14 21V3H16V21H14M8 21V3H10V21H8Z\";\r\nvar mdiMathNormBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M10 18H8V6H10V18M16 18H14V6H16V18Z\";\r\nvar mdiMathSin = \"M4,7A2,2 0 0,0 2,9V11A2,2 0 0,0 4,13H6V15H2V17H6A2,2 0 0,0 8,15V13A2,2 0 0,0 6,11H4V9H8V7H4M14,7V9H13V15H14V17H10V15H11V9H10V7H14M16,7V17H18V12L20,17H22V7H20V12L18,7H16Z\";\r\nvar mdiMathTan = \"M2,7V9H4V17H6V9H8V7H2M11,7A2,2 0 0,0 9,9V17H11V13H13V17H15V9A2,2 0 0,0 13,7H11M11,9H13V11H11V9M16,7V17H18V12L20,17H22V7H20V12L18,7H16Z\";\r\nvar mdiMatrix = \"M2,2H6V4H4V20H6V22H2V2M20,4H18V2H22V22H18V20H20V4M9,5H10V10H11V11H8V10H9V6L8,6.5V5.5L9,5M15,13H16V18H17V19H14V18H15V14L14,14.5V13.5L15,13M9,13C10.1,13 11,14.34 11,16C11,17.66 10.1,19 9,19C7.9,19 7,17.66 7,16C7,14.34 7.9,13 9,13M9,14C8.45,14 8,14.9 8,16C8,17.1 8.45,18 9,18C9.55,18 10,17.1 10,16C10,14.9 9.55,14 9,14M15,5C16.1,5 17,6.34 17,8C17,9.66 16.1,11 15,11C13.9,11 13,9.66 13,8C13,6.34 13.9,5 15,5M15,6C14.45,6 14,6.9 14,8C14,9.1 14.45,10 15,10C15.55,10 16,9.1 16,8C16,6.9 15.55,6 15,6Z\";\r\nvar mdiMedal = \"M20,2H4V4L9.81,8.36C6.14,9.57 4.14,13.53 5.35,17.2C6.56,20.87 10.5,22.87 14.19,21.66C17.86,20.45 19.86,16.5 18.65,12.82C17.95,10.71 16.3,9.05 14.19,8.36L20,4V2M14.94,19.5L12,17.78L9.06,19.5L9.84,16.17L7.25,13.93L10.66,13.64L12,10.5L13.34,13.64L16.75,13.93L14.16,16.17L14.94,19.5Z\";\r\nvar mdiMedalOutline = \"M14.94 19.5L12 17.77L9.06 19.5L9.84 16.16L7.25 13.92L10.66 13.63L12 10.5L13.34 13.63L16.75 13.92L14.16 16.16M20 2H4V4L8.86 7.64A8 8 0 1 0 15.14 7.64L20 4M18 15A6 6 0 1 1 10.82 9.12A5.86 5.86 0 0 1 13.18 9.12A6 6 0 0 1 18 15M12.63 7H11.37L7.37 4H16.71Z\";\r\nvar mdiMedicalBag = \"M10,3L8,5V7H5C3.85,7 3.12,8 3,9L2,19C1.88,20 2.54,21 4,21H20C21.46,21 22.12,20 22,19L21,9C20.88,8 20.06,7 19,7H16V5L14,3H10M10,5H14V7H10V5M11,10H13V13H16V15H13V18H11V15H8V13H11V10Z\";\r\nvar mdiMeditation = \"M12 4C13.11 4 14 4.89 14 6S13.11 8 12 8 10 7.11 10 6 10.9 4 12 4M21 16V14C18.76 14 16.84 13.04 15.4 11.32L14.06 9.72C13.68 9.26 13.12 9 12.53 9H11.5C10.89 9 10.33 9.26 9.95 9.72L8.61 11.32C7.16 13.04 5.24 14 3 14V16C5.77 16 8.19 14.83 10 12.75V15L6.12 16.55C5.45 16.82 5 17.5 5 18.21C5 19.2 5.8 20 6.79 20H9V19.5C9 18.12 10.12 17 11.5 17H14.5C14.78 17 15 17.22 15 17.5S14.78 18 14.5 18H11.5C10.67 18 10 18.67 10 19.5V20H17.21C18.2 20 19 19.2 19 18.21C19 17.5 18.55 16.82 17.88 16.55L14 15V12.75C15.81 14.83 18.23 16 21 16Z\";\r\nvar mdiMemory = \"M17,17H7V7H17M21,11V9H19V7C19,5.89 18.1,5 17,5H15V3H13V5H11V3H9V5H7C5.89,5 5,5.89 5,7V9H3V11H5V13H3V15H5V17A2,2 0 0,0 7,19H9V21H11V19H13V21H15V19H17A2,2 0 0,0 19,17V15H21V13H19V11M13,13H11V11H13M15,9H9V15H15V9Z\";\r\nvar mdiMenu = \"M3,6H21V8H3V6M3,11H21V13H3V11M3,16H21V18H3V16Z\";\r\nvar mdiMenuDown = \"M7,10L12,15L17,10H7Z\";\r\nvar mdiMenuDownOutline = \"M18,9V10.5L12,16.5L6,10.5V9H18M12,13.67L14.67,11H9.33L12,13.67Z\";\r\nvar mdiMenuLeft = \"M14,7L9,12L14,17V7Z\";\r\nvar mdiMenuLeftOutline = \"M15,18H13.5L7.5,12L13.5,6H15V18M10.33,12L13,14.67V9.33L10.33,12Z\";\r\nvar mdiMenuOpen = \"M21,15.61L19.59,17L14.58,12L19.59,7L21,8.39L17.44,12L21,15.61M3,6H16V8H3V6M3,13V11H13V13H3M3,18V16H16V18H3Z\";\r\nvar mdiMenuRight = \"M10,17L15,12L10,7V17Z\";\r\nvar mdiMenuRightOutline = \"M9,6H10.5L16.5,12L10.5,18H9V6M13.67,12L11,9.33V14.67L13.67,12Z\";\r\nvar mdiMenuSwap = \"M12,6L7,11H17L12,6M7,13L12,18L17,13H7Z\";\r\nvar mdiMenuSwapOutline = \"M12,3.5L6,9.5V11H18V9.5L12,3.5M12,6.33L14.67,9H9.33L12,6.33M6,13V14.5L12,20.5L18,14.5V13H6M9.33,15H14.67L12,17.67L9.33,15Z\";\r\nvar mdiMenuUp = \"M7,15L12,10L17,15H7Z\";\r\nvar mdiMenuUpOutline = \"M18,16V14.5L12,8.5L6,14.5V16H18M12,11.33L14.67,14H9.33L12,11.33Z\";\r\nvar mdiMerge = \"M8 17L12 13H15.2C15.6 14.2 16.7 15 18 15C19.7 15 21 13.7 21 12S19.7 9 18 9C16.7 9 15.6 9.8 15.2 11H12L8 7V3H3V8H6L10.2 12L6 16H3V21H8V17Z\";\r\nvar mdiMessage = \"M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMessageAlert = \"M13 11H11V5H13M13 15H11V13H13M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2Z\";\r\nvar mdiMessageAlertOutline = \"M13,10H11V6H13V10M13,12H11V14H13V12M22,4V16A2,2 0 0,1 20,18H6L2,22V4A2,2 0 0,1 4,2H20A2,2 0 0,1 22,4M20,4H4V17.2L5.2,16H20V4Z\";\r\nvar mdiMessageArrowLeft = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M16 11H11.5L13.3 12.8L12 14L8 10L12 6L13.2 7.2L11.5 9H16V11Z\";\r\nvar mdiMessageArrowLeftOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H6L4 18V4H20M16 11V9H11.5L13.3 7.2L12 6L8 10L12 14L13.2 12.8L11.5 11H16Z\";\r\nvar mdiMessageArrowRight = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M12 14L10.8 12.8L12.6 11H8V9H12.5L10.7 7.2L12 6L16 10L12 14Z\";\r\nvar mdiMessageArrowRightOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H6L4 18V4H20M8 9V11H12.5L10.7 12.8L12 14L16 10L12 6L10.8 7.2L12.5 9H8Z\";\r\nvar mdiMessageBookmark = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M19 13L16.5 11.5L14 13V5H19V13Z\";\r\nvar mdiMessageBookmarkOutline = \"M18 14V6H13V14L15.5 12.5L18 14M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H6L4 18V4H20V16Z\";\r\nvar mdiMessageBulleted = \"M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M8,14H6V12H8V14M8,11H6V9H8V11M8,8H6V6H8V8M15,14H10V12H15V14M18,11H10V9H18V11M18,8H10V6H18V8Z\";\r\nvar mdiMessageBulletedOff = \"M1.27,1.73L0,3L2,5V22L6,18H15L20.73,23.73L22,22.46L1.27,1.73M8,14H6V12H8V14M6,11V9L8,11H6M20,2H4.08L10,7.92V6H18V8H10.08L11.08,9H18V11H13.08L20.07,18C21.14,17.95 22,17.08 22,16V4A2,2 0 0,0 20,2Z\";\r\nvar mdiMessageCog = \"M13.5,10A1.5,1.5 0 0,1 12,11.5C11.16,11.5 10.5,10.83 10.5,10A1.5,1.5 0 0,1 12,8.5A1.5,1.5 0 0,1 13.5,10M22,4V16A2,2 0 0,1 20,18H6L2,22V4A2,2 0 0,1 4,2H20A2,2 0 0,1 22,4M16.77,11.32L15.7,10.5C15.71,10.33 15.71,10.16 15.7,10C15.72,9.84 15.72,9.67 15.7,9.5L16.76,8.68C16.85,8.6 16.88,8.47 16.82,8.36L15.82,6.63C15.76,6.5 15.63,6.47 15.5,6.5L14.27,7C14,6.8 13.73,6.63 13.42,6.5L13.23,5.19C13.21,5.08 13.11,5 13,5H11C10.88,5 10.77,5.09 10.75,5.21L10.56,6.53C10.26,6.65 9.97,6.81 9.7,7L8.46,6.5C8.34,6.46 8.21,6.5 8.15,6.61L7.15,8.34C7.09,8.45 7.11,8.58 7.21,8.66L8.27,9.5C8.23,9.82 8.23,10.16 8.27,10.5L7.21,11.32C7.12,11.4 7.09,11.53 7.15,11.64L8.15,13.37C8.21,13.5 8.34,13.53 8.46,13.5L9.7,13C9.96,13.2 10.24,13.37 10.55,13.5L10.74,14.81C10.77,14.93 10.88,15 11,15H13C13.12,15 13.23,14.91 13.25,14.79L13.44,13.47C13.74,13.34 14,13.18 14.28,13L15.53,13.5C15.65,13.5 15.78,13.5 15.84,13.37L16.84,11.64C16.9,11.53 16.87,11.4 16.77,11.32Z\";\r\nvar mdiMessageCogOutline = \"M16.77 11.32L15.7 10.5C15.71 10.33 15.71 10.16 15.7 10C15.72 9.84 15.72 9.67 15.7 9.5L16.76 8.68C16.85 8.6 16.88 8.47 16.82 8.36L15.82 6.63C15.76 6.5 15.63 6.47 15.5 6.5L14.27 7C14 6.8 13.73 6.63 13.42 6.5L13.23 5.19C13.21 5.08 13.11 5 13 5H11C10.88 5 10.77 5.09 10.75 5.21L10.56 6.53C10.26 6.65 9.97 6.81 9.7 7L8.46 6.5C8.34 6.46 8.21 6.5 8.15 6.61L7.15 8.34C7.09 8.45 7.11 8.58 7.21 8.66L8.27 9.5C8.23 9.82 8.23 10.16 8.27 10.5L7.21 11.32C7.12 11.4 7.09 11.53 7.15 11.64L8.15 13.37C8.21 13.5 8.34 13.53 8.46 13.5L9.7 13C9.96 13.2 10.24 13.37 10.55 13.5L10.74 14.81C10.77 14.93 10.88 15 11 15H13C13.12 15 13.23 14.91 13.25 14.79L13.44 13.47C13.74 13.34 14 13.18 14.28 13L15.53 13.5C15.65 13.5 15.78 13.5 15.84 13.37L16.84 11.64C16.9 11.53 16.87 11.4 16.77 11.32M12 11.5C11.16 11.5 10.5 10.83 10.5 10C10.5 9.17 11.17 8.5 12 8.5S13.5 9.17 13.5 10 12.83 11.5 12 11.5M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H6L4 18V4H20\";\r\nvar mdiMessageDraw = \"M18,14H10.5L12.5,12H18M6,14V11.5L12.88,4.64C13.07,4.45 13.39,4.45 13.59,4.64L15.35,6.41C15.55,6.61 15.55,6.92 15.35,7.12L8.47,14M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMessageFlash = \"M22 4C22 2.9 21.1 2 20 2H4C2.9 2 2 2.9 2 4V22L6 18H15V10H22V4M22.5 16H20.3L22 12H17V18H19V23L22.5 16Z\";\r\nvar mdiMessageFlashOutline = \"M4 17.2V4H20V10H22V4C22 2.9 21.1 2 20 2H4C2.9 2 2 2.9 2 4V22L6 18H15V16H5.2L4 17.2M22.5 16H20.3L22 12H17V18H19V23L22.5 16Z\";\r\nvar mdiMessageImage = \"M5,14L8.5,9.5L11,12.5L14.5,8L19,14M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMessageImageOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H6L4 18V4H20M5 14L8.5 9.5L11 12.5L14.5 8L19 14\";\r\nvar mdiMessageLock = \"M20.5 0A2.5 2.5 0 0 0 18 2.5V3A1 1 0 0 0 17 4V8A1 1 0 0 0 18 9H23A1 1 0 0 0 24 8V4A1 1 0 0 0 23 3V2.5A2.5 2.5 0 0 0 20.5 0M20.5 1A1.5 1.5 0 0 1 22 2.5V3H19V2.5A1.5 1.5 0 0 1 20.5 1M4 2A2 2 0 0 0 2 4V22L6 18H20A2 2 0 0 0 22 16V11H17C15.89 11 15 10.11 15 9V2H4Z\";\r\nvar mdiMessageLockOutline = \"M23 3V2.5C23 1.12 21.88 0 20.5 0S18 1.12 18 2.5V3C17.45 3 17 3.45 17 4V8C17 8.55 17.45 9 18 9H23C23.55 9 24 8.55 24 8V4C24 3.45 23.55 3 23 3M22 3H19V2.5C19 1.67 19.67 1 20.5 1S22 1.67 22 2.5V3M22 11V16C22 17.11 21.11 18 20 18H6L2 22V4C2 2.9 2.9 2 4 2H15.03V4H4V18L6 16H20V11H22Z\";\r\nvar mdiMessageMinus = \"M20 2C21.11 2 22 2.9 22 4V16C22 17.11 21.11 18 20 18H6L2 22V4C2 2.89 2.9 2 4 2H20M8 9V11H16V9H8Z\";\r\nvar mdiMessageMinusOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H6L4 18V4H20M8 9V11H16V9H8Z\";\r\nvar mdiMessageOutline = \"M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M20,16H6L4,18V4H20\";\r\nvar mdiMessagePlus = \"M20,2A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H6L2,22V4C2,2.89 2.9,2 4,2H20M11,6V9H8V11H11V14H13V11H16V9H13V6H11Z\";\r\nvar mdiMessagePlusOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M20 16H6L4 18V4H20M16 9V11H13V14H11V11H8V9H11V6H13V9H16Z\";\r\nvar mdiMessageProcessing = \"M17,11H15V9H17M13,11H11V9H13M9,11H7V9H9M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMessageProcessingOutline = \"M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H6L4 18V4H20M17 11H15V9H17M13 11H11V9H13M9 11H7V9H9\";\r\nvar mdiMessageReply = \"M22,4C22,2.89 21.1,2 20,2H4A2,2 0 0,0 2,4V16A2,2 0 0,0 4,18H18L22,22V4Z\";\r\nvar mdiMessageReplyText = \"M18,8H6V6H18V8M18,11H6V9H18V11M18,14H6V12H18V14M22,4A2,2 0 0,0 20,2H4A2,2 0 0,0 2,4V16A2,2 0 0,0 4,18H18L22,22V4Z\";\r\nvar mdiMessageSettings = \"M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M11,24H13V22H11V24M7,24H9V22H7V24M15,24H17V22H15V24Z\";\r\nvar mdiMessageSettingsOutline = \"M11 24H13V22H11V24M7 24H9V22H7V24M15 24H17V22H15V24M20 2H4C2.9 2 2 2.9 2 4V22L6 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H6L4 18V4H20\";\r\nvar mdiMessageText = \"M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M6,9H18V11H6M14,14H6V12H14M18,8H6V6H18\";\r\nvar mdiMessageTextClock = \"M22 12.41V4C22 2.9 21.11 2 20 2H4C2.9 2 2 2.9 2 4V22L6 18H9.29C10.15 20.89 12.83 23 16 23C19.86 23 23 19.87 23 16C23 14.69 22.63 13.46 22 12.41M6 6H18V8H6V6M16 9C14.1 9 12.37 9.77 11.11 11H6V9H16M6 12H10.26C9.84 12.6 9.5 13.28 9.3 14H6V12M16 20.85C13.32 20.85 11.15 18.68 11.15 16S13.32 11.15 16 11.15C18.67 11.15 20.85 13.32 20.85 16S18.67 20.85 16 20.85M16.5 15.82L18.94 17.23L18.19 18.53L15 16.69V13H16.5V15.82Z\";\r\nvar mdiMessageTextClockOutline = \"M22 12.41V4C22 2.9 21.11 2 20 2H4C2.9 2 2 2.89 2 4V22L6 18H9.29C10.15 20.89 12.83 23 16 23C19.86 23 23 19.87 23 16C23 14.69 22.63 13.46 22 12.41M5.17 16L4 17.17V4H20V10.26C18.86 9.47 17.5 9 16 9C14.1 9 12.37 9.77 11.11 11H6V13H9.69C9.25 13.91 9 14.93 9 16H5.17M16 20.85C13.32 20.85 11.15 18.68 11.15 16S13.32 11.15 16 11.15C18.67 11.15 20.85 13.32 20.85 16S18.67 20.85 16 20.85M18 9H6V7H18V9M16.5 15.82L18.94 17.23L18.19 18.53L15 16.69V13H16.5V15.82Z\";\r\nvar mdiMessageTextLock = \"M20.5 0A2.5 2.5 0 0 0 18 2.5V3A1 1 0 0 0 17 4V8A1 1 0 0 0 18 9H23A1 1 0 0 0 24 8V4A1 1 0 0 0 23 3V2.5A2.5 2.5 0 0 0 20.5 0M20.5 1A1.5 1.5 0 0 1 22 2.5V3H19V2.5A1.5 1.5 0 0 1 20.5 1M4 2A2 2 0 0 0 2 4V22L6 18H20A2 2 0 0 0 22 16V11H17C15.89 11 15 10.11 15 9V2H4M6 6H13V8H6V6M6 9H13V11H6V9M6 12H14V14H6V12Z\";\r\nvar mdiMessageTextLockOutline = \"M23 3V2.5C23 1.12 21.88 0 20.5 0S18 1.12 18 2.5V3C17.45 3 17 3.45 17 4V8C17 8.55 17.45 9 18 9H23C23.55 9 24 8.55 24 8V4C24 3.45 23.55 3 23 3M22 3H19V2.5C19 1.67 19.67 1 20.5 1S22 1.67 22 2.5V3M6 11H15V13H6V11M6 7H15V9H6V7M22 11V16C22 17.11 21.11 18 20 18H6L2 22V4C2 2.89 2.9 2 4 2H15V4H4V17.17L5.17 16H20V11H22Z\";\r\nvar mdiMessageTextOutline = \"M20,2A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H6L2,22V4C2,2.89 2.9,2 4,2H20M4,4V17.17L5.17,16H20V4H4M6,7H18V9H6V7M6,11H15V13H6V11Z\";\r\nvar mdiMessageVideo = \"M18,14L14,10.8V14H6V6H14V9.2L18,6M20,2H4A2,2 0 0,0 2,4V22L6,18H20A2,2 0 0,0 22,16V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMeteor = \"M2.8,3L19.67,18.82C19.67,18.82 20,19.27 19.58,19.71C19.17,20.15 18.63,19.77 18.63,19.77L2.8,3M7.81,4.59L20.91,16.64C20.91,16.64 21.23,17.08 20.82,17.5C20.4,17.97 19.86,17.59 19.86,17.59L7.81,4.59M4.29,8L17.39,20.03C17.39,20.03 17.71,20.47 17.3,20.91C16.88,21.36 16.34,21 16.34,21L4.29,8M12.05,5.96L21.2,14.37C21.2,14.37 21.42,14.68 21.13,15C20.85,15.3 20.47,15.03 20.47,15.03L12.05,5.96M5.45,11.91L14.6,20.33C14.6,20.33 14.82,20.64 14.54,20.95C14.25,21.26 13.87,21 13.87,21L5.45,11.91M16.38,7.92L20.55,11.74C20.55,11.74 20.66,11.88 20.5,12.03C20.38,12.17 20.19,12.05 20.19,12.05L16.38,7.92M7.56,16.1L11.74,19.91C11.74,19.91 11.85,20.06 11.7,20.2C11.56,20.35 11.37,20.22 11.37,20.22L7.56,16.1Z\";\r\nvar mdiMetronome = \"M12,1.75L8.57,2.67L4.06,19.53C4.03,19.68 4,19.84 4,20C4,21.11 4.89,22 6,22H18C19.11,22 20,21.11 20,20C20,19.84 19.97,19.68 19.94,19.53L18.58,14.42L17,16L17.2,17H13.41L16.25,14.16L14.84,12.75L10.59,17H6.8L10.29,4H13.71L15.17,9.43L16.8,7.79L15.43,2.67L12,1.75M11.25,5V14.75L12.75,13.25V5H11.25M19.79,7.8L16.96,10.63L16.25,9.92L14.84,11.34L17.66,14.16L19.08,12.75L18.37,12.04L21.2,9.21L19.79,7.8Z\";\r\nvar mdiMetronomeTick = \"M12,1.75L8.57,2.67L4.07,19.5C4.06,19.5 4,19.84 4,20C4,21.11 4.89,22 6,22H18C19.11,22 20,21.11 20,20C20,19.84 19.94,19.5 19.93,19.5L15.43,2.67L12,1.75M10.29,4H13.71L17.2,17H13V12H11V17H6.8L10.29,4M11,5V9H10V11H14V9H13V5H11Z\";\r\nvar mdiMicroSd = \"M8,2A2,2 0 0,0 6,4V11L4,13V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2H8M9,4H11V8H9V4M12,4H14V8H12V4M15,4H17V8H15V4Z\";\r\nvar mdiMicrophone = \"M12,2A3,3 0 0,1 15,5V11A3,3 0 0,1 12,14A3,3 0 0,1 9,11V5A3,3 0 0,1 12,2M19,11C19,14.53 16.39,17.44 13,17.93V21H11V17.93C7.61,17.44 5,14.53 5,11H7A5,5 0 0,0 12,16A5,5 0 0,0 17,11H19Z\";\r\nvar mdiMicrophoneMinus = \"M9,2A3,3 0 0,1 12,5V11A3,3 0 0,1 9,14A3,3 0 0,1 6,11V5A3,3 0 0,1 9,2M16,11C16,14.5 13.44,17.43 10,17.93V21H8V17.93C4.56,17.43 2,14.5 2,11H4A5,5 0 0,0 9,16A5,5 0 0,0 14,11H16M15,5H23V7H15V5Z\";\r\nvar mdiMicrophoneOff = \"M19,11C19,12.19 18.66,13.3 18.1,14.28L16.87,13.05C17.14,12.43 17.3,11.74 17.3,11H19M15,11.16L9,5.18V5A3,3 0 0,1 12,2A3,3 0 0,1 15,5V11L15,11.16M4.27,3L21,19.73L19.73,21L15.54,16.81C14.77,17.27 13.91,17.58 13,17.72V21H11V17.72C7.72,17.23 5,14.41 5,11H6.7C6.7,14 9.24,16.1 12,16.1C12.81,16.1 13.6,15.91 14.31,15.58L12.65,13.92L12,14A3,3 0 0,1 9,11V10.28L3,4.27L4.27,3Z\";\r\nvar mdiMicrophoneOutline = \"M17.3,11C17.3,14 14.76,16.1 12,16.1C9.24,16.1 6.7,14 6.7,11H5C5,14.41 7.72,17.23 11,17.72V21H13V17.72C16.28,17.23 19,14.41 19,11M10.8,4.9C10.8,4.24 11.34,3.7 12,3.7C12.66,3.7 13.2,4.24 13.2,4.9L13.19,11.1C13.19,11.76 12.66,12.3 12,12.3C11.34,12.3 10.8,11.76 10.8,11.1M12,14A3,3 0 0,0 15,11V5A3,3 0 0,0 12,2A3,3 0 0,0 9,5V11A3,3 0 0,0 12,14Z\";\r\nvar mdiMicrophonePlus = \"M9,2A3,3 0 0,1 12,5V11A3,3 0 0,1 9,14A3,3 0 0,1 6,11V5A3,3 0 0,1 9,2M16,11C16,14.5 13.44,17.43 10,17.93V21H8V17.93C4.56,17.43 2,14.5 2,11H4A5,5 0 0,0 9,16A5,5 0 0,0 14,11H16M15,5H18V2H20V5H23V7H20V10H18V7H15V5Z\";\r\nvar mdiMicrophoneSettings = \"M19,10H17.3C17.3,13 14.76,15.1 12,15.1C9.24,15.1 6.7,13 6.7,10H5C5,13.41 7.72,16.23 11,16.72V20H13V16.72C16.28,16.23 19,13.41 19,10M15,24H17V22H15M11,24H13V22H11M12,13A3,3 0 0,0 15,10V4A3,3 0 0,0 12,1A3,3 0 0,0 9,4V10A3,3 0 0,0 12,13M7,24H9V22H7V24Z\";\r\nvar mdiMicrophoneVariant = \"M9,3A4,4 0 0,1 13,7H5A4,4 0 0,1 9,3M11.84,9.82L11,18H10V19A2,2 0 0,0 12,21A2,2 0 0,0 14,19V14A4,4 0 0,1 18,10H20L19,11L20,12H18A2,2 0 0,0 16,14V19A4,4 0 0,1 12,23A4,4 0 0,1 8,19V18H7L6.16,9.82C5.67,9.32 5.31,8.7 5.13,8H12.87C12.69,8.7 12.33,9.32 11.84,9.82M9,11A1,1 0 0,0 8,12A1,1 0 0,0 9,13A1,1 0 0,0 10,12A1,1 0 0,0 9,11Z\";\r\nvar mdiMicrophoneVariantOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L16,19.26C15.86,21.35 14.12,23 12,23A4,4 0 0,1 8,19V18H7L6.16,9.82C5.82,9.47 5.53,9.06 5.33,8.6L2,5.27M9,3A4,4 0 0,1 13,7H8.82L6.08,4.26C6.81,3.5 7.85,3 9,3M11.84,9.82L11.82,10L9.82,8H12.87C12.69,8.7 12.33,9.32 11.84,9.82M11,18H10V19A2,2 0 0,0 12,21A2,2 0 0,0 14,19V17.27L11.35,14.62L11,18M18,10H20L19,11L20,12H18A2,2 0 0,0 16,14V14.18L14.3,12.5C14.9,11 16.33,10 18,10M8,12A1,1 0 0,0 9,13C9.21,13 9.4,12.94 9.56,12.83L8.17,11.44C8.06,11.6 8,11.79 8,12Z\";\r\nvar mdiMicroscope = \"M9.46,6.28L11.05,9C8.47,9.26 6.5,11.41 6.5,14A5,5 0 0,0 11.5,19C13.55,19 15.31,17.77 16.08,16H13.5V14H21.5V16H19.25C18.84,17.57 17.97,18.96 16.79,20H19.5V22H3.5V20H6.21C4.55,18.53 3.5,16.39 3.5,14C3.5,10.37 5.96,7.2 9.46,6.28M12.74,2.07L13.5,3.37L14.36,2.87L17.86,8.93L14.39,10.93L10.89,4.87L11.76,4.37L11,3.07L12.74,2.07Z\";\r\nvar mdiMicrosoft = \"M2,3H11V12H2V3M11,22H2V13H11V22M21,3V12H12V3H21M21,22H12V13H21V22Z\";\r\nvar mdiMicrosoftAccess = \"M14.5 2.63Q15.84 2.63 17.18 2.77L17.85 2.86Q18.3 2.93 18.84 3.04 19.37 3.15 19.93 3.31 20.5 3.47 20.96 3.69 21.42 3.91 21.71 4.19 22 4.47 22 4.81V19.19Q22 19.53 21.71 19.81 21.41 20.09 20.96 20.31 20.5 20.53 19.93 20.69 19.37 20.85 18.83 20.96 18.3 21.07 17.86 21.14 17.41 21.21 17.17 21.23 15.84 21.38 14.5 21.38 13.15 21.38 11.82 21.23 11.59 21.21 11.15 21.14 10.7 21.07 10.16 20.96 9.63 20.85 9.07 20.69 8.5 20.53 8.05 20.31 7.59 20.09 7.29 19.81 7 19.53 7 19.19V17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H7V4.81Q7 4.47 7.29 4.19 7.59 3.91 8.05 3.69 8.5 3.47 9.07 3.31 9.63 3.15 10.17 3.04 10.7 2.93 11.14 2.86 11.59 2.8 11.83 2.77 13.15 2.63 14.5 2.63M14.5 3.88Q13.87 3.88 13.08 3.92 12.3 3.96 11.5 4.07 10.69 4.18 9.93 4.36 9.17 4.54 8.58 4.81 9.19 5.1 9.95 5.28 10.7 5.46 11.5 5.56 12.29 5.66 13.07 5.71 13.85 5.75 14.5 5.75 15.16 5.75 15.93 5.71 16.71 5.66 17.5 5.56 18.3 5.46 19.06 5.28 19.81 5.1 20.42 4.81 19.83 4.54 19.07 4.36 18.31 4.18 17.5 4.07 16.7 3.96 15.92 3.92 15.14 3.88 14.5 3.88M5.94 13.79H8.06L8.55 15.28H10.22L7.83 8.72H6.2L3.78 15.28H5.44M20.75 19V16Q20.11 16.31 19.31 16.5 18.5 16.68 17.67 16.79 16.83 16.9 16 16.95 15.19 17 14.5 17 13.79 17 13.08 16.96 12.37 16.91 11.67 16.83 11.44 17 11.17 17H8.25V19Q8.53 19.21 9 19.38 9.5 19.56 10.07 19.68 10.65 19.81 11.29 19.9 11.92 20 12.5 20.03 13.12 20.09 13.64 20.11 14.16 20.13 14.5 20.13 14.84 20.12 15.36 20.1 15.88 20.09 16.5 20.03 17.08 20 17.71 19.9 18.35 19.81 18.93 19.68 19.5 19.56 20 19.38 20.47 19.21 20.75 19M20.75 14.63V11Q20.11 11.31 19.31 11.5 18.5 11.68 17.67 11.79 16.83 11.9 16 11.95 15.19 12 14.5 12 13.88 12 13.25 11.97 12.63 11.93 12 11.87V15.62Q12.63 15.69 13.25 15.72 13.88 15.75 14.5 15.75 14.86 15.75 15.38 15.73 15.9 15.71 16.5 15.66 17.08 15.6 17.7 15.5 18.33 15.44 18.9 15.31 19.5 15.18 19.96 15 20.45 14.85 20.75 14.63M20.75 9.63V6Q20.11 6.31 19.31 6.5 18.5 6.68 17.67 6.79 16.83 6.9 16 6.95 15.19 7 14.5 7 13.81 7 13 6.95 12.17 6.9 11.33 6.79 10.5 6.68 9.69 6.5 8.89 6.31 8.25 6V7H11.17Q11.5 7 11.76 7.24 12 7.5 12 7.83V10.62Q12.63 10.69 13.25 10.72 13.88 10.75 14.5 10.75 14.86 10.75 15.38 10.73 15.9 10.71 16.5 10.66 17.08 10.6 17.7 10.5 18.33 10.44 18.9 10.31 19.5 10.18 19.96 10 20.44 9.85 20.75 9.63M6.32 12.5L7 10.5L7.65 12.5Z\";\r\nvar mdiMicrosoftAzure = \"M13.05,4.24L6.56,18.05L2,18L7.09,9.24L13.05,4.24M13.75,5.33L22,19.76H6.74L16.04,18.1L11.17,12.31L13.75,5.33Z\";\r\nvar mdiMicrosoftAzureDevops = \"M22 18L17 22L9 19V22L4.81 16.25L17.72 17.3V6.34L22 5.65V18M4.81 16.25V8.96L17.72 6.34L10.6 2V4.84L3.97 6.76L2 9.38V15.07L4.81 16.25Z\";\r\nvar mdiMicrosoftBing = \"M5,3V19L8.72,21L18,15.82V11.73H18L9.77,8.95L11.38,12.84L13.94,14L8.7,16.92V4.27L5,3\";\r\nvar mdiMicrosoftDynamics365 = \"M6,2L17.25,8.5L13.5,11.5L6,8V2M6,9L9.5,11.25L6,22L18,9V15L6,22V9Z\";\r\nvar mdiMicrosoftEdge = \"M10.86 15.37C10.17 14.6 9.7 13.68 9.55 12.65C9.25 13.11 9 13.61 8.82 14.15C7.9 16.9 9.5 20.33 12.22 21.33C14.56 22.11 17.19 20.72 18.92 19.2C19.18 18.85 21.23 17.04 20.21 16.84C17.19 18.39 13.19 17.95 10.86 15.37M11.46 9.56C12.5 9.55 11.5 9.13 11.07 8.81C10.03 8.24 8.81 7.96 7.63 7.96C3.78 8 .995 10.41 2.3 14.4C3.24 18.28 6.61 21.4 10.59 21.9C8.54 20.61 7.3 18.19 7.3 15.78C7.38 13.25 8.94 10.28 11.46 9.56M2.78 8.24C5.82 6 10.66 6.18 13.28 9C14.3 10.11 15 12 14.07 13.37C12.33 15.25 17.15 15.5 18.18 15.22C21.92 14.5 22.91 10.15 21.13 7.15C19.43 3.75 15.66 1.97 11.96 2C7.9 1.93 4.25 4.5 2.78 8.24Z\";\r\nvar mdiMicrosoftEdgeLegacy = \"M 2.73675,10.8077C 3.8293,-1.36109 22.5157,-1.36109 21.1971,13.5579L 8.61392,13.5579C 8.61392,17.8527 14.4157,19.209 19.5394,16.3081L 19.5394,20.5276C 13.2478,23.8806 4.9972,21.4318 4.9972,14.0853C 4.9972,8.58476 9.97019,6.8142 9.97019,6.8142C 9.97019,6.8142 8.57624,8.58489 8.53857,10.0542L 15.6967,10.0542C 15.6967,2.93376 5.90137,5.57095 2.73675,10.8077 Z\";\r\nvar mdiMicrosoftExcel = \"M21.17 3.25Q21.5 3.25 21.76 3.5 22 3.74 22 4.08V19.92Q22 20.26 21.76 20.5 21.5 20.75 21.17 20.75H7.83Q7.5 20.75 7.24 20.5 7 20.26 7 19.92V17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H7V4.08Q7 3.74 7.24 3.5 7.5 3.25 7.83 3.25M7 13.06L8.18 15.28H9.97L8 12.06L9.93 8.89H8.22L7.13 10.9L7.09 10.96L7.06 11.03Q6.8 10.5 6.5 9.96 6.25 9.43 5.97 8.89H4.16L6.05 12.08L4 15.28H5.78M13.88 19.5V17H8.25V19.5M13.88 15.75V12.63H12V15.75M13.88 11.38V8.25H12V11.38M13.88 7V4.5H8.25V7M20.75 19.5V17H15.13V19.5M20.75 15.75V12.63H15.13V15.75M20.75 11.38V8.25H15.13V11.38M20.75 7V4.5H15.13V7Z\";\r\nvar mdiMicrosoftInternetExplorer = \"M13,3L14,3.06C16.8,1.79 19.23,1.64 20.5,2.92C21.5,3.93 21.58,5.67 20.92,7.72C21.61,9 22,10.45 22,12L21.95,13H9.08C9.45,15.28 11.06,17 13,17C14.31,17 15.47,16.21 16.2,15H21.5C20.25,18.5 16.92,21 13,21C11.72,21 10.5,20.73 9.41,20.25C6.5,21.68 3.89,21.9 2.57,20.56C1,18.96 1.68,15.57 4,12C4.93,10.54 6.14,9.06 7.57,7.65L8.38,6.88C7.21,7.57 5.71,8.62 4.19,10.17C5.03,6.08 8.66,3 13,3M13,7C11.21,7 9.69,8.47 9.18,10.5H16.82C16.31,8.47 14.79,7 13,7M20.06,4.06C19.4,3.39 18.22,3.35 16.74,3.81C18.22,4.5 19.5,5.56 20.41,6.89C20.73,5.65 20.64,4.65 20.06,4.06M3.89,20C4.72,20.84 6.4,20.69 8.44,19.76C6.59,18.67 5.17,16.94 4.47,14.88C3.27,17.15 3,19.07 3.89,20Z\";\r\nvar mdiMicrosoftOffice = \"M19.94 5.59V18.39Q19.94 19.06 19.55 19.59 19.16 20.11 18.5 20.29L12.77 21.94Q12.65 21.97 12.5 22H12.28Q11.95 22 11.68 21.91 11.41 21.82 11.13 21.67L7.38 19.55Q7.17 19.43 7.05 19.24 6.93 19.05 6.93 18.81 6.93 18.45 7.19 18.2 7.44 17.95 7.8 17.95H12.66V6.14L9 7.44Q8.57 7.6 8.3 8 8.03 8.38 8.03 8.85V15.58Q8.03 16 7.82 16.34 7.62 16.68 7.25 16.88L5.53 17.82Q5.29 17.95 5.05 17.95 4.64 17.95 4.35 17.66 4.06 17.37 4.06 16.95V7.47Q4.06 6.95 4.33 6.5 4.61 6 5.06 5.74L11.22 2.24Q11.43 2.12 11.67 2.06 11.91 2 12.15 2 12.32 2 12.46 2.03 12.6 2.05 12.77 2.1L18.5 3.69Q18.83 3.78 19.09 3.96 19.35 4.14 19.54 4.39 19.74 4.65 19.84 4.95 19.94 5.26 19.94 5.59M18.62 18.39V5.59Q18.62 5.36 18.5 5.19 18.35 5 18.13 4.96L15.31 4.18Q15 4.09 14.65 4 14.32 3.89 14 3.81V20.21L18.13 19Q18.35 18.96 18.5 18.79 18.62 18.62 18.62 18.39Z\";\r\nvar mdiMicrosoftOnedrive = \"M18.21 10.29Q19 10.34 19.7 10.68 20.39 11 20.9 11.57 21.41 12.12 21.71 12.83 22 13.54 22 14.34 22 15.18 21.68 15.92 21.36 16.66 20.8 17.21 20.25 17.76 19.5 18.08 18.78 18.41 17.94 18.41H7Q5.97 18.41 5.06 18 4.15 17.61 3.47 16.94 2.79 16.26 2.4 15.35 2 14.44 2 13.41 2 12.59 2.26 11.83 2.5 11.08 3 10.45 3.44 9.82 4.08 9.35 4.72 8.88 5.5 8.63 5.87 8.5 6.21 8.5 6.56 8.43 6.93 8.41H6.94Q7.37 7.75 7.95 7.23 8.5 6.71 9.2 6.34 9.87 6 10.62 5.78 11.37 5.59 12.16 5.59 13.22 5.59 14.2 5.94 15.18 6.29 16 6.91 16.8 7.53 17.37 8.39 17.95 9.26 18.21 10.29M12.16 6.84Q11.05 6.84 10.06 7.3 9.06 7.75 8.36 8.6 8.73 8.7 9.07 8.85 9.4 9 9.73 9.2L13.71 11.58L16 10.62Q16.21 10.53 16.44 10.45 16.67 10.38 16.92 10.33 16.68 9.55 16.21 8.91 15.74 8.27 15.11 7.81 14.5 7.35 13.73 7.1 13 6.84 12.16 6.84M4 15.66L12.27 12.18L9.08 10.26Q8.59 9.97 8.06 9.81 7.5 9.66 6.95 9.66 6.19 9.66 5.5 9.96 4.84 10.26 4.34 10.77 3.84 11.29 3.54 11.97 3.25 12.65 3.25 13.41 3.25 14 3.45 14.59 3.64 15.19 4 15.66M17.94 17.16Q18.41 17.16 18.84 17 19.27 16.86 19.64 16.58L13.61 13L5.03 16.59Q5.47 16.86 5.97 17 6.47 17.16 7 17.16M20.45 15.61Q20.75 15 20.75 14.34 20.75 13.7 20.5 13.17 20.26 12.65 19.85 12.28 19.43 11.91 18.88 11.71 18.32 11.5 17.7 11.5 17.35 11.5 17 11.6 16.66 11.68 16.33 11.81 16 11.93 15.67 12.08 15.35 12.23 15.04 12.37Z\";\r\nvar mdiMicrosoftOnenote = \"M21.17 3.25Q21.5 3.25 21.76 3.5 22 3.74 22 4.08V19.92Q22 20.26 21.76 20.5 21.5 20.75 21.17 20.75H7.83Q7.5 20.75 7.24 20.5 7 20.26 7 19.92V17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H7V4.08Q7 3.74 7.24 3.5 7.5 3.25 7.83 3.25M5.8 11.17L8.16 15.27H9.65V8.73H8.2V12.92L5.93 8.73H4.35V15.27H5.8M20.75 19.5V17H18.25V19.5M20.75 15.75V13.25H18.25V15.75M20.75 12V9.5H18.25V12M20.75 8.25V4.5H8.25V7H11.17Q11.5 7 11.76 7.24 12 7.5 12 7.83V16.17Q12 16.5 11.76 16.76 11.5 17 11.17 17H8.25V19.5H17V8.25Z\";\r\nvar mdiMicrosoftOutlook = \"M8.56 12.03Q8.56 12.41 8.5 12.76 8.39 13.1 8.2 13.38 8 13.65 7.71 13.81 7.41 13.97 7 13.97 6.58 13.97 6.29 13.8 6 13.63 5.81 13.35 5.62 13.07 5.54 12.72 5.45 12.37 5.45 12 5.45 11.64 5.54 11.28 5.62 10.93 5.81 10.65 6 10.37 6.31 10.2 6.61 10.03 7.03 10.03 7.46 10.03 7.75 10.2 8.05 10.38 8.23 10.66 8.41 10.95 8.5 11.3 8.56 11.66 8.56 12.03M22 12V19.81Q22 20.2 21.73 20.5 21.45 20.75 21.06 20.75H7.94Q7.55 20.75 7.27 20.5 7 20.2 7 19.81V17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H8.25V4.13Q8.25 3.76 8.5 3.5 8.76 3.25 9.13 3.25H19.87Q20.24 3.25 20.5 3.5 20.75 3.76 20.75 4.13V11.04L21.79 11.64H21.8Q21.88 11.7 21.94 11.8 22 11.89 22 12M17 5.13V7.63H19.5V5.13M17 8.88V11.38H19.5V8.88M17 12.63V14.15L19.54 12.63M12.63 5.13V7.63H15.75V5.13M12.63 8.88V11.38H15.75V8.88M12.63 12.63V14.32L14.64 15.56L15.75 14.9V12.63M9.5 5.13V7H11.27Q11.33 7 11.38 7.04V5.12M7 15.32Q7.73 15.32 8.32 15.06 8.9 14.8 9.31 14.35 9.71 13.9 9.91 13.28 10.12 12.66 10.13 11.94 10.13 11.25 9.92 10.65 9.72 10.06 9.32 9.62 8.93 9.18 8.37 8.93 7.8 8.68 7.08 8.68 6.31 8.68 5.71 8.93 5.12 9.18 4.71 9.63 4.3 10.09 4.09 10.71 3.88 11.34 3.88 12.08 3.88 12.78 4.09 13.38 4.31 13.97 4.71 14.4 5.11 14.83 5.68 15.08 6.26 15.32 7 15.32M8.25 19.5H18.57L12 15.4V16.17Q12 16.5 11.76 16.76 11.5 17 11.17 17H8.25M20.75 19.39V13.36L15.83 16.31Z\";\r\nvar mdiMicrosoftPowerpoint = \"M13.25 3.25Q14.46 3.25 15.58 3.56 16.7 3.88 17.67 4.45 18.64 5 19.44 5.81 20.23 6.61 20.8 7.58 21.38 8.55 21.69 9.67 22 10.79 22 12 22 13.21 21.69 14.33 21.38 15.45 20.8 16.42 20.23 17.39 19.44 18.19 18.64 19 17.67 19.55 16.7 20.13 15.58 20.44 14.46 20.75 13.25 20.75 12.18 20.75 11.15 20.5 10.12 20.24 9.2 19.76 8.28 19.27 7.5 18.58 6.69 17.88 6.07 17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.25 2.5 7 2.83 7H6.07Q6.69 6.12 7.5 5.42 8.28 4.72 9.2 4.24 10.13 3.76 11.15 3.5 12.18 3.25 13.25 3.25M13.88 4.53V11.37H20.72Q20.6 10 20.03 8.81 19.46 7.62 18.55 6.7 17.64 5.79 16.43 5.22 15.23 4.65 13.88 4.53M9.5 10.84Q9.5 10.27 9.3 9.87 9.11 9.46 8.78 9.21 8.45 8.95 8 8.84 7.55 8.72 7 8.72H4.37V15.27H5.91V13H6.94Q7.42 13 7.87 12.84 8.33 12.7 8.69 12.43 9.05 12.17 9.27 11.76 9.5 11.36 9.5 10.84M13.25 19.5Q14.23 19.5 15.14 19.26 16.04 19 16.85 18.58 17.66 18.13 18.33 17.5 19 16.89 19.5 16.13 20 15.36 20.33 14.47 20.64 13.58 20.72 12.62H12.64V4.53Q11.19 4.65 9.91 5.29 8.63 5.93 7.67 7H11.17Q11.5 7 11.76 7.25 12 7.5 12 7.83V16.17Q12 16.5 11.76 16.76 11.5 17 11.17 17H7.67Q8.2 17.6 8.84 18.06 9.5 18.5 10.19 18.84 10.91 19.17 11.68 19.33 12.45 19.5 13.25 19.5M6.85 10Q7.32 10 7.61 10.19 7.89 10.38 7.89 10.89 7.89 11.11 7.79 11.25 7.69 11.39 7.53 11.5 7.37 11.57 7.18 11.6 7 11.64 6.8 11.64H5.91V10H6.85Z\";\r\nvar mdiMicrosoftSharepoint = \"M22 13.25Q22 14.29 21.6 15.2 21.21 16.1 20.53 16.78 19.85 17.46 18.94 17.86 18.03 18.25 17 18.25 16.36 18.25 15.73 18.09 15.64 18.92 15.27 19.63 14.89 20.35 14.3 20.88 13.72 21.41 12.97 21.7 12.21 22 11.38 22 10.47 22 9.67 21.65 8.88 21.31 8.28 20.72 7.69 20.13 7.35 19.33 7 18.53 7 17.63V17.31Q7.03 17.16 7.05 17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H5.78Q5.9 5.94 6.39 5 6.87 4.11 7.63 3.44 8.38 2.76 9.34 2.38 10.3 2 11.38 2 12.54 2 13.56 2.44 14.59 2.89 15.35 3.65 16.11 4.41 16.56 5.44 17 6.46 17 7.63V7.94Q17 8.09 16.96 8.25 18 8.25 18.91 8.64 19.83 9.03 20.5 9.71 21.21 10.38 21.6 11.29 22 12.21 22 13.25M11.37 3.25Q10.56 3.25 9.83 3.54 9.09 3.82 8.5 4.32 7.94 4.82 7.55 5.5 7.17 6.2 7.05 7H11.17Q11.5 7 11.76 7.25 12 7.5 12 7.83V11.95L12.18 11.92Q12.35 11.3 12.68 10.74 13 10.17 13.47 9.72 13.92 9.27 14.5 8.93 15.04 8.6 15.67 8.43 15.75 8 15.75 7.63 15.75 6.72 15.4 5.92 15.06 5.13 14.46 4.54 13.87 3.95 13.08 3.6 12.28 3.25 11.37 3.25M7.1 15.25Q7.55 15.25 8 15.16 8.42 15.07 8.76 14.85 9.1 14.64 9.31 14.29 9.5 13.93 9.5 13.41 9.5 12.88 9.3 12.53 9.08 12.18 8.75 11.94 8.42 11.71 8.04 11.56L7.32 11.27Q7 11.14 6.77 11 6.55 10.85 6.55 10.62 6.55 10.46 6.67 10.35 6.79 10.25 6.95 10.2 7.11 10.13 7.28 10.11 7.46 10.1 7.58 10.1 8.07 10.1 8.46 10.22 8.84 10.35 9.25 10.6V9.12Q9 9.05 8.81 9 8.61 8.95 8.42 8.92 8.22 8.89 8 8.87 7.8 8.86 7.55 8.86 7.12 8.86 6.67 8.95 6.22 9.05 5.85 9.27 5.5 9.5 5.26 9.83 5.03 10.18 5.03 10.69 5.03 11.19 5.25 11.5 5.47 11.85 5.8 12.09 6.13 12.32 6.5 12.5L7.22 12.79Q7.56 12.93 7.78 13.08 8 13.24 8 13.46 8 13.65 7.89 13.76 7.79 13.87 7.63 13.92 7.5 14 7.31 14H7Q6.41 14 5.96 13.82 5.5 13.62 5.04 13.3V14.86Q6.03 15.25 7.1 15.25M11.37 20.75Q12 20.75 12.58 20.5 13.15 20.26 13.58 19.84 14 19.41 14.25 18.84 14.5 18.27 14.5 17.63 14.5 17.07 14.31 16.56 14.13 16.05 13.8 15.65 13.46 15.24 13 14.96 12.55 14.68 12 14.56V16.17Q12 16.5 11.76 16.76 11.5 17 11.17 17H8.31Q8.25 17.31 8.25 17.63 8.25 18.27 8.5 18.84 8.74 19.41 9.16 19.84 9.59 20.26 10.16 20.5 10.73 20.75 11.37 20.75M17 17Q17.77 17 18.45 16.71 19.14 16.42 19.65 15.9 20.16 15.39 20.46 14.71 20.75 14.03 20.75 13.25 20.75 12.5 20.46 11.8 20.16 11.11 19.65 10.6 19.14 10.09 18.45 9.79 17.77 9.5 17 9.5 16.23 9.5 15.55 9.8 14.87 10.1 14.36 10.61 13.85 11.12 13.55 11.8 13.25 12.5 13.25 13.25V13.46L13.27 13.68Q13.73 13.9 14.12 14.22 14.5 14.54 14.82 14.93 15.12 15.33 15.34 15.79 15.55 16.25 15.66 16.74 16.32 17 17 17Z\";\r\nvar mdiMicrosoftTeams = \"M19.19 8.77Q18.73 8.77 18.33 8.6 17.94 8.43 17.64 8.13 17.34 7.83 17.17 7.44 17 7.04 17 6.58 17 6.13 17.17 5.73 17.34 5.33 17.64 5.04 17.94 4.74 18.33 4.57 18.73 4.39 19.19 4.4 19.64 4.39 20.04 4.57 20.44 4.74 20.74 5.04 21.03 5.33 21.21 5.73 21.38 6.13 21.38 6.58 21.38 7.04 21.21 7.44 21.04 7.83 20.74 8.13 20.44 8.43 20.04 8.6 19.64 8.77 19.19 8.77M19.19 5.65Q18.8 5.65 18.5 5.92 18.25 6.19 18.25 6.58 18.25 6.97 18.5 7.25 18.8 7.5 19.19 7.5 19.58 7.5 19.85 7.25 20.13 7 20.13 6.58 20.13 6.19 19.85 5.92 19.58 5.65 19.19 5.65M22 10.33V15Q22 15.63 21.76 16.2 21.5 16.77 21.09 17.19 20.66 17.62 20.09 17.86 19.5 18.11 18.88 18.11 18.5 18.11 18.12 18 17.73 17.93 17.41 17.75 17.17 18.54 16.7 19.19 16.23 19.84 15.6 20.3 14.97 20.76 14.21 21 13.45 21.27 12.63 21.27 11.67 21.27 10.82 20.94 10 20.61 9.32 20 8.66 19.43 8.23 18.64 7.79 17.84 7.66 16.9H2.83Q2.5 16.9 2.24 16.65 2 16.41 2 16.07V7.73Q2 7.39 2.24 7.14 2.5 6.9 2.83 6.9H10Q9.71 6.3 9.71 5.65 9.71 5.04 9.94 4.5 10.16 4 10.56 3.58 10.96 3.19 11.5 2.96 12 2.73 12.62 2.73 13.23 2.73 13.76 2.96 14.29 3.19 14.69 3.58 15.09 4 15.31 4.5 15.54 5.04 15.54 5.65 15.54 6.25 15.31 6.79 15.09 7.32 14.69 7.71 14.29 8.11 13.76 8.34 13.23 8.57 12.62 8.57 12.47 8.57 12.31 8.55 12.16 8.53 12 8.5V9.4H21.06Q21.45 9.4 21.73 9.67 22 9.94 22 10.33M12.63 4Q12.28 4 12 4.11 11.67 4.24 11.44 4.47 11.22 4.7 11.09 5 10.96 5.31 10.96 5.65 10.96 6 11.09 6.3 11.22 6.6 11.44 6.83 11.67 7.05 12 7.19 12.28 7.32 12.63 7.32 12.97 7.32 13.27 7.19 13.57 7.05 13.8 6.83 14.03 6.6 14.16 6.3 14.3 6 14.3 5.65 14.3 5.31 14.16 5 14.03 4.7 13.8 4.47 13.57 4.24 13.27 4.11 12.97 4 12.63 4M7.78 10.18H9.66V8.62H4.34V10.18H6.22V15.18H7.78M16.38 16.27V10.65H12V16.07Q12 16.41 11.76 16.65 11.5 16.9 11.17 16.9H8.92Q9.05 17.57 9.39 18.15 9.73 18.72 10.21 19.14 10.69 19.55 11.31 19.79 11.92 20 12.63 20 13.4 20 14.08 19.73 14.76 19.43 15.28 18.92 15.79 18.41 16.08 17.73 16.38 17.05 16.38 16.27M20.75 15V10.65H17.63V16.36Q17.88 16.61 18.2 16.74 18.5 16.86 18.88 16.86 19.27 16.86 19.61 16.71 19.95 16.56 20.2 16.31 20.46 16.06 20.6 15.71 20.75 15.37 20.75 15Z\";\r\nvar mdiMicrosoftVisualStudio = \"M17,8.5L12.25,12.32L17,16V8.5M4.7,18.4L2,16.7V7.7L5,6.7L9.3,10.03L18,2L22,4.5V20L17,22L9.34,14.66L4.7,18.4M5,14L6.86,12.28L5,10.5V14Z\";\r\nvar mdiMicrosoftVisualStudioCode = \"M17,16.47V7.39L11,11.93M2.22,9.19C1.92,8.87 1.91,8.37 2.2,8.04L3.4,6.93C3.6,6.75 4.09,6.67 4.45,6.93L7.87,9.54L15.8,2.29C16.12,1.97 16.67,1.84 17.3,2.17L21.3,4.08C21.66,4.29 22,4.62 22,5.23V18.73C22,19.13 21.71,19.56 21.4,19.73L17,21.83C16.68,21.96 16.08,21.84 15.87,21.63L7.85,14.33L4.45,16.93C4.07,17.19 3.6,17.12 3.4,16.93L2.2,15.83C1.88,15.5 1.92,14.96 2.25,14.63L5.25,11.93\";\r\nvar mdiMicrosoftWindows = \"M3,12V6.75L9,5.43V11.91L3,12M20,3V11.75L10,11.9V5.21L20,3M3,13L9,13.09V19.9L3,18.75V13M20,13.25V22L10,20.09V13.1L20,13.25Z\";\r\nvar mdiMicrosoftWindowsClassic = \"M2.67,5.3V5.91L1.96,6.21V5.6L2.67,5.3M2.67,11.24V11.86L1.96,12.15V11.56L2.67,11.24M2.67,17.27V17.89L1.96,18.18V17.59L2.67,17.27M2.6,7.29V7.84L2.03,8.1V7.56L2.6,7.29M2.6,9.28V9.82L2.03,10.08V9.54L2.6,9.28M2.6,13.31V13.84L2.03,14.1V13.56L2.6,13.31M2.6,15.33V15.87L2.03,16.13V15.6L2.6,15.33M4.5,5.64V6.36L3.5,6.73V6L4.5,5.64M4.5,11.66V12.37L3.5,12.74V12.03L4.5,11.66M4.5,17.7V18.41L3.5,18.81V18.1L4.5,17.7M4.43,7.72V8.38L3.64,8.68V8L4.43,7.72M4.43,9.73V10.37L3.65,10.67V10L4.43,9.73M4.43,13.74V14.38L3.65,14.69V14.03L4.43,13.74M4.43,15.76V16.41L3.65,16.72V16.06L4.43,15.76M6.31,6.09V6.94L5.05,7.43V6.59L6.31,6.09M6.31,12.11V12.96L5.05,13.45V12.61L6.31,12.11M6.31,18.08V18.93L5.05,19.43V18.58L6.31,18.08M6.25,8.18V8.94L5.19,9.34V8.61L6.25,8.18M6.25,10.18V10.93L5.19,11.35V10.6L6.25,10.18M6.25,14.19V14.94L5.19,15.37V14.62L6.25,14.19M6.25,16.14V16.9L5.19,17.32V16.57L6.25,16.14M8.29,6.04V7.16L6.72,7.78V6.67L8.29,6.04M8.29,12.06V13.19L6.72,13.8V12.68L8.29,12.06M8.29,18.03V19.15L6.72,19.77V18.66L8.29,18.03M8.2,8.13V9.16L6.89,9.69V8.66L8.2,8.13M8.2,10.13V11.15L6.89,11.68V10.65L8.2,10.13M8.2,14.15V15.18L6.89,15.7V14.67L8.2,14.15M8.2,16.1V17.12L6.89,17.64V16.63L8.2,16.1M10.34,5.85V7.32L8.61,8V6.56L10.34,5.85M10.34,11.87V13.33L8.61,14.03V12.56L10.34,11.87M10.34,17.84V19.3L8.61,20V18.54L10.34,17.84M10.26,8.05V9.28L8.78,9.87V8.64L10.26,8.05M10.26,9.97V11.2L8.78,11.78V10.56L10.26,9.97M10.26,14.06V15.31L8.78,15.88V14.65L10.26,14.06M10.26,16V17.25L8.78,17.84V16.6L10.26,16M12.45,5.12V7.12L10.59,7.89V6C11.23,5.65 11.85,5.35 12.45,5.12M12.45,7.33V9.06L10.59,9.84V8.1L12.45,7.33M12.45,9.28V11.04L10.59,11.82V10.06L12.45,9.28M12.45,11.25V13L10.59,13.77V12L12.45,11.25M12.45,13.21V15L10.59,15.78V14L12.45,13.21M12.45,15.21V16.96L10.59,17.76V16L12.45,15.21M12.45,17.17V19.04C11.72,19.32 11.1,19.59 10.59,19.84V17.96L12.45,17.17M22.04,5.18V19.23C20.85,18.44 19.37,18.05 17.59,18.05C16.12,18.05 14.47,18.35 12.65,18.96V17.06C13.62,16.69 14.68,16.42 15.84,16.26V11.69C14.86,11.81 13.8,12.15 12.65,12.71V11.4C13.64,10.94 14.71,10.63 15.84,10.46V6C14.82,6.18 13.76,6.53 12.65,7V5.03C14.27,4.34 15.86,4 17.41,4C19.09,4 20.63,4.39 22.04,5.18M20.15,6.41C19.39,6 18.5,5.82 17.42,5.82C17.29,5.82 17.17,5.83 17.05,5.84V10.38L17.46,10.37C18.37,10.37 19.27,10.5 20.15,10.8V6.41M20.15,12.1C19.34,11.74 18.43,11.56 17.44,11.56C17.31,11.56 17.18,11.57 17.05,11.58V16.16H17.46C18.45,16.16 19.35,16.28 20.15,16.53V12.1H20.15Z\";\r\nvar mdiMicrosoftWord = \"M21.17 3.25Q21.5 3.25 21.76 3.5 22 3.74 22 4.08V19.92Q22 20.26 21.76 20.5 21.5 20.75 21.17 20.75H7.83Q7.5 20.75 7.24 20.5 7 20.26 7 19.92V17H2.83Q2.5 17 2.24 16.76 2 16.5 2 16.17V7.83Q2 7.5 2.24 7.24 2.5 7 2.83 7H7V4.08Q7 3.74 7.24 3.5 7.5 3.25 7.83 3.25M7.03 11.34L8.23 15.28H9.6L10.91 8.72H9.53L8.75 12.6L7.64 8.85H6.5L5.31 12.62L4.53 8.72H3.09L4.4 15.28H5.77M20.75 19.5V17H8.25V19.5M20.75 15.75V12.63H12V15.75M20.75 11.38V8.25H12V11.38M20.75 7V4.5H8.25V7Z\";\r\nvar mdiMicrosoftXbox = \"M6.43,3.72C6.5,3.66 6.57,3.6 6.62,3.56C8.18,2.55 10,2 12,2C13.88,2 15.64,2.5 17.14,3.42C17.25,3.5 17.54,3.69 17.7,3.88C16.25,2.28 12,5.7 12,5.7C10.5,4.57 9.17,3.8 8.16,3.5C7.31,3.29 6.73,3.5 6.46,3.7M19.34,5.21C19.29,5.16 19.24,5.11 19.2,5.06C18.84,4.66 18.38,4.56 18,4.59C17.61,4.71 15.9,5.32 13.8,7.31C13.8,7.31 16.17,9.61 17.62,11.96C19.07,14.31 19.93,16.16 19.4,18.73C21,16.95 22,14.59 22,12C22,9.38 21,7 19.34,5.21M15.73,12.96C15.08,12.24 14.13,11.21 12.86,9.95C12.59,9.68 12.3,9.4 12,9.1C12,9.1 11.53,9.56 10.93,10.17C10.16,10.94 9.17,11.95 8.61,12.54C7.63,13.59 4.81,16.89 4.65,18.74C4.65,18.74 4,17.28 5.4,13.89C6.3,11.68 9,8.36 10.15,7.28C10.15,7.28 9.12,6.14 7.82,5.35L7.77,5.32C7.14,4.95 6.46,4.66 5.8,4.62C5.13,4.67 4.71,5.16 4.71,5.16C3.03,6.95 2,9.35 2,12A10,10 0 0,0 12,22C14.93,22 17.57,20.74 19.4,18.73C19.4,18.73 19.19,17.4 17.84,15.5C17.53,15.07 16.37,13.69 15.73,12.96Z\";\r\nvar mdiMicrosoftXboxController = \"M8.75,15.75C6.75,15.75 6,18 4,19C2,19 0.5,16 4.5,7.5H4.75L5.19,6.67C5.19,6.67 8,5 9.33,6.23H14.67C16,5 18.81,6.67 18.81,6.67L19.25,7.5H19.5C23.5,16 22,19 20,19C18,18 17.25,15.75 15.25,15.75H8.75M12,7A1,1 0 0,0 11,8A1,1 0 0,0 12,9A1,1 0 0,0 13,8A1,1 0 0,0 12,7Z\";\r\nvar mdiMicrosoftXboxControllerBatteryAlert = \"M21,19V7H15V19H21M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8M17,9H19V14H17V9M17,15H19V17H17V15Z\";\r\nvar mdiMicrosoftXboxControllerBatteryCharging = \"M20,5H21.67C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5M21,7H15V19H21V7M15.5,14L18.5,7.5V12H20.5L17.5,18.5V14H15.5M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8Z\";\r\nvar mdiMicrosoftXboxControllerBatteryEmpty = \"M21,19V7H15V19H21M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8Z\";\r\nvar mdiMicrosoftXboxControllerBatteryFull = \"M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8Z\";\r\nvar mdiMicrosoftXboxControllerBatteryLow = \"M21,16V7H15V16H21M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8Z\";\r\nvar mdiMicrosoftXboxControllerBatteryMedium = \"M21,12V7H15V12H21M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8Z\";\r\nvar mdiMicrosoftXboxControllerBatteryUnknown = \"M21.67,5C22.4,5 23,5.6 23,6.33V19.67A1.33,1.33 0 0,1 21.67,21H14.33C13.6,21 13,20.4 13,19.67V16.75H7.75C5.75,16.75 5,19 3,20C1,20 -0.5,17 3.5,8.5H3.75L4.19,7.67C4.19,7.67 7,6 8.33,7.23H13V6.33A1.33,1.33 0 0,1 14.33,5H16V3H20V5H21.67M11,8A1,1 0 0,0 10,9A1,1 0 0,0 11,10A1,1 0 0,0 12,9A1,1 0 0,0 11,8M18.19,8C17.32,8 16.62,8.2 16.08,8.59C15.56,9 15.3,9.57 15.31,10.36L15.32,10.39H17.25C17.26,10.09 17.35,9.86 17.53,9.7C17.71,9.55 17.93,9.47 18.19,9.47C18.5,9.47 18.76,9.57 18.94,9.75C19.12,9.94 19.2,10.2 19.2,10.5C19.2,10.82 19.13,11.09 18.97,11.32C18.83,11.55 18.62,11.75 18.36,11.91C17.85,12.25 17.5,12.55 17.31,12.82C17.11,13.08 17,13.5 17,14H19C19,13.69 19.04,13.44 19.13,13.26C19.22,13.08 19.39,12.9 19.64,12.74C20.09,12.5 20.46,12.21 20.75,11.81C21.04,11.41 21.19,11 21.19,10.5C21.19,9.74 20.92,9.13 20.38,8.68C19.85,8.23 19.12,8 18.19,8M17,15V17H19V15H17Z\";\r\nvar mdiMicrosoftXboxControllerMenu = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M6,7H18V9H6V7M6,11H18V13H6V11M6,15H18V17H6V15Z\";\r\nvar mdiMicrosoftXboxControllerOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L12.5,15.75H8.75C6.75,15.75 6,18 4,19C2,19 0.5,16.04 4.42,7.69L2,5.27M9.33,6.23H14.67C16,5 18.81,6.67 18.81,6.67L19.25,7.5H19.5C23,15 22.28,18.2 20.69,18.87L7.62,5.8C8.25,5.73 8.87,5.81 9.33,6.23M12,7A1,1 0 0,0 11,8A1,1 0 0,0 12,9A1,1 0 0,0 13,8A1,1 0 0,0 12,7Z\";\r\nvar mdiMicrosoftXboxControllerView = \"M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M6,7H15V9H8V14H6V7M9,10H18V17H9V10M11,12V15H16V12H11Z\";\r\nvar mdiMicrosoftYammer = \"M22 12Q22 12.43 21.97 12.94 21.95 13.45 21.89 13.97 21.84 14.5 21.76 15 21.68 15.5 21.56 15.89 21.5 16.07 21.38 16.19 21.24 16.3 21.04 16.3 20.95 16.3 20.66 16.23 20.37 16.16 20.03 16.07L19.39 15.88Q19.09 15.79 18.96 15.76 18.75 16.54 18.41 17.38 18.08 18.21 17.65 19 17.22 19.8 16.7 20.5 16.18 21.25 15.61 21.82L15.43 21.95Q15.33 22 15.21 22 15 22 14.84 21.84L10.1 17.11H2.85Q2.5 17.11 2.25 16.86 2 16.61 2 16.26V7.74Q2 7.39 2.25 7.14 2.5 6.89 2.85 6.89H10.1L14.83 2.16Q15 2 15.21 2 15.33 2 15.42 2.05 15.5 2.09 15.59 2.18 15.85 2.44 16.08 2.71 16.3 3 16.5 3.28 18.23 5.55 18.96 8.28 19.14 8.23 19.44 8.14 19.74 8.05 20.06 7.96 20.37 7.87 20.65 7.8 20.92 7.74 21.04 7.74 21.24 7.74 21.38 7.85 21.5 7.97 21.56 8.15 21.68 8.56 21.77 9.05 21.85 9.55 21.91 10.06 21.96 10.57 22 11.08V12M9.82 9.37Q9.82 9.06 9.62 8.85 9.4 8.64 9.1 8.64 8.9 8.64 8.72 8.74 8.55 8.85 8.45 9.03L7.15 11.47L5.89 9.03Q5.77 8.8 5.57 8.72 5.37 8.64 5.13 8.64 4.82 8.64 4.61 8.85 4.4 9.06 4.4 9.36 4.4 9.57 4.5 9.73L6.25 12.87Q6.27 12.91 6.29 12.97 6.3 13.03 6.3 13.08V14.63Q6.3 15 6.56 15.19 6.81 15.36 7.15 15.36 7.39 15.36 7.54 15.27 7.68 15.18 7.76 15.03 7.84 14.88 7.87 14.69 7.9 14.5 7.9 14.28 7.9 14 7.88 13.76 7.86 13.5 7.86 13.28 7.86 13.14 7.87 13.03 7.88 12.93 7.93 12.85L9.73 9.73Q9.83 9.55 9.83 9.37M15.17 3.63L11.8 7Q12 7.12 12.1 7.31 12.22 7.5 12.22 7.74V10.07L17.72 8.61Q17.34 7.19 16.71 6 16.08 4.77 15.17 3.63M17.73 15.42L12.22 13.95V16.26Q12.22 16.5 12.1 16.69 12 16.88 11.8 17L15.18 20.37Q16.07 19.29 16.72 18.04 17.37 16.79 17.73 15.43V15.42M20.47 14.84Q20.6 14.14 20.66 13.43 20.72 12.73 20.72 12 20.72 11.29 20.66 10.59 20.6 9.89 20.47 9.19 18.4 9.74 16.35 10.29 14.3 10.83 12.22 11.39 12.21 11.55 12.21 11.7V12.32L12.22 12.63Q14.3 13.19 16.35 13.73 18.4 14.27 20.47 14.84Z\";\r\nvar mdiMicrowave = \"M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M4,7H16V17H4V7M19,7A1,1 0 0,1 20,8A1,1 0 0,1 19,9A1,1 0 0,1 18,8A1,1 0 0,1 19,7M13,9V15H15V9H13M19,11A1,1 0 0,1 20,12A1,1 0 0,1 19,13A1,1 0 0,1 18,12A1,1 0 0,1 19,11Z\";\r\nvar mdiMicrowaveOff = \"M22.11 21.46L2.39 1.73L1.11 3L3.26 5.15C2.5 5.44 2 6.16 2 7V17C2 18.11 2.9 19 4 19H17.11L20.84 22.73L22.11 21.46M4 17V7H5.11L15.11 17H4M16 7V12.8L21.5 18.31C21.81 17.95 22 17.5 22 17V7C22 5.9 21.11 5 20 5H8.2L10.2 7H16M19 7C19.55 7 20 7.45 20 8S19.55 9 19 9 18 8.55 18 8 18.45 7 19 7M19 11C19.55 11 20 11.45 20 12S19.55 13 19 13 18 12.55 18 12 18.45 11 19 11M13 9.8V9H15V11.8L13 9.8Z\";\r\nvar mdiMiddleware = \"M23 12L19 8V11H14.82C14.4 9.84 13.3 9 12 9S9.6 9.84 9.18 11H5L2 8V16L5 13H9.18C9.6 14.16 10.7 15 12 15S14.4 14.16 14.82 13H19V16L23 12Z\";\r\nvar mdiMiddlewareOutline = \"M23 12L19 8V11H15.86C15.41 9.28 13.86 8 12 8S8.59 9.28 8.14 11H5L2 8V16L5 13H8.14C8.59 14.72 10.14 16 12 16S15.41 14.72 15.86 13H19V16L23 12M12 14C10.9 14 10 13.1 10 12C10 10.9 10.9 10 12 10S14 10.9 14 12C14 13.1 13.1 14 12 14Z\";\r\nvar mdiMidi = \"M20.15 8.26H22V15.74H20.15M13 8.26H18.43C19 8.26 19.3 8.74 19.3 9.3V14.81C19.3 15.5 19 15.74 18.38 15.74H13V11H14.87V13.91H17.5V9.95H13M10.32 8.26H12.14V15.74H10.32M2 8.26H8.55C9.1 8.26 9.41 8.74 9.41 9.3V15.74H7.59V10.15H6.5V15.74H4.87V10.15H3.83V15.74H2Z\";\r\nvar mdiMidiPort = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M20.18,12C20.18,8.18 17.55,4.96 14,4.07V6H10V4.07C6.45,4.96 3.82,8.18 3.82,12A8.18,8.18 0 0,0 12,20.18A8.18,8.18 0 0,0 20.18,12M7,10.64A1.36,1.36 0 0,1 8.36,12A1.36,1.36 0 0,1 7,13.36C6.25,13.36 5.64,12.75 5.64,12C5.64,11.25 6.25,10.64 7,10.64M17,10.64A1.36,1.36 0 0,1 18.36,12A1.36,1.36 0 0,1 17,13.36A1.36,1.36 0 0,1 15.64,12A1.36,1.36 0 0,1 17,10.64M8.36,14.27A1.37,1.37 0 0,1 9.73,15.64C9.73,16.39 9.12,17 8.36,17A1.36,1.36 0 0,1 7,15.64C7,14.88 7.61,14.27 8.36,14.27M15.64,14.27C16.39,14.27 17,14.88 17,15.64A1.36,1.36 0 0,1 15.64,17C14.88,17 14.27,16.39 14.27,15.64A1.37,1.37 0 0,1 15.64,14.27M12,15.64A1.36,1.36 0 0,1 13.36,17A1.36,1.36 0 0,1 12,18.36A1.36,1.36 0 0,1 10.64,17A1.36,1.36 0 0,1 12,15.64Z\";\r\nvar mdiMine = \"M23,13V11H19.93C19.75,9.58 19.19,8.23 18.31,7.1L20.5,4.93L19.07,3.5L16.9,5.69C15.77,4.81 14.42,4.25 13,4.07V1H11V4.07C9.58,4.25 8.23,4.81 7.1,5.69L4.93,3.5L3.5,4.93L5.69,7.1C4.81,8.23 4.25,9.58 4.07,11H1V13H4.07C4.25,14.42 4.81,15.77 5.69,16.9L3.5,19.07L4.93,20.5L7.1,18.31C8.23,19.19 9.58,19.75 11,19.93V23H13V19.93C14.42,19.75 15.77,19.19 16.9,18.31L19.07,20.5L20.5,19.07L18.31,16.9C19.19,15.77 19.75,14.42 19.93,13H23M12,8A4,4 0 0,0 8,12H6A6,6 0 0,1 12,6V8Z\";\r\nvar mdiMinecraft = \"M4,2H20A2,2 0 0,1 22,4V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V4A2,2 0 0,1 4,2M6,6V10H10V12H8V18H10V16H14V18H16V12H14V10H18V6H14V10H10V6H6Z\";\r\nvar mdiMiniSd = \"M6,4A2,2 0 0,0 4,6V18A2,2 0 0,0 6,20H18A2,2 0 0,0 20,18V12L18,10V6A2,2 0 0,0 16,4H6M7,6H9V10H7V6M10,6H12V10H10V6M13,6H15V10H13V6Z\";\r\nvar mdiMinidisc = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H5M12,5C15.09,5 17.82,7.04 18.7,10H16A1,1 0 0,0 15,11V13A1,1 0 0,0 16,14H18.71C17.82,16.97 15.09,19 12,19A7,7 0 0,1 5,12A7,7 0 0,1 12,5M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiMinus = \"M19,13H5V11H19V13Z\";\r\nvar mdiMinusBox = \"M17,13H7V11H17M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiMinusBoxMultiple = \"M19 11H9V9H19M20 2H8C6.9 2 6 2.9 6 4V16C6 17.11 6.9 18 8 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6Z\";\r\nvar mdiMinusBoxMultipleOutline = \"M18 11H10V9H18M20 4V16H8V4H20M20 2H8C6.9 2 6 2.9 6 4V16C6 17.11 6.9 18 8 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6Z\";\r\nvar mdiMinusBoxOutline = \"M19,19V5H5V19H19M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5C3,3.89 3.9,3 5,3H19M17,11V13H7V11H17Z\";\r\nvar mdiMinusCircle = \"M17,13H7V11H17M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiMinusCircleMultiple = \"M2 12C2 9.21 3.64 6.8 6 5.68V3.5C2.5 4.76 0 8.09 0 12S2.5 19.24 6 20.5V18.32C3.64 17.2 2 14.79 2 12M15 3C10.04 3 6 7.04 6 12S10.04 21 15 21 24 16.96 24 12 19.96 3 15 3M20 13H10V11H20V13Z\";\r\nvar mdiMinusCircleMultipleOutline = \"M11 11V13H19V11H11M2 12C2 9.21 3.64 6.8 6 5.68V3.5C2.5 4.76 0 8.09 0 12S2.5 19.24 6 20.5V18.32C3.64 17.2 2 14.79 2 12M15 3C10.04 3 6 7.04 6 12S10.04 21 15 21 24 16.96 24 12 19.96 3 15 3M15 19C11.14 19 8 15.86 8 12S11.14 5 15 5 22 8.14 22 12 18.86 19 15 19Z\";\r\nvar mdiMinusCircleOff = \"M22.1 21.5L2.4 1.7L1.1 3L4.1 6C2.8 7.6 2 9.7 2 12C2 17.5 6.5 22 12 22C14.3 22 16.4 21.2 18 19.9L20.8 22.7L22.1 21.5M7 13V11H9.1L11.1 13H7M14.2 11L6.7 3.5C8.3 2.6 10.1 2 12 2C17.5 2 22 6.5 22 12C22 13.9 21.4 15.7 20.5 17.3L16.2 13H17V11H14.2Z\";\r\nvar mdiMinusCircleOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L4.1 6C2.8 7.6 2 9.7 2 12C2 17.5 6.5 22 12 22C14.3 22 16.4 21.2 18 19.9L20.8 22.7L22.1 21.5M12 20C7.6 20 4 16.4 4 12C4 10.3 4.6 8.7 5.5 7.4L9.1 11H7V13H11.1L16.6 18.5C15.3 19.4 13.7 20 12 20M8.2 5L6.7 3.5C8.3 2.6 10.1 2 12 2C17.5 2 22 6.5 22 12C22 13.9 21.4 15.7 20.5 17.3L19 15.8C19.6 14.7 20 13.4 20 12C20 7.6 16.4 4 12 4C10.6 4 9.3 4.4 8.2 5M16.2 13L14.2 11H17V13H16.2Z\";\r\nvar mdiMinusCircleOutline = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M7,13H17V11H7\";\r\nvar mdiMinusNetwork = \"M16,11V9H8V11H16M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17Z\";\r\nvar mdiMinusNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M15,11V9H9V11H15\";\r\nvar mdiMirror = \"M12 1C16.69 1 20.5 5.93 20.5 12C20.5 18.08 16.69 23 12 23C7.31 23 3.5 18.08 3.5 12C3.5 5.93 7.31 1 12 1M12 3C8.41 3 5.5 7.03 5.5 12C5.5 16.97 8.41 21 12 21C15.59 21 18.5 16.97 18.5 12C18.5 7.03 15.59 3 12 3M8.29 10.28L11.53 7.03L12.59 8.09L9.35 11.34L8.29 10.28M8.7 14.61L14.36 8.95L15.42 10L9.76 15.67L8.7 14.61Z\";\r\nvar mdiMixedMartialArts = \"M15,10V7H7V10H15M18,7C18.28,7 18.5,7.09 18.7,7.29C18.89,7.5 19,7.73 19,8V10.78C19,10.97 18.97,11.11 18.94,11.2L18.14,15.19C18,15.72 17.7,16 17.2,16H6.8C6.27,16 5.95,15.72 5.86,15.19L5.06,11.2C5.03,11.11 5,10.97 5,10.78V5C5,4.5 5.21,4 5.6,3.61C6,3.2 6.45,3 7,3H15C15.53,3 16,3.2 16.41,3.61C16.81,4 17,4.5 17,5V8C17,7.73 17.11,7.5 17.3,7.29C17.5,7.09 17.72,7 18,7M7,20V17H17V20C17,20.3 16.91,20.53 16.71,20.72C16.5,20.91 16.27,21 16,21H8C7.73,21 7.5,20.91 7.29,20.72C7.09,20.53 7,20.3 7,20Z\";\r\nvar mdiMixedReality = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3M8.25,15H9.75L10.75,11.57V15H12.25V9H10L9,12.43L8,9H5.75V15H7.25V11.57L8.25,15M13.5,9V15H15V13H16.15L17,15H18.5L17.6,12.9C18.1,12.65 18.5,12.1 18.5,11.5V10.5C18.5,9.65 17.85,9 17,9H13.5M15,10.5H17V11.5H15V10.5Z\";\r\nvar mdiMolecule = \"M7.27,10L9,7H14.42L15.58,5L15.5,4.5A1.5,1.5 0 0,1 17,3A1.5,1.5 0 0,1 18.5,4.5C18.5,5.21 18,5.81 17.33,5.96L16.37,7.63L17.73,10L18.59,8.5L18.5,8A1.5,1.5 0 0,1 20,6.5A1.5,1.5 0 0,1 21.5,8C21.5,8.71 21,9.3 20.35,9.46L18.89,12L20.62,15C21.39,15.07 22,15.71 22,16.5A1.5,1.5 0 0,1 20.5,18A1.5,1.5 0 0,1 19,16.5V16.24L17.73,14L16.37,16.37L17.33,18.04C18,18.19 18.5,18.79 18.5,19.5A1.5,1.5 0 0,1 17,21A1.5,1.5 0 0,1 15.5,19.5L15.58,19L14.42,17H10.58L9.42,19L9.5,19.5A1.5,1.5 0 0,1 8,21A1.5,1.5 0 0,1 6.5,19.5C6.5,18.79 7,18.19 7.67,18.04L8.63,16.37L4.38,9C3.61,8.93 3,8.29 3,7.5A1.5,1.5 0 0,1 4.5,6A1.5,1.5 0 0,1 6,7.5C6,7.59 6,7.68 6,7.76L7.27,10M10.15,9L8.42,12L10.15,15H14.85L16.58,12L14.85,9H10.15Z\";\r\nvar mdiMoleculeCo = \"M8 7C6.9 7 6 7.9 6 9V15C6 16.11 6.9 17 8 17H11V15H8V9H11V7H8M14 7C12.9 7 12 7.9 12 9V15C12 16.11 12.9 17 14 17H16C17.11 17 18 16.11 18 15V9C18 7.9 17.11 7 16 7H14M14 9H16V15H14V9\";\r\nvar mdiMoleculeCo2 = \"M5,7A2,2 0 0,0 3,9V15A2,2 0 0,0 5,17H8V15H5V9H8V7H5M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M16,10.5V12H19V13.5H17.5A1.5,1.5 0 0,0 16,15V18H20.5V16.5H17.5V15H19A1.5,1.5 0 0,0 20.5,13.5V12A1.5,1.5 0 0,0 19,10.5H16Z\";\r\nvar mdiMonitor = \"M21,16H3V4H21M21,2H3C1.89,2 1,2.89 1,4V16A2,2 0 0,0 3,18H10V20H8V22H16V20H14V18H21A2,2 0 0,0 23,16V4C23,2.89 22.1,2 21,2Z\";\r\nvar mdiMonitorCellphone = \"M23,11H18A1,1 0 0,0 17,12V21A1,1 0 0,0 18,22H23A1,1 0 0,0 24,21V12A1,1 0 0,0 23,11M23,20H18V13H23V20M20,2H2C0.89,2 0,2.89 0,4V16A2,2 0 0,0 2,18H9V20H7V22H15V20H13V18H15V16H2V4H20V9H22V4C22,2.89 21.1,2 20,2Z\";\r\nvar mdiMonitorCellphoneStar = \"M23,11H18A1,1 0 0,0 17,12V21A1,1 0 0,0 18,22H23A1,1 0 0,0 24,21V12A1,1 0 0,0 23,11M23,20H18V13H23V20M20,2H2C0.89,2 0,2.89 0,4V16A2,2 0 0,0 2,18H9V20H7V22H15V20H13V18H15V16H2V4H20V9H22V4C22,2.89 21.1,2 20,2M11.97,9L11,6L10.03,9H7L9.47,10.76L8.53,13.67L11,11.87L13.47,13.67L12.53,10.76L15,9H11.97Z\";\r\nvar mdiMonitorClean = \"M21 16H3V4H21M21 2H3C1.89 2 1 2.89 1 4V16C1 17.11 1.9 18 3 18H10V20H8V22H16V20H14V18H21C22.11 18 23 17.11 23 16V4C23 2.89 22.1 2 21 2M15 5.5L14.38 6.87L13 7.5L14.38 8.13L15 9.5L15.63 8.13L17 7.5L15.63 6.87L15 5.5M10.5 7.5L9.41 9.91L7 11L9.41 12.09L10.5 14.5L11.6 12.09L14 11L11.6 9.91L10.5 7.5\";\r\nvar mdiMonitorDashboard = \"M21,16V4H3V16H21M21,2A2,2 0 0,1 23,4V16A2,2 0 0,1 21,18H14V20H16V22H8V20H10V18H3C1.89,18 1,17.1 1,16V4C1,2.89 1.89,2 3,2H21M5,6H14V11H5V6M15,6H19V8H15V6M19,9V14H15V9H19M5,12H9V14H5V12M10,12H14V14H10V12Z\";\r\nvar mdiMonitorEdit = \"M21 2H3C1.9 2 1 2.9 1 4V16C1 17.11 1.9 18 3 18H10V20H8V22H16V20H14V18H21C22.11 18 23 17.11 23 16V4C23 2.9 22.11 2 21 2M21 16H3V4H21V16M15.84 8.2L14.83 9.21L12.76 7.18L13.77 6.16C13.97 5.95 14.31 5.94 14.55 6.16L15.84 7.41C16.05 7.62 16.06 7.96 15.84 8.2M8 11.91L12.17 7.72L14.24 9.8L10.08 14H8V11.91Z\";\r\nvar mdiMonitorEye = \"M3 4V16H21V4H3M3 2H21C22.1 2 23 2.89 23 4V16C23 16.53 22.79 17.04 22.41 17.41C22.04 17.79 21.53 18 21 18H14V20H16V22H8V20H10V18H3C2.47 18 1.96 17.79 1.59 17.41C1.21 17.04 1 16.53 1 16V4C1 2.89 1.89 2 3 2M10.84 8.93C11.15 8.63 11.57 8.45 12 8.45C12.43 8.46 12.85 8.63 13.16 8.94C13.46 9.24 13.64 9.66 13.64 10.09C13.64 10.53 13.46 10.94 13.16 11.25C12.85 11.56 12.43 11.73 12 11.73C11.57 11.73 11.15 11.55 10.84 11.25C10.54 10.94 10.36 10.53 10.36 10.09C10.36 9.66 10.54 9.24 10.84 8.93M10.07 12C10.58 12.53 11.28 12.82 12 12.82C12.72 12.82 13.42 12.53 13.93 12C14.44 11.5 14.73 10.81 14.73 10.09C14.73 9.37 14.44 8.67 13.93 8.16C13.42 7.65 12.72 7.36 12 7.36C11.28 7.36 10.58 7.65 10.07 8.16C9.56 8.67 9.27 9.37 9.27 10.09C9.27 10.81 9.56 11.5 10.07 12M6 10.09C6.94 7.7 9.27 6 12 6C14.73 6 17.06 7.7 18 10.09C17.06 12.5 14.73 14.18 12 14.18C9.27 14.18 6.94 12.5 6 10.09Z\";\r\nvar mdiMonitorLock = \"M20.5,13A2.5,2.5 0 0,1 23,15.5V16A1,1 0 0,1 24,17V21A1,1 0 0,1 23,22H18A1,1 0 0,1 17,21V17A1,1 0 0,1 18,16V15.5A2.5,2.5 0 0,1 20.5,13M20.5,14A1.5,1.5 0 0,0 19,15.5V16H22V15.5A1.5,1.5 0 0,0 20.5,14M20,4H2V16H15V18H13V20H15V22H7V20H9V18H2C0.89,18 0,17.1 0,16V4C0,2.89 0.89,2 2,2H20A2,2 0 0,1 22,4V11.53C21.41,11.19 20.73,11 20,11V4Z\";\r\nvar mdiMonitorMultiple = \"M22,17V7H6V17H22M22,5A2,2 0 0,1 24,7V17C24,18.11 23.1,19 22,19H16V21H18V23H10V21H12V19H6C4.89,19 4,18.11 4,17V7A2,2 0 0,1 6,5H22M2,3V15H0V3A2,2 0 0,1 2,1H20V3H2Z\";\r\nvar mdiMonitorOff = \"M14,18V20H16V22H8V20H10V18H3A2,2 0 0,1 1,16V4L0,3L1.41,1.58L22.16,22.34L20.75,23.75L15,18H14M3,16H13L3,6V16M21,2A2,2 0 0,1 23,4V16A2,2 0 0,1 21,18H20.66L18.66,16H21V4H6.66L4.66,2H21Z\";\r\nvar mdiMonitorScreenshot = \"M9,6H5V10H7V8H9M19,10H17V12H15V14H19M21,16H3V4H21M21,2H3C1.89,2 1,2.89 1,4V16A2,2 0 0,0 3,18H10V20H8V22H16V20H14V18H21A2,2 0 0,0 23,16V4C23,2.89 22.1,2 21,2\";\r\nvar mdiMonitorShare = \"M23 4V16C23 17.11 22.11 18 21 18H15V16H21V4H3V16H9V18H3C1.9 18 1 17.11 1 16V4C1 2.89 1.89 2 3 2H21C22.1 2 23 2.89 23 4M13 13H16L12 9L8 13H11V20H8V22H16V20H13V13Z\";\r\nvar mdiMonitorSpeaker = \"M10 20V18H3C1.9 18 1 17.1 1 16V4C1 2.89 1.89 2 3 2H21C22.1 2 23 2.89 23 4V8H21V4H3V16H12V22H8V20H10M18.5 15C17.12 15 16 16.12 16 17.5S17.12 20 18.5 20 21 18.88 21 17.5 19.88 15 18.5 15M23 10V21C23 21.55 22.55 22 22 22H15C14.45 22 14 21.55 14 21V10C14 9.45 14.45 9 15 9H22C22.55 9 23 9.45 23 10M17 11.5C17 12.33 17.67 13 18.5 13S20 12.33 20 11.5 19.33 10 18.5 10 17 10.67 17 11.5M22 17.5C22 15.57 20.43 14 18.5 14S15 15.57 15 17.5 16.57 21 18.5 21 22 19.43 22 17.5Z\";\r\nvar mdiMonitorSpeakerOff = \"M23.1 22.5L1.4.7.1 2L1.2 3.1C1.1 3.4 1 3.7 1 4V16C1 17.1 1.9 18 3 18H10V20H8V22H12V16H3V4.9L14 15.9V21C14 21.6 14.5 22 15 22H20.1L21.8 23.7L23.1 22.5M18.5 21C16.6 21 15 19.4 15 17.5C15 17.3 15 17.1 15.1 16.9L16.1 17.9C16.3 18.9 17.1 19.7 18.1 19.9L19.1 20.9C18.9 21 18.7 21 18.5 21M21 17.5V17.8L18.2 15H18.5C19.9 15 21 16.1 21 17.5M23 19.8V10C23 9.4 22.5 9 22 9H15C14.4 9 14 9.5 14 10V10.8L17.4 14.2C17.7 14.1 18.1 14 18.5 14C20.4 14 22 15.6 22 17.5C22 17.9 21.9 18.3 21.8 18.6L23 19.8M18.5 13C17.7 13 17 12.3 17 11.5S17.7 10 18.5 10 20 10.7 20 11.5 19.3 13 18.5 13M7.2 4L5.2 2H21C22.1 2 23 2.9 23 4V8H21V4H7.2Z\";\r\nvar mdiMonitorStar = \"M21,16V4H3V16H21M21,2A2,2 0 0,1 23,4V16A2,2 0 0,1 21,18H14V20H16V22H8V20H10V18H3C1.89,18 1,17.1 1,16V4C1,2.89 1.89,2 3,2H21M12.97,9H16L13.53,10.76L14.47,13.67L12,11.87L9.53,13.67L10.47,10.76L8,9H11.03L12,6L12.97,9Z\";\r\nvar mdiMoonFirstQuarter = \"M12 2V22A10 10 0 0 0 12 2Z\";\r\nvar mdiMoonFull = \"M12 2A10 10 0 1 1 2 12A10 10 0 0 1 12 2Z\";\r\nvar mdiMoonLastQuarter = \"M12 2A10 10 0 0 0 12 22Z\";\r\nvar mdiMoonNew = \"M12 20A8 8 0 1 1 20 12A8 8 0 0 1 12 20M12 2A10 10 0 1 0 22 12A10 10 0 0 0 12 2Z\";\r\nvar mdiMoonWaningCrescent = \"M2 12A10 10 0 0 0 15 21.54A10 10 0 0 1 15 2.46A10 10 0 0 0 2 12Z\";\r\nvar mdiMoonWaningGibbous = \"M18 12C18 7.5 16.08 3.26 12 2A10 10 0 0 0 12 22C16.08 20.74 18 16.5 18 12Z\";\r\nvar mdiMoonWaxingCrescent = \"M12 2A9.91 9.91 0 0 0 9 2.46A10 10 0 0 1 9 21.54A10 10 0 1 0 12 2Z\";\r\nvar mdiMoonWaxingGibbous = \"M6 12C6 7.5 7.93 3.26 12 2A10 10 0 0 1 12 22C7.93 20.74 6 16.5 6 12Z\";\r\nvar mdiMoped = \"M19 15C19.55 15 20 15.45 20 16C20 16.55 19.55 17 19 17S18 16.55 18 16C18 15.45 18.45 15 19 15M19 13C17.34 13 16 14.34 16 16S17.34 19 19 19 22 17.66 22 16 20.66 13 19 13M10 6H5V8H10V6M17 5H14V7H17V9.65L13.5 14H10V9H6C3.79 9 2 10.79 2 13V16H4C4 17.66 5.34 19 7 19S10 17.66 10 16H14.5L19 10.35V7C19 5.9 18.11 5 17 5M7 17C6.45 17 6 16.55 6 16H8C8 16.55 7.55 17 7 17Z\";\r\nvar mdiMopedElectric = \"M19 5C19 3.9 18.1 3 17 3H14V5H17V7.65L13.5 12H10V7H6C3.79 7 2 8.79 2 11V14H4C4 15.66 5.34 17 7 17S10 15.66 10 14H14.5L19 8.35V5M7 15C6.45 15 6 14.55 6 14H8C8 14.55 7.55 15 7 15M5 4H10V6H5V4M19 11C17.34 11 16 12.34 16 14S17.34 17 19 17 22 15.66 22 14 20.66 11 19 11M19 15C18.45 15 18 14.55 18 14S18.45 13 19 13 20 13.45 20 14 19.55 15 19 15M7 20H11V18L17 21H13V23L7 20Z\";\r\nvar mdiMopedElectricOutline = \"M19 5C19 3.9 18.1 3 17 3H14V5H17V7.65L13.5 12H10V7H6C3.79 7 2 8.79 2 11V14H4C4 15.66 5.34 17 7 17S10 15.66 10 14H14.5L19 8.35V5M4 12V11C4 9.9 4.9 9 6 9H8V12H4M7 15C6.45 15 6 14.55 6 14H8C8 14.55 7.55 15 7 15M5 4H10V6H5V4M19 11C17.34 11 16 12.34 16 14S17.34 17 19 17 22 15.66 22 14 20.66 11 19 11M19 15C18.45 15 18 14.55 18 14S18.45 13 19 13 20 13.45 20 14 19.55 15 19 15M7 20H11V18L17 21H13V23L7 20Z\";\r\nvar mdiMopedOutline = \"M19 7C19 5.9 18.11 5 17 5H14V7H17V9.65L13.5 14H10V9H6C3.79 9 2 10.79 2 13V16H4C4 17.66 5.34 19 7 19S10 17.66 10 16H14.5L19 10.35V7M7 17C6.45 17 6 16.55 6 16H8C8 16.55 7.55 17 7 17M8 14H4V13C4 11.9 4.9 11 6 11H8V14M19 13C17.34 13 16 14.34 16 16S17.34 19 19 19 22 17.66 22 16 20.66 13 19 13M19 17C18.45 17 18 16.55 18 16S18.45 15 19 15 20 15.45 20 16 19.55 17 19 17M10 8H5V6H10V8Z\";\r\nvar mdiMore = \"M19,13.5A1.5,1.5 0 0,1 17.5,12A1.5,1.5 0 0,1 19,10.5A1.5,1.5 0 0,1 20.5,12A1.5,1.5 0 0,1 19,13.5M14,13.5A1.5,1.5 0 0,1 12.5,12A1.5,1.5 0 0,1 14,10.5A1.5,1.5 0 0,1 15.5,12A1.5,1.5 0 0,1 14,13.5M9,13.5A1.5,1.5 0 0,1 7.5,12A1.5,1.5 0 0,1 9,10.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 9,13.5M22,3H7C6.31,3 5.77,3.35 5.41,3.88L0,12L5.41,20.11C5.77,20.64 6.37,21 7.06,21H22A2,2 0 0,0 24,19V5C24,3.89 23.1,3 22,3Z\";\r\nvar mdiMotherHeart = \"M12 2C13.66 2 15 3.34 15 5S13.66 8 12 8 9 6.66 9 5 10.34 2 12 2M20 18L18 12.56C17.65 11.57 17.34 10.71 16 10C14.63 9.3 13.63 9 12 9C10.39 9 9.39 9.3 8 10C6.68 10.71 6.37 11.57 6 12.56L4 18C3.77 19.13 6.38 20.44 8.13 21.19C9.34 21.72 10.64 22 12 22C13.38 22 14.67 21.72 15.89 21.19C17.64 20.44 20.25 19.13 20 18M15.42 17.5L12 21L8.58 17.5C8.22 17.12 8 16.61 8 16.05C8 14.92 8.9 14 10 14C10.55 14 11.06 14.23 11.42 14.61L12 15.2L12.58 14.6C12.94 14.23 13.45 14 14 14C15.11 14 16 14.92 16 16.05C16 16.61 15.78 17.13 15.42 17.5Z\";\r\nvar mdiMotherNurse = \"M12,2A3,3 0 0,1 15,5A3,3 0 0,1 12,8A3,3 0 0,1 9,5A3,3 0 0,1 12,2M20,18L18,12.56C17.65,11.57 17.34,10.71 16,10C14.62,9.3 13.62,9 12,9C10.37,9 9.38,9.3 8,10C6.66,10.71 6.35,11.57 6,12.56L4,18C3.68,19.35 6.36,20.44 8.11,21.19V19C8.11,18.05 8.97,17.38 10.69,16.97C10.85,16.93 11,16.91 11.12,16.89C10.58,16.07 10.36,15.34 10.34,15.28L12.11,14.68C12.12,14.7 12.63,16.27 13.84,17.06C14.05,17.13 14.26,17.21 14.46,17.3C15.23,17.64 15.69,18.08 15.84,18.61C14.5,19.14 13.22,19.41 12,19.41L11,19.31V21.94L12,22C13.37,22 14.67,21.72 15.89,21.19C17.64,20.44 20.25,19.13 20,18M15.5,17A1.5,1.5 0 0,1 14,15.5A1.5,1.5 0 0,1 15.5,14A1.5,1.5 0 0,1 17,15.5A1.5,1.5 0 0,1 15.5,17Z\";\r\nvar mdiMotion = \"M7 13H3C2.45 13 2 12.55 2 12S2.45 11 3 11H7C7.55 11 8 11.45 8 12S7.55 13 7 13M6 8C6 7.45 5.55 7 5 7H4C3.45 7 3 7.45 3 8S3.45 9 4 9H5C5.55 9 6 8.55 6 8M22 12C22 14.76 19.76 17 17 17H4C3.45 17 3 16.55 3 16S3.45 15 4 15H13C12.58 14.42 12.25 13.74 12.1 13H10C9.45 13 9 12.55 9 12S9.45 11 10 11H12.1C12.25 10.26 12.58 9.58 13 9H8C7.45 9 7 8.55 7 8S7.45 7 8 7H17C19.76 7 22 9.24 22 12Z\";\r\nvar mdiMotionOutline = \"M7 13H3C2.45 13 2 12.55 2 12S2.45 11 3 11H7C7.55 11 8 11.45 8 12S7.55 13 7 13M6 8C6 7.45 5.55 7 5 7H4C3.45 7 3 7.45 3 8S3.45 9 4 9H5C5.55 9 6 8.55 6 8M22 12C22 14.76 19.76 17 17 17H4C3.45 17 3 16.55 3 16S3.45 15 4 15H13C12.58 14.42 12.25 13.74 12.1 13H10C9.45 13 9 12.55 9 12S9.45 11 10 11H12.1C12.25 10.26 12.58 9.58 13 9H8C7.45 9 7 8.55 7 8S7.45 7 8 7H17C19.76 7 22 9.24 22 12M20 12C20 10.35 18.65 9 17 9S14 10.35 14 12C14 13.65 15.35 15 17 15S20 13.65 20 12Z\";\r\nvar mdiMotionPause = \"M22 12C22 6.46 17.54 2 12 2C10.83 2 9.7 2.19 8.62 2.56L9.32 4.5C10.17 4.16 11.06 3.97 12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 11.06 4.16 10.12 4.5 9.28L2.56 8.62C2.19 9.7 2 10.83 2 12C2 17.54 6.46 22 12 22C17.54 22 22 17.54 22 12M5.47 3.97C6.32 3.97 7 4.68 7 5.47C7 6.32 6.32 7 5.47 7C4.68 7 3.97 6.32 3.97 5.47C3.97 4.68 4.68 3.97 5.47 3.97M18 12C18 8.67 15.33 6 12 6C8.67 6 6 8.67 6 12C6 15.33 8.67 18 12 18C15.33 18 18 15.33 18 12M11 9V15H9V9M15 9V15H13V9\";\r\nvar mdiMotionPauseOutline = \"M22 12C22 6.46 17.54 2 12 2C10.83 2 9.7 2.19 8.62 2.56L9.32 4.5C10.17 4.16 11.06 3.97 12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 11.06 4.16 10.12 4.5 9.28L2.56 8.62C2.19 9.7 2 10.83 2 12C2 17.54 6.46 22 12 22C17.54 22 22 17.54 22 12M5.47 7C4.68 7 3.97 6.32 3.97 5.47C3.97 4.68 4.68 3.97 5.47 3.97C6.32 3.97 7 4.68 7 5.47C7 6.32 6.32 7 5.47 7M9 9H11V15H9M13 9H15V15H13\";\r\nvar mdiMotionPlay = \"M22 12C22 6.46 17.54 2 12 2C10.83 2 9.7 2.19 8.62 2.56L9.32 4.5C10.17 4.16 11.06 3.97 12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 11.06 4.16 10.12 4.5 9.28L2.56 8.62C2.19 9.7 2 10.83 2 12C2 17.54 6.46 22 12 22C17.54 22 22 17.54 22 12M5.47 3.97C6.32 3.97 7 4.68 7 5.47C7 6.32 6.32 7 5.47 7C4.68 7 3.97 6.32 3.97 5.47C3.97 4.68 4.68 3.97 5.47 3.97M18 12C18 8.67 15.33 6 12 6C8.67 6 6 8.67 6 12C6 15.33 8.67 18 12 18C15.33 18 18 15.33 18 12M15 12L10 15V9\";\r\nvar mdiMotionPlayOutline = \"M10 16.5L16 12L10 7.5M22 12C22 6.46 17.54 2 12 2C10.83 2 9.7 2.19 8.62 2.56L9.32 4.5C10.17 4.16 11.06 3.97 12 3.97C16.41 3.97 20.03 7.59 20.03 12C20.03 16.41 16.41 20.03 12 20.03C7.59 20.03 3.97 16.41 3.97 12C3.97 11.06 4.16 10.12 4.5 9.28L2.56 8.62C2.19 9.7 2 10.83 2 12C2 17.54 6.46 22 12 22C17.54 22 22 17.54 22 12M5.47 3.97C6.32 3.97 7 4.68 7 5.47C7 6.32 6.32 7 5.47 7C4.68 7 3.97 6.32 3.97 5.47C3.97 4.68 4.68 3.97 5.47 3.97Z\";\r\nvar mdiMotionSensor = \"M10,0.2C9,0.2 8.2,1 8.2,2C8.2,3 9,3.8 10,3.8C11,3.8 11.8,3 11.8,2C11.8,1 11,0.2 10,0.2M15.67,1A7.33,7.33 0 0,0 23,8.33V7A6,6 0 0,1 17,1H15.67M18.33,1C18.33,3.58 20.42,5.67 23,5.67V4.33C21.16,4.33 19.67,2.84 19.67,1H18.33M21,1A2,2 0 0,0 23,3V1H21M7.92,4.03C7.75,4.03 7.58,4.06 7.42,4.11L2,5.8V11H3.8V7.33L5.91,6.67L2,22H3.8L6.67,13.89L9,17V22H10.8V15.59L8.31,11.05L9.04,8.18L10.12,10H15V8.2H11.38L9.38,4.87C9.08,4.37 8.54,4.03 7.92,4.03Z\";\r\nvar mdiMotionSensorOff = \"M11.4 8.2H15V10H13.2L11.4 8.2M19.67 1H18.33C18.33 3.58 20.42 5.67 23 5.67V4.33C21.16 4.33 19.67 2.84 19.67 1M21 1C21 2.11 21.9 3 23 3V1H21M17 1H15.67C15.67 5.05 18.95 8.33 23 8.33V7C19.69 7 17 4.31 17 1M10 3.8C11 3.8 11.8 3 11.8 2S11 .2 10 .2 8.2 1 8.2 2 9 3.8 10 3.8M2.39 1.73L1.11 3L3.46 5.35L2 5.8V11H3.8V7.33L5.05 6.94L5.68 7.57L2 22H3.8L6.67 13.89L9 17V22H10.8V15.59L8.31 11.05L8.5 10.37L20.84 22.73L22.11 21.46L2.39 1.73M9.38 4.87C9.08 4.37 8.54 4.03 7.92 4.03C7.75 4.03 7.58 4.06 7.42 4.11L7.34 4.14L11.35 8.15L9.38 4.87Z\";\r\nvar mdiMotorbike = \"M17.42,10L13.41,6H9V8H12.59L14.59,10H6.5C4,10 2,12 2,14.5C2,17 4,19 6.5,19C8.72,19 10.56,17.38 10.92,15.27L13.04,14C13,14.17 13,14.33 13,14.5C13,17 15,19 17.5,19C20,19 22,17 22,14.5C22,12 20,10 17.5,10M8.84,15.26C8.5,16.27 7.58,17 6.47,17C5.09,17 3.97,15.88 3.97,14.5C3.97,13.12 5.09,12 6.47,12C7.59,12 8.5,12.74 8.84,13.75H6V15.25L8.84,15.26M17.47,17C16.09,17 14.97,15.88 14.97,14.5C14.97,13.12 16.09,12 17.47,12A2.5,2.5 0 0,1 19.97,14.5A2.5,2.5 0 0,1 17.47,17Z\";\r\nvar mdiMotorbikeElectric = \"M17.42 8L13.41 4H9V6H12.59L14.59 8H6.5C4 8 2 10 2 12.5S4 17 6.5 17C8.72 17 10.56 15.38 10.92 13.27L13.04 12C13 12.17 13 12.33 13 12.5C13 15 15 17 17.5 17S22 15 22 12.5 20 8 17.5 8M8.84 13.26C8.5 14.27 7.58 15 6.47 15C5.09 15 3.97 13.88 3.97 12.5S5.09 10 6.47 10C7.59 10 8.5 10.74 8.84 11.75H6V13.25L8.84 13.26M17.47 15C16.09 15 14.97 13.88 14.97 12.5S16.09 10 17.47 10C18.85 10 19.97 11.12 19.97 12.5S18.85 15 17.47 15M11 20H7L13 23V21H17L11 18V20Z\";\r\nvar mdiMouse = \"M11,1.07C7.05,1.56 4,4.92 4,9H11M4,15A8,8 0 0,0 12,23A8,8 0 0,0 20,15V11H4M13,1.07V9H20C20,4.92 16.94,1.56 13,1.07Z\";\r\nvar mdiMouseBluetooth = \"M20,7H20.5L23.35,9.85L21.21,12L23.35,14.14L20.5,17H20V13.21L17.71,15.5L17,14.79L19.79,12L17,9.21L17.71,8.5L20,10.79V7M21,8.91V10.79L21.94,9.85L21,8.91M21,13.21V15.08L21.94,14.14L21,13.21M15,9V10H9V2.07C12.39,2.56 15,5.47 15,9M1,10V9C1,5.47 3.61,2.56 7,2.07V10H1M15,15A7,7 0 0,1 8,22A7,7 0 0,1 1,15V12H15V15Z\";\r\nvar mdiMouseMoveDown = \"M7 9H2C2 6.04 4.17 3.57 7 3.09V9M20 7H18V13H15L19 17L23 13H20V7M9 3.09V9H14C14 6.04 11.83 3.57 9 3.09M2 15C2 18.3 4.7 21 8 21S14 18.3 14 15V11H2V15Z\";\r\nvar mdiMouseMoveUp = \"M7 9H2C2 6.04 4.17 3.57 7 3.09V9M18 17H20V11H23L19 7L15 11H18V17M9 3.09V9H14C14 6.04 11.83 3.57 9 3.09M2 15C2 18.3 4.7 21 8 21S14 18.3 14 15V11H2V15Z\";\r\nvar mdiMouseMoveVertical = \"M20 6H23L19 2L15 6H18V18H15L19 22L23 18H20V6M9 3.09C11.83 3.57 14 6.04 14 9H9V3.09M14 11V15C14 18.3 11.3 21 8 21S2 18.3 2 15V11H14M7 9H2C2 6.04 4.17 3.57 7 3.09V9Z\";\r\nvar mdiMouseOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L17.5,20.79C16.08,22.16 14.14,23 12,23A8,8 0 0,1 4,15V11H7.73L5.73,9H4C4,8.46 4.05,7.93 4.15,7.42L2,5.27M11,1.07V9H10.82L5.79,3.96C7.05,2.4 8.9,1.33 11,1.07M20,11V15C20,15.95 19.83,16.86 19.53,17.71L12.82,11H20M13,1.07C16.94,1.56 20,4.92 20,9H13V1.07Z\";\r\nvar mdiMouseVariant = \"M14,7H10V2.1C12.28,2.56 14,4.58 14,7M4,7C4,4.58 5.72,2.56 8,2.1V7H4M14,12C14,14.42 12.28,16.44 10,16.9V18A3,3 0 0,0 13,21A3,3 0 0,0 16,18V13A4,4 0 0,1 20,9H22L21,10L22,11H20A2,2 0 0,0 18,13H18V18A5,5 0 0,1 13,23A5,5 0 0,1 8,18V16.9C5.72,16.44 4,14.42 4,12V9H14V12Z\";\r\nvar mdiMouseVariantOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L17.29,20.56C16.42,22 14.82,23 13,23A5,5 0 0,1 8,18V16.9C5.72,16.44 4,14.42 4,12V9H5.73L2,5.27M14,7H10V2.1C12.28,2.56 14,4.58 14,7M8,2.1V6.18L5.38,3.55C6.07,2.83 7,2.31 8,2.1M14,12V12.17L10.82,9H14V12M10,16.9V18A3,3 0 0,0 13,21C14.28,21 15.37,20.2 15.8,19.07L12.4,15.67C11.74,16.28 10.92,16.71 10,16.9M16,13A4,4 0 0,1 20,9H22L21,10L22,11H20A2,2 0 0,0 18,13V16.18L16,14.18V13Z\";\r\nvar mdiMoveResize = \"M9,1V2H10V5H9V6H12V5H11V2H12V1M9,7C7.89,7 7,7.89 7,9V21C7,22.11 7.89,23 9,23H21C22.11,23 23,22.11 23,21V9C23,7.89 22.11,7 21,7M1,9V12H2V11H5V12H6V9H5V10H2V9M9,9H21V21H9M14,10V11H15V16H11V15H10V18H11V17H15V19H14V20H17V19H16V17H19V18H20V15H19V16H16V11H17V10\";\r\nvar mdiMoveResizeVariant = \"M1.88,0.46L0.46,1.88L5.59,7H2V9H9V2H7V5.59M11,7V9H21V15H23V9A2,2 0 0,0 21,7M7,11V21A2,2 0 0,0 9,23H15V21H9V11M15.88,14.46L14.46,15.88L19.6,21H17V23H23V17H21V19.59\";\r\nvar mdiMovie = \"M18,4L20,8H17L15,4H13L15,8H12L10,4H8L10,8H7L5,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V4H18Z\";\r\nvar mdiMovieEdit = \"M21.04 11.13C20.9 11.13 20.76 11.19 20.65 11.3L19.65 12.3L21.7 14.35L22.7 13.35C22.92 13.14 22.92 12.79 22.7 12.58L21.42 11.3C21.31 11.19 21.18 11.13 21.04 11.13M19.07 12.88L13 18.94V21H15.06L21.12 14.93L19.07 12.88M11 20H3C1.9 20 1 19.11 1 18V6C1 4.89 1.9 4 3 4H4L6 8H9L7 4H9L11 8H14L12 4H14L16 8H19L17 4H21V8.12L11 18.11V20Z\";\r\nvar mdiMovieEditOutline = \"M21 4V8.12L19.12 10H4.76L3 6.47V18H11V20H3C1.9 20 1 19.11 1 18V6C1 4.89 1.9 4 3 4H4L6 8H9L7 4H9L11 8H14L12 4H14L16 8H19L17 4H21M21.42 12.3L22.7 13.58C22.92 13.79 22.92 14.14 22.7 14.35L21.7 15.35L19.65 13.3L20.65 12.3C20.76 12.19 20.9 12.13 21.04 12.13C21.18 12.13 21.31 12.19 21.42 12.3M21.12 15.93L15.06 22H13V19.94L19.07 13.88L21.12 15.93Z\";\r\nvar mdiMovieFilter = \"M18 4L20 7H17L15 4H13L15 7H12L10 4H8L10 7H7L5 4H4C2.9 4 2 4.9 2 6L2 18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V4H18M11.25 15.25L10 18L8.75 15.25L6 14L8.75 12.75L10 10L11.25 12.75L14 14L11.25 15.25M16.94 11.94L16 14L15.06 11.94L13 11L15.06 10.06L16 8L16.94 10.06L19 11L16.94 11.94Z\";\r\nvar mdiMovieFilterOutline = \"M10 11L9.06 13.06L7 14L9.06 14.94L10 17L10.94 14.94L13 14L10.94 13.06M18 4L20 8H17L15 4H13L15 8H12L10 4H8L10 8H7L5 4H4C2.91 4 2 4.9 2 6L2 18C2 19.1 2.91 20 4 20H20C21.11 20 22 19.1 22 18V4H18M20 18H4V6.47L5.77 10H16L15.37 11.37L14 12L15.37 12.63L16 14L16.63 12.63L18 12L16.63 11.37L16 10H20V18Z\";\r\nvar mdiMovieOpen = \"M20.84 2.18L16.91 2.96L19.65 6.5L21.62 6.1L20.84 2.18M13.97 3.54L12 3.93L14.75 7.46L16.71 7.07L13.97 3.54M9.07 4.5L7.1 4.91L9.85 8.44L11.81 8.05L9.07 4.5M4.16 5.5L3.18 5.69A2 2 0 0 0 1.61 8.04L2 10L6.9 9.03L4.16 5.5M2 10V20C2 21.11 2.9 22 4 22H20C21.11 22 22 21.11 22 20V10H2Z\";\r\nvar mdiMovieOpenOutline = \"M20.84 2.18L16.91 2.96L19.65 6.5L21.62 6.1L20.84 2.18M13.97 3.54L12 3.93L14.75 7.46L16.71 7.07L13.97 3.54M9.07 4.5L7.1 4.91L9.85 8.44L11.81 8.05L9.07 4.5M4.16 5.5L3.18 5.69C2.1 5.9 1.39 6.96 1.61 8.04L2 10L6.9 9.03L4.16 5.5M20 12V20H4V12H20M22 10H2V20C2 21.11 2.9 22 4 22H20C21.11 22 22 21.11 22 20V10Z\";\r\nvar mdiMovieOutline = \"M5.76,10H20V18H4V6.47M22,4H18L20,8H17L15,4H13L15,8H12L10,4H8L10,8H7L5,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V4Z\";\r\nvar mdiMovieRoll = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A2.5,2.5 0 0,0 9.5,6.5A2.5,2.5 0 0,0 12,9A2.5,2.5 0 0,0 14.5,6.5A2.5,2.5 0 0,0 12,4M4.4,9.53C3.97,10.84 4.69,12.25 6,12.68C7.32,13.1 8.73,12.39 9.15,11.07C9.58,9.76 8.86,8.35 7.55,7.92C6.24,7.5 4.82,8.21 4.4,9.53M19.61,9.5C19.18,8.21 17.77,7.5 16.46,7.92C15.14,8.34 14.42,9.75 14.85,11.07C15.28,12.38 16.69,13.1 18,12.67C19.31,12.25 20.03,10.83 19.61,9.5M7.31,18.46C8.42,19.28 10,19.03 10.8,17.91C11.61,16.79 11.36,15.23 10.24,14.42C9.13,13.61 7.56,13.86 6.75,14.97C5.94,16.09 6.19,17.65 7.31,18.46M16.7,18.46C17.82,17.65 18.07,16.09 17.26,14.97C16.45,13.85 14.88,13.6 13.77,14.42C12.65,15.23 12.4,16.79 13.21,17.91C14,19.03 15.59,19.27 16.7,18.46M12,10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 12,13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 12,10.5Z\";\r\nvar mdiMovieSearch = \"M11.03 20H4C2.9 20 2 19.1 2 18L2 6C2 4.9 2.9 4 4 4H5L7 8H10L8 4H10L12 8H15L13 4H15L17 8H20L18 4H22V13.05C20.85 11.22 18.82 10 16.5 10C12.92 10 10 12.92 10 16.5C10 17.79 10.38 19 11.03 20M23.39 22L22 23.39L18.88 20.32C18.19 20.75 17.37 21 16.5 21C14 21 12 19 12 16.5S14 12 16.5 12 21 14 21 16.5C21 17.38 20.75 18.21 20.31 18.9L23.39 22M19 16.5C19 15.12 17.88 14 16.5 14S14 15.12 14 16.5 15.12 19 16.5 19 19 17.88 19 16.5Z\";\r\nvar mdiMovieSearchOutline = \"M11 20H4C2.9 20 2 19.1 2 18V6C2 4.9 2.9 4 4 4H5L7 8H10L8 4H10L12 8H15L13 4H15L17 8H20L18 4H22V13C21.5 12.2 20.8 11.5 20 11V10H5.8L4 6.5V18H10.2C10.4 18.7 10.6 19.4 11 20M20.3 18.9C20.7 18.2 21 17.4 21 16.5C21 14 19 12 16.5 12S12 14 12 16.5 14 21 16.5 21C17.4 21 18.2 20.8 18.9 20.3L22 23.4L23.4 22L20.3 18.9M16.5 19C15.1 19 14 17.9 14 16.5S15.1 14 16.5 14 19 15.1 19 16.5 17.9 19 16.5 19Z\";\r\nvar mdiMuffin = \"M16,5C16,5 15,2 12,2C9,2 8,5 8,5C6,5 4,7 4,9C1.3,9 1.3,13 4,13H20C22.7,13 22.7,9 20,9C20,7 18,5 16,5M5,15L7,22H9L8,15H5M10,15L11,22H13L14,15H10M16,15L15,22H17L19,15H16Z\";\r\nvar mdiMultiplication = \"M11,3H13V10.27L19.29,6.64L20.29,8.37L14,12L20.3,15.64L19.3,17.37L13,13.72V21H11V13.73L4.69,17.36L3.69,15.63L10,12L3.72,8.36L4.72,6.63L11,10.26V3Z\";\r\nvar mdiMultiplicationBox = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19M11,17H13V13.73L15.83,15.36L16.83,13.63L14,12L16.83,10.36L15.83,8.63L13,10.27V7H11V10.27L8.17,8.63L7.17,10.36L10,12L7.17,13.63L8.17,15.36L11,13.73V17Z\";\r\nvar mdiMushroom = \"M12,2A10,10 0 0,1 22,12A2,2 0 0,1 20,14H4A2,2 0 0,1 2,12A10,10 0 0,1 12,2M12,8A2,2 0 0,0 14,6A2,2 0 0,0 12,4A2,2 0 0,0 10,6A2,2 0 0,0 12,8M17,12A2,2 0 0,0 19,10A2,2 0 0,0 17,8A2,2 0 0,0 15,10A2,2 0 0,0 17,12M7,12A2,2 0 0,0 9,10A2,2 0 0,0 7,8A2,2 0 0,0 5,10A2,2 0 0,0 7,12M15,15L16.27,19.45L16.35,20C16.35,21.1 15.45,22 14.35,22H9.65A2,2 0 0,1 7.65,20L7.73,19.45L9,15H15Z\";\r\nvar mdiMushroomOff = \"M22.1 21.5L2.4 1.7L1.1 3L4.1 6C2.8 7.6 2 9.7 2 12C2 13.1 2.9 14 4 14H12.1L13.1 15H9L7.7 19.5V20C7.7 21.1 8.6 22 9.7 22H14.4C15.5 22 16.4 21.1 16.4 20L16.3 19.5L15.8 17.7L20.9 22.8L22.1 21.5M7 12C5.9 12 5 11.1 5 10C5 9.2 5.5 8.4 6.3 8.1L8.9 10.7C8.6 11.5 7.8 12 7 12M10 6C10 4.9 10.9 4 12 4S14 4.9 14 6 13.1 8 12 8C11.5 8 11.1 7.8 10.7 7.5L17.2 14H20C21.1 14 22 13.1 22 12C22 6.5 17.5 2 12 2C10.1 2 8.3 2.6 6.7 3.5L10.4 7.2C10.2 6.9 10 6.5 10 6M17 8C18.1 8 19 8.9 19 10S18.1 12 17 12 15 11.1 15 10 15.9 8 17 8Z\";\r\nvar mdiMushroomOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L4.1 6C2.8 7.6 2 9.7 2 12C2 13.1 2.9 14 4 14H12.1L13.1 15H9L8 18.5L7.7 19.5C7.4 20.6 8.1 21.7 9.1 21.9L9.7 22H14.4C15.5 22 16.4 21.1 16.4 20L16.3 19.5L16 18.5L15.8 17.6L20.9 22.7L22.1 21.5M4 12C4 10.3 4.6 8.7 5.5 7.4L6.2 8.1C6.1 8.4 6 8.7 6 9C6 10.1 6.9 11 8 11C8.3 11 8.6 10.9 8.9 10.8L10.1 12H4M9.7 20L10 19L10.6 17H13.6L14.2 19L14.5 20H9.7M16 11C14.9 11 14 10.1 14 9S14.9 7 16 7 18 7.9 18 9 17.1 11 16 11M8.2 5L6.7 3.5C8.3 2.6 10.1 2 12 2C17.5 2 22 6.5 22 12C22 13.1 21.1 14 20 14H17.2L15.2 12H20C20 8.3 17.4 5.1 14 4.2C13.9 5.2 13 6 12 6S10.1 5.2 10 4.2C9.4 4.4 8.7 4.7 8.2 5Z\";\r\nvar mdiMushroomOutline = \"M4,12H20C20,8.27 17.44,5.13 14,4.25C13.86,5.24 13,6 12,6C11,6 10.14,5.24 10,4.25C6.56,5.13 4,8.27 4,12M12,2A10,10 0 0,1 22,12A2,2 0 0,1 20,14H4A2,2 0 0,1 2,12A10,10 0 0,1 12,2M13.5,17H10.5L9.92,19L9.65,20H14.35L14.08,19L13.5,17M15,15L16,18.5L16.27,19.45L16.35,20C16.35,21.1 15.45,22 14.35,22H9.65L9.17,21.94C8.1,21.66 7.45,20.57 7.73,19.5L8,18.5L9,15H15M16,7A2,2 0 0,1 18,9A2,2 0 0,1 16,11A2,2 0 0,1 14,9A2,2 0 0,1 16,7M8,7A2,2 0 0,1 10,9A2,2 0 0,1 8,11A2,2 0 0,1 6,9A2,2 0 0,1 8,7Z\";\r\nvar mdiMusic = \"M21,3V15.5A3.5,3.5 0 0,1 17.5,19A3.5,3.5 0 0,1 14,15.5A3.5,3.5 0 0,1 17.5,12C18.04,12 18.55,12.12 19,12.34V6.47L9,8.6V17.5A3.5,3.5 0 0,1 5.5,21A3.5,3.5 0 0,1 2,17.5A3.5,3.5 0 0,1 5.5,14C6.04,14 6.55,14.12 7,14.34V6L21,3Z\";\r\nvar mdiMusicAccidentalDoubleFlat = \"M15.5 9C14.8 9 14.11 9.28 13.5 9.67V5H11.5V9.62C11.04 9.24 10.39 9 9.5 9C8.8 9 8.11 9.28 7.5 9.67V5H5.5V19C8.5 17.32 10.43 15.79 11.5 14.41V19C16.36 16.26 18.5 13.91 18.5 12C18.5 10.59 17.79 9 15.5 9M7.5 15.38V12.26C8.12 11.59 8.95 11 9.5 11C10.09 11 10.5 11.07 10.5 12C10.5 12.15 10.4 13.3 7.5 15.38M13.5 15.38V12.26C14.12 11.59 14.95 11 15.5 11C16.09 11 16.5 11.07 16.5 12C16.5 12.15 16.4 13.3 13.5 15.38Z\";\r\nvar mdiMusicAccidentalDoubleSharp = \"M15.41 10H17V7H14V8.59L12 10.59L10 8.59V7H7V10H8.59L10.59 12L8.59 14H7V17H10V15.41L12 13.41L14 15.41V17H17V14H15.41L13.41 12L15.41 10Z\";\r\nvar mdiMusicAccidentalFlat = \"M8.5 19C13.36 16.26 15.5 13.91 15.5 12C15.5 10.59 14.79 9 12.5 9C11.8 9 11.11 9.28 10.5 9.67V5H8.5M10.5 15.38V12.26C11.12 11.59 11.95 11 12.5 11C13.09 11 13.5 11.07 13.5 12C13.5 12.15 13.4 13.3 10.5 15.38Z\";\r\nvar mdiMusicAccidentalNatural = \"M10 8.75V3.5H8V17.5L14 15.25V20.5H16V6.5L10 8.75M14 13.25L10 14.75V10.75L14 9.25V13.25Z\";\r\nvar mdiMusicAccidentalSharp = \"M17 9.5V7.5L15 8.1V5.5H13V8.7L11 9.3V6.5H9V9.9L7 10.5V12.5L9 11.9V13.9L7 14.5V16.5L9 15.9V18.5H11V15.3L13 14.7V17.5H15V14.1L17 13.5V11.5L15 12.1V10.1L17 9.5M13 12.7L11 13.3V11.3L13 10.7V12.7Z\";\r\nvar mdiMusicBox = \"M16,9H13V14.5A2.5,2.5 0 0,1 10.5,17A2.5,2.5 0 0,1 8,14.5A2.5,2.5 0 0,1 10.5,12C11.07,12 11.58,12.19 12,12.5V7H16M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiMusicBoxMultiple = \"M4,6H2V20A2,2 0 0,0 4,22H18V20H4M18,7H15V12.5A2.5,2.5 0 0,1 12.5,15A2.5,2.5 0 0,1 10,12.5A2.5,2.5 0 0,1 12.5,10C13.07,10 13.58,10.19 14,10.5V5H18M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2Z\";\r\nvar mdiMusicBoxMultipleOutline = \"M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M20,16H8V4H20M12.5,15A2.5,2.5 0 0,0 15,12.5V7H18V5H14V10.5C13.58,10.19 13.07,10 12.5,10A2.5,2.5 0 0,0 10,12.5A2.5,2.5 0 0,0 12.5,15M4,6H2V20A2,2 0 0,0 4,22H18V20H4\";\r\nvar mdiMusicBoxOutline = \"M16,9H13V14.5A2.5,2.5 0 0,1 10.5,17A2.5,2.5 0 0,1 8,14.5A2.5,2.5 0 0,1 10.5,12C11.07,12 11.58,12.19 12,12.5V7H16V9M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M5,5V19H19V5H5Z\";\r\nvar mdiMusicCircle = \"M16,9V7H12V12.5C11.58,12.19 11.07,12 10.5,12A2.5,2.5 0 0,0 8,14.5A2.5,2.5 0 0,0 10.5,17A2.5,2.5 0 0,0 13,14.5V9H16M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiMusicCircleOutline = \"M16,9H13V14.5A2.5,2.5 0 0,1 10.5,17A2.5,2.5 0 0,1 8,14.5A2.5,2.5 0 0,1 10.5,12C11.07,12 11.58,12.19 12,12.5V7H16V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiMusicClefAlto = \"M5 4H7V20H5M15.46 13H14.83L13.83 12L14.83 11H15.46A3.5 3.5 0 1 0 11.96 7.5H13.96A1.5 1.5 0 1 1 15.46 9H14L12 11H11V4H9V20H11V13H12L14 15H15.46A1.5 1.5 0 1 1 13.96 16.5H11.96A3.5 3.5 0 1 0 15.46 13Z\";\r\nvar mdiMusicClefBass = \"M18.5 5A1.5 1.5 0 1 1 17 6.5A1.5 1.5 0 0 1 18.5 5M18.5 11A1.5 1.5 0 1 1 17 12.5A1.5 1.5 0 0 1 18.5 11M10 4A5 5 0 0 0 5 9V10A2 2 0 1 0 7.18 8A3 3 0 0 1 10 6A4 4 0 0 1 14 10C14 13.59 11.77 16.19 7 18.2L7.76 20.04C13.31 17.72 16 14.43 16 10A6 6 0 0 0 10 4Z\";\r\nvar mdiMusicClefTreble = \"M13 11V7.5L15.2 5.29C16 4.5 16.15 3.24 15.59 2.26C15.14 1.47 14.32 1 13.45 1C13.24 1 13 1.03 12.81 1.09C11.73 1.38 11 2.38 11 3.5V6.74L7.86 9.91C6.2 11.6 5.7 14.13 6.61 16.34C7.38 18.24 9.06 19.55 11 19.89V20.5C11 20.76 10.77 21 10.5 21H9V23H10.5C11.85 23 13 21.89 13 20.5V20C15.03 20 17.16 18.08 17.16 15.25C17.16 12.95 15.24 11 13 11M13 3.5C13 3.27 13.11 3.09 13.32 3.03C13.54 2.97 13.77 3.06 13.88 3.26C14 3.46 13.96 3.71 13.8 3.87L13 4.73V3.5M11 11.5C10.03 12.14 9.3 13.24 9.04 14.26L11 14.78V17.83C9.87 17.53 8.9 16.71 8.43 15.57C7.84 14.11 8.16 12.45 9.26 11.33L11 9.5V11.5M13 18V12.94C14.17 12.94 15.18 14.04 15.18 15.25C15.18 17 13.91 18 13 18Z\";\r\nvar mdiMusicNote = \"M12 3V13.55C11.41 13.21 10.73 13 10 13C7.79 13 6 14.79 6 17S7.79 21 10 21 14 19.21 14 17V7H18V3H12Z\";\r\nvar mdiMusicNoteBluetooth = \"M22 9.85L19.14 7H18.64V10.79L16.35 8.5L15.64 9.21L18.43 12L15.64 14.79L16.35 15.5L18.64 13.21V17H19.14L22 14.15L19.85 12L22 9.85M19.64 8.91L20.58 9.85L19.64 10.79V8.91M20.58 14.15L19.64 15.09V13.21L20.58 14.15M9.64 3V13.55C9.05 13.21 8.37 13 7.64 13C5.43 13 3.64 14.79 3.64 17S5.43 21 7.64 21 11.64 19.21 11.64 17V7H15.64V3H9.64Z\";\r\nvar mdiMusicNoteBluetoothOff = \"M22 9.85L19.14 7H18.64V10.79L16.35 8.5L15.64 9.21L18.43 12L15.64 14.79L16.35 15.5L18.64 13.21V17H19.14L22 14.15L19.85 12L22 9.85M19.64 8.91L20.58 9.85L19.64 10.79V8.91M20.58 14.15L19.64 15.09V13.21L20.58 14.15M1.96 3L.687 4.27L9.69 13.27V13.55C9.1 13.21 8.42 13 7.69 13C5.5 13 3.69 14.79 3.69 17S5.5 21 7.69 21 11.69 19.21 11.69 17V15.27L17.42 21L18.69 19.73L1.96 3M11.69 7H15.69V3H9.69V8.18L11.69 10.18V7Z\";\r\nvar mdiMusicNoteEighth = \"M12 3V13.55C11.41 13.21 10.73 13 10 13C7.79 13 6 14.79 6 17S7.79 21 10 21 14 19.21 14 17V7H18V3H12Z\";\r\nvar mdiMusicNoteEighthDotted = \"M12 3V13.55A4 4 0 1 0 14 17V7H18V3M16.5 20A1.5 1.5 0 1 1 18 18.5A1.5 1.5 0 0 1 16.5 20Z\";\r\nvar mdiMusicNoteHalf = \"M16 3H14V13.56A3.96 3.96 0 0 0 12 13A4 4 0 1 0 16 17V3M12 19A2 2 0 1 1 14 17A2 2 0 0 1 12 19Z\";\r\nvar mdiMusicNoteHalfDotted = \"M14 3H12V13.56A3.96 3.96 0 0 0 10 13A4 4 0 1 0 14 17V3M10 19A2 2 0 1 1 12 17A2 2 0 0 1 10 19M16.5 20A1.5 1.5 0 1 1 18 18.5A1.5 1.5 0 0 1 16.5 20Z\";\r\nvar mdiMusicNoteOff = \"M4.27 3L3 4.27L12 13.27V13.55C11.41 13.21 10.73 13 10 13C7.79 13 6 14.79 6 17S7.79 21 10 21 14 19.21 14 17V15.27L19.73 21L21 19.73L4.27 3M14 7H18V3H12V8.18L14 10.18Z\";\r\nvar mdiMusicNoteOffOutline = \"M14 7H18V3H12V7.61L14 9.61M12 10.44L4.41 2.86L3 4.27L12 13.27V13.55A3.94 3.94 0 0 0 8.67 13.23A4 4 0 0 0 10.65 20.95A4.1 4.1 0 0 0 14 16.85V15.27L19.73 21L21.14 19.59M10 19A2 2 0 1 1 12 17A2 2 0 0 1 10 19Z\";\r\nvar mdiMusicNoteOutline = \"M12 3V13.55A4 4 0 1 0 14 17V7H18V3M10 19A2 2 0 1 1 12 17A2 2 0 0 1 10 19Z\";\r\nvar mdiMusicNotePlus = \"M17 9V12H14V14H17V17H19V14H22V12H19V9H17M9 3V13.55C8.41 13.21 7.73 13 7 13C4.79 13 3 14.79 3 17S4.79 21 7 21 11 19.21 11 17V7H15V3H9Z\";\r\nvar mdiMusicNoteQuarter = \"M14 3V13.56C13.41 13.21 12.73 13 12 13C9.79 13 8 14.79 8 17S9.79 21 12 21 16 19.21 16 17V3H14Z\";\r\nvar mdiMusicNoteQuarterDotted = \"M12 13V13.56A3.96 3.96 0 0 0 10 13A4 4 0 1 0 14 17V3H12M16.5 17A1.5 1.5 0 1 1 15 18.5A1.5 1.5 0 0 1 16.5 17Z\";\r\nvar mdiMusicNoteSixteenth = \"M18 7V3H12V13.55C11.41 13.21 10.73 13 10 13C7.79 13 6 14.79 6 17S7.79 21 10 21 14 19.21 14 17V11H18V8H14V7H18Z\";\r\nvar mdiMusicNoteSixteenthDotted = \"M18 18.5A1.5 1.5 0 1 1 16.5 17A1.5 1.5 0 0 1 18 18.5M18 7V3H12V13.55A4 4 0 1 0 14 17V11H18V8H14V7Z\";\r\nvar mdiMusicNoteWhole = \"M12 15A2 2 0 1 1 10 17A2 2 0 0 1 12 15M12 13A4 4 0 1 0 16 17A4 4 0 0 0 12 13Z\";\r\nvar mdiMusicNoteWholeDotted = \"M10 15A2 2 0 1 1 8 17A2 2 0 0 1 10 15M10 13A4 4 0 1 0 14 17A4 4 0 0 0 10 13M16.5 17A1.5 1.5 0 1 1 15 18.5A1.5 1.5 0 0 1 16.5 17Z\";\r\nvar mdiMusicOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L9,12.27V17.5A3.5,3.5 0 0,1 5.5,21A3.5,3.5 0 0,1 2,17.5A3.5,3.5 0 0,1 5.5,14C6.04,14 6.55,14.12 7,14.34V10.27L2,5.27M21,3V15.5C21,16.5 20.57,17.42 19.88,18.06L14.94,13.12C15.58,12.43 16.5,12 17.5,12C18.04,12 18.55,12.12 19,12.34V6.47L10.17,8.35L7.66,5.84L21,3Z\";\r\nvar mdiMusicRestEighth = \"M14 6A5.56 5.56 0 0 1 10.95 7.86A1.5 1.5 0 1 0 9.5 9H9.74A6.32 6.32 0 0 0 13.25 7.93L10 18H12L16 6Z\";\r\nvar mdiMusicRestHalf = \"M6 14H8V10H16V14H18V15H6V14Z\";\r\nvar mdiMusicRestQuarter = \"M11.71 16.81C10.91 17.6 10.88 18.84 11.64 19.58L10.19 21C8.66 19.5 8.72 17.03 10.32 15.46C10.85 14.94 11.5 14.61 12.16 14.42L9 11.34L10.45 9.92L10.82 9.57C11.82 8.59 11.85 7.04 10.9 6.11L9.16 4.42L10.62 3L14.78 7.06C15.54 7.81 15.5 9.05 14.71 9.83L12.53 11.95L16 15.33L15.61 15.72C15.11 16.21 14.38 16.46 13.72 16.28C13.04 16.1 12.26 16.28 11.71 16.81Z\";\r\nvar mdiMusicRestSixteenth = \"M15 3A5.56 5.56 0 0 1 11.95 4.86A1.5 1.5 0 1 0 10.5 6H10.74A6.32 6.32 0 0 0 14.25 4.93L12.9 9.1A5.56 5.56 0 0 1 9.95 10.86A1.5 1.5 0 1 0 8.5 12H8.74A6.32 6.32 0 0 0 12.25 10.93L9 21H11L17 3Z\";\r\nvar mdiMusicRestWhole = \"M18 10H16V14H8V10H6V9H18V10Z\";\r\nvar mdiMustache = \"M21 12C19 12 18 9 15 9S12 11 12 11 12 9 9 9 5 12 3 12C2 12 1 11 1 11S2 16 6 16C11 16 12 13 12 13S13 16 18 16C22 16 23 11 23 11S22 12 21 12Z\";\r\nvar mdiNail = \"M13.5,5V16L12,22L10.5,16V5H13.5M17,2H7V4H17V2Z\";\r\nvar mdiNas = \"M4,5C2.89,5 2,5.89 2,7V17C2,18.11 2.89,19 4,19H20C21.11,19 22,18.11 22,17V7C22,5.89 21.11,5 20,5H4M4.5,7A1,1 0 0,1 5.5,8A1,1 0 0,1 4.5,9A1,1 0 0,1 3.5,8A1,1 0 0,1 4.5,7M7,7H20V17H7V7M8,8V16H11V8H8M12,8V16H15V8H12M16,8V16H19V8H16M9,9H10V10H9V9M13,9H14V10H13V9M17,9H18V10H17V9Z\";\r\nvar mdiNativescript = \"M7.5,3H16.5C19,3 21,5 21,7.5V16.5C21,19 19,21 16.5,21H7.5C5,21 3,19 3,16.5V7.5C3,5 5,3 7.5,3M6,13.5V16.5A1.5,1.5 0 0,0 7.5,18H9V10.5L15,18H16.5A1.5,1.5 0 0,0 18,16.5V13.5A1.5,1.5 0 0,1 19.5,12A1.5,1.5 0 0,1 18,10.5V7.5A1.5,1.5 0 0,0 16.5,6H15V13.5L9,6H7.5A1.5,1.5 0 0,0 6,7.5V10.5A1.5,1.5 0 0,1 4.5,12A1.5,1.5 0 0,1 6,13.5Z\";\r\nvar mdiNature = \"M13,16.12C16.47,15.71 19.17,12.76 19.17,9.17C19.17,5.3 16.04,2.17 12.17,2.17A7,7 0 0,0 5.17,9.17C5.17,12.64 7.69,15.5 11,16.06V20H5V22H19V20H13V16.12Z\";\r\nvar mdiNaturePeople = \"M4.5,11A1.5,1.5 0 0,0 6,9.5A1.5,1.5 0 0,0 4.5,8A1.5,1.5 0 0,0 3,9.5A1.5,1.5 0 0,0 4.5,11M22.17,9.17C22.17,5.3 19.04,2.17 15.17,2.17A7,7 0 0,0 8.17,9.17C8.17,12.64 10.69,15.5 14,16.06V20H6V17H7V13A1,1 0 0,0 6,12H3A1,1 0 0,0 2,13V17H3V22H19V20H16V16.12C19.47,15.71 22.17,12.76 22.17,9.17Z\";\r\nvar mdiNavigation = \"M12,2L4.5,20.29L5.21,21L12,18L18.79,21L19.5,20.29L12,2Z\";\r\nvar mdiNavigationOutline = \"M12 7.3L16.3 17.7L12.8 16.2L12 15.8L11.2 16.2L7.7 17.7L12 7.3M12 2L4.5 20.3L5.2 21L12 18L18.8 21L19.5 20.3L12 2Z\";\r\nvar mdiNearMe = \"M21,3L3,10.53V11.5L9.84,14.16L12.5,21H13.46L21,3Z\";\r\nvar mdiNecklace = \"M21.5 5H19.5C19.5 9.14 16.14 12.5 12 12.5C7.86 12.5 4.5 9.14 4.5 5H2.5C2.55 10.11 6.59 14.29 11.7 14.5C11.1 15.4 10 17.2 10 18C10 20.67 14 20.67 14 18C14 17.2 12.9 15.4 12.3 14.5C17.41 14.29 21.45 10.11 21.5 5Z\";\r\nvar mdiNeedle = \"M11.15,15.18L9.73,13.77L11.15,12.35L12.56,13.77L13.97,12.35L12.56,10.94L13.97,9.53L15.39,10.94L16.8,9.53L13.97,6.7L6.9,13.77L9.73,16.6L11.15,15.18M3.08,19L6.2,15.89L4.08,13.77L13.97,3.87L16.1,6L17.5,4.58L16.1,3.16L17.5,1.75L21.75,6L20.34,7.4L18.92,6L17.5,7.4L19.63,9.53L9.73,19.42L7.61,17.3L3.08,21.84V19Z\";\r\nvar mdiNetflix = \"M6.5,2H10.5L13.44,10.83L13.5,2H17.5V22C16.25,21.78 14.87,21.64 13.41,21.58L10.5,13L10.43,21.59C9.03,21.65 7.7,21.79 6.5,22V2Z\";\r\nvar mdiNetwork = \"M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17Z\";\r\nvar mdiNetworkOff = \"M1,5.27L5,9.27V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H17.73L19.73,24L21,22.72L2.28,4L1,5.27M15,20A1,1 0 0,0 14,19H13V17.27L15.73,20H15M17.69,16.87L5.13,4.31C5.41,3.55 6.14,3 7,3H17A2,2 0 0,1 19,5V15C19,15.86 18.45,16.59 17.69,16.87M22,20V21.18L20.82,20H22Z\";\r\nvar mdiNetworkOffOutline = \"M1.04,5.27L5,9.23V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H17.77L19.77,24L21.04,22.72L2.32,4L1.04,5.27M7,11.23L10.77,15H7V11.23M15,20A1,1 0 0,0 14,19H13V17.23L15.77,20H15M22,20V21.14L20.86,20H22M7,6.14L5.14,4.28C5.43,3.53 6.16,3 7,3H17A2,2 0 0,1 19,5V15C19,15.85 18.47,16.57 17.72,16.86L15.86,15H17V5H7V6.14Z\";\r\nvar mdiNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7Z\";\r\nvar mdiNetworkStrength1 = \"M1,21H21V1M19,5.83V19H11V13.83\";\r\nvar mdiNetworkStrength1Alert = \"M21 1L1 21H17V19H11V13.8L19 5.8V9H21M19 11V17H21V11M19 19V21H21V19\";\r\nvar mdiNetworkStrength2 = \"M1,21H21V1M19,5.83V19H13V11.83\";\r\nvar mdiNetworkStrength2Alert = \"M21 1L1 21H17V19H13V11.8L19 5.8V9H21M19 11V17H21V11M19 19V21H21V19\";\r\nvar mdiNetworkStrength3 = \"M1,21H21V1M19,5.83V19H16V8.83\";\r\nvar mdiNetworkStrength3Alert = \"M21 1L1 21H17V19H16V8.8L19 5.8V9H21M19 11V17H21V11M19 19V21H21V19\";\r\nvar mdiNetworkStrength4 = \"M1,21H21V1\";\r\nvar mdiNetworkStrength4Alert = \"M19 17H21V11H19M19 21H21V19H19M1 21H17V9H21V1\";\r\nvar mdiNetworkStrengthOff = \"M21,1L12.4,9.6L21,18.19M4.77,4.5L3.5,5.77L9.86,12.13L1,21H18.73L20.73,23L22,21.73\";\r\nvar mdiNetworkStrengthOffOutline = \"M21,1L12.4,9.6L13.85,11.05L19,5.83V16.19L21,18.19M4.77,4.5L3.5,5.77L9.86,12.13L1,21H18.73L20.73,23L22,21.73M11.33,13.6L16.73,19H6\";\r\nvar mdiNetworkStrengthOutline = \"M1,21H21V1M19,5.83V19H6\";\r\nvar mdiNewBox = \"M20,4C21.11,4 22,4.89 22,6V18C22,19.11 21.11,20 20,20H4C2.89,20 2,19.11 2,18V6C2,4.89 2.89,4 4,4H20M8.5,15V9H7.25V12.5L4.75,9H3.5V15H4.75V11.5L7.3,15H8.5M13.5,10.26V9H9.5V15H13.5V13.75H11V12.64H13.5V11.38H11V10.26H13.5M20.5,14V9H19.25V13.5H18.13V10H16.88V13.5H15.75V9H14.5V14A1,1 0 0,0 15.5,15H19.5A1,1 0 0,0 20.5,14Z\";\r\nvar mdiNewspaper = \"M20,11H4V8H20M20,15H13V13H20M20,19H13V17H20M11,19H4V13H11M20.33,4.67L18.67,3L17,4.67L15.33,3L13.67,4.67L12,3L10.33,4.67L8.67,3L7,4.67L5.33,3L3.67,4.67L2,3V19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19V3L20.33,4.67Z\";\r\nvar mdiNewspaperMinus = \"M22,17V19H14V17H22M20,11V8H4V11H20M13,13V14.68C12.37,15.63 12,16.77 12,18C12,19.09 12.29,20.12 12.8,21H4A2,2 0 0,1 2,19V3L3.67,4.67L5.33,3L7,4.67L8.67,3L10.33,4.67L12,3L13.67,4.67L15.33,3L17,4.67L18.67,3L20.33,4.67L22,3V13.5C20.93,12.58 19.53,12 18,12C16.77,12 15.63,12.37 14.68,13H13M11,19V13H4V19H11Z\";\r\nvar mdiNewspaperPlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M20,11V8H4V11H20M13,13V14.68C12.37,15.63 12,16.77 12,18C12,19.09 12.29,20.12 12.8,21H4A2,2 0 0,1 2,19V3L3.67,4.67L5.33,3L7,4.67L8.67,3L10.33,4.67L12,3L13.67,4.67L15.33,3L17,4.67L18.67,3L20.33,4.67L22,3V13.5C20.93,12.58 19.53,12 18,12C16.77,12 15.63,12.37 14.68,13H13M11,19V13H4V19H11Z\";\r\nvar mdiNewspaperVariant = \"M20 3H4C2.89 3 2 3.89 2 5V19C2 20.11 2.89 21 4 21H20C21.11 21 22 20.11 22 19V5C22 3.89 21.11 3 20 3M5 7H10V13H5V7M19 17H5V15H19V17M19 13H12V11H19V13M19 9H12V7H19V9Z\";\r\nvar mdiNewspaperVariantMultiple = \"M4 7V19H19V21H4C2 21 2 19 2 19V7H4M21.3 3H7.7C6.76 3 6 3.7 6 4.55V15.45C6 16.31 6.76 17 7.7 17H21.3C22.24 17 23 16.31 23 15.45V4.55C23 3.7 22.24 3 21.3 3M8 5H13V11H8V5M21 15H8V13H21V15M21 11H15V9H21V11M21 7H15V5H21V7Z\";\r\nvar mdiNewspaperVariantMultipleOutline = \"M4 7V19H19V21H4C2 21 2 19 2 19V7H4M21 5V15H8V5H21M21.3 3H7.7C6.76 3 6 3.7 6 4.55V15.45C6 16.31 6.76 17 7.7 17H21.3C22.24 17 23 16.31 23 15.45V4.55C23 3.7 22.24 3 21.3 3M9 6H12V11H9V6M20 14H9V12H20V14M20 8H14V6H20V8M20 11H14V9H20V11Z\";\r\nvar mdiNewspaperVariantOutline = \"M20 5L20 19L4 19L4 5H20M20 3H4C2.89 3 2 3.89 2 5V19C2 20.11 2.89 21 4 21H20C21.11 21 22 20.11 22 19V5C22 3.89 21.11 3 20 3M18 15H6V17H18V15M10 7H6V13H10V7M12 9H18V7H12V9M18 11H12V13H18V11Z\";\r\nvar mdiNfc = \"M7.24 2C5.6 2 3.96 2 3.55 2.04C2.67 2.09 2.08 2.73 2.04 3.56C2 4.37 2 19.59 2.04 20.41C2.09 21.23 2.71 21.86 3.55 21.91C4.46 21.96 7.44 21.97 8.29 21.97C6.76 20.91 6.55 18.92 6.41 15.23C6.33 13.04 6.4 5.36 6.41 5.04L6.45 2.94L14.5 11V13.5L8.09 7.11C8.08 8.38 8.06 10.03 8.06 11.54C8.06 13 8.08 14.34 8.12 15.05C8.36 19.07 8.74 20.96 10.83 21.7C11.5 21.93 12.07 22 13.07 22C13.89 22 19.63 22 20.45 21.96C21.33 21.91 21.93 21.27 21.97 20.44C22 19.63 22 4.45 21.97 3.62C21.91 2.8 21.29 2.18 20.45 2.13C19.54 2.08 16.57 2.03 15.71 2.03C17.24 3.09 17.44 5.08 17.59 8.78C17.67 10.97 17.6 18.64 17.59 18.97L17.55 21.06L9.53 13V10.5L15.91 16.89C15.92 15.62 15.94 13.97 15.94 12.46C15.94 11 15.92 9.66 15.88 8.96C15.64 4.93 15.26 3.04 13.17 2.3C12.53 2.07 11.93 2 10.93 2H7.24Z\";\r\nvar mdiNfcSearchVariant = \"M16.5,12C19,12 21,14 21,16.5C21,17.38 20.76,18.21 20.32,18.9L23.4,22L22,23.39L18.89,20.32C18.2,20.75 17.38,21 16.5,21C14,21 12,19 12,16.5C12,14 14,12 16.5,12M16.5,14A2.5,2.5 0 0,0 14,16.5A2.5,2.5 0 0,0 16.5,19C17.89,19 19,17.88 19,16.5A2.5,2.5 0 0,0 16.5,14M18,6V10.18C17.33,10 16.66,9.97 16,10V8H13V10.28L13.53,10.72C12.34,11.33 11.35,12.3 10.72,13.53C10.28,13.17 10,12.62 10,12C10,11.26 10.41,10.62 11,10.28V8A2,2 0 0,1 13,6H18M6,18V6H8L10,6V8H8V16H10C9.96,16.68 10,17.35 10.17,18H6M20,4H4V20H11C11.53,20.8 12.21,21.5 13.03,22H4C2.89,22 2,21.1 2,20V4A2,2 0 0,1 4,2H20A2,2 0 0,1 22,4V13.04C21.5,12.24 20.82,11.54 20,11V4Z\";\r\nvar mdiNfcTap = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M4,4H11A2,2 0 0,1 13,6V9H11V6H4V11H6V9L9,12L6,15V13H4A2,2 0 0,1 2,11V6A2,2 0 0,1 4,4M20,20H13A2,2 0 0,1 11,18V15H13V18H20V13H18V15L15,12L18,9V11H20A2,2 0 0,1 22,13V18A2,2 0 0,1 20,20Z\";\r\nvar mdiNfcVariant = \"M18,6H13A2,2 0 0,0 11,8V10.28C10.41,10.62 10,11.26 10,12A2,2 0 0,0 12,14C13.11,14 14,13.1 14,12C14,11.26 13.6,10.62 13,10.28V8H16V16H8V8H10V6H8L6,6V18H18M20,20H4V4H20M20,2H4A2,2 0 0,0 2,4V20A2,2 0 0,0 4,22H20C21.11,22 22,21.1 22,20V4C22,2.89 21.11,2 20,2Z\";\r\nvar mdiNfcVariantOff = \"M1.25,2.05L21.95,22.75L20.7,24L18.7,22H4A2,2 0 0,1 2,20V5.3L0,3.3L1.25,2.05M3.81,2C3.87,2 3.94,2 4,2H20C21.11,2 22,2.89 22,4V20C22,20.06 22,20.13 22,20.19L20,18.2V4H5.8L3.81,2M6,9.3L4,7.3V20H16.7L14.7,18H6V9.3M18,16.2L16,14.2V8H13V10.28C13.6,10.62 14,11.26 14,12C14,12.06 14,12.13 14,12.19L11,9.2V8A2,2 0 0,1 13,6H18V16.2M8,16H12.7L8,11.3V16M10,8H9.8L7.8,6H10V8Z\";\r\nvar mdiNinja = \"M7.75,13C7.74,12.65 7.9,12.31 8.17,12.08C8.92,12.24 9.62,12.55 10.25,13C10.25,13.68 9.69,14.24 9,14.24C8.31,14.24 7.76,13.69 7.75,13M13.75,13C14.38,12.56 15.08,12.25 15.83,12.09C16.1,12.32 16.26,12.66 16.25,13C16.25,13.7 15.69,14.26 15,14.26C14.31,14.26 13.75,13.7 13.75,13V13M12,9C9.23,8.96 6.5,9.65 4.07,11L4,12C4,13.23 4.29,14.44 4.84,15.54C7.21,15.18 9.6,15 12,15C14.4,15 16.79,15.18 19.16,15.54C19.71,14.44 20,13.23 20,12L19.93,11C17.5,9.65 14.77,8.96 12,9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNintendoGameBoy = \"M7 1C5.9 1 5 1.9 5 3V21C5 22.11 5.9 23 7 23H14C16.76 23 19 20.76 19 18V3C19 1.9 18.11 1 17 1H7M8 4H16V11H8V4M9 14H10V16H12V17H10V19H9V17H7V16H9V14M16 15C16.55 15 17 15.45 17 16C17 16.55 16.55 17 16 17C15.45 17 15 16.55 15 16C15 15.45 15.45 15 16 15M14 17C14.55 17 15 17.45 15 18C15 18.55 14.55 19 14 19C13.45 19 13 18.55 13 18C13 17.45 13.45 17 14 17Z\";\r\nvar mdiNintendoSwitch = \"M10.04,20.4H7.12C6.19,20.4 5.3,20 4.64,19.36C4,18.7 3.6,17.81 3.6,16.88V7.12C3.6,6.19 4,5.3 4.64,4.64C5.3,4 6.19,3.62 7.12,3.62H10.04V20.4M7.12,2A5.12,5.12 0 0,0 2,7.12V16.88C2,19.71 4.29,22 7.12,22H11.65V2H7.12M5.11,8C5.11,9.04 5.95,9.88 7,9.88C8.03,9.88 8.87,9.04 8.87,8C8.87,6.96 8.03,6.12 7,6.12C5.95,6.12 5.11,6.96 5.11,8M17.61,11C18.72,11 19.62,11.89 19.62,13C19.62,14.12 18.72,15 17.61,15C16.5,15 15.58,14.12 15.58,13C15.58,11.89 16.5,11 17.61,11M16.88,22A5.12,5.12 0 0,0 22,16.88V7.12C22,4.29 19.71,2 16.88,2H13.65V22H16.88Z\";\r\nvar mdiNintendoWii = \"M17.84,16.94H15.97V10.79H17.84V16.94M18,8.58C18,9.19 17.5,9.69 16.9,9.69A1.11,1.11 0 0,1 15.79,8.58C15.79,7.96 16.29,7.46 16.9,7.46C17.5,7.46 18,7.96 18,8.58M21.82,16.94H19.94V10.79H21.82V16.94M22,8.58C22,9.19 21.5,9.69 20.88,9.69A1.11,1.11 0 0,1 19.77,8.58C19.77,7.96 20.27,7.46 20.88,7.46C21.5,7.46 22,7.96 22,8.58M12.9,8.05H14.9L12.78,15.5C12.78,15.5 12.5,17.04 11.28,17.04C10.07,17.04 9.79,15.5 9.79,15.5L8.45,10.64L7.11,15.5C7.11,15.5 6.82,17.04 5.61,17.04C4.4,17.04 4.12,15.5 4.12,15.5L2,8.05H4L5.72,14.67L7.11,9.3C7.43,7.95 8.45,7.97 8.45,7.97C8.45,7.97 9.47,7.95 9.79,9.3L11.17,14.67L12.9,8.05Z\";\r\nvar mdiNintendoWiiu = \"M2,15.96C2,18.19 3.54,19.5 5.79,19.5H18.57C20.47,19.5 22,18.2 22,16.32V6.97C22,5.83 21.15,4.6 20.11,4.6H17.15V12.3C17.15,18.14 6.97,18.09 6.97,12.41V4.5H4.72C3.26,4.5 2,5.41 2,6.85V15.96M9.34,11.23C9.34,15.74 14.66,15.09 14.66,11.94V4.5H9.34V11.23Z\";\r\nvar mdiNix = \"M9.9 8.7L5 17.2L3.9 15.3L5.2 13H2.6L2 12L2.6 11H6.3L7.6 8.7H9.9M10.2 15.5H19.9L18.8 17.4H16.2L17.5 19.7L16.9 20.7H15.8L14 17.4H11.3L10.2 15.5M15.9 11.8L11 3.3H13.2L14.5 5.6L15.8 3.3H16.9L17.5 4.3L15.6 7.5L17 9.8L15.9 11.8M13.8 8.5H4L5.1 6.6H7.7L6.4 4.3L7 3.3H8.1L10 6.5H12.7L13.8 8.5M14.1 15.3L19 6.8L20.1 8.7L18.8 11H21.4L22 12L21.4 13H17.7L16.4 15.3H14.1M8.1 12.2L13 20.6H10.8L9.5 18.3L8.4 20.6H7.1L6.5 19.6L8.4 16.4L7 14.2L8.1 12.2Z\";\r\nvar mdiNodejs = \"M12,1.85C11.73,1.85 11.45,1.92 11.22,2.05L3.78,6.35C3.3,6.63 3,7.15 3,7.71V16.29C3,16.85 3.3,17.37 3.78,17.65L5.73,18.77C6.68,19.23 7,19.24 7.44,19.24C8.84,19.24 9.65,18.39 9.65,16.91V8.44C9.65,8.32 9.55,8.22 9.43,8.22H8.5C8.37,8.22 8.27,8.32 8.27,8.44V16.91C8.27,17.57 7.59,18.22 6.5,17.67L4.45,16.5C4.38,16.45 4.34,16.37 4.34,16.29V7.71C4.34,7.62 4.38,7.54 4.45,7.5L11.89,3.21C11.95,3.17 12.05,3.17 12.11,3.21L19.55,7.5C19.62,7.54 19.66,7.62 19.66,7.71V16.29C19.66,16.37 19.62,16.45 19.55,16.5L12.11,20.79C12.05,20.83 11.95,20.83 11.88,20.79L10,19.65C9.92,19.62 9.84,19.61 9.79,19.64C9.26,19.94 9.16,20 8.67,20.15C8.55,20.19 8.36,20.26 8.74,20.47L11.22,21.94C11.46,22.08 11.72,22.15 12,22.15C12.28,22.15 12.54,22.08 12.78,21.94L20.22,17.65C20.7,17.37 21,16.85 21,16.29V7.71C21,7.15 20.7,6.63 20.22,6.35L12.78,2.05C12.55,1.92 12.28,1.85 12,1.85M14,8C11.88,8 10.61,8.89 10.61,10.39C10.61,12 11.87,12.47 13.91,12.67C16.34,12.91 16.53,13.27 16.53,13.75C16.53,14.58 15.86,14.93 14.3,14.93C12.32,14.93 11.9,14.44 11.75,13.46C11.73,13.36 11.64,13.28 11.53,13.28H10.57C10.45,13.28 10.36,13.37 10.36,13.5C10.36,14.74 11.04,16.24 14.3,16.24C16.65,16.24 18,15.31 18,13.69C18,12.08 16.92,11.66 14.63,11.35C12.32,11.05 12.09,10.89 12.09,10.35C12.09,9.9 12.29,9.3 14,9.3C15.5,9.3 16.09,9.63 16.32,10.66C16.34,10.76 16.43,10.83 16.53,10.83H17.5C17.55,10.83 17.61,10.81 17.65,10.76C17.69,10.72 17.72,10.66 17.7,10.6C17.56,8.82 16.38,8 14,8Z\";\r\nvar mdiNoodles = \"M22 3L10 4.41V6H22V7H10V12H22C22 13.81 21.43 15.46 20.32 16.95S17.77 19.53 16 20.25V22H8V20.25C6.24 19.53 4.79 18.43 3.68 16.95S2 13.81 2 12H5V4L22 2V3M6 4.88V6H7V4.78L6 4.88M6 7V12H7V7H6M9 12V7H8V12H9M9 6V4.55L8 4.64V6H9Z\";\r\nvar mdiNotEqual = \"M21,10H9V8H21V10M21,16H9V14H21V16M4,5H6V16H4V5M6,18V20H4V18H6Z\";\r\nvar mdiNotEqualVariant = \"M14.08,4.61L15.92,5.4L14.8,8H19V10H13.95L12.23,14H19V16H11.38L9.92,19.4L8.08,18.61L9.2,16H5V14H10.06L11.77,10H5V8H12.63L14.08,4.61Z\";\r\nvar mdiNote = \"M14,10V4.5L19.5,10M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V9L15,3H5Z\";\r\nvar mdiNoteMultiple = \"M16,9H21.5L16,3.5V9M7,2H17L23,8V18A2,2 0 0,1 21,20H7C5.89,20 5,19.1 5,18V4A2,2 0 0,1 7,2M3,6V22H21V24H3A2,2 0 0,1 1,22V6H3Z\";\r\nvar mdiNoteMultipleOutline = \"M3,6V22H21V24H3A2,2 0 0,1 1,22V6H3M16,9H21.5L16,3.5V9M7,2H17L23,8V18A2,2 0 0,1 21,20H7C5.89,20 5,19.1 5,18V4A2,2 0 0,1 7,2M7,4V18H21V11H14V4H7Z\";\r\nvar mdiNoteOutline = \"M14,10H19.5L14,4.5V10M5,3H15L21,9V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3M5,5V19H19V12H12V5H5Z\";\r\nvar mdiNotePlus = \"M14,10H19.5L14,4.5V10M5,3H15L21,9V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3M9,18H11V15H14V13H11V10H9V13H6V15H9V18Z\";\r\nvar mdiNotePlusOutline = \"M15,10H20.5L15,4.5V10M4,3H16L22,9V19A2,2 0 0,1 20,21H4C2.89,21 2,20.1 2,19V5C2,3.89 2.89,3 4,3M4,5V19H20V12H13V5H4M8,17V15H6V13H8V11H10V13H12V15H10V17H8Z\";\r\nvar mdiNoteText = \"M14,10H19.5L14,4.5V10M5,3H15L21,9V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3M5,12V14H19V12H5M5,16V18H14V16H5Z\";\r\nvar mdiNoteTextOutline = \"M15 3H5A2 2 0 0 0 3 5V19A2 2 0 0 0 5 21H19A2 2 0 0 0 21 19V9L15 3M19 19H5V5H14V10H19M17 14H7V12H17M14 17H7V15H14\";\r\nvar mdiNotebook = \"M3,7V5H5V4C5,2.89 5.9,2 7,2H13V9L15.5,7.5L18,9V2H19C20.05,2 21,2.95 21,4V20C21,21.05 20.05,22 19,22H7C5.95,22 5,21.05 5,20V19H3V17H5V13H3V11H5V7H3M7,11H5V13H7V11M7,7V5H5V7H7M7,19V17H5V19H7Z\";\r\nvar mdiNotebookCheck = \"M16.75 22.16L14 19.16L15.16 18L16.75 19.59L20.34 16L21.5 17.41L16.75 22.16M3 7V5H5V4C5 2.89 5.9 2 7 2H13V9L15.5 7.5L18 9V2H19C20.05 2 21 2.95 21 4V13.8C20.12 13.29 19.09 13 18 13C14.69 13 12 15.69 12 19C12 20.09 12.29 21.12 12.8 22H7C5.95 22 5 21.05 5 20V19H3V17H5V13H3V11H5V7H3M5 5V7H7V5H5M5 19H7V17H5V19M5 13H7V11H5V13Z\";\r\nvar mdiNotebookCheckOutline = \"M16.75 22.16L14 19.16L15.16 18L16.75 19.59L20.34 16L21.5 17.41L16.75 22.16M17 4V10L15 8L13 10V4H9V20H12.08C12.2 20.72 12.45 21.39 12.8 22H7C5.95 22 5 21.05 5 20V19H3V17H5V13H3V11H5V7H3V5H5V4C5 2.89 5.9 2 7 2H19C20.05 2 21 2.95 21 4V13.8C20.39 13.45 19.72 13.2 19 13.08V4H17M5 19H7V17H5V19M5 13H7V11H5V13M5 7H7V5H5V7Z\";\r\nvar mdiNotebookEdit = \"M21.04 13.13C21.18 13.13 21.31 13.19 21.42 13.3L22.7 14.58C22.92 14.79 22.92 15.14 22.7 15.35L21.7 16.35L19.65 14.3L20.65 13.3C20.76 13.19 20.9 13.13 21.04 13.13M19.07 14.88L21.12 16.93L15.06 23H13V20.94L19.07 14.88M3 7V5H5V4C5 2.89 5.9 2 7 2H13V9L15.5 7.5L18 9V2H19C20.05 2 21 2.95 21 4V10L11 20V22H7C5.95 22 5 21.05 5 20V19H3V17H5V13H3V11H5V7H3M5 7H7V5H5V7M5 11V13H7V11H5M5 17V19H7V17H5Z\";\r\nvar mdiNotebookEditOutline = \"M19.07 14.88L21.12 16.93L15.06 23H13V20.94L19.07 14.88M21.04 13.13C21.18 13.13 21.31 13.19 21.42 13.3L22.7 14.58C22.92 14.79 22.92 15.14 22.7 15.35L21.7 16.35L19.65 14.3L20.65 13.3C20.76 13.19 20.9 13.13 21.04 13.13M17 4V10L15 8L13 10V4H9V20H11V22H7C5.95 22 5 21.05 5 20V19H3V17H5V13H3V11H5V7H3V5H5V4C5 2.89 5.9 2 7 2H19C20.05 2 21 2.95 21 4V10L19 12V4H17M5 5V7H7V5H5M5 11V13H7V11H5M5 17V19H7V17H5Z\";\r\nvar mdiNotebookMinus = \"M3 7V5H5V4C5 2.9 5.9 2 7 2H13V9L15.5 7.5L18 9V2H19C20 2 21 3 21 4V13.8C20.1 13.3 19.1 13 18 13C14.7 13 12 15.7 12 19C12 20.1 12.3 21.1 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3M5 5V7H7V5H5M5 19H7V17H5V19M5 13H7V11H5V13M14 18V20H22V18H14Z\";\r\nvar mdiNotebookMinusOutline = \"M17 4V10L15 8L13 10V4H9V20H12.1C12.2 20.7 12.5 21.4 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3V5H5V4C5 2.9 5.9 2 7 2H19C20 2 21 3 21 4V13.8C20.4 13.4 19.7 13.2 19 13.1V4H17M5 19H7V17H5V19M5 13H7V11H5V13M5 7H7V5H5V7M14 18V20H22V18H14Z\";\r\nvar mdiNotebookMultiple = \"M9.05,9H7.06V6H9.05V4.03H7.06V3.03C7.06,1.92 7.95,1.04 9.05,1.04H15.03V8L17.5,6.5L20,8V1.04H21C22.05,1.04 23,2 23,3.03V17C23,18.03 22.05,19 21,19H9.05C8,19 7.06,18.05 7.06,17V16H9.05V14H7.06V11H9.05V9M1,18H3V15H1V13H3V10H1V8H3V5H5V8H3V10H5V13H3V15H5V18H3V20H5V21H21V23H5A2,2 0 0,1 3,21V20H1V18Z\";\r\nvar mdiNotebookOutline = \"M17,4V10L15,8L13,10V4H9V20H19V4H17M3,7V5H5V4C5,2.89 5.9,2 7,2H19C20.05,2 21,2.95 21,4V20C21,21.05 20.05,22 19,22H7C5.95,22 5,21.05 5,20V19H3V17H5V13H3V11H5V7H3M5,5V7H7V5H5M5,19H7V17H5V19M5,13H7V11H5V13Z\";\r\nvar mdiNotebookPlus = \"M3 7V5H5V4C5 2.9 5.9 2 7 2H13V9L15.5 7.5L18 9V2H19C20 2 21 3 21 4V13.8C20.1 13.3 19.1 13 18 13C14.7 13 12 15.7 12 19C12 20.1 12.3 21.1 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3M5 5V7H7V5H5M5 19H7V17H5V19M5 13H7V11H5V13M17 15V18H14V20H17V23H19V20H22V18H19V15H17Z\";\r\nvar mdiNotebookPlusOutline = \"M17 4V10L15 8L13 10V4H9V20H12.1C12.2 20.7 12.5 21.4 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3V5H5V4C5 2.9 5.9 2 7 2H19C20 2 21 3 21 4V13.8C20.4 13.4 19.7 13.2 19 13.1V4H17M5 19H7V17H5V19M5 13H7V11H5V13M5 7H7V5H5V7M17 15V18H14V20H17V23H19V20H22V18H19V15H17Z\";\r\nvar mdiNotebookRemove = \"M3 7V5H5V4C5 2.9 5.9 2 7 2H13V9L15.5 7.5L18 9V2H19C20 2 21 3 21 4V13.8C20.1 13.3 19.1 13 18 13C14.7 13 12 15.7 12 19C12 20.1 12.3 21.1 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3M5 5V7H7V5H5M5 19H7V17H5V19M5 13H7V11H5V13M20.1 15.5L18 17.6L15.9 15.5L14.5 16.9L16.6 19L14.5 21.1L15.9 22.5L18 20.4L20.1 22.5L21.5 21.1L19.4 19L21.5 16.9L20.1 15.5Z\";\r\nvar mdiNotebookRemoveOutline = \"M17 4V10L15 8L13 10V4H9V20H12.1C12.2 20.7 12.5 21.4 12.8 22H7C5.9 22 5 21 5 20V19H3V17H5V13H3V11H5V7H3V5H5V4C5 2.9 5.9 2 7 2H19C20 2 21 3 21 4V13.8C20.4 13.4 19.7 13.2 19 13.1V4H17M5 19H7V17H5V19M5 13H7V11H5V13M5 7H7V5H5V7M20.1 15.5L18 17.6L15.9 15.5L14.5 16.9L16.6 19L14.5 21.1L15.9 22.5L18 20.4L20.1 22.5L21.5 21.1L19.4 19L21.5 16.9L20.1 15.5Z\";\r\nvar mdiNotificationClearAll = \"M5,13H19V11H5M3,17H17V15H3M7,7V9H21V7\";\r\nvar mdiNpm = \"M4,10V14H6V11H7V14H8V10H4M9,10V15H11V14H13V10H9M12,11V13H11V11H12M14,10V14H16V11H17V14H18V11H19V14H20V10H14M3,9H21V15H12V16H8V15H3V9Z\";\r\nvar mdiNuke = \"M14.04,12H10V11H5.5A3.5,3.5 0 0,1 2,7.5A3.5,3.5 0 0,1 5.5,4C6.53,4 7.45,4.44 8.09,5.15C8.5,3.35 10.08,2 12,2C13.92,2 15.5,3.35 15.91,5.15C16.55,4.44 17.47,4 18.5,4A3.5,3.5 0 0,1 22,7.5A3.5,3.5 0 0,1 18.5,11H14.04V12M10,16.9V15.76H5V13.76H19V15.76H14.04V16.92L20,19.08C20.58,19.29 21,19.84 21,20.5A1.5,1.5 0 0,1 19.5,22H4.5A1.5,1.5 0 0,1 3,20.5C3,19.84 3.42,19.29 4,19.08L10,16.9Z\";\r\nvar mdiNull = \"M12,2C13.85,2 15.55,2.78 16.9,4.1L18.6,1.93L20.18,3.16L18.2,5.68C19.33,7.41 20,9.6 20,12C20,17.5 16.42,22 12,22C10.15,22 8.45,21.22 7.1,19.9L5.4,22.07L3.82,20.84L5.8,18.32C4.67,16.59 4,14.4 4,12C4,6.5 7.58,2 12,2M12,4C8.69,4 6,7.58 6,12C6,13.73 6.41,15.33 7.11,16.64L15.67,5.67C14.66,4.62 13.38,4 12,4M12,20C15.31,20 18,16.42 18,12C18,10.27 17.59,8.67 16.89,7.36L8.33,18.33C9.34,19.38 10.62,20 12,20Z\";\r\nvar mdiNumeric = \"M4,17V9H2V7H6V17H4M22,15C22,16.11 21.1,17 20,17H16V15H20V13H18V11H20V9H16V7H20A2,2 0 0,1 22,9V10.5A1.5,1.5 0 0,1 20.5,12A1.5,1.5 0 0,1 22,13.5V15M14,15V17H8V13C8,11.89 8.9,11 10,11H12V9H8V7H12A2,2 0 0,1 14,9V11C14,12.11 13.1,13 12,13H10V15H14Z\";\r\nvar mdiNumeric0 = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9Z\";\r\nvar mdiNumeric0Box = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9Z\";\r\nvar mdiNumeric0BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M13,5A2,2 0 0,0 11,7V13A2,2 0 0,0 13,15H15A2,2 0 0,0 17,13V7A2,2 0 0,0 15,5H13M13,7H15V13H13V7Z\";\r\nvar mdiNumeric0BoxMultipleOutline = \"M21,17V3H7V17H21M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M13,5H15A2,2 0 0,1 17,7V13A2,2 0 0,1 15,15H13A2,2 0 0,1 11,13V7A2,2 0 0,1 13,5M13,7V13H15V7H13Z\";\r\nvar mdiNumeric0BoxOutline = \"M19,19V5H5V19H19M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11Z\";\r\nvar mdiNumeric0Circle = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11M11,9H13V15H11V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric0CircleOutline = \"M11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,9V15H13V9H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric1 = \"M10,7V9H12V17H14V7H10Z\";\r\nvar mdiNumeric1Box = \"M14,17H12V9H10V7H14M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric1BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M14,15H16V5H12V7H14V15Z\";\r\nvar mdiNumeric1BoxMultipleOutline = \"M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M14,15H16V5H12V7H14M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric1BoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,17H14V7H10V9H12\";\r\nvar mdiNumeric1Circle = \"M10,7V9H12V17H14V7H10M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric1CircleOutline = \"M10,7H14V17H12V9H10V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric10 = \"M10 7H6V9H8V17H10V7M16 7H14C12.9 7 12 7.9 12 9V15C12 16.11 12.9 17 14 17H16C17.11 17 18 16.11 18 15V9C18 7.9 17.11 7 16 7M16 15H14V9H16V15Z\";\r\nvar mdiNumeric10Box = \"M14,9H16V15H14V9M21,5V19C21,20.11 20.11,21 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19C20.11,3 21,3.9 21,5M10,7H6V9H8V17H10V7M18,9A2,2 0 0,0 16,7H14A2,2 0 0,0 12,9V15C12,16.11 12.9,17 14,17H16C17.11,17 18,16.11 18,15V9Z\";\r\nvar mdiNumeric10BoxMultiple = \"M3 5V21H19V23H3C1.9 23 1 22.11 1 21V5H3M16 13H18V7H16V13M21 1H7C5.9 1 5 1.9 5 3V17C5 18.11 5.9 19 7 19H21C22.11 19 23 18.11 23 17V3C23 1.9 22.11 1 21 1M12 15H10V7H8V5H12V15M20 13C20 14.11 19.11 15 18 15H16C14.9 15 14 14.11 14 13V7C14 5.9 14.9 5 16 5H18C19.11 5 20 5.9 20 7V13Z\";\r\nvar mdiNumeric10BoxMultipleOutline = \"M21 17V3H7V17H21M21 1C22.11 1 23 1.9 23 3V17C23 18.11 22.11 19 21 19H7C5.9 19 5 18.11 5 17V3C5 1.9 5.9 1 7 1H21M3 5V21H19V23H3C1.9 23 1 22.11 1 21V5H3M12 5H8V7H10V15H12V5M18 5H16C14.9 5 14 5.9 14 7V13C14 14.11 14.9 15 16 15H18C19.11 15 20 14.11 20 13V7C20 5.9 19.11 5 18 5M18 13H16V7H18V13Z\";\r\nvar mdiNumeric10BoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19C3,20.11 3.9,21 5,21H19C20.11,21 21,20.11 21,19V5A2,2 0 0,0 19,3M8,17H10V7H6V9H8M14,7H16C17.11,7 18,7.9 18,9V15C18,16.11 17.11,17 16,17H14A2,2 0 0,1 12,15V9A2,2 0 0,1 14,7M14,9V15H16V9H14Z\";\r\nvar mdiNumeric10Circle = \"M14 9H16V15H14V9M22 12C22 17.5 17.5 22 12 22S2 17.5 2 12 6.5 2 12 2 22 6.5 22 12M10 7H6V9H8V17H10V7M18 9C18 7.9 17.11 7 16 7H14C12.9 7 12 7.9 12 9V15C12 16.11 12.9 17 14 17H16C17.11 17 18 16.11 18 15V9Z\";\r\nvar mdiNumeric10CircleOutline = \"M12 2C17.5 2 22 6.5 22 12S17.5 22 12 22 2 17.5 2 12 6.5 2 12 2M12 4C7.58 4 4 7.58 4 12S7.58 20 12 20 20 16.42 20 12 16.42 4 12 4M10 7H6V9H8V17H10V7M16 7H14C12.9 7 12 7.9 12 9V15C12 16.11 12.9 17 14 17H16C17.11 17 18 16.11 18 15V9C18 7.9 17.11 7 16 7M16 15H14V9H16V15Z\";\r\nvar mdiNumeric2 = \"M9,7V9H13V11H11A2,2 0 0,0 9,13V17H11L15,17V15H11V13H13A2,2 0 0,0 15,11V9A2,2 0 0,0 13,7H9Z\";\r\nvar mdiNumeric2Box = \"M15,11C15,12.11 14.1,13 13,13H11V15H15V17H9V13C9,11.89 9.9,11 11,11H13V9H9V7H13A2,2 0 0,1 15,9M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric2BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M17,13H13V11H15A2,2 0 0,0 17,9V7C17,5.89 16.1,5 15,5H11V7H15V9H13A2,2 0 0,0 11,11V15H17V13M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21Z\";\r\nvar mdiNumeric2BoxMultipleOutline = \"M17,13H13V11H15A2,2 0 0,0 17,9V7C17,5.89 16.1,5 15,5H11V7H15V9H13A2,2 0 0,0 11,11V15H17M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric2BoxOutline = \"M15,15H11V13H13A2,2 0 0,0 15,11V9C15,7.89 14.1,7 13,7H9V9H13V11H11A2,2 0 0,0 9,13V17H15M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric2Circle = \"M9,7V9H13V11H11A2,2 0 0,0 9,13V17H11L15,17V15H11V13H13A2,2 0 0,0 15,11V9A2,2 0 0,0 13,7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric2CircleOutline = \"M9,7H13A2,2 0 0,1 15,9V11A2,2 0 0,1 13,13H11V15H15V17H11L9,17V13A2,2 0 0,1 11,11H13V9H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric3 = \"M15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H9V9H13V11H11V13H13V15H9V17H13A2,2 0 0,0 15,15\";\r\nvar mdiNumeric3Box = \"M15,10.5A1.5,1.5 0 0,1 13.5,12C14.34,12 15,12.67 15,13.5V15C15,16.11 14.11,17 13,17H9V15H13V13H11V11H13V9H9V7H13C14.11,7 15,7.89 15,9M19,3H5C3.91,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19C20.11,21 21,20.1 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric3BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M17,13V11.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 17,8.5V7C17,5.89 16.1,5 15,5H11V7H15V9H13V11H15V13H11V15H15A2,2 0 0,0 17,13M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21Z\";\r\nvar mdiNumeric3BoxMultipleOutline = \"M17,13V11.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 17,8.5V7C17,5.89 16.1,5 15,5H11V7H15V9H13V11H15V13H11V15H15A2,2 0 0,0 17,13M3,5H1V21A2,2 0 0,0 3,23H19V21H3M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1Z\";\r\nvar mdiNumeric3BoxOutline = \"M15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H9V9H13V11H11V13H13V15H9V17H13A2,2 0 0,0 15,15M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric3Circle = \"M15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H9V9H13V11H11V13H13V15H9V17H13A2,2 0 0,0 15,15M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric3CircleOutline = \"M15,15A2,2 0 0,1 13,17H9V15H13V13H11V11H13V9H9V7H13A2,2 0 0,1 15,9V10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 15,13.5V15M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric4 = \"M9,7V13H13V17H15V7H13V11H11V7H9Z\";\r\nvar mdiNumeric4Box = \"M15,17H13V13H9V7H11V11H13V7H15M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric4BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M15,15H17V5H15V9H13V5H11V11H15V15Z\";\r\nvar mdiNumeric4BoxMultipleOutline = \"M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M15,15H17V5H15V9H13V5H11V11H15M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric4BoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M13,17H15V7H13V11H11V7H9V13H13\";\r\nvar mdiNumeric4Circle = \"M9,7V13H13V17H15V7H13V11H11V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric4CircleOutline = \"M9,7H11V11H13V7H15V17H13V13H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric5 = \"M9,7V13H13V15H9V17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H9Z\";\r\nvar mdiNumeric5Box = \"M15,9H11V11H13A2,2 0 0,1 15,13V15C15,16.11 14.1,17 13,17H9V15H13V13H9V7H15M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric5BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M17,13V11C17,9.89 16.1,9 15,9H13V7H17V5H11V11H15V13H11V15H15A2,2 0 0,0 17,13Z\";\r\nvar mdiNumeric5BoxMultipleOutline = \"M17,13V11C17,9.89 16.1,9 15,9H13V7H17V5H11V11H15V13H11V15H15A2,2 0 0,0 17,13M3,5H1V21A2,2 0 0,0 3,23H19V21H3M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1Z\";\r\nvar mdiNumeric5BoxOutline = \"M15,15V13C15,11.89 14.1,11 13,11H11V9H15V7H9V13H13V15H9V17H13A2,2 0 0,0 15,15M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric5Circle = \"M9,7V13H13V15H9V17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric5CircleOutline = \"M9,7H15V9H11V11H13A2,2 0 0,1 15,13V15A2,2 0 0,1 13,17H9V15H13V13H9V7M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric6 = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H11M11,13H13V15H11V13Z\";\r\nvar mdiNumeric6Box = \"M15,9H11V11H13A2,2 0 0,1 15,13V15C15,16.11 14.1,17 13,17H11A2,2 0 0,1 9,15V9C9,7.89 9.9,7 11,7H15M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M11,15H13V13H11V15Z\";\r\nvar mdiNumeric6BoxMultiple = \"M13,11H15V13H13V11M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M13,15H15A2,2 0 0,0 17,13V11C17,9.89 16.1,9 15,9H13V7H17V5H13A2,2 0 0,0 11,7V13C11,14.11 11.9,15 13,15Z\";\r\nvar mdiNumeric6BoxMultipleOutline = \"M13,11H15V13H13M13,15H15A2,2 0 0,0 17,13V11C17,9.89 16.1,9 15,9H13V7H17V5H13A2,2 0 0,0 11,7V13C11,14.11 11.9,15 13,15M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric6BoxOutline = \"M11,13H13V15H11M11,17H13A2,2 0 0,0 15,15V13C15,11.89 14.1,11 13,11H11V9H15V7H11A2,2 0 0,0 9,9V15C9,16.11 9.9,17 11,17M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric6Circle = \"M11,7A2,2 0 0,0 9,9V15A2,2 0 0,0 11,17H13A2,2 0 0,0 15,15V13A2,2 0 0,0 13,11H11V9H15V7H11M11,13H13V15H11V13M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric6CircleOutline = \"M11,7H15V9H11V11H13A2,2 0 0,1 15,13V15A2,2 0 0,1 13,17H11A2,2 0 0,1 9,15V9A2,2 0 0,1 11,7M11,13V15H13V13H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric7 = \"M11,17L15,9V7H9V9H13L9,17\";\r\nvar mdiNumeric7Box = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M11,17L15,9V7H9V9H13L9,17H11Z\";\r\nvar mdiNumeric7BoxMultiple = \"M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M13,15L17,7V5H11V7H15L11,15H13M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21Z\";\r\nvar mdiNumeric7BoxMultipleOutline = \"M13,15L17,7V5H11V7H15L11,15M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric7BoxOutline = \"M11,17L15,9V7H9V9H13L9,17M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric7Circle = \"M11,17L15,9V7H9V9H13L9,17H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric7CircleOutline = \"M11,17H9L13,9H9V7H15V9L11,17M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric8 = \"M11,13H13V15H11M11,9H13V11H11M11,17H13A2,2 0 0,0 15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H11A2,2 0 0,0 9,9V10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 9,13.5V15C9,16.11 9.9,17 11,17\";\r\nvar mdiNumeric8Box = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M11,17H13A2,2 0 0,0 15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H11A2,2 0 0,0 9,9V10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 9,13.5V15C9,16.11 9.9,17 11,17M11,13H13V15H11V13M11,9H13V11H11V9Z\";\r\nvar mdiNumeric8BoxMultiple = \"M13,11H15V13H13V11M13,7H15V9H13V7M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M13,15H15A2,2 0 0,0 17,13V11.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 17,8.5V7C17,5.89 16.1,5 15,5H13A2,2 0 0,0 11,7V8.5A1.5,1.5 0 0,0 12.5,10A1.5,1.5 0 0,0 11,11.5V13C11,14.11 11.9,15 13,15M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21Z\";\r\nvar mdiNumeric8BoxMultipleOutline = \"M13,11H15V13H13M13,7H15V9H13M13,15H15A2,2 0 0,0 17,13V11.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 17,8.5V7C17,5.89 16.1,5 15,5H13A2,2 0 0,0 11,7V8.5A1.5,1.5 0 0,0 12.5,10A1.5,1.5 0 0,0 11,11.5V13C11,14.11 11.9,15 13,15M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric8BoxOutline = \"M11,13H13V15H11M11,9H13V11H11M11,17H13A2,2 0 0,0 15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H11A2,2 0 0,0 9,9V10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 9,13.5V15C9,16.11 9.9,17 11,17M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric8Circle = \"M11,13H13V15H11V13M11,9H13V11H11V9M11,17H13A2,2 0 0,0 15,15V13.5A1.5,1.5 0 0,0 13.5,12A1.5,1.5 0 0,0 15,10.5V9C15,7.89 14.1,7 13,7H11A2,2 0 0,0 9,9V10.5A1.5,1.5 0 0,0 10.5,12A1.5,1.5 0 0,0 9,13.5V15C9,16.11 9.9,17 11,17M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric8CircleOutline = \"M11,13V15H13V13H11M11,9V11H13V9H11M11,17A2,2 0 0,1 9,15V13.5A1.5,1.5 0 0,1 10.5,12A1.5,1.5 0 0,1 9,10.5V9A2,2 0 0,1 11,7H13A2,2 0 0,1 15,9V10.5A1.5,1.5 0 0,1 13.5,12A1.5,1.5 0 0,1 15,13.5V15A2,2 0 0,1 13,17H11M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric9 = \"M13,17A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11A2,2 0 0,0 9,9V11A2,2 0 0,0 11,13H13V15H9V17H13M13,11H11V9H13V11Z\";\r\nvar mdiNumeric9Box = \"M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M13,11H11V9H13V11M13,7H11A2,2 0 0,0 9,9V11C9,12.11 9.9,13 11,13H13V15H9V17H13A2,2 0 0,0 15,15V9C15,7.89 14.1,7 13,7Z\";\r\nvar mdiNumeric9BoxMultiple = \"M15,9H13V7H15V9M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M15,5H13A2,2 0 0,0 11,7V9C11,10.11 11.9,11 13,11H15V13H11V15H15A2,2 0 0,0 17,13V7C17,5.89 16.1,5 15,5M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21Z\";\r\nvar mdiNumeric9BoxMultipleOutline = \"M15,9H13V7H15M15,5H13A2,2 0 0,0 11,7V9C11,10.11 11.9,11 13,11H15V13H11V15H15A2,2 0 0,0 17,13V7C17,5.89 16.1,5 15,5M21,17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric9BoxOutline = \"M13,11H11V9H13M13,7H11A2,2 0 0,0 9,9V11C9,12.11 9.9,13 11,13H13V15H9V17H13A2,2 0 0,0 15,15V9C15,7.89 14.1,7 13,7M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3Z\";\r\nvar mdiNumeric9Circle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M13,17A2,2 0 0,0 15,15V9A2,2 0 0,0 13,7H11A2,2 0 0,0 9,9V11A2,2 0 0,0 11,13H13V15H9V17H13M13,11H11V9H13V11Z\";\r\nvar mdiNumeric9CircleOutline = \"M13,17H9V15H13V13H11A2,2 0 0,1 9,11V9A2,2 0 0,1 11,7H13A2,2 0 0,1 15,9V15A2,2 0 0,1 13,17M13,11V9H11V11H13M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumeric9Plus = \"M19 11H17V9H15V11H13V13H15V15H17V13H19V11M10 7H8C6.9 7 6 7.9 6 9V11C6 12.11 6.9 13 8 13H10V15H6V17H10C11.11 17 12 16.11 12 15V9C12 7.89 11.1 7 10 7M10 11H8V9H10V11Z\";\r\nvar mdiNumeric9PlusBox = \"M21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5M19,11H17V9H15V11H13V13H15V15H17V13H19V11M10,7H8A2,2 0 0,0 6,9V11C6,12.11 6.9,13 8,13H10V15H6V17H10A2,2 0 0,0 12,15V9C12,7.89 11.1,7 10,7M8,9H10V11H8V9Z\";\r\nvar mdiNumeric9PlusBoxMultiple = \"M11,9V8H12V9H11M21,1A2,2 0 0,1 23,3V17A2,2 0 0,1 21,19H7A2,2 0 0,1 5,17V3A2,2 0 0,1 7,1H21M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M15,9V11H17V13H19V11H21V9H19V7H17V9H15M14,12V8C14,6.89 13.1,6 12,6H11A2,2 0 0,0 9,8V9C9,10.11 9.9,11 11,11H12V12H9V14H12A2,2 0 0,0 14,12Z\";\r\nvar mdiNumeric9PlusBoxMultipleOutline = \"M21,9H19V7H17V9H15V11H17V13H19V11H21V17H7V3H21M21,1H7A2,2 0 0,0 5,3V17A2,2 0 0,0 7,19H21A2,2 0 0,0 23,17V3A2,2 0 0,0 21,1M11,9V8H12V9M14,12V8C14,6.89 13.1,6 12,6H11A2,2 0 0,0 9,8V9C9,10.11 9.9,11 11,11H12V12H9V14H12A2,2 0 0,0 14,12M3,5H1V21A2,2 0 0,0 3,23H19V21H3V5Z\";\r\nvar mdiNumeric9PlusBoxOutline = \"M19,11H17V9H15V11H13V13H15V15H17V13H19V19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M9,11V10H10V11M12,14V10C12,8.89 11.1,8 10,8H9A2,2 0 0,0 7,10V11C7,12.11 7.9,13 9,13H10V14H7V16H10A2,2 0 0,0 12,14Z\";\r\nvar mdiNumeric9PlusCircle = \"M19,11H17V9H15V11H13V13H15V15H17V13H19V11M10,7H8A2,2 0 0,0 6,9V11C6,12.11 6.9,13 8,13H10V15H6V17H10A2,2 0 0,0 12,15V9C12,7.89 11.1,7 10,7M8,9H10V11H8V9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2Z\";\r\nvar mdiNumeric9PlusCircleOutline = \"M19,11V13H17V15H15V13H13V11H15V9H17V11H19M10,7A2,2 0 0,1 12,9V15C12,16.11 11.1,17 10,17H6V15H10V13H8A2,2 0 0,1 6,11V9C6,7.89 6.9,7 8,7H10M8,9V11H10V9H8M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiNumericNegative1 = \"M13 7V9H15V17H17V7H13M11 13H5V11H11V13Z\";\r\nvar mdiNumericPositive1 = \"M13 7V9H15V17H17V7H13M11 13H9V15H7V13H5V11H7V9H9V11H11V13Z\";\r\nvar mdiNut = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12A5,5 0 0,0 12,7Z\";\r\nvar mdiNutrition = \"M22,18A4,4 0 0,1 18,22H14A4,4 0 0,1 10,18V16H22V18M4,3H14A2,2 0 0,1 16,5V14H8V19H4A2,2 0 0,1 2,17V5A2,2 0 0,1 4,3M4,6V8H6V6H4M14,8V6H8V8H14M4,10V12H6V10H4M8,10V12H14V10H8M4,14V16H6V14H4Z\";\r\nvar mdiNuxt = \"M21.8 18.36L16.03 8.08C15.93 8 15.63 7.43 15.03 7.43C14.78 7.43 14.43 7.53 14.07 8.08L13.33 9.26L11.31 5.65C11.26 5.55 10.91 5 10.31 5C10.06 5 9.66 5.1 9.36 5.65L2.18 18.31C2.13 18.41 1.83 19 2.13 19.5C2.23 19.75 2.53 20 3.19 20H20.85C20.95 20 21.6 20 21.9 19.5C22 19.26 22.1 18.86 21.8 18.36M8.1 18.31L7.95 18.86H3.24L10.36 6.34L12.66 10.47L8.1 18.31M9.21 18.86L13.32 11.66L17.5 18.86H9.21M18.74 18.86L18.54 18.31L14 10.46L15.03 8.73L20.75 18.86H18.74Z\";\r\nvar mdiOar = \"M20.23,15.21C18.77,13.75 14.97,10.2 12.77,11.27L4.5,3L3,4.5L11.28,12.79C10.3,15 13.88,18.62 15.35,20.08C17.11,21.84 18.26,20.92 19.61,19.57C21.1,18.08 21.61,16.61 20.23,15.21Z\";\r\nvar mdiOcarina = \"M20,12C16.8,10.4 13.4,9.7 10.8,9.3L9.7,5.9C9.3,4.8 7.7,4.8 7.3,5.9L6.3,9C3.9,9.4 2,11.5 2,14C2,16.8 4.2,19 7,19C7,19 14,19 20,16C20,16 22,15 22,14C22,13 20,12 20,12M5,14C4.4,14 4,13.6 4,13C4,12.4 4.4,12 5,12C5.6,12 6,12.4 6,13C6,13.5 5.6,14 5,14M7,17C6.4,17 6,16.6 6,16C6,15.4 6.4,15 7,15C7.6,15 8,15.4 8,16C8,16.5 7.6,17 7,17M9,14C8.4,14 8,13.6 8,13C8,12.4 8.4,12 9,12C9.6,12 10,12.4 10,13C10,13.5 9.6,14 9,14M11,17C10.4,17 10,16.6 10,16C10,15.4 10.4,15 11,15C11.6,15 12,15.4 12,16C12,16.5 11.6,17 11,17M16,14C15.4,14 15,13.6 15,13C15,12.4 15.4,12 16,12C16.6,12 17,12.4 17,13C17,13.5 16.6,14 16,14M19,15C18.4,15 18,14.6 18,14C18,13.4 18.4,13 19,13C19.6,13 20,13.4 20,14C20,14.5 19.6,15 19,15Z\";\r\nvar mdiOci = \"M2 2V22H22V2M19.12 19.03H4.87V5H19.13V19.03M14.83 10.71H17.69V17.59H14.83M14.83 6.41H17.69V9.27H14.83M6.3 6.41V17.59H13.4V14.72H9.17V9.28H13.4V6.41Z\";\r\nvar mdiOcr = \"M2 5V19H14V17H12C10.89 17 10 16.11 10 15V9C10 7.89 10.89 7 12 7H14V5M14 7V9H16V7M14 9H12V15H14M14 15V17H16V15M5 7H7C8.11 7 9 7.89 9 9V15C9 16.11 8.11 17 7 17H5C3.89 17 3 16.11 3 15V9C3 7.89 3.89 7 5 7M17 7V17H19V13H20V14H21V17H23V14H22V12H23V8H22V7M5 9V15H7V9M19 9H21V11H19Z\";\r\nvar mdiOctagon = \"M15.73,3H8.27L3,8.27V15.73L8.27,21H15.73L21,15.73V8.27\";\r\nvar mdiOctagonOutline = \"M8.27,3L3,8.27V15.73L8.27,21H15.73C17.5,19.24 21,15.73 21,15.73V8.27L15.73,3M9.1,5H14.9L19,9.1V14.9L14.9,19H9.1L5,14.9V9.1\";\r\nvar mdiOctagram = \"M2.2,16.06L3.88,12L2.2,7.94L6.26,6.26L7.94,2.2L12,3.88L16.06,2.2L17.74,6.26L21.8,7.94L20.12,12L21.8,16.06L17.74,17.74L16.06,21.8L12,20.12L7.94,21.8L6.26,17.74L2.2,16.06Z\";\r\nvar mdiOctagramOutline = \"M2.2,16.06L3.88,12L2.2,7.94L6.26,6.26L7.94,2.2L12,3.88L16.06,2.2L17.74,6.26L21.8,7.94L20.12,12L21.8,16.06L17.74,17.74L16.06,21.8L12,20.12L7.94,21.8L6.26,17.74L2.2,16.06M4.81,9L6.05,12L4.81,15L7.79,16.21L9,19.19L12,17.95L15,19.19L16.21,16.21L19.19,15L17.95,12L19.19,9L16.21,7.79L15,4.81L12,6.05L9,4.81L7.79,7.79L4.81,9Z\";\r\nvar mdiOdnoklassniki = \"M17.83,12.74C17.55,12.17 16.76,11.69 15.71,12.5C14.28,13.64 12,13.64 12,13.64C12,13.64 9.72,13.64 8.29,12.5C7.24,11.69 6.45,12.17 6.17,12.74C5.67,13.74 6.23,14.23 7.5,15.04C8.59,15.74 10.08,16 11.04,16.1L10.24,16.9C9.1,18.03 8,19.12 7.25,19.88C6.8,20.34 6.8,21.07 7.25,21.5L7.39,21.66C7.84,22.11 8.58,22.11 9.03,21.66L12,18.68C13.15,19.81 14.24,20.9 15,21.66C15.45,22.11 16.18,22.11 16.64,21.66L16.77,21.5C17.23,21.07 17.23,20.34 16.77,19.88L13.79,16.9L13,16.09C13.95,16 15.42,15.73 16.5,15.04C17.77,14.23 18.33,13.74 17.83,12.74M12,4.57C13.38,4.57 14.5,5.69 14.5,7.06C14.5,8.44 13.38,9.55 12,9.55C10.62,9.55 9.5,8.44 9.5,7.06C9.5,5.69 10.62,4.57 12,4.57M12,12.12C14.8,12.12 17.06,9.86 17.06,7.06C17.06,4.27 14.8,2 12,2C9.2,2 6.94,4.27 6.94,7.06C6.94,9.86 9.2,12.12 12,12.12Z\";\r\nvar mdiOffer = \"M21 13C21.6 13 22.1 13.2 22.4 13.6C22.8 14 23 14.5 23 15L15 18L8 16V7H9.9L17.2 9.7C17.7 9.9 18 10.3 18 10.8C18 11.1 17.9 11.4 17.7 11.6C17.5 11.8 17.2 12 16.8 12H14L12.3 11.3L12 12.2L14 13H21M2 7H6V18H2V7Z\";\r\nvar mdiOfficeBuilding = \"M5,3V21H11V17.5H13V21H19V3H5M7,5H9V7H7V5M11,5H13V7H11V5M15,5H17V7H15V5M7,9H9V11H7V9M11,9H13V11H11V9M15,9H17V11H15V9M7,13H9V15H7V13M11,13H13V15H11V13M15,13H17V15H15V13M7,17H9V19H7V17M15,17H17V19H15V17Z\";\r\nvar mdiOfficeBuildingMarker = \"M15.19 21C14.12 19.43 13 17.36 13 15.5C13 13.67 13.96 12 15.4 11H15V9H17V10.23C17.5 10.09 18 10 18.5 10C18.67 10 18.84 10 19 10.03V3H5V21H11V17.5H13V21H15.19M15 5H17V7H15V5M9 19H7V17H9V19M9 15H7V13H9V15M9 11H7V9H9V11M9 7H7V5H9V7M11 5H13V7H11V5M11 9H13V11H11V9M11 15V13H13V15H11M18.5 12C16.6 12 15 13.61 15 15.5C15 18.11 18.5 22 18.5 22S22 18.11 22 15.5C22 13.61 20.4 12 18.5 12M18.5 16.81C17.8 16.81 17.3 16.21 17.3 15.61C17.3 14.91 17.9 14.41 18.5 14.41S19.7 15 19.7 15.61C19.8 16.21 19.2 16.81 18.5 16.81Z\";\r\nvar mdiOfficeBuildingMarkerOutline = \"M15 9H17V11H15V9M17 5H15V7H17V5M11 15H13V13H11V15M13 5H11V7H13V5M11 11H13V9H11V11M9 5H7V7H9V5M9 9H7V11H9V9M14.55 21H13V17.5H11V21H5V3H19V11.03C19.71 11.09 20.39 11.31 21 11.63V1H3V23H15.91C15.5 22.44 15 21.76 14.55 21M7 19H9V17H7V19M9 13H7V15H9V13M22 16.5C22 19.1 18.5 23 18.5 23S15 19.1 15 16.5C15 14.6 16.6 13 18.5 13S22 14.6 22 16.5M19.7 16.6C19.7 16 19.1 15.4 18.5 15.4S17.3 15.9 17.3 16.6C17.3 17.2 17.8 17.8 18.5 17.8S19.8 17.2 19.7 16.6Z\";\r\nvar mdiOfficeBuildingOutline = \"M19 3V21H13V17.5H11V21H5V3H19M15 7H17V5H15V7M11 7H13V5H11V7M7 7H9V5H7V7M15 11H17V9H15V11M11 11H13V9H11V11M7 11H9V9H7V11M15 15H17V13H15V15M11 15H13V13H11V15M7 15H9V13H7V15M15 19H17V17H15V19M7 19H9V17H7V19M21 1H3V23H21V1Z\";\r\nvar mdiOil = \"M22,12.5C22,12.5 24,14.67 24,16A2,2 0 0,1 22,18A2,2 0 0,1 20,16C20,14.67 22,12.5 22,12.5M6,6H10A1,1 0 0,1 11,7A1,1 0 0,1 10,8H9V10H11C11.74,10 12.39,10.4 12.73,11L19.24,7.24L22.5,9.13C23,9.4 23.14,10 22.87,10.5C22.59,10.97 22,11.14 21.5,10.86L19.4,9.65L15.75,15.97C15.41,16.58 14.75,17 14,17H5A2,2 0 0,1 3,15V12A2,2 0 0,1 5,10H7V8H6A1,1 0 0,1 5,7A1,1 0 0,1 6,6M5,12V15H14L16.06,11.43L12.6,13.43L11.69,12H5M0.38,9.21L2.09,7.5C2.5,7.11 3.11,7.11 3.5,7.5C3.89,7.89 3.89,8.5 3.5,8.91L1.79,10.62C1.4,11 0.77,11 0.38,10.62C0,10.23 0,9.6 0.38,9.21Z\";\r\nvar mdiOilLamp = \"M5,20H16V22H5M11,5H10A2,2 0 0,0 8,7H13A2,2 0 0,0 11,5M16,8H22A2,2 0 0,1 20,10H19A4,4 0 0,0 15,14V15A4,4 0 0,1 11,19H10A4,4 0 0,1 6,15H4A2,2 0 0,1 2,13V10A2,2 0 0,1 4,8M6,10H4V13H6M19,5A2,2 0 0,1 21,7H22A2.9,2.9 0 0,0 19,4A2,2 0 0,1 17,2H16A2.9,2.9 0 0,0 19,5\";\r\nvar mdiOilLevel = \"M8 18C6.67 18 5.79 18.79 5.29 19.29S4.67 20 4 20 3.21 19.79 2.71 19.29C2.35 18.93 1.79 18.42 1 18.16V20.41C1.09 20.5 1.18 20.59 1.29 20.71C1.79 21.21 2.67 22 4 22S6.21 21.21 6.71 20.71 7.33 20 8 20 8.79 20.21 9.29 20.71C9.73 21.14 10.44 21.8 11.5 21.96C11.66 22 11.83 22 12 22C13.33 22 14.21 21.21 14.71 20.71S15.33 20 16 20 16.79 20.21 17.29 20.71 18.67 22 20 22 22.21 21.21 22.71 20.71C22.82 20.59 22.91 20.5 23 20.41V18.16C22.21 18.42 21.65 18.93 21.29 19.29C20.79 19.79 20.67 20 20 20S19.21 19.79 18.71 19.29 17.33 18 16 18 13.79 18.79 13.29 19.29 12.67 20 12 20C11.78 20 11.63 19.97 11.5 19.92C11.22 19.82 11.05 19.63 10.71 19.29C10.21 18.79 9.33 18 8 18M22 10.5C22 10.5 24 12.67 24 14C24 15.1 23.1 16 22 16S20 15.1 20 14C20 12.67 22 10.5 22 10.5M22.5 7.13L19.24 5.24L12.73 9C12.39 8.4 11.74 8 11 8H9V6H10C10.55 6 11 5.55 11 5S10.55 4 10 4H6C5.45 4 5 4.45 5 5S5.45 6 6 6H7V8H5C3.9 8 3 8.9 3 10V13C3 14.1 3.9 15 5 15H14C14.75 15 15.41 14.58 15.75 13.97L19.4 7.65L21.5 8.86C22 9.14 22.59 8.97 22.87 8.5C23.14 8 23 7.4 22.5 7.13M14 13H5V10H11.69L12.6 11.43L16.06 9.43L14 13M3.5 6.92L1.79 8.62A1 1 0 0 1 .38 7.21L2.09 5.5A1 1 0 0 1 3.5 5.5C3.89 5.89 3.89 6.5 3.5 6.92Z\";\r\nvar mdiOilTemperature = \"M10 5H13V3H10V2C10 1.4 9.6 1 9 1S8 1.4 8 2V15.3C7.4 15.6 7 16.3 7 17C7 18.1 7.9 19 9 19S11 18.1 11 17C11 16.3 10.6 15.6 10 15.3V13H13V11H10V9H13V7H10V5M22 17.5C22 17.5 24 19.7 24 21C24 22.1 23.1 23 22 23S20 22.1 20 21C20 19.7 22 17.5 22 17.5M22.9 15.5C22.6 16 22 16.1 21.5 15.9L19.4 14.7L15.8 21C15.5 21.6 14.8 22 14 22H5C3.9 22 3 21.1 3 20V17C3 15.9 3.9 15 5 15V20H14L16.1 16.4L13 18.2V15.8L19.2 12.2L22.5 14.1C23 14.4 23.1 15 22.9 15.5M3.5 13.9L1.8 15.6C1.4 16 .8 16 .4 15.6S0 14.6.4 14.2L2.1 12.5C2.5 12.1 3.1 12.1 3.5 12.5S3.9 13.5 3.5 13.9Z\";\r\nvar mdiOmega = \"M19.15,19H13.39V16.87C15.5,15.25 16.59,13.24 16.59,10.84C16.59,9.34 16.16,8.16 15.32,7.29C14.47,6.42 13.37,6 12.03,6C10.68,6 9.57,6.42 8.71,7.3C7.84,8.17 7.41,9.37 7.41,10.88C7.41,13.26 8.5,15.26 10.61,16.87V19H4.85V16.87H8.41C6.04,15.32 4.85,13.23 4.85,10.6C4.85,8.5 5.5,6.86 6.81,5.66C8.12,4.45 9.84,3.85 11.97,3.85C14.15,3.85 15.89,4.45 17.19,5.64C18.5,6.83 19.15,8.5 19.15,10.58C19.15,13.21 17.95,15.31 15.55,16.87H19.15V19Z\";\r\nvar mdiOneUp = \"M10,19V19C9.4,19 9,18.6 9,18V17C9,16.5 9.4,16 10,16V16C10.5,16 11,16.4 11,17V18C11,18.6 10.6,19 10,19M15,18V17C15,16.5 14.6,16 14,16V16C13.5,16 13,16.4 13,17V18C13,18.5 13.4,19 14,19V19C14.6,19 15,18.6 15,18M22,12C22,14.6 20.4,16.9 18,18.4V20A2,2 0 0,1 16,22H8A2,2 0 0,1 6,20V18.4C3.6,16.9 2,14.6 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M7,10C7,8.9 6.4,7.9 5.5,7.4C4.5,8.7 4,10.3 4,12C4,12.3 4,12.7 4.1,13C5.7,12.9 7,11.6 7,10M9,9C9,10.7 10.3,12 12,12C13.7,12 15,10.7 15,9C15,7.3 13.7,6 12,6C10.3,6 9,7.3 9,9M16,20V15.5C14.8,15.2 13.4,15 12,15C10.6,15 9.2,15.2 8,15.5V20H16M19.9,13C20,12.7 20,12.3 20,12C20,10.3 19.5,8.7 18.5,7.4C17.6,7.9 17,8.9 17,10C17,11.6 18.3,12.9 19.9,13Z\";\r\nvar mdiOnepassword = \"M12,1C5.92,1 1,5.92 1,12C1,18.08 5.92,23 12,23C18.08,23 23,18.08 23,12C23,5.92 18.08,1 12,1M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M13,13.5C13,14.13 13.4,14.7 14,14.91V18H10V11.91C10.78,11.64 11.19,10.8 10.93,10C10.78,9.58 10.44,9.24 10,9.09V6H14V12.09C13.4,12.3 13,12.87 13,13.5Z\";\r\nvar mdiOpacity = \"M17.66,8L12,2.35L6.34,8C4.78,9.56 4,11.64 4,13.64C4,15.64 4.78,17.75 6.34,19.31C7.9,20.87 9.95,21.66 12,21.66C14.05,21.66 16.1,20.87 17.66,19.31C19.22,17.75 20,15.64 20,13.64C20,11.64 19.22,9.56 17.66,8M6,14C6,12 6.62,10.73 7.76,9.6L12,5.27L16.24,9.65C17.38,10.77 18,12 18,14H6Z\";\r\nvar mdiOpenInApp = \"M12,10L8,14H11V20H13V14H16M19,4H5C3.89,4 3,4.9 3,6V18A2,2 0 0,0 5,20H9V18H5V8H19V18H15V20H19A2,2 0 0,0 21,18V6A2,2 0 0,0 19,4Z\";\r\nvar mdiOpenInNew = \"M14,3V5H17.59L7.76,14.83L9.17,16.24L19,6.41V10H21V3M19,19H5V5H12V3H5C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V12H19V19Z\";\r\nvar mdiOpenSourceInitiative = \"M15.41,22C15.35,22 15.28,22 15.22,22C15.1,21.95 15,21.85 14.96,21.73L12.74,15.93C12.65,15.69 12.77,15.42 13,15.32C13.71,15.06 14.28,14.5 14.58,13.83C15.22,12.4 14.58,10.73 13.15,10.09C11.72,9.45 10.05,10.09 9.41,11.5C9.11,12.21 9.09,13 9.36,13.69C9.66,14.43 10.25,15 11,15.28C11.24,15.37 11.37,15.64 11.28,15.89L9,21.69C8.96,21.81 8.87,21.91 8.75,21.96C8.63,22 8.5,22 8.39,21.96C3.24,19.97 0.67,14.18 2.66,9.03C4.65,3.88 10.44,1.31 15.59,3.3C18.06,4.26 20.05,6.15 21.13,8.57C22.22,11 22.29,13.75 21.33,16.22C20.32,18.88 18.23,21 15.58,22C15.5,22 15.47,22 15.41,22M12,3.59C7.03,3.46 2.9,7.39 2.77,12.36C2.68,16.08 4.88,19.47 8.32,20.9L10.21,16C8.38,15 7.69,12.72 8.68,10.89C9.67,9.06 11.96,8.38 13.79,9.36C15.62,10.35 16.31,12.64 15.32,14.47C14.97,15.12 14.44,15.65 13.79,16L15.68,20.93C17.86,19.95 19.57,18.16 20.44,15.93C22.28,11.31 20.04,6.08 15.42,4.23C14.33,3.8 13.17,3.58 12,3.59Z\";\r\nvar mdiOpenid = \"M14,2L11,3.5V19.94C7,19.5 4,17.46 4,15C4,12.75 6.5,10.85 10,10.22V8.19C4.86,8.88 1,11.66 1,15C1,18.56 5.36,21.5 11,21.94C11.03,21.94 11.06,21.94 11.09,21.94L14,20.5V2M15,8.19V10.22C16.15,10.43 17.18,10.77 18.06,11.22L16.5,12L23,13.5L22.5,9L20.5,10C19,9.12 17.12,8.47 15,8.19Z\";\r\nvar mdiOpera = \"M9.04,17.07C8.04,15.9 7.4,14.16 7.35,12.21V11.79C7.4,9.84 8.04,8.1 9.04,6.93C9.86,5.95 10.93,5.37 12.1,5.37C14.72,5.37 16.84,8.34 16.84,12C16.84,15.66 14.72,18.63 12.1,18.63C10.93,18.63 10.33,18.5 9.04,17.07M12.03,3H12A9,9 0 0,0 3,12C3,16.83 6.8,20.77 11.57,21H12C14.3,21 16.4,20.13 18,18.71C19.84,17.06 21,14.67 21,12C21,9.33 19.84,6.94 18,5.29C16.41,3.87 14.32,3 12.03,3Z\";\r\nvar mdiOrbit = \"M8.11,1.75C9.3,1.25 10.62,1 12,1C18.08,1 23,5.92 23,12C23,18.08 18.08,23 12,23C5.92,23 1,18.08 1,12C1,10.62 1.25,9.3 1.72,8.08C2.24,8.61 2.83,8.96 3.45,9.18C3.16,10.07 3,11 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3C11,3 10.07,3.16 9.18,3.45C8.96,2.83 8.61,2.24 8.11,1.75M4.93,2.93C6.03,2.93 6.93,3.82 6.93,4.93A2,2 0 0,1 4.93,6.93C3.82,6.93 2.93,6.03 2.93,4.93C2.93,3.82 3.82,2.93 4.93,2.93M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7Z\";\r\nvar mdiOrbitVariant = \"M19 8L15 12H18C18 15.31 15.31 18 12 18C11 18 10.03 17.75 9.2 17.3L7.74 18.76C8.97 19.54 10.43 20 12 20C16.42 20 20 16.42 20 12H23M6 12C6 8.69 8.69 6 12 6C13 6 13.97 6.25 14.8 6.7L16.26 5.24C15.03 4.46 13.57 4 12 4C7.58 4 4 7.58 4 12H1L5 16L9 12M14 12C14 13.11 13.11 14 12 14S10 13.11 10 12 10.9 10 12 10 14 10.9 14 12Z\";\r\nvar mdiOrderAlphabeticalAscending = \"M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12M9 13V15L5.67 19H9V21H3V19L6.33 15H3V13M7 3H5C3.9 3 3 3.9 3 5V11H5V9H7V11H9V5C9 3.9 8.11 3 7 3M7 7H5V5H7Z\";\r\nvar mdiOrderAlphabeticalDescending = \"M7 13H5C3.9 13 3 13.9 3 15V21H5V19H7V21H9V15C9 13.9 8.11 13 7 13M7 17H5V15H7M9 3V5L5.67 9H9V11H3V9L6.33 5H3V3M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12Z\";\r\nvar mdiOrderBoolAscending = \"M6 3C3.79 3 2 4.79 2 7S3.79 11 6 11 10 9.21 10 7 8.21 3 6 3M6 9C4.9 9 4 8.1 4 7S4.9 5 6 5 8 5.9 8 7 7.1 9 6 9M6 13C3.79 13 2 14.79 2 17S3.79 21 6 21 10 19.21 10 17 8.21 13 6 13M12 5H22V7H12V5M12 19V17H22V19H12M12 11H22V13H12V11Z\";\r\nvar mdiOrderBoolAscendingVariant = \"M4 13C2.89 13 2 13.89 2 15V19C2 20.11 2.89 21 4 21H8C9.11 21 10 20.11 10 19V15C10 13.89 9.11 13 8 13M8.2 14.5L9.26 15.55L5.27 19.5L2.74 16.95L3.81 15.9L5.28 17.39M4 3C2.89 3 2 3.89 2 5V9C2 10.11 2.89 11 4 11H8C9.11 11 10 10.11 10 9V5C10 3.89 9.11 3 8 3M4 5H8V9H4M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12Z\";\r\nvar mdiOrderBoolDescending = \"M6 13C3.79 13 2 14.79 2 17S3.79 21 6 21 10 19.21 10 17 8.21 13 6 13M6 19C4.9 19 4 18.1 4 17S4.9 15 6 15 8 15.9 8 17 7.1 19 6 19M6 3C3.79 3 2 4.79 2 7S3.79 11 6 11 10 9.21 10 7 8.21 3 6 3M12 5H22V7H12V5M12 19V17H22V19H12M12 11H22V13H12V11Z\";\r\nvar mdiOrderBoolDescendingVariant = \"M4 3C2.89 3 2 3.89 2 5V9C2 10.11 2.89 11 4 11H8C9.11 11 10 10.11 10 9V5C10 3.89 9.11 3 8 3M8.2 4.5L9.26 5.55L5.27 9.5L2.74 6.95L3.81 5.9L5.28 7.39M4 13C2.89 13 2 13.89 2 15V19C2 20.11 2.89 21 4 21H8C9.11 21 10 20.11 10 19V15C10 13.89 9.11 13 8 13M4 15H8V19H4M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12Z\";\r\nvar mdiOrderNumericAscending = \"M7 21H3V19H7V18H5C3.9 18 3 17.11 3 16V15C3 13.9 3.9 13 5 13H7C8.11 13 9 13.9 9 15V19C9 20.11 8.11 21 7 21M7 15H5V16H7M5 3H7C8.11 3 9 3.9 9 5V9C9 10.11 8.11 11 7 11H5C3.9 11 3 10.11 3 9V5C3 3.9 3.9 3 5 3M5 9H7V5H5M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12Z\";\r\nvar mdiOrderNumericDescending = \"M7 11H3V9H7V8H5C3.9 8 3 7.11 3 6V5C3 3.9 3.9 3 5 3H7C8.11 3 9 3.9 9 5V9C9 10.11 8.11 11 7 11M7 5H5V6H7M5 13H7C8.11 13 9 13.9 9 15V19C9 20.11 8.11 21 7 21H5C3.9 21 3 20.11 3 19V15C3 13.9 3.9 13 5 13M5 19H7V15H5M12 5H22V7H12M12 19V17H22V19M12 11H22V13H12Z\";\r\nvar mdiOrigin = \"M12,2.13C12,2.23 11.95,2.33 11.89,2.41C11.5,3 11.16,3.64 11.04,4.33L11,4.56L12,4.5A7.5,7.5 0 0,1 19.5,12C19.5,13.62 19,15.11 18.12,16.34C16.73,18.68 14.72,20.65 12.34,21.97C12.25,22 12.12,22 12.06,21.93C12,21.83 12,21.7 12.09,21.61C12.47,21.09 12.73,20.5 12.87,19.85L12.93,19.44L12,19.5A7.5,7.5 0 0,1 4.5,12C4.5,10.39 5,8.89 5.88,7.67C7.26,5.32 9.28,3.34 11.67,2C11.78,1.95 11.94,2 12,2.13M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiOrnament = \"M12,1A3,3 0 0,1 15,4V5A1,1 0 0,1 16,6V7.07C18.39,8.45 20,11.04 20,14A8,8 0 0,1 12,22A8,8 0 0,1 4,14C4,11.04 5.61,8.45 8,7.07V6A1,1 0 0,1 9,5V4A3,3 0 0,1 12,1M12,3A1,1 0 0,0 11,4V5H13V4A1,1 0 0,0 12,3M12,8C10.22,8 8.63,8.77 7.53,10H16.47C15.37,8.77 13.78,8 12,8M6.34,16H7.59L6,14.43C6.05,15 6.17,15.5 6.34,16M12.59,16L8.59,12H6.41L10.41,16H12.59M17.66,12H16.41L18,13.57C17.95,13 17.83,12.5 17.66,12M11.41,12L15.41,16H17.59L13.59,12H11.41M12,20C13.78,20 15.37,19.23 16.47,18H7.53C8.63,19.23 10.22,20 12,20Z\";\r\nvar mdiOrnamentVariant = \"M12,1A3,3 0 0,1 15,4V5A1,1 0 0,1 16,6V7.07C18.39,8.45 20,11.04 20,14A8,8 0 0,1 12,22A8,8 0 0,1 4,14C4,11.04 5.61,8.45 8,7.07V6A1,1 0 0,1 9,5V4A3,3 0 0,1 12,1M12,3A1,1 0 0,0 11,4V5H13V4A1,1 0 0,0 12,3M12,8C10.22,8 8.63,8.77 7.53,10H16.47C15.37,8.77 13.78,8 12,8M12,20C13.78,20 15.37,19.23 16.47,18H7.53C8.63,19.23 10.22,20 12,20M12,12A2,2 0 0,0 10,14A2,2 0 0,0 12,16A2,2 0 0,0 14,14A2,2 0 0,0 12,12M18,14C18,13.31 17.88,12.65 17.67,12C16.72,12.19 16,13 16,14C16,15 16.72,15.81 17.67,15.97C17.88,15.35 18,14.69 18,14M6,14C6,14.69 6.12,15.35 6.33,15.97C7.28,15.81 8,15 8,14C8,13 7.28,12.19 6.33,12C6.12,12.65 6,13.31 6,14Z\";\r\nvar mdiOutdoorLamp = \"M15 22H13C11.9 22 11 21.1 11 20V15H17V20C17 21.1 16.1 22 15 22M7 14H21L15 9.71V6C15 4.39 13.94 2 11 2S7 4.39 7 6C7 6.45 6.81 7 6 7H5V3H3V12H5V9H6C8.2 9 9 7.21 9 6C9 5.67 9.1 4 11 4C12.83 4 13 5.54 13 6V9.71L7 14Z\";\r\nvar mdiOverscan = \"M12 5.5L10 8H14L12 5.5M18 10V14L20.5 12L18 10M6 10L3.5 12L6 14V10M14 16H10L12 18.5L14 16M21 3H3C1.9 3 1 3.9 1 5V19C1 20.1 1.9 21 3 21H21C22.1 21 23 20.1 23 19V5C23 3.9 22.1 3 21 3M21 19H3V5H21V19Z\";\r\nvar mdiOwl = \"M12,16C12.56,16.84 13.31,17.53 14.2,18L12,20.2L9.8,18C10.69,17.53 11.45,16.84 12,16M17,11.2A2,2 0 0,0 15,13.2A2,2 0 0,0 17,15.2A2,2 0 0,0 19,13.2C19,12.09 18.1,11.2 17,11.2M7,11.2A2,2 0 0,0 5,13.2A2,2 0 0,0 7,15.2A2,2 0 0,0 9,13.2C9,12.09 8.1,11.2 7,11.2M17,8.7A4,4 0 0,1 21,12.7A4,4 0 0,1 17,16.7A4,4 0 0,1 13,12.7A4,4 0 0,1 17,8.7M7,8.7A4,4 0 0,1 11,12.7A4,4 0 0,1 7,16.7A4,4 0 0,1 3,12.7A4,4 0 0,1 7,8.7M2.24,1C4,4.7 2.73,7.46 1.55,10.2C1.19,11 1,11.83 1,12.7A6,6 0 0,0 7,18.7C7.21,18.69 7.42,18.68 7.63,18.65L10.59,21.61L12,23L13.41,21.61L16.37,18.65C16.58,18.68 16.79,18.69 17,18.7A6,6 0 0,0 23,12.7C23,11.83 22.81,11 22.45,10.2C21.27,7.46 20,4.7 21.76,1C19.12,3.06 15.36,4.69 12,4.7C8.64,4.69 4.88,3.06 2.24,1Z\";\r\nvar mdiPacMan = \"M12,12L19.07,19.07C15.17,23 8.83,23 4.93,19.07C1,15.17 1,8.84 4.93,4.93C8.83,1 15.16,1 19.07,4.93L12,12M19,10A2,2 0 0,0 17,12A2,2 0 0,0 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10Z\";\r\nvar mdiPackage = \"M5.12,5H18.87L17.93,4H5.93L5.12,5M20.54,5.23C20.83,5.57 21,6 21,6.5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V6.5C3,6 3.17,5.57 3.46,5.23L4.84,3.55C5.12,3.21 5.53,3 6,3H18C18.47,3 18.88,3.21 19.15,3.55L20.54,5.23M6,18H12V15H6V18Z\";\r\nvar mdiPackageDown = \"M5.12,5L5.93,4H17.93L18.87,5M12,17.5L6.5,12H10V10H14V12H17.5L12,17.5M20.54,5.23L19.15,3.55C18.88,3.21 18.47,3 18,3H6C5.53,3 5.12,3.21 4.84,3.55L3.46,5.23C3.17,5.57 3,6 3,6.5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V6.5C21,6 20.83,5.57 20.54,5.23Z\";\r\nvar mdiPackageUp = \"M20.54,5.23C20.83,5.57 21,6 21,6.5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V6.5C3,6 3.17,5.57 3.46,5.23L4.84,3.55C5.12,3.21 5.53,3 6,3H18C18.47,3 18.88,3.21 19.15,3.55L20.54,5.23M5.12,5H18.87L17.93,4H5.93L5.12,5M12,9.5L6.5,15H10V17H14V15H17.5L12,9.5Z\";\r\nvar mdiPackageVariant = \"M2,10.96C1.5,10.68 1.35,10.07 1.63,9.59L3.13,7C3.24,6.8 3.41,6.66 3.6,6.58L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.66,6.72 20.82,6.88 20.91,7.08L22.36,9.6C22.64,10.08 22.47,10.69 22,10.96L21,11.54V16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V10.96C2.7,11.13 2.32,11.14 2,10.96M12,4.15V4.15L12,10.85V10.85L17.96,7.5L12,4.15M5,15.91L11,19.29V12.58L5,9.21V15.91M19,15.91V12.69L14,15.59C13.67,15.77 13.3,15.76 13,15.6V19.29L19,15.91M13.85,13.36L20.13,9.73L19.55,8.72L13.27,12.35L13.85,13.36Z\";\r\nvar mdiPackageVariantClosed = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M12,4.15L10.11,5.22L16,8.61L17.96,7.5L12,4.15M6.04,7.5L12,10.85L13.96,9.75L8.08,6.35L6.04,7.5M5,15.91L11,19.29V12.58L5,9.21V15.91M19,15.91V9.21L13,12.58V19.29L19,15.91Z\";\r\nvar mdiPageFirst = \"M18.41,16.59L13.82,12L18.41,7.41L17,6L11,12L17,18L18.41,16.59M6,6H8V18H6V6Z\";\r\nvar mdiPageLast = \"M5.59,7.41L10.18,12L5.59,16.59L7,18L13,12L7,6L5.59,7.41M16,6H18V18H16V6Z\";\r\nvar mdiPageLayoutBody = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M6,8V16H18V8H6Z\";\r\nvar mdiPageLayoutFooter = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M6,16V20H18V16H6Z\";\r\nvar mdiPageLayoutHeader = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M6,4V8H18V4H6Z\";\r\nvar mdiPageLayoutHeaderFooter = \"M18 2H6C4.89 2 4 2.9 4 4V20C4 21.11 4.89 22 6 22H18C19.11 22 20 21.11 20 20V4C20 2.9 19.11 2 18 2M18 20H6V16H18V20M18 8H6V4H18V8Z\";\r\nvar mdiPageLayoutSidebarLeft = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M6,8V16H10V8H6Z\";\r\nvar mdiPageLayoutSidebarRight = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M14,8V16H18V8H14Z\";\r\nvar mdiPageNext = \"M20,3H5A2,2 0 0,0 3,5V11H7V9L11,12L7,15V13H3V19A2,2 0 0,0 5,21H20A2,2 0 0,0 22,19V5A2,2 0 0,0 20,3M17,17H13V15H17V17M20,13H13V11H20V13M20,9H13V7H20V9M3,13H0V11H3V13Z\";\r\nvar mdiPageNextOutline = \"M22,3H5A2,2 0 0,0 3,5V9H5V5H22V19H5V15H3V19A2,2 0 0,0 5,21H22A2,2 0 0,0 24,19V5A2,2 0 0,0 22,3M7,15V13H0V11H7V9L11,12L7,15M20,13H13V11H20V13M20,9H13V7H20V9M17,17H13V15H17V17Z\";\r\nvar mdiPagePrevious = \"M4,21H19A2,2 0 0,0 21,19V13H17V15L13,12L17,9V11H21V5A2,2 0 0,0 19,3H4A2,2 0 0,0 2,5V19A2,2 0 0,0 4,21M4,15H8V17H4V15M4,11H11V13H4V11M4,7H11V9H4V7M21,11H24V13H21V11Z\";\r\nvar mdiPagePreviousOutline = \"M2,3H19A2,2 0 0,1 21,5V9H19V5H2V19H19V15H21V19A2,2 0 0,1 19,21H2A2,2 0 0,1 0,19V5A2,2 0 0,1 2,3M17,15V13H24V11H17V9L13,12L17,15M4,13H11V11H4V13M4,9H11V7H4V9M4,17H8V15H4V17Z\";\r\nvar mdiPail = \"M11.5 7.63C11.97 7.35 12.58 7.5 12.86 8C13.14 8.47 12.97 9.09 12.5 9.36L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L11.5 7.63M7 21L5.79 14.97L13.21 10.69C14 10.26 14.5 9.44 14.5 8.5C14.5 7.12 13.38 6 12 6C11.53 6 11.09 6.13 10.71 6.36L4.76 9.79L4 6H3V4H21V6H20L17 21H7Z\";\r\nvar mdiPailMinus = \"M12.5 9.36L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L11.5 7.63C11.97 7.35 12.58 7.5 12.86 8C13.14 8.47 12.97 9.09 12.5 9.36M13 19C13 15.82 15.47 13.23 18.6 13L20 6H21V4H3V6H4L4.76 9.79L10.71 6.36C11.09 6.13 11.53 6 12 6C13.38 6 14.5 7.12 14.5 8.5C14.5 9.44 14 10.26 13.21 10.69L5.79 14.97L7 21H13.35C13.13 20.37 13 19.7 13 19M15 18V20H23V18H15Z\";\r\nvar mdiPailMinusOutline = \"M4 6H3V4H21V6H20L18.6 13C17.83 13.07 17.11 13.26 16.45 13.58L17.96 6H6.04L6.5 8.22L4.65 9.27L4 6M12.86 8C12.58 7.5 11.97 7.35 11.5 7.63L3.27 12.38C2.79 12.66 2.62 13.27 2.9 13.75C3.18 14.23 3.79 14.39 4.27 14.11L12.5 9.36C12.97 9.09 13.14 8.47 12.86 8M13 19H8.64L7.73 14.43L5.9 15.5L7 21H13.35C13.13 20.37 13 19.7 13 19M15 18V20H23V18H15Z\";\r\nvar mdiPailOff = \"M20.84 22.73L17.35 19.24L17 21H7L5.79 14.97L10.41 12.3L9.31 11.2L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L7.85 9.74L6.75 8.64L4.76 9.79L4 6H3V4.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M10.71 6.36C11.09 6.13 11.53 6 12 6C13.38 6 14.5 7.12 14.5 8.5C14.5 9.27 14.16 9.94 13.6 10.4L18.2 15L20 6H21V4H7.2L10 6.78L10.71 6.36M11.5 7.63L11.08 7.88L12.53 9.33C12.97 9.05 13.13 8.46 12.86 8C12.58 7.5 11.97 7.35 11.5 7.63Z\";\r\nvar mdiPailOffOutline = \"M20.84 22.73L17.35 19.24L17 21H7L5.9 15.5L7.73 14.43L8.64 19H15.36L15.65 17.54L9.31 11.2L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L7.85 9.74L6.38 8.27L4.65 9.27L4 6H3V4.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M17.96 6L16.5 13.3L18.2 15L20 6H21V4H7.2L9.2 6H17.96M11.5 7.63L11.08 7.88L12.53 9.33C12.97 9.05 13.13 8.46 12.86 8C12.58 7.5 11.97 7.35 11.5 7.63Z\";\r\nvar mdiPailOutline = \"M11.5 7.63C11.97 7.35 12.58 7.5 12.86 8C13.14 8.47 12.97 9.09 12.5 9.36L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75S2.79 12.66 3.27 12.38L11.5 7.63M3 4V6H4L4.65 9.27L6.5 8.22L6.04 6H17.96L15.36 19H8.64L7.73 14.43L5.9 15.5L7 21H17L20 6H21V4H3Z\";\r\nvar mdiPailPlus = \"M12.5 9.36L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L11.5 7.63C11.97 7.35 12.58 7.5 12.86 8C13.14 8.47 12.97 9.09 12.5 9.36M13 19C13 15.82 15.47 13.23 18.6 13L20 6H21V4H3V6H4L4.76 9.79L10.71 6.36C11.09 6.13 11.53 6 12 6C13.38 6 14.5 7.12 14.5 8.5C14.5 9.44 14 10.26 13.21 10.69L5.79 14.97L7 21H13.35C13.13 20.37 13 19.7 13 19M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiPailPlusOutline = \"M4 6H3V4H21V6H20L18.6 13C17.83 13.07 17.11 13.26 16.45 13.58L17.96 6H6.04L6.5 8.22L4.65 9.27L4 6M12.86 8C12.58 7.5 11.97 7.35 11.5 7.63L3.27 12.38C2.79 12.66 2.62 13.27 2.9 13.75C3.18 14.23 3.79 14.39 4.27 14.11L12.5 9.36C12.97 9.09 13.14 8.47 12.86 8M13 19H8.64L7.73 14.43L5.9 15.5L7 21H13.35C13.13 20.37 13 19.7 13 19M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiPailRemove = \"M12.5 9.36L4.27 14.11C3.79 14.39 3.18 14.23 2.9 13.75C2.62 13.27 2.79 12.66 3.27 12.38L11.5 7.63C11.97 7.35 12.58 7.5 12.86 8C13.14 8.47 12.97 9.09 12.5 9.36M13 19C13 15.82 15.47 13.23 18.6 13L20 6H21V4H3V6H4L4.76 9.79L10.71 6.36C11.09 6.13 11.53 6 12 6C13.38 6 14.5 7.12 14.5 8.5C14.5 9.44 14 10.26 13.21 10.69L5.79 14.97L7 21H13.35C13.13 20.37 13 19.7 13 19M21.12 15.46L19 17.59L16.88 15.46L15.47 16.88L17.59 19L15.47 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88L21.12 15.46Z\";\r\nvar mdiPailRemoveOutline = \"M4 6H3V4H21V6H20L18.6 13C17.83 13.07 17.11 13.26 16.45 13.58L17.96 6H6.04L6.5 8.22L4.65 9.27L4 6M12.86 8C12.58 7.5 11.97 7.35 11.5 7.63L3.27 12.38C2.79 12.66 2.62 13.27 2.9 13.75C3.18 14.23 3.79 14.39 4.27 14.11L12.5 9.36C12.97 9.09 13.14 8.47 12.86 8M13 19H8.64L7.73 14.43L5.9 15.5L7 21H13.35C13.13 20.37 13 19.7 13 19M21.12 15.46L19 17.59L16.88 15.46L15.46 16.88L17.58 19L15.46 21.12L16.87 22.54L19 20.41L21.12 22.54L22.53 21.12L20.41 19L22.53 16.88L21.12 15.46Z\";\r\nvar mdiPalette = \"M17.5,12A1.5,1.5 0 0,1 16,10.5A1.5,1.5 0 0,1 17.5,9A1.5,1.5 0 0,1 19,10.5A1.5,1.5 0 0,1 17.5,12M14.5,8A1.5,1.5 0 0,1 13,6.5A1.5,1.5 0 0,1 14.5,5A1.5,1.5 0 0,1 16,6.5A1.5,1.5 0 0,1 14.5,8M9.5,8A1.5,1.5 0 0,1 8,6.5A1.5,1.5 0 0,1 9.5,5A1.5,1.5 0 0,1 11,6.5A1.5,1.5 0 0,1 9.5,8M6.5,12A1.5,1.5 0 0,1 5,10.5A1.5,1.5 0 0,1 6.5,9A1.5,1.5 0 0,1 8,10.5A1.5,1.5 0 0,1 6.5,12M12,3A9,9 0 0,0 3,12A9,9 0 0,0 12,21A1.5,1.5 0 0,0 13.5,19.5C13.5,19.11 13.35,18.76 13.11,18.5C12.88,18.23 12.73,17.88 12.73,17.5A1.5,1.5 0 0,1 14.23,16H16A5,5 0 0,0 21,11C21,6.58 16.97,3 12,3Z\";\r\nvar mdiPaletteAdvanced = \"M22,22H10V20H22V22M2,22V20H9V22H2M18,18V10H22V18H18M18,3H22V9H18V3M2,18V3H16V18H2M9,14.56A3,3 0 0,0 12,11.56C12,9.56 9,6.19 9,6.19C9,6.19 6,9.56 6,11.56A3,3 0 0,0 9,14.56Z\";\r\nvar mdiPaletteOutline = \"M12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2C17.5,2 22,6 22,11A6,6 0 0,1 16,17H14.2C13.9,17 13.7,17.2 13.7,17.5C13.7,17.6 13.8,17.7 13.8,17.8C14.2,18.3 14.4,18.9 14.4,19.5C14.5,20.9 13.4,22 12,22M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20C12.3,20 12.5,19.8 12.5,19.5C12.5,19.3 12.4,19.2 12.4,19.1C12,18.6 11.8,18.1 11.8,17.5C11.8,16.1 12.9,15 14.3,15H16A4,4 0 0,0 20,11C20,7.1 16.4,4 12,4M6.5,10C7.3,10 8,10.7 8,11.5C8,12.3 7.3,13 6.5,13C5.7,13 5,12.3 5,11.5C5,10.7 5.7,10 6.5,10M9.5,6C10.3,6 11,6.7 11,7.5C11,8.3 10.3,9 9.5,9C8.7,9 8,8.3 8,7.5C8,6.7 8.7,6 9.5,6M14.5,6C15.3,6 16,6.7 16,7.5C16,8.3 15.3,9 14.5,9C13.7,9 13,8.3 13,7.5C13,6.7 13.7,6 14.5,6M17.5,10C18.3,10 19,10.7 19,11.5C19,12.3 18.3,13 17.5,13C16.7,13 16,12.3 16,11.5C16,10.7 16.7,10 17.5,10Z\";\r\nvar mdiPaletteSwatch = \"M2.53,19.65L3.87,20.21V11.18L1.44,17.04C1.03,18.06 1.5,19.23 2.53,19.65M22.03,15.95L17.07,4C16.76,3.23 16.03,2.77 15.26,2.75C15,2.75 14.73,2.79 14.47,2.9L7.1,5.95C6.35,6.26 5.89,7 5.87,7.75C5.86,8 5.91,8.29 6,8.55L11,20.5C11.29,21.28 12.03,21.74 12.81,21.75C13.07,21.75 13.33,21.7 13.58,21.6L20.94,18.55C21.96,18.13 22.45,16.96 22.03,15.95M7.88,8.75A1,1 0 0,1 6.88,7.75A1,1 0 0,1 7.88,6.75C8.43,6.75 8.88,7.2 8.88,7.75C8.88,8.3 8.43,8.75 7.88,8.75M5.88,19.75A2,2 0 0,0 7.88,21.75H9.33L5.88,13.41V19.75Z\";\r\nvar mdiPaletteSwatchOutline = \"M2.5 19.6L3.8 20.2V11.2L1.4 17C1 18.1 1.5 19.2 2.5 19.6M15.2 4.8L20.2 16.8L12.9 19.8L7.9 7.9V7.8L15.2 4.8M15.3 2.8C15 2.8 14.8 2.8 14.5 2.9L7.1 6C6.4 6.3 5.9 7 5.9 7.8C5.9 8 5.9 8.3 6 8.6L11 20.5C11.3 21.3 12 21.7 12.8 21.7C13.1 21.7 13.3 21.7 13.6 21.6L21 18.5C22 18.1 22.5 16.9 22.1 15.9L17.1 4C16.8 3.2 16 2.8 15.3 2.8M10.5 9.9C9.9 9.9 9.5 9.5 9.5 8.9S9.9 7.9 10.5 7.9C11.1 7.9 11.5 8.4 11.5 8.9S11.1 9.9 10.5 9.9M5.9 19.8C5.9 20.9 6.8 21.8 7.9 21.8H9.3L5.9 13.5V19.8Z\";\r\nvar mdiPalmTree = \"M12 9C13.59 16.61 10 22 10 22H13C14.88 16.2 14 12.09 13.5 10M15.66 7.16C15.83 7.37 16 7.59 16.13 7.82C17.84 10.53 17.5 13.95 15.5 16.26C16.34 14.21 16.22 11.79 14.95 9.77C14.87 9.64 14.78 9.53 14.7 9.41C14.11 8.58 13.36 7.92 12.54 7.43C9.66 8.35 7.58 11.04 7.58 14.22C7.58 14.96 7.69 15.67 7.89 16.33C7.05 15.16 6.56 13.73 6.56 12.19C6.56 9.84 7.7 7.76 9.45 6.46C8 6.35 6.46 6.67 5.12 7.5C4.5 7.91 3.96 8.38 3.5 8.91C4.05 7.58 5 6.39 6.3 5.57C7.8 4.63 9.5 4.32 11.14 4.56C10.73 4 10.23 3.47 9.63 3C9.05 2.58 8.42 2.24 7.76 2C9.2 2.04 10.64 2.5 11.87 3.43C12.5 3.9 13 4.47 13.4 5.07C13.5 5.07 13.59 5.06 13.69 5.06C16.89 5.06 19.6 7.17 20.5 10.08C19.38 8.5 17.65 7.43 15.66 7.16Z\";\r\nvar mdiPan = \"M12,2.5L8,7H16L12,2.5M7,8L2.5,12L7,16V8M17,8V16L21.5,12L17,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M8,17L12,21.5L16,17H8Z\";\r\nvar mdiPanBottomLeft = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M5.35,13L11,18.65L5,19L5.35,13Z\";\r\nvar mdiPanBottomRight = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M13,18.65L18.65,13L19,19L13,18.65Z\";\r\nvar mdiPanDown = \"M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M8,17L12,21.5L16,17H8Z\";\r\nvar mdiPanHorizontal = \"M7,8L2.5,12L7,16V8M17,8V16L21.5,12L17,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiPanLeft = \"M7,8L2.5,12L7,16V8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiPanRight = \"M17,8V16L21.5,12L17,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiPanTopLeft = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M11,5.35L5.35,11L5,5L11,5.35Z\";\r\nvar mdiPanTopRight = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M18.65,11L13,5.35L19,5L18.65,11Z\";\r\nvar mdiPanUp = \"M12,2.5L8,7H16L12,2.5M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiPanVertical = \"M12,2.5L8,7H16L12,2.5M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M8,17L12,21.5L16,17H8Z\";\r\nvar mdiPanda = \"M12,3C13.74,3 15.36,3.5 16.74,4.35C17.38,3.53 18.38,3 19.5,3A3.5,3.5 0 0,1 23,6.5C23,8 22.05,9.28 20.72,9.78C20.9,10.5 21,11.23 21,12A9,9 0 0,1 12,21A9,9 0 0,1 3,12C3,11.23 3.1,10.5 3.28,9.78C1.95,9.28 1,8 1,6.5A3.5,3.5 0 0,1 4.5,3C5.62,3 6.62,3.53 7.26,4.35C8.64,3.5 10.26,3 12,3M12,5A7,7 0 0,0 5,12A7,7 0 0,0 12,19A7,7 0 0,0 19,12A7,7 0 0,0 12,5M16.19,10.3C16.55,11.63 16.08,12.91 15.15,13.16C14.21,13.42 13.17,12.54 12.81,11.2C12.45,9.87 12.92,8.59 13.85,8.34C14.79,8.09 15.83,8.96 16.19,10.3M7.81,10.3C8.17,8.96 9.21,8.09 10.15,8.34C11.08,8.59 11.55,9.87 11.19,11.2C10.83,12.54 9.79,13.42 8.85,13.16C7.92,12.91 7.45,11.63 7.81,10.3M12,14C12.6,14 13.13,14.19 13.5,14.5L12.5,15.5C12.5,15.92 12.84,16.25 13.25,16.25A0.75,0.75 0 0,0 14,15.5A0.5,0.5 0 0,1 14.5,15A0.5,0.5 0 0,1 15,15.5A1.75,1.75 0 0,1 13.25,17.25C12.76,17.25 12.32,17.05 12,16.72C11.68,17.05 11.24,17.25 10.75,17.25A1.75,1.75 0 0,1 9,15.5A0.5,0.5 0 0,1 9.5,15A0.5,0.5 0 0,1 10,15.5A0.75,0.75 0 0,0 10.75,16.25A0.75,0.75 0 0,0 11.5,15.5L10.5,14.5C10.87,14.19 11.4,14 12,14Z\";\r\nvar mdiPandora = \"M10,20A1,1 0 0,1 9,21H4V3H13.71A6.75,6.75 0 0,1 20.46,9.75C20.46,13.5 17.44,16.5 13.71,16.5H10V20Z\";\r\nvar mdiPanorama = \"M8.5,12.5L11,15.5L14.5,11L19,17H5M23,18V6A2,2 0 0,0 21,4H3A2,2 0 0,0 1,6V18A2,2 0 0,0 3,20H21A2,2 0 0,0 23,18Z\";\r\nvar mdiPanoramaFisheye = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22C17.53,22 22,17.53 22,12C22,6.47 17.53,2 12,2Z\";\r\nvar mdiPanoramaHorizontal = \"M21.43,4C21.33,4 21.23,4 21.12,4.06C18.18,5.16 15.09,5.7 12,5.7C8.91,5.7 5.82,5.15 2.88,4.06C2.77,4 2.66,4 2.57,4C2.23,4 2,4.23 2,4.63V19.38C2,19.77 2.23,20 2.57,20C2.67,20 2.77,20 2.88,19.94C5.82,18.84 8.91,18.3 12,18.3C15.09,18.3 18.18,18.85 21.12,19.94C21.23,20 21.33,20 21.43,20C21.76,20 22,19.77 22,19.37V4.63C22,4.23 21.76,4 21.43,4M20,6.54V17.45C17.4,16.68 14.72,16.29 12,16.29C9.28,16.29 6.6,16.68 4,17.45V6.54C6.6,7.31 9.28,7.7 12,7.7C14.72,7.71 17.4,7.32 20,6.54Z\";\r\nvar mdiPanoramaVertical = \"M6.54,20C7.31,17.4 7.7,14.72 7.7,12C7.7,9.28 7.31,6.6 6.54,4H17.45C16.68,6.6 16.29,9.28 16.29,12C16.29,14.72 16.68,17.4 17.45,20M19.94,21.12C18.84,18.18 18.3,15.09 18.3,12C18.3,8.91 18.85,5.82 19.94,2.88C20,2.77 20,2.66 20,2.57C20,2.23 19.77,2 19.37,2H4.63C4.23,2 4,2.23 4,2.57C4,2.67 4,2.77 4.06,2.88C5.16,5.82 5.71,8.91 5.71,12C5.71,15.09 5.16,18.18 4.07,21.12C4,21.23 4,21.34 4,21.43C4,21.76 4.23,22 4.63,22H19.38C19.77,22 20,21.76 20,21.43C20,21.33 20,21.23 19.94,21.12Z\";\r\nvar mdiPanoramaWideAngle = \"M12,4C9.27,4 6.78,4.24 4.05,4.72L3.12,4.88L2.87,5.78C2.29,7.85 2,9.93 2,12C2,14.07 2.29,16.15 2.87,18.22L3.12,19.11L4.05,19.27C6.78,19.76 9.27,20 12,20C14.73,20 17.22,19.76 19.95,19.28L20.88,19.12L21.13,18.23C21.71,16.15 22,14.07 22,12C22,9.93 21.71,7.85 21.13,5.78L20.88,4.89L19.95,4.73C17.22,4.24 14.73,4 12,4M12,6C14.45,6 16.71,6.2 19.29,6.64C19.76,8.42 20,10.22 20,12C20,13.78 19.76,15.58 19.29,17.36C16.71,17.8 14.45,18 12,18C9.55,18 7.29,17.8 4.71,17.36C4.24,15.58 4,13.78 4,12C4,10.22 4.24,8.42 4.71,6.64C7.29,6.2 9.55,6 12,6Z\";\r\nvar mdiPaperCutVertical = \"M11.43,3.23L12,4L12.57,3.23V3.24C13.12,2.5 14,2 15,2A3,3 0 0,1 18,5C18,5.35 17.94,5.69 17.83,6H20A2,2 0 0,1 22,8V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V8A2,2 0 0,1 4,6H6.17C6.06,5.69 6,5.35 6,5A3,3 0 0,1 9,2C10,2 10.88,2.5 11.43,3.24V3.23M4,8V20H11A1,1 0 0,1 12,19A1,1 0 0,1 13,20H20V8H15L14.9,8L17,10.92L15.4,12.1L12.42,8H11.58L8.6,12.1L7,10.92L9.1,8H9L4,8M9,4A1,1 0 0,0 8,5A1,1 0 0,0 9,6A1,1 0 0,0 10,5A1,1 0 0,0 9,4M15,4A1,1 0 0,0 14,5A1,1 0 0,0 15,6A1,1 0 0,0 16,5A1,1 0 0,0 15,4M12,16A1,1 0 0,1 13,17A1,1 0 0,1 12,18A1,1 0 0,1 11,17A1,1 0 0,1 12,16M12,13A1,1 0 0,1 13,14A1,1 0 0,1 12,15A1,1 0 0,1 11,14A1,1 0 0,1 12,13M12,10A1,1 0 0,1 13,11A1,1 0 0,1 12,12A1,1 0 0,1 11,11A1,1 0 0,1 12,10Z\";\r\nvar mdiPaperRoll = \"M9 3C5.69 3 3.14 5.69 3 9V21H12V13.46C13.1 14.45 14.5 15 16 15C19.31 15 22 12.31 22 9C22 5.69 19.31 3 16 3H9M16 5C18.21 5 20 6.79 20 9C20 11.21 18.21 13 16 13C13.79 13 12 11.21 12 9C12 6.79 13.79 5 16 5M16 7.25C15.03 7.25 14.25 8.03 14.25 9C14.25 9.97 15.03 10.75 16 10.75C16.97 10.75 17.75 9.97 17.75 9C17.75 8.03 16.97 7.25 16 7.25M4 12H5V13H4V12M6 12H7V13H6V12M8 12H9V13H8V12M10 12H11V13H10V12Z\";\r\nvar mdiPaperRollOutline = \"M9 3C5.69 3 3.14 5.69 3 9V21H12V13.46C13.1 14.45 14.5 15 16 15C19.31 15 22 12.31 22 9C22 5.69 19.31 3 16 3H9M9 5H11.54C10.55 6.1 10 7.5 10 9V12H9V13H10V19H5V13H6V12H5V9C5 6.79 6.79 5 9 5M16 5C18.21 5 20 6.79 20 9C20 11.21 18.21 13 16 13C13.79 13 12 11.21 12 9C12 6.79 13.79 5 16 5M16 7.25C15.03 7.25 14.25 8.03 14.25 9C14.25 9.97 15.03 10.75 16 10.75C16.97 10.75 17.75 9.97 17.75 9C17.75 8.03 16.97 7.25 16 7.25M7 12V13H8V12H7Z\";\r\nvar mdiPaperclip = \"M16.5,6V17.5A4,4 0 0,1 12.5,21.5A4,4 0 0,1 8.5,17.5V5A2.5,2.5 0 0,1 11,2.5A2.5,2.5 0 0,1 13.5,5V15.5A1,1 0 0,1 12.5,16.5A1,1 0 0,1 11.5,15.5V6H10V15.5A2.5,2.5 0 0,0 12.5,18A2.5,2.5 0 0,0 15,15.5V5A4,4 0 0,0 11,1A4,4 0 0,0 7,5V17.5A5.5,5.5 0 0,0 12.5,23A5.5,5.5 0 0,0 18,17.5V6H16.5Z\";\r\nvar mdiParachute = \"M21.2,10.95L12,23L2.78,10.96L2.87,10.88C3.08,10.67 3.33,10.5 3.58,10.36L10.73,19.69L8.58,13L9.24,11.81L12,20.38L14.73,11.8L15.4,13L13.27,19.69L20.41,10.35C20.66,10.5 20.9,10.64 21.1,10.85L21.2,10.95M5,9C6.5,9 7.81,9.86 8.5,11.1C9.17,9.86 10.47,9 12,9C13.5,9 14.8,9.85 15.5,11.09C16.16,9.84 17.47,9 19,9C20.09,9 21.09,9.42 21.81,10.14C20.94,5.5 16.88,2 12,2C7.09,2 3.03,5.5 2.16,10.17C2.89,9.45 3.89,9 5,9Z\";\r\nvar mdiParachuteOutline = \"M21.2,10.95L12,23L2.78,10.96L2.87,10.88C3.08,10.67 3.33,10.5 3.58,10.36L10.73,19.69L8.58,13L9.24,11.81L12,20.38L14.73,11.8L15.4,13L13.27,19.69L20.41,10.35C20.66,10.5 20.9,10.64 21.1,10.85L21.2,10.95M12,4C14.5,4 16.77,5.17 18.25,7.03C17.24,7.15 16.28,7.54 15.47,8.13C14.47,7.41 13.26,7 12,7C10.71,7 9.5,7.41 8.5,8.14C7.68,7.55 6.72,7.17 5.71,7.04C7.19,5.17 9.47,4 12,4M12,2C7.09,2 3.03,5.5 2.16,10.17C2.89,9.45 3.89,9 5,9C6.5,9 7.81,9.86 8.5,11.1C9.17,9.86 10.47,9 12,9C13.5,9 14.8,9.85 15.5,11.09C16.16,9.84 17.47,9 19,9C20.09,9 21.09,9.42 21.81,10.14C20.94,5.5 16.88,2 12,2Z\";\r\nvar mdiParking = \"M13.2,11H10V7H13.2A2,2 0 0,1 15.2,9A2,2 0 0,1 13.2,11M13,3H6V21H10V15H13A6,6 0 0,0 19,9C19,5.68 16.31,3 13,3Z\";\r\nvar mdiPartyPopper = \"M14.53 1.45L13.45 2.53L15.05 4.13C15.27 4.38 15.38 4.67 15.38 5S15.27 5.64 15.05 5.86L11.5 9.47L12.5 10.55L16.13 6.94C16.66 6.35 16.92 5.7 16.92 5C16.92 4.3 16.66 3.64 16.13 3.05L14.53 1.45M10.55 3.47L9.47 4.55L10.08 5.11C10.3 5.33 10.41 5.63 10.41 6S10.3 6.67 10.08 6.89L9.47 7.45L10.55 8.53L11.11 7.92C11.64 7.33 11.91 6.69 11.91 6C11.91 5.28 11.64 4.63 11.11 4.03L10.55 3.47M21 5.06C20.31 5.06 19.67 5.33 19.08 5.86L13.45 11.5L14.53 12.5L20.11 6.94C20.36 6.69 20.66 6.56 21 6.56S21.64 6.69 21.89 6.94L22.5 7.55L23.53 6.47L22.97 5.86C22.38 5.33 21.72 5.06 21 5.06M7 8L2 22L16 17L7 8M19 11.06C18.3 11.06 17.66 11.33 17.06 11.86L15.47 13.45L16.55 14.53L18.14 12.94C18.39 12.69 18.67 12.56 19 12.56C19.33 12.56 19.63 12.69 19.88 12.94L21.5 14.53L22.55 13.5L20.95 11.86C20.36 11.33 19.7 11.06 19 11.06Z\";\r\nvar mdiPassport = \"M6,2A2,2 0 0,0 4,4V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2H6M12,5A5,5 0 0,1 17,10A5,5 0 0,1 12,15A5,5 0 0,1 7,10A5,5 0 0,1 12,5M12,6C11.59,6.62 11.25,7.29 11.04,8H12.96C12.75,7.29 12.42,6.62 12,6M10.7,6.22C9.78,6.53 9,7.17 8.54,8H10C10.18,7.38 10.4,6.78 10.7,6.22M13.29,6.22C13.59,6.78 13.82,7.38 14,8H15.46C15,7.17 14.21,6.54 13.29,6.22M8.13,9C8.05,9.32 8,9.65 8,10C8,10.35 8.05,10.68 8.13,11H9.82C9.78,10.67 9.75,10.34 9.75,10C9.75,9.66 9.78,9.33 9.82,9H8.13M10.83,9C10.78,9.32 10.75,9.66 10.75,10C10.75,10.34 10.78,10.67 10.83,11H13.17C13.21,10.67 13.25,10.34 13.25,10C13.25,9.66 13.21,9.32 13.17,9H10.83M14.18,9C14.22,9.33 14.25,9.66 14.25,10C14.25,10.34 14.22,10.67 14.18,11H15.87C15.95,10.68 16,10.35 16,10C16,9.65 15.95,9.32 15.87,9H14.18M8.54,12C9,12.83 9.78,13.46 10.7,13.78C10.4,13.22 10.18,12.63 10,12H8.54M11.04,12C11.25,12.72 11.59,13.38 12,14C12.42,13.38 12.75,12.72 12.96,12H11.04M14,12C13.82,12.63 13.59,13.22 13.29,13.78C14.21,13.46 15,12.83 15.46,12H14M7,17H17V19H7V17Z\";\r\nvar mdiPassportBiometric = \"M4,4A2,2 0 0,0 2,6V11H8.13C8.59,9.24 10.18,8 12,8C13.82,8 15.41,9.24 15.87,11H22V6A2,2 0 0,0 20,4H4M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10M2,13V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V13H15.87C15.41,14.76 13.82,16 12,16C10.18,16 8.59,14.76 8.13,13H2Z\";\r\nvar mdiPasta = \"M4 16.5V8H3V7H4V6H3V5H4V4H3V3H9C9.5 3.03 9.95 3.24 10.34 3.63S10.95 4.5 11 5H21V6H11C10.95 6.53 10.73 7 10.34 7.43S9.5 8.05 9 8H7V15.05C7.05 15.05 7.13 15.04 7.24 15S7.44 15 7.5 15C8.06 15 8.7 15.14 9.42 15.42C9.83 14.5 10.53 13.68 11.53 13S13.53 12 14.53 12C16.06 12 17.36 12.53 18.42 13.59S20 15.95 20 17.5C20 17.55 20 17.64 20 17.77S19.97 17.97 19.97 18H3.14C3.27 17.5 3.55 17 4 16.5M6 15.23V8H5V15.7C5.5 15.45 5.81 15.3 6 15.23M9 7V6H7V7H9M9 4H7V5H9V4M5 4V5H6V4H5M5 6V7H6V6H5M2 19H22L20 21H4L2 19Z\";\r\nvar mdiPatioHeater = \"M15 22H9V21H15V22M19 4L15 2H9L5 4H19M8 5L8.4 6H15.6L16 5H8M10 10H11V15C10.4 15 10 15.4 10 16V20H14V16C14 15.4 13.6 15 13 15V10H14L14.4 9H9.6L10 10M9.2 8H14.8L15.2 7H8.8L9.2 8Z\";\r\nvar mdiPatreon = \"M14.82 2.41C18.78 2.41 22 5.65 22 9.62C22 13.58 18.78 16.8 14.82 16.8C10.85 16.8 7.61 13.58 7.61 9.62C7.61 5.65 10.85 2.41 14.82 2.41M2 21.6H5.5V2.41H2V21.6Z\";\r\nvar mdiPause = \"M14,19H18V5H14M6,19H10V5H6V19Z\";\r\nvar mdiPauseCircle = \"M15,16H13V8H15M11,16H9V8H11M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiPauseCircleOutline = \"M13,16V8H15V16H13M9,16V8H11V16H9M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiPauseOctagon = \"M15.73,3L21,8.27V15.73L15.73,21H8.27L3,15.73V8.27L8.27,3H15.73M15,16V8H13V16H15M11,16V8H9V16H11Z\";\r\nvar mdiPauseOctagonOutline = \"M15,16H13V8H15V16M11,16H9V8H11V16M15.73,3L21,8.27V15.73L15.73,21H8.27L3,15.73V8.27L8.27,3H15.73M14.9,5H9.1L5,9.1V14.9L9.1,19H14.9L19,14.9V9.1L14.9,5Z\";\r\nvar mdiPaw = \"M8.35,3C9.53,2.83 10.78,4.12 11.14,5.9C11.5,7.67 10.85,9.25 9.67,9.43C8.5,9.61 7.24,8.32 6.87,6.54C6.5,4.77 7.17,3.19 8.35,3M15.5,3C16.69,3.19 17.35,4.77 17,6.54C16.62,8.32 15.37,9.61 14.19,9.43C13,9.25 12.35,7.67 12.72,5.9C13.08,4.12 14.33,2.83 15.5,3M3,7.6C4.14,7.11 5.69,8 6.5,9.55C7.26,11.13 7,12.79 5.87,13.28C4.74,13.77 3.2,12.89 2.41,11.32C1.62,9.75 1.9,8.08 3,7.6M21,7.6C22.1,8.08 22.38,9.75 21.59,11.32C20.8,12.89 19.26,13.77 18.13,13.28C17,12.79 16.74,11.13 17.5,9.55C18.31,8 19.86,7.11 21,7.6M19.33,18.38C19.37,19.32 18.65,20.36 17.79,20.75C16,21.57 13.88,19.87 11.89,19.87C9.9,19.87 7.76,21.64 6,20.75C5,20.26 4.31,18.96 4.44,17.88C4.62,16.39 6.41,15.59 7.47,14.5C8.88,13.09 9.88,10.44 11.89,10.44C13.89,10.44 14.95,13.05 16.3,14.5C17.41,15.72 19.26,16.75 19.33,18.38Z\";\r\nvar mdiPawOff = \"M2,4.27L3.28,3L21.5,21.22L20.23,22.5L18.23,20.5C18.09,20.6 17.94,20.68 17.79,20.75C16,21.57 13.88,19.87 11.89,19.87C9.9,19.87 7.76,21.64 6,20.75C5,20.26 4.31,18.96 4.44,17.88C4.62,16.39 6.41,15.59 7.47,14.5C8.21,13.77 8.84,12.69 9.55,11.82L2,4.27M8.35,3C9.53,2.83 10.78,4.12 11.14,5.9C11.32,6.75 11.26,7.56 11,8.19L7.03,4.2C7.29,3.55 7.75,3.1 8.35,3M15.5,3C16.69,3.19 17.35,4.77 17,6.54C16.62,8.32 15.37,9.61 14.19,9.43C13,9.25 12.35,7.67 12.72,5.9C13.08,4.12 14.33,2.83 15.5,3M3,7.6C4.14,7.11 5.69,8 6.5,9.55C7.26,11.13 7,12.79 5.87,13.28C4.74,13.77 3.2,12.89 2.41,11.32C1.62,9.75 1.9,8.08 3,7.6M21,7.6C22.1,8.08 22.38,9.75 21.59,11.32C20.8,12.89 19.26,13.77 18.13,13.28C17,12.79 16.74,11.13 17.5,9.55C18.31,8 19.86,7.11 21,7.6Z\";\r\nvar mdiPdfBox = \"M12,10.5H13V13.5H12V10.5M7,11.5H8V10.5H7V11.5M20,6V18A2,2 0 0,1 18,20H6A2,2 0 0,1 4,18V6A2,2 0 0,1 6,4H18A2,2 0 0,1 20,6M9.5,10.5A1.5,1.5 0 0,0 8,9H5.5V15H7V13H8A1.5,1.5 0 0,0 9.5,11.5V10.5M14.5,10.5A1.5,1.5 0 0,0 13,9H10.5V15H13A1.5,1.5 0 0,0 14.5,13.5V10.5M18.5,9H15.5V15H17V13H18.5V11.5H17V10.5H18.5V9Z\";\r\nvar mdiPeace = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M11,14.41V19.93C9.58,19.75 8.23,19.19 7.1,18.31L11,14.41M13,14.41L16.9,18.31C15.77,19.19 14.42,19.75 13,19.93V14.41M4,12C4,7.97 7,4.57 11,4.07V11.59L5.69,16.9C4.59,15.5 4,13.78 4,12M18.31,16.9L13,11.59V4.07C17,4.57 20,7.97 20,12C20,13.78 19.41,15.5 18.31,16.9Z\";\r\nvar mdiPeanut = \"M16 12.77A2 2 0 0 1 15.86 10.12A5 5 0 0 0 13.04 2.12A5.74 5.74 0 0 0 12 2A5 5 0 0 0 7 7A5 5 0 0 0 8.11 10.12A2 2 0 0 1 8 12.72A5.5 5.5 0 0 0 10.81 21.87A5.42 5.42 0 0 0 12 22A5.5 5.5 0 0 0 16 12.77M13 5A1 1 0 1 1 12 6A1 1 0 0 1 13 5M11 18A1 1 0 1 1 12 17A1 1 0 0 1 11 18M12 15A1 1 0 1 1 13 16A1 1 0 0 1 12 15M14 19A1 1 0 1 1 15 18A1 1 0 0 1 14 19Z\";\r\nvar mdiPeanutOff = \"M15.9 10.12A5 5 0 0 0 13.08 2.12A5.74 5.74 0 0 0 12 2A5 5 0 0 0 7.68 4.5L16.38 13.18A4.35 4.35 0 0 0 16.04 12.77A2 2 0 0 1 15.9 10.12M13 7A1 1 0 1 1 14 6A1 1 0 0 1 13 7M7 6.39L2.39 1.73L1.11 3L7.8 9.69C7.9 9.84 8 10 8.11 10.12A2 2 0 0 1 8 12.72A5.5 5.5 0 0 0 10.81 21.87A5.42 5.42 0 0 0 12 22A5.5 5.5 0 0 0 17 18.86L20.87 22.73L22.14 21.46M11 18A1 1 0 1 1 12 17A1 1 0 0 1 11 18M14 19A1 1 0 1 1 15 18A1 1 0 0 1 14 19M13 16A1 1 0 0 1 12 15A1 1 0 0 1 12.35 14.24L13.76 15.65A1 1 0 0 1 13 16Z\";\r\nvar mdiPeanutOffOutline = \"M22.11 21.46L20.84 22.73L17.69 19.58C17.36 20.21 16.93 20.77 16.41 21.25C14.86 22.71 12.69 23.31 10.61 22.85C7.1 22.1 4.87 18.64 5.62 15.13C5.87 13.95 6.45 12.87 7.28 12C7.62 11.64 7.62 11.08 7.28 10.72C6.63 9.91 6.21 8.95 6.04 7.93L1.11 3L2.39 1.73L22.11 21.46M15.3 19.56C15.69 19.13 16 18.63 16.19 18.08L13.75 15.64C13.57 15.87 13.29 16 13 16C12.45 16 12 15.55 12 15C12 14.71 12.13 14.43 12.36 14.25L9.55 11.44C9.53 12.18 9.24 12.88 8.73 13.41C7.03 15.22 7.13 18.07 8.94 19.77L8.95 19.78C10.76 21.47 13.61 21.37 15.3 19.56M14 17C12.71 17 12.72 19 14 19C15.28 19 15.29 17 14 17M6.9 3.7L8.43 5.23C8.68 4.71 9.05 4.25 9.5 3.89C10.2 3.31 11.09 3 12 3H12.88C13.47 3.14 14 3.41 14.5 3.79C16.22 5.17 16.5 7.69 15.12 9.41C14.7 9.93 14.46 10.58 14.45 11.25L18.32 15.12C18.07 13.97 17.5 12.92 16.72 12.06C16.37 11.7 16.33 11.13 16.62 10.72C16.62 10.72 18 9 18 7S15.97.997 12 .997 6.9 3.7 6.9 3.7M12 17C12 15.71 10 15.72 10 17C10 18.28 12 18.29 12 17M13 5C11.71 5 11.72 7 13 7C14.28 7 14.29 5 13 5Z\";\r\nvar mdiPeanutOutline = \"M12 23C11.53 23 11.07 22.95 10.61 22.85C7.1 22.1 4.87 18.64 5.62 15.13C5.87 13.95 6.45 12.87 7.28 12C7.62 11.64 7.62 11.08 7.28 10.72C5.2 8.14 5.6 4.36 8.18 2.28S14.54.607 16.62 3.19C18.39 5.38 18.39 8.5 16.62 10.72C16.33 11.13 16.37 11.7 16.72 12.06C19.17 14.68 19.04 18.8 16.41 21.25C15.22 22.37 13.64 23 12 23M12 3C11.09 3 10.2 3.31 9.5 3.89C8.55 4.65 8 5.79 8 7C8 7.91 8.31 8.79 8.88 9.5C9.84 10.64 9.77 12.33 8.73 13.41C7.03 15.22 7.13 18.07 8.94 19.77S13.6 21.38 15.3 19.56C16.92 17.83 16.92 15.14 15.3 13.41C14.23 12.32 14.15 10.6 15.12 9.41C16.5 7.69 16.22 5.17 14.5 3.79C14 3.41 13.47 3.14 12.88 3C12.59 3 12.29 3 12 3M12 6C12 6.55 12.45 7 13 7S14 6.55 14 6 13.55 5 13 5 12 5.45 12 6M14 19C14.55 19 15 18.55 15 18S14.55 17 14 17 13 17.45 13 18 13.45 19 14 19M13 16C13.55 16 14 15.55 14 15S13.55 14 13 14 12 14.45 12 15 12.45 16 13 16M11 18C11.55 18 12 17.55 12 17S11.55 16 11 16 10 16.45 10 17 10.45 18 11 18Z\";\r\nvar mdiPen = \"M20.71,7.04C20.37,7.38 20.04,7.71 20.03,8.04C20,8.36 20.34,8.69 20.66,9C21.14,9.5 21.61,9.95 21.59,10.44C21.57,10.93 21.06,11.44 20.55,11.94L16.42,16.08L15,14.66L19.25,10.42L18.29,9.46L16.87,10.87L13.12,7.12L16.96,3.29C17.35,2.9 18,2.9 18.37,3.29L20.71,5.63C21.1,6 21.1,6.65 20.71,7.04M3,17.25L12.56,7.68L16.31,11.43L6.75,21H3V17.25Z\";\r\nvar mdiPenLock = \"M21.7,7C21.4,7.4 21,7.7 21,8C21,8.3 21.3,8.6 21.6,9C22.1,9.5 22.6,9.9 22.5,10.4C22.5,10.9 22,11.4 21.5,11.9L17.4,16L16,14.7L20.2,10.5L19.2,9.5L17.8,10.9L14,7.1L18,3.3C18.4,2.9 19,2.9 19.4,3.3L21.7,5.6C22.1,6 22.1,6.7 21.7,7M4,17.2L13.6,7.6L17.3,11.4L7.8,21H4V17.2M8,5V4.5C8,3.1 6.9,2 5.5,2C4.1,2 3,3.1 3,4.5V5C2.4,5 2,5.4 2,6V10C2,10.6 2.4,11 3,11H8C8.6,11 9,10.6 9,10V6C9,5.4 8.6,5 8,5M7,5H4V4.5C4,3.7 4.7,3 5.5,3C6.3,3 7,3.7 7,4.5V5Z\";\r\nvar mdiPenMinus = \"M20.7,7C20.4,7.4 20,7.7 20,8C20,8.3 20.3,8.6 20.6,9C21.1,9.5 21.6,9.9 21.5,10.4C21.5,10.9 21,11.4 20.5,11.9L16.4,16L15,14.7L19.2,10.5L18.2,9.5L16.8,10.9L13,7.1L17,3.3C17.4,2.9 18,2.9 18.4,3.3L20.7,5.6C21.1,6 21.1,6.7 20.7,7M3,17.2L12.6,7.6L16.3,11.4L6.8,21H3V17.2M10,5V7H2V5H10Z\";\r\nvar mdiPenOff = \"M2.3,5L1,6.3L7.5,12.8L3,17.2V21H6.8L11.3,16.5L17.8,23L19.1,21.7L2.3,5M16.9,10.9L13.1,7.1L17,3.3C17.4,2.9 18,2.9 18.4,3.3L20.7,5.6C21.1,6 21.1,6.6 20.7,7C20.4,7.4 20,7.7 20,8C20,8.3 20.3,8.7 20.6,9C21.1,9.5 21.6,10 21.5,10.4C21.5,10.9 21,11.4 20.5,11.9L16.4,16L15,14.7L19.2,10.5L18.2,9.5L16.9,10.9M10,10.2L12.5,7.7L16.3,11.5L13.8,14L10,10.2Z\";\r\nvar mdiPenPlus = \"M20.7,7C20.4,7.4 20,7.7 20,8C20,8.3 20.3,8.6 20.6,9C21.1,9.5 21.6,9.9 21.5,10.4C21.5,10.9 21,11.4 20.5,11.9L16.4,16L15,14.7L19.2,10.5L18.2,9.5L16.8,10.9L13,7.1L17,3.3C17.4,2.9 18,2.9 18.4,3.3L20.7,5.6C21.1,6 21.1,6.7 20.7,7M3,17.2L12.6,7.6L16.3,11.4L6.8,21H3V17.2M7,2V5H10V7H7V10H5V7H2V5H5V2H7Z\";\r\nvar mdiPenRemove = \"M20.7,7C20.4,7.4 20,7.7 20,8C20,8.3 20.3,8.6 20.6,9C21.1,9.5 21.6,9.9 21.5,10.4C21.5,10.9 21,11.4 20.5,11.9L16.4,16L15,14.7L19.2,10.5L18.2,9.5L16.8,10.9L13,7.1L17,3.3C17.4,2.9 18,2.9 18.4,3.3L20.7,5.6C21.1,6 21.1,6.7 20.7,7M3,17.2L12.6,7.6L16.3,11.4L6.8,21H3V17.2M3.88,2.46L6,4.59L8.12,2.46L9.54,3.88L7.41,6L9.54,8.12L8.12,9.54L6,7.41L3.88,9.54L2.46,8.12L4.59,6L2.46,3.88L3.88,2.46Z\";\r\nvar mdiPencil = \"M20.71,7.04C21.1,6.65 21.1,6 20.71,5.63L18.37,3.29C18,2.9 17.35,2.9 16.96,3.29L15.12,5.12L18.87,8.87M3,17.25V21H6.75L17.81,9.93L14.06,6.18L3,17.25Z\";\r\nvar mdiPencilBox = \"M19,3A2,2 0 0,1 21,5V19C21,20.11 20.1,21 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M16.7,9.35C16.92,9.14 16.92,8.79 16.7,8.58L15.42,7.3C15.21,7.08 14.86,7.08 14.65,7.3L13.65,8.3L15.7,10.35L16.7,9.35M7,14.94V17H9.06L15.12,10.94L13.06,8.88L7,14.94Z\";\r\nvar mdiPencilBoxMultiple = \"M20.22 2H7.78C6.8 2 6 2.8 6 3.78V16.22C6 17.2 6.8 18 7.78 18H20.22C21.2 18 22 17.21 22 16.22V3.78C22 2.8 21.2 2 20.22 2M11.06 15H9V12.94L15.06 6.88L17.12 8.94L11.06 15M18.7 7.35L17.7 8.35L15.65 6.3L16.65 5.3C16.86 5.08 17.21 5.08 17.42 5.3L18.7 6.58C18.92 6.79 18.92 7.14 18.7 7.35M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6Z\";\r\nvar mdiPencilBoxMultipleOutline = \"M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6M18.7 7.35L17.7 8.35L15.65 6.3L16.65 5.3C16.86 5.08 17.21 5.08 17.42 5.3L18.7 6.58C18.92 6.79 18.92 7.14 18.7 7.35M9 12.94L15.06 6.88L17.12 8.94L11.06 15H9V12.94M20 4L20 4L20 16L8 16L8 4H20M20 2H8C6.9 2 6 2.9 6 4V16C6 17.1 6.9 18 8 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2Z\";\r\nvar mdiPencilBoxOutline = \"M19,19V5H5V19H19M19,3A2,2 0 0,1 21,5V19C21,20.11 20.1,21 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M16.7,9.35L15.7,10.35L13.65,8.3L14.65,7.3C14.86,7.08 15.21,7.08 15.42,7.3L16.7,8.58C16.92,8.79 16.92,9.14 16.7,9.35M7,14.94L13.06,8.88L15.12,10.94L9.06,17H7V14.94Z\";\r\nvar mdiPencilCircle = \"M12,2C6.47,2 2,6.47 2,12C2,17.53 6.47,22 12,22C17.53,22 22,17.53 22,12C22,6.47 17.53,2 12,2M15.1,7.07C15.24,7.07 15.38,7.12 15.5,7.23L16.77,8.5C17,8.72 17,9.07 16.77,9.28L15.77,10.28L13.72,8.23L14.72,7.23C14.82,7.12 14.96,7.07 15.1,7.07M13.13,8.81L15.19,10.87L9.13,16.93H7.07V14.87L13.13,8.81Z\";\r\nvar mdiPencilCircleOutline = \"M7,14.94L13.06,8.88L15.12,10.94L9.06,17H7V14.94M12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20M16.7,9.35L15.7,10.35L13.65,8.3L14.65,7.3C14.86,7.08 15.21,7.08 15.42,7.3L16.7,8.58C16.92,8.79 16.92,9.14 16.7,9.35M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2\";\r\nvar mdiPencilLock = \"M5.5,2A2.5,2.5 0 0,0 3,4.5V5A1,1 0 0,0 2,6V10A1,1 0 0,0 3,11H8A1,1 0 0,0 9,10V6A1,1 0 0,0 8,5V4.5A2.5,2.5 0 0,0 5.5,2M5.5,3A1.5,1.5 0 0,1 7,4.5V5H4V4.5A1.5,1.5 0 0,1 5.5,3M19.66,3C19.4,3 19.16,3.09 18.97,3.28L17.13,5.13L20.88,8.88L22.72,7.03C23.11,6.64 23.11,6 22.72,5.63L20.38,3.28C20.18,3.09 19.91,3 19.66,3M16.06,6.19L5,17.25V21H8.75L19.81,9.94L16.06,6.19Z\";\r\nvar mdiPencilLockOutline = \"M16.1,9L17,9.9L7.9,19H7V18.1L16.1,9M19.7,3C19.5,3 19.2,3.1 19,3.3L17.2,5.1L20.9,8.9L22.7,7C23.1,6.6 23.1,6 22.7,5.6L20.4,3.3C20.2,3.1 19.9,3 19.7,3M16.1,6.2L5,17.2V21H8.8L19.8,9.9L16.1,6.2M8,5V4.5C8,3.1 6.9,2 5.5,2C4.1,2 3,3.1 3,4.5V5C2.4,5 2,5.4 2,6V10C2,10.6 2.4,11 3,11H8C8.6,11 9,10.6 9,10V6C9,5.4 8.6,5 8,5M7,5H4V4.5C4,3.7 4.7,3 5.5,3C6.3,3 7,3.7 7,4.5V5Z\";\r\nvar mdiPencilMinus = \"M20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18,2.9 17.4,2.9 17,3.3L15.2,5.1L19,8.9M3,17.2V21H6.8L17.8,9.9L14.1,6.1L3,17.2M10,5V7H2V5H10Z\";\r\nvar mdiPencilMinusOutline = \"M14.1,9L15,9.9L5.9,19H5V18.1L14.1,9M17.7,3C17.5,3 17.2,3.1 17,3.3L15.2,5.1L18.9,8.9L20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18.2,3.1 17.9,3 17.7,3M14.1,6.2L3,17.2V21H6.8L17.8,9.9L14.1,6.2M10,5V7H2V5H10Z\";\r\nvar mdiPencilOff = \"M18.66,2C18.4,2 18.16,2.09 17.97,2.28L16.13,4.13L19.88,7.88L21.72,6.03C22.11,5.64 22.11,5 21.72,4.63L19.38,2.28C19.18,2.09 18.91,2 18.66,2M3.28,4L2,5.28L8.5,11.75L4,16.25V20H7.75L12.25,15.5L18.72,22L20,20.72L13.5,14.25L9.75,10.5L3.28,4M15.06,5.19L11.03,9.22L14.78,12.97L18.81,8.94L15.06,5.19Z\";\r\nvar mdiPencilOffOutline = \"M10,10.2L14,6.2L17.8,10L13.8,14L12.4,12.6L15,9.9L14.1,9L11.5,11.6L10,10.2M20.7,5.6L18.4,3.3C18.2,3.1 17.9,3 17.7,3C17.5,3 17.2,3.1 17,3.3L15.2,5.1L19,8.9L20.7,7C21.1,6.7 21.1,6 20.7,5.6M19,21.7L17.7,23L11.2,16.5L6.8,21H3V17.2L7.5,12.7L1,6.3L2.3,5L19,21.7M9.8,15.1L8.9,14.2L5,18.1V19H5.9L9.8,15.1Z\";\r\nvar mdiPencilOutline = \"M14.06,9L15,9.94L5.92,19H5V18.08L14.06,9M17.66,3C17.41,3 17.15,3.1 16.96,3.29L15.13,5.12L18.88,8.87L20.71,7.04C21.1,6.65 21.1,6 20.71,5.63L18.37,3.29C18.17,3.09 17.92,3 17.66,3M14.06,6.19L3,17.25V21H6.75L17.81,9.94L14.06,6.19Z\";\r\nvar mdiPencilPlus = \"M20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18,2.9 17.4,2.9 17,3.3L15.2,5.1L19,8.9M3,17.2V21H6.8L17.8,9.9L14.1,6.1L3,17.2M7,2V5H10V7H7V10H5V7H2V5H5V2H7Z\";\r\nvar mdiPencilPlusOutline = \"M14.1,9L15,9.9L5.9,19H5V18.1L14.1,9M17.7,3C17.5,3 17.2,3.1 17,3.3L15.2,5.1L18.9,8.9L20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18.2,3.1 17.9,3 17.7,3M14.1,6.2L3,17.2V21H6.8L17.8,9.9L14.1,6.2M7,2V5H10V7H7V10H5V7H2V5H5V2H7Z\";\r\nvar mdiPencilRemove = \"M20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18,2.9 17.4,2.9 17,3.3L15.2,5.1L19,8.9M3,17.2V21H6.8L17.8,9.9L14.1,6.1L3,17.2M3.9,2.4L6,4.5L8.1,2.4L9.5,3.8L7.4,5.9L9.5,8L8.1,9.5L6,7.4L3.9,9.5L2.5,8.1L4.6,6L2.5,3.8L3.9,2.4Z\";\r\nvar mdiPencilRemoveOutline = \"M17.7,3C17.5,3 17.2,3.1 17,3.3L15.2,5.1L18.9,8.9L20.7,7C21.1,6.6 21.1,6 20.7,5.6L18.4,3.3C18.2,3.1 17.9,3 17.7,3M14.1,6.2L3,17.2V21H6.8L17.8,9.9L14.1,6.2M5.9,19H5V18.1L14.1,9L15,9.9L5.9,19M3.9,2.5L6,4.6L8.1,2.5L9.5,3.9L7.4,6L9.5,8.1L8.1,9.5L6,7.4L3.9,9.5L2.5,8.1L4.6,6L2.5,3.9L3.9,2.5Z\";\r\nvar mdiPencilRuler = \"M3 17.25V21H6.75L17.81 9.93L14.06 6.18L3 17.25M22.61 18.36L18.36 22.61L13.16 17.41L14.93 15.64L15.93 16.64L18.4 14.16L19.82 15.58L18.36 17L19.42 18L20.84 16.6L22.61 18.36M6.61 10.83L1.39 5.64L5.64 1.39L7.4 3.16L4.93 5.64L6 6.7L8.46 4.22L9.88 5.64L8.46 7.05L9.46 8.05L6.61 10.83M20.71 7C21.1 6.61 21.1 6 20.71 5.59L18.37 3.29C18 2.9 17.35 2.9 16.96 3.29L15.12 5.12L18.87 8.87L20.71 7Z\";\r\nvar mdiPenguin = \"M19,16C19,17.72 18.37,19.3 17.34,20.5C17.75,20.89 18,21.41 18,22H6C6,21.41 6.25,20.89 6.66,20.5C5.63,19.3 5,17.72 5,16H3C3,14.75 3.57,13.64 4.46,12.91L4.47,12.89C6,11.81 7,10 7,8V7A5,5 0 0,1 12,2A5,5 0 0,1 17,7V8C17,10 18,11.81 19.53,12.89L19.54,12.91C20.43,13.64 21,14.75 21,16H19M16,16A4,4 0 0,0 12,12A4,4 0 0,0 8,16A4,4 0 0,0 12,20A4,4 0 0,0 16,16M10,9L12,10.5L14,9L12,7.5L10,9M10,5A1,1 0 0,0 9,6A1,1 0 0,0 10,7A1,1 0 0,0 11,6A1,1 0 0,0 10,5M14,5A1,1 0 0,0 13,6A1,1 0 0,0 14,7A1,1 0 0,0 15,6A1,1 0 0,0 14,5Z\";\r\nvar mdiPentagon = \"M12,2.5L2,9.8L5.8,21.5H18.2L22,9.8L12,2.5Z\";\r\nvar mdiPentagonOutline = \"M12,5L19.6,10.5L16.7,19.4H7.3L4.4,10.5L12,5M12,2.5L2,9.8L5.8,21.5H18.1L22,9.8L12,2.5Z\";\r\nvar mdiPercent = \"M18.5,3.5L3.5,18.5L5.5,20.5L20.5,5.5M7,4A3,3 0 0,0 4,7A3,3 0 0,0 7,10A3,3 0 0,0 10,7A3,3 0 0,0 7,4M17,14A3,3 0 0,0 14,17A3,3 0 0,0 17,20A3,3 0 0,0 20,17A3,3 0 0,0 17,14Z\";\r\nvar mdiPercentOutline = \"M18.5 3.5L20.5 5.5L5.5 20.5L3.5 18.5L18.5 3.5M7 4C8.66 4 10 5.34 10 7C10 8.66 8.66 10 7 10C5.34 10 4 8.66 4 7C4 5.34 5.34 4 7 4M17 14C18.66 14 20 15.34 20 17C20 18.66 18.66 20 17 20C15.34 20 14 18.66 14 17C14 15.34 15.34 14 17 14M7 6C6.45 6 6 6.45 6 7C6 7.55 6.45 8 7 8C7.55 8 8 7.55 8 7C8 6.45 7.55 6 7 6M17 16C16.45 16 16 16.45 16 17C16 17.55 16.45 18 17 18C17.55 18 18 17.55 18 17C18 16.45 17.55 16 17 16Z\";\r\nvar mdiPeriodicTable = \"M2,4V6H4V4H2M20,4V6H22V4H20M2,7V9H4V7H2M5,7V9H7V7H5M14,7V9H16V7H14M17,7V9H19V7H17M20,7V9H22V7H20M2,10V12H4V10H2M5,10V12H7V10H5M8,10V12H10V10H8M11,10V12H13V10H11M14,10V12H16V10H14M17,10V12H19V10H17M20,10V12H22V10H20M2,13V15H4V13H2M5,13V15H7V13H5M8,13V15H10V13H8M11,13V15H13V13H11M14,13V15H16V13H14M17,13V15H19V13H17M20,13V15H22V13H20M5,17V19H7V17H5M8,17V19H10V17H8M11,17V19H13V17H11M14,17V19H16V17H14M17,17V19H19V17H17Z\";\r\nvar mdiPerspectiveLess = \"M16.56,12L19.23,20H4.78L7.44,12H16.56M7,1L3,5L7,9V6H11V4H7V1M17,1V4H13V6H17V9L21,5L17,1M18,10H6L2,22H22L18,10Z\";\r\nvar mdiPerspectiveMore = \"M16.56,12L19.23,20H4.78L7.44,12H16.56M17,1L13,5L17,9V6H21V4H17V1M7,1V4H3V6H7V9L11,5L7,1M18,10H6L2,22H22L18,10Z\";\r\nvar mdiPharmacy = \"M16,14H13V17H11V14H8V12H11V9H13V12H16M21,5H18.35L19.5,1.85L17.15,1L15.69,5H3V7L5,13L3,19V21H21V19L19,13L21,7V5Z\";\r\nvar mdiPhone = \"M6.62,10.79C8.06,13.62 10.38,15.94 13.21,17.38L15.41,15.18C15.69,14.9 16.08,14.82 16.43,14.93C17.55,15.3 18.75,15.5 20,15.5A1,1 0 0,1 21,16.5V20A1,1 0 0,1 20,21A17,17 0 0,1 3,4A1,1 0 0,1 4,3H7.5A1,1 0 0,1 8.5,4C8.5,5.25 8.7,6.45 9.07,7.57C9.18,7.92 9.1,8.31 8.82,8.59L6.62,10.79Z\";\r\nvar mdiPhoneAlert = \"M6.62,10.79C8.06,13.62 10.38,15.94 13.21,17.38L15.41,15.18C15.69,14.9 16.08,14.82 16.43,14.93C17.55,15.3 18.75,15.5 20,15.5A1,1 0 0,1 21,16.5V20A1,1 0 0,1 20,21A17,17 0 0,1 3,4C3,3.44 3.45,3 4,3H7.5A1,1 0 0,1 8.5,4C8.5,5.24 8.7,6.45 9.07,7.57C9.18,7.92 9.1,8.31 8.82,8.58L6.62,10.79M17,12V10H19V12H17M17,8V2H19V8H17Z\";\r\nvar mdiPhoneAlertOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M17 12V10H19V12H17M17 8V2H19V8H17Z\";\r\nvar mdiPhoneBluetooth = \"M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5M18,7.21L18.94,8.14L18,9.08M18,2.91L18.94,3.85L18,4.79M14.71,9.5L17,7.21V11H17.5L20.35,8.14L18.21,6L20.35,3.85L17.5,1H17V4.79L14.71,2.5L14,3.21L16.79,6L14,8.79L14.71,9.5Z\";\r\nvar mdiPhoneBluetoothOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M18 7.21L18.94 8.14L18 9.08M18 2.91L18.94 3.85L18 4.79M14.71 9.5L17 7.21V11H17.5L20.35 8.14L18.21 6L20.35 3.85L17.5 1H17V4.79L14.71 2.5L14 3.21L16.79 6L14 8.79L14.71 9.5Z\";\r\nvar mdiPhoneCancel = \"M6.62 10.79C8.06 13.62 10.38 15.94 13.21 17.38L15.41 15.18C15.69 14.9 16.08 14.82 16.43 14.93C17.55 15.3 18.75 15.5 20 15.5C20.55 15.5 21 15.95 21 16.5V20C21 20.55 20.55 21 20 21C10.61 21 3 13.39 3 4C3 3.45 3.45 3 4 3H7.5C8.05 3 8.5 3.45 8.5 4C8.5 5.25 8.7 6.45 9.07 7.57C9.18 7.92 9.1 8.31 8.82 8.59L6.62 10.79M16.5 2C14 2 12 4 12 6.5S14 11 16.5 11 21 9 21 6.5 19 2 16.5 2M16.5 9.5C14.84 9.5 13.5 8.16 13.5 6.5C13.5 5.94 13.65 5.42 13.92 5L18 9.08C17.58 9.35 17.06 9.5 16.5 9.5M19.08 8L15 3.92C15.42 3.65 15.94 3.5 16.5 3.5C18.16 3.5 19.5 4.84 19.5 6.5C19.5 7.06 19.35 7.58 19.08 8Z\";\r\nvar mdiPhoneCancelOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M16.5 2C14 2 12 4 12 6.5S14 11 16.5 11 21 9 21 6.5 19 2 16.5 2M16.5 9.5C14.84 9.5 13.5 8.16 13.5 6.5C13.5 5.94 13.65 5.42 13.92 5L18 9.08C17.58 9.35 17.06 9.5 16.5 9.5M19.08 8L15 3.92C15.42 3.65 15.94 3.5 16.5 3.5C18.16 3.5 19.5 4.84 19.5 6.5C19.5 7.06 19.35 7.58 19.08 8Z\";\r\nvar mdiPhoneCheck = \"M6.62 10.79A15.1 15.1 0 0 0 13.21 17.38L15.41 15.18A1 1 0 0 1 16.41 14.93A11.36 11.36 0 0 0 20 15.5A1 1 0 0 1 21 16.5V20A1 1 0 0 1 20 21A17 17 0 0 1 3 4A1 1 0 0 1 4 3H7.5A1 1 0 0 1 8.5 4A11.36 11.36 0 0 0 9.07 7.57A1 1 0 0 1 8.82 8.57M21.71 4.71L20.29 3.29L15 8.59L12.71 6.29L11.29 7.71L15 11.41Z\";\r\nvar mdiPhoneCheckOutline = \"M20 15.5A11.36 11.36 0 0 1 16.43 14.93A1 1 0 0 0 15.43 15.18L13.23 17.38A15.1 15.1 0 0 1 6.64 10.79L8.84 8.59A1 1 0 0 0 9.09 7.59A11.36 11.36 0 0 1 8.5 4A1 1 0 0 0 7.5 3H4A1 1 0 0 0 3 4A17 17 0 0 0 20 21A1 1 0 0 0 21 20V16.5A1 1 0 0 0 20 15.5M5 5H6.54A12.54 12.54 0 0 0 7 7.59L5.79 8.8A15 15 0 0 1 5 5M19 19A15 15 0 0 1 15.2 18.24L16.41 17A12.31 12.31 0 0 0 19 17.45M15 11.44L11.29 7.74L12.71 6.32L15 8.59L20.29 3.29L21.71 4.71Z\";\r\nvar mdiPhoneClassic = \"M12,3C7.46,3 3.34,4.78 0.29,7.67C0.11,7.85 0,8.1 0,8.38C0,8.66 0.11,8.91 0.29,9.09L2.77,11.57C2.95,11.75 3.2,11.86 3.5,11.86C3.75,11.86 4,11.75 4.18,11.58C4.97,10.84 5.87,10.22 6.84,9.73C7.17,9.57 7.4,9.23 7.4,8.83V5.73C8.85,5.25 10.39,5 12,5C13.59,5 15.14,5.25 16.59,5.72V8.82C16.59,9.21 16.82,9.56 17.15,9.72C18.13,10.21 19,10.84 19.82,11.57C20,11.75 20.25,11.85 20.5,11.85C20.8,11.85 21.05,11.74 21.23,11.56L23.71,9.08C23.89,8.9 24,8.65 24,8.37C24,8.09 23.88,7.85 23.7,7.67C20.65,4.78 16.53,3 12,3M9,7V10C9,10 3,15 3,18V22H21V18C21,15 15,10 15,10V7H13V9H11V7H9M12,12A4,4 0 0,1 16,16A4,4 0 0,1 12,20A4,4 0 0,1 8,16A4,4 0 0,1 12,12M12,13.5A2.5,2.5 0 0,0 9.5,16A2.5,2.5 0 0,0 12,18.5A2.5,2.5 0 0,0 14.5,16A2.5,2.5 0 0,0 12,13.5Z\";\r\nvar mdiPhoneClassicOff = \"M12 3C16.53 3 20.65 4.78 23.7 7.67C23.88 7.85 24 8.09 24 8.37C24 8.65 23.89 8.9 23.71 9.08L21.23 11.56C21.05 11.74 20.8 11.85 20.5 11.85C20.25 11.85 20 11.75 19.82 11.57C19 10.84 18.13 10.21 17.15 9.72C16.82 9.56 16.59 9.21 16.59 8.82V5.72C15.14 5.25 13.59 5 12 5C10.44 5 8.93 5.24 7.5 5.69L5.94 4.11C7.82 3.4 9.86 3 12 3M9 7H11V9H13V7H15V10C15 10 21 15 21 18V19.18L9 7.18V7M1 4.27L2.28 3L21.5 22.22L20.23 23.5L18.73 22H3V18C3 15.86 6.05 12.71 7.8 11.07L6.59 9.86C5.71 10.33 4.9 10.9 4.18 11.58C4 11.75 3.75 11.86 3.5 11.86C3.2 11.86 2.95 11.75 2.77 11.57L.29 9.09C.11 8.91 0 8.66 0 8.38C0 8.1 .11 7.85 .29 7.67C.996 7 2.58 5.85 2.58 5.85L1 4.27M8 16C8 18.21 9.79 20 12 20C13.29 20 14.44 19.39 15.17 18.44L14.1 17.36C13.65 18.05 12.88 18.5 12 18.5C10.62 18.5 9.5 17.38 9.5 16C9.5 15.12 9.95 14.35 10.64 13.91L9.56 12.83C8.61 13.56 8 14.71 8 16Z\";\r\nvar mdiPhoneDial = \"M6.6 10.8C8 13.6 10.4 15.9 13.2 17.4L15.4 15.2C15.7 14.9 16.1 14.8 16.4 15C17.5 15.4 18.7 15.6 20 15.6C20.6 15.6 21 16 21 16.6V20C21 20.6 20.6 21 20 21C10.6 21 3 13.4 3 4C3 3.4 3.5 3 4 3H7.5C8.1 3 8.5 3.4 8.5 4C8.5 5.2 8.7 6.4 9.1 7.6C9.2 7.9 9.1 8.3 8.9 8.6L6.6 10.8M14 3C13.4 3 13 3.4 13 4S13.4 5 14 5 15 4.6 15 4 14.6 3 14 3M17 3C16.4 3 16 3.4 16 4S16.4 5 17 5 18 4.6 18 4 17.6 3 17 3M20 3C19.4 3 19 3.4 19 4S19.4 5 20 5 21 4.6 21 4 20.6 3 20 3M14 6C13.4 6 13 6.4 13 7S13.4 8 14 8 15 7.6 15 7 14.6 6 14 6M17 6C16.4 6 16 6.4 16 7S16.4 8 17 8 18 7.6 18 7 17.6 6 17 6M20 6C19.4 6 19 6.4 19 7S19.4 8 20 8 21 7.6 21 7 20.6 6 20 6M14 9C13.4 9 13 9.4 13 10S13.4 11 14 11 15 10.6 15 10 14.6 9 14 9M17 9C16.4 9 16 9.4 16 10S16.4 11 17 11 18 10.6 18 10 17.6 9 17 9M20 9C19.4 9 19 9.4 19 10S19.4 11 20 11 21 10.6 21 10 20.6 9 20 9Z\";\r\nvar mdiPhoneDialOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M15 4C15 4.6 14.6 5 14 5S13 4.6 13 4 13.4 3 14 3 15 3.4 15 4M18 4C18 4.6 17.6 5 17 5S16 4.6 16 4 16.4 3 17 3 18 3.4 18 4M21 4C21 4.6 20.6 5 20 5S19 4.6 19 4 19.4 3 20 3 21 3.4 21 4M15 7C15 7.6 14.6 8 14 8S13 7.6 13 7 13.4 6 14 6 15 6.4 15 7M18 7C18 7.6 17.6 8 17 8S16 7.6 16 7 16.4 6 17 6 18 6.4 18 7M21 7C21 7.6 20.6 8 20 8S19 7.6 19 7 19.4 6 20 6 21 6.4 21 7M15 10C15 10.6 14.6 11 14 11S13 10.6 13 10 13.4 9 14 9 15 9.4 15 10M18 10C18 10.6 17.6 11 17 11S16 10.6 16 10 16.4 9 17 9 18 9.4 18 10M21 10C21 10.6 20.6 11 20 11S19 10.6 19 10 19.4 9 20 9 21 9.4 21 10Z\";\r\nvar mdiPhoneForward = \"M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5M18,11L23,6L18,1V4H14V8H18V11Z\";\r\nvar mdiPhoneForwardOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M18 11L23 6L18 1V4H14V8H18V11Z\";\r\nvar mdiPhoneHangup = \"M12,9C10.4,9 8.85,9.25 7.4,9.72V12.82C7.4,13.22 7.17,13.56 6.84,13.72C5.86,14.21 4.97,14.84 4.17,15.57C4,15.75 3.75,15.86 3.5,15.86C3.2,15.86 2.95,15.74 2.77,15.56L0.29,13.08C0.11,12.9 0,12.65 0,12.38C0,12.1 0.11,11.85 0.29,11.67C3.34,8.77 7.46,7 12,7C16.54,7 20.66,8.77 23.71,11.67C23.89,11.85 24,12.1 24,12.38C24,12.65 23.89,12.9 23.71,13.08L21.23,15.56C21.05,15.74 20.8,15.86 20.5,15.86C20.25,15.86 20,15.75 19.82,15.57C19.03,14.84 18.14,14.21 17.16,13.72C16.83,13.56 16.6,13.22 16.6,12.82V9.72C15.15,9.25 13.6,9 12,9Z\";\r\nvar mdiPhoneHangupOutline = \"M23.71 11.67A17 17 0 0 0 .29 11.67A1 1 0 0 0 0 12.38A1 1 0 0 0 .29 13.08L2.77 15.56A1 1 0 0 0 3.5 15.85A1 1 0 0 0 4.18 15.57A11.5 11.5 0 0 1 6.84 13.72A1 1 0 0 0 7.4 12.82V9.72A14.91 14.91 0 0 1 12 9A14.5 14.5 0 0 1 16.59 9.73V12.83A1 1 0 0 0 17.15 13.73A11.27 11.27 0 0 1 19.82 15.58A1 1 0 0 0 20.5 15.86A1 1 0 0 0 21.23 15.57L23.71 13.09A1 1 0 0 0 23.71 11.67M5.4 12.22A13.68 13.68 0 0 0 3.53 13.5L2.46 12.42A15.54 15.54 0 0 1 5.4 10.5M20.5 13.5A13.75 13.75 0 0 0 18.6 12.23V10.53A14.26 14.26 0 0 1 21.55 12.43Z\";\r\nvar mdiPhoneInTalk = \"M15,12H17A5,5 0 0,0 12,7V9A3,3 0 0,1 15,12M19,12H21C21,7 16.97,3 12,3V5C15.86,5 19,8.13 19,12M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5Z\";\r\nvar mdiPhoneInTalkOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M15 12H17A5 5 0 0 0 12 7V9A3 3 0 0 1 15 12M19 12H21C21 7 16.97 3 12 3V5C15.86 5 19 8.13 19 12Z\";\r\nvar mdiPhoneIncoming = \"M4,3A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.17L13.21,17.37C10.38,15.93 8.06,13.62 6.62,10.78L8.82,8.57C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4M19,11V9.5H15.5L21,4L20,3L14.5,8.5V5H13V11H19Z\";\r\nvar mdiPhoneIncomingOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M19 11V9.5H15.5L21 4L20 3L14.5 8.5V5H13V11H19Z\";\r\nvar mdiPhoneLock = \"M19.2,4H15.8V3.5C15.8,2.56 16.56,1.8 17.5,1.8C18.44,1.8 19.2,2.56 19.2,3.5M20,4V3.5A2.5,2.5 0 0,0 17.5,1A2.5,2.5 0 0,0 15,3.5V4A1,1 0 0,0 14,5V9A1,1 0 0,0 15,10H20A1,1 0 0,0 21,9V5A1,1 0 0,0 20,4M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5Z\";\r\nvar mdiPhoneLockOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M19.2 4H15.8V3.5C15.8 2.56 16.56 1.8 17.5 1.8C18.44 1.8 19.2 2.56 19.2 3.5M20 4V3.5A2.5 2.5 0 0 0 17.5 1A2.5 2.5 0 0 0 15 3.5V4A1 1 0 0 0 14 5V9A1 1 0 0 0 15 10H20A1 1 0 0 0 21 9V5A1 1 0 0 0 20 4Z\";\r\nvar mdiPhoneLog = \"M20,15.5A1,1 0 0,1 21,16.5V20A1,1 0 0,1 20,21A17,17 0 0,1 3,4A1,1 0 0,1 4,3H7.5A1,1 0 0,1 8.5,4C8.5,5.24 8.7,6.45 9.07,7.57C9.18,7.92 9.1,8.31 8.82,8.58L6.62,10.79C8.06,13.62 10.38,15.94 13.21,17.38L15.41,15.18C15.69,14.9 16.08,14.82 16.43,14.93C17.55,15.3 18.75,15.5 20,15.5M12,3H14V5H12M15,3H21V5H15M12,6H14V8H12M15,6H21V8H15M12,9H14V11H12M15,9H21V11H15\";\r\nvar mdiPhoneLogOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M12 3H14V5H12M15 3H21V5H15M12 6H14V8H12M15 6H21V8H15M12 9H14V11H12M15 9H21V11H15Z\";\r\nvar mdiPhoneMessage = \"M20 15.5C18.75 15.5 17.55 15.3 16.43 14.93C16.08 14.82 15.69 14.9 15.41 15.17L13.21 17.37C10.38 15.93 8.06 13.62 6.62 10.79L8.82 8.58C9.1 8.31 9.18 7.92 9.07 7.57C8.7 6.45 8.5 5.25 8.5 4C8.5 3.45 8.05 3 7.5 3H4C3.45 3 3 3.45 3 4C3 13.39 10.61 21 20 21C20.55 21 21 20.55 21 20V16.5C21 15.95 20.55 15.5 20 15.5M12 3V13L15 10H21V3H12Z\";\r\nvar mdiPhoneMessageOutline = \"M20 15.5C18.75 15.5 17.55 15.3 16.43 14.93C16.33 14.9 16.22 14.88 16.12 14.88C15.86 14.88 15.61 15 15.41 15.17L13.21 17.37C10.38 15.93 8.06 13.62 6.62 10.79L8.82 8.58C9.1 8.31 9.18 7.92 9.07 7.57C8.7 6.45 8.5 5.25 8.5 4C8.5 3.45 8.05 3 7.5 3H4C3.45 3 3 3.45 3 4C3 13.39 10.61 21 20 21C20.55 21 21 20.55 21 20V16.5C21 15.95 20.55 15.5 20 15.5M5.03 5H6.53C6.6 5.88 6.75 6.75 7 7.59L5.79 8.8C5.38 7.59 5.12 6.32 5.03 5M19 18.97C17.68 18.88 16.4 18.62 15.2 18.21L16.4 17C17.25 17.25 18.12 17.4 19 17.46V18.97M12 3V13L15 10H21V3H12M19 8H14V5H19V8Z\";\r\nvar mdiPhoneMinus = \"M4,3A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.76,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.07,13.62 6.62,10.79L8.82,8.58C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.24 8.5,4A1,1 0 0,0 7.5,3M13,6V8H21V6\";\r\nvar mdiPhoneMinusOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M13 6V8H21V6Z\";\r\nvar mdiPhoneMissed = \"M23.71,16.67C20.66,13.77 16.54,12 12,12C7.46,12 3.34,13.77 0.29,16.67C0.11,16.85 0,17.1 0,17.38C0,17.65 0.11,17.9 0.29,18.08L2.77,20.56C2.95,20.74 3.2,20.86 3.5,20.86C3.75,20.86 4,20.75 4.18,20.57C4.97,19.83 5.86,19.21 6.84,18.72C7.17,18.56 7.4,18.22 7.4,17.82V14.72C8.85,14.25 10.39,14 12,14C13.6,14 15.15,14.25 16.6,14.72V17.82C16.6,18.22 16.83,18.56 17.16,18.72C18.14,19.21 19.03,19.83 19.82,20.57C20,20.75 20.25,20.86 20.5,20.86C20.8,20.86 21.05,20.74 21.23,20.56L23.71,18.08C23.89,17.9 24,17.65 24,17.38C24,17.1 23.89,16.85 23.71,16.67M6.5,5.5L12,11L19,4L18,3L12,9L7.5,4.5H11V3H5V9H6.5V5.5Z\";\r\nvar mdiPhoneMissedOutline = \"M18.6 15.5v1.8c.7.4 1.3.8 1.9 1.3l1.1-1.1c-.9-.9-1.9-1.5-3-2m-13.2 0c-1 .5-2 1.1-2.9 1.9l1.1 1.1c.6-.5 1.2-.9 1.9-1.3v-1.7M12 12c4.5 0 8.7 1.7 11.7 4.7.2.2.3.4.3.7 0 .3-.1.5-.3.7l-2.5 2.5c-.2.2-.4.3-.7.3-.2 0-.5-.1-.7-.3-.8-.7-1.7-1.4-2.7-1.8-.3-.2-.6-.5-.6-.9v-3.1c-1.5-.5-3-.7-4.6-.7-1.6 0-3.1.2-4.6.7v3.1c0 .4-.2.7-.6.9-1 .5-1.9 1.1-2.7 1.8-.2.2-.4.3-.7.3-.3 0-.5-.1-.7-.3L.1 18.1c0-.2-.1-.5-.1-.7 0-.3.1-.5.3-.7C3.3 13.8 7.5 12 12 12zM6.5 5.5V9H5V3h6v1.5H7.5L12 9l6-6 1 1-7 7-5.5-5.5z\";\r\nvar mdiPhoneOff = \"M20.22,2.5L2.5,20.22L3.77,21.5L8.65,16.62C11.76,19.43 15.81,21 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C12.06,16.8 11,16.06 10.06,15.21L21.5,3.77L20.22,2.5M4,3A1,1 0 0,0 3,4C3,7.57 4.14,11.05 6.24,13.94L7.66,12.5C7.28,11.97 6.93,11.39 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4Z\";\r\nvar mdiPhoneOffOutline = \"M16.4 17C17.2 17.2 18.1 17.4 19 17.5V19C17.7 18.9 16.4 18.7 15.2 18.2L16.4 17M20.2 2.5L2.5 20.2L3.8 21.5L8.7 16.6C11.8 19.4 15.8 21 20 21C20.6 21 21 20.6 21 20V16.5C21 15.9 20.6 15.5 20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C12.1 16.8 11 16.1 10.1 15.2L21.5 3.8L20.2 2.5M6.5 5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5H6.5M7.5 3H4C3.4 3 3 3.4 3 4C3 7.6 4.1 11 6.2 13.9L7.6 12.5C7.2 12 6.9 11.4 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.4 8.5 5.2 8.5 4C8.5 3.4 8.1 3 7.5 3Z\";\r\nvar mdiPhoneOutgoing = \"M4,3A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.17L13.21,17.37C10.38,15.93 8.06,13.62 6.62,10.78L8.82,8.57C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4M15,3V4.5H18.5L13,10L14,11L19.5,5.5V9H21V3H15Z\";\r\nvar mdiPhoneOutgoingOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M15 3V4.5H18.5L13 10L14 11L19.5 5.5V9H21V3H15Z\";\r\nvar mdiPhoneOutline = \"M20,15.5C18.8,15.5 17.5,15.3 16.4,14.9C16.3,14.9 16.2,14.9 16.1,14.9C15.8,14.9 15.6,15 15.4,15.2L13.2,17.4C10.4,15.9 8,13.6 6.6,10.8L8.8,8.6C9.1,8.3 9.2,7.9 9,7.6C8.7,6.5 8.5,5.2 8.5,4C8.5,3.5 8,3 7.5,3H4C3.5,3 3,3.5 3,4C3,13.4 10.6,21 20,21C20.5,21 21,20.5 21,20V16.5C21,16 20.5,15.5 20,15.5M5,5H6.5C6.6,5.9 6.8,6.8 7,7.6L5.8,8.8C5.4,7.6 5.1,6.3 5,5M19,19C17.7,18.9 16.4,18.6 15.2,18.2L16.4,17C17.2,17.2 18.1,17.4 19,17.4V19Z\";\r\nvar mdiPhonePaused = \"M19,10H21V3H19M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5M17,3H15V10H17V3Z\";\r\nvar mdiPhonePausedOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M19 10H21V3H19M17 3H15V10H17V3Z\";\r\nvar mdiPhonePlus = \"M4,3A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.76,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.07,13.62 6.62,10.79L8.82,8.58C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.24 8.5,4A1,1 0 0,0 7.5,3M16,3V6H13V8H16V11H18V8H21V6H18V3\";\r\nvar mdiPhonePlusOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M16 3V6H13V8H16V11H18V8H21V6H18V3Z\";\r\nvar mdiPhoneRemove = \"M4 3C3.4 3 3 3.4 3 4C3 13.4 10.6 21 20 21C20.6 21 21 20.6 21 20V16.5C21 15.9 20.6 15.5 20 15.5C18.8 15.5 17.5 15.3 16.4 14.9C16 14.8 15.7 14.9 15.4 15.1L13.2 17.3C10.4 15.9 8.1 13.5 6.6 10.7L8.8 8.5C9.1 8.2 9.2 7.8 9 7.5C8.7 6.4 8.5 5.2 8.5 4C8.5 3.4 8.1 3 7.5 3M19.1 3.5L17 5.6L14.9 3.5L13.5 4.9L15.6 7L13.5 9.1L14.9 10.5L17 8.4L19.1 10.5L20.5 9.1L18.4 7L20.5 4.9\";\r\nvar mdiPhoneRemoveOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M19.1 3.5L17 5.6L14.9 3.5L13.5 4.9L15.6 7L13.5 9.1L14.9 10.5L17 8.4L19.1 10.5L20.5 9.1L18.4 7L20.5 4.9L19.1 3.5Z\";\r\nvar mdiPhoneReturn = \"M21,6V11H19.5V7.5H13.87L16.3,9.93L15.24,11L11,6.75L15.24,2.5L16.3,3.57L13.87,6H21M8.82,8.58C9.08,8.32 9.17,7.93 9.06,7.58C8.69,6.42 8.5,5.22 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5C18.79,15.5 17.58,15.31 16.43,14.93C16.08,14.82 15.69,14.91 15.43,15.17L13.23,17.37C10.39,15.92 8.09,13.62 6.64,10.78L8.82,8.58Z\";\r\nvar mdiPhoneReturnOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M21 6V11H19.5V7.5H13.87L16.3 9.93L15.24 11L11 6.75L15.24 2.5L16.3 3.57L13.87 6H21Z\";\r\nvar mdiPhoneRing = \"M23.71 16.67C20.66 13.78 16.54 12 12 12S3.34 13.78.29 16.67c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71a.99.99 0 0 0-.29-.7zM21.16 6.26l-1.41-1.41-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zM13 2h-2v5h2V2zM6.4 9.81L7.81 8.4 4.26 4.84 2.84 6.26c.11.03 3.56 3.55 3.56 3.55z\";\r\nvar mdiPhoneRingOutline = \"M23.71 16.67C20.66 13.78 16.54 12 12 12S3.34 13.78.29 16.67c-.18.18-.29.43-.29.71 0 .28.11.53.29.71l2.48 2.48c.18.18.43.29.71.29.27 0 .52-.11.7-.28.79-.74 1.69-1.36 2.66-1.85.33-.16.56-.5.56-.9v-3.1c1.45-.48 3-.73 4.6-.73s3.15.25 4.6.72v3.1c0 .39.23.74.56.9.98.49 1.87 1.12 2.66 1.85.18.18.43.28.7.28.28 0 .53-.11.71-.29l2.48-2.48c.18-.18.29-.43.29-.71a.99.99 0 0 0-.29-.7zm-18.31.56c-.66.37-1.29.8-1.87 1.27l-1.07-1.07c.91-.75 1.9-1.39 2.95-1.9v1.7H5.4zm15.07 1.26c-.59-.48-1.21-.9-1.87-1.27v-1.7c1.04.51 2.03 1.15 2.94 1.9l-1.07 1.07zm.69-12.23l-1.41-1.41-3.56 3.55 1.41 1.41s3.45-3.52 3.56-3.55zM11 2h2v5h-2V2zM6.4 9.81L7.81 8.4 4.26 4.84 2.84 6.26c.11.03 3.56 3.55 3.56 3.55z\";\r\nvar mdiPhoneRotateLandscape = \"M9,1H3A2,2 0 0,0 1,3V16A2,2 0 0,0 3,18H9A2,2 0 0,0 11,16V3A2,2 0 0,0 9,1M9,15H3V3H9V15M21,13H13V15H21V21H9V20H6V21A2,2 0 0,0 8,23H21A2,2 0 0,0 23,21V15A2,2 0 0,0 21,13M23,10L19,8L20.91,7.09C19.74,4.31 17,2.5 14,2.5V1A9,9 0 0,1 23,10Z\";\r\nvar mdiPhoneRotatePortrait = \"M9,1H3A2,2 0 0,0 1,3V16A2,2 0 0,0 3,18H4V15H3V3H9V11H11V3A2,2 0 0,0 9,1M23,21V15A2,2 0 0,0 21,13H8A2,2 0 0,0 6,15V21A2,2 0 0,0 8,23H21A2,2 0 0,0 23,21M9,21V15H21V21H9M23,10H21.5C21.5,7 19.69,4.27 16.92,3.09L16,5L14,1A9,9 0 0,1 23,10Z\";\r\nvar mdiPhoneSettings = \"M19,11H21V9H19M20,15.5C18.75,15.5 17.55,15.3 16.43,14.93C16.08,14.82 15.69,14.9 15.41,15.18L13.21,17.38C10.38,15.94 8.06,13.62 6.62,10.79L8.82,8.59C9.1,8.31 9.18,7.92 9.07,7.57C8.7,6.45 8.5,5.25 8.5,4A1,1 0 0,0 7.5,3H4A1,1 0 0,0 3,4A17,17 0 0,0 20,21A1,1 0 0,0 21,20V16.5A1,1 0 0,0 20,15.5M17,9H15V11H17M13,9H11V11H13V9Z\";\r\nvar mdiPhoneSettingsOutline = \"M20 15.5C18.8 15.5 17.5 15.3 16.4 14.9H16.1C15.8 14.9 15.6 15 15.4 15.2L13.2 17.4C10.4 15.9 8 13.6 6.6 10.8L8.8 8.6C9.1 8.3 9.2 7.9 9 7.6C8.7 6.5 8.5 5.2 8.5 4C8.5 3.5 8 3 7.5 3H4C3.5 3 3 3.5 3 4C3 13.4 10.6 21 20 21C20.5 21 21 20.5 21 20V16.5C21 16 20.5 15.5 20 15.5M5 5H6.5C6.6 5.9 6.8 6.8 7 7.6L5.8 8.8C5.4 7.6 5.1 6.3 5 5M19 19C17.7 18.9 16.4 18.6 15.2 18.2L16.4 17C17.2 17.2 18.1 17.4 19 17.4V19M17 9H15V11H17M13 9H11V11H13V9M19 11H21V9H19Z\";\r\nvar mdiPhoneVoip = \"M13,17V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H13M23.7,7.67C23.88,7.85 24,8.09 24,8.37C24,8.65 23.89,8.9 23.71,9.08L21.23,11.56C21.05,11.74 20.8,11.85 20.5,11.85C20.25,11.85 20,11.75 19.82,11.57C19,10.84 18.13,10.21 17.15,9.72C16.82,9.56 16.59,9.21 16.59,8.82V5.72C15.14,5.25 13.59,5 12,5C10.4,5 8.85,5.25 7.4,5.73V8.83C7.4,9.23 7.17,9.57 6.84,9.73C5.87,10.22 4.97,10.84 4.18,11.58C4,11.75 3.75,11.86 3.5,11.86C3.2,11.86 2.95,11.75 2.77,11.57L0.29,9.09C0.11,8.91 0,8.66 0,8.38C0,8.1 0.11,7.85 0.29,7.67C3.34,4.78 7.46,3 12,3C16.53,3 20.65,4.78 23.7,7.67M11,10V15H10V10H11M12,10H15V13H13V15H12V10M14,12V11H13V12H14Z\";\r\nvar mdiPi = \"M4,5V7H6V19H8V7H14V16A3,3 0 0,0 17,19A3,3 0 0,0 20,16H18A1,1 0 0,1 17,17A1,1 0 0,1 16,16V7H18V5\";\r\nvar mdiPiBox = \"M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M6,7H17V9H15V14A1,1 0 0,0 16,15A1,1 0 0,0 17,14H19A3,3 0 0,1 16,17A3,3 0 0,1 13,14V9H10V17H8V9H6\";\r\nvar mdiPiHole = \"M5.62,2C9.5,2 11.57,4.29 11.77,7.93C12.5,3.57 15.93,4.08 15.93,4.08C16.1,6.55 14.07,8.05 11.77,8.17C11.12,6.81 7.25,3.47 7.25,3.47C7.23,3.5 10.97,6.74 10.83,8.15C8.33,7.88 5.82,6 5.62,2M6.06,13.11L9.92,9.25C11.09,8.08 13,8.08 14.16,9.25L18,13.11C19.19,14.28 19.19,16.18 18,17.35L14.16,21.21C13,22.38 11.09,22.38 9.92,21.21L6.06,17.35C4.89,16.18 4.89,14.28 6.06,13.11M9.39,19.59C9.39,18.36 10.15,16.85 12.09,16.85C13.4,16.85 14.87,18.1 16.31,17.96C14.87,17.92 13.59,16.85 13.59,15.19C13.59,13.86 14.69,12.9 14.69,11.34C14.63,12.33 13.82,13.77 12,13.77C10.59,13.77 9.55,12.63 7.87,12.63C8.58,12.67 10.5,13.3 10.5,15.35C10.5,17 9.39,17.5 9.39,19.59Z\";\r\nvar mdiPiano = \"M4,3H20A2,2 0 0,1 22,5V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V5A2,2 0 0,1 4,3M4,5V19H8V13H6.75V5H4M9,19H15V13H13.75V5H10.25V13H9V19M16,19H20V5H17.25V13H16V19Z\";\r\nvar mdiPickaxe = \"M14.79,10.62L3.5,21.9L2.1,20.5L13.38,9.21L14.79,10.62M19.27,7.73L19.86,7.14L19.07,6.35L19.71,5.71L18.29,4.29L17.65,4.93L16.86,4.14L16.27,4.73C14.53,3.31 12.57,2.17 10.47,1.37L9.64,3.16C11.39,4.08 13,5.19 14.5,6.5L14,7L17,10L17.5,9.5C18.81,11 19.92,12.61 20.84,14.36L22.63,13.53C21.83,11.43 20.69,9.47 19.27,7.73Z\";\r\nvar mdiPictureInPictureBottomRight = \"M19,11H11V17H19V11M23,19V5C23,3.88 22.1,3 21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19M21,19H3V4.97H21V19Z\";\r\nvar mdiPictureInPictureBottomRightOutline = \"M19,11H11V17H19V11M17,15H13V13H17V15M21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5C23,3.88 22.1,3 21,3M21,19H3V4.97H21V19Z\";\r\nvar mdiPictureInPictureTopRight = \"M19,7H11V13H19V7M21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3M21,19H3V5H21V19Z\";\r\nvar mdiPictureInPictureTopRightOutline = \"M19,7H11V13H19V7M17,11H13V9H17V11M21,3H3A2,2 0 0,0 1,5V19C1,20.11 1.9,21 3,21H21A2,2 0 0,0 23,19V5C23,3.91 22.1,3 21,3M21,19H3V5H21V19Z\";\r\nvar mdiPier = \"M20,18C18.6,18 17.2,17.5 16,16.7C13.6,18.4 10.4,18.4 8,16.7C6.8,17.5 5.4,18 4,18H2V20H4C5.4,20 6.7,19.6 8,19C10.5,20.3 13.5,20.3 16,19C17.3,19.6 18.6,20 20,20H22V18H20M20,13H19V16.9C18.3,16.8 17.6,16.6 17,16.2V13H12V17C11.3,17 10.7,16.9 10,16.7V13H5V16.9C4.7,17 4.3,17 4,17H3V13H2V11H3V9H5V11H10V9H12V11H17V9H19V11H20V13Z\";\r\nvar mdiPierCrane = \"M20,20C18.61,20 17.22,19.53 16,18.67C13.56,20.38 10.44,20.38 8,18.67C6.78,19.53 5.39,20 4,20H2V22H4C5.37,22 6.74,21.65 8,21C10.5,22.3 13.5,22.3 16,21C17.26,21.65 18.62,22 20,22H22V20H20M20,4V3A1,1 0 0,0 19,2H9V1H6V2H5V4H6V13H5V11H3V13H2V15H3V19H4C4.33,19 4.67,18.97 5,18.92V15H10V18.65C10.65,18.85 11.33,18.95 12,18.95V18.92L12,15H13V13H12V11H10V13H9V4H17V8.62C16.53,8.79 16.19,9.23 16.19,9.76C16.19,10.2 16.43,10.6 16.8,10.82V12H17.42C17.76,12 18.03,12.28 18.03,12.62C18.03,12.96 17.76,13.24 17.42,13.24C17.2,13.24 17,13.12 16.88,12.93C16.71,12.64 16.34,12.54 16.05,12.71C15.75,12.87 15.65,13.25 15.82,13.55C16.15,14.11 16.76,14.47 17.42,14.47C18.43,14.47 19.26,13.64 19.26,12.62C19.26,11.84 18.76,11.14 18.03,10.88V10.82C18.41,10.6 18.65,10.2 18.65,9.76C18.65,9.3 18.38,8.91 18,8.7V4H20M8,11.66L7,12.66V11.24L8,10.24V11.66M8,8.71L7,9.71V8.29L8,7.29V8.71M7,6.71V5.29L8,4.29V5.71L7,6.71Z\";\r\nvar mdiPig = \"M9.5,9A1.5,1.5 0 0,0 8,10.5A1.5,1.5 0 0,0 9.5,12A1.5,1.5 0 0,0 11,10.5A1.5,1.5 0 0,0 9.5,9M14.5,9A1.5,1.5 0 0,0 13,10.5A1.5,1.5 0 0,0 14.5,12A1.5,1.5 0 0,0 16,10.5A1.5,1.5 0 0,0 14.5,9M12,4L12.68,4.03C13.62,3.24 14.82,2.59 15.72,2.35C17.59,1.85 20.88,2.23 21.31,3.83C21.62,5 20.6,6.45 19.03,7.38C20.26,8.92 21,10.87 21,13A9,9 0 0,1 12,22A9,9 0 0,1 3,13C3,10.87 3.74,8.92 4.97,7.38C3.4,6.45 2.38,5 2.69,3.83C3.12,2.23 6.41,1.85 8.28,2.35C9.18,2.59 10.38,3.24 11.32,4.03L12,4M10,16A1,1 0 0,1 11,17A1,1 0 0,1 10,18A1,1 0 0,1 9,17A1,1 0 0,1 10,16M14,16A1,1 0 0,1 15,17A1,1 0 0,1 14,18A1,1 0 0,1 13,17A1,1 0 0,1 14,16M12,13C9.24,13 7,15.34 7,17C7,18.66 9.24,20 12,20C14.76,20 17,18.66 17,17C17,15.34 14.76,13 12,13M7.76,4.28C7.31,4.16 4.59,4.35 4.59,4.35C4.59,4.35 6.8,6.1 7.24,6.22C7.69,6.34 9.77,6.43 9.91,5.9C10.06,5.36 8.2,4.4 7.76,4.28M16.24,4.28C15.8,4.4 13.94,5.36 14.09,5.9C14.23,6.43 16.31,6.34 16.76,6.22C17.2,6.1 19.41,4.35 19.41,4.35C19.41,4.35 16.69,4.16 16.24,4.28Z\";\r\nvar mdiPigVariant = \"M20 12C20 8.69 16.42 6 12 6C11.15 6 10.34 6.1 9.57 6.28L7 5V7.32C5.5 8.22 4.45 9.5 4.12 11H2V15H5.08C5.58 15.65 6.23 16.22 7 16.68V20H9V17.56C9.93 17.84 10.94 18 12 18S14.07 17.84 15 17.56V20H17V16.68C18.15 16 19.03 15.06 19.54 14H22V12H20M7 11C6.45 11 6 10.55 6 10S6.45 9 7 9 8 9.45 8 10 7.55 11 7 11Z\";\r\nvar mdiPiggyBank = \"M13 1C14.66 1 16 2.34 16 4S14.66 7 13 7 10 5.66 10 4 11.34 1 13 1M20 14C20 11.64 18.17 9.6 15.5 8.62C15 9.45 14.06 10 13 10C11.76 10 10.69 9.24 10.24 8.17C10 8.2 9.78 8.23 9.57 8.29L7 7V9.32C5.5 10.22 4.45 11.5 4.12 13H2V17H5.08C5.58 17.65 6.23 18.22 7 18.68V22H9V19.56C9.93 19.84 10.94 20 12 20S14.07 19.84 15 19.56V22H17V18.68C18.15 18 19.03 17.06 19.54 16H22V14H20M7 13C6.45 13 6 12.55 6 12S6.45 11 7 11 8 11.45 8 12 7.55 13 7 13Z\";\r\nvar mdiPill = \"M4.22,11.29L11.29,4.22C13.64,1.88 17.43,1.88 19.78,4.22C22.12,6.56 22.12,10.36 19.78,12.71L12.71,19.78C10.36,22.12 6.56,22.12 4.22,19.78C1.88,17.43 1.88,13.64 4.22,11.29M5.64,12.71C4.59,13.75 4.24,15.24 4.6,16.57L10.59,10.59L14.83,14.83L18.36,11.29C19.93,9.73 19.93,7.2 18.36,5.64C16.8,4.07 14.27,4.07 12.71,5.64L5.64,12.71Z\";\r\nvar mdiPillar = \"M6,5H18A1,1 0 0,1 19,6A1,1 0 0,1 18,7H6A1,1 0 0,1 5,6A1,1 0 0,1 6,5M21,2V4H3V2H21M15,8H17V22H15V8M7,8H9V22H7V8M11,8H13V22H11V8Z\";\r\nvar mdiPin = \"M16,12V4H17V2H7V4H8V12L6,14V16H11.2V22H12.8V16H18V14L16,12Z\";\r\nvar mdiPinOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L12.8,16.07V22H11.2V16H6V14L8,12V11.27L2,5.27M16,12L18,14V16H17.82L8,6.18V4H7V2H17V4H16V12Z\";\r\nvar mdiPinOffOutline = \"M8,6.2V4H7V2H17V4H16V12L18,14V16H17.8L14,12.2V4H10V8.2L8,6.2M20,20.7L18.7,22L12.8,16.1V22H11.2V16H6V14L8,12V11.3L2,5.3L3.3,4L20,20.7M8.8,14H10.6L9.7,13.1L8.8,14Z\";\r\nvar mdiPinOutline = \"M16,12V4H17V2H7V4H8V12L6,14V16H11.2V22H12.8V16H18V14L16,12M8.8,14L10,12.8V4H14V12.8L15.2,14H8.8Z\";\r\nvar mdiPineTree = \"M10,21V18H3L8,13H5L10,8H7L12,3L17,8H14L19,13H16L21,18H14V21H10Z\";\r\nvar mdiPineTreeBox = \"M4,2H20A2,2 0 0,1 22,4V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V4A2,2 0 0,1 4,2M11,19H13V17H18L14,13H17L13,9H16L12,5L8,9H11L7,13H10L6,17H11V19Z\";\r\nvar mdiPineTreeFire = \"M22.14 14.84L22.12 14.85C22.35 15.13 22.55 15.44 22.7 15.77L22.79 15.96C23.5 17.65 23 19.6 21.69 20.82C20.5 21.91 18.84 22.2 17.3 22C15.84 21.82 14.5 20.9 13.73 19.63C13.5 19.24 13.3 18.8 13.2 18.35C13.07 18 13.03 17.62 13 17.25C12.91 15.65 13.55 13.95 14.76 12.95C14.21 14.16 14.34 15.67 15.15 16.72L15.26 16.85C15.4 16.97 15.57 17 15.73 16.94C15.88 16.88 16 16.73 16 16.57L15.93 16.33C15.05 14 15.79 11.3 17.66 9.77C18.17 9.35 18.8 8.97 19.46 8.8C18.78 10.16 19 11.94 20.09 13C20.55 13.5 21.11 13.79 21.58 14.23L22.14 14.84M19.86 19.5L19.85 19.47C20.3 19.08 20.55 18.41 20.53 17.81L20.5 17.5C20.3 16.5 19.43 16.16 18.87 15.43C18.7 15.21 18.55 14.93 18.44 14.65C18.22 15.15 18.2 15.62 18.29 16.16C18.39 16.73 18.61 17.22 18.5 17.81C18.34 18.46 17.83 19.11 16.94 19.32C17.44 19.81 18.25 20.2 19.06 19.92C19.32 19.85 19.65 19.66 19.86 19.5M9 21V18H2L7 13H4L9 8H6L11 3L16 8H13L14.82 9.82C12.55 11.06 11 13.59 11 16.5C11 18.19 11.5 19.75 12.4 21H9Z\";\r\nvar mdiPinterest = \"M9.04,21.54C10,21.83 10.97,22 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2A10,10 0 0,0 2,12C2,16.25 4.67,19.9 8.44,21.34C8.35,20.56 8.26,19.27 8.44,18.38L9.59,13.44C9.59,13.44 9.3,12.86 9.3,11.94C9.3,10.56 10.16,9.53 11.14,9.53C12,9.53 12.4,10.16 12.4,10.97C12.4,11.83 11.83,13.06 11.54,14.24C11.37,15.22 12.06,16.08 13.06,16.08C14.84,16.08 16.22,14.18 16.22,11.5C16.22,9.1 14.5,7.46 12.03,7.46C9.21,7.46 7.55,9.56 7.55,11.77C7.55,12.63 7.83,13.5 8.29,14.07C8.38,14.13 8.38,14.21 8.35,14.36L8.06,15.45C8.06,15.62 7.95,15.68 7.78,15.56C6.5,15 5.76,13.18 5.76,11.71C5.76,8.55 8,5.68 12.32,5.68C15.76,5.68 18.44,8.15 18.44,11.43C18.44,14.87 16.31,17.63 13.26,17.63C12.29,17.63 11.34,17.11 11,16.5L10.33,18.87C10.1,19.73 9.47,20.88 9.04,21.57V21.54Z\";\r\nvar mdiPinwheel = \"M12,12C12,9 14.5,6.5 17.5,6.5C20.5,6.5 23,9 23,12H12M12,12C12,15 9.5,17.5 6.5,17.5C3.5,17.5 1,15 1,12H12M12,12C9,12 6.5,9.5 6.5,6.5C6.5,3.5 9,1 12,1V12M12,12C15,12 17.5,14.5 17.5,17.5C17.5,20.5 15,23 12,23V12Z\";\r\nvar mdiPinwheelOutline = \"M12,23H11V16.43C9.93,17.4 8.5,18 7,18C3.75,18 1,15.25 1,12V11H7.57C6.6,9.93 6,8.5 6,7C6,3.75 8.75,1 12,1H13V7.57C14.07,6.6 15.5,6 17,6C20.25,6 23,8.75 23,12V13H16.43C17.4,14.07 18,15.5 18,17C18,20.25 15.25,23 12,23M13,13.13V20.87C14.7,20.41 16,18.83 16,17C16,15.17 14.7,13.59 13,13.13M3.13,13C3.59,14.7 5.17,16 7,16C8.83,16 10.41,14.7 10.87,13H3.13M13.13,11H20.87C20.41,9.3 18.82,8 17,8C15.18,8 13.59,9.3 13.13,11M11,3.13C9.3,3.59 8,5.18 8,7C8,8.82 9.3,10.41 11,10.87V3.13Z\";\r\nvar mdiPipe = \"M22,14H20V16H14V13H16V11H14V6A2,2 0 0,0 12,4H4V2H2V10H4V8H10V11H8V13H10V18A2,2 0 0,0 12,20H20V22H22\";\r\nvar mdiPipeDisconnected = \"M16,9V11H8V9H10V8H4V10H2V2H4V4H12A2,2 0 0,1 14,6V9H16M10,15V18A2,2 0 0,0 12,20H20V22H22V14H20V16H14V15H16V13H8V15H10Z\";\r\nvar mdiPipeLeak = \"M2,5V13H4V11H10L12,9L10,7H4V5H2M20,5V7H12L14,9L12,11H20V13H22V5H20M12,13C12,13 10,15.17 10,16.5A2,2 0 0,0 12,18.5A2,2 0 0,0 14,16.5C14,15.17 12,13 12,13Z\";\r\nvar mdiPipeWrench = \"M16.17 5.63L14.06 7.78L11.91 5.63L16.17 1.41L19.69 4.92C20.86 6.09 20.86 8 19.69 9.19L16.17 5.63M4.83 12.7L7 14.81L10.5 11.3L8.39 9.19L4.83 12.7M15.47 7.78L19 11.3L17.58 12.7L16.88 12L6.23 22.59L3.42 19.78L11.91 11.3L7.69 7.03L9.8 4.92L14.06 9.19L15.47 7.78Z\";\r\nvar mdiPirate = \"M8.2,12.1C7.9,12.3 7.7,12.7 7.8,13C7.8,13.7 8.5,14.2 9.1,14.2C9.7,14.2 10.3,13.7 10.3,13C9.7,12.6 9,12.3 8.2,12.1M22,11L23,7C23,7 21,7 18,5C15,3 15,1 12,1C9,1 9,3 6,5C3,7 1,7 1,7L2,11H2.1C2,11.3 2,11.7 2,12C2,15.5 3.8,18.6 6.5,20.4L6,21.3C12.4,25.4 18,21.3 18,21.3L17.5,20.4C20.2,18.6 22,15.5 22,12C22,11.7 22,11.3 22,11M11.3,4.5L9.9,3.1L10.6,2.4L12,3.8L13.4,2.4L14.1,3.1L12.7,4.5L14.1,5.9L13.4,6.6L12,5.2L10.6,6.6L9.9,5.9L11.3,4.5M9.3,8.5C10.3,8.2 11.3,8 12,8C14.2,8 17.9,9.6 19.8,10.4C19.9,10.7 19.9,11 19.9,11.3L9.3,8.5M13.6,19.1C12.9,19.5 12.2,19.8 11.4,19.9C10.9,19.5 10.9,18.7 11.4,18.3C11.8,17.9 12.7,17.7 13.2,18.2C13.5,18.3 13.6,18.8 13.6,19.1M20,13.4C19.5,15.5 18.2,17.4 16.5,18.6L15,16H9L7.5,18.6C5.4,17.2 4,14.8 4,12C4,11.5 4.1,11 4.2,10.5C4.7,10.3 5.3,10 6,9.7L13.1,11.6V14C13.1,14.5 13.5,15 14.1,15H16.1C16.6,15 17.1,14.6 17.1,14V12.6L20,13.4Z\";\r\nvar mdiPistol = \"M7,5H23V9H22V10H16A1,1 0 0,0 15,11V12A2,2 0 0,1 13,14H9.62C9.24,14 8.89,14.22 8.72,14.56L6.27,19.45C6.1,19.79 5.76,20 5.38,20H2C2,20 -1,20 3,14C3,14 6,10 2,10V5H3L3.5,4H6.5L7,5M14,12V11A1,1 0 0,0 13,10H12C12,10 11,11 12,12A2,2 0 0,1 10,10A1,1 0 0,0 9,11V12A1,1 0 0,0 10,13H13A1,1 0 0,0 14,12Z\";\r\nvar mdiPiston = \"M13,16.18C13.5,16.35 13.9,16.63 14.23,17H15V21H14.21C13.89,21.35 13.5,21.63 13,21.8C11.85,22.22 10.58,21.87 9.78,21H9V17H9.77C10.1,16.63 10.5,16.35 11,16.18V12H13V16.18M12,20A1,1 0 0,0 13,19A1,1 0 0,0 12,18A1,1 0 0,0 11,19A1,1 0 0,0 12,20M17,4H15V5H17V11H7V5H9V4H7V2H17V4M12,9A1,1 0 0,0 13,8A1,1 0 0,0 12,7A1,1 0 0,0 11,8A1,1 0 0,0 12,9Z\";\r\nvar mdiPitchfork = \"M15.9 .9L13.1 3.7C12.3 4.5 12.3 5.7 13.1 6.5L14.5 8L9.2 13.4L7.8 12C7 11.2 5.8 11.2 5 12L1 16L2.4 17.4L6.4 13.4L7.8 14.8L3.8 18.8L5.2 20.2L9.2 16.2L10.6 17.6L9.9 18.4L6.7 21.6L8 23L12 19C12.8 18.2 12.8 17 12 16.2L10.6 14.8L15.9 9.4L17.3 10.8C18.1 11.6 19.3 11.6 20.1 10.8L23 8L15.9 .9M18.7 9.4L14.5 5.2L15.9 3.8L20.1 8L18.7 9.4Z\";\r\nvar mdiPizza = \"M12,15A2,2 0 0,1 10,13C10,11.89 10.9,11 12,11A2,2 0 0,1 14,13A2,2 0 0,1 12,15M7,7C7,5.89 7.89,5 9,5A2,2 0 0,1 11,7A2,2 0 0,1 9,9C7.89,9 7,8.1 7,7M12,2C8.43,2 5.23,3.54 3,6L12,22L21,6C18.78,3.54 15.57,2 12,2Z\";\r\nvar mdiPlay = \"M8,5.14V19.14L19,12.14L8,5.14Z\";\r\nvar mdiPlayBox = \"M19 3H5C3.89 3 3 3.89 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.89 20.1 3 19 3M10 16V8L15 12\";\r\nvar mdiPlayBoxMultiple = \"M4,6H2V20A2,2 0 0,0 4,22H18V20H4V6M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M12,14.5V5.5L18,10L12,14.5Z\";\r\nvar mdiPlayBoxMultipleOutline = \"M4 6H2V20C2 21.1 2.9 22 4 22H18V20H4V6M20 4V16H8V4H20M20 2H8C6.9 2 6 2.9 6 4V16C6 17.1 6.9 18 8 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2M12 14.5V5.5L18 10L12 14.5Z\";\r\nvar mdiPlayBoxOutline = \"M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3M10,8V16L15,12L10,8Z\";\r\nvar mdiPlayCircle = \"M10,16.5V7.5L16,12M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiPlayCircleOutline = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M10,16.5L16,12L10,7.5V16.5Z\";\r\nvar mdiPlayNetwork = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M10,14V6L15,10L10,14Z\";\r\nvar mdiPlayNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M10,14V6L15,10L10,14Z\";\r\nvar mdiPlayOutline = \"M8.5,8.64L13.77,12L8.5,15.36V8.64M6.5,5V19L17.5,12\";\r\nvar mdiPlayPause = \"M3,5V19L11,12M13,19H16V5H13M18,5V19H21V5\";\r\nvar mdiPlayProtectedContent = \"M2,5V18H11V16H4V7H17V11H19V5H2M9,9V14L12.5,11.5L9,9M21.04,11.67L16.09,16.62L13.96,14.5L12.55,15.91L16.09,19.45L22.45,13.09L21.04,11.67Z\";\r\nvar mdiPlaySpeed = \"M13,2.05V4.05C17.39,4.59 20.5,8.58 19.96,12.97C19.5,16.61 16.64,19.5 13,19.93V21.93C18.5,21.38 22.5,16.5 21.95,11C21.5,6.25 17.73,2.5 13,2.03V2.05M5.67,19.74C7.18,21 9.04,21.79 11,22V20C9.58,19.82 8.23,19.25 7.1,18.37L5.67,19.74M7.1,5.74C8.22,4.84 9.57,4.26 11,4.06V2.06C9.05,2.25 7.19,3 5.67,4.26L7.1,5.74M5.69,7.1L4.26,5.67C3,7.19 2.25,9.04 2.05,11H4.05C4.24,9.58 4.8,8.23 5.69,7.1M4.06,13H2.06C2.26,14.96 3.03,16.81 4.27,18.33L5.69,16.9C4.81,15.77 4.24,14.42 4.06,13M10,16.5L16,12L10,7.5V16.5Z\";\r\nvar mdiPlaylistCheck = \"M14,10H2V12H14V10M14,6H2V8H14V6M2,16H10V14H2V16M21.5,11.5L23,13L16,20L11.5,15.5L13,14L16,17L21.5,11.5Z\";\r\nvar mdiPlaylistEdit = \"M2,6V8H14V6H2M2,10V12H14V10H2M20.04,10.13C19.9,10.13 19.76,10.19 19.65,10.3L18.65,11.3L20.7,13.35L21.7,12.35C21.92,12.14 21.92,11.79 21.7,11.58L20.42,10.3C20.31,10.19 20.18,10.13 20.04,10.13M18.07,11.88L12,17.94V20H14.06L20.12,13.93L18.07,11.88M2,14V16H10V14H2Z\";\r\nvar mdiPlaylistMinus = \"M2,16H10V14H2M12,14V16H22V14M14,6H2V8H14M14,10H2V12H14V10Z\";\r\nvar mdiPlaylistMusic = \"M15,6H3V8H15V6M15,10H3V12H15V10M3,16H11V14H3V16M17,6V14.18C16.69,14.07 16.35,14 16,14A3,3 0 0,0 13,17A3,3 0 0,0 16,20A3,3 0 0,0 19,17V8H22V6H17Z\";\r\nvar mdiPlaylistMusicOutline = \"M15,6V8H3V6H15M15,10V12H3V10H15M3,16V14H11V16H3M17,6H22V8H19V17A3,3 0 0,1 16,20A3,3 0 0,1 13,17A3,3 0 0,1 16,14C16.35,14 16.69,14.07 17,14.18V6M16,16A1,1 0 0,0 15,17A1,1 0 0,0 16,18A1,1 0 0,0 17,17A1,1 0 0,0 16,16Z\";\r\nvar mdiPlaylistPlay = \"M19,9H2V11H19V9M19,5H2V7H19V5M2,15H15V13H2V15M17,13V19L22,16L17,13Z\";\r\nvar mdiPlaylistPlus = \"M2,16H10V14H2M18,14V10H16V14H12V16H16V20H18V16H22V14M14,6H2V8H14M14,10H2V12H14V10Z\";\r\nvar mdiPlaylistRemove = \"M2,6V8H14V6H2M2,10V12H11V10H2M14.17,10.76L12.76,12.17L15.59,15L12.76,17.83L14.17,19.24L17,16.41L19.83,19.24L21.24,17.83L18.41,15L21.24,12.17L19.83,10.76L17,13.59L14.17,10.76M2,14V16H11V14H2Z\";\r\nvar mdiPlaylistStar = \"M17,19.09L19.45,20.58L18.8,17.77L21,15.89L18.11,15.64L17,13L15.87,15.64L13,15.89L15.18,17.77L14.5,20.58L17,19.09M4,14H12V16H4V14M4,6H16V8H4V6M4,10H16V12H4V10Z\";\r\nvar mdiPlex = \"M4,2C2.89,2 2,2.89 2,4V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.11,2 20,2H4M8.56,6H12.06L15.5,12L12.06,18H8.56L12,12L8.56,6Z\";\r\nvar mdiPlus = \"M19,13H13V19H11V13H5V11H11V5H13V11H19V13Z\";\r\nvar mdiPlusBox = \"M17,13H13V17H11V13H7V11H11V7H13V11H17M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiPlusBoxMultiple = \"M19,11H15V15H13V11H9V9H13V5H15V9H19M20,2H8A2,2 0 0,0 6,4V16A2,2 0 0,0 8,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M4,6H2V20A2,2 0 0,0 4,22H18V20H4V6Z\";\r\nvar mdiPlusBoxMultipleOutline = \"M18 11H15V14H13V11H10V9H13V6H15V9H18M20 4V16H8V4H20M20 2H8C6.9 2 6 2.9 6 4V16C6 17.11 6.9 18 8 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M4 6H2V20C2 21.11 2.9 22 4 22H18V20H4V6Z\";\r\nvar mdiPlusBoxOutline = \"M19,19V5H5V19H19M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5C3,3.89 3.9,3 5,3H19M11,7H13V11H17V13H13V17H11V13H7V11H11V7Z\";\r\nvar mdiPlusCircle = \"M17,13H13V17H11V13H7V11H11V7H13V11H17M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiPlusCircleMultiple = \"M2 12C2 9.2 3.6 6.8 6 5.7V3.5C2.5 4.8 0 8.1 0 12S2.5 19.2 6 20.5V18.3C3.6 17.2 2 14.8 2 12M15 3C10 3 6 7 6 12S10 21 15 21 24 17 24 12 20 3 15 3M20 13H16V17H14V13H10V11H14V7H16V11H20V13Z\";\r\nvar mdiPlusCircleMultipleOutline = \"M16,8H14V11H11V13H14V16H16V13H19V11H16M2,12C2,9.21 3.64,6.8 6,5.68V3.5C2.5,4.76 0,8.09 0,12C0,15.91 2.5,19.24 6,20.5V18.32C3.64,17.2 2,14.79 2,12M15,3C10.04,3 6,7.04 6,12C6,16.96 10.04,21 15,21C19.96,21 24,16.96 24,12C24,7.04 19.96,3 15,3M15,19C11.14,19 8,15.86 8,12C8,8.14 11.14,5 15,5C18.86,5 22,8.14 22,12C22,15.86 18.86,19 15,19Z\";\r\nvar mdiPlusCircleOutline = \"M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M13,7H11V11H7V13H11V17H13V13H17V11H13V7Z\";\r\nvar mdiPlusMinus = \"M11,4V9H6V11H11V16H13V11H18V9H13V4H11M6,18V20H18V18H6Z\";\r\nvar mdiPlusMinusBox = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M11,6H13V9H16V11H13V14H11V11H8V9H11V6M8,16H16V18H8V16Z\";\r\nvar mdiPlusMinusVariant = \"M3 7H6V4H8V7H11V9H8V12H6V9H3V7M13 15H21V17H13V15M16.04 3H18.35L7.96 21H5.65L16.04 3Z\";\r\nvar mdiPlusNetwork = \"M16,11V9H13V6H11V9H8V11H11V14H13V11H16M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17Z\";\r\nvar mdiPlusNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M15,11H13V13H11V11H9V9H11V7H13V9H15V11Z\";\r\nvar mdiPlusOne = \"M10,8V12H14V14H10V18H8V14H4V12H8V8H10M14.5,6.08L19,5V18H17V7.4L14.5,7.9V6.08Z\";\r\nvar mdiPlusOutline = \"M4,9H9V4H15V9H20V15H15V20H9V15H4V9M11,13V18H13V13H18V11H13V6H11V11H6V13H11Z\";\r\nvar mdiPlusThick = \"M20 14H14V20H10V14H4V10H10V4H14V10H20V14Z\";\r\nvar mdiPodcast = \"M17,18.25V21.5H7V18.25C7,16.87 9.24,15.75 12,15.75C14.76,15.75 17,16.87 17,18.25M12,5.5A6.5,6.5 0 0,1 18.5,12C18.5,13.25 18.15,14.42 17.54,15.41L16,14.04C16.32,13.43 16.5,12.73 16.5,12C16.5,9.5 14.5,7.5 12,7.5C9.5,7.5 7.5,9.5 7.5,12C7.5,12.73 7.68,13.43 8,14.04L6.46,15.41C5.85,14.42 5.5,13.25 5.5,12A6.5,6.5 0 0,1 12,5.5M12,1.5A10.5,10.5 0 0,1 22.5,12C22.5,14.28 21.77,16.39 20.54,18.11L19.04,16.76C19.96,15.4 20.5,13.76 20.5,12A8.5,8.5 0 0,0 12,3.5A8.5,8.5 0 0,0 3.5,12C3.5,13.76 4.04,15.4 4.96,16.76L3.46,18.11C2.23,16.39 1.5,14.28 1.5,12A10.5,10.5 0 0,1 12,1.5M12,9.5A2.5,2.5 0 0,1 14.5,12A2.5,2.5 0 0,1 12,14.5A2.5,2.5 0 0,1 9.5,12A2.5,2.5 0 0,1 12,9.5Z\";\r\nvar mdiPodium = \"M12,7.09L14.45,8.58L13.8,5.77L16,3.89L13.11,3.64L12,1L10.87,3.64L8,3.89L10.18,5.77L9.5,8.58L12,7.09M4,13.09L6.45,14.58L5.8,11.77L8,9.89L5.11,9.64L4,7L2.87,9.64L0,9.89L2.18,11.77L1.5,14.58L4,13.09M20,10.09L22.45,11.58L21.8,8.77L24,6.89L21.11,6.64L20,4L18.87,6.64L16,6.89L18.18,8.77L17.5,11.58L20,10.09M15,23H9V10H15V23M7,23H1V17H7V23M23,23H17V13H23V23Z\";\r\nvar mdiPodiumBronze = \"M4,13.09L6.45,14.58L5.8,11.77L8,9.89L5.11,9.64L4,7L2.87,9.64L0,9.89L2.18,11.77L1.5,14.58L4,13.09M7,23H1V17H7V23M9,10V23H15V10H9M13,21H11V12H13V21M17,13V23H23V13H17M21,21H19V15H21V21Z\";\r\nvar mdiPodiumGold = \"M12,7.09L14.45,8.58L13.8,5.77L16,3.89L13.11,3.64L12,1L10.87,3.64L8,3.89L10.18,5.77L9.5,8.58L12,7.09M15,23H9V10H15V23M1,17V23H7V17H1M5,21H3V19H5V21M17,13V23H23V13H17M21,21H19V15H21V21Z\";\r\nvar mdiPodiumSilver = \"M20,10.09L22.45,11.58L21.8,8.77L24,6.89L21.11,6.64L20,4L18.87,6.64L16,6.89L18.18,8.77L17.5,11.58L20,10.09M23,23H17V13H23V23M1,17V23H7V17H1M5,21H3V19H5V21M9,10V23H15V10H9M13,21H11V12H13V21Z\";\r\nvar mdiPointOfSale = \"M20,5C19.4,5 19,5.5 19,6.1V16C19,16.6 19.4,17 20,17.1C20.6,17.1 21,16.6 21,16V6.1C21,5.5 20.6,5 20,5M16.4,2H4.6C3.7,2 3,2.7 3,3.6V17.4C3,18.3 3.7,19 4.6,19H6V21C6,21.6 6.4,22 7,22H13C13.6,22 14,21.6 14,21V19H16.4C17.3,19 18,18.3 18,17.4V3.6C18,2.7 17.3,2 16.4,2M5,8H8V10H5V8M12,11V13H9V11H12M9,10V8H12V10H9M12,14V16H9V14H12M5,11H8V13H5V11M5,16V14H8V16H5M8,21H7V19H8V21M13,21H10V19H13V21M16,16H13V14H16V16M16,13H13V11H16V13M16,10H13V8H16V10M16,6H5V4H16V6Z\";\r\nvar mdiPokeball = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4C7.92,4 4.55,7.05 4.06,11H8.13C8.57,9.27 10.14,8 12,8C13.86,8 15.43,9.27 15.87,11H19.94C19.45,7.05 16.08,4 12,4M12,20C16.08,20 19.45,16.95 19.94,13H15.87C15.43,14.73 13.86,16 12,16C10.14,16 8.57,14.73 8.13,13H4.06C4.55,16.95 7.92,20 12,20M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiPokemonGo = \"M12,2A7,7 0 0,1 19,9C19,10.4 18.59,11.71 17.88,12.8L12,22.21L6.12,12.8C5.41,11.71 5,10.4 5,9A7,7 0 0,1 12,2M12,3.5C9.3,3.5 7.06,5.44 6.59,8H9.17C9.58,6.83 10.69,6 12,6C13.31,6 14.42,6.83 14.83,8H17.41C16.94,5.44 14.7,3.5 12,3.5M12,12C10.69,12 9.58,11.17 9.17,10H6.59C6.72,10.69 6.97,11.34 7.34,11.91V11.91L7.38,12C8.36,13.5 10.06,14.5 12,14.5C13.94,14.5 15.64,13.5 16.62,12L16.66,11.91V11.91C17.03,11.34 17.28,10.69 17.41,10H14.83C14.42,11.17 13.31,12 12,12M12,7.5A1.5,1.5 0 0,0 10.5,9A1.5,1.5 0 0,0 12,10.5A1.5,1.5 0 0,0 13.5,9A1.5,1.5 0 0,0 12,7.5Z\";\r\nvar mdiPokerChip = \"M23,12C23,18.08 18.08,23 12,23C5.92,23 1,18.08 1,12C1,5.92 5.92,1 12,1C18.08,1 23,5.92 23,12M13,4.06C15.13,4.33 17.07,5.45 18.37,7.16L20.11,6.16C18.45,3.82 15.86,2.3 13,2V4.06M3.89,6.16L5.63,7.16C6.93,5.45 8.87,4.33 11,4.06V2C8.14,2.3 5.55,3.82 3.89,6.16M2.89,16.1L4.62,15.1C3.79,13.12 3.79,10.88 4.62,8.9L2.89,7.9C1.7,10.5 1.7,13.5 2.89,16.1M11,19.94C8.87,19.67 6.93,18.55 5.63,16.84L3.89,17.84C5.55,20.18 8.14,21.7 11,22V19.94M20.11,17.84L18.37,16.84C17.07,18.55 15.13,19.67 13,19.94V21.94C15.85,21.65 18.44,20.16 20.11,17.84M21.11,16.1C22.3,13.5 22.3,10.5 21.11,7.9L19.38,8.9C20.21,10.88 20.21,13.12 19.38,15.1L21.11,16.1M15,12L12,7L9,12L12,17L15,12Z\";\r\nvar mdiPolaroid = \"M6,3H18A2,2 0 0,1 20,5V19A2,2 0 0,1 18,21H6A2,2 0 0,1 4,19V5A2,2 0 0,1 6,3M6,5V17H18V5H6Z\";\r\nvar mdiPoliceBadge = \"M22 4L20 2C18.85 2.64 17.4 3 16 3C14.6 3 13.14 2.63 12 2C10.86 2.63 9.4 3 8 3C6.6 3 5.15 2.64 4 2L2 4C2 4 4 6 4 8S2 14 2 16C2 20 12 22 12 22S22 20 22 16C22 14 20 10 20 8S22 4 22 4M15.05 16.45L11.97 14.59L8.9 16.45L9.72 12.95L7 10.61L10.58 10.3L11.97 7L13.37 10.29L16.95 10.6L14.23 12.94L15.05 16.45Z\";\r\nvar mdiPoliceBadgeOutline = \"M12 4.21C13.24 4.72 14.65 5 16 5C17.05 5 18.1 4.84 19.08 4.54C18.5 5.5 18 6.71 18 8C18 9.32 18.54 10.93 19.1 12.63C19.5 13.83 20 15.33 20 16C20 17.03 16.47 19 12 19.96C7.54 19 4 17.03 4 16C4 15.33 4.5 13.83 4.9 12.63C5.46 10.93 6 9.32 6 8C6 6.71 5.5 5.5 4.92 4.54C5.9 4.84 6.96 5 8 5C9.35 5 10.76 4.72 12 4.21M20 2C18.85 2.64 17.4 3 16 3C14.6 3 13.14 2.63 12 2C10.86 2.63 9.4 3 8 3C6.6 3 5.15 2.64 4 2L2 4C2 4 4 6 4 8S2 14 2 16C2 20 12 22 12 22S22 20 22 16C22 14 20 10 20 8S22 4 22 4L20 2M15.05 16.45L11.97 14.59L8.9 16.45L9.72 12.95L7 10.61L10.58 10.3L11.97 7L13.37 10.29L16.95 10.6L14.23 12.94L15.05 16.45\";\r\nvar mdiPoll = \"M3,22V8H7V22H3M10,22V2H14V22H10M17,22V14H21V22H17Z\";\r\nvar mdiPollBox = \"M17,17H15V13H17M13,17H11V7H13M9,17H7V10H9M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiPollBoxOutline = \"M9 17H7V10H9M13 17H11V7H13M17 17H15V13H17M19.5 19.1H4.5V5H19.5M19.5 3H4.5C3.4 3 2.5 3.9 2.5 5V19C2.5 20.1 3.4 21 4.5 21H19.5C20.6 21 21.5 20.1 21.5 19V5C21.5 3.9 20.6 3 19.5 3Z\";\r\nvar mdiPolo = \"M22 9.5C22 10.88 20.88 12 19.5 12S17 10.88 17 9.5 18.12 7 19.5 7 22 8.12 22 9.5M11 17V3H8V17H2L6 21H13V17H11M16 17H14V21H16V17Z\";\r\nvar mdiPolymer = \"M19,4H15L7.1,16.63L4.5,12L9,4H5L0.5,12L5,20H9L16.89,7.37L19.5,12L15,20H19L23.5,12L19,4Z\";\r\nvar mdiPool = \"M2,15C3.67,14.25 5.33,13.5 7,13.17V5A3,3 0 0,1 10,2C11.31,2 12.42,2.83 12.83,4H10A1,1 0 0,0 9,5V6H14V5A3,3 0 0,1 17,2C18.31,2 19.42,2.83 19.83,4H17A1,1 0 0,0 16,5V14.94C18,14.62 20,13 22,13V15C19.78,15 17.56,17 15.33,17C13.11,17 10.89,15 8.67,15C6.44,15 4.22,16 2,17V15M14,8H9V10H14V8M14,12H9V13C10.67,13.16 12.33,14.31 14,14.79V12M2,19C4.22,18 6.44,17 8.67,17C10.89,17 13.11,19 15.33,19C17.56,19 19.78,17 22,17V19C19.78,19 17.56,21 15.33,21C13.11,21 10.89,19 8.67,19C6.44,19 4.22,20 2,21V19Z\";\r\nvar mdiPopcorn = \"M7,22H4.75C4.75,22 4,22 3.81,20.65L2.04,3.81L2,3.5C2,2.67 2.9,2 4,2C5.1,2 6,2.67 6,3.5C6,2.67 6.9,2 8,2C9.1,2 10,2.67 10,3.5C10,2.67 10.9,2 12,2C13.09,2 14,2.66 14,3.5V3.5C14,2.67 14.9,2 16,2C17.1,2 18,2.67 18,3.5C18,2.67 18.9,2 20,2C21.1,2 22,2.67 22,3.5L21.96,3.81L20.19,20.65C20,22 19.25,22 19.25,22H17L16.5,22H13.75L10.25,22H7.5L7,22M17.85,4.93C17.55,4.39 16.84,4 16,4C15.19,4 14.36,4.36 14,4.87L13.78,20H16.66L17.85,4.93M10,4.87C9.64,4.36 8.81,4 8,4C7.16,4 6.45,4.39 6.15,4.93L7.34,20H10.22L10,4.87Z\";\r\nvar mdiPost = \"M3 3V21H21V3H3M18 18H6V17H18V18M18 16H6V15H18V16M18 12H6V6H18V12Z\";\r\nvar mdiPostOutline = \"M19 5V19H5V5H19M21 3H3V21H21V3M17 17H7V16H17V17M17 15H7V14H17V15M17 12H7V7H17V12Z\";\r\nvar mdiPostageStamp = \"M2,2V5.5C3.1,5.5 4,6.62 4,8C4,9.38 3.1,10.5 2,10.5V13.5C3.1,13.5 4,14.62 4,16C4,17.38 3.1,18.5 2,18.5V22H5.5C5.5,20.9 6.62,20 8,20C9.38,20 10.5,20.9 10.5,22H13.5C13.5,20.9 14.62,20 16,20C17.38,20 18.5,20.9 18.5,22H22V18.5C20.9,18.5 20,17.38 20,16V16C20,14.62 20.9,13.5 22,13.5V10.5C20.9,10.5 20,9.38 20,8V8C20,6.62 20.9,5.5 22,5.5V2H18.5C18.5,3.1 17.38,4 16,4C14.62,4 13.5,3.1 13.5,2H10.5C10.5,3.1 9.38,4 8,4C6.62,4 5.5,3.1 5.5,2H2M6,6H18V18H6V6M9,7A2,2 0 0,0 7,9A2,2 0 0,0 9,11A2,2 0 0,0 11,9A2,2 0 0,0 9,7M17,10L14,13L12,12L7,17H17V10Z\";\r\nvar mdiPot = \"M19 19C19 20.1 18.1 21 17 21H7C5.9 21 5 20.1 5 19V12H3V10H21V12H19V19Z\";\r\nvar mdiPotMix = \"M14.6 9L18 3.1L19.7 4.1L16.9 9H14.6M14 10H3V12H5V19C5 20.1 5.9 21 7 21H17C18.1 21 19 20.1 19 19V12H21V10H14Z\";\r\nvar mdiPotMixOutline = \"M14.6 9L18 3.1L19.7 4.1L16.9 9H14.6M16.3 10H21V12H19V19C19 20.1 18.1 21 17 21H7C5.9 21 5 20.1 5 19V12H3V10H16.3M17 12H7V19H17V12Z\";\r\nvar mdiPotOutline = \"M3 10V12H5V19C5 20.1 5.9 21 7 21H17C18.1 21 19 20.1 19 19V12H21V10H3M7 12H17V19H7V12Z\";\r\nvar mdiPotSteam = \"M19 19C19 20.11 18.11 21 17 21H7C5.9 21 5 20.11 5 19V12H3V10H21V12H19M8 1.5C6.15 1.5 4.65 3 4.65 4.85C4.65 6.7 6.15 8.2 8 8.2H9.53C9.92 8.2 10.29 8.3 10.61 8.5H12.63C12.05 7.45 10.86 6.75 9.53 6.75H8C7 6.75 6.15 5.77 6.15 4.75C6.15 3.73 7 3 8 3M12.85 2C12.85 3 12 3.85 11 3.85V5.35C12.92 5.35 14.5 6.7 14.89 8.5H16.42C16.12 6.67 14.96 5.15 13.35 4.38C13.97 3.77 14.35 2.93 14.35 2Z\";\r\nvar mdiPotSteamOutline = \"M8 1.5C6.15 1.5 4.65 3 4.65 4.85C4.65 6.7 6.15 8.2 8 8.2H9.53C9.92 8.2 10.29 8.3 10.61 8.5H12.63C12.05 7.45 10.86 6.75 9.53 6.75H8C7 6.75 6.15 5.77 6.15 4.75C6.15 3.73 7 3 8 3V1.5M12.85 2C12.85 3 12 3.85 11 3.85V5.35C12.92 5.35 14.5 6.7 14.89 8.5H16.42C16.12 6.67 14.96 5.15 13.35 4.38C13.97 3.77 14.35 2.93 14.35 2H12.85M3 10V12H5V19C5 20.11 5.9 21 7 21H17C18.11 21 19 20.11 19 19V12H21V10H3M7 12H17V19H7V12Z\";\r\nvar mdiPound = \"M5.41,21L6.12,17H2.12L2.47,15H6.47L7.53,9H3.53L3.88,7H7.88L8.59,3H10.59L9.88,7H15.88L16.59,3H18.59L17.88,7H21.88L21.53,9H17.53L16.47,15H20.47L20.12,17H16.12L15.41,21H13.41L14.12,17H8.12L7.41,21H5.41M9.53,9L8.47,15H14.47L15.53,9H9.53Z\";\r\nvar mdiPoundBox = \"M3,5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5M7,18H9L9.35,16H13.35L13,18H15L15.35,16H17.35L17.71,14H15.71L16.41,10H18.41L18.76,8H16.76L17.12,6H15.12L14.76,8H10.76L11.12,6H9.12L8.76,8H6.76L6.41,10H8.41L7.71,14H5.71L5.35,16H7.35L7,18M10.41,10H14.41L13.71,14H9.71L10.41,10Z\";\r\nvar mdiPoundBoxOutline = \"M19 19H5V5H19M19 3H5A2 2 0 0 0 3 5V19A2 2 0 0 0 5 21H19A2 2 0 0 0 21 19V5A2 2 0 0 0 19 3M7 9H9.31L9.63 6H11.63L11.31 9H13.31L13.63 6H15.63L15.31 9H17V11H15.1L14.9 13H17V15H14.69L14.37 18H12.37L12.69 15H10.69L10.37 18H8.37L8.69 15H7V13H8.9L9.1 11H7V9M11.1 11L10.9 13H12.9L13.1 11Z\";\r\nvar mdiPower = \"M16.56,5.44L15.11,6.89C16.84,7.94 18,9.83 18,12A6,6 0 0,1 12,18A6,6 0 0,1 6,12C6,9.83 7.16,7.94 8.88,6.88L7.44,5.44C5.36,6.88 4,9.28 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12C20,9.28 18.64,6.88 16.56,5.44M13,3H11V13H13\";\r\nvar mdiPowerCycle = \"M12,3A9,9 0 0,0 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3M12,19A7,7 0 0,1 5,12A7,7 0 0,1 12,5A7,7 0 0,1 19,12A7,7 0 0,1 12,19M13,17H11V7H13V17Z\";\r\nvar mdiPowerOff = \"M12,3A9,9 0 0,0 3,12A9,9 0 0,0 12,21A9,9 0 0,0 21,12A9,9 0 0,0 12,3M12,19A7,7 0 0,1 5,12A7,7 0 0,1 12,5A7,7 0 0,1 19,12A7,7 0 0,1 12,19Z\";\r\nvar mdiPowerOn = \"M11,3H13V21H11V3Z\";\r\nvar mdiPowerPlug = \"M16,7V3H14V7H10V3H8V7H8C7,7 6,8 6,9V14.5L9.5,18V21H14.5V18L18,14.5V9C18,8 17,7 16,7Z\";\r\nvar mdiPowerPlugOff = \"M20.84 22.73L15.31 17.2L14.5 18V21H9.5V18L6 14.5V9C6 8.7 6.1 8.41 6.25 8.14L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M18 14.5V9C18 8 17 7 16 7V3H14V7H10.2L17.85 14.65L18 14.5M10 3H8V4.8L10 6.8V3Z\";\r\nvar mdiPowerPlugOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L6.25 8.14C6.1 8.41 6 8.7 6 9V14.5L9.5 18V21H14.5V18L15.31 17.2L20.84 22.73L22.11 21.46M13.09 16.59L12.67 17H11.33L10.92 16.59L8 13.67V9.89L13.89 15.78L13.09 16.59M12.2 9L10.2 7H14V3H16V7C17 7 18 8 18 9V14.5L17.85 14.65L16 12.8V9.09C16 9.06 15.95 9 15.92 9H12.2M10 6.8L8 4.8V3H10V6.8Z\";\r\nvar mdiPowerPlugOutline = \"M16 7V3H14V7H10V3H8V7C7 7 6 8 6 9V14.5L9.5 18V21H14.5V18L18 14.5V9C18 8 17 7 16 7M16 13.67L13.09 16.59L12.67 17H11.33L10.92 16.59L8 13.67V9.09C8 9.06 8.06 9 8.09 9H15.92C15.95 9 16 9.06 16 9.09V13.67Z\";\r\nvar mdiPowerSettings = \"M15,24H17V22H15M16.56,4.44L15.11,5.89C16.84,6.94 18,8.83 18,11A6,6 0 0,1 12,17A6,6 0 0,1 6,11C6,8.83 7.16,6.94 8.88,5.88L7.44,4.44C5.36,5.88 4,8.28 4,11A8,8 0 0,0 12,19A8,8 0 0,0 20,11C20,8.28 18.64,5.88 16.56,4.44M13,2H11V12H13M11,24H13V22H11M7,24H9V22H7V24Z\";\r\nvar mdiPowerSleep = \"M18.73,18C15.4,21.69 9.71,22 6,18.64C2.33,15.31 2.04,9.62 5.37,5.93C6.9,4.25 9,3.2 11.27,3C7.96,6.7 8.27,12.39 12,15.71C13.63,17.19 15.78,18 18,18C18.25,18 18.5,18 18.73,18Z\";\r\nvar mdiPowerSocket = \"M15,15H17V11H15M7,15H9V11H7M11,13H13V9H11M8.83,7H15.2L19,10.8V17H5V10.8M8,5L3,10V19H21V10L16,5H8Z\";\r\nvar mdiPowerSocketAu = \"M4.22,2A2.22,2.22 0 0,0 2,4.22V19.78C2,21 3,22 4.22,22H19.78A2.22,2.22 0 0,0 22,19.78V4.22C22,3 21,2 19.78,2H4.22M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M8.27,7.54L6.27,11L8,12L10,8.54L8.27,7.54M15.73,7.54L14,8.54L16,12L17.73,11L15.73,7.54M11,14V18H13V14H11Z\";\r\nvar mdiPowerSocketDe = \"M4.22 2A2.22 2.22 0 0 0 2 4.22V19.78C2 21 3 22 4.22 22H19.78A2.22 2.22 0 0 0 22 19.78V4.22C22 3 21 2 19.78 2H4.22M11 4.07V6H13V4.07A8 8 0 0 1 20 12A8 8 0 0 1 13 19.93V18H11V19.93A8 8 0 0 1 4 12A8 8 0 0 1 11 4.07M7.5 10.5A1.5 1.5 0 0 0 6 12C6 12.83 6.66 13.5 7.5 13.5A1.5 1.5 0 0 0 9 12A1.5 1.5 0 0 0 7.5 10.5M16.5 10.5A1.5 1.5 0 0 0 15 12A1.5 1.5 0 0 0 16.5 13.5A1.5 1.5 0 0 0 18 12A1.5 1.5 0 0 0 16.5 10.5Z\";\r\nvar mdiPowerSocketEu = \"M7.5,10.5A1.5,1.5 0 0,1 9,12A1.5,1.5 0 0,1 7.5,13.5C6.66,13.5 6,12.83 6,12A1.5,1.5 0 0,1 7.5,10.5M16.5,10.5A1.5,1.5 0 0,1 18,12A1.5,1.5 0 0,1 16.5,13.5A1.5,1.5 0 0,1 15,12A1.5,1.5 0 0,1 16.5,10.5M4.22,2H19.78C21,2 22,3 22,4.22V19.78A2.22,2.22 0 0,1 19.78,22H4.22C3,22 2,21 2,19.78V4.22A2.22,2.22 0 0,1 4.22,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiPowerSocketFr = \"M4.22 2A2.22 2.22 0 0 0 2 4.22V19.78C2 21 3 22 4.22 22H19.78A2.22 2.22 0 0 0 22 19.78V4.22C22 3 21 2 19.78 2H4.22M12 4A8 8 0 0 1 20 12A8 8 0 0 1 12 20A8 8 0 0 1 4 12A8 8 0 0 1 12 4M12 6A1.5 1.5 0 0 0 10.5 7.5A1.5 1.5 0 0 0 12 9A1.5 1.5 0 0 0 13.5 7.5A1.5 1.5 0 0 0 12 6M7.5 10.5A1.5 1.5 0 0 0 6 12C6 12.83 6.66 13.5 7.5 13.5A1.5 1.5 0 0 0 9 12A1.5 1.5 0 0 0 7.5 10.5M16.5 10.5A1.5 1.5 0 0 0 15 12A1.5 1.5 0 0 0 16.5 13.5A1.5 1.5 0 0 0 18 12A1.5 1.5 0 0 0 16.5 10.5Z\";\r\nvar mdiPowerSocketIt = \"M10.5 16.5C10.5 15.68 11.17 15 12 15C12.83 15 13.5 15.68 13.5 16.5C13.5 17.34 12.83 18 12 18C11.17 18 10.5 17.34 10.5 16.5M10.5 7.5C10.5 6.67 11.17 6 12 6C12.83 6 13.5 6.67 13.5 7.5C13.5 8.33 12.83 9 12 9C11.17 9 10.5 8.33 10.5 7.5M4.22 2H19.78C21 2 22 3 22 4.22V19.78C22 21 21 22 19.78 22H4.22C3 22 2 21 2 19.78V4.22C2 3 3 2 4.22 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M10.5 12C10.5 11.17 11.17 10.5 12 10.5C12.83 10.5 13.5 11.17 13.5 12C13.5 12.83 12.83 13.5 12 13.5C11.17 13.5 10.5 12.83 10.5 12Z\";\r\nvar mdiPowerSocketJp = \"M10 9.5V14.5H8V9.5M19.78 2C21 2 22 3 22 4.22V19.78C22 21 21 22 19.78 22H4.22C3 22 2 21 2 19.78V4.22C2 3 3 2 4.22 2M12 4C7.58 4 4 7.58 4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4M16 9.5V14.5H14V9.5Z\";\r\nvar mdiPowerSocketUk = \"M4 2A2 2 0 0 0 2 4V20A2 2 0 0 0 4 22H20A2 2 0 0 0 22 20V4A2 2 0 0 0 20 2H4M4 4H20V20H4V4M11 7V11H13V7H11M6 14.75V17H9.5V14.75H6M14.5 14.75V17H18V14.75H14.5Z\";\r\nvar mdiPowerSocketUs = \"M8,7H10V12H8V7M4.22,2H19.78C21,2 22,3 22,4.22V19.78A2.22,2.22 0 0,1 19.78,22H4.22C3,22 2,21 2,19.78V4.22A2.22,2.22 0 0,1 4.22,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4M14,7.5H16V11.5H14V7.5M10.5,16.25A1.5,1.5 0 0,1 12,14.75A1.5,1.5 0 0,1 13.5,16.25V17H10.5V16.25Z\";\r\nvar mdiPowerStandby = \"M13,3H11V13H13V3M17.83,5.17L16.41,6.59C18.05,7.91 19,9.9 19,12A7,7 0 0,1 12,19C8.14,19 5,15.88 5,12C5,9.91 5.95,7.91 7.58,6.58L6.17,5.17C2.38,8.39 1.92,14.07 5.14,17.86C8.36,21.64 14.04,22.1 17.83,18.88C19.85,17.17 21,14.65 21,12C21,9.37 19.84,6.87 17.83,5.17Z\";\r\nvar mdiPowershell = \"M21.83,4C22.32,4 22.63,4.4 22.5,4.89L19.34,19.11C19.23,19.6 18.75,20 18.26,20H2.17C1.68,20 1.37,19.6 1.5,19.11L4.66,4.89C4.77,4.4 5.25,4 5.74,4H21.83M15.83,16H11.83C11.37,16 11,16.38 11,16.84C11,17.31 11.37,17.69 11.83,17.69H15.83C16.3,17.69 16.68,17.31 16.68,16.84C16.68,16.38 16.3,16 15.83,16M5.78,16.28C5.38,16.56 5.29,17.11 5.57,17.5C5.85,17.92 6.41,18 6.81,17.73C14.16,12.56 14.21,12.5 14.26,12.47C14.44,12.31 14.53,12.09 14.54,11.87C14.55,11.67 14.5,11.5 14.38,11.31L9.46,6.03C9.13,5.67 8.57,5.65 8.21,6C7.85,6.32 7.83,6.88 8.16,7.24L12.31,11.68L5.78,16.28Z\";\r\nvar mdiPrescription = \"M4,4V10L4,14H6V10H8L13.41,15.41L9.83,19L11.24,20.41L14.83,16.83L18.41,20.41L19.82,19L16.24,15.41L19.82,11.83L18.41,10.41L14.83,14L10.83,10H11A3,3 0 0,0 14,7A3,3 0 0,0 11,4H4M6,6H11A1,1 0 0,1 12,7A1,1 0 0,1 11,8H6V6Z\";\r\nvar mdiPresentation = \"M2,3H10A2,2 0 0,1 12,1A2,2 0 0,1 14,3H22V5H21V16H15.25L17,22H15L13.25,16H10.75L9,22H7L8.75,16H3V5H2V3M5,5V14H19V5H5Z\";\r\nvar mdiPresentationPlay = \"M2,3H10A2,2 0 0,1 12,1A2,2 0 0,1 14,3H22V5H21V16H15.25L17,22H15L13.25,16H10.75L9,22H7L8.75,16H3V5H2V3M5,5V14H19V5H5M11.85,11.85C11.76,11.94 11.64,12 11.5,12A0.5,0.5 0 0,1 11,11.5V7.5A0.5,0.5 0 0,1 11.5,7C11.64,7 11.76,7.06 11.85,7.15L13.25,8.54C13.57,8.86 13.89,9.18 13.89,9.5C13.89,9.82 13.57,10.14 13.25,10.46L11.85,11.85Z\";\r\nvar mdiPretzel = \"M5.15 15.84C3.81 14.27 3 12.23 3 10V9.97C3 7.22 5.25 5 8 5C9.64 5 11.09 5.79 12 7C12.91 5.79 14.37 5 16 5C18.76 5 21 7.24 21 10C21 12.23 20.19 14.27 18.85 15.84L20.21 17.2L18.79 18.61L17.39 17.21C15.89 18.33 14 19 12 19C10 19 8.11 18.33 6.61 17.21L5.21 18.61L3.79 17.2L5.15 15.84M15.96 15.77L12 11.82L8.04 15.77C9.17 16.55 10.53 17 12 17C13.47 17 14.83 16.55 15.96 15.77M11 10C11 8.34 9.65 7 8 7C6.34 7 5 8.34 5 10C5 11.68 5.59 13.21 6.57 14.42L11 10M17.43 14.42C18.41 13.21 19 11.68 19 10V10C19 8.33 17.65 7 16 7C14.35 7 13 8.34 13 10L17.43 14.42Z\";\r\nvar mdiPrinter = \"M18,3H6V7H18M19,12A1,1 0 0,1 18,11A1,1 0 0,1 19,10A1,1 0 0,1 20,11A1,1 0 0,1 19,12M16,19H8V14H16M19,8H5A3,3 0 0,0 2,11V17H6V21H18V17H22V11A3,3 0 0,0 19,8Z\";\r\nvar mdiPrinter3d = \"M19,6A1,1 0 0,0 20,5A1,1 0 0,0 19,4A1,1 0 0,0 18,5A1,1 0 0,0 19,6M19,2A3,3 0 0,1 22,5V11H18V7H6V11H2V5A3,3 0 0,1 5,2H19M18,18.25C18,18.63 17.79,18.96 17.47,19.13L12.57,21.82C12.4,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L6.53,19.13C6.21,18.96 6,18.63 6,18.25V13C6,12.62 6.21,12.29 6.53,12.12L11.43,9.68C11.59,9.56 11.79,9.5 12,9.5C12.21,9.5 12.4,9.56 12.57,9.68L17.47,12.12C17.79,12.29 18,12.62 18,13V18.25M12,11.65L9.04,13L12,14.6L14.96,13L12,11.65M8,17.66L11,19.29V16.33L8,14.71V17.66M16,17.66V14.71L13,16.33V19.29L16,17.66Z\";\r\nvar mdiPrinter3dNozzle = \"M7,2H17V8H19V13H16.5L13,17H11L7.5,13H5V8H7V2M10,22H2V20H10A1,1 0 0,0 11,19V18H13V19A3,3 0 0,1 10,22Z\";\r\nvar mdiPrinter3dNozzleAlert = \"M7 2H17V8H19V13H16.5L13 17H11L7.5 13H5V8H7V2M10 22H2V20H10C10.6 20 11 19.5 11 19V18H13V19C13 20.7 11.7 22 10 22M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiPrinter3dNozzleAlertOutline = \"M7 2H17V7H19V13H16.5L13 17H11L7.5 13H5V7H7V2M10 22H2V20H10C10.6 20 11 19.5 11 19V18H13V19C13 20.7 11.7 22 10 22M7 9V11H8.5L12 15L15.5 11H17V9H15V4H9V9H7M21 13V7H23V13H21M21 17V15H23V17H21Z\";\r\nvar mdiPrinter3dNozzleOutline = \"M7,2H17V7H19V13H16.5L13,17H11L7.5,13H5V7H7V2M10,22H2V20H10A1,1 0 0,0 11,19V18H13V19A3,3 0 0,1 10,22M7,9V11H8.5L12,15L15.5,11H17V9H15V4H9V9H7Z\";\r\nvar mdiPrinterAlert = \"M16 3H4V7H16M17 12C16.4 12 16 11.6 16 11S16.4 10 17 10 18 10.4 18 11 17.6 12 17 12M14 19H6V14H14M17 8H3C1.3 8 0 9.3 0 11V17H4V21H16V17H20V11C20 9.3 18.7 8 17 8M24 13H22V7H24V13M24 17H22V15H24V17Z\";\r\nvar mdiPrinterCheck = \"M18 7H6V3H18V7M6 21V17H2V11C2 9.34 3.34 8 5 8H19C20.66 8 22 9.34 22 11V13.81C21.12 13.3 20.1 13 19 13C17.77 13 16.64 13.37 15.69 14H8V19H13C13 19.7 13.13 20.37 13.35 21H6M18 11C18 11.55 18.45 12 19 12S20 11.55 20 11 19.55 10 19 10 18 10.45 18 11M23.5 17L22 15.5L18.5 19L16.5 17L15 18.5L18.5 22L23.5 17\";\r\nvar mdiPrinterEye = \"M9.8 21C9.6 20.6 9.3 20.2 9.2 19.7L8.8 19H8V14H13C14.2 13.4 15.6 13 17 13C18.9 13 20.6 13.6 22 14.6V11C22 9.3 20.7 8 19 8H5C3.3 8 2 9.3 2 11V17H6V21H9.8M19 10C19.6 10 20 10.4 20 11S19.6 12 19 12 18 11.6 18 11 18.4 10 19 10M18 7H6V3H18V7M17 18C17.6 18 18 18.4 18 19S17.6 20 17 20 16 19.6 16 19 16.4 18 17 18M17 15C14.3 15 11.9 16.7 11 19C11.9 21.3 14.3 23 17 23S22.1 21.3 23 19C22.1 16.7 19.7 15 17 15M17 21.5C15.6 21.5 14.5 20.4 14.5 19S15.6 16.5 17 16.5 19.5 17.6 19.5 19 18.4 21.5 17 21.5Z\";\r\nvar mdiPrinterOff = \"M6,3V4.18L8.82,7H18V3H6M2.28,3L1,4.27L4.75,8C3.19,8.15 2,9.44 2,11V17H6V21H17.73L19.73,23L21,21.72L2.28,3M9.82,8L18.82,17H22V11A3,3 0 0,0 19,8H9.82M19,10A1,1 0 0,1 20,11A1,1 0 0,1 19,12A1,1 0 0,1 18,11A1,1 0 0,1 19,10M8,14H10.73L15.73,19H8V14Z\";\r\nvar mdiPrinterPos = \"M18 10H6A2 2 0 0 0 4 12V19H20V12A2 2 0 0 0 18 10M18 14H14V12H18M17 9H7V4H17Z\";\r\nvar mdiPrinterSearch = \"M20.3 18.9C20.7 18.2 21 17.4 21 16.5C21 14 19 12 16.5 12S12 14 12 16.5 14 21 16.5 21C17.4 21 18.2 20.8 18.9 20.3L22 23.4L23.4 22L20.3 18.9M16.5 19C15.1 19 14 17.9 14 16.5S15.1 14 16.5 14 19 15.1 19 16.5 17.9 19 16.5 19M18 7H6V3H18V7M6 21V17H2V11C2 9.3 3.3 8 5 8H19C20.7 8 22 9.3 22 11V13C20.8 11.2 18.8 10 16.5 10C13.8 10 11.5 11.7 10.5 14H8V19H10.5C10.8 19.7 11.3 20.4 11.8 21H6Z\";\r\nvar mdiPrinterSettings = \"M18,2V6H6V2H18M19,11A1,1 0 0,0 20,10A1,1 0 0,0 19,9A1,1 0 0,0 18,10A1,1 0 0,0 19,11M16,18V13H8V18H16M19,7A3,3 0 0,1 22,10V16H18V20H6V16H2V10A3,3 0 0,1 5,7H19M15,24V22H17V24H15M11,24V22H13V24H11M7,24V22H9V24H7Z\";\r\nvar mdiPrinterWireless = \"M4.93,3.92L6.34,5.33C9.46,2.2 14.53,2.2 17.66,5.33L19.07,3.92C15.17,0 8.84,0 4.93,3.92M7.76,6.75L9.17,8.16C10.73,6.6 13.26,6.6 14.83,8.16L16.24,6.75C13.9,4.41 10.1,4.41 7.76,6.75M19,14A1,1 0 0,1 18,13A1,1 0 0,1 19,12A1,1 0 0,1 20,13A1,1 0 0,1 19,14M16,20H8V15H16V20M19,10H5A3,3 0 0,0 2,13V18H6V22H18V18H22V13A3,3 0 0,0 19,10Z\";\r\nvar mdiPriorityHigh = \"M14,19H22V17H14V19M14,13.5H22V11.5H14V13.5M14,8H22V6H14V8M2,12.5C2,8.92 4.92,6 8.5,6H9V4L12,7L9,10V8H8.5C6,8 4,10 4,12.5C4,15 6,17 8.5,17H12V19H8.5C4.92,19 2,16.08 2,12.5Z\";\r\nvar mdiPriorityLow = \"M14,5H22V7H14V5M14,10.5H22V12.5H14V10.5M14,16H22V18H14V16M2,11.5C2,15.08 4.92,18 8.5,18H9V20L12,17L9,14V16H8.5C6,16 4,14 4,11.5C4,9 6,7 8.5,7H12V5H8.5C4.92,5 2,7.92 2,11.5Z\";\r\nvar mdiProfessionalHexagon = \"M21,16.5C21,16.88 20.79,17.21 20.47,17.38L12.57,21.82C12.41,21.94 12.21,22 12,22C11.79,22 11.59,21.94 11.43,21.82L3.53,17.38C3.21,17.21 3,16.88 3,16.5V7.5C3,7.12 3.21,6.79 3.53,6.62L11.43,2.18C11.59,2.06 11.79,2 12,2C12.21,2 12.41,2.06 12.57,2.18L20.47,6.62C20.79,6.79 21,7.12 21,7.5V16.5M5,9V15H6.25V13H7A2,2 0 0,0 9,11A2,2 0 0,0 7,9H5M6.25,12V10H6.75A1,1 0 0,1 7.75,11A1,1 0 0,1 6.75,12H6.25M9.75,9V15H11V13H11.75L12.41,15H13.73L12.94,12.61C13.43,12.25 13.75,11.66 13.75,11A2,2 0 0,0 11.75,9H9.75M11,12V10H11.5A1,1 0 0,1 12.5,11A1,1 0 0,1 11.5,12H11M17,9C15.62,9 14.5,10.34 14.5,12C14.5,13.66 15.62,15 17,15C18.38,15 19.5,13.66 19.5,12C19.5,10.34 18.38,9 17,9M17,10.25C17.76,10.25 18.38,11.03 18.38,12C18.38,12.97 17.76,13.75 17,13.75C16.24,13.75 15.63,12.97 15.63,12C15.63,11.03 16.24,10.25 17,10.25Z\";\r\nvar mdiProgressAlert = \"M13,2V4C17.39,4.54 20.5,8.53 19.96,12.92C19.5,16.56 16.64,19.43 13,19.88V21.88C18.5,21.28 22.45,16.34 21.85,10.85C21.33,6.19 17.66,2.5 13,2M11,2C9.04,2.18 7.19,2.95 5.67,4.2L7.1,5.74C8.22,4.84 9.57,4.26 11,4.06V2.06M4.26,5.67C3,7.19 2.24,9.04 2.05,11H4.05C4.24,9.58 4.8,8.23 5.69,7.1L4.26,5.67M2.06,13C2.26,14.96 3.03,16.81 4.27,18.33L5.69,16.9C4.81,15.77 4.24,14.42 4.06,13H2.06M7.06,18.37L5.67,19.74C7.18,21 9.04,21.79 11,22V20C9.58,19.82 8.23,19.25 7.1,18.37H7.06M13,13V7H11V13H13M13,17V15H11V17H13Z\";\r\nvar mdiProgressCheck = \"M13,2.03V2.05L13,4.05C17.39,4.59 20.5,8.58 19.96,12.97C19.5,16.61 16.64,19.5 13,19.93V21.93C18.5,21.38 22.5,16.5 21.95,11C21.5,6.25 17.73,2.5 13,2.03M11,2.06C9.05,2.25 7.19,3 5.67,4.26L7.1,5.74C8.22,4.84 9.57,4.26 11,4.06V2.06M4.26,5.67C3,7.19 2.25,9.04 2.05,11H4.05C4.24,9.58 4.8,8.23 5.69,7.1L4.26,5.67M15.5,8.5L10.62,13.38L8.5,11.26L7.44,12.32L10.62,15.5L16.56,9.56L15.5,8.5M2.06,13C2.26,14.96 3.03,16.81 4.27,18.33L5.69,16.9C4.81,15.77 4.24,14.42 4.06,13H2.06M7.1,18.37L5.67,19.74C7.18,21 9.04,21.79 11,22V20C9.58,19.82 8.23,19.25 7.1,18.37Z\";\r\nvar mdiProgressClock = \"M13,2.03V2.05L13,4.05C17.39,4.59 20.5,8.58 19.96,12.97C19.5,16.61 16.64,19.5 13,19.93V21.93C18.5,21.38 22.5,16.5 21.95,11C21.5,6.25 17.73,2.5 13,2.03M11,2.06C9.05,2.25 7.19,3 5.67,4.26L7.1,5.74C8.22,4.84 9.57,4.26 11,4.06V2.06M4.26,5.67C3,7.19 2.25,9.04 2.05,11H4.05C4.24,9.58 4.8,8.23 5.69,7.1L4.26,5.67M2.06,13C2.26,14.96 3.03,16.81 4.27,18.33L5.69,16.9C4.81,15.77 4.24,14.42 4.06,13H2.06M7.1,18.37L5.67,19.74C7.18,21 9.04,21.79 11,22V20C9.58,19.82 8.23,19.25 7.1,18.37M12.5,7V12.25L17,14.92L16.25,16.15L11,13V7H12.5Z\";\r\nvar mdiProgressClose = \"M13 2.03V4.05C17.39 4.59 20.5 8.58 19.96 12.97C19.5 16.61 16.64 19.5 13 19.93V21.93C18.5 21.38 22.5 16.5 21.95 11C21.5 6.25 17.73 2.5 13 2.03M11 2.06C9.05 2.25 7.19 3 5.67 4.26L7.1 5.74C8.22 4.84 9.57 4.26 11 4.06V2.06M4.26 5.67C3 7.19 2.25 9.04 2.05 11H4.05C4.24 9.58 4.8 8.23 5.69 7.1L4.26 5.67M2.06 13C2.26 14.96 3.03 16.81 4.27 18.33L5.69 16.9C4.81 15.77 4.24 14.42 4.06 13H2.06M7.1 18.37L5.67 19.74C7.18 21 9.04 21.79 11 22V20C9.58 19.82 8.23 19.25 7.1 18.37M14.59 8L12 10.59L9.41 8L8 9.41L10.59 12L8 14.59L9.41 16L12 13.41L14.59 16L16 14.59L13.41 12L16 9.41L14.59 8Z\";\r\nvar mdiProgressDownload = \"M13,2.03C17.73,2.5 21.5,6.25 21.95,11C22.5,16.5 18.5,21.38 13,21.93V19.93C16.64,19.5 19.5,16.61 19.96,12.97C20.5,8.58 17.39,4.59 13,4.05V2.05L13,2.03M11,2.06V4.06C9.57,4.26 8.22,4.84 7.1,5.74L5.67,4.26C7.19,3 9.05,2.25 11,2.06M4.26,5.67L5.69,7.1C4.8,8.23 4.24,9.58 4.05,11H2.05C2.25,9.04 3,7.19 4.26,5.67M2.06,13H4.06C4.24,14.42 4.81,15.77 5.69,16.9L4.27,18.33C3.03,16.81 2.26,14.96 2.06,13M7.1,18.37C8.23,19.25 9.58,19.82 11,20V22C9.04,21.79 7.18,21 5.67,19.74L7.1,18.37M12,16.5L7.5,12H11V8H13V12H16.5L12,16.5Z\";\r\nvar mdiProgressQuestion = \"M13 2.03V4.05C17.39 4.59 20.5 8.58 19.96 12.97C19.5 16.61 16.64 19.5 13 19.93V21.93C18.5 21.38 22.5 16.5 21.95 11C21.5 6.25 17.73 2.5 13 2.03M11 2.06C9.05 2.25 7.19 3 5.67 4.26L7.1 5.74C8.22 4.84 9.57 4.26 11 4.06V2.06M4.26 5.67C3 7.19 2.25 9.04 2.05 11H4.05C4.24 9.58 4.8 8.23 5.69 7.1L4.26 5.67M2.06 13C2.26 14.96 3.03 16.81 4.27 18.33L5.69 16.9C4.81 15.77 4.24 14.42 4.06 13H2.06M7.1 18.37L5.67 19.74C7.18 21 9.04 21.79 11 22V20C9.58 19.82 8.23 19.25 7.1 18.37M20 4H44M13 18H11V16H13V18M13 15H11C11 11.75 14 12 14 10C14 8.9 13.1 8 12 8S10 8.9 10 10H8C8 7.79 9.79 6 12 6S16 7.79 16 10C16 12.5 13 12.75 13 15Z\";\r\nvar mdiProgressUpload = \"M13,2.03C17.73,2.5 21.5,6.25 21.95,11C22.5,16.5 18.5,21.38 13,21.93V19.93C16.64,19.5 19.5,16.61 19.96,12.97C20.5,8.58 17.39,4.59 13,4.05V2.05L13,2.03M11,2.06V4.06C9.57,4.26 8.22,4.84 7.1,5.74L5.67,4.26C7.19,3 9.05,2.25 11,2.06M4.26,5.67L5.69,7.1C4.8,8.23 4.24,9.58 4.05,11H2.05C2.25,9.04 3,7.19 4.26,5.67M2.06,13H4.06C4.24,14.42 4.81,15.77 5.69,16.9L4.27,18.33C3.03,16.81 2.26,14.96 2.06,13M7.1,18.37C8.23,19.25 9.58,19.82 11,20V22C9.04,21.79 7.18,21 5.67,19.74L7.1,18.37M12,7.5L7.5,12H11V16H13V12H16.5L12,7.5Z\";\r\nvar mdiProgressWrench = \"M13,2.03V2.05L13,4.05C17.39,4.59 20.5,8.58 19.96,12.97C19.5,16.61 16.64,19.5 13,19.93V21.93C18.5,21.38 22.5,16.5 21.95,11C21.5,6.25 17.73,2.5 13,2.03M11,2.06C9.05,2.25 7.19,3 5.67,4.26L7.1,5.74C8.22,4.84 9.57,4.26 11,4.06V2.06M4.26,5.67C3,7.19 2.25,9.04 2.05,11H4.05C4.24,9.58 4.8,8.23 5.69,7.1L4.26,5.67M2.06,13C2.26,14.96 3.03,16.81 4.27,18.33L5.69,16.9C4.81,15.77 4.24,14.42 4.06,13H2.06M7.1,18.37L5.67,19.74C7.18,21 9.04,21.79 11,22V20C9.58,19.82 8.23,19.25 7.1,18.37M16.82,15.19L12.71,11.08C13.12,10.04 12.89,8.82 12.03,7.97C11.13,7.06 9.78,6.88 8.69,7.38L10.63,9.32L9.28,10.68L7.29,8.73C6.75,9.82 7,11.17 7.88,12.08C8.74,12.94 9.96,13.16 11,12.76L15.11,16.86C15.29,17.05 15.56,17.05 15.74,16.86L16.78,15.83C17,15.65 17,15.33 16.82,15.19Z\";\r\nvar mdiProjector = \"M16,6C14.87,6 13.77,6.35 12.84,7H4C2.89,7 2,7.89 2,9V15C2,16.11 2.89,17 4,17H5V18A1,1 0 0,0 6,19H8A1,1 0 0,0 9,18V17H15V18A1,1 0 0,0 16,19H18A1,1 0 0,0 19,18V17H20C21.11,17 22,16.11 22,15V9C22,7.89 21.11,7 20,7H19.15C18.23,6.35 17.13,6 16,6M16,7.5A3.5,3.5 0 0,1 19.5,11A3.5,3.5 0 0,1 16,14.5A3.5,3.5 0 0,1 12.5,11A3.5,3.5 0 0,1 16,7.5M4,9H8V10H4V9M16,9A2,2 0 0,0 14,11A2,2 0 0,0 16,13A2,2 0 0,0 18,11A2,2 0 0,0 16,9M4,11H8V12H4V11M4,13H8V14H4V13Z\";\r\nvar mdiProjectorScreen = \"M4,2A1,1 0 0,0 3,3V4A1,1 0 0,0 4,5H5V14H11V16.59L6.79,20.79L8.21,22.21L11,19.41V22H13V19.41L15.79,22.21L17.21,20.79L13,16.59V14H19V5H20A1,1 0 0,0 21,4V3A1,1 0 0,0 20,2H4Z\";\r\nvar mdiPropaneTank = \"M16 6H16V4C16 2.9 15.11 2 14 2H10C8.9 2 8 2.9 8 4V6H8C5.79 6 4 7.79 4 10V17C4 18.86 5.28 20.41 7 20.86V22H17V20.86C18.72 20.42 20 18.86 20 17V10C20 7.79 18.21 6 16 6M10 4H14V6H10V4Z\";\r\nvar mdiPropaneTankOutline = \"M16 6V4C16 2.9 15.11 2 14 2H10C8.9 2 8 2.9 8 4V6C5.79 6 4 7.79 4 10V17C4 18.86 5.28 20.41 7 20.86V22H17V20.86C18.72 20.42 20 18.86 20 17V10C20 7.79 18.21 6 16 6M10 4H14V6H10V4M18 17C18 18.1 17.1 19 16 19H8C6.9 19 6 18.1 6 17V10C6 8.9 6.9 8 8 8H16C17.1 8 18 8.9 18 10V17Z\";\r\nvar mdiProtocol = \"M18 20H14L18 4H22M16 4H12L8 20H12M2 16.5A2.5 2.5 0 0 0 4.5 19A2.5 2.5 0 0 0 7 16.5A2.5 2.5 0 0 0 4.5 14A2.5 2.5 0 0 0 2 16.5M2 9.5A2.5 2.5 0 0 0 4.5 12A2.5 2.5 0 0 0 7 9.5A2.5 2.5 0 0 0 4.5 7A2.5 2.5 0 0 0 2 9.5Z\";\r\nvar mdiPublish = \"M5,4V6H19V4H5M5,14H9V20H15V14H19L12,7L5,14Z\";\r\nvar mdiPulse = \"M3,13H5.79L10.1,4.79L11.28,13.75L14.5,9.66L17.83,13H21V15H17L14.67,12.67L9.92,18.73L8.94,11.31L7,15H3V13Z\";\r\nvar mdiPump = \"M2 21V15H3.5C3.18 14.06 3 13.05 3 12C3 7.03 7.03 3 12 3H22V9H20.5C20.82 9.94 21 10.95 21 12C21 16.97 16.97 21 12 21H2M5 12C5 13.28 5.34 14.47 5.94 15.5L9.4 13.5C9.15 13.06 9 12.55 9 12C9 11.35 9.21 10.75 9.56 10.26L6.3 7.93C5.5 9.08 5 10.5 5 12M12 19C14.59 19 16.85 17.59 18.06 15.5L14.6 13.5C14.08 14.4 13.11 15 12 15L11.71 15L11.33 18.97L12 19M12 9C13.21 9 14.26 9.72 14.73 10.76L18.37 9.1C17.27 6.68 14.83 5 12 5V9M12 11C11.45 11 11 11.45 11 12C11 12.55 11.45 13 12 13C12.55 13 13 12.55 13 12C13 11.45 12.55 11 12 11Z\";\r\nvar mdiPumpkin = \"M6.5,6C7.47,6 8.37,6.5 9.11,7.38C9.66,6.79 10.31,6.36 11,6.15V4A2,2 0 0,1 13,2H15V4H13V6.15C13.69,6.36 14.34,6.79 14.89,7.38C15.63,6.5 16.53,6 17.5,6C20,6 22,9.36 22,13.5C22,17.64 20,21 17.5,21C16.53,21 15.63,20.5 14.89,19.62C14.08,20.5 13.08,21 12,21C10.92,21 9.92,20.5 9.11,19.62C8.37,20.5 7.47,21 6.5,21C4,21 2,17.64 2,13.5C2,9.36 4,6 6.5,6Z\";\r\nvar mdiPurse = \"M22,19.1L21,10.5A1.65,1.65 0 0,0 19.3,9H16V5L14,3H10L8,5V9H4.7A1.65,1.65 0 0,0 3,10.5L2,19.1A1.74,1.74 0 0,0 3.7,21H20.3A1.74,1.74 0 0,0 22,19.1M10,5H14V9H10\";\r\nvar mdiPurseOutline = \"M19,11L20,19H4L5,11H19M14,3H10L8,5V9H4.7A1.65,1.65 0 0,0 3,10.5L2,19.1A1.74,1.74 0 0,0 3.7,21H20.3A1.74,1.74 0 0,0 22,19.1L21,10.5A1.65,1.65 0 0,0 19.3,9H16V5L14,3M10,9V5H14V9\";\r\nvar mdiPuzzle = \"M20.5,11H19V7C19,5.89 18.1,5 17,5H13V3.5A2.5,2.5 0 0,0 10.5,1A2.5,2.5 0 0,0 8,3.5V5H4A2,2 0 0,0 2,7V10.8H3.5C5,10.8 6.2,12 6.2,13.5C6.2,15 5,16.2 3.5,16.2H2V20A2,2 0 0,0 4,22H7.8V20.5C7.8,19 9,17.8 10.5,17.8C12,17.8 13.2,19 13.2,20.5V22H17A2,2 0 0,0 19,20V16H20.5A2.5,2.5 0 0,0 23,13.5A2.5,2.5 0 0,0 20.5,11Z\";\r\nvar mdiPuzzleCheck = \"M23.5 17L18.5 22L15 18.5L16.5 17L18.5 19L22 15.5L23.5 17M20.5 11C21.88 11 23 12.12 23 13.5C23 13.81 22.94 14.11 22.84 14.39C21.8 13.5 20.46 13 19 13C15.69 13 13 15.69 13 19V19.54C12.64 18.5 11.65 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.1 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.89 2.9 5 4 5H8V3.5C8 2.12 9.12 .998 10.5 .998S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11H20.5\";\r\nvar mdiPuzzleCheckOutline = \"M23.5 17L18.5 22L15 18.5L16.5 17L18.5 19L22 15.5L23.5 17M22 13.5L22 13.8C21.37 13.44 20.67 13.19 19.94 13.07C19.75 12.45 19.18 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4C9.67 4 9 4.67 9 5.5V7H4L4 9.12C5.76 9.8 7 11.5 7 13.5C7 15.5 5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.47 17 12.37 17.3 13.12 17.8L13 19C13 20.09 13.29 21.12 13.8 22H13.2V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.1 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5C5 12 3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2C12.26 2 13.72 3.3 13.96 5H17C18.1 5 19 5.9 19 7V10.04C20.7 10.28 22 11.74 22 13.5Z\";\r\nvar mdiPuzzleEdit = \"M21.04 12.13C20.9 12.13 20.76 12.19 20.65 12.3L19.65 13.3L21.7 15.35L22.7 14.35C22.92 14.14 22.92 13.79 22.7 13.58L21.42 12.3C21.31 12.19 21.18 12.13 21.04 12.13M19.07 13.88L13 19.94V22H15.06L21.12 15.93L19.07 13.88M19 11.12L11.91 18.2C11.5 17.95 11 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.11 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.9 2.9 5 4 5H8V3.5C8 2.12 9.12 1 10.5 1S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11.12Z\";\r\nvar mdiPuzzleEditOutline = \"M21.04 12.13C20.9 12.13 20.76 12.19 20.65 12.3L19.65 13.3L21.7 15.35L22.7 14.35C22.92 14.14 22.92 13.79 22.7 13.58L21.42 12.3C21.31 12.19 21.18 12.13 21.04 12.13M19.07 13.88L13 19.94V22H15.06L21.12 15.93L19.07 13.88M11.05 19.06C10.87 19 10.69 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C19.36 10.09 19.69 10.21 20 10.36C19.73 10.5 19.46 10.66 19.24 10.89L18.12 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.26 17 12 17.18 12.61 17.5L11.05 19.06Z\";\r\nvar mdiPuzzleHeart = \"M19 22.3L18.4 21.8C16.4 19.9 15 18.7 15 17.2C15 16 16 15 17.2 15C17.9 15 18.6 15.3 19 15.8C19.4 15.3 20.1 15 20.8 15C22 15 23 15.9 23 17.2C23 18.7 21.6 19.9 19.6 21.8L19 22.3M20.5 11H19V7C19 5.89 18.1 5 17 5H13V3.5C13 2.12 11.88 1 10.5 1S8 2.12 8 3.5V5H4C2.9 5 2 5.9 2 7V10.8H3.5C5 10.8 6.2 12 6.2 13.5S5 16.2 3.5 16.2H2V20C2 21.11 2.9 22 4 22H7.8V20.5C7.8 19 9 17.8 10.5 17.8C11.44 17.8 12.27 18.27 12.75 19H13.09C13.04 18.67 13 18.34 13 18C13 14.69 15.69 12 19 12C20.54 12 21.94 12.58 23 13.53C23 13.5 23 13.5 23 13.5C23 12.12 21.88 11 20.5 11Z\";\r\nvar mdiPuzzleHeartOutline = \"M13.2 22V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C20.45 10.25 21.61 11.34 21.91 12.76C21.05 12.28 20.06 12 19 12C18.89 12 18.78 12 18.67 12C18.61 12 18.56 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.43 17 12.29 17.28 13 17.74C13 17.83 13 17.91 13 18C13 19.54 13.58 20.94 14.54 22H13.2M19 22.3L19.6 21.8C21.6 19.9 23 18.7 23 17.2C23 15.9 22 15 20.8 15C20.1 15 19.4 15.3 19 15.8C18.6 15.3 17.9 15 17.2 15C16 15 15 16 15 17.2C15 18.7 16.4 19.9 18.4 21.8L19 22.3\";\r\nvar mdiPuzzleMinus = \"M13.04 19.61C12.67 18.55 11.68 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.11 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.9 2.9 5 4 5H8V3.5C8 2.12 9.12 1 10.5 1S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11H20.5C21.88 11 23 12.12 23 13.5C23 13.82 22.94 14.12 22.83 14.39C21.79 13.53 20.46 13 19 13C15.69 13 13 15.69 13 19C13 19.2 13 19.41 13.04 19.61M15 18V20H23V18H15Z\";\r\nvar mdiPuzzleMinusOutline = \"M13.2 22V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C20.7 10.28 22 11.74 22 13.5C22 13.6 22 13.7 21.97 13.79C21.35 13.44 20.67 13.2 19.93 13.08C19.75 12.46 19.18 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.47 17 12.37 17.3 13.12 17.81C13.04 18.19 13 18.59 13 19C13 20.1 13.3 21.12 13.81 22H13.2M15 18V20H23V18H15Z\";\r\nvar mdiPuzzleOutline = \"M22,13.5C22,15.26 20.7,16.72 19,16.96V20A2,2 0 0,1 17,22H13.2V21.7A2.7,2.7 0 0,0 10.5,19C9,19 7.8,20.21 7.8,21.7V22H4A2,2 0 0,1 2,20V16.2H2.3C3.79,16.2 5,15 5,13.5C5,12 3.79,10.8 2.3,10.8H2V7A2,2 0 0,1 4,5H7.04C7.28,3.3 8.74,2 10.5,2C12.26,2 13.72,3.3 13.96,5H17A2,2 0 0,1 19,7V10.04C20.7,10.28 22,11.74 22,13.5M17,15H18.5A1.5,1.5 0 0,0 20,13.5A1.5,1.5 0 0,0 18.5,12H17V7H12V5.5A1.5,1.5 0 0,0 10.5,4A1.5,1.5 0 0,0 9,5.5V7H4V9.12C5.76,9.8 7,11.5 7,13.5C7,15.5 5.75,17.2 4,17.88V20H6.12C6.8,18.25 8.5,17 10.5,17C12.5,17 14.2,18.25 14.88,20H17V15Z\";\r\nvar mdiPuzzlePlus = \"M13.04 19.61C12.67 18.55 11.68 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.11 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.9 2.9 5 4 5H8V3.5C8 2.12 9.12 1 10.5 1S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11H20.5C21.88 11 23 12.12 23 13.5C23 13.82 22.94 14.12 22.83 14.39C21.79 13.53 20.46 13 19 13C15.69 13 13 15.69 13 19C13 19.2 13 19.41 13.04 19.61M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiPuzzlePlusOutline = \"M13.2 22V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C20.7 10.28 22 11.74 22 13.5C22 13.6 22 13.7 21.97 13.79C21.35 13.44 20.67 13.2 19.93 13.08C19.75 12.46 19.18 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.47 17 12.37 17.3 13.12 17.81C13.04 18.19 13 18.59 13 19C13 20.1 13.3 21.12 13.81 22H13.2M18 15V18H15V20H18V23H20V20H23V18H20V15H18Z\";\r\nvar mdiPuzzleRemove = \"M13.04 19.61C12.67 18.55 11.68 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.11 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.9 2.9 5 4 5H8V3.5C8 2.12 9.12 1 10.5 1S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11H20.5C21.88 11 23 12.12 23 13.5C23 13.82 22.94 14.12 22.83 14.39C21.79 13.53 20.46 13 19 13C15.69 13 13 15.69 13 19C13 19.2 13 19.41 13.04 19.61M21.12 15.46L19 17.59L16.88 15.46L15.47 16.88L17.59 19L15.47 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88L21.12 15.46Z\";\r\nvar mdiPuzzleRemoveOutline = \"M13.2 22V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C20.7 10.28 22 11.74 22 13.5C22 13.6 22 13.7 21.97 13.79C21.35 13.44 20.67 13.2 19.93 13.08C19.75 12.46 19.18 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.47 17 12.37 17.3 13.12 17.81C13.04 18.19 13 18.59 13 19C13 20.1 13.3 21.12 13.81 22H13.2M21.12 15.46L19 17.59L16.88 15.46L15.47 16.88L17.59 19L15.47 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88L21.12 15.46Z\";\r\nvar mdiPuzzleStar = \"M19 20.09L21.45 21.58L20.8 18.77L23 16.89L20.11 16.64L19 14L17.87 16.64L15 16.89L17.18 18.77L16.5 21.58L19 20.09M23 13.5C23 13.5 23 13.5 23 13.53C21.94 12.58 20.54 12 19 12C15.69 12 13 14.69 13 18C13 18.34 13.04 18.67 13.09 19H12.75C12.27 18.27 11.44 17.8 10.5 17.8C9 17.8 7.8 19 7.8 20.5V22H4C2.9 22 2 21.11 2 20V16.2H3.5C5 16.2 6.2 15 6.2 13.5S5 10.8 3.5 10.8H2V7C2 5.9 2.9 5 4 5H8V3.5C8 2.12 9.12 1 10.5 1S13 2.12 13 3.5V5H17C18.1 5 19 5.89 19 7V11H20.5C21.88 11 23 12.12 23 13.5Z\";\r\nvar mdiPuzzleStarOutline = \"M13.2 22V21.7C13.2 20.21 12 19 10.5 19C9 19 7.8 20.21 7.8 21.7V22H4C2.9 22 2 21.11 2 20V16.2H2.3C3.79 16.2 5 15 5 13.5S3.79 10.8 2.3 10.8H2V7C2 5.9 2.9 5 4 5H7.04C7.28 3.3 8.74 2 10.5 2S13.72 3.3 13.96 5H17C18.11 5 19 5.9 19 7V10.04C20.45 10.25 21.61 11.34 21.91 12.76C21.05 12.28 20.06 12 19 12C18.89 12 18.78 12 18.67 12C18.61 12 18.56 12 18.5 12H17V7H12V5.5C12 4.67 11.33 4 10.5 4S9 4.67 9 5.5V7H4V9.12C5.76 9.8 7 11.5 7 13.5S5.75 17.2 4 17.88V20H6.12C6.8 18.25 8.5 17 10.5 17C11.43 17 12.29 17.28 13 17.74C13 17.83 13 17.91 13 18C13 19.54 13.58 20.94 14.54 22H13.2M19 20.09L16.5 21.58L17.18 18.77L15 16.89L17.87 16.64L19 14L20.11 16.64L23 16.89L20.8 18.77L21.45 21.58L19 20.09\";\r\nvar mdiQi = \"M12.09,6.56V14.64C12.09,14.72 12,14.79 11.94,14.79C9.62,14.79 7.75,12.91 7.75,10.6C7.75,8.28 9.62,6.4 11.94,6.4C12,6.4 12.09,6.47 12.09,6.56M12.09,17.86V20.29C12.06,21.69 13.12,22.87 14.5,23C14.66,23 14.78,22.89 14.79,22.73V4.47C14.78,4.3 14.68,4.15 14.5,4.09C10.92,2.67 6.86,4.44 5.44,8.03C4,11.63 5.79,15.69 9.38,17.11C10.16,17.42 11,17.58 11.81,17.6C11.95,17.59 12.07,17.71 12.08,17.87M16.19,5.5V15.72C16.19,16 16.19,16.2 16.46,16V16C19.42,13.5 19.81,9.09 17.33,6.13C17.07,5.81 16.77,5.5 16.46,5.26C16.19,5.05 16.19,5.26 16.19,5.53M14.79,2.43C14.79,1.66 15.42,1.03 16.19,1.03C16.96,1.03 17.59,1.66 17.59,2.43C17.59,3.2 16.96,3.83 16.19,3.83V3.83C15.42,3.83 14.79,3.2 14.79,2.43\";\r\nvar mdiQqchat = \"M3.18,13.54C3.76,12.16 4.57,11.14 5.17,10.92C5.16,10.12 5.31,9.62 5.56,9.22C5.56,9.19 5.5,8.86 5.72,8.45C5.87,4.85 8.21,2 12,2C15.79,2 18.13,4.85 18.28,8.45C18.5,8.86 18.44,9.19 18.44,9.22C18.69,9.62 18.84,10.12 18.83,10.92C19.43,11.14 20.24,12.16 20.82,13.55C21.57,15.31 21.69,17 21.09,17.3C20.68,17.5 20.03,17 19.42,16.12C19.18,17.1 18.58,18 17.73,18.71C18.63,19.04 19.21,19.58 19.21,20.19C19.21,21.19 17.63,22 15.69,22C13.93,22 12.5,21.34 12.21,20.5H11.79C11.5,21.34 10.07,22 8.31,22C6.37,22 4.79,21.19 4.79,20.19C4.79,19.58 5.37,19.04 6.27,18.71C5.42,18 4.82,17.1 4.58,16.12C3.97,17 3.32,17.5 2.91,17.3C2.31,17 2.43,15.31 3.18,13.54Z\";\r\nvar mdiQrcode = \"M3,11H5V13H3V11M11,5H13V9H11V5M9,11H13V15H11V13H9V11M15,11H17V13H19V11H21V13H19V15H21V19H19V21H17V19H13V21H11V17H15V15H17V13H15V11M19,19V15H17V19H19M15,3H21V9H15V3M17,5V7H19V5H17M3,3H9V9H3V3M5,5V7H7V5H5M3,15H9V21H3V15M5,17V19H7V17H5Z\";\r\nvar mdiQrcodeEdit = \"M5,5H7V7H5V5M1,1H11V11H1V1M3,3V9H9V3H3M5,17H7V19H5V17M1,13H11V23H1V13M3,15V21H9V15H3M13,13H17V15H19V13H23V15H19V17H23V23H19V21H15V23H13V21H15V19H13V13M21,21V19H19V21H21M19,17H17V15H15V19H19V17M22.7,3.35L21.7,4.35L19.65,2.35L20.65,1.35C20.85,1.14 21.19,1.13 21.42,1.35L22.7,2.58C22.91,2.78 22.92,3.12 22.7,3.35M13,8.94L19.07,2.88L21.12,4.93L15.06,11H13V8.94Z\";\r\nvar mdiQrcodeMinus = \"M5 5H7V7H5V5M1 1H11V11H1V1M3 3V9H9V3H3M5 17H7V19H5V17M1 13H11V23H1V13M3 15V21H9V15H3M13 13H17V15H19V13H23V15H19V17H23V23H19V21H15V23H13V21H15V19H13V13M21 21V19H19V21H21M19 17H17V15H15V19H19V17M14 5V7H22V5Z\";\r\nvar mdiQrcodePlus = \"M5 5H7V7H5V5M1 1H11V11H1V1M3 3V9H9V3H3M5 17H7V19H5V17M1 13H11V23H1V13M3 15V21H9V15H3M13 13H17V15H19V13H23V15H19V17H23V23H19V21H15V23H13V21H15V19H13V13M21 21V19H19V21H21M19 17H17V15H15V19H19V17M17 2V5H14V7H17V10H19V7H22V5H19V2Z\";\r\nvar mdiQrcodeRemove = \"M5 5H7V7H5V5M1 1H11V11H1V1M3 3V9H9V3H3M5 17H7V19H5V17M1 13H11V23H1V13M3 15V21H9V15H3M13 13H17V15H19V13H23V15H19V17H23V23H19V21H15V23H13V21H15V19H13V13M21 21V19H19V21H21M19 17H17V15H15V19H19V17M15.17 1.76L13.76 3.17L16.59 6L13.76 8.83L15.17 10.24L18 7.41L20.83 10.24L22.24 8.83L19.41 6L22.24 3.17L20.83 1.76L18 4.59L15.17 1.76Z\";\r\nvar mdiQrcodeScan = \"M4,4H10V10H4V4M20,4V10H14V4H20M14,15H16V13H14V11H16V13H18V11H20V13H18V15H20V18H18V20H16V18H13V20H11V16H14V15M16,15V18H18V15H16M4,20V14H10V20H4M6,6V8H8V6H6M16,6V8H18V6H16M6,16V18H8V16H6M4,11H6V13H4V11M9,11H13V15H11V13H9V11M11,6H13V10H11V6M2,2V6H0V2A2,2 0 0,1 2,0H6V2H2M22,0A2,2 0 0,1 24,2V6H22V2H18V0H22M2,18V22H6V24H2A2,2 0 0,1 0,22V18H2M22,22V18H24V22A2,2 0 0,1 22,24H18V22H22Z\";\r\nvar mdiQuadcopter = \"M5.5,1C8,1 10,3 10,5.5C10,6.38 9.75,7.2 9.31,7.9L9.41,8H14.59L14.69,7.9C14.25,7.2 14,6.38 14,5.5C14,3 16,1 18.5,1C21,1 23,3 23,5.5C23,8 21,10 18.5,10C17.62,10 16.8,9.75 16.1,9.31L15,10.41V13.59L16.1,14.69C16.8,14.25 17.62,14 18.5,14C21,14 23,16 23,18.5C23,21 21,23 18.5,23C16,23 14,21 14,18.5C14,17.62 14.25,16.8 14.69,16.1L14.59,16H9.41L9.31,16.1C9.75,16.8 10,17.62 10,18.5C10,21 8,23 5.5,23C3,23 1,21 1,18.5C1,16 3,14 5.5,14C6.38,14 7.2,14.25 7.9,14.69L9,13.59V10.41L7.9,9.31C7.2,9.75 6.38,10 5.5,10C3,10 1,8 1,5.5C1,3 3,1 5.5,1M5.5,3A2.5,2.5 0 0,0 3,5.5A2.5,2.5 0 0,0 5.5,8A2.5,2.5 0 0,0 8,5.5A2.5,2.5 0 0,0 5.5,3M5.5,16A2.5,2.5 0 0,0 3,18.5A2.5,2.5 0 0,0 5.5,21A2.5,2.5 0 0,0 8,18.5A2.5,2.5 0 0,0 5.5,16M18.5,3A2.5,2.5 0 0,0 16,5.5A2.5,2.5 0 0,0 18.5,8A2.5,2.5 0 0,0 21,5.5A2.5,2.5 0 0,0 18.5,3M18.5,16A2.5,2.5 0 0,0 16,18.5A2.5,2.5 0 0,0 18.5,21A2.5,2.5 0 0,0 21,18.5A2.5,2.5 0 0,0 18.5,16M3.91,17.25L5.04,17.91C5.17,17.81 5.33,17.75 5.5,17.75A0.75,0.75 0 0,1 6.25,18.5L6.24,18.6L7.37,19.25L7.09,19.75L5.96,19.09C5.83,19.19 5.67,19.25 5.5,19.25A0.75,0.75 0 0,1 4.75,18.5L4.76,18.4L3.63,17.75L3.91,17.25M3.63,6.25L4.76,5.6L4.75,5.5A0.75,0.75 0 0,1 5.5,4.75C5.67,4.75 5.83,4.81 5.96,4.91L7.09,4.25L7.37,4.75L6.24,5.4L6.25,5.5A0.75,0.75 0 0,1 5.5,6.25C5.33,6.25 5.17,6.19 5.04,6.09L3.91,6.75L3.63,6.25M16.91,4.25L18.04,4.91C18.17,4.81 18.33,4.75 18.5,4.75A0.75,0.75 0 0,1 19.25,5.5L19.24,5.6L20.37,6.25L20.09,6.75L18.96,6.09C18.83,6.19 18.67,6.25 18.5,6.25A0.75,0.75 0 0,1 17.75,5.5L17.76,5.4L16.63,4.75L16.91,4.25M16.63,19.25L17.75,18.5A0.75,0.75 0 0,1 18.5,17.75C18.67,17.75 18.83,17.81 18.96,17.91L20.09,17.25L20.37,17.75L19.25,18.5A0.75,0.75 0 0,1 18.5,19.25C18.33,19.25 18.17,19.19 18.04,19.09L16.91,19.75L16.63,19.25Z\";\r\nvar mdiQualityHigh = \"M14.5,13.5H16.5V10.5H14.5M18,14A1,1 0 0,1 17,15H16.25V16.5H14.75V15H14A1,1 0 0,1 13,14V10A1,1 0 0,1 14,9H17A1,1 0 0,1 18,10M11,15H9.5V13H7.5V15H6V9H7.5V11.5H9.5V9H11M19,4H5C3.89,4 3,4.89 3,6V18A2,2 0 0,0 5,20H19A2,2 0 0,0 21,18V6C21,4.89 20.1,4 19,4Z\";\r\nvar mdiQualityLow = \"M14.5,13.5H16.5V10.5H14.5M18,14C18,14.6 17.6,15 17,15H16.25V16.5H14.75V15H14C13.4,15 13,14.6 13,14V10C13,9.4 13.4,9 14,9H17C17.6,9 18,9.4 18,10M19,4H5A2,2 0 0,0 3,6V18A2,2 0 0,0 5,20H19A2,2 0 0,0 21,18V6A2,2 0 0,0 19,4M11,13.5V15H6V9H7.5V13.5H11Z\";\r\nvar mdiQualityMedium = \"M21,6V18A2,2 0 0,1 19,20H5A2,2 0 0,1 3,18V6A2,2 0 0,1 5,4H19A2,2 0 0,1 21,6M12,10C12,9.5 11.5,9 11,9H6.5C6,9 5.5,9.5 5.5,10V15H7V10.5H8V14H9.5V10.5H10.5V15H12V10M14.5,9A1,1 0 0,0 13.5,10V14A1,1 0 0,0 14.5,15H15.5V16.5H16.75V15H17.5A1,1 0 0,0 18.5,14V10A1,1 0 0,0 17.5,9H14.5M15,10.5H17V13.5H15V10.5Z\";\r\nvar mdiQuora = \"M19.7,18.8C20.2,18.2 20.1,17.7 20.1,17.7H21.6C21.6,17.7 21.6,18.1 21.5,18.6C21.4,19 21.3,19.3 21.2,19.6C21,20.3 20,21.1 20,21.1C18.9,22 17.7,21.9 17.7,21.9C17.7,21.9 16.3,22.1 15.2,21.4C14.1,20.7 13.2,19.2 13.2,19.2C13.2,19.2 8.8,20.4 5.4,17.5C2,14.6 2.2,11.1 2.2,10.8C2.2,10.1 2.6,2.3 10.8,2C15.6,1.8 18.2,4.8 19.2,7.2C19.9,8.9 19.9,10.2 19.9,10.4C19.9,10.6 19.9,11.5 19.7,12.4C19.6,13.3 19.2,14.3 18.9,14.8C18.6,15.3 18.2,16 17.7,16.5C17.2,17.1 16.6,17.6 16.5,17.7C16.5,17.7 17.5,18.9 18.1,19.1C18.3,19.1 19.2,19.4 19.7,18.8M12.7,17.3C12.8,17.2 12.4,16.7 12.2,16.4C12,16.1 12.3,16.5 11.5,15.4C11.2,14.9 10.8,14.7 10.2,14.6C10,14.6 9.7,14.6 9.5,14.6C9,14.6 8.7,14.7 8.6,14.7C8.6,14.6 8.4,14.4 8.3,14.2C8.2,14 8.2,13.7 8.2,13.7C8.2,13.5 9.7,12.8 11.4,12.8C12.8,12.8 13.8,13.6 14.2,14C14.6,14.3 14.7,14.7 15.1,15C15.1,15 15.2,15 15.2,15.1C15.6,15.4 16.1,12.1 16,9.9C15.9,7.7 15.8,6.6 15,5.5C14.3,4.5 12.8,3.7 11.4,3.7C10.7,3.7 8.4,3.8 7.4,5.5C6.2,7.5 6.4,11.1 6.4,11.1C6.4,11.1 6.1,14.3 7.8,16C9.5,17.7 11.2,17.4 12,17.4L12.7,17.3Z\";\r\nvar mdiRabbit = \"M18.05,21L15.32,16.26C15.32,14.53 14.25,13.42 12.95,13.42C12.05,13.42 11.27,13.92 10.87,14.66C11.2,14.47 11.59,14.37 12,14.37C13.3,14.37 14.36,15.43 14.36,16.73C14.36,18.04 13.31,19.11 12,19.11H15.3V21H6.79C6.55,21 6.3,20.91 6.12,20.72C5.75,20.35 5.75,19.75 6.12,19.38V19.38L6.62,18.88C6.28,18.73 6,18.5 5.72,18.26C5.5,18.76 5,19.11 4.42,19.11C3.64,19.11 3,18.47 3,17.68C3,16.9 3.64,16.26 4.42,16.26L4.89,16.34V14.37C4.89,11.75 7,9.63 9.63,9.63H9.65C11.77,9.64 13.42,10.47 13.42,9.16C13.42,8.23 13.62,7.86 13.96,7.34C13.23,7 12.4,6.79 11.53,6.79C11,6.79 10.58,6.37 10.58,5.84C10.58,5.41 10.86,5.05 11.25,4.93L10.58,4.89C10.06,4.89 9.63,4.47 9.63,3.95C9.63,3.42 10.06,3 10.58,3H11.53C13.63,3 15.47,4.15 16.46,5.85L16.74,5.84C17.45,5.84 18.11,6.07 18.65,6.45L19.1,6.83C21.27,8.78 21,10.1 21,10.11C21,11.39 19.94,12.44 18.65,12.44L18.16,12.39V12.47C18.16,13.58 17.68,14.57 16.93,15.27L20.24,21H18.05M18.16,7.74C17.63,7.74 17.21,8.16 17.21,8.68C17.21,9.21 17.63,9.63 18.16,9.63C18.68,9.63 19.11,9.21 19.11,8.68C19.11,8.16 18.68,7.74 18.16,7.74Z\";\r\nvar mdiRacingHelmet = \"M2.2,11.2C2,13.6 2.7,15.6 4.2,17.4C5.7,19.2 7.7,20 10.1,20H20.1C20.6,20 21.1,19.8 21.5,19.4C21.9,19 22.1,18.5 22.1,18V17.2C22.1,16.6 22,15.9 21.9,15H13.7C12.7,15 11.9,14.6 11.2,13.9C10.5,13.2 10.1,12.3 10.1,11.4C10.1,9.8 10.8,8.7 12.3,8.1L17.1,6C15.4,4.8 13.4,4.1 11.1,4C8.9,3.8 6.9,4.5 5.1,5.9C3.3,7.3 2.4,9 2.2,11.2M12.1,11.4C12.1,11.8 12.3,12.2 12.6,12.5C12.9,12.8 13.3,13 13.7,13H21.5C20.9,10.8 20,9 18.7,7.6L13.1,9.9C12.4,10.1 12.1,10.6 12.1,11.4Z\";\r\nvar mdiRacquetball = \"M18.5,16C19.9,16 21,17.1 21,18.5C21,19.9 19.9,21 18.5,21C17.1,21 16,19.9 16,18.5C16,17.1 17.1,16 18.5,16M10.5,1C3,1 3,3.7 3,9.8C3,13.2 6.4,16.9 9,18.1V23H12V18.1C14.6,16.9 18,13.2 18,9.8C18,3.6 18,1 10.5,1M15.4,4.2C15.7,4.6 15.8,5.2 15.9,6H15V3.8C15.2,3.9 15.3,4.1 15.4,4.2M16,9.8C16,9.9 16,10 16,10H15V7H16C16,7.8 16,8.7 16,9.8M14,14H11V11H14V14M7,14V11H10V14H7M5,9.8C5,8.8 5,7.9 5,7H6V10H5C5,9.9 5,9.8 5,9.8M7,7H10V10H7V7M11,3C12.4,3 13.4,3.2 14,3.3V6H11V3M10,6H7V3.4C7.6,3.2 8.6,3 10,3V6M11,10V7H14V10H11M6,3.8V6H5.1C5.2,5.2 5.3,4.6 5.6,4.2C5.7,4.1 5.8,4 6,3.8M5.2,11H6V12.7C5.7,12.1 5.4,11.6 5.2,11M8,15H10V16.3L9.8,16.2C9.2,16 8.6,15.5 8,15M11.2,16.3H11V15H13C12.4,15.5 11.8,16 11.2,16.3M15,12.7V11H15.8C15.6,11.5 15.3,12.1 15,12.7Z\";\r\nvar mdiRadar = \"M19.07,4.93L17.66,6.34C19.1,7.79 20,9.79 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12C4,7.92 7.05,4.56 11,4.07V6.09C8.16,6.57 6,9.03 6,12A6,6 0 0,0 12,18A6,6 0 0,0 18,12C18,10.34 17.33,8.84 16.24,7.76L14.83,9.17C15.55,9.9 16,10.9 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12C8,10.14 9.28,8.59 11,8.14V10.28C10.4,10.63 10,11.26 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12C14,11.26 13.6,10.62 13,10.28V2H12A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,9.24 20.88,6.74 19.07,4.93Z\";\r\nvar mdiRadiator = \"M7.95,3L6.53,5.19L7.95,7.4H7.94L5.95,10.5L4.22,9.6L5.64,7.39L4.22,5.19L6.22,2.09L7.95,3M13.95,2.89L12.53,5.1L13.95,7.3L13.94,7.31L11.95,10.4L10.22,9.5L11.64,7.3L10.22,5.1L12.22,2L13.95,2.89M20,2.89L18.56,5.1L20,7.3V7.31L18,10.4L16.25,9.5L17.67,7.3L16.25,5.1L18.25,2L20,2.89M2,22V14A2,2 0 0,1 4,12H20A2,2 0 0,1 22,14V22H20V20H4V22H2M6,14A1,1 0 0,0 5,15V17A1,1 0 0,0 6,18A1,1 0 0,0 7,17V15A1,1 0 0,0 6,14M10,14A1,1 0 0,0 9,15V17A1,1 0 0,0 10,18A1,1 0 0,0 11,17V15A1,1 0 0,0 10,14M14,14A1,1 0 0,0 13,15V17A1,1 0 0,0 14,18A1,1 0 0,0 15,17V15A1,1 0 0,0 14,14M18,14A1,1 0 0,0 17,15V17A1,1 0 0,0 18,18A1,1 0 0,0 19,17V15A1,1 0 0,0 18,14Z\";\r\nvar mdiRadiatorDisabled = \"M20,12H4A2,2 0 0,0 2,14V22H4V20H20V22H22V14A2,2 0 0,0 20,12M7,17A1,1 0 0,1 6,18A1,1 0 0,1 5,17V15A1,1 0 0,1 6,14A1,1 0 0,1 7,15V17M11,17A1,1 0 0,1 10,18A1,1 0 0,1 9,17V15A1,1 0 0,1 10,14A1,1 0 0,1 11,15V17M15,17A1,1 0 0,1 14,18A1,1 0 0,1 13,17V15A1,1 0 0,1 14,14A1,1 0 0,1 15,15V17M19,17A1,1 0 0,1 18,18A1,1 0 0,1 17,17V15A1,1 0 0,1 18,14A1,1 0 0,1 19,15V17Z\";\r\nvar mdiRadiatorOff = \"M3.28,2L2,3.27L4.77,6.04L5.64,7.39L4.22,9.6L5.95,10.5L7.23,8.5L10.73,12H4A2,2 0 0,0 2,14V22H4V20H18.73L20,21.27V22H22V20.73L22,20.72V20.72L3.28,2M7,17A1,1 0 0,1 6,18A1,1 0 0,1 5,17V15A1,1 0 0,1 6,14A1,1 0 0,1 7,15V17M11,17A1,1 0 0,1 10,18A1,1 0 0,1 9,17V15A1,1 0 0,1 10,14A1,1 0 0,1 11,15V17M15,17A1,1 0 0,1 14,18A1,1 0 0,1 13,17V15C13,14.79 13.08,14.61 13.18,14.45L15,16.27V17M16.25,9.5L17.67,7.3L16.25,5.1L18.25,2L20,2.89L18.56,5.1L20,7.3V7.31L18,10.4L16.25,9.5M22,14V18.18L19,15.18V15A1,1 0 0,0 18,14C17.95,14 17.9,14 17.85,14.03L15.82,12H20C21.11,12 22,12.9 22,14M11.64,7.3L10.22,5.1L12.22,2L13.95,2.89L12.53,5.1L13.95,7.3L13.94,7.31L12.84,9L11.44,7.62L11.64,7.3M7.5,3.69L6.1,2.28L6.22,2.09L7.95,3L7.5,3.69Z\";\r\nvar mdiRadio = \"M20,6A2,2 0 0,1 22,8V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V8C2,7.15 2.53,6.42 3.28,6.13L15.71,1L16.47,2.83L8.83,6H20M20,8H4V12H16V10H18V12H20V8M7,14A3,3 0 0,0 4,17A3,3 0 0,0 7,20A3,3 0 0,0 10,17A3,3 0 0,0 7,14Z\";\r\nvar mdiRadioAm = \"M5,7A2,2 0 0,0 3,9V17H5V13H7V17H9V9A2,2 0 0,0 7,7H5M5,9H7V11H5V9M13,7A2,2 0 0,0 11,9V17H13V9H15V16H17V9H19V17H21V9A2,2 0 0,0 19,7H13Z\";\r\nvar mdiRadioFm = \"M3,7V17H5V13H8V11H5V9H9V7H3M13,7A2,2 0 0,0 11,9V17H13V9H15V16H17V9H19V17H21V9A2,2 0 0,0 19,7H13Z\";\r\nvar mdiRadioHandheld = \"M9,2A1,1 0 0,0 8,3C8,8.67 8,14.33 8,20C8,21.11 8.89,22 10,22H15C16.11,22 17,21.11 17,20V9C17,7.89 16.11,7 15,7H10V3A1,1 0 0,0 9,2M10,9H15V13H10V9Z\";\r\nvar mdiRadioOff = \"M1 4.27L3 6.27C2.4 6.61 2 7.26 2 8V20C2 21.11 2.9 22 4 22H18.73L20.73 24L22 22.72L2.28 3L1 4.27M20 6H8.83L16.47 2.83L15.71 1L6.59 4.76L9.82 8H20V12H18V10H16V12H13.82L22 20.18V8C22 6.9 21.11 6 20 6M4 8H4.73L8.73 12H4V8M7 14C8.66 14 10 15.34 10 17C10 18.66 8.66 20 7 20C5.34 20 4 18.66 4 17C4 15.34 5.34 14 7 14Z\";\r\nvar mdiRadioTower = \"M12,10A2,2 0 0,1 14,12C14,12.5 13.82,12.94 13.53,13.29L16.7,22H14.57L12,14.93L9.43,22H7.3L10.47,13.29C10.18,12.94 10,12.5 10,12A2,2 0 0,1 12,10M12,8A4,4 0 0,0 8,12C8,12.5 8.1,13 8.28,13.46L7.4,15.86C6.53,14.81 6,13.47 6,12A6,6 0 0,1 12,6A6,6 0 0,1 18,12C18,13.47 17.47,14.81 16.6,15.86L15.72,13.46C15.9,13 16,12.5 16,12A4,4 0 0,0 12,8M12,4A8,8 0 0,0 4,12C4,14.36 5,16.5 6.64,17.94L5.92,19.94C3.54,18.11 2,15.23 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12C22,15.23 20.46,18.11 18.08,19.94L17.36,17.94C19,16.5 20,14.36 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiRadioactive = \"M12,10A2,2 0 0,1 14,12A2,2 0 0,1 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10M12,22C10.05,22 8.22,21.44 6.69,20.47L10,15.47C10.6,15.81 11.28,16 12,16C12.72,16 13.4,15.81 14,15.47L17.31,20.47C15.78,21.44 13.95,22 12,22M2,12C2,7.86 4.5,4.3 8.11,2.78L10.34,8.36C8.96,9 8,10.38 8,12H2M16,12C16,10.38 15.04,9 13.66,8.36L15.89,2.78C19.5,4.3 22,7.86 22,12H16Z\";\r\nvar mdiRadioactiveOff = \"M1,4.27L2.28,3L21,21.72L19.73,23L17.25,20.5C15.72,21.46 13.92,22 12,22C10.05,22 8.22,21.44 6.69,20.47L10,15.47C10.6,15.81 11.28,16 12,16C12.23,16 12.46,16 12.67,15.94L8.06,11.33C8,11.54 8,11.77 8,12H2C2,10.08 2.54,8.28 3.5,6.75L1,4.27M12,10A2,2 0 0,1 14,12V12.17L11.83,10H12M8.11,2.78L10.23,8.41L5.9,4.08C6.57,3.56 7.32,3.12 8.11,2.78M16,12C16,10.38 15.04,9 13.66,8.36L15.89,2.78C19.5,4.3 22,7.86 22,12H16Z\";\r\nvar mdiRadioboxBlank = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiRadioboxMarked = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12A5,5 0 0,0 12,7Z\";\r\nvar mdiRadiologyBox = \"M19 3H5C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3M17.1 13H13V14H17C17 14 16.94 17 15.5 17C14.15 17 14.5 15.47 13 15V17C13 17.55 12.55 18 12 18S11 17.55 11 17V15C9.5 15.47 9.85 17 8.5 17C7.06 17 7 14 7 14H11V13H6.9C6.85 12.69 6.84 12.35 6.8 12H11V11H6.81C6.83 10.67 6.91 10.33 7 10H11V9H7.34C7.5 8.65 7.65 8.31 7.83 8H11V7C11 6.45 11.45 6 12 6S13 6.45 13 7V8H16.17C16.35 8.31 16.5 8.65 16.66 9H13V10H17C17.1 10.33 17.17 10.67 17.19 11H13V12H17.2C17.16 12.35 17.15 12.69 17.1 13Z\";\r\nvar mdiRadiologyBoxOutline = \"M19 5V19H5V5H19M19 3H5C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3M12 6C12.55 6 13 6.45 13 7V8H16.17C16.35 8.31 16.5 8.65 16.66 9H13V10H17C17.1 10.33 17.17 10.67 17.19 11H13V12H17.2C17.16 12.35 17.15 12.69 17.1 13H13V14H17C17 14 16.94 17 15.5 17C14.15 17 14.5 15.47 13 15V17C13 17.55 12.55 18 12 18S11 17.55 11 17V15C9.5 15.47 9.85 17 8.5 17C7.06 17 7 14 7 14H11V13H6.9C6.85 12.69 6.84 12.35 6.8 12H11V11H6.81C6.83 10.67 6.91 10.33 7 10H11V9H7.34C7.5 8.65 7.65 8.31 7.83 8H11V7C11 6.45 11.45 6 12 6Z\";\r\nvar mdiRadius = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M17,15V13H13.72C13.36,13.62 12.71,14 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10C12.71,10 13.36,10.38 13.72,11H17V9L20,12L17,15Z\";\r\nvar mdiRadiusOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M16,15V13H13.72C13.36,13.62 12.71,14 12,14A2,2 0 0,1 10,12A2,2 0 0,1 12,10C12.71,10 13.36,10.38 13.72,11H16V9L19,12L16,15Z\";\r\nvar mdiRailroadLight = \"M17.67,10.5C16.4,10.5 15.27,11.3 14.85,12.5H13.17V7.77L16.66,9.86L17.66,8.14L14.11,6L17.68,3.86L16.68,2.14L13.17,4.23V2H11.17V4.23L7.68,2.14L6.68,3.86L10.23,6L6.66,8.14L7.66,9.86L11.17,7.77V12.5H9.5C8.36,9.32 3.66,10.13 3.66,13.5C3.66,16.87 8.36,17.68 9.5,14.5H11.17V20A2,2 0 0,0 9.17,22H15.17A2,2 0 0,0 13.17,20V14.5H14.85C15.66,16.8 18.73,17.22 20.13,15.23C21.53,13.24 20.1,10.5 17.67,10.5M6.67,14.5C5.78,14.5 5.33,13.42 5.96,12.79C6.59,12.16 7.67,12.61 7.67,13.5A1,1 0 0,1 6.67,14.5M17.67,14.5C16.78,14.5 16.33,13.42 16.96,12.79C17.59,12.16 18.67,12.61 18.67,13.5A1,1 0 0,1 17.67,14.5Z\";\r\nvar mdiRake = \"M10.5 17.05L9.43 16L22.07 3.35L20.66 1.93L8 14.58L6.95 13.5C6.17 12.73 4.9 12.73 4.12 13.5L2 15.64L2.71 16.34L4.83 14.22L5.54 14.93L3.41 17.05L4.12 17.76L6.24 15.64L6.95 16.34L4.83 18.46L5.54 19.17L7.66 17.05L8.36 17.76L6.24 19.88L6.95 20.59L9.07 18.46L9.78 19.17L7.66 21.29L8.36 22L10.5 19.88C11.27 19.1 11.27 17.83 10.5 17.05Z\";\r\nvar mdiRaspberryPi = \"M20,8H22V10H20V8M4,5H20A2,2 0 0,1 22,7H19V9H5V13H8V16H19V17H22A2,2 0 0,1 20,19H16V20H14V19H11V20H7V19H4A2,2 0 0,1 2,17V7A2,2 0 0,1 4,5M19,15H9V10H19V11H22V13H19V15M13,12V14H15V12H13M5,6V8H6V6H5M7,6V8H8V6H7M9,6V8H10V6H9M11,6V8H12V6H11M13,6V8H14V6H13M15,6V8H16V6H15M20,14H22V16H20V14Z\";\r\nvar mdiRayEnd = \"M20,9C18.69,9 17.58,9.83 17.17,11H2V13H17.17C17.58,14.17 18.69,15 20,15A3,3 0 0,0 23,12A3,3 0 0,0 20,9Z\";\r\nvar mdiRayEndArrow = \"M1,12L5,16V13H17.17C17.58,14.17 18.69,15 20,15A3,3 0 0,0 23,12A3,3 0 0,0 20,9C18.69,9 17.58,9.83 17.17,11H5V8L1,12Z\";\r\nvar mdiRayStart = \"M4,9C5.31,9 6.42,9.83 6.83,11H22V13H6.83C6.42,14.17 5.31,15 4,15A3,3 0 0,1 1,12A3,3 0 0,1 4,9Z\";\r\nvar mdiRayStartArrow = \"M23,12L19,16V13H6.83C6.42,14.17 5.31,15 4,15A3,3 0 0,1 1,12A3,3 0 0,1 4,9C5.31,9 6.42,9.83 6.83,11H19V8L23,12Z\";\r\nvar mdiRayStartEnd = \"M4,9C5.31,9 6.42,9.83 6.83,11H17.17C17.58,9.83 18.69,9 20,9A3,3 0 0,1 23,12A3,3 0 0,1 20,15C18.69,15 17.58,14.17 17.17,13H6.83C6.42,14.17 5.31,15 4,15A3,3 0 0,1 1,12A3,3 0 0,1 4,9Z\";\r\nvar mdiRayStartVertexEnd = \"M20 9C18.69 9 17.58 9.83 17.17 11H14.82C14.4 9.84 13.3 9 12 9S9.6 9.84 9.18 11H6.83C6.42 9.83 5.31 9 4 9C2.34 9 1 10.34 1 12S2.34 15 4 15C5.31 15 6.42 14.17 6.83 13H9.18C9.6 14.16 10.7 15 12 15S14.4 14.16 14.82 13H17.17C17.58 14.17 18.69 15 20 15C21.66 15 23 13.66 23 12S21.66 9 20 9\";\r\nvar mdiRayVertex = \"M2,11H9.17C9.58,9.83 10.69,9 12,9C13.31,9 14.42,9.83 14.83,11H22V13H14.83C14.42,14.17 13.31,15 12,15C10.69,15 9.58,14.17 9.17,13H2V11Z\";\r\nvar mdiReact = \"M12,10.11C13.03,10.11 13.87,10.95 13.87,12C13.87,13 13.03,13.85 12,13.85C10.97,13.85 10.13,13 10.13,12C10.13,10.95 10.97,10.11 12,10.11M7.37,20C8,20.38 9.38,19.8 10.97,18.3C10.45,17.71 9.94,17.07 9.46,16.4C8.64,16.32 7.83,16.2 7.06,16.04C6.55,18.18 6.74,19.65 7.37,20M8.08,14.26L7.79,13.75C7.68,14.04 7.57,14.33 7.5,14.61C7.77,14.67 8.07,14.72 8.38,14.77C8.28,14.6 8.18,14.43 8.08,14.26M14.62,13.5L15.43,12L14.62,10.5C14.32,9.97 14,9.5 13.71,9.03C13.17,9 12.6,9 12,9C11.4,9 10.83,9 10.29,9.03C10,9.5 9.68,9.97 9.38,10.5L8.57,12L9.38,13.5C9.68,14.03 10,14.5 10.29,14.97C10.83,15 11.4,15 12,15C12.6,15 13.17,15 13.71,14.97C14,14.5 14.32,14.03 14.62,13.5M12,6.78C11.81,7 11.61,7.23 11.41,7.5C11.61,7.5 11.8,7.5 12,7.5C12.2,7.5 12.39,7.5 12.59,7.5C12.39,7.23 12.19,7 12,6.78M12,17.22C12.19,17 12.39,16.77 12.59,16.5C12.39,16.5 12.2,16.5 12,16.5C11.8,16.5 11.61,16.5 11.41,16.5C11.61,16.77 11.81,17 12,17.22M16.62,4C16,3.62 14.62,4.2 13.03,5.7C13.55,6.29 14.06,6.93 14.54,7.6C15.36,7.68 16.17,7.8 16.94,7.96C17.45,5.82 17.26,4.35 16.62,4M15.92,9.74L16.21,10.25C16.32,9.96 16.43,9.67 16.5,9.39C16.23,9.33 15.93,9.28 15.62,9.23C15.72,9.4 15.82,9.57 15.92,9.74M17.37,2.69C18.84,3.53 19,5.74 18.38,8.32C20.92,9.07 22.75,10.31 22.75,12C22.75,13.69 20.92,14.93 18.38,15.68C19,18.26 18.84,20.47 17.37,21.31C15.91,22.15 13.92,21.19 12,19.36C10.08,21.19 8.09,22.15 6.62,21.31C5.16,20.47 5,18.26 5.62,15.68C3.08,14.93 1.25,13.69 1.25,12C1.25,10.31 3.08,9.07 5.62,8.32C5,5.74 5.16,3.53 6.62,2.69C8.09,1.85 10.08,2.81 12,4.64C13.92,2.81 15.91,1.85 17.37,2.69M17.08,12C17.42,12.75 17.72,13.5 17.97,14.26C20.07,13.63 21.25,12.73 21.25,12C21.25,11.27 20.07,10.37 17.97,9.74C17.72,10.5 17.42,11.25 17.08,12M6.92,12C6.58,11.25 6.28,10.5 6.03,9.74C3.93,10.37 2.75,11.27 2.75,12C2.75,12.73 3.93,13.63 6.03,14.26C6.28,13.5 6.58,12.75 6.92,12M15.92,14.26C15.82,14.43 15.72,14.6 15.62,14.77C15.93,14.72 16.23,14.67 16.5,14.61C16.43,14.33 16.32,14.04 16.21,13.75L15.92,14.26M13.03,18.3C14.62,19.8 16,20.38 16.62,20C17.26,19.65 17.45,18.18 16.94,16.04C16.17,16.2 15.36,16.32 14.54,16.4C14.06,17.07 13.55,17.71 13.03,18.3M8.08,9.74C8.18,9.57 8.28,9.4 8.38,9.23C8.07,9.28 7.77,9.33 7.5,9.39C7.57,9.67 7.68,9.96 7.79,10.25L8.08,9.74M10.97,5.7C9.38,4.2 8,3.62 7.37,4C6.74,4.35 6.55,5.82 7.06,7.96C7.83,7.8 8.64,7.68 9.46,7.6C9.94,6.93 10.45,6.29 10.97,5.7Z\";\r\nvar mdiRead = \"M21.59,11.59L23,13L13.5,22.5L8.42,17.41L9.83,16L13.5,19.68L21.59,11.59M4,16V3H6L9,3A4,4 0 0,1 13,7C13,8.54 12.13,9.88 10.85,10.55L14,16H12L9.11,11H6V16H4M6,9H9A2,2 0 0,0 11,7A2,2 0 0,0 9,5H6V9Z\";\r\nvar mdiReceipt = \"M3,22L4.5,20.5L6,22L7.5,20.5L9,22L10.5,20.5L12,22L13.5,20.5L15,22L16.5,20.5L18,22L19.5,20.5L21,22V2L19.5,3.5L18,2L16.5,3.5L15,2L13.5,3.5L12,2L10.5,3.5L9,2L7.5,3.5L6,2L4.5,3.5L3,2M18,9H6V7H18M18,13H6V11H18M18,17H6V15H18V17Z\";\r\nvar mdiRecord = \"M19,12C19,15.86 15.86,19 12,19C8.14,19 5,15.86 5,12C5,8.14 8.14,5 12,5C15.86,5 19,8.14 19,12Z\";\r\nvar mdiRecordCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9Z\";\r\nvar mdiRecordCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiRecordPlayer = \"M5,17.5A0.5,0.5 0 0,1 4.5,18H3.5A0.5,0.5 0 0,1 3,17.5V17H2A1,1 0 0,1 1,16V13A1,1 0 0,1 2,12H19V10H7L6,11V9A1,1 0 0,1 7,8H19V7H21V8A1,1 0 0,1 22,9V10H21V12H22A1,1 0 0,1 23,13V16A1,1 0 0,1 22,17H21V17.5A0.5,0.5 0 0,1 20.5,18H19.5A0.5,0.5 0 0,1 19,17.5V17H5V17.5M3,14V15H5V14H3M6,14V15H8V14H6M20.5,13.5A1,1 0 0,0 19.5,14.5A1,1 0 0,0 20.5,15.5A1,1 0 0,0 21.5,14.5A1,1 0 0,0 20.5,13.5Z\";\r\nvar mdiRecordRec = \"M12.5,5A7.5,7.5 0 0,0 5,12.5A7.5,7.5 0 0,0 12.5,20A7.5,7.5 0 0,0 20,12.5A7.5,7.5 0 0,0 12.5,5M7,10H9A1,1 0 0,1 10,11V12C10,12.5 9.62,12.9 9.14,12.97L10.31,15H9.15L8,13V15H7M12,10H14V11H12V12H14V13H12V14H14V15H12A1,1 0 0,1 11,14V11A1,1 0 0,1 12,10M16,10H18V11H16V14H18V15H16A1,1 0 0,1 15,14V11A1,1 0 0,1 16,10M8,11V12H9V11\";\r\nvar mdiRectangle = \"M4,6V19H20V6H4Z\";\r\nvar mdiRectangleOutline = \"M4,6V19H20V6H4M18,17H6V8H18V17Z\";\r\nvar mdiRecycle = \"M21.82,15.42L19.32,19.75C18.83,20.61 17.92,21.06 17,21H15V23L12.5,18.5L15,14V16H17.82L15.6,12.15L19.93,9.65L21.73,12.77C22.25,13.54 22.32,14.57 21.82,15.42M9.21,3.06H14.21C15.19,3.06 16.04,3.63 16.45,4.45L17.45,6.19L19.18,5.19L16.54,9.6L11.39,9.69L13.12,8.69L11.71,6.24L9.5,10.09L5.16,7.59L6.96,4.47C7.37,3.64 8.22,3.06 9.21,3.06M5.05,19.76L2.55,15.43C2.06,14.58 2.13,13.56 2.64,12.79L3.64,11.06L1.91,10.06L7.05,10.14L9.7,14.56L7.97,13.56L6.56,16H11V21H7.4C6.47,21.07 5.55,20.61 5.05,19.76Z\";\r\nvar mdiRecycleVariant = \"M7.17 7.91L8.9 8.91L12.08 3.42L14.33 7.31L11.73 8.81L17.19 10.27L18.66 4.81L16.06 6.31L13.81 2.41C13.26 1.45 12.03 1.12 11.08 1.68C10.81 1.83 10.58 2.05 10.41 2.31M10 20V18L3.66 18L5.9 14.1L8.5 15.6L7.04 10.14L1.57 11.6L4.17 13.1L1.92 17C1.37 17.96 1.7 19.18 2.65 19.73C2.92 19.89 3.22 19.97 3.54 20M19.06 11.5L17.32 12.5L20.5 18H16V15L12 19L16 23V20H20.5C21.61 20 22.5 19.11 22.5 18C22.5 17.69 22.42 17.38 22.28 17.11Z\";\r\nvar mdiReddit = \"M14.5 15.41C14.58 15.5 14.58 15.69 14.5 15.8C13.77 16.5 12.41 16.56 12 16.56C11.61 16.56 10.25 16.5 9.54 15.8C9.44 15.69 9.44 15.5 9.54 15.41C9.65 15.31 9.82 15.31 9.92 15.41C10.38 15.87 11.33 16 12 16C12.69 16 13.66 15.87 14.1 15.41C14.21 15.31 14.38 15.31 14.5 15.41M10.75 13.04C10.75 12.47 10.28 12 9.71 12C9.14 12 8.67 12.47 8.67 13.04C8.67 13.61 9.14 14.09 9.71 14.08C10.28 14.08 10.75 13.61 10.75 13.04M14.29 12C13.72 12 13.25 12.5 13.25 13.05S13.72 14.09 14.29 14.09C14.86 14.09 15.33 13.61 15.33 13.05C15.33 12.5 14.86 12 14.29 12M22 12C22 17.5 17.5 22 12 22S2 17.5 2 12C2 6.5 6.5 2 12 2S22 6.5 22 12M18.67 12C18.67 11.19 18 10.54 17.22 10.54C16.82 10.54 16.46 10.7 16.2 10.95C15.2 10.23 13.83 9.77 12.3 9.71L12.97 6.58L15.14 7.05C15.16 7.6 15.62 8.04 16.18 8.04C16.75 8.04 17.22 7.57 17.22 7C17.22 6.43 16.75 5.96 16.18 5.96C15.77 5.96 15.41 6.2 15.25 6.55L12.82 6.03C12.75 6 12.68 6.03 12.63 6.07C12.57 6.11 12.54 6.17 12.53 6.24L11.79 9.72C10.24 9.77 8.84 10.23 7.82 10.96C7.56 10.71 7.2 10.56 6.81 10.56C6 10.56 5.35 11.21 5.35 12C5.35 12.61 5.71 13.11 6.21 13.34C6.19 13.5 6.18 13.62 6.18 13.78C6.18 16 8.79 17.85 12 17.85C15.23 17.85 17.85 16.03 17.85 13.78C17.85 13.64 17.84 13.5 17.81 13.34C18.31 13.11 18.67 12.6 18.67 12Z\";\r\nvar mdiRedhat = \"M15.34 13.16C16.66 13.16 18.56 12.89 18.56 11.32C18.57 11.2 18.56 11.08 18.53 10.96L17.75 7.56C17.57 6.81 17.41 6.47 16.09 5.81C15.07 5.29 12.85 4.43 12.19 4.43C11.58 4.43 11.4 5.22 10.67 5.22C9.97 5.22 9.45 4.63 8.79 4.63C8.16 4.63 7.75 5.06 7.43 5.94C7.43 5.94 6.55 8.44 6.43 8.8C6.42 8.87 6.41 8.93 6.41 9C6.41 9.97 10.23 13.15 15.34 13.15M18.77 11.96C18.95 12.82 18.95 12.91 18.95 13C18.95 14.5 17.29 15.31 15.12 15.31C10.2 15.31 5.89 12.43 5.89 10.53C5.89 10.26 5.95 10 6.05 9.76C4.28 9.84 2 10.16 2 12.18C2 15.5 9.84 19.57 16.05 19.57C20.81 19.57 22 17.42 22 15.72C22 14.38 20.85 12.86 18.77 11.96\";\r\nvar mdiRedo = \"M18.4,10.6C16.55,9 14.15,8 11.5,8C6.85,8 2.92,11.03 1.54,15.22L3.9,16C4.95,12.81 7.95,10.5 11.5,10.5C13.45,10.5 15.23,11.22 16.62,12.38L13,16H22V7L18.4,10.6Z\";\r\nvar mdiRedoVariant = \"M10.5,7A6.5,6.5 0 0,0 4,13.5A6.5,6.5 0 0,0 10.5,20H14V18H10.5C8,18 6,16 6,13.5C6,11 8,9 10.5,9H16.17L13.09,12.09L14.5,13.5L20,8L14.5,2.5L13.08,3.91L16.17,7H10.5M18,18H16V20H18V18Z\";\r\nvar mdiReflectHorizontal = \"M22,20H14A1,1 0 0,1 13,19V4.97C13,4.5 13.31,4.12 13.74,4C14.19,3.88 14.65,4.08 14.87,4.47L22.89,18.5C23.07,18.81 23.07,19.19 22.89,19.5C22.71,19.81 22.38,20 22,20M2,20C1.62,20 1.29,19.81 1.11,19.5C0.93,19.19 0.93,18.81 1.11,18.5L9.13,4.47C9.35,4.08 9.81,3.88 10.26,4C10.69,4.12 11,4.5 11,4.97V19A1,1 0 0,1 10,20H2M9,18V8.74L3.71,18H9Z\";\r\nvar mdiReflectVertical = \"M18,23H6C5.61,23 5.26,22.79 5.09,22.45C4.92,22.11 4.96,21.7 5.19,21.4L11.2,13.38C11.58,12.87 12.42,12.87 12.8,13.38L18.81,21.4C19.04,21.7 19.08,22.11 18.91,22.45C18.74,22.79 18.39,23 18,23M18,1C18.39,1 18.74,1.21 18.91,1.55C19.08,1.89 19.04,2.3 18.81,2.6L12.8,10.62C12.42,11.13 11.58,11.13 11.2,10.62L5.19,2.6C4.96,2.3 4.92,1.89 5.09,1.55C5.26,1.21 5.61,1 6,1H18M8,3L12,8.35L16,3H8Z\";\r\nvar mdiRefresh = \"M17.65,6.35C16.2,4.9 14.21,4 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20C15.73,20 18.84,17.45 19.73,14H17.65C16.83,16.33 14.61,18 12,18A6,6 0 0,1 6,12A6,6 0 0,1 12,6C13.66,6 15.14,6.69 16.22,7.78L13,11H20V4L17.65,6.35Z\";\r\nvar mdiRefreshCircle = \"M12 2A10 10 0 1 0 22 12A10 10 0 0 0 12 2M18 11H13L14.81 9.19A3.94 3.94 0 0 0 12 8A4 4 0 1 0 15.86 13H17.91A6 6 0 1 1 12 6A5.91 5.91 0 0 1 16.22 7.78L18 6Z\";\r\nvar mdiRegex = \"M16,16.92C15.67,16.97 15.34,17 15,17C14.66,17 14.33,16.97 14,16.92V13.41L11.5,15.89C11,15.5 10.5,15 10.11,14.5L12.59,12H9.08C9.03,11.67 9,11.34 9,11C9,10.66 9.03,10.33 9.08,10H12.59L10.11,7.5C10.3,7.25 10.5,7 10.76,6.76V6.76C11,6.5 11.25,6.3 11.5,6.11L14,8.59V5.08C14.33,5.03 14.66,5 15,5C15.34,5 15.67,5.03 16,5.08V8.59L18.5,6.11C19,6.5 19.5,7 19.89,7.5L17.41,10H20.92C20.97,10.33 21,10.66 21,11C21,11.34 20.97,11.67 20.92,12H17.41L19.89,14.5C19.7,14.75 19.5,15 19.24,15.24V15.24C19,15.5 18.75,15.7 18.5,15.89L16,13.41V16.92H16V16.92M5,19A2,2 0 0,1 7,17A2,2 0 0,1 9,19A2,2 0 0,1 7,21A2,2 0 0,1 5,19H5Z\";\r\nvar mdiRegisteredTrademark = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20M12.25,13.27H10.81V16.5H9V7.71H12.26C13.29,7.71 14.09,7.94 14.66,8.4C15.22,8.87 15.5,9.5 15.5,10.36C15.5,10.96 15.37,11.46 15.11,11.86C14.85,12.26 14.46,12.58 13.93,12.81L15.83,16.4V16.5H13.89L12.25,13.27M10.81,11.81H12.27C12.72,11.81 13.07,11.69 13.32,11.46C13.57,11.23 13.69,10.91 13.69,10.5C13.69,10.09 13.58,9.77 13.34,9.53C13.11,9.29 12.75,9.18 12.26,9.18H10.81V11.81Z\";\r\nvar mdiReiterate = \"M10.5 4A6.5 6.5 0 0 0 4 10H1L5 14L9 10H6.03A4.5 4.5 0 0 1 10.5 6A4.5 4.5 0 0 1 15 10.5A4.5 4.5 0 0 1 10.5 15H2V17H10.5A6.5 6.5 0 0 0 17 10.5A6.5 6.5 0 0 0 10.5 4M19 12V15H16.5A7.5 7.5 0 0 1 14.24 17H19V20L23 16Z\";\r\nvar mdiRelationManyToMany = \"M22 13V19H21L19 17H11V9H5L3 11H2V5H3L5 7H13V15H19L21 13Z\";\r\nvar mdiRelationManyToOne = \"M22 15V17H19V19H17V17H11V9H5L3 11H2V5H3L5 7H13V15H17V13H19V15Z\";\r\nvar mdiRelationManyToOneOrMany = \"M22 13V19H21L19 17V19H17V17H11V9H5L3 11H2V5H3L5 7H13V15H17V13H19V15L21 13Z\";\r\nvar mdiRelationManyToOnlyOne = \"M22 15V17H21V19H19V17H18V19H16V17H11V9H5L3 11H2V5H3L5 7H13V15H16V13H18V15H19V13H21V15Z\";\r\nvar mdiRelationManyToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H5L3 5H2V11H3L5 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationManyToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H5L3 5H2V11H3L5 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOneOrManyToMany = \"M22 13V19H21L19 17H11V9H7V11H5V9L3 11H2V5H3L5 7V5H7V7H13V15H19L21 13Z\";\r\nvar mdiRelationOneOrManyToOne = \"M22 15V17H19V19H17V17H11V9H7V11H5V9L3 11H2V5H3L5 7V5H7V7H13V15H17V13H19V15Z\";\r\nvar mdiRelationOneOrManyToOneOrMany = \"M22 13V19H21L19 17V19H17V17H11V9H7V11H5V9L3 11H2V5H3L5 7V5H7V7H13V15H17V13H19V15L21 13Z\";\r\nvar mdiRelationOneOrManyToOnlyOne = \"M22 15V17H21V19H19V17H18V19H16V17H11V9H7V11H5V9L3 11H2V5H3L5 7V5H7V7H13V15H16V13H18V15H19V13H21V15Z\";\r\nvar mdiRelationOneOrManyToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H7V5H5V7L3 5H2V11H3L5 9V11H7V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOneOrManyToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H7V5H5V7L3 5H2V11H3L5 9V11H7V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOneToMany = \"M22 13V19H21L19 17H11V9H7V11H5V9H2V7H5V5H7V7H13V15H19L21 13Z\";\r\nvar mdiRelationOneToOne = \"M22 15V17H19V19H17V17H11V9H7V11H5V9H2V7H5V5H7V7H13V15H17V13H19V15Z\";\r\nvar mdiRelationOneToOneOrMany = \"M22 13V19H21L19 17V19H17V17H11V9H7V11H5V9H2V7H5V5H7V7H13V15H17V13H19V15L21 13Z\";\r\nvar mdiRelationOneToOnlyOne = \"M22 15V17H21V19H19V17H18V19H16V17H11V9H7V11H5V9H2V7H5V5H7V7H13V15H16V13H18V15H19V13H21V15Z\";\r\nvar mdiRelationOneToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H7V5H5V7H2V9H5V11H7V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOneToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H7V5H5V7H2V9H5V11H7V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOnlyOneToMany = \"M22 13V19H21L19 17H11V9H8V11H6V9H5V11H3V9H2V7H3V5H5V7H6V5H8V7H13V15H19L21 13Z\";\r\nvar mdiRelationOnlyOneToOne = \"M22 15V17H19V19H17V17H11V9H8V11H6V9H5V11H3V9H2V7H3V5H5V7H6V5H8V7H13V15H17V13H19V15Z\";\r\nvar mdiRelationOnlyOneToOneOrMany = \"M22 13V19H21L19 17V19H17V17H11V9H8V11H6V9H5V11H3V9H2V7H3V5H5V7H6V5H8V7H13V15H17V13H19V15L21 13Z\";\r\nvar mdiRelationOnlyOneToOnlyOne = \"M22 15V17H21V19H19V17H18V19H16V17H11V9H8V11H6V9H5V11H3V9H2V7H3V5H5V7H6V5H8V7H13V15H16V13H18V15H19V13H21V15Z\";\r\nvar mdiRelationOnlyOneToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H8V5H6V7H5V5H3V7H2V9H3V11H5V9H6V11H8V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationOnlyOneToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H8V5H6V7H5V5H3V7H2V9H3V11H5V9H6V11H8V9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationZeroOrManyToMany = \"M21 13L19 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H19L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrManyToOne = \"M19 15V13H17V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H17V19H19V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrManyToOneOrMany = \"M21 13L19 15V13H17V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H17V19H19V17L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrManyToOnlyOne = \"M21 15V13H19V15H18V13H16V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H16V19H18V17H19V19H21V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrManyToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationZeroOrManyToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5L3 5H2V11H3L5 9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationZeroOrOneToMany = \"M21 13L19 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H19L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrOneToOne = \"M19 15V13H17V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H17V19H19V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrOneToOneOrMany = \"M21 13L19 15V13H17V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H17V19H19V17L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrOneToOnlyOne = \"M21 15V13H19V15H18V13H16V15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H16V19H18V17H19V19H21V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9Z\";\r\nvar mdiRelationZeroOrOneToZeroOrMany = \"M21 13L19 15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19L21 19H22V13M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelationZeroOrOneToZeroOrOne = \"M21 15V13H19V15H18.79A2.5 2.5 0 0 0 14.21 15H13V7H9.79A2.5 2.5 0 0 0 5.21 7H5V5H3V7H2V9H3V11H5V9H5.21A2.5 2.5 0 0 0 9.79 9H11V17H14.21A2.5 2.5 0 0 0 18.79 17H19V19H21V17H22V15M7.5 9A1 1 0 1 1 8.5 8A1 1 0 0 1 7.5 9M16.5 17A1 1 0 1 1 17.5 16A1 1 0 0 1 16.5 17Z\";\r\nvar mdiRelativeScale = \"M20,18H4V6H20M20,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4M12,10H10V12H12M8,10H6V12H8M16,14H14V16H16M16,10H14V12H16V10Z\";\r\nvar mdiReload = \"M2 12C2 16.97 6.03 21 11 21C13.39 21 15.68 20.06 17.4 18.4L15.9 16.9C14.63 18.25 12.86 19 11 19C4.76 19 1.64 11.46 6.05 7.05C10.46 2.64 18 5.77 18 12H15L19 16H19.1L23 12H20C20 7.03 15.97 3 11 3C6.03 3 2 7.03 2 12Z\";\r\nvar mdiReloadAlert = \"M2 12C2 17 6 21 11 21C13.4 21 15.7 20.1 17.4 18.4L15.9 16.9C14.6 18.3 12.9 19 11 19C4.8 19 1.6 11.5 6.1 7.1S18 5.8 18 12H15L19 16H19.1L23 12H20C20 7 16 3 11 3S2 7 2 12M10 15H12V17H10V15M10 7H12V13H10V7\";\r\nvar mdiReminder = \"M7.25,3C7.9,3 8.5,3.21 9,3.56V3A2,2 0 0,1 11,1A2,2 0 0,1 13,3V3.57C13.5,3.22 14.1,3 14.75,3A3,3 0 0,1 17.75,6C17.75,7.58 16.54,8.87 15,9H13V10H14.24L14.72,10.13L19.31,12.42C20.13,12.73 20.53,13.34 20.53,14.25L20.5,14.39V14.53L19.5,21.28C19.44,21.75 19.22,22.16 18.84,22.5C18.47,22.84 18.05,23 17.58,23H10C9.45,23 9,22.81 8.58,22.41L2,15.84L3.05,14.77C3.33,14.5 3.69,14.34 4.13,14.34H4.45L9,15.33V10L9,9H7V9C5.46,8.86 4.25,7.57 4.25,6A3,3 0 0,1 7.25,3M9,6A1.75,1.75 0 0,0 7.25,4.25A1.75,1.75 0 0,0 5.5,6C5.5,6.88 6.15,7.61 7,7.73V7.75H9V6M15,7.75V7.74C15.85,7.62 16.5,6.89 16.5,6C16.5,5.04 15.72,4.26 14.75,4.26C13.78,4.26 13,5.04 13,6V7.75H15Z\";\r\nvar mdiRemote = \"M12,0C8.96,0 6.21,1.23 4.22,3.22L5.63,4.63C7.26,3 9.5,2 12,2C14.5,2 16.74,3 18.36,4.64L19.77,3.23C17.79,1.23 15.04,0 12,0M7.05,6.05L8.46,7.46C9.37,6.56 10.62,6 12,6C13.38,6 14.63,6.56 15.54,7.46L16.95,6.05C15.68,4.78 13.93,4 12,4C10.07,4 8.32,4.78 7.05,6.05M12,15A2,2 0 0,1 10,13A2,2 0 0,1 12,11A2,2 0 0,1 14,13A2,2 0 0,1 12,15M15,9H9A1,1 0 0,0 8,10V22A1,1 0 0,0 9,23H15A1,1 0 0,0 16,22V10A1,1 0 0,0 15,9Z\";\r\nvar mdiRemoteDesktop = \"M3,2A2,2 0 0,0 1,4V16C1,17.11 1.9,18 3,18H10V20H8V22H16V20H14V18H21A2,2 0 0,0 23,16V4A2,2 0 0,0 21,2M3,4H21V16H3M15,5L11.5,8.5L15,12L16.4,10.6L14.3,8.5L16.4,6.4M9,8L7.6,9.4L9.7,11.5L7.6,13.6L9,15L12.5,11.5\";\r\nvar mdiRemoteOff = \"M2,5.27L3.28,4L21,21.72L19.73,23L16,19.27V22A1,1 0 0,1 15,23H9C8.46,23 8,22.55 8,22V11.27L2,5.27M12,0C15.05,0 17.8,1.23 19.77,3.23L18.36,4.64C16.75,3 14.5,2 12,2C9.72,2 7.64,2.85 6.06,4.24L4.64,2.82C6.59,1.07 9.17,0 12,0M12,4C13.94,4 15.69,4.78 16.95,6.05L15.55,7.46C14.64,6.56 13.39,6 12,6C10.83,6 9.76,6.4 8.9,7.08L7.5,5.66C8.7,4.62 10.28,4 12,4M15,9C15.56,9 16,9.45 16,10V14.18L13.5,11.69L13.31,11.5L10.82,9H15M10.03,13.3C10.16,14.16 10.84,14.85 11.71,15L10.03,13.3Z\";\r\nvar mdiRemoteTv = \"M9,2C7.89,2 7,2.89 7,4V20C7,21.11 7.89,22 9,22H15C16.11,22 17,21.11 17,20V4C17,2.89 16.11,2 15,2H13V4H11V2H9M11,6H13V8H15V10H13V12H11V10H9V8H11V6M9,14H11V16H9V14M13,14H15V16H13V14M9,18H11V20H9V18M13,18H15V20H13V18Z\";\r\nvar mdiRemoteTvOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L17,20.25C16.86,21.24 16,22 15,22H9A2,2 0 0,1 7,20V10.27L2,5.27M9,2H11V4H13V2H15A2,2 0 0,1 17,4V15.18L13,11.18V10H15V8H13V6H11V8H9.82L7,5.18V4A2,2 0 0,1 9,2M9,20H11V18H9V20M13,20H15V18.27L14.73,18H13V20M9,14V16H11V14.27L10.73,14H9Z\";\r\nvar mdiRenameBox = \"M18,17H10.5L12.5,15H18M6,17V14.5L13.88,6.65C14.07,6.45 14.39,6.45 14.59,6.65L16.35,8.41C16.55,8.61 16.55,8.92 16.35,9.12L8.47,17M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiReorderHorizontal = \"M3,15H21V13H3V15M3,19H21V17H3V19M3,11H21V9H3V11M3,5V7H21V5H3Z\";\r\nvar mdiReorderVertical = \"M9,3V21H11V3H9M5,3V21H7V3H5M13,3V21H15V3H13M19,3H17V21H19V3Z\";\r\nvar mdiRepeat = \"M17,17H7V14L3,18L7,22V19H19V13H17M7,7H17V10L21,6L17,2V5H5V11H7V7Z\";\r\nvar mdiRepeatOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L15.73,19H7V22L3,18L7,14V17H13.73L7,10.27V11H5V8.27L2,5.27M17,13H19V17.18L17,15.18V13M17,5V2L21,6L17,10V7H8.82L6.82,5H17Z\";\r\nvar mdiRepeatOnce = \"M13,15V9H12L10,10V11H11.5V15M17,17H7V14L3,18L7,22V19H19V13H17M7,7H17V10L21,6L17,2V5H5V11H7V7Z\";\r\nvar mdiReplay = \"M12,5V1L7,6L12,11V7A6,6 0 0,1 18,13A6,6 0 0,1 12,19A6,6 0 0,1 6,13H4A8,8 0 0,0 12,21A8,8 0 0,0 20,13A8,8 0 0,0 12,5Z\";\r\nvar mdiReply = \"M10,9V5L3,12L10,19V14.9C15,14.9 18.5,16.5 21,20C20,15 17,10 10,9Z\";\r\nvar mdiReplyAll = \"M13,9V5L6,12L13,19V14.9C18,14.9 21.5,16.5 24,20C23,15 20,10 13,9M7,8V5L0,12L7,19V16L3,12L7,8Z\";\r\nvar mdiReplyAllOutline = \"M11,9.8V10.7L12.7,10.9C15.3,11.3 17.2,12.3 18.6,13.6C16.9,13.1 15.1,12.8 13,12.8H11V14.1L8.8,12L11,9.8M13,5L6,12L13,19V14.9C18,14.9 21.5,16.5 24,20C23,15 20,10 13,9M7,8V5L0,12L7,19V16L3,12\";\r\nvar mdiReplyCircle = \"M2 12C2 17.5 6.5 22 12 22S22 17.5 22 12 17.5 2 12 2 2 6.5 2 12M5 11L10 6V9C15.06 9.73 17.28 13.33 18 17C16.19 14.43 13.61 13 10 13V16L5 11Z\";\r\nvar mdiReplyOutline = \"M8,9.8V10.7L9.7,11C12.3,11.4 14.2,12.4 15.6,13.7C13.9,13.2 12.1,12.9 10,12.9H8V14.2L5.8,12L8,9.8M10,5L3,12L10,19V14.9C15,14.9 18.5,16.5 21,20C20,15 17,10 10,9\";\r\nvar mdiReproduction = \"M12.72,13.15L13.62,12.26C13.6,11 14.31,9.44 15.62,8.14C17.57,6.18 20.11,5.55 21.28,6.72C22.45,7.89 21.82,10.43 19.86,12.38C18.56,13.69 17,14.4 15.74,14.38L14.85,15.28C14.5,15.61 14,15.66 13.6,15.41C12.76,15.71 12,16.08 11.56,16.8C11.03,17.68 11.03,19.1 10.47,19.95C9.91,20.81 8.79,21.1 7.61,21.1C6.43,21.1 5,21 3.95,19.5L6.43,19.92C7,20 8.5,19.39 9.05,18.54C9.61,17.68 9.61,16.27 10.14,15.38C10.61,14.6 11.5,14.23 12.43,13.91C12.42,13.64 12.5,13.36 12.72,13.15M7,2A5,5 0 0,1 12,7A5,5 0 0,1 7,12A5,5 0 0,1 2,7A5,5 0 0,1 7,2M7,4A3,3 0 0,0 4,7A3,3 0 0,0 7,10A3,3 0 0,0 10,7A3,3 0 0,0 7,4Z\";\r\nvar mdiResistor = \"M2,11H7L10.07,15.35L13.11,4L18,11H22V13H17L13.93,8.65L10.89,20L6,13H2V11Z\";\r\nvar mdiResistorNodes = \"M2,11H3.67C4.08,9.83 5.19,9 6.5,9A3,3 0 0,1 9.5,12C9.5,12.65 9.29,13.25 8.94,13.74L10.07,15.35L13.11,4L14.61,6.13L16.7,9.11L17.5,9C18.81,9 19.92,9.83 20.33,11H22V13H20.33C19.92,14.17 18.81,15 17.5,15A3,3 0 0,1 14.5,12C14.5,11.35 14.71,10.75 15.06,10.26L13.93,8.65L10.89,20L7.3,14.89C7.05,14.96 6.78,15 6.5,15C5.19,15 4.08,14.17 3.67,13H2V11M17.5,10.5A1.5,1.5 0 0,0 16,12A1.5,1.5 0 0,0 17.5,13.5A1.5,1.5 0 0,0 19,12A1.5,1.5 0 0,0 17.5,10.5M6.5,10.5A1.5,1.5 0 0,0 5,12A1.5,1.5 0 0,0 6.5,13.5A1.5,1.5 0 0,0 8,12A1.5,1.5 0 0,0 6.5,10.5Z\";\r\nvar mdiResize = \"M10.59,12L14.59,8H11V6H18V13H16V9.41L12,13.41V16H20V4H8V12H10.59M22,2V18H12V22H2V12H6V2H22M10,14H4V20H10V14Z\";\r\nvar mdiResizeBottomRight = \"M22,22H20V20H22V22M22,18H20V16H22V18M18,22H16V20H18V22M18,18H16V16H18V18M14,22H12V20H14V22M22,14H20V12H22V14Z\";\r\nvar mdiResponsive = \"M4,6V16H9V12A2,2 0 0,1 11,10H16A2,2 0 0,1 18,12V16H20V6H4M0,20V18H4A2,2 0 0,1 2,16V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V16A2,2 0 0,1 20,18H24V20H18V20C18,21.11 17.1,22 16,22H11A2,2 0 0,1 9,20H9L0,20M11.5,20A0.5,0.5 0 0,0 11,20.5A0.5,0.5 0 0,0 11.5,21A0.5,0.5 0 0,0 12,20.5A0.5,0.5 0 0,0 11.5,20M15.5,20A0.5,0.5 0 0,0 15,20.5A0.5,0.5 0 0,0 15.5,21A0.5,0.5 0 0,0 16,20.5A0.5,0.5 0 0,0 15.5,20M13,20V21H14V20H13M11,12V19H16V12H11Z\";\r\nvar mdiRestart = \"M12,4C14.1,4 16.1,4.8 17.6,6.3C20.7,9.4 20.7,14.5 17.6,17.6C15.8,19.5 13.3,20.2 10.9,19.9L11.4,17.9C13.1,18.1 14.9,17.5 16.2,16.2C18.5,13.9 18.5,10.1 16.2,7.7C15.1,6.6 13.5,6 12,6V10.6L7,5.6L12,0.6V4M6.3,17.6C3.7,15 3.3,11 5.1,7.9L6.6,9.4C5.5,11.6 5.9,14.4 7.8,16.2C8.3,16.7 8.9,17.1 9.6,17.4L9,19.4C8,19 7.1,18.4 6.3,17.6Z\";\r\nvar mdiRestartAlert = \"M10 4.03V.633L5 5.63L10 10.63V6.03C11.5 6.03 13.11 6.63 14.21 7.73C16.5 10.13 16.5 13.93 14.21 16.23C12.91 17.53 11.11 18.13 9.4 17.93L8.9 19.93C11.31 20.23 13.81 19.53 15.61 17.63C18.7 14.53 18.7 9.43 15.61 6.33C14.11 4.83 12.11 4.03 10 4.03M4.31 17.63C5.11 18.43 6 19.03 7 19.43L7.61 17.43C6.91 17.13 6.31 16.73 5.81 16.23C3.91 14.43 3.5 11.63 4.61 9.43L3.11 7.93C1.31 11.03 1.71 15.03 4.31 17.63M20 13H22V7H20V13M20 17H22V15H20V17Z\";\r\nvar mdiRestartOff = \"M20.8,22.7L16.6,18.5C14.9,19.7 12.9,20.2 10.9,19.9L11.4,17.9C12.7,18 14,17.7 15.1,17L1.1,3L2.4,1.7L16.5,15.8L17.9,17.2L22.1,21.4L20.8,22.7M12,6C13.5,6 15.1,6.6 16.2,7.8C18,9.6 18.4,12.2 17.5,14.4L19,15.9C20.7,12.9 20.2,9 17.6,6.4C16.1,4.8 14,4 12,4V0.7L7.9,4.7L12,8.8V6M6.6,9.4L5.1,7.9C3.3,11 3.7,15 6.3,17.7C7.1,18.4 8,19 9,19.4L9.5,17.4C8.9,17.1 8.3,16.7 7.7,16.2C5.9,14.4 5.5,11.6 6.6,9.4Z\";\r\nvar mdiRestore = \"M13,3A9,9 0 0,0 4,12H1L4.89,15.89L4.96,16.03L9,12H6A7,7 0 0,1 13,5A7,7 0 0,1 20,12A7,7 0 0,1 13,19C11.07,19 9.32,18.21 8.06,16.94L6.64,18.36C8.27,20 10.5,21 13,21A9,9 0 0,0 22,12A9,9 0 0,0 13,3Z\";\r\nvar mdiRestoreAlert = \"M13 3C8 3 4 7 4 12H1L4.9 15.9L5 16L9 12H6C6 8.1 9.1 5 13 5S20 8.1 20 12 16.9 19 13 19C11.1 19 9.3 18.2 8.1 16.9L6.7 18.3C8.3 20 10.5 21 13 21C18 21 22 17 22 12S18 3 13 3M12 15H14V17H12V15M12 7H14V13H12V7\";\r\nvar mdiRewind = \"M11.5,12L20,18V6M11,18V6L2.5,12L11,18Z\";\r\nvar mdiRewind10 = \"M12.5,3C17.15,3 21.08,6.03 22.47,10.22L20.1,11C19.05,7.81 16.04,5.5 12.5,5.5C10.54,5.5 8.77,6.22 7.38,7.38L10,10H3V3L5.6,5.6C7.45,4 9.85,3 12.5,3M10,12V22H8V14H6V12H10M18,14V20C18,21.11 17.11,22 16,22H14A2,2 0 0,1 12,20V14A2,2 0 0,1 14,12H16C17.11,12 18,12.9 18,14M14,14V20H16V14H14Z\";\r\nvar mdiRewind30 = \"M19,14V20C19,21.11 18.11,22 17,22H15A2,2 0 0,1 13,20V14A2,2 0 0,1 15,12H17C18.11,12 19,12.9 19,14M15,14V20H17V14H15M11,20C11,21.11 10.1,22 9,22H5V20H9V18H7V16H9V14H5V12H9A2,2 0 0,1 11,14V15.5A1.5,1.5 0 0,1 9.5,17A1.5,1.5 0 0,1 11,18.5V20M12.5,3C17.15,3 21.08,6.03 22.47,10.22L20.1,11C19.05,7.81 16.04,5.5 12.5,5.5C10.54,5.5 8.77,6.22 7.38,7.38L10,10H3V3L5.6,5.6C7.45,4 9.85,3 12.5,3Z\";\r\nvar mdiRewind5 = \"M12.5 3C17.15 3 21.08 6.03 22.47 10.22L20.1 11C19.05 7.81 16.04 5.5 12.5 5.5C10.54 5.5 8.77 6.22 7.38 7.38L10 10H3V3L5.6 5.6C7.45 4 9.85 3 12.5 3M9 12H15V14H11V16H13C14.11 16 15 16.9 15 18V20C15 21.11 14.11 22 13 22H9V20H13V18H9V12Z\";\r\nvar mdiRewind60 = \"M19 14V20C19 21.1 18.1 22 17 22H15C13.9 22 13 21.1 13 20V14C13 12.9 13.9 12 15 12H17C18.1 12 19 12.9 19 14M15 14V20H17V14H15M12.5 3C17.1 3 21.1 6 22.5 10.2L20.1 11C19 7.8 16 5.5 12.5 5.5C10.5 5.5 8.8 6.2 7.4 7.4L10 10H3V3L5.6 5.6C7.4 4 9.9 3 12.5 3M7 12C5.9 12 5 12.9 5 14V20C5 21.1 5.9 22 7 22H9C10.1 22 11 21.1 11 20V18C11 16.9 10.1 16 9 16H7V14H11V12H7M7 18H9V20H7V18Z\";\r\nvar mdiRewindOutline = \"M10,9.9L7,12L10,14.1V9.9M19,9.9L16,12L19,14.1V9.9M12,6V18L3.5,12L12,6M21,6V18L12.5,12L21,6Z\";\r\nvar mdiRhombus = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2Z\";\r\nvar mdiRhombusMedium = \"M12 6.46C11.72 6.46 11.44 6.56 11.22 6.78L6.78 11.22C6.35 11.65 6.35 12.35 6.78 12.78L11.22 17.22C11.65 17.65 12.35 17.65 12.78 17.22L17.22 12.78C17.65 12.35 17.65 11.65 17.22 11.22L12.78 6.78C12.56 6.56 12.28 6.46 12 6.46Z\";\r\nvar mdiRhombusMediumOutline = \"M12 6.46C11.72 6.46 11.44 6.56 11.22 6.78L6.78 11.22C6.35 11.65 6.35 12.35 6.78 12.78L11.22 17.22C11.65 17.65 12.35 17.65 12.78 17.22L17.22 12.78C17.65 12.35 17.65 11.65 17.22 11.22L12.78 6.78C12.56 6.56 12.28 6.46 12 6.46M12 8.83L15.17 12L12 15.17L8.83 12L12 8.83Z\";\r\nvar mdiRhombusOutline = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L20 12L12 20L4 12Z\";\r\nvar mdiRhombusSplit = \"M12 2C11.5 2 11 2.19 10.59 2.59L7.29 5.88L12 10.58L16.71 5.88L13.41 2.59C13 2.19 12.5 2 12 2M5.88 7.29L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L5.88 16.71L10.58 12L5.88 7.29M18.12 7.29L13.42 12L18.12 16.71L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L18.12 7.29M12 13.42L7.29 18.12L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L16.71 18.12L12 13.42Z\";\r\nvar mdiRhombusSplitOutline = \"M12 2C11.5 2 11 2.19 10.59 2.59L2.59 10.59C1.8 11.37 1.8 12.63 2.59 13.41L10.59 21.41C11.37 22.2 12.63 22.2 13.41 21.41L21.41 13.41C22.2 12.63 22.2 11.37 21.41 10.59L13.41 2.59C13 2.19 12.5 2 12 2M12 4L15.29 7.29L12 10.59L8.71 7.29L12 4M7.29 8.71L10.59 12L7.29 15.29L4 12L7.29 8.71M16.71 8.71L20 12L16.71 15.29L13.41 12L16.71 8.71M12 13.41L15.29 16.71L12 20L8.71 16.71L12 13.41Z\";\r\nvar mdiRibbon = \"M13.41,19.31L16.59,22.5L18,21.07L14.83,17.9M15.54,11.53H15.53L12,15.07L8.47,11.53H8.46V11.53C7.56,10.63 7,9.38 7,8A5,5 0 0,1 12,3A5,5 0 0,1 17,8C17,9.38 16.44,10.63 15.54,11.53M16.9,13C18.2,11.73 19,9.96 19,8A7,7 0 0,0 12,1A7,7 0 0,0 5,8C5,9.96 5.81,11.73 7.1,13V13L10.59,16.5L6,21.07L7.41,22.5L16.9,13Z\";\r\nvar mdiRice = \"M22,11H19.7C19.4,9.9 18.9,8.8 18.2,8L21.6,2.6L19.9,1.5L16.7,6.6C16.3,6.3 16,6.1 15.5,5.9L16.4,2.3L14.5,1.8L13.7,5.2C13.1,5.1 12.6,5 12,5C8.3,5 5.2,7.6 4.3,11H2C2,15.1 4.5,18.6 8,20.2V22H16V20.2C19.5,18.6 22,15.1 22,11M12,7C14.6,7 16.8,8.7 17.6,11H6.4C7.2,8.7 9.4,7 12,7Z\";\r\nvar mdiRickshaw = \"M20 14.05V12.73C20 12.26 19.84 11.8 19.54 11.44L15.6 6.72C15.22 6.26 14.66 6 14.06 6H4C2.9 6 2 6.9 2 8V15C2 16.1 2.9 17 4 17H4.05C4.28 18.14 5.29 19 6.5 19S8.72 18.14 8.95 17H17.05C17.28 18.14 18.29 19 19.5 19C20.88 19 22 17.88 22 16.5C22 15.29 21.14 14.28 20 14.05M3.5 8C3.5 7.73 3.73 7.5 4 7.5H7V12H3.5V8M6.5 17.5C5.95 17.5 5.5 17.05 5.5 16.5S5.95 15.5 6.5 15.5 7.5 15.95 7.5 16.5 7.05 17.5 6.5 17.5M13 15.5H9V14H11V12H9V7.5H13V15.5M15 8.34L18.05 12H15V8.34M19.5 17.5C18.95 17.5 18.5 17.05 18.5 16.5S18.95 15.5 19.5 15.5 20.5 15.95 20.5 16.5 20.05 17.5 19.5 17.5Z\";\r\nvar mdiRickshawElectric = \"M20 12.05V10.73C20 10.26 19.84 9.8 19.54 9.44L15.6 4.72C15.22 4.26 14.66 4 14.06 4H4C2.9 4 2 4.9 2 6V13C2 14.1 2.9 15 4 15H4.05C4.28 16.14 5.29 17 6.5 17S8.72 16.14 8.95 15H17.05C17.28 16.14 18.29 17 19.5 17C20.88 17 22 15.88 22 14.5C22 13.29 21.14 12.28 20 12.05M3.5 6C3.5 5.73 3.73 5.5 4 5.5H7V10H3.5V6M6.5 15.5C5.95 15.5 5.5 15.05 5.5 14.5S5.95 13.5 6.5 13.5 7.5 13.95 7.5 14.5 7.05 15.5 6.5 15.5M13 13.5H9V12H11V10H9V5.5H13V13.5M15 6.34L18.05 10H15V6.34M19.5 15.5C18.95 15.5 18.5 15.05 18.5 14.5S18.95 13.5 19.5 13.5 20.5 13.95 20.5 14.5 20.05 15.5 19.5 15.5M11 20H7L13 23V21H17L11 18V20Z\";\r\nvar mdiRing = \"M12,10L8,4.4L9.6,2H14.4L16,4.4L12,10M15.5,6.8L14.3,8.5C16.5,9.4 18,11.5 18,14A6,6 0 0,1 12,20A6,6 0 0,1 6,14C6,11.5 7.5,9.4 9.7,8.5L8.5,6.8C5.8,8.1 4,10.8 4,14A8,8 0 0,0 12,22A8,8 0 0,0 20,14C20,10.8 18.2,8.1 15.5,6.8Z\";\r\nvar mdiRivet = \"M11.43,2C10.61,2 9.94,2.65 9.94,3.5C9.94,4.64 9.94,5.8 9.94,6.96H7.95V7.95H15.91V6.96H13.92C13.92,5.8 13.92,4.64 13.92,3.5C13.92,2.65 13.25,2 12.43,2H11.43M10.94,8.95V21.87L11.93,22.87L12.92,21.87V8.95H10.94Z\";\r\nvar mdiRoad = \"M11,16H13V20H11M11,10H13V14H11M11,4H13V8H11M4,22H20V2H4V22Z\";\r\nvar mdiRoadVariant = \"M18.1,4.8C18,4.3 17.6,4 17.1,4H13L13.2,7H10.8L11,4H6.8C6.3,4 5.9,4.4 5.8,4.8L3.1,18.8C3,19.4 3.5,20 4.1,20H10L10.3,15H13.7L14,20H19.8C20.4,20 20.9,19.4 20.8,18.8L18.1,4.8M10.4,13L10.6,9H13.2L13.4,13H10.4Z\";\r\nvar mdiRobber = \"M10.7 12.5C10.7 12.8 9.4 13.2 8.4 13.2S6.3 12.5 6.3 12.3C6.3 12 7 11.1 8.6 11C9.5 10.9 10.5 11.5 10.7 12.5M15.4 11C14.4 10.9 13.5 11.5 13.3 12.5C13.3 12.8 14.5 13.2 15.6 13.2C16.7 13.2 17.7 12.5 17.7 12.3S17 11.1 15.4 11M22 12C22 17.5 17.5 22 12 22S2 17.5 2 12 6.5 2 12 2 22 6.5 22 12M20 11.2C20 9.2 19.3 8.5 16.7 8.5C14.1 8.5 13.3 9.6 12 9.6S10 8.5 7.3 8.5 4 9.1 4 11.2C4 14.6 5.5 16.5 7.6 16.5C9.2 16.5 10.4 14.5 12 14.5S14.7 16.5 16.4 16.5C18.5 16.5 20 14.6 20 11.2Z\";\r\nvar mdiRobot = \"M12,2A2,2 0 0,1 14,4C14,4.74 13.6,5.39 13,5.73V7H14A7,7 0 0,1 21,14H22A1,1 0 0,1 23,15V18A1,1 0 0,1 22,19H21V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V19H2A1,1 0 0,1 1,18V15A1,1 0 0,1 2,14H3A7,7 0 0,1 10,7H11V5.73C10.4,5.39 10,4.74 10,4A2,2 0 0,1 12,2M7.5,13A2.5,2.5 0 0,0 5,15.5A2.5,2.5 0 0,0 7.5,18A2.5,2.5 0 0,0 10,15.5A2.5,2.5 0 0,0 7.5,13M16.5,13A2.5,2.5 0 0,0 14,15.5A2.5,2.5 0 0,0 16.5,18A2.5,2.5 0 0,0 19,15.5A2.5,2.5 0 0,0 16.5,13Z\";\r\nvar mdiRobotIndustrial = \"M18.41,4L16,6.41V6.59L18.41,9H22V11H17.59L16,9.41V12H15A2,2 0 0,1 13,10V7.5H9.86C9.77,7.87 9.62,8.22 9.42,8.55L15.18,19H20A2,2 0 0,1 22,21V22H2V21A2,2 0 0,1 4,19H10.61L5.92,10.5C4.12,10.47 2.56,9.24 2.11,7.5C1.56,5.36 2.85,3.18 5,2.63C7.13,2.08 9.31,3.36 9.86,5.5H13V3A2,2 0 0,1 15,1H16V3.59L17.59,2H22V4H18.41M6,4.5A2,2 0 0,0 4,6.5A2,2 0 0,0 6,8.5A2,2 0 0,0 8,6.5A2,2 0 0,0 6,4.5Z\";\r\nvar mdiRobotMower = \"M1 14V5H13C18.5 5 23 9.5 23 15V17H20.83C20.42 18.17 19.31 19 18 19C16.69 19 15.58 18.17 15.17 17H10C9.09 18.21 7.64 19 6 19C3.24 19 1 16.76 1 14M6 11C4.34 11 3 12.34 3 14C3 15.66 4.34 17 6 17C7.66 17 9 15.66 9 14C9 12.34 7.66 11 6 11M15 10V12H20.25C19.92 11.27 19.5 10.6 19 10H15Z\";\r\nvar mdiRobotMowerOutline = \"M1 14C1 16.76 3.24 19 6 19C7.64 19 9.09 18.21 10 17H15.17C15.58 18.17 16.7 19 18 19C19.31 19 20.42 18.17 20.83 17H23V15C23 9.5 18.5 5 13 5H1V14M21 15H10.9C10.97 14.68 11 14.34 11 14C11 11.24 8.76 9 6 9C4.87 9 3.84 9.37 3 10V7H12.5C15.1 7 17.42 8.16 19 10H15V12H20.25C20.67 12.92 20.92 13.94 21 15M6 11C7.66 11 9 12.34 9 14C9 15.66 7.66 17 6 17C4.34 17 3 15.66 3 14C3 12.34 4.34 11 6 11Z\";\r\nvar mdiRobotVacuum = \"M12,2C14.65,2 17.19,3.06 19.07,4.93L17.65,6.35C16.15,4.85 14.12,4 12,4C9.88,4 7.84,4.84 6.35,6.35L4.93,4.93C6.81,3.06 9.35,2 12,2M3.66,6.5L5.11,7.94C4.39,9.17 4,10.57 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12C20,10.57 19.61,9.17 18.88,7.94L20.34,6.5C21.42,8.12 22,10.04 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12C2,10.04 2.58,8.12 3.66,6.5M12,6A6,6 0 0,1 18,12C18,13.59 17.37,15.12 16.24,16.24L14.83,14.83C14.08,15.58 13.06,16 12,16C10.94,16 9.92,15.58 9.17,14.83L7.76,16.24C6.63,15.12 6,13.59 6,12A6,6 0 0,1 12,6M12,8A1,1 0 0,0 11,9A1,1 0 0,0 12,10A1,1 0 0,0 13,9A1,1 0 0,0 12,8Z\";\r\nvar mdiRobotVacuumVariant = \"M5,3A2,2 0 0,0 3,5V7H5V5H19V7H21V5A2,2 0 0,0 19,3H5M8,7V9H16V7H8M3,9V12A9,9 0 0,0 12,21A9,9 0 0,0 21,12V9H19V12A7,7 0 0,1 12,19A7,7 0 0,1 5,12V9H3M12,12A2.5,2.5 0 0,0 9.5,14.5A2.5,2.5 0 0,0 12,17A2.5,2.5 0 0,0 14.5,14.5A2.5,2.5 0 0,0 12,12Z\";\r\nvar mdiRocket = \"M20 22L16.14 20.45C16.84 18.92 17.34 17.34 17.65 15.73L20 22M7.86 20.45L4 22L6.35 15.73C6.66 17.34 7.16 18.92 7.86 20.45M12 2C12 2 17 4 17 12C17 15.1 16.25 17.75 15.33 19.83C15 20.55 14.29 21 13.5 21H10.5C9.71 21 9 20.55 8.67 19.83C7.76 17.75 7 15.1 7 12C7 4 12 2 12 2M12 12C13.1 12 14 11.1 14 10C14 8.9 13.1 8 12 8C10.9 8 10 8.9 10 10C10 11.1 10.9 12 12 12Z\";\r\nvar mdiRocketLaunch = \"M13.13 22.19L11.5 18.36C13.07 17.78 14.54 17 15.9 16.09L13.13 22.19M5.64 12.5L1.81 10.87L7.91 8.1C7 9.46 6.22 10.93 5.64 12.5M21.61 2.39C21.61 2.39 16.66 .269 11 5.93C8.81 8.12 7.5 10.53 6.65 12.64C6.37 13.39 6.56 14.21 7.11 14.77L9.24 16.89C9.79 17.45 10.61 17.63 11.36 17.35C13.5 16.53 15.88 15.19 18.07 13C23.73 7.34 21.61 2.39 21.61 2.39M14.54 9.46C13.76 8.68 13.76 7.41 14.54 6.63S16.59 5.85 17.37 6.63C18.14 7.41 18.15 8.68 17.37 9.46C16.59 10.24 15.32 10.24 14.54 9.46M8.88 16.53L7.47 15.12L8.88 16.53M6.24 22L9.88 18.36C9.54 18.27 9.21 18.12 8.91 17.91L4.83 22H6.24M2 22H3.41L8.18 17.24L6.76 15.83L2 20.59V22M2 19.17L6.09 15.09C5.88 14.79 5.73 14.47 5.64 14.12L2 17.76V19.17Z\";\r\nvar mdiRocketLaunchOutline = \"M13.13 22.19L11.5 18.36C13.07 17.78 14.54 17 15.9 16.09L13.13 22.19M5.64 12.5L1.81 10.87L7.91 8.1C7 9.46 6.22 10.93 5.64 12.5M19.22 4C19.5 4 19.75 4 19.96 4.05C20.13 5.44 19.94 8.3 16.66 11.58C14.96 13.29 12.93 14.6 10.65 15.47L8.5 13.37C9.42 11.06 10.73 9.03 12.42 7.34C15.18 4.58 17.64 4 19.22 4M19.22 2C17.24 2 14.24 2.69 11 5.93C8.81 8.12 7.5 10.53 6.65 12.64C6.37 13.39 6.56 14.21 7.11 14.77L9.24 16.89C9.62 17.27 10.13 17.5 10.66 17.5C10.89 17.5 11.13 17.44 11.36 17.35C13.5 16.53 15.88 15.19 18.07 13C23.73 7.34 21.61 2.39 21.61 2.39S20.7 2 19.22 2M14.54 9.46C13.76 8.68 13.76 7.41 14.54 6.63S16.59 5.85 17.37 6.63C18.14 7.41 18.15 8.68 17.37 9.46C16.59 10.24 15.32 10.24 14.54 9.46M8.88 16.53L7.47 15.12L8.88 16.53M6.24 22L9.88 18.36C9.54 18.27 9.21 18.12 8.91 17.91L4.83 22H6.24M2 22H3.41L8.18 17.24L6.76 15.83L2 20.59V22M2 19.17L6.09 15.09C5.88 14.79 5.73 14.47 5.64 14.12L2 17.76V19.17Z\";\r\nvar mdiRocketOutline = \"M12 2C12 2 7 4 7 12C7 15.1 7.76 17.75 8.67 19.83C9 20.55 9.71 21 10.5 21H13.5C14.29 21 15 20.55 15.33 19.83C16.25 17.75 17 15.1 17 12C17 4 12 2 12 2M13.5 19H10.5C9.5 16.76 9 14.41 9 12C9 7.36 10.9 5.2 12 4.33C13.1 5.2 15 7.36 15 12C15 14.41 14.5 16.76 13.5 19M20 22L16.14 20.45C16.84 18.92 17.34 17.34 17.65 15.73M7.86 20.45L4 22L6.35 15.73C6.66 17.34 7.16 18.92 7.86 20.45M12 12C10.9 12 10 11.1 10 10C10 8.9 10.9 8 12 8C13.1 8 14 8.9 14 10C14 11.1 13.1 12 12 12Z\";\r\nvar mdiRodent = \"M21.33 17.39C22.73 18.66 21.8 21 19.92 21H11.06C8.25 21 6 18.75 6 15.94V15.89C3.7 15.42 2 13.41 2 11C2 8.25 4.22 6 7 6H9.5C9.8 6 10 5.77 10 5.5S9.8 5 9.5 5H7V3H9.5C10.88 3 12 4.13 12 5.5C12 6.89 10.88 8 9.5 8H7C5.34 8 4 9.33 4 11C4 12.37 4.92 13.5 6.14 13.87C6.7 11.67 8.67 10 11.06 10C11.86 10 12.66 10.22 13.36 10.55C11.95 11.34 11 12.8 11 14.5C11 15.75 11.5 16.87 12.33 17.67L13.03 16.97C12.38 16.36 12 15.47 12 14.5C12 11.91 14.34 11 15.5 11C17.58 11 19.45 12.89 18.94 15.23L21.33 17.39M18 19C18.56 19 19 18.56 19 18S18.56 17 18 17 17 17.44 17 18 17.44 19 18 19Z\";\r\nvar mdiRollerSkate = \"M19,15C19,15 19,16 17,16C15,16 4,16 4,16V3H11L11.21,4.5H9.24V6H11.43L11.64,7.5H9.24V9H11.86L12,10H14C14,10 19,10 19,15M6.5,17A2.5,2.5 0 0,0 4,19.5A2.5,2.5 0 0,0 6.5,22A2.5,2.5 0 0,0 9,19.5A2.5,2.5 0 0,0 6.5,17M16.5,17A2.5,2.5 0 0,0 14,19.5A2.5,2.5 0 0,0 16.5,22A2.5,2.5 0 0,0 19,19.5A2.5,2.5 0 0,0 16.5,17Z\";\r\nvar mdiRollerSkateOff = \"M20.84 22.73L18.73 20.62C18.32 21.43 17.5 22 16.5 22C15.12 22 14 20.88 14 19.5C14 18.5 14.57 17.68 15.38 17.27L14.11 16H4V5.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M19 15C19 10 14 10 14 10H13.2L18.72 15.5C19 15.27 19 15 19 15M11.64 7.5L11.43 6H9.24V4.5H11.21L11 3H6.2L10.7 7.5H11.64M6.5 17C5.12 17 4 18.12 4 19.5S5.12 22 6.5 22 9 20.88 9 19.5 7.88 17 6.5 17Z\";\r\nvar mdiRollerblade = \"M19,15C19,15 19,16 17,16C15,16 4,16 4,16V3H11L11.21,4.5H9.24V6H11.43L11.64,7.5H9.24V9H11.86L12,10H14C14,10 19,10 19,15M5.5,17A2.5,2.5 0 0,0 3,19.5A2.5,2.5 0 0,0 5.5,22A2.5,2.5 0 0,0 8,19.5A2.5,2.5 0 0,0 5.5,17M17.5,17A2.5,2.5 0 0,0 15,19.5A2.5,2.5 0 0,0 17.5,22A2.5,2.5 0 0,0 20,19.5A2.5,2.5 0 0,0 17.5,17M11.5,17A2.5,2.5 0 0,0 9,19.5A2.5,2.5 0 0,0 11.5,22A2.5,2.5 0 0,0 14,19.5A2.5,2.5 0 0,0 11.5,17Z\";\r\nvar mdiRollerbladeOff = \"M20.84 22.73L19.32 21.21C18.86 21.69 18.22 22 17.5 22C16.12 22 15 20.88 15 19.5C15 18.78 15.31 18.14 15.79 17.68L14.11 16H4V5.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M11.64 7.5L11.43 6H9.24V4.5H11.21L11 3H6.2L10.7 7.5H11.64M19 15C19 10 14 10 14 10H13.2L18.72 15.5C19 15.27 19 15 19 15M11.5 17C10.12 17 9 18.12 9 19.5S10.12 22 11.5 22 14 20.88 14 19.5 12.88 17 11.5 17M5.5 17C4.12 17 3 18.12 3 19.5S4.12 22 5.5 22 8 20.88 8 19.5 6.88 17 5.5 17Z\";\r\nvar mdiRollupjs = \"M19.46,8.64C19.46,11.11 18.11,13.26 16.12,14.4C16,14.5 15.93,14.66 16,14.81L19.41,21.55C19.5,21.76 19.36,22 19.13,22H6.1L6.17,21.96C6.66,21.68 10.06,14.97 13.38,11.79C16.7,8.61 17.12,9.67 15.29,6.21C15.29,6.21 16.7,8.96 15.5,9.17C14.56,9.34 12.4,7.25 13.2,5.37C14,3.53 17.15,3.88 18.6,5.38C19.15,6.34 19.46,7.45 19.46,8.64M7.16,13.13C5.84,15.56 5,17.33 4.54,18.57V2.31C4.54,2.14 4.68,2 4.85,2H12.92C15.26,2.04 17.31,3.28 18.46,5.15C17.62,4.1 16.3,3.5 15,3.5C12.53,3.5 11.91,4.4 7.16,13.13Z\";\r\nvar mdiRomanNumeral1 = \"M14 7V9H13V15H14V17H10V15H11V9H10V7H14Z\";\r\nvar mdiRomanNumeral10 = \"M9 7L11 12L9 17H11L12 14.5L13 17H15L13 12L15 7H13L12 9.5L11 7H9Z\";\r\nvar mdiRomanNumeral2 = \"M11 7V9H10V15H11V17H7V15H8V9H7V7H11M17 7V9H16V15H17V17H13V15H14V9H13V7H17Z\";\r\nvar mdiRomanNumeral3 = \"M9 7V9H8V15H9V17H5V15H6V9H5V7H9M14 7V9H13V15H14V17H10V15H11V9H10V7H14M19 7V9H18V15H19V17H15V15H16V9H15V7H19Z\";\r\nvar mdiRomanNumeral4 = \"M12 7L14 17H16L18 7H16L15 12L14 7H12M11 7V9H10V15H11V17H7V15H8V9H7V7H11Z\";\r\nvar mdiRomanNumeral5 = \"M9 7L11 17H13L15 7H13L12 12L11 7H9Z\";\r\nvar mdiRomanNumeral6 = \"M6 7L8 17H10L12 7H10L9 12L8 7H6M17 7V9H16V15H17V17H13V15H14V9H13V7H17Z\";\r\nvar mdiRomanNumeral7 = \"M4 7L6 17H8L10 7H8L7 12L6 7H4M15 7V9H14V15H15V17H11V15H12V9H11V7H15M20 7V9H19V15H20V17H16V15H17V9H16V7H20Z\";\r\nvar mdiRomanNumeral8 = \"M1 7L3 17H5L7 7H5L4 12L3 7H1M12 7V9H11V15H12V17H8V15H9V9H8V7H12M17 7V9H16V15H17V17H13V15H14V9H13V7H17M22 7V9H21V15H22V17H18V15H19V9H18V7H22Z\";\r\nvar mdiRomanNumeral9 = \"M11 7V9H10V15H11V17H7V15H8V9H7V7H11M12 7L14 12L12 17H14L15 14.5L16 17H18L16 12L18 7H16L15 9.5L14 7H12Z\";\r\nvar mdiRoomService = \"M12,5A2,2 0 0,1 14,7C14,7.24 13.96,7.47 13.88,7.69C17.95,8.5 21,11.91 21,16H3C3,11.91 6.05,8.5 10.12,7.69C10.04,7.47 10,7.24 10,7A2,2 0 0,1 12,5M22,19H2V17H22V19Z\";\r\nvar mdiRoomServiceOutline = \"M12,5A2,2 0 0,1 14,7C14,7.24 13.96,7.47 13.88,7.69C17.95,8.5 21,11.91 21,16H3C3,11.91 6.05,8.5 10.12,7.69C10.04,7.47 10,7.24 10,7A2,2 0 0,1 12,5M22,19H2V17H22V19M12,9.5C8.89,9.5 6.25,11.39 5.34,14H18.66C17.75,11.39 15.11,9.5 12,9.5Z\";\r\nvar mdiRotate3d = \"M7.47,21.5C4.2,19.94 1.86,16.76 1.5,13H0C0.5,19.16 5.66,24 11.95,24L12.61,23.97L8.8,20.16L7.47,21.5M8.36,14.96C8.17,14.96 8,14.93 7.84,14.88C7.68,14.82 7.55,14.75 7.44,14.64C7.33,14.54 7.24,14.42 7.18,14.27C7.12,14.13 7.09,13.97 7.09,13.8H5.79C5.79,14.16 5.86,14.5 6,14.75C6.14,15 6.33,15.25 6.56,15.44C6.8,15.62 7.07,15.76 7.38,15.85C7.68,15.95 8,16 8.34,16C8.71,16 9.06,15.95 9.37,15.85C9.69,15.75 9.97,15.6 10.2,15.41C10.43,15.22 10.62,15 10.75,14.69C10.88,14.4 10.95,14.08 10.95,13.72C10.95,13.53 10.93,13.34 10.88,13.16C10.83,13 10.76,12.81 10.65,12.65C10.55,12.5 10.41,12.35 10.25,12.22C10.08,12.09 9.88,12 9.64,11.91C9.84,11.82 10,11.71 10.16,11.58C10.31,11.45 10.43,11.31 10.53,11.16C10.63,11 10.7,10.86 10.75,10.7C10.8,10.54 10.82,10.38 10.82,10.22C10.82,9.86 10.76,9.54 10.64,9.26C10.5,9 10.35,8.75 10.13,8.57C9.93,8.38 9.66,8.24 9.36,8.14C9.05,8.05 8.71,8 8.34,8C8,8 7.65,8.05 7.34,8.16C7.04,8.27 6.77,8.42 6.55,8.61C6.34,8.8 6.17,9 6.04,9.28C5.92,9.54 5.86,9.82 5.86,10.13H7.16C7.16,9.96 7.19,9.81 7.25,9.68C7.31,9.55 7.39,9.43 7.5,9.34C7.61,9.25 7.73,9.17 7.88,9.12C8.03,9.07 8.18,9.04 8.36,9.04C8.76,9.04 9.06,9.14 9.25,9.35C9.44,9.55 9.54,9.84 9.54,10.21C9.54,10.39 9.5,10.55 9.46,10.7C9.41,10.85 9.32,10.97 9.21,11.07C9.1,11.17 8.96,11.25 8.8,11.31C8.64,11.37 8.44,11.4 8.22,11.4H7.45V12.43H8.22C8.44,12.43 8.64,12.45 8.82,12.5C9,12.55 9.15,12.63 9.27,12.73C9.39,12.84 9.5,12.97 9.56,13.13C9.63,13.29 9.66,13.5 9.66,13.7C9.66,14.11 9.54,14.42 9.31,14.63C9.08,14.86 8.76,14.96 8.36,14.96M16.91,9.04C16.59,8.71 16.21,8.45 15.77,8.27C15.34,8.09 14.85,8 14.31,8H11.95V16H14.25C14.8,16 15.31,15.91 15.76,15.73C16.21,15.55 16.6,15.3 16.92,14.97C17.24,14.64 17.5,14.24 17.66,13.78C17.83,13.31 17.92,12.79 17.92,12.21V11.81C17.92,11.23 17.83,10.71 17.66,10.24C17.5,9.77 17.23,9.37 16.91,9.04M16.5,12.2C16.5,12.62 16.47,13 16.38,13.33C16.28,13.66 16.14,13.95 15.95,14.18C15.76,14.41 15.5,14.59 15.24,14.71C14.95,14.83 14.62,14.89 14.25,14.89H13.34V9.12H14.31C15.03,9.12 15.58,9.35 15.95,9.81C16.33,10.27 16.5,10.93 16.5,11.8M11.95,0L11.29,0.03L15.1,3.84L16.43,2.5C19.7,4.06 22.04,7.23 22.39,11H23.89C23.39,4.84 18.24,0 11.95,0Z\";\r\nvar mdiRotate3dVariant = \"M12,5C16.97,5 21,7.69 21,11C21,12.68 19.96,14.2 18.29,15.29C19.36,14.42 20,13.32 20,12.13C20,9.29 16.42,7 12,7V10L8,6L12,2V5M12,19C7.03,19 3,16.31 3,13C3,11.32 4.04,9.8 5.71,8.71C4.64,9.58 4,10.68 4,11.88C4,14.71 7.58,17 12,17V14L16,18L12,22V19Z\";\r\nvar mdiRotateLeft = \"M13,4.07V1L8.45,5.55L13,10V6.09C15.84,6.57 18,9.03 18,12C18,14.97 15.84,17.43 13,17.91V19.93C16.95,19.44 20,16.08 20,12C20,7.92 16.95,4.56 13,4.07M7.1,18.32C8.26,19.22 9.61,19.76 11,19.93V17.9C10.13,17.75 9.29,17.41 8.54,16.87L7.1,18.32M6.09,13H4.07C4.24,14.39 4.79,15.73 5.69,16.89L7.1,15.47C6.58,14.72 6.23,13.88 6.09,13M7.11,8.53L5.7,7.11C4.8,8.27 4.24,9.61 4.07,11H6.09C6.23,10.13 6.58,9.28 7.11,8.53Z\";\r\nvar mdiRotateLeftVariant = \"M4,2H7A2,2 0 0,1 9,4V20A2,2 0 0,1 7,22H4A2,2 0 0,1 2,20V4A2,2 0 0,1 4,2M20,15A2,2 0 0,1 22,17V20A2,2 0 0,1 20,22H11V15H20M14,4A8,8 0 0,1 22,12L21.94,13H19.92L20,12A6,6 0 0,0 14,6V9L10,5L14,1V4Z\";\r\nvar mdiRotateOrbit = \"M8,14.25L4.75,11H7C7.25,5.39 9.39,1 12,1C14,1 15.77,3.64 16.55,7.45C20.36,8.23 23,10 23,12C23,13.83 20.83,15.43 17.6,16.3L17.89,14.27C19.8,13.72 21,12.91 21,12C21,10.94 19.35,10 16.87,9.5C16.95,10.29 17,11.13 17,12C17,18.08 14.76,23 12,23C10.17,23 8.57,20.83 7.7,17.6L9.73,17.89C10.28,19.8 11.09,21 12,21C13.66,21 15,16.97 15,12C15,11 14.95,10.05 14.85,9.15C13.95,9.05 13,9 12,9L10.14,9.06L10.43,7.05L12,7C12.87,7 13.71,7.05 14.5,7.13C14,4.65 13.06,3 12,3C10.46,3 9.18,6.5 9,11H11.25L8,14.25M14.25,16L11,19.25V17C5.39,16.75 1,14.61 1,12C1,10.17 3.17,8.57 6.4,7.7L6.11,9.73C4.2,10.28 3,11.09 3,12C3,13.54 6.5,14.82 11,15V12.75L14.25,16Z\";\r\nvar mdiRotateRight = \"M16.89,15.5L18.31,16.89C19.21,15.73 19.76,14.39 19.93,13H17.91C17.77,13.87 17.43,14.72 16.89,15.5M13,17.9V19.92C14.39,19.75 15.74,19.21 16.9,18.31L15.46,16.87C14.71,17.41 13.87,17.76 13,17.9M19.93,11C19.76,9.61 19.21,8.27 18.31,7.11L16.89,8.53C17.43,9.28 17.77,10.13 17.91,11M15.55,5.55L11,1V4.07C7.06,4.56 4,7.92 4,12C4,16.08 7.05,19.44 11,19.93V17.91C8.16,17.43 6,14.97 6,12C6,9.03 8.16,6.57 11,6.09V10L15.55,5.55Z\";\r\nvar mdiRotateRightVariant = \"M10,4V1L14,5L10,9V6A6,6 0 0,0 4,12L4.08,13H2.06L2,12A8,8 0 0,1 10,4M17,2H20A2,2 0 0,1 22,4V20A2,2 0 0,1 20,22H17A2,2 0 0,1 15,20V4A2,2 0 0,1 17,2M4,15H13V22H4A2,2 0 0,1 2,20V17A2,2 0 0,1 4,15Z\";\r\nvar mdiRoundedCorner = \"M19,19H21V21H19V19M19,17H21V15H19V17M3,13H5V11H3V13M3,17H5V15H3V17M3,9H5V7H3V9M3,5H5V3H3V5M7,5H9V3H7V5M15,21H17V19H15V21M11,21H13V19H11V21M15,21H17V19H15V21M7,21H9V19H7V21M3,21H5V19H3V21M21,8A5,5 0 0,0 16,3H11V5H16A3,3 0 0,1 19,8V13H21V8Z\";\r\nvar mdiRouter = \"M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 6.5 17.5 2 12 2M12 20C7.58 20 4 16.42 4 12C4 7.58 7.58 4 12 4C16.42 4 20 7.58 20 12C20 16.42 16.42 20 12 20M13 13V16H15L12 19L9 16H11V13M5 13H8V15L11 12L8 9V11H5M11 11V8H9L12 5L15 8H13V11M19 11H16V9L13 12L16 15V13H19\";\r\nvar mdiRouterNetwork = \"M5 9C3.9 9 3 9.9 3 11V15C3 16.11 3.9 17 5 17H11V19H10C9.45 19 9 19.45 9 20H2V22H9C9 22.55 9.45 23 10 23H14C14.55 23 15 22.55 15 22H22V20H15C15 19.45 14.55 19 14 19H13V17H19C20.11 17 21 16.11 21 15V11C21 9.9 20.11 9 19 9H5M6 12H8V14H6V12M9.5 12H11.5V14H9.5V12M13 12H15V14H13V12Z\";\r\nvar mdiRouterWireless = \"M20.2,5.9L21,5.1C19.6,3.7 17.8,3 16,3C14.2,3 12.4,3.7 11,5.1L11.8,5.9C13,4.8 14.5,4.2 16,4.2C17.5,4.2 19,4.8 20.2,5.9M19.3,6.7C18.4,5.8 17.2,5.3 16,5.3C14.8,5.3 13.6,5.8 12.7,6.7L13.5,7.5C14.2,6.8 15.1,6.5 16,6.5C16.9,6.5 17.8,6.8 18.5,7.5L19.3,6.7M19,13H17V9H15V13H5A2,2 0 0,0 3,15V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V15A2,2 0 0,0 19,13M8,18H6V16H8V18M11.5,18H9.5V16H11.5V18M15,18H13V16H15V18Z\";\r\nvar mdiRouterWirelessOff = \"M11.8 5.9L11 5.1C12.4 3.7 14.2 3 16 3S19.6 3.7 21 5.1L20.2 5.9C19 4.8 17.5 4.2 16 4.2S13 4.8 11.8 5.9M21 15C21 13.9 20.1 13 19 13H17V9H15V11.8L21 17.8V15M18.5 7.5L19.3 6.7C18.4 5.8 17.2 5.3 16 5.3S13.6 5.8 12.7 6.7L13.5 7.5C14.2 6.8 15.1 6.5 16 6.5C16.9 6.5 17.8 6.8 18.5 7.5M22.1 21.5L20.8 22.8L19.1 21H5C3.9 21 3 20.1 3 19V15C3 13.9 3.9 13 5 13H11.1L1.1 3L2.4 1.7L22.1 21.5M8 16H6V18H8V16M11.5 16H9.5V18H11.5V16M15 16.9L14.1 16H13V18H15V16.9Z\";\r\nvar mdiRouterWirelessSettings = \"M20.2,4.9C19,3.8 17.5,3.2 16,3.2C14.5,3.2 13,3.8 11.8,4.9L11,4.1C12.4,2.7 14.2,2 16,2C17.8,2 19.6,2.7 21,4.1L20.2,4.9M19.3,5.7L18.5,6.5C17.8,5.8 16.9,5.5 16,5.5C15.1,5.5 14.2,5.8 13.5,6.5L12.7,5.7C13.6,4.8 14.8,4.3 16,4.3C17.2,4.3 18.4,4.8 19.3,5.7M19,12A2,2 0 0,1 21,14V18A2,2 0 0,1 19,20H5A2,2 0 0,1 3,18V14A2,2 0 0,1 5,12H15V8H17V12H19M8,17V15H6V17H8M11.5,17V15H9.5V17H11.5M15,17V15H13V17H15M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiRoutes = \"M11,10H5L3,8L5,6H11V3L12,2L13,3V4H19L21,6L19,8H13V10H19L21,12L19,14H13V20A2,2 0 0,1 15,22H9A2,2 0 0,1 11,20V10Z\";\r\nvar mdiRoutesClock = \"M16.5 13H15V16.69L18.19 18.53L18.94 17.23L16.5 15.82V13M16 9C14.04 9 12.27 9.82 11 11.12V7H17L19 5L17 3H11V2L10 1L9 2V6H3L1 8L3 10H9V20C7.9 20 7 20.9 7 22H12.41C13.46 22.63 14.69 23 16 23C19.87 23 23 19.87 23 16S19.87 9 16 9M16 20.85C13.32 20.85 11.15 18.68 11.15 16S13.32 11.15 16 11.15 20.85 13.32 20.85 16 18.68 20.85 16 20.85Z\";\r\nvar mdiRowing = \"M8.5,14.5L4,19L5.5,20.5L9,17H11L8.5,14.5M15,1A2,2 0 0,0 13,3A2,2 0 0,0 15,5A2,2 0 0,0 17,3A2,2 0 0,0 15,1M21,21L18,24L15,21V19.5L7.91,12.41C7.6,12.46 7.3,12.5 7,12.5V10.32C8.66,10.35 10.61,9.45 11.67,8.28L13.07,6.73C13.26,6.5 13.5,6.35 13.76,6.23C14.05,6.09 14.38,6 14.72,6H14.75C16,6 17,7 17,8.26V14C17,14.85 16.65,15.62 16.08,16.17L12.5,12.59V10.32C11.87,10.84 11.07,11.34 10.21,11.71L16.5,18H18L21,21Z\";\r\nvar mdiRss = \"M6.18,15.64A2.18,2.18 0 0,1 8.36,17.82C8.36,19 7.38,20 6.18,20C5,20 4,19 4,17.82A2.18,2.18 0 0,1 6.18,15.64M4,4.44A15.56,15.56 0 0,1 19.56,20H16.73A12.73,12.73 0 0,0 4,7.27V4.44M4,10.1A9.9,9.9 0 0,1 13.9,20H11.07A7.07,7.07 0 0,0 4,12.93V10.1Z\";\r\nvar mdiRssBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M7.5,15A1.5,1.5 0 0,0 6,16.5A1.5,1.5 0 0,0 7.5,18A1.5,1.5 0 0,0 9,16.5A1.5,1.5 0 0,0 7.5,15M6,10V12A6,6 0 0,1 12,18H14A8,8 0 0,0 6,10M6,6V8A10,10 0 0,1 16,18H18A12,12 0 0,0 6,6Z\";\r\nvar mdiRssOff = \"M2.5,3.77L3.78,2.5L21.5,20.22L20.23,21.5L18.73,20H16.73C16.73,19.25 16.67,18.5 16.54,17.81L6.19,7.46C5.5,7.33 4.75,7.27 4,7.27V5.27L2.5,3.77M6.18,15.64A2.18,2.18 0 0,1 8.36,17.82C8.36,19 7.38,20 6.18,20C5,20 4,19 4,17.82A2.18,2.18 0 0,1 6.18,15.64M4,10.1A9.9,9.9 0 0,1 13.9,20H11.07A7.07,7.07 0 0,0 4,12.93V10.1M9.13,5.31C13.59,6.87 17.13,10.41 18.69,14.87L9.13,5.31Z\";\r\nvar mdiRug = \"M12 14C10.9 14 10 13.11 10 12S10.9 10 12 10 14 10.9 14 12 13.11 14 12 14M23 19H1V17H4V15H1V13H4V11H1V9H4V7H1V5H23V7H20V9H23V11H20V13H23V15H20V17H23V19M12 15.92C12.62 16.62 13.66 16.81 14.5 16.33C15.34 15.85 15.69 14.84 15.4 13.96C16.31 13.78 17 12.97 17 12S16.31 10.22 15.4 10.04C15.69 9.16 15.34 8.15 14.5 7.67C13.66 7.19 12.62 7.38 12 8.08C11.38 7.38 10.34 7.19 9.5 7.67C8.66 8.15 8.31 9.16 8.61 10.04C7.69 10.22 7 11.03 7 12S7.69 13.78 8.61 13.96C8.31 14.84 8.66 15.85 9.5 16.33C10.34 16.82 11.38 16.62 12 15.92Z\";\r\nvar mdiRugby = \"M16.22,16.22C18.25,14.19 19.33,11.5 19.45,8.2C18.36,10.61 16.81,12.81 14.81,14.81C12.81,16.81 10.61,18.36 8.2,19.45C11.5,19.36 14.16,18.28 16.22,16.22M7.78,7.78C5.75,9.81 4.67,12.5 4.55,15.8C5,14.8 5.7,13.65 6.61,12.35C7.5,11.05 8.38,10 9.19,9.19C11.19,7.19 13.39,5.64 15.8,4.55C12.5,4.64 9.84,5.72 7.78,7.78M20.5,3.5C21,4.05 21.34,5.11 21.47,6.7C21.59,8.3 21.35,10.16 20.74,12.3C20.13,14.45 19.11,16.23 17.67,17.67C16.36,19 14.8,19.95 13,20.55C11.21,21.16 9.44,21.47 7.69,21.47C5.56,21.47 4.17,21.14 3.5,20.5C3,19.95 2.66,18.89 2.53,17.3C2.41,15.7 2.65,13.84 3.26,11.7C3.87,9.55 4.89,7.77 6.33,6.33C7.64,5 9.2,4.05 11,3.45C12.79,2.84 14.56,2.53 16.31,2.53C18.44,2.53 19.83,2.86 20.5,3.5Z\";\r\nvar mdiRuler = \"M1.39,18.36L3.16,16.6L4.58,18L5.64,16.95L4.22,15.54L5.64,14.12L8.11,16.6L9.17,15.54L6.7,13.06L8.11,11.65L9.53,13.06L10.59,12L9.17,10.59L10.59,9.17L13.06,11.65L14.12,10.59L11.65,8.11L13.06,6.7L14.47,8.11L15.54,7.05L14.12,5.64L15.54,4.22L18,6.7L19.07,5.64L16.6,3.16L18.36,1.39L22.61,5.64L5.64,22.61L1.39,18.36Z\";\r\nvar mdiRulerSquare = \"M3,5V21H9V19.5H7V18H9V16.5H5V15H9V13.5H7V12H9V10.5H5V9H9V5H10.5V9H12V7H13.5V9H15V5H16.5V9H18V7H19.5V9H21V3H5A2,2 0 0,0 3,5M6,7A1,1 0 0,1 5,6A1,1 0 0,1 6,5A1,1 0 0,1 7,6A1,1 0 0,1 6,7Z\";\r\nvar mdiRulerSquareCompass = \"M20 19.88V22L18.2 20.83L13.41 11.83A4.94 4.94 0 0 0 15.19 10.83M15 7A3 3 0 0 1 12 10A3.27 3.27 0 0 1 11.56 10L5.8 20.83L4 22V19.88L9.79 9A3 3 0 0 1 12 4V2A1 1 0 0 1 13 3V4.18A3 3 0 0 1 15 7M13 7A1 1 0 1 0 12 8A1 1 0 0 0 13 7M4.22 10L6 11.8L4.56 14.56L2.1 12.1M12 17.76L10.5 16.25L9 19L12 22L15 19L13.53 16.23M19.78 10L18 11.8L19.5 14.56L21.9 12.1Z\";\r\nvar mdiRun = \"M13.5,5.5C14.59,5.5 15.5,4.58 15.5,3.5C15.5,2.38 14.59,1.5 13.5,1.5C12.39,1.5 11.5,2.38 11.5,3.5C11.5,4.58 12.39,5.5 13.5,5.5M9.89,19.38L10.89,15L13,17V23H15V15.5L12.89,13.5L13.5,10.5C14.79,12 16.79,13 19,13V11C17.09,11 15.5,10 14.69,8.58L13.69,7C13.29,6.38 12.69,6 12,6C11.69,6 11.5,6.08 11.19,6.08L6,8.28V13H8V9.58L9.79,8.88L8.19,17L3.29,16L2.89,18L9.89,19.38Z\";\r\nvar mdiRunFast = \"M16.5,5.5A2,2 0 0,0 18.5,3.5A2,2 0 0,0 16.5,1.5A2,2 0 0,0 14.5,3.5A2,2 0 0,0 16.5,5.5M12.9,19.4L13.9,15L16,17V23H18V15.5L15.9,13.5L16.5,10.5C17.89,12.09 19.89,13 22,13V11C20.24,11.03 18.6,10.11 17.7,8.6L16.7,7C16.34,6.4 15.7,6 15,6C14.7,6 14.5,6.1 14.2,6.1L9,8.3V13H11V9.6L12.8,8.9L11.2,17L6.3,16L5.9,18L12.9,19.4M4,9A1,1 0 0,1 3,8A1,1 0 0,1 4,7H7V9H4M5,5A1,1 0 0,1 4,4A1,1 0 0,1 5,3H10V5H5M3,13A1,1 0 0,1 2,12A1,1 0 0,1 3,11H7V13H3Z\";\r\nvar mdiRvTruck = \"M20 8H22V6L20 4H3A2 2 0 0 0 1 6V15A2 2 0 0 0 3 17H4A3 3 0 0 0 7 20A3 3 0 0 0 10 17H15A3 3 0 0 0 21 17H23V12M7 18.5A1.5 1.5 0 0 1 7 15.5A1.5 1.5 0 0 1 7 18.5M9 12H3V9H9M14 15H11V9H14M18 18.5A1.5 1.5 0 1 1 19.5 17A1.54 1.54 0 0 1 18 18.5M17 12V9.5H19.5L21.5 12Z\";\r\nvar mdiSack = \"M16,9C20,11 21,18 21,18C21,18 22,22 16,22C10,22 8,22 8,22C2,22 3,18 3,18C3,18 4,11 8,9M14,4L12,2L10,4L6,2L8,7H16L18,2L14,4Z\";\r\nvar mdiSackPercent = \"M8,7L6,2L10,4L12,2L14,4L18,2L16,7H8M16,22C10,22 8,22 8,22C2,22 3,18 3,18C3,18 4,11 8,9H16C20,11 21,18 21,18C21,18 22,22 16,22M7.5,12.5A1.5,1.5 0 0,0 9,14A1.5,1.5 0 0,0 10.5,12.5A1.5,1.5 0 0,0 9,11A1.5,1.5 0 0,0 7.5,12.5M16.5,18.5A1.5,1.5 0 0,0 15,17A1.5,1.5 0 0,0 13.5,18.5A1.5,1.5 0 0,0 15,20A1.5,1.5 0 0,0 16.5,18.5M16.5,12.35L15.15,11L7.5,18.65L8.87,20L16.5,12.35Z\";\r\nvar mdiSafe = \"M4,4A2,2 0 0,0 2,6V17A2,2 0 0,0 4,19V20H6V19H17V20H19V19A2,2 0 0,0 21,17V16H22V14H21V9H22V7H21V6A2,2 0 0,0 19,4H4M4,6H19V17H4V6M13.5,7.5A4,4 0 0,0 9.5,11.5A4,4 0 0,0 13.5,15.5A4,4 0 0,0 17.5,11.5A4,4 0 0,0 13.5,7.5M5,9V14H7V9H5M13.5,9.5A2,2 0 0,1 15.5,11.5A2,2 0 0,1 13.5,13.5A2,2 0 0,1 11.5,11.5A2,2 0 0,1 13.5,9.5Z\";\r\nvar mdiSafeSquare = \"M20 2C21.1 2 22 2.9 22 4V20C22 21.1 21.1 22 20 22H19V23H15V22H9V23H5V22H4C2.9 22 2 21.1 2 20V4C2 2.9 2.9 2 4 2H20M17 12C17 11 16.7 10 16.2 9.2L17.7 7.7L16.3 6.3L14.8 7.8C14 7.3 13 7 12 7C11 7 10 7.3 9.2 7.8L7.8 6.3L6.3 7.8L7.8 9.3C7.3 10 7 11 7 12C7 13 7.3 14 7.8 14.8L6.3 16.3L7.8 17.7L9.3 16.2C10 16.7 11 17 12 17C13 17 14 16.7 14.8 16.2L16.3 17.7L17.7 16.3L16.2 14.8C16.7 14 17 13 17 12M12 9C13.7 9 15 10.3 15 12C15 13.7 13.7 15 12 15C10.3 15 9 13.7 9 12C9 10.3 10.3 9 12 9M12 14C13.1 14 14 13.1 14 12C14 10.9 13.1 10 12 10C10.9 10 10 10.9 10 12C10 13.1 10.9 14 12 14Z\";\r\nvar mdiSafeSquareOutline = \"M10 12C10 10.9 10.9 10 12 10C13.1 10 14 10.9 14 12C14 13.1 13.1 14 12 14C10.9 14 10 13.1 10 12M7.8 17.7L6.3 16.3L7.8 14.8C7.3 14 7 13 7 12C7 11 7.3 10 7.8 9.3L6.3 7.8L7.8 6.3L9.2 7.8C10 7.3 11 7 12 7C13 7 14 7.3 14.8 7.8L16.3 6.3L17.7 7.7L16.2 9.2C16.7 10 17 11 17 12C17 13 16.7 14 16.2 14.8L17.7 16.3L16.3 17.7L14.8 16.2C14 16.7 13 17 12 17C11 17 10 16.7 9.3 16.2L7.8 17.7M12 9C10.3 9 9 10.3 9 12C9 13.7 10.3 15 12 15C13.7 15 15 13.7 15 12C15 10.3 13.7 9 12 9M20 2C21.1 2 22 2.9 22 4V20C22 21.1 21.1 22 20 22H19V23H15V22H9V23H5V22H4C2.9 22 2 21.1 2 20V4C2 2.9 2.9 2 4 2H20M20 20V4H4V20H20Z\";\r\nvar mdiSafetyGoggles = \"M18,9C19.11,9 20,9.89 20,11V14C20,15.11 19.11,16 18,16H15.77L14.53,14.77C13.78,14 12.77,13.6 11.7,13.6C10.63,13.6 9.63,14 8.87,14.77L7.64,16H6C4.89,16 4,15.11 4,14V11C4,9.89 4.89,9 6,9H18M18,7H6A4,4 0 0,0 2,11H2L1,11V14H2V14A4,4 0 0,0 6,18H8.5C8.54,17.94 8.59,17.88 10.29,16.18C10.68,15.79 11.19,15.6 11.7,15.6C12.22,15.6 12.73,15.79 13.12,16.18L14.91,18H18A4,4 0 0,0 22,14H22L23,14V11H22V11A4,4 0 0,0 18,7Z\";\r\nvar mdiSailBoat = \"M14,3L5,14H14M3,16L6,21H18L21,16\";\r\nvar mdiSale = \"M18.65,2.85L19.26,6.71L22.77,8.5L21,12L22.78,15.5L19.24,17.29L18.63,21.15L14.74,20.54L11.97,23.3L9.19,20.5L5.33,21.14L4.71,17.25L1.22,15.47L3,11.97L1.23,8.5L4.74,6.69L5.35,2.86L9.22,3.5L12,0.69L14.77,3.46L18.65,2.85M9.5,7A1.5,1.5 0 0,0 8,8.5A1.5,1.5 0 0,0 9.5,10A1.5,1.5 0 0,0 11,8.5A1.5,1.5 0 0,0 9.5,7M14.5,14A1.5,1.5 0 0,0 13,15.5A1.5,1.5 0 0,0 14.5,17A1.5,1.5 0 0,0 16,15.5A1.5,1.5 0 0,0 14.5,14M8.41,17L17,8.41L15.59,7L7,15.59L8.41,17Z\";\r\nvar mdiSalesforce = \"M18.38,6.37C17.68,6.37 17.07,6.58 16.47,6.78C15.77,5.57 14.46,4.77 13.05,4.77C11.95,4.77 10.95,5.27 10.24,5.97C9.44,4.97 8.23,4.26 6.83,4.26C4.5,4.26 2.5,6.17 2.5,8.5C2.5,9.09 2.71,9.69 2.91,10.29C1.8,10.9 1,12.1 1,13.5C1,15.5 2.61,17.22 4.62,17.22C4.92,17.22 5.22,17.22 5.42,17.12C5.82,18.63 7.33,19.74 9.14,19.74C10.84,19.74 12.25,18.73 12.75,17.32C13.26,17.53 13.76,17.73 14.26,17.73C15.57,17.73 16.77,17 17.37,15.92C17.68,16 18,16 18.28,16C20.89,16 23,13.91 23,11.2C23.1,8.5 21,6.37 18.38,6.37Z\";\r\nvar mdiSass = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M10,15.33C10.16,15.87 10.14,16.37 10,16.83C10,16.88 9.96,16.93 9.94,17C9.92,17 9.9,17.07 9.87,17.12C9.76,17.36 9.6,17.59 9.41,17.79C8.83,18.43 8,18.67 7.67,18.47C7.29,18.25 7.5,17.35 8.16,16.64C8.88,15.88 9.92,15.38 9.92,15.38V15.38L10,15.33M18.27,6.28C17.82,4.5 14.87,3.92 12.09,4.91C10.43,5.5 8.63,6.42 7.34,7.63C5.81,9.07 5.56,10.32 5.66,10.84C6,12.68 8.54,13.89 9.58,14.78V14.79C9.28,14.94 7.04,16.07 6.5,17.23C5.96,18.45 6.6,19.33 7,19.45C8.34,19.81 9.69,19.16 10.41,18.07C11.11,17.03 11.06,15.68 10.75,15C11.17,14.9 11.66,14.85 12.28,14.92C14.04,15.13 14.38,16.22 14.31,16.68C14.25,17.14 13.88,17.39 13.76,17.47C13.64,17.54 13.6,17.57 13.61,17.63C13.62,17.71 13.68,17.71 13.78,17.69C13.93,17.66 14.71,17.32 14.74,16.47C14.78,15.39 13.75,14.19 11.93,14.22C11.18,14.24 10.71,14.31 10.37,14.44L10.29,14.35C9.16,13.15 7.08,12.3 7.17,10.68C7.2,10.09 7.4,8.55 11.17,6.67C14.25,5.13 16.72,5.55 17.15,6.5C17.76,7.83 15.83,10.32 12.63,10.68C11.41,10.82 10.76,10.34 10.6,10.17C10.43,10 10.41,9.97 10.35,10C10.24,10.07 10.31,10.23 10.35,10.33C10.44,10.58 10.84,11 11.5,11.24C12.09,11.43 13.53,11.54 15.26,10.87C17.2,10.12 18.72,8.03 18.27,6.28Z\";\r\nvar mdiSatellite = \"M5,18L8.5,13.5L11,16.5L14.5,12L19,18M5,12V10A5,5 0 0,0 10,5H12A7,7 0 0,1 5,12M5,5H8A3,3 0 0,1 5,8M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiSatelliteUplink = \"M11.86,2L11.34,3.93C15.75,4.78 19.2,8.23 20.05,12.65L22,12.13C20.95,7.03 16.96,3.04 11.86,2M10.82,5.86L10.3,7.81C13.34,8.27 15.72,10.65 16.18,13.68L18.12,13.16C17.46,9.44 14.55,6.5 10.82,5.86M3.72,9.69C3.25,10.73 3,11.86 3,13C3,14.95 3.71,16.82 5,18.28V22H8V20.41C8.95,20.8 9.97,21 11,21C12.14,21 13.27,20.75 14.3,20.28L3.72,9.69M9.79,9.76L9.26,11.72A3,3 0 0,1 12.26,14.72L14.23,14.2C14,11.86 12.13,10 9.79,9.76Z\";\r\nvar mdiSatelliteVariant = \"M11.62,1L17.28,6.67L15.16,8.79L13.04,6.67L11.62,8.09L13.95,10.41L12.79,11.58L13.24,12.04C14.17,11.61 15.31,11.77 16.07,12.54L12.54,16.07C11.77,15.31 11.61,14.17 12.04,13.24L11.58,12.79L10.41,13.95L8.09,11.62L6.67,13.04L8.79,15.16L6.67,17.28L1,11.62L3.14,9.5L5.26,11.62L6.67,10.21L3.84,7.38C3.06,6.6 3.06,5.33 3.84,4.55L4.55,3.84C5.33,3.06 6.6,3.06 7.38,3.84L10.21,6.67L11.62,5.26L9.5,3.14L11.62,1M18,14A4,4 0 0,1 14,18V16A2,2 0 0,0 16,14H18M22,14A8,8 0 0,1 14,22V20A6,6 0 0,0 20,14H22Z\";\r\nvar mdiSausage = \"M3.5,3H9.5L7.96,5.32C9.16,5.87 10,7.09 10,8.5A5.5,5.5 0 0,0 15.5,14C16.91,14 18.13,14.84 18.68,16.04L21,14.5V20.5L18.68,18.96C18.13,20.16 16.91,21 15.5,21A12.5,12.5 0 0,1 3,8.5C3,7.09 3.84,5.87 5.04,5.32L3.5,3Z\";\r\nvar mdiSawBlade = \"M20,15C20,15 18.6,16.3 21.1,17L18.3,19.8H15.5C15.5,19.8 13.6,19.7 15,22H11L9,20C9,20 7.7,18.6 7,21.1L4.2,18.3V15.5C4.2,15.5 4.3,13.6 2,15V11L4,9C4,9 5.4,7.7 2.8,7.1L5.6,4.2H8.5C8.5,4.2 10.4,4.3 9,2H13L15,4C15,4 16.3,5.4 17,2.8L19.8,5.6V8.5C19.8,8.5 19.7,10.4 22,9V13L20,15M14,12A2,2 0 0,0 12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12Z\";\r\nvar mdiSawtoothWave = \"M11 22V6.83L2 16V13.17L13 2V17.17L22 8V10.83L11 22Z\";\r\nvar mdiSaxophone = \"M4,2A1,1 0 0,0 3,3A1,1 0 0,0 4,4A3,3 0 0,1 7,7V8.66L7,15.5C7,19.1 9.9,22 13.5,22C17.1,22 20,19.1 20,15.5V13A1,1 0 0,0 21,12A1,1 0 0,0 20,11H14A1,1 0 0,0 13,12A1,1 0 0,0 14,13V15A1,1 0 0,1 13,16A1,1 0 0,1 12,15V11A1,1 0 0,0 13,10A1,1 0 0,0 12,9V8A1,1 0 0,0 13,7A1,1 0 0,0 12,6V5.5A3.5,3.5 0 0,0 8.5,2H4Z\";\r\nvar mdiScale = \"M8.46,15.06L7.05,16.47L5.68,15.1C4.82,16.21 4.24,17.54 4.06,19H6V21H2V20C2,15.16 5.44,11.13 10,10.2V8.2L2,5V3H22V5L14,8.2V10.2C18.56,11.13 22,15.16 22,20V21H18V19H19.94C19.76,17.54 19.18,16.21 18.32,15.1L16.95,16.47L15.54,15.06L16.91,13.68C15.8,12.82 14.46,12.24 13,12.06V14H11V12.06C9.54,12.24 8.2,12.82 7.09,13.68L8.46,15.06M12,18A2,2 0 0,1 14,20A2,2 0 0,1 12,22C11.68,22 11.38,21.93 11.12,21.79L7.27,20L11.12,18.21C11.38,18.07 11.68,18 12,18Z\";\r\nvar mdiScaleBalance = \"M12,3C10.73,3 9.6,3.8 9.18,5H3V7H4.95L2,14C1.53,16 3,17 5.5,17C8,17 9.56,16 9,14L6.05,7H9.17C9.5,7.85 10.15,8.5 11,8.83V20H2V22H22V20H13V8.82C13.85,8.5 14.5,7.85 14.82,7H17.95L15,14C14.53,16 16,17 18.5,17C21,17 22.56,16 22,14L19.05,7H21V5H14.83C14.4,3.8 13.27,3 12,3M12,5A1,1 0 0,1 13,6A1,1 0 0,1 12,7A1,1 0 0,1 11,6A1,1 0 0,1 12,5M5.5,10.25L7,14H4L5.5,10.25M18.5,10.25L20,14H17L18.5,10.25Z\";\r\nvar mdiScaleBathroom = \"M5,2H19A2,2 0 0,1 21,4V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V4A2,2 0 0,1 5,2M12,4A4,4 0 0,0 8,8H11.26L10.85,5.23L12.9,8H16A4,4 0 0,0 12,4M5,10V20H19V10H5Z\";\r\nvar mdiScaleOff = \"M22.11 21.46L20.84 22.73L19.11 21H18V19.89L12.11 14H11V12.89L10.31 12.2A7.92 7.92 0 0 0 7.09 13.68L8.46 15.06L7.05 16.47L5.68 15.1A7.94 7.94 0 0 0 4.06 19H6V21H2V20A10 10 0 0 1 8.68 10.57L3.85 5.74L2 5V3.89L1.11 3L2.39 1.73M21.91 18.71A10 10 0 0 0 14 10.2V8.2L22 5V3H6.2M12 18A1.84 1.84 0 0 0 11.12 18.21L7.27 20L11.12 21.79A1.84 1.84 0 0 0 12 22A2 2 0 0 0 12 18Z\";\r\nvar mdiScanHelper = \"M0 2A2 2 0 0 1 2 0H6V2H2V6H0V2M24 22A2 2 0 0 1 22 24H18V22H22V18H24V22M2 24A2 2 0 0 1 0 22V18H2V22H6V24H2M22 0A2 2 0 0 1 24 2V6H22V2H18V0H22Z\";\r\nvar mdiScanner = \"M4.2,10.7L19.8,5L20.5,6.9L6.4,12H19A2,2 0 0,1 21,14V18A2,2 0 0,1 19,20H5A2,2 0 0,1 3,18V12.5C3,11.7 3.5,10.9 4.2,10.7M17,17H19V15H17V17M5,17H15V15H5V17Z\";\r\nvar mdiScannerOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L16.73,20H5A2,2 0 0,1 3,18V12.5C3,11.7 3.5,10.9 4.2,10.7L6.57,9.84L2,5.27M6.4,12H8.73L8.11,11.38L6.4,12M5,15V17H13.73L11.73,15H5M19.8,5L20.5,6.9L11.85,10.03L10.3,8.47L19.8,5M19,12A2,2 0 0,1 21,14V18C21,18.34 20.91,18.66 20.76,18.94L19,17.18V15H16.82L13.82,12H19Z\";\r\nvar mdiScatterPlot = \"M7,11A3,3 0 0,1 10,14A3,3 0 0,1 7,17A3,3 0 0,1 4,14A3,3 0 0,1 7,11M11,3A3,3 0 0,1 14,6A3,3 0 0,1 11,9A3,3 0 0,1 8,6A3,3 0 0,1 11,3M16.6,14.6C18.25,14.6 19.6,15.94 19.6,17.6A3,3 0 0,1 16.6,20.6C14.94,20.6 13.6,19.25 13.6,17.6A3,3 0 0,1 16.6,14.6Z\";\r\nvar mdiScatterPlotOutline = \"M7,18A4,4 0 0,1 3,14A4,4 0 0,1 7,10A4,4 0 0,1 11,14A4,4 0 0,1 7,18M7,12A2,2 0 0,0 5,14A2,2 0 0,0 7,16A2,2 0 0,0 9,14A2,2 0 0,0 7,12M11,10A4,4 0 0,1 7,6A4,4 0 0,1 11,2A4,4 0 0,1 15,6A4,4 0 0,1 11,10M11,4A2,2 0 0,0 9,6A2,2 0 0,0 11,8A2,2 0 0,0 13,6A2,2 0 0,0 11,4M16.6,21.6C14.39,21.6 12.6,19.81 12.6,17.6A4,4 0 0,1 16.6,13.6C18.81,13.6 20.6,15.39 20.6,17.6A4,4 0 0,1 16.6,21.6M16.6,15.6A2,2 0 0,0 14.6,17.6C14.6,18.7 15.5,19.6 16.6,19.6A2,2 0 0,0 18.6,17.6C18.6,16.5 17.7,15.6 16.6,15.6Z\";\r\nvar mdiSchool = \"M12,3L1,9L12,15L21,10.09V17H23V9M5,13.18V17.18L12,21L19,17.18V13.18L12,17L5,13.18Z\";\r\nvar mdiSchoolOutline = \"M12 3L1 9L5 11.18V17.18L12 21L19 17.18V11.18L21 10.09V17H23V9L12 3M18.82 9L12 12.72L5.18 9L12 5.28L18.82 9M17 16L12 18.72L7 16V12.27L12 15L17 12.27V16Z\";\r\nvar mdiScissorsCutting = \"M11,21H7V19H11V21M15.5,19H17V21H13V19H13.2L11.8,12.9L9.3,13.5C9.2,14 9,14.4 8.8,14.8C7.9,16.3 6,16.7 4.5,15.8C3,14.9 2.6,13 3.5,11.5C4.4,10 6.3,9.6 7.8,10.5C8.2,10.7 8.5,11.1 8.7,11.4L11.2,10.8L10.6,8.3C10.2,8.2 9.8,8 9.4,7.8C8,6.9 7.5,5 8.4,3.5C9.3,2 11.2,1.6 12.7,2.5C14.2,3.4 14.6,5.3 13.7,6.8C13.5,7.2 13.1,7.5 12.8,7.7L15.5,19M7,11.8C6.3,11.3 5.3,11.6 4.8,12.3C4.3,13 4.6,14 5.3,14.4C6,14.9 7,14.7 7.5,13.9C7.9,13.2 7.7,12.2 7,11.8M12.4,6C12.9,5.3 12.6,4.3 11.9,3.8C11.2,3.3 10.2,3.6 9.7,4.3C9.3,5 9.5,6 10.3,6.5C11,6.9 12,6.7 12.4,6M12.8,11.3C12.6,11.2 12.4,11.2 12.3,11.4C12.2,11.6 12.2,11.8 12.4,11.9C12.6,12 12.8,12 12.9,11.8C13.1,11.6 13,11.4 12.8,11.3M21,8.5L14.5,10L15,12.2L22.5,10.4L23,9.7L21,8.5M23,19H19V21H23V19M5,19H1V21H5V19Z\";\r\nvar mdiScooter = \"M7.82 19H15V18C15 15.79 16.79 14 19 14H19.74L17.84 5.56C17.63 4.65 16.82 4 15.89 4H12V6H15.89L17.29 12.25H17.28C15.12 12.9 13.47 14.73 13.09 17H7.82C7.34 15.66 5.96 14.76 4.4 15.06C3.22 15.29 2.27 16.26 2.05 17.44C1.7 19.34 3.16 21 5 21C6.3 21 7.4 20.16 7.82 19M5 19C4.45 19 4 18.55 4 18S4.45 17 5 17 6 17.45 6 18 5.55 19 5 19M19 15C17.34 15 16 16.34 16 18S17.34 21 19 21 22 19.66 22 18 20.66 15 19 15M19 19C18.45 19 18 18.55 18 18S18.45 17 19 17 20 17.45 20 18 19.55 19 19 19Z\";\r\nvar mdiScooterElectric = \"M7.82 16H15V15C15 12.79 16.79 11 19 11H19.74L17.84 2.56C17.63 1.65 16.82 1 15.89 1H12V3H15.89L17.29 9.25H17.28C15.12 9.9 13.47 11.73 13.09 14H7.82C7.34 12.66 5.96 11.76 4.4 12.06C3.22 12.29 2.27 13.26 2.05 14.44C1.7 16.34 3.16 18 5 18C6.3 18 7.4 17.16 7.82 16M5 16C4.45 16 4 15.55 4 15S4.45 14 5 14 6 14.45 6 15 5.55 16 5 16M19 12C17.34 12 16 13.34 16 15S17.34 18 19 18 22 16.66 22 15 20.66 12 19 12M19 16C18.45 16 18 15.55 18 15S18.45 14 19 14 20 14.45 20 15 19.55 16 19 16M11 20H7L13 23V21H17L11 18V20Z\";\r\nvar mdiScoreboard = \"M6 9H8V15H6V9M16 9H18V15H16V9M21 3C22.1 3 23 3.9 23 5V19C23 20.1 22.1 21 21 21H3C1.9 21 1 20.1 1 19V5C1 3.9 1.9 3 3 3H21M5 7C4.4 7 4 7.4 4 8V16C4 16.6 4.4 17 5 17H9C9.6 17 10 16.6 10 16V8C10 7.4 9.6 7 9 7H5M15 7C14.4 7 14 7.4 14 8V16C14 16.6 14.4 17 15 17H19C19.6 17 20 16.6 20 16V8C20 7.4 19.6 7 19 7H15M12 11C12.6 11 13 10.6 13 10C13 9.4 12.6 9 12 9C11.4 9 11 9.4 11 10C11 10.6 11.4 11 12 11M12 15C12.6 15 13 14.6 13 14C13 13.4 12.6 13 12 13C11.4 13 11 13.4 11 14C11 14.6 11.4 15 12 15Z\";\r\nvar mdiScoreboardOutline = \"M21 3H3C1.9 3 1 3.9 1 5V19C1 20.1 1.9 21 3 21H21C22.1 21 23 20.1 23 19V5C23 3.9 22.1 3 21 3M21 19H3V5H21M5 7H9C9.6 7 10 7.4 10 8V16C10 16.6 9.6 17 9 17H5C4.4 17 4 16.6 4 16V8C4 7.4 4.4 7 5 7M6 9V15H8V9M15 7H19C19.6 7 20 7.4 20 8V16C20 16.6 19.6 17 19 17H15C14.4 17 14 16.6 14 16V8C14 7.4 14.4 7 15 7M16 9V15H18V9M12 11C12.6 11 13 10.6 13 10C13 9.4 12.6 9 12 9C11.4 9 11 9.4 11 10C11 10.6 11.4 11 12 11M12 15C12.6 15 13 14.6 13 14C13 13.4 12.6 13 12 13C11.4 13 11 13.4 11 14C11 14.6 11.4 15 12 15Z\";\r\nvar mdiScreenRotation = \"M7.5,21.5C4.25,19.94 1.91,16.76 1.55,13H0.05C0.56,19.16 5.71,24 12,24L12.66,23.97L8.85,20.16M14.83,21.19L2.81,9.17L9.17,2.81L21.19,14.83M10.23,1.75C9.64,1.16 8.69,1.16 8.11,1.75L1.75,8.11C1.16,8.7 1.16,9.65 1.75,10.23L13.77,22.25C14.36,22.84 15.31,22.84 15.89,22.25L22.25,15.89C22.84,15.3 22.84,14.35 22.25,13.77L10.23,1.75M16.5,2.5C19.75,4.07 22.09,7.24 22.45,11H23.95C23.44,4.84 18.29,0 12,0L11.34,0.03L15.15,3.84L16.5,2.5Z\";\r\nvar mdiScreenRotationLock = \"M16.8,2.5C16.8,1.56 17.56,0.8 18.5,0.8C19.44,0.8 20.2,1.56 20.2,2.5V3H16.8V2.5M16,9H21A1,1 0 0,0 22,8V4A1,1 0 0,0 21,3V2.5A2.5,2.5 0 0,0 18.5,0A2.5,2.5 0 0,0 16,2.5V3A1,1 0 0,0 15,4V8A1,1 0 0,0 16,9M8.47,20.5C5.2,18.94 2.86,15.76 2.5,12H1C1.5,18.16 6.66,23 12.95,23L13.61,22.97L9.8,19.15L8.47,20.5M23.25,12.77L20.68,10.2L19.27,11.61L21.5,13.83L15.83,19.5L4.5,8.17L10.17,2.5L12.27,4.61L13.68,3.2L11.23,0.75C10.64,0.16 9.69,0.16 9.11,0.75L2.75,7.11C2.16,7.7 2.16,8.65 2.75,9.23L14.77,21.25C15.36,21.84 16.31,21.84 16.89,21.25L23.25,14.89C23.84,14.3 23.84,13.35 23.25,12.77Z\";\r\nvar mdiScrewFlatTop = \"M13.5,17V19L12,22L10.5,19L13.5,17M14.5,6.3L13.5,7V6H10.5V9L9.5,9.7V10.7L14.5,7.4V6.3M14.5,10.3L13.5,11V9L10.5,11V13L9.5,13.7V14.7L14.5,11.4V10.3M14.5,14.3L13.5,15V13L10.5,15V17L9.5,17.7V18.7L14.5,15.4V14.3M8,2C8,2 7,2 7,3L10,5H14L17,3C17,3 17,2 16,2C15,2 8,2 8,2Z\";\r\nvar mdiScrewLag = \"M10,19.3L14,16.6V20L12,22L10,20V19.3M14,12.7L10,15.4V17.4L9,18V19L15,15.1V14L14,14.7V12.7M7,2V5H17V2H7M9,6V9L10,9.7V13.4L9,14V15L15,11.1V10L14,10.7C14,10.7 14,10.3 14,9.7L15,9V6H9Z\";\r\nvar mdiScrewMachineFlatTop = \"M14.5,7.3L13.5,8V7H10.5V10L9.5,10.7V11.7L14.5,8.4V7.3M14.5,11.3L13.5,12V10L10.5,12V14L9.5,14.7V15.7L14.5,12.4V11.3M14.5,15.3L13.5,16V14L10.5,16V18L9.5,18.7V19.7L14.5,16.4V15.3M8,3C8,3 7,3 7,4L10,6H14L17,4C17,4 17,3 16,3C15,3 8,3 8,3M13.5,18V21H10.5V20L13.5,18Z\";\r\nvar mdiScrewMachineRoundTop = \"M14.5,7.3L13.5,8V7H10.5V10L9.5,10.7V11.7L14.5,8.4V7.3M14.5,11.3L13.5,12V10L10.5,12V14L9.5,14.7V15.7L14.5,12.4V11.3M14.5,15.3L13.5,16V14L10.5,16V18L9.5,18.7V19.7L14.5,16.4V15.3M7,6H17C17,6 16,3 12,3C8,3 7,6 7,6M13.5,18V21H10.5V20L13.5,18Z\";\r\nvar mdiScrewRoundTop = \"M13.5,17V19L12,22L10.5,19L13.5,17M14.5,6.3L13.5,7V6H10.5V9L9.5,9.7V10.7L14.5,7.4V6.3M14.5,10.3L13.5,11V9L10.5,11V13L9.5,13.7V14.7L14.5,11.4V10.3M14.5,14.3L13.5,15V13L10.5,15V17L9.5,17.7V18.7L14.5,15.4V14.3M7,5H17C17,5 16,2 12,2C8,2 7,5 7,5Z\";\r\nvar mdiScrewdriver = \"M18,1.83C17.5,1.83 17,2 16.59,2.41C13.72,5.28 8,11 8,11L9.5,12.5L6,16H4L2,20L4,22L8,20V18L11.5,14.5L13,16C13,16 18.72,10.28 21.59,7.41C22.21,6.5 22.37,5.37 21.59,4.59L19.41,2.41C19,2 18.5,1.83 18,1.83M18,4L20,6L13,13L11,11L18,4Z\";\r\nvar mdiScript = \"M17.8,20C17.4,21.2 16.3,22 15,22H5C3.3,22 2,20.7 2,19V18H5L14.2,18C14.6,19.2 15.7,20 17,20H17.8M19,2H8C6.3,2 5,3.3 5,5V16H16V17C16,17.6 16.4,18 17,18H18V5C18,4.4 18.4,4 19,4C19.6,4 20,4.4 20,5V6H22V5C22,3.3 20.7,2 19,2Z\";\r\nvar mdiScriptOutline = \"M15,20A1,1 0 0,0 16,19V4H8A1,1 0 0,0 7,5V16H5V5A3,3 0 0,1 8,2H19A3,3 0 0,1 22,5V6H20V5A1,1 0 0,0 19,4A1,1 0 0,0 18,5V9L18,19A3,3 0 0,1 15,22H5A3,3 0 0,1 2,19V18H13A2,2 0 0,0 15,20Z\";\r\nvar mdiScriptText = \"M17.8,20C17.4,21.2 16.3,22 15,22H5C3.3,22 2,20.7 2,19V18H5L14.2,18C14.6,19.2 15.7,20 17,20H17.8M19,2C20.7,2 22,3.3 22,5V6H20V5C20,4.4 19.6,4 19,4C18.4,4 18,4.4 18,5V18H17C16.4,18 16,17.6 16,17V16H5V5C5,3.3 6.3,2 8,2H19M8,6V8H15V6H8M8,10V12H14V10H8Z\";\r\nvar mdiScriptTextOutline = \"M15,20A1,1 0 0,0 16,19V4H8A1,1 0 0,0 7,5V16H5V5A3,3 0 0,1 8,2H19A3,3 0 0,1 22,5V6H20V5A1,1 0 0,0 19,4A1,1 0 0,0 18,5V9L18,19A3,3 0 0,1 15,22H5A3,3 0 0,1 2,19V18H13A2,2 0 0,0 15,20M9,6H14V8H9V6M9,10H14V12H9V10M9,14H14V16H9V14Z\";\r\nvar mdiSd = \"M18,8H16V4H18M15,8H13V4H15M12,8H10V4H12M18,2H10L4,8V20A2,2 0 0,0 6,22H18A2,2 0 0,0 20,20V4A2,2 0 0,0 18,2Z\";\r\nvar mdiSeal = \"M20.39,19.37L16.38,18L15,22L11.92,16L9,22L7.62,18L3.61,19.37L6.53,13.37C5.57,12.17 5,10.65 5,9A7,7 0 0,1 12,2A7,7 0 0,1 19,9C19,10.65 18.43,12.17 17.47,13.37L20.39,19.37M7,9L9.69,10.34L9.5,13.34L12,11.68L14.5,13.33L14.33,10.34L17,9L14.32,7.65L14.5,4.67L12,6.31L9.5,4.65L9.67,7.66L7,9Z\";\r\nvar mdiSealVariant = \"M17.71 6.15C17.46 5.38 16.79 5.21 16.45 4.77C16.14 4.31 16.18 3.62 15.53 3.15S14.23 2.92 13.7 2.77 12.81 2 12 2 10.82 2.58 10.3 2.77 9.13 2.67 8.47 3.15 7.86 4.31 7.55 4.77C7.21 5.21 6.55 5.38 6.29 6.15S6.5 7.45 6.5 8 6 9.08 6.29 9.85 7.21 10.79 7.55 11.23C7.86 11.69 7.82 12.38 8.47 12.85S9.77 13.08 10.3 13.23 11.19 14 12 14 13.18 13.42 13.7 13.23 14.87 13.33 15.53 12.85 16.14 11.69 16.45 11.23C16.79 10.79 17.45 10.62 17.71 9.85S17.5 8.55 17.5 8 18 6.92 17.71 6.15M12 12A4 4 0 1 1 16 8A4 4 0 0 1 12 12M14 8A2 2 0 1 1 12 6A2 2 0 0 1 14 8M13.71 15.56L13.08 19.16L12.35 23.29L9.74 20.8L6.44 22.25L7.77 14.75A4 4 0 0 0 9.66 15.17A4.15 4.15 0 0 0 11 15.85A3.32 3.32 0 0 0 12 16A3.5 3.5 0 0 0 13.71 15.56M17.92 18.78L15.34 17.86L15.85 14.92A3.2 3.2 0 0 0 16.7 14.47L16.82 14.37Z\";\r\nvar mdiSearchWeb = \"M15.5,14L20.5,19L19,20.5L14,15.5V14.71L13.73,14.43C12.59,15.41 11.11,16 9.5,16A6.5,6.5 0 0,1 3,9.5A6.5,6.5 0 0,1 9.5,3A6.5,6.5 0 0,1 16,9.5C16,11.11 15.41,12.59 14.43,13.73L14.71,14H15.5M9.5,4.5L8.95,4.53C8.71,5.05 8.34,5.93 8.07,7H10.93C10.66,5.93 10.29,5.05 10.05,4.53C9.87,4.5 9.69,4.5 9.5,4.5M13.83,7C13.24,5.97 12.29,5.17 11.15,4.78C11.39,5.31 11.7,6.08 11.93,7H13.83M5.17,7H7.07C7.3,6.08 7.61,5.31 7.85,4.78C6.71,5.17 5.76,5.97 5.17,7M4.5,9.5C4.5,10 4.58,10.53 4.73,11H6.87L6.75,9.5L6.87,8H4.73C4.58,8.47 4.5,9 4.5,9.5M14.27,11C14.42,10.53 14.5,10 14.5,9.5C14.5,9 14.42,8.47 14.27,8H12.13C12.21,8.5 12.25,9 12.25,9.5C12.25,10 12.21,10.5 12.13,11H14.27M7.87,8L7.75,9.5L7.87,11H11.13C11.21,10.5 11.25,10 11.25,9.5C11.25,9 11.21,8.5 11.13,8H7.87M9.5,14.5C9.68,14.5 9.86,14.5 10.03,14.47C10.28,13.95 10.66,13.07 10.93,12H8.07C8.34,13.07 8.72,13.95 8.97,14.47L9.5,14.5M13.83,12H11.93C11.7,12.92 11.39,13.69 11.15,14.22C12.29,13.83 13.24,13.03 13.83,12M5.17,12C5.76,13.03 6.71,13.83 7.85,14.22C7.61,13.69 7.3,12.92 7.07,12H5.17Z\";\r\nvar mdiSeat = \"M4,18V21H7V18H17V21H20V15H4V18M19,10H22V13H19V10M2,10H5V13H2V10M17,13H7V5A2,2 0 0,1 9,3H15A2,2 0 0,1 17,5V13Z\";\r\nvar mdiSeatFlat = \"M22,11V13H9V7H18A4,4 0 0,1 22,11M2,14V16H8V18H16V16H22V14M7.14,12.1C8.3,10.91 8.28,9 7.1,7.86C5.91,6.7 4,6.72 2.86,7.9C1.7,9.09 1.72,11 2.9,12.14C4.09,13.3 6,13.28 7.14,12.1Z\";\r\nvar mdiSeatFlatAngled = \"M22.25,14.29L21.56,16.18L9.2,11.71L11.28,6.05L19.84,9.14C21.94,9.9 23,12.2 22.25,14.29M1.5,12.14L8,14.5V19H16V17.37L20.5,19L21.21,17.11L2.19,10.25M7.3,10.2C8.79,9.5 9.42,7.69 8.71,6.2C8,4.71 6.2,4.08 4.7,4.8C3.21,5.5 2.58,7.3 3.3,8.8C4,10.29 5.8,10.92 7.3,10.2Z\";\r\nvar mdiSeatIndividualSuite = \"M7,13A3,3 0 0,0 10,10A3,3 0 0,0 7,7A3,3 0 0,0 4,10A3,3 0 0,0 7,13M19,7H11V14H3V7H1V17H23V11A4,4 0 0,0 19,7Z\";\r\nvar mdiSeatLegroomExtra = \"M4,12V3H2V12A5,5 0 0,0 7,17H13V15H7A3,3 0 0,1 4,12M22.83,17.24C22.45,16.5 21.54,16.27 20.8,16.61L19.71,17.11L16.3,10.13C15.96,9.45 15.27,9 14.5,9H11V3H5V11A3,3 0 0,0 8,14H15L18.41,21L22.13,19.3C22.9,18.94 23.23,18 22.83,17.24Z\";\r\nvar mdiSeatLegroomNormal = \"M5,12V3H3V12A5,5 0 0,0 8,17H14V15H8A3,3 0 0,1 5,12M20.5,18H19V11A2,2 0 0,0 17,9H12V3H6V11A3,3 0 0,0 9,14H16V21H20.5A1.5,1.5 0 0,0 22,19.5A1.5,1.5 0 0,0 20.5,18Z\";\r\nvar mdiSeatLegroomReduced = \"M19.97,19.2C20.15,20.16 19.42,21 18.5,21H14V18L15,14H9A3,3 0 0,1 6,11V3H12V9H17A2,2 0 0,1 19,11L17,18H18.44C19.17,18 19.83,18.5 19.97,19.2M5,12V3H3V12A5,5 0 0,0 8,17H12V15H8A3,3 0 0,1 5,12Z\";\r\nvar mdiSeatOutline = \"M15,5V12H9V5H15M15,3H9A2,2 0 0,0 7,5V14H17V5A2,2 0 0,0 15,3M22,10H19V13H22V10M5,10H2V13H5V10M20,15H4V21H6V17H18V21H20V15Z\";\r\nvar mdiSeatPassenger = \"M9 19H15V21H9C6.24 21 4 18.76 4 16V7H6V16C6 17.66 7.34 19 9 19M10.42 5.41C11.2 4.63 11.2 3.36 10.42 2.58C9.64 1.8 8.37 1.8 7.59 2.58C6.81 3.36 6.81 4.63 7.59 5.41C8.37 6.2 9.63 6.2 10.42 5.41M11.5 9C11.5 7.9 10.6 7 9.5 7H9C7.9 7 7 7.9 7 9V15C7 16.66 8.34 18 10 18H15.07L18.57 21.5L20 20.07L14.93 15H11.5L11.5 9Z\";\r\nvar mdiSeatReclineExtra = \"M5.35,5.64C4.45,5 4.23,3.76 4.86,2.85C5.5,1.95 6.74,1.73 7.65,2.36C8.55,3 8.77,4.24 8.14,5.15C7.5,6.05 6.26,6.27 5.35,5.64M16,19H8.93C7.45,19 6.19,17.92 5.97,16.46L4,7H2L4,16.76C4.37,19.2 6.47,21 8.94,21H16M16.23,15H11.35L10.32,10.9C11.9,11.79 13.6,12.44 15.47,12.12V10C13.84,10.3 12.03,9.72 10.78,8.74L9.14,7.47C8.91,7.29 8.65,7.17 8.38,7.09C8.06,7 7.72,6.97 7.39,7.03H7.37C6.14,7.25 5.32,8.42 5.53,9.64L6.88,15.56C7.16,17 8.39,18 9.83,18H16.68L20.5,21L22,19.5\";\r\nvar mdiSeatReclineNormal = \"M7.59,5.41C6.81,4.63 6.81,3.36 7.59,2.58C8.37,1.8 9.64,1.8 10.42,2.58C11.2,3.36 11.2,4.63 10.42,5.41C9.63,6.2 8.37,6.2 7.59,5.41M6,16V7H4V16A5,5 0 0,0 9,21H15V19H9A3,3 0 0,1 6,16M20,20.07L14.93,15H11.5V11.32C12.9,12.47 15.1,13.5 17,13.5V11.32C15.34,11.34 13.39,10.45 12.33,9.28L10.93,7.73C10.74,7.5 10.5,7.35 10.24,7.23C9.95,7.09 9.62,7 9.28,7H9.25C8,7 7,8 7,9.25V15A3,3 0 0,0 10,18H15.07L18.57,21.5\";\r\nvar mdiSeatbelt = \"M12,2C13.11,2 14,2.9 14,4C14,5.11 13.11,6 12,6A2,2 0 0,1 10,4A2,2 0 0,1 12,2M12.39,14.79C14.03,14.79 15.46,14.89 16.64,15.04C16.7,12.32 16.46,9.92 16,9C15.87,8.73 15.69,8.5 15.5,8.3L7.43,15.22C8.79,15 10.5,14.79 12.39,14.79M7.46,17C7.59,18.74 7.85,20.5 8.27,22H10.34C10.05,21.12 9.84,20.09 9.68,19C9.68,19 12,18.56 14.32,19C14.16,20.09 13.95,21.12 13.66,22H15.73C16.17,20.45 16.43,18.61 16.56,16.79C15.41,16.65 14,16.54 12.39,16.54C10.46,16.54 8.78,16.75 7.46,17M12,7C12,7 9,7 8,9C7.66,9.68 7.44,11.15 7.37,12.96L13.92,7.34C12.93,7 12,7 12,7M18.57,5.67L17.43,4.34L13.92,7.35C14.47,7.54 15.05,7.84 15.5,8.3L18.57,5.67M20.67,15.83C20.58,15.8 19.14,15.33 16.64,15.04C16.63,15.61 16.6,16.2 16.56,16.79C18.81,17.07 20.1,17.5 20.12,17.5L20.67,15.83M7.37,12.96L3.43,16.34L4.32,17.82C4.34,17.81 5.5,17.36 7.46,17C7.35,15.59 7.32,14.2 7.37,12.96Z\";\r\nvar mdiSecurity = \"M12,12H19C18.47,16.11 15.72,19.78 12,20.92V12H5V6.3L12,3.19M12,1L3,5V11C3,16.55 6.84,21.73 12,23C17.16,21.73 21,16.55 21,11V5L12,1Z\";\r\nvar mdiSecurityNetwork = \"M13,19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17.34C8.07,16.13 6,13 6,9.67V5.67L12,3L18,5.67V9.67C18,13 15.93,16.13 13,17.34V19M12,5L8,6.69V10H12V5M12,10V16C13.91,15.53 16,13.06 16,11V10H12Z\";\r\nvar mdiSeed = \"M20.7,3.3C20.7,3.3 19.3,3 17.2,3C11.7,3 1.6,5.1 3.2,20.8C4.3,20.9 5.4,21 6.4,21C24.3,21 20.7,3.3 20.7,3.3M7,17C7,17 7,7 17,7C17,7 11,9 7,17Z\";\r\nvar mdiSeedOff = \"M22.1 21.5L2.4 1.7L1.1 3L5.9 7.8C3.8 10.5 2.6 14.6 3.2 20.8C4.3 20.9 5.4 21 6.4 21C10.9 21 14.1 19.9 16.3 18.2L20.9 22.8L22.1 21.5M7 17C7 17 7 13.7 8.9 10.8L10.2 12.1C9.1 13.4 8 15 7 17M11.6 8.4L8.5 5.3C11.3 3.4 14.7 3 17.2 3C19.3 3 20.7 3.3 20.7 3.3S22.1 10.3 18.7 15.5L12.8 9.6C15.1 7.6 17 7 17 7C14.7 7 12.9 7.5 11.6 8.4Z\";\r\nvar mdiSeedOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L5.9 7.8C3.8 10.5 2.6 14.6 3.2 20.8C4.3 20.9 5.4 21 6.4 21C10.9 21 14.1 19.9 16.3 18.2L20.9 22.8L22.1 21.5M6.4 19H5.1C4.9 14.8 5.6 11.5 7.3 9.2L8.9 10.8C7 13.7 7 17 7 17C8 15 9.1 13.4 10.2 12.1L14.8 16.7C12.8 18.2 10 19 6.4 19M10 6.8L8.5 5.3C11.3 3.4 14.7 3 17.2 3C19.3 3 20.7 3.3 20.7 3.3S22.1 10.3 18.7 15.5L17.2 14C19.1 10.9 19 7.1 18.9 5.1C18.4 5 17.8 5 17.2 5C15.1 5 12.3 5.3 10 6.8M12.8 9.6L11.6 8.4C12.9 7.5 14.7 7 17 7C17 7 15.1 7.6 12.8 9.6Z\";\r\nvar mdiSeedOutline = \"M17.2,5V5C17.8,5 18.4,5 18.9,5.1C19.1,7.4 19.1,12 16.4,15.2C14.4,17.7 11,19 6.4,19C6,19 5.5,19 5.1,19C4.9,14.4 5.8,10.8 7.9,8.5C10.4,5.6 14.4,5 17.2,5M17.2,3C11.7,3 1.6,5.1 3.2,20.8C4.3,20.9 5.4,21 6.4,21C24.3,21 20.7,3.3 20.7,3.3C20.7,3.3 19.3,3 17.2,3M17,7C7,7 7,17 7,17C11,9 17,7 17,7Z\";\r\nvar mdiSeesaw = \"M21.68 13.26L22.04 15.23L2.35 18.77L2 16.8L4.95 16.27L4.6 14.3C4.5 13.76 4.86 13.24 5.41 13.14C5.95 13.04 6.47 13.4 6.57 13.95L6.92 15.91L16.76 14.15L16.41 12.18C16.31 11.63 16.67 11.11 17.22 11C17.76 10.92 18.28 11.28 18.38 11.82L18.73 13.79L21.68 13.26M10.06 18.4L8 22H16L13.58 17.77L10.06 18.4Z\";\r\nvar mdiSegment = \"M21,8H3V6H21M9,13H21V11H9M9,18H21V16H9\";\r\nvar mdiSelect = \"M4,3H5V5H3V4A1,1 0 0,1 4,3M20,3A1,1 0 0,1 21,4V5H19V3H20M15,5V3H17V5H15M11,5V3H13V5H11M7,5V3H9V5H7M21,20A1,1 0 0,1 20,21H19V19H21V20M15,21V19H17V21H15M11,21V19H13V21H11M7,21V19H9V21H7M4,21A1,1 0 0,1 3,20V19H5V21H4M3,15H5V17H3V15M21,15V17H19V15H21M3,11H5V13H3V11M21,11V13H19V11H21M3,7H5V9H3V7M21,7V9H19V7H21Z\";\r\nvar mdiSelectAll = \"M9,9H15V15H9M7,17H17V7H7M15,5H17V3H15M15,21H17V19H15M19,17H21V15H19M19,9H21V7H19M19,21A2,2 0 0,0 21,19H19M19,13H21V11H19M11,21H13V19H11M9,3H7V5H9M3,17H5V15H3M5,21V19H3A2,2 0 0,0 5,21M19,3V5H21A2,2 0 0,0 19,3M13,3H11V5H13M3,9H5V7H3M7,21H9V19H7M3,13H5V11H3M3,5H5V3A2,2 0 0,0 3,5Z\";\r\nvar mdiSelectColor = \"M3.88,3C3.38,3.06 3,3.5 3,4V4L3,5H4L5,5V4L5,3H4L3.88,3M7,3V5H9V3H7M11,3V5H13V3H11M15,3V5H17V3H15M19,3V4L19,5H20L21,5V4L21,3.88C20.94,3.38 20.5,3 20,3H19M3,7V9H5V7H3M19,7V9H21V7H19M3,11V13H5V11H3M19.31,12C19.18,12 19.05,12.05 18.95,12.14L17.39,13.71L16.43,12.75L15.72,13.46L16.43,14.17L11.97,18.63V21H14.35L18.8,16.54L19.5,17.25L20.22,16.54L19.26,15.58L20.82,14.03C21,13.83 21,13.5 20.82,13.31L19.65,12.14C19.56,12.05 19.44,12 19.31,12M3,15V17H5V15H3M17,15L17.97,15.97L13.93,20L12.97,19.04L17,15M3,19V20L3,20.12C3.06,20.62 3.5,21 4,21V21H5V20L5,19H4L3,19M7,19V21H9V19H7Z\";\r\nvar mdiSelectCompare = \"M13,23H11V1H13V23M9,19H5V5H9V3H5C3.89,3 3,3.89 3,5V19C3,20.11 3.9,21 5,21H9V19M19,7V9H21V7H19M19,5H21C21,3.89 20.1,3 19,3V5M21,15H19V17H21V15M19,11V13H21V11H19M17,3H15V5H17V3M19,21C20.11,21 21,20.11 21,19H19V21M17,19H15V21H17V19Z\";\r\nvar mdiSelectDrag = \"M13,17H17V13H19V17H23V19H19V23H17V19H13V17M11,17V19H9V17H11M7,17V19H5V17H7M19,9V11H17V9H19M19,5V7H17V5H19M15,5V7H13V5H15M11,5V7H9V5H11M7,5V7H5V5H7M7,13V15H5V13H7M7,9V11H5V9H7Z\";\r\nvar mdiSelectGroup = \"M5 3A2 2 0 0 0 3 5H5M7 3V5H9V3M11 3V5H13V3M15 3V5H17V3M19 3V5H21A2 2 0 0 0 19 3M3 7V9H5V7M7 7V11H11V7M13 7V11H17V7M19 7V9H21V7M3 11V13H5V11M19 11V13H21V11M7 13V17H11V13M13 13V17H17V13M3 15V17H5V15M19 15V17H21V15M3 19A2 2 0 0 0 5 21V19M7 19V21H9V19M11 19V21H13V19M15 19V21H17V19M19 19V21A2 2 0 0 0 21 19Z\";\r\nvar mdiSelectInverse = \"M5,3H7V5H9V3H11V5H13V3H15V5H17V3H19V5H21V7H19V9H21V11H19V13H21V15H19V17H21V19H19V21H17V19H15V21H13V19H11V21H9V19H7V21H5V19H3V17H5V15H3V13H5V11H3V9H5V7H3V5H5V3Z\";\r\nvar mdiSelectMarker = \"M4 3H5V5H3V4C3 3.45 3.45 3 4 3M20 3C20.55 3 21 3.45 21 4V5H19V3H20M15 5V3H17V5H15M11 5V3H13V5H11M7 5V3H9V5H7M11 21V19H13V21H11M7 21V19H9V21H7M4 21C3.45 21 3 20.55 3 20V19H5V21H4M3 15H5V17H3V15M3 11H5V13H3V11M3 7H5V9H3V7M21 7V9H19V7H21M19.5 13C21.4 13 23 14.6 23 16.5C23 19.1 19.5 23 19.5 23C19.5 23 16 19.1 16 16.5C16 14.6 17.6 13 19.5 13M19.5 17.8C20.2 17.8 20.8 17.2 20.7 16.6C20.7 16 20.1 15.4 19.5 15.4C18.9 15.4 18.3 15.9 18.3 16.6C18.3 17.2 18.8 17.8 19.5 17.8Z\";\r\nvar mdiSelectMultiple = \"M18 12H20V14H18V12M14 16H16V18H14V16M20 17C20 17.55 19.55 18 19 18H18V16H20V17M7 4H8V6H6V5C6 4.45 6.45 4 7 4M19 4C19.55 4 20 4.45 20 5V6H18V4H19M14 6V4H16V6H14M10 6V4H12V6H10M10 18V16H12V18H10M7 18C6.45 18 6 17.55 6 17V16H8V18H7M6 12H8V14H6V12M6 8H8V10H6V8M20 8V10H18V8H20M3 8H4V20H16V21C16 21.54 15.57 22 15.03 22H15L3 22C2.45 22 2 21.55 2 21V9C2 8.45 2.45 8 3 8Z\";\r\nvar mdiSelectMultipleMarker = \"M7 4H8V6H6V5C6 4.45 6.45 4 7 4M19 4C19.55 4 20 4.45 20 5V6H18V4H19M14 6V4H16V6H14M10 6V4H12V6H10M10 18V16H12V18H10M7 18C6.45 18 6 17.55 6 17V16H8V18H7M6 12H8V14H6V12M6 8H8V10H6V8M20 8V10H18V8H20M3 8H4V20H14.58L16.03 22L3 22C2.45 22 2 21.55 2 21V9C2 8.45 2.45 8 3 8M18.5 12C20.4 12 22 13.6 22 15.5C22 18.1 18.5 22 18.5 22C18.5 22 15 18.1 15 15.5C15 13.6 16.6 12 18.5 12M18.5 16.8C19.2 16.8 19.8 16.2 19.7 15.6C19.7 15 19.1 14.4 18.5 14.4C17.9 14.4 17.3 14.9 17.3 15.6C17.3 16.2 17.8 16.8 18.5 16.8Z\";\r\nvar mdiSelectOff = \"M1,4.27L2.28,3L21,21.72L19.73,23L17,20.27V21H15V19H15.73L5,8.27V9H3V7H3.73L1,4.27M20,3A1,1 0 0,1 21,4V5H19V3H20M15,5V3H17V5H15M11,5V3H13V5H11M7,5V3H9V5H7M11,21V19H13V21H11M7,21V19H9V21H7M4,21A1,1 0 0,1 3,20V19H5V21H4M3,15H5V17H3V15M21,15V17H19V15H21M3,11H5V13H3V11M21,11V13H19V11H21M21,7V9H19V7H21Z\";\r\nvar mdiSelectPlace = \"M4 3H5V5H3V4C3 3.5 3.5 3 4 3M20 3C20.5 3 21 3.5 21 4V5H19V3H20M15 5V3H17V5H15M11 5V3H13V5H11M7 5V3H9V5H7M21 12C21 12.5 20.5 13 20 13H19V11H21V12M15 13V11H17V13H15M11 13V11H13V13H11M7 13V11H9V13H7M4 13C3.5 13 3 12.5 3 12V11H5V13H4M3 7H5V9H3V7M21 7V9H19V7H21M7 16L12 21L17 16H7Z\";\r\nvar mdiSelectSearch = \"M19.31 18.9C19.75 18.21 20 17.38 20 16.5C20 14 18 12 15.5 12S11 14 11 16.5 13 21 15.5 21C16.37 21 17.19 20.75 17.88 20.32L21 23.39L22.39 22L19.31 18.9M15.5 19C14.12 19 13 17.88 13 16.5S14.12 14 15.5 14 18 15.12 18 16.5 16.88 19 15.5 19M21 9H19V7H21V9M21 5H19V3H20C20.55 3 21 3.45 21 4V5M19 11.03V11H21V13H20.97C20.46 12.21 19.79 11.54 19 11.03M17 5H15V3H17V5M13 5H11V3H13V5M3 7H5V9H3V7M7 19H9V21H7V19M3 11H5V13H3V11M4 3H5V5H3V4C3 3.45 3.45 3 4 3M9 5H7V3H9V5M3 19H5V21H4C3.45 21 3 20.55 3 20V19M3 15H5V17H3V15Z\";\r\nvar mdiSelection = \"M2,4C2,2.89 2.9,2 4,2H7V4H4V7H2V4M22,4V7H20V4H17V2H20A2,2 0 0,1 22,4M20,20V17H22V20C22,21.11 21.1,22 20,22H17V20H20M2,20V17H4V20H7V22H4A2,2 0 0,1 2,20M10,2H14V4H10V2M10,20H14V22H10V20M20,10H22V14H20V10M2,10H4V14H2V10Z\";\r\nvar mdiSelectionDrag = \"M14,17H17V14H19V17H22V19H19V22H17V19H14V17M12,17V19H9V17H12M7,17V19H3V15H5V17H7M3,13V10H5V13H3M3,8V4H7V6H5V8H3M9,4H12V6H9V4M15,4H19V8H17V6H15V4M19,10V12H17V10H19Z\";\r\nvar mdiSelectionEllipse = \"M6.35,20.25L7.56,18.66C8.42,19.23 9.39,19.64 10.43,19.85L10.16,21.83C8.77,21.57 7.5,21 6.35,20.25M16.43,18.66L17.64,20.26C16.5,21.03 15.23,21.57 13.84,21.83L13.57,19.85C14.61,19.64 15.57,19.23 16.43,18.66M19.84,13.59L21.83,13.86C21.57,15.25 21,16.54 20.24,17.66L18.65,16.45C19.22,15.6 19.63,14.63 19.84,13.59M2.17,13.84L4.15,13.57C4.36,14.61 4.77,15.58 5.34,16.44L3.75,17.65C3,16.5 2.43,15.23 2.17,13.84M18.66,7.56L20.25,6.35C21.03,7.5 21.58,8.78 21.83,10.18L19.85,10.45C19.64,9.4 19.23,8.42 18.66,7.56M13.57,4.15L13.84,2.17C15.23,2.43 16.5,3 17.65,3.75L16.44,5.34C15.58,4.77 14.61,4.36 13.57,4.15M7.56,5.34L6.35,3.75C7.5,3 8.77,2.43 10.16,2.17L10.43,4.15C9.39,4.36 8.42,4.77 7.56,5.34M4.15,10.43L2.17,10.16C2.43,8.77 3,7.5 3.75,6.35L5.34,7.56C4.77,8.42 4.36,9.39 4.15,10.43Z\";\r\nvar mdiSelectionEllipseArrowInside = \"M11.2 4C9.94 4.12 8.72 4.53 7.64 5.2L6.64 3.47C7.95 2.64 9.45 2.13 11 2M17.53 6.25C16.62 5.39 15.53 4.73 14.34 4.33L15 2.39C16.5 2.84 17.89 3.66 19 4.78M5.34 7.41C4.64 8.44 4.19 9.6 4 10.83L2 10.55C2.2 9 2.79 7.5 3.7 6.23M22 12V12.66L20 12.5V12C20 10.92 19.81 9.86 19.39 8.86L21.22 8.06C21.75 9.31 22 10.65 22 12M6 17.3L4.5 18.61C3.47 17.43 2.72 16.04 2.3 14.53L4.17 14C4.53 15.22 5.16 16.35 6 17.3M12.14 22H12C10.5 22 9 21.68 7.64 21.07L8.53 19.24C9.62 19.75 10.8 20 12 20H12.19M17 21H15V15H21V17H18.42L21.14 19.76L19.73 21.17L17 18.5\";\r\nvar mdiSelectionMarker = \"M2 4C2 2.89 2.9 2 4 2H7V4H4V7H2V4M22 4V7H20V4H17V2H20C21.1 2 22 2.89 22 4M2 20V17H4V20H7V22H4C2.9 22 2 21.11 2 20M10 2H14V4H10V2M10 20H14V22H10V20M2 10H4V14H2V10M18.5 13C20.4 13 22 14.6 22 16.5C22 19.1 18.5 23 18.5 23C18.5 23 15 19.1 15 16.5C15 14.6 16.6 13 18.5 13M18.5 17.8C19.2 17.8 19.8 17.2 19.7 16.6C19.7 16 19.1 15.4 18.5 15.4C17.9 15.4 17.3 15.9 17.3 16.6C17.3 17.2 17.8 17.8 18.5 17.8M20 10H22V12.34C21.42 11.84 20.74 11.45 20 11.23V10Z\";\r\nvar mdiSelectionMultiple = \"M11 6V4H15V6H11M6 9H8V13H6V9M6 6C6 4.89 6.9 4 8 4H9V6H8V7H6V6M8 18C6.89 18 6 17.1 6 16V15H8V16H9V18H8M18 4C19.11 4 20 4.9 20 6V7H18V6H17V4H18M15 16V18H11V16H15M20 13H18V9H20V13M20 16C20 17.11 19.1 18 18 18H17V16H18V15H20V16M3 8H4V20H16V21C16 21.54 15.57 22 15.03 22H15L3 22C2.45 22 2 21.55 2 21V9C2 8.45 2.45 8 3 8Z\";\r\nvar mdiSelectionMultipleMarker = \"M7 4H9V6H8V7H6V5C6 4.45 6.45 4 7 4M19 4C19.55 4 20 4.45 20 5V7H18V6H17V4H19M11 6V4H15V6H11M7 18C6.45 18 6 17.55 6 17V15H8V16H9V18H7M6 9H8V13H6V9M3 8H4V20H14.58L16.03 22L3 22C2.45 22 2 21.55 2 21V9C2 8.45 2.45 8 3 8M18.5 12C20.4 12 22 13.6 22 15.5C22 18.1 18.5 22 18.5 22C18.5 22 15 18.1 15 15.5C15 13.6 16.6 12 18.5 12M18.5 16.8C19.2 16.8 19.8 16.2 19.7 15.6C19.7 15 19.1 14.4 18.5 14.4C17.9 14.4 17.3 14.9 17.3 15.6C17.3 16.2 17.8 16.8 18.5 16.8M11 18V16H13C13.09 16.66 13.27 17.33 13.5 18H11M20 9V10.23C19.5 10.08 19 10 18.5 10L18 10.03V9H20Z\";\r\nvar mdiSelectionOff = \"M0.5,3.77L1.78,2.5L21.5,22.22L20.23,23.5L18.73,22H17V20.27L3.73,7H2V5.27L0.5,3.77M4,2H7V4H5.82L3.83,2H4M22,4V7H20V4H17V2H20A2,2 0 0,1 22,4M20,17H22V20L22,20.17L20,18.18V17M2,20V17H4V20H7V22H4A2,2 0 0,1 2,20M10,2H14V4H10V2M10,20H14V22H10V20M20,10H22V14H20V10M2,10H4V14H2V10Z\";\r\nvar mdiSelectionSearch = \"M19.27 18.9C19.7 18.21 19.95 17.38 19.95 16.5C19.95 14 17.95 12 15.46 12S10.96 14 10.96 16.5 12.96 21 15.46 21C16.33 21 17.15 20.75 17.84 20.32L20.96 23.39L22.35 22L19.27 18.9M15.46 19C14.07 19 12.96 17.88 12.96 16.5S14.07 14 15.46 14 17.95 15.12 17.95 16.5 16.84 19 15.46 19M22 14H21.45C21.12 13.19 20.62 12.47 20 11.86V10H22V14M20 4H17V2H20C21.11 2 22 2.9 22 4V7H20V4M14 4H10V2H14V4M4 2H7V4H4V7H2V4C2 2.89 2.9 2 4 2M12 22H10V20C10.5 20.82 11.2 21.5 12 22M4 20H7V22H4C2.9 22 2 21.11 2 20V17H4V20M4 14H2V10H4V14Z\";\r\nvar mdiSemanticWeb = \"M12.9 4.22C18.73 6.84 20 2 20 2S18.89 8.07 13.79 10.55C12.75 11.06 12.1 11.33 12.1 11.33L3.73 7.25L12.1 3.82C12.1 3.82 11.9 3.76 12.9 4.22M11.12 22L3.33 17.78V9.07L11.12 13.04V22M12.88 22L20.68 17.78V9.07L12.88 13.04V22Z\";\r\nvar mdiSend = \"M2,21L23,12L2,3V10L17,12L2,14V21Z\";\r\nvar mdiSendCheck = \"M2 3V10L17 12L2 14V21L23 12M22 15.5L18.5 19L16.5 17L15 18.5L18.5 22L23.5 17Z\";\r\nvar mdiSendCheckOutline = \"M2 3V10L17 12L2 14V21L23 12M4 6.03L11.53 9.25L4 8.25M11.53 14.75L4 17.97V15.75M22 15.5L18.5 19L16.5 17L15 18.5L18.5 22L23.5 17Z\";\r\nvar mdiSendCircle = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M8,7.71V11.05L15.14,12L8,12.95V16.29L18,12L8,7.71Z\";\r\nvar mdiSendCircleOutline = \"M8,7.71L18,12L8,16.29V12.95L15.14,12L8,11.05V7.71M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiSendClock = \"M2 3V10L11 12L2 14V21L9.27 17.89A7 7 0 0 0 16 23A7 7 0 0 0 23 16A7 7 0 0 0 16 9L2 3M16 11A5 5 0 0 1 21 16A5 5 0 0 1 16 21A5 5 0 0 1 11 16A5 5 0 0 1 16 11M15 12.5V16.5L18 18.5L18.75 17.25L16.5 15.75V12.5H15Z\";\r\nvar mdiSendClockOutline = \"M2 3V10L11 12L2 14V21L9.27 17.89A7 7 0 0 0 16 23A7 7 0 0 0 23 16A7 7 0 0 0 16 9L2 3M4 6.03L12.78 9.8A7 7 0 0 0 12.1 10.2L4 8.4V6.03M16 11A5 5 0 0 1 21 16A5 5 0 0 1 16 21A5 5 0 0 1 11 16A5 5 0 0 1 16 11M15 12.5V16.5L18 18.5L18.75 17.25L16.5 15.75V12.5H15M9.18 14.45A7 7 0 0 0 9 15.82L4 17.97V15.6L9.18 14.45Z\";\r\nvar mdiSendLock = \"M23,18V17.5A2.5,2.5 0 0,0 20.5,15A2.5,2.5 0 0,0 18,17.5V18A1,1 0 0,0 17,19V23A1,1 0 0,0 18,24H23A1,1 0 0,0 24,23V19A1,1 0 0,0 23,18M22,18H19V17.5A1.5,1.5 0 0,1 20.5,16A1.5,1.5 0 0,1 22,17.5V18M23,12L2,21V14L17,12L2,10V3L23,12Z\";\r\nvar mdiSendLockOutline = \"M23 18V17.5C23 16.12 21.88 15 20.5 15S18 16.12 18 17.5V18C17.45 18 17 18.45 17 19V23C17 23.55 17.45 24 18 24H23C23.55 24 24 23.55 24 23V19C24 18.45 23.55 18 23 18M22 18H19V17.5C19 16.67 19.67 16 20.5 16S22 16.67 22 17.5V18M4 6.03L11.5 9.25L4 8.25L4 6.03M11.5 14.75L4 17.97V15.75L11.5 14.75M2 3L2 10L17 12L2 14L2 21L23 12L2 3Z\";\r\nvar mdiSendOutline = \"M4 6.03L11.5 9.25L4 8.25L4 6.03M11.5 14.75L4 17.97V15.75L11.5 14.75M2 3L2 10L17 12L2 14L2 21L23 12L2 3Z\";\r\nvar mdiSerialPort = \"M7,3H17V5H19V8H16V14H8V8H5V5H7V3M17,9H19V14H17V9M11,15H13V22H11V15M5,9H7V14H5V9Z\";\r\nvar mdiServer = \"M4,1H20A1,1 0 0,1 21,2V6A1,1 0 0,1 20,7H4A1,1 0 0,1 3,6V2A1,1 0 0,1 4,1M4,9H20A1,1 0 0,1 21,10V14A1,1 0 0,1 20,15H4A1,1 0 0,1 3,14V10A1,1 0 0,1 4,9M4,17H20A1,1 0 0,1 21,18V22A1,1 0 0,1 20,23H4A1,1 0 0,1 3,22V18A1,1 0 0,1 4,17M9,5H10V3H9V5M9,13H10V11H9V13M9,21H10V19H9V21M5,3V5H7V3H5M5,11V13H7V11H5M5,19V21H7V19H5Z\";\r\nvar mdiServerMinus = \"M4,4H20A1,1 0 0,1 21,5V9A1,1 0 0,1 20,10H4A1,1 0 0,1 3,9V5A1,1 0 0,1 4,4M9,8H10V6H9V8M5,6V8H7V6H5M8,16H16V18H8V16Z\";\r\nvar mdiServerNetwork = \"M13,19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H4A1,1 0 0,1 3,16V12A1,1 0 0,1 4,11H20A1,1 0 0,1 21,12V16A1,1 0 0,1 20,17H13V19M4,3H20A1,1 0 0,1 21,4V8A1,1 0 0,1 20,9H4A1,1 0 0,1 3,8V4A1,1 0 0,1 4,3M9,7H10V5H9V7M9,15H10V13H9V15M5,5V7H7V5H5M5,13V15H7V13H5Z\";\r\nvar mdiServerNetworkOff = \"M13,19H14A1,1 0 0,1 15,20H15.73L13,17.27V19M22,20V21.18L20.82,20H22M21,22.72L19.73,24L17.73,22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H4A1,1 0 0,1 3,16V12A1,1 0 0,1 4,11H6.73L4.73,9H4A1,1 0 0,1 3,8V7.27L1,5.27L2.28,4L21,22.72M4,3H20A1,1 0 0,1 21,4V8A1,1 0 0,1 20,9H9.82L7,6.18V5H5.82L3.84,3C3.89,3 3.94,3 4,3M20,11A1,1 0 0,1 21,12V16A1,1 0 0,1 20,17H17.82L11.82,11H20M9,7H10V5H9V7M9,15H10V14.27L9,13.27V15M5,13V15H7V13H5Z\";\r\nvar mdiServerOff = \"M4,1H20A1,1 0 0,1 21,2V6A1,1 0 0,1 20,7H8.82L6.82,5H7V3H5V3.18L3.21,1.39C3.39,1.15 3.68,1 4,1M22,22.72L20.73,24L19.73,23H4A1,1 0 0,1 3,22V18A1,1 0 0,1 4,17H13.73L11.73,15H4A1,1 0 0,1 3,14V10A1,1 0 0,1 4,9H5.73L3.68,6.95C3.38,6.85 3.15,6.62 3.05,6.32L1,4.27L2.28,3L22,22.72M20,9A1,1 0 0,1 21,10V14A1,1 0 0,1 20,15H16.82L10.82,9H20M20,17A1,1 0 0,1 21,18V19.18L18.82,17H20M9,5H10V3H9V5M9,13H9.73L9,12.27V13M9,21H10V19H9V21M5,11V13H7V11H5M5,19V21H7V19H5Z\";\r\nvar mdiServerPlus = \"M4,4H20A1,1 0 0,1 21,5V9A1,1 0 0,1 20,10H4A1,1 0 0,1 3,9V5A1,1 0 0,1 4,4M9,8H10V6H9V8M5,6V8H7V6H5M8,16H11V13H13V16H16V18H13V21H11V18H8V16Z\";\r\nvar mdiServerRemove = \"M4,4H20A1,1 0 0,1 21,5V9A1,1 0 0,1 20,10H4A1,1 0 0,1 3,9V5A1,1 0 0,1 4,4M9,8H10V6H9V8M5,6V8H7V6H5M10.59,17L8,14.41L9.41,13L12,15.59L14.59,13L16,14.41L13.41,17L16,19.59L14.59,21L12,18.41L9.41,21L8,19.59L10.59,17Z\";\r\nvar mdiServerSecurity = \"M3,1H19A1,1 0 0,1 20,2V6A1,1 0 0,1 19,7H3A1,1 0 0,1 2,6V2A1,1 0 0,1 3,1M3,9H19A1,1 0 0,1 20,10V10.67L17.5,9.56L11,12.44V15H3A1,1 0 0,1 2,14V10A1,1 0 0,1 3,9M3,17H11C11.06,19.25 12,21.4 13.46,23H3A1,1 0 0,1 2,22V18A1,1 0 0,1 3,17M8,5H9V3H8V5M8,13H9V11H8V13M8,21H9V19H8V21M4,3V5H6V3H4M4,11V13H6V11H4M4,19V21H6V19H4M17.5,12L22,14V17C22,19.78 20.08,22.37 17.5,23C14.92,22.37 13,19.78 13,17V14L17.5,12M17.5,13.94L15,15.06V17.72C15,19.26 16.07,20.7 17.5,21.06V13.94Z\";\r\nvar mdiSetAll = \"M9,5C10.04,5 11.06,5.24 12,5.68C12.94,5.24 13.96,5 15,5A7,7 0 0,1 22,12A7,7 0 0,1 15,19C13.96,19 12.94,18.76 12,18.32C11.06,18.76 10.04,19 9,19A7,7 0 0,1 2,12A7,7 0 0,1 9,5M8.5,12C8.5,13.87 9.29,15.56 10.56,16.75L11.56,16.29C10.31,15.29 9.5,13.74 9.5,12C9.5,10.26 10.31,8.71 11.56,7.71L10.56,7.25C9.29,8.44 8.5,10.13 8.5,12M15.5,12C15.5,10.13 14.71,8.44 13.44,7.25L12.44,7.71C13.69,8.71 14.5,10.26 14.5,12C14.5,13.74 13.69,15.29 12.44,16.29L13.44,16.75C14.71,15.56 15.5,13.87 15.5,12Z\";\r\nvar mdiSetCenter = \"M9,5A7,7 0 0,0 2,12A7,7 0 0,0 9,19C10.04,19 11.06,18.76 12,18.32C12.94,18.76 13.96,19 15,19A7,7 0 0,0 22,12A7,7 0 0,0 15,5C13.96,5 12.94,5.24 12,5.68C11.06,5.24 10.04,5 9,5M9,7C9.34,7 9.67,7.03 10,7.1C8.72,8.41 8,10.17 8,12C8,13.83 8.72,15.59 10,16.89C9.67,16.96 9.34,17 9,17A5,5 0 0,1 4,12A5,5 0 0,1 9,7M15,7A5,5 0 0,1 20,12A5,5 0 0,1 15,17C14.66,17 14.33,16.97 14,16.9C15.28,15.59 16,13.83 16,12C16,10.17 15.28,8.41 14,7.11C14.33,7.04 14.66,7 15,7Z\";\r\nvar mdiSetCenterRight = \"M15,19C13.96,19 12.94,18.76 12,18.32C11.06,18.76 10.04,19 9,19A7,7 0 0,1 2,12A7,7 0 0,1 9,5C10.04,5 11.06,5.24 12,5.68C12.94,5.24 13.96,5 15,5A7,7 0 0,1 22,12A7,7 0 0,1 15,19M9,17L10,16.89C8.72,15.59 8,13.83 8,12C8,10.17 8.72,8.41 10,7.1L9,7A5,5 0 0,0 4,12A5,5 0 0,0 9,17M15.5,12C15.5,10.13 14.71,8.44 13.44,7.25L12.44,7.71C13.69,8.71 14.5,10.26 14.5,12C14.5,13.74 13.69,15.29 12.44,16.29L13.44,16.75C14.71,15.56 15.5,13.87 15.5,12Z\";\r\nvar mdiSetLeft = \"M9,5A7,7 0 0,0 2,12A7,7 0 0,0 9,19C10.04,19 11.06,18.76 12,18.32C12.94,18.76 13.96,19 15,19A7,7 0 0,0 22,12A7,7 0 0,0 15,5C13.96,5 12.94,5.24 12,5.68C11.06,5.24 10.04,5 9,5M15,7A5,5 0 0,1 20,12A5,5 0 0,1 15,17C14.66,17 14.33,16.97 14,16.9C15.28,15.59 16,13.83 16,12C16,10.17 15.28,8.41 14,7.11C14.33,7.04 14.66,7 15,7M12,8C13.26,8.95 14,10.43 14,12C14,13.57 13.26,15.05 12,16C10.74,15.05 10,13.57 10,12C10,10.43 10.74,8.95 12,8Z\";\r\nvar mdiSetLeftCenter = \"M9,5C10.04,5 11.06,5.24 12,5.68C12.94,5.24 13.96,5 15,5A7,7 0 0,1 22,12A7,7 0 0,1 15,19C13.96,19 12.94,18.76 12,18.32C11.06,18.76 10.04,19 9,19A7,7 0 0,1 2,12A7,7 0 0,1 9,5M15,7L14,7.11C15.28,8.41 16,10.17 16,12C16,13.83 15.28,15.59 14,16.9L15,17A5,5 0 0,0 20,12A5,5 0 0,0 15,7M8.5,12C8.5,13.87 9.29,15.56 10.56,16.75L11.56,16.29C10.31,15.29 9.5,13.74 9.5,12C9.5,10.26 10.31,8.71 11.56,7.71L10.56,7.25C9.29,8.44 8.5,10.13 8.5,12Z\";\r\nvar mdiSetLeftRight = \"M9,5C10.04,5 11.06,5.24 12,5.68C12.94,5.24 13.96,5 15,5A7,7 0 0,1 22,12A7,7 0 0,1 15,19C13.96,19 12.94,18.76 12,18.32C11.06,18.76 10.04,19 9,19A7,7 0 0,1 2,12A7,7 0 0,1 9,5M9,12C9,14.22 10.21,16.16 12,17.2C13.79,16.16 15,14.22 15,12C15,9.78 13.79,7.84 12,6.8C10.21,7.84 9,9.78 9,12Z\";\r\nvar mdiSetMerge = \"M2 7V9H7V7H2M12 9V11H9V13H12V15L15 12L12 9M17 9V15H22V9H17M2 11V13H7V11H2M2 15V17H7V15H2Z\";\r\nvar mdiSetNone = \"M9,5A7,7 0 0,0 2,12A7,7 0 0,0 9,19C10.04,19 11.06,18.76 12,18.32C12.94,18.76 13.96,19 15,19A7,7 0 0,0 22,12A7,7 0 0,0 15,5C13.96,5 12.94,5.24 12,5.68C11.06,5.24 10.04,5 9,5M9,7C9.34,7 9.67,7.03 10,7.1C8.72,8.41 8,10.17 8,12C8,13.83 8.72,15.59 10,16.89C9.67,16.96 9.34,17 9,17A5,5 0 0,1 4,12A5,5 0 0,1 9,7M15,7A5,5 0 0,1 20,12A5,5 0 0,1 15,17C14.66,17 14.33,16.97 14,16.9C15.28,15.59 16,13.83 16,12C16,10.17 15.28,8.41 14,7.11C14.33,7.04 14.66,7 15,7M12,8C13.26,8.95 14,10.43 14,12C14,13.57 13.26,15.05 12,16C10.74,15.05 10,13.57 10,12C10,10.43 10.74,8.95 12,8Z\";\r\nvar mdiSetRight = \"M15,19C13.96,19 12.94,18.76 12,18.32C11.06,18.76 10.04,19 9,19A7,7 0 0,1 2,12A7,7 0 0,1 9,5C10.04,5 11.06,5.24 12,5.68C12.94,5.24 13.96,5 15,5A7,7 0 0,1 22,12A7,7 0 0,1 15,19M9,17L10,16.89C8.72,15.59 8,13.83 8,12C8,10.17 8.72,8.41 10,7.1L9,7A5,5 0 0,0 4,12A5,5 0 0,0 9,17M12,16C13.26,15.05 14,13.57 14,12C14,10.43 13.26,8.95 12,8C10.74,8.95 10,10.43 10,12C10,13.57 10.74,15.05 12,16Z\";\r\nvar mdiSetSplit = \"M17 7V9H22V7H17M2 9V15H7V9H2M12 9V11H9V13H12V15L15 12L12 9M17 11V13H22V11H17M17 15V17H22V15H17Z\";\r\nvar mdiSetSquare = \"M17.7 17.7L16.6 18.8L15.9 18L17 17L15 15L14 16.1L13.3 15.4L14.4 14.3L12.5 12.4L11.4 13.5L10.7 12.8L11.8 11.7L9.8 9.8L8.7 10.9L8 10.2L9 9L7.1 7.1L6 8.1L5.3 7.4L6.4 6.3L4 4V20H20L17.7 17.7M7 17V11.2L12.8 17H7Z\";\r\nvar mdiSetTopBox = \"M5,15.5A0.5,0.5 0 0,1 4.5,16H3.5A0.5,0.5 0 0,1 3,15.5V15H2A1,1 0 0,1 1,14V11A1,1 0 0,1 2,10H22A1,1 0 0,1 23,11V14A1,1 0 0,1 22,15H21V15.5A0.5,0.5 0 0,1 20.5,16H19.5A0.5,0.5 0 0,1 19,15.5V15H5V15.5M3,12V13H5V12H3M6,12V13H8V12H6M20.5,11.5A1,1 0 0,0 19.5,12.5A1,1 0 0,0 20.5,13.5A1,1 0 0,0 21.5,12.5A1,1 0 0,0 20.5,11.5Z\";\r\nvar mdiSettingsHelper = \"M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22Z\";\r\nvar mdiShaker = \"M7 16C7 16.55 6.55 17 6 17S5 16.55 5 16C5 15.45 5.45 15 6 15S7 15.45 7 16M9 16C8.45 16 8 16.45 8 17S8.45 18 9 18 10 17.55 10 17 9.55 16 9 16M4 18C3.45 18 3 18.45 3 19S3.45 20 4 20 5 19.55 5 19 4.55 18 4 18M7 19C6.45 19 6 19.45 6 20S6.45 21 7 21 8 20.55 8 20 7.55 19 7 19M15.33 2.72L9.8 9.65L13.34 13.19L20.28 7.67C21.18 6.91 21.25 5.54 20.41 4.7L18.3 2.59C17.46 1.75 16.09 1.82 15.33 2.72M8.39 12.5L10.5 14.6C10.9 15 11.54 15 11.93 14.6L12.63 13.9L9.1 10.36L8.39 11.07C8 11.46 8 12.09 8.39 12.5Z\";\r\nvar mdiShakerOutline = \"M16.88 4L16.88 4L19.03 6.1L13.5 10.5L12.5 9.5L16.87 4L16.88 4M16.88 2C16.3 2 15.73 2.24 15.33 2.72L9.8 9.65L13.34 13.19L20.28 7.67C21.18 6.91 21.25 5.54 20.41 4.7L18.3 2.59C17.9 2.19 17.39 2 16.88 2M9.1 10.36L8.39 11.07C8 11.46 8 12.09 8.39 12.5L10.5 14.6C10.71 14.8 10.96 14.89 11.22 14.89S11.73 14.8 11.93 14.6L12.63 13.9L9.1 10.36M6 15C5.45 15 5 15.45 5 16C5 16.55 5.45 17 6 17C6.55 17 7 16.55 7 16C7 15.45 6.55 15 6 15M9 16C8.45 16 8 16.45 8 17S8.45 18 9 18C9.55 18 10 17.55 10 17S9.55 16 9 16M4 18C3.45 18 3 18.45 3 19S3.45 20 4 20C4.55 20 5 19.55 5 19S4.55 18 4 18M7 19C6.45 19 6 19.45 6 20S6.45 21 7 21C7.55 21 8 20.55 8 20S7.55 19 7 19Z\";\r\nvar mdiShape = \"M11,13.5V21.5H3V13.5H11M12,2L17.5,11H6.5L12,2M17.5,13C20,13 22,15 22,17.5C22,20 20,22 17.5,22C15,22 13,20 13,17.5C13,15 15,13 17.5,13Z\";\r\nvar mdiShapeCirclePlus = \"M11,19A6,6 0 0,0 17,13H19A8,8 0 0,1 11,21A8,8 0 0,1 3,13A8,8 0 0,1 11,5V7A6,6 0 0,0 5,13A6,6 0 0,0 11,19M19,5H22V7H19V10H17V7H14V5H17V2H19V5Z\";\r\nvar mdiShapeOutline = \"M11,13.5V21.5H3V13.5H11M9,15.5H5V19.5H9V15.5M12,2L17.5,11H6.5L12,2M12,5.86L10.08,9H13.92L12,5.86M17.5,13C20,13 22,15 22,17.5C22,20 20,22 17.5,22C15,22 13,20 13,17.5C13,15 15,13 17.5,13M17.5,15A2.5,2.5 0 0,0 15,17.5A2.5,2.5 0 0,0 17.5,20A2.5,2.5 0 0,0 20,17.5A2.5,2.5 0 0,0 17.5,15Z\";\r\nvar mdiShapeOvalPlus = \"M19 5H22V7H19V10H17V7H14V5H17V2H19V5M11 4L12 4.09V6.14C11.68 6.05 11.34 6 11 6C8.24 6 6 9.13 6 13C6 16.87 8.24 20 11 20C13.76 20 16 16.87 16 13L15.95 12H17.96L18 13C18 17.97 14.87 22 11 22C7.13 22 4 17.97 4 13C4 8.03 7.13 4 11 4Z\";\r\nvar mdiShapePlus = \"M2,2H11V11H2V2M17.5,2C20,2 22,4 22,6.5C22,9 20,11 17.5,11C15,11 13,9 13,6.5C13,4 15,2 17.5,2M6.5,14L11,22H2L6.5,14M19,17H22V19H19V22H17V19H14V17H17V14H19V17Z\";\r\nvar mdiShapePolygonPlus = \"M17,15.7V13H19V17L10,21L3,14L7,5H11V7H8.3L5.4,13.6L10.4,18.6L17,15.7M22,5V7H19V10H17V7H14V5H17V2H19V5H22Z\";\r\nvar mdiShapeRectanglePlus = \"M19,6H22V8H19V11H17V8H14V6H17V3H19V6M17,17V14H19V19H3V6H11V8H5V17H17Z\";\r\nvar mdiShapeSquarePlus = \"M19,5H22V7H19V10H17V7H14V5H17V2H19V5M17,19V13H19V21H3V5H11V7H5V19H17Z\";\r\nvar mdiShapeSquareRoundedPlus = \"M17 2H19V5H22V7H19V10H17V7H14V5H17V2M7 5H11V7H7C5.9 7 5 7.9 5 9V17C5 18.11 5.9 19 7 19H15C16.11 19 17 18.11 17 17V13H19V17C19 19.21 17.21 21 15 21H7C4.79 21 3 19.21 3 17V9C3 6.79 4.79 5 7 5Z\";\r\nvar mdiShare = \"M21,12L14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12Z\";\r\nvar mdiShareAll = \"M11 9V5L18 12L11 19V14.9C6 14.9 2.5 16.5 0 20C1 15 4 10 11 9M17 8V5L24 12L17 19V16L21 12L17 8Z\";\r\nvar mdiShareAllOutline = \"M13 9.8V10.7L11.3 10.9C8.7 11.3 6.8 12.3 5.4 13.6C7.1 13.1 8.9 12.8 11 12.8H13V14.1L15.2 12L13 9.8M11 5L18 12L11 19V14.9C6 14.9 2.5 16.5 0 20C1 15 4 10 11 9M17 8V5L24 12L17 19V16L21 12\";\r\nvar mdiShareCircle = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M14 16V13C10.39 13 7.81 14.43 6 17C6.72 13.33 8.94 9.73 14 9V6L19 11L14 16Z\";\r\nvar mdiShareOff = \"M20.8 22.7L15.6 17.5L14 19V15.9L13.1 14.9C8.6 15.2 5.4 16.8 3 20.1C3.58 16.31 5.72 12.94 8.9 10.8L1.1 3L2.4 1.7L22.1 21.5M18.1 14.9L21 12L14 5V9L12.5 9.3\";\r\nvar mdiShareOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L8.9 10.8C5.4 12.9 3.7 16.4 3 20C5.3 16.7 8.6 15.1 13 14.9L14 15.9V19L15.6 17.4L20.8 22.7M8.3 13.8C8.94 13.22 9.65 12.71 10.4 12.3L11.3 13.1M14.2 11L12.5 9.3L14 9V5L21 12L18.1 14.9L16.7 13.5L18.2 12L16 9.8V10.7\";\r\nvar mdiShareOutline = \"M14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12L14,5M16,9.83L18.17,12L16,14.17V12.9H14C11.93,12.9 10.07,13.28 8.34,13.85C9.74,12.46 11.54,11.37 14.28,11L16,10.73V9.83Z\";\r\nvar mdiShareVariant = \"M18,16.08C17.24,16.08 16.56,16.38 16.04,16.85L8.91,12.7C8.96,12.47 9,12.24 9,12C9,11.76 8.96,11.53 8.91,11.3L15.96,7.19C16.5,7.69 17.21,8 18,8A3,3 0 0,0 21,5A3,3 0 0,0 18,2A3,3 0 0,0 15,5C15,5.24 15.04,5.47 15.09,5.7L8.04,9.81C7.5,9.31 6.79,9 6,9A3,3 0 0,0 3,12A3,3 0 0,0 6,15C6.79,15 7.5,14.69 8.04,14.19L15.16,18.34C15.11,18.55 15.08,18.77 15.08,19C15.08,20.61 16.39,21.91 18,21.91C19.61,21.91 20.92,20.61 20.92,19A2.92,2.92 0 0,0 18,16.08Z\";\r\nvar mdiShareVariantOutline = \"M18 16.08C17.24 16.08 16.56 16.38 16.04 16.85L8.91 12.7C8.96 12.47 9 12.24 9 12S8.96 11.53 8.91 11.3L15.96 7.19C16.5 7.69 17.21 8 18 8C19.66 8 21 6.66 21 5S19.66 2 18 2 15 3.34 15 5C15 5.24 15.04 5.47 15.09 5.7L8.04 9.81C7.5 9.31 6.79 9 6 9C4.34 9 3 10.34 3 12S4.34 15 6 15C6.79 15 7.5 14.69 8.04 14.19L15.16 18.34C15.11 18.55 15.08 18.77 15.08 19C15.08 20.61 16.39 21.91 18 21.91S20.92 20.61 20.92 19C20.92 17.39 19.61 16.08 18 16.08M18 4C18.55 4 19 4.45 19 5S18.55 6 18 6 17 5.55 17 5 17.45 4 18 4M6 13C5.45 13 5 12.55 5 12S5.45 11 6 11 7 11.45 7 12 6.55 13 6 13M18 20C17.45 20 17 19.55 17 19S17.45 18 18 18 19 18.45 19 19 18.55 20 18 20Z\";\r\nvar mdiSheep = \"M20,8.5A2.5,2.5 0 0,1 17.5,11C16.42,11 15.5,10.31 15.16,9.36C14.72,9.75 14.14,10 13.5,10C12.94,10 12.42,9.81 12,9.5C11.58,9.81 11.07,10 10.5,10C9.86,10 9.28,9.75 8.84,9.36C8.5,10.31 7.58,11 6.5,11A2.5,2.5 0 0,1 4,8.5C4,7.26 4.91,6.23 6.1,6.04C6.04,5.87 6,5.69 6,5.5A1.5,1.5 0 0,1 7.5,4C7.7,4 7.89,4.04 8.06,4.11C8.23,3.47 8.81,3 9.5,3C9.75,3 10,3.07 10.18,3.17C10.5,2.5 11.19,2 12,2C12.81,2 13.5,2.5 13.82,3.17C14,3.07 14.25,3 14.5,3C15.19,3 15.77,3.47 15.94,4.11C16.11,4.04 16.3,4 16.5,4A1.5,1.5 0 0,1 18,5.5C18,5.69 17.96,5.87 17.9,6.04C19.09,6.23 20,7.26 20,8.5M10,12A1,1 0 0,0 9,13A1,1 0 0,0 10,14A1,1 0 0,0 11,13A1,1 0 0,0 10,12M14,12A1,1 0 0,0 13,13A1,1 0 0,0 14,14A1,1 0 0,0 15,13A1,1 0 0,0 14,12M20.23,10.66C19.59,11.47 18.61,12 17.5,12C17.05,12 16.62,11.9 16.21,11.73C16.2,14.28 15.83,17.36 14.45,18.95C13.93,19.54 13.3,19.86 12.5,19.96V18H11.5V19.96C10.7,19.86 10.07,19.55 9.55,18.95C8.16,17.35 7.79,14.29 7.78,11.74C7.38,11.9 6.95,12 6.5,12C5.39,12 4.41,11.47 3.77,10.66C2.88,11.55 2,12 2,12C2,12 3,14 5,14C5.36,14 5.64,13.96 5.88,13.91C6.22,17.73 7.58,22 12,22C16.42,22 17.78,17.73 18.12,13.91C18.36,13.96 18.64,14 19,14C21,14 22,12 22,12C22,12 21.12,11.55 20.23,10.66Z\";\r\nvar mdiShield = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1Z\";\r\nvar mdiShieldAccount = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1M12,5A3,3 0 0,1 15,8A3,3 0 0,1 12,11A3,3 0 0,1 9,8A3,3 0 0,1 12,5M17.13,17C15.92,18.85 14.11,20.24 12,20.92C9.89,20.24 8.08,18.85 6.87,17C6.53,16.5 6.24,16 6,15.47C6,13.82 8.71,12.47 12,12.47C15.29,12.47 18,13.79 18,15.47C17.76,16 17.47,16.5 17.13,17Z\";\r\nvar mdiShieldAccountOutline = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1M12,3.18L19,6.3V11.22C19,12.92 18.5,14.65 17.65,16.17C16,14.94 13.26,14.5 12,14.5C10.74,14.5 8,14.94 6.35,16.17C5.5,14.65 5,12.92 5,11.22V6.3L12,3.18M12,6A3.5,3.5 0 0,0 8.5,9.5A3.5,3.5 0 0,0 12,13A3.5,3.5 0 0,0 15.5,9.5A3.5,3.5 0 0,0 12,6M12,8A1.5,1.5 0 0,1 13.5,9.5A1.5,1.5 0 0,1 12,11A1.5,1.5 0 0,1 10.5,9.5A1.5,1.5 0 0,1 12,8M12,16.5C13.57,16.5 15.64,17.11 16.53,17.84C15.29,19.38 13.7,20.55 12,21C10.3,20.55 8.71,19.38 7.47,17.84C8.37,17.11 10.43,16.5 12,16.5Z\";\r\nvar mdiShieldAccountVariant = \"M17 11C17.3 11 17.7 11 18 11.1V6.3L10.5 3L3 6.3V11.2C3 15.7 6.2 20 10.5 21C11.1 20.9 11.6 20.7 12.1 20.5C11.4 19.5 11 18.3 11 17C11 13.7 13.7 11 17 11M17 13C14.8 13 13 14.8 13 17S14.8 21 17 21 21 19.2 21 17 19.2 13 17 13M17 14.4C17.6 14.4 18.1 14.9 18.1 15.5C18.1 16.1 17.6 16.6 17 16.6S15.9 16.1 15.9 15.5 16.4 14.4 17 14.4M17 19.8C16.1 19.8 15.3 19.3 14.8 18.6C14.9 17.9 16.3 17.5 17 17.5S19.2 17.9 19.2 18.6C18.7 19.3 17.9 19.8 17 19.8Z\";\r\nvar mdiShieldAccountVariantOutline = \"M17 14.4C17.6 14.4 18.1 14.9 18.1 15.5S17.6 16.6 17 16.6 15.9 16.1 15.9 15.5 16.4 14.4 17 14.4M17 17.5C16.3 17.5 14.8 17.9 14.8 18.6C15.3 19.3 16.1 19.8 17 19.8S18.7 19.3 19.2 18.6C19.2 17.9 17.7 17.5 17 17.5M18 11.1V6.3L10.5 3L3 6.3V11.2C3 15.7 6.2 20 10.5 21C11.1 20.9 11.6 20.7 12.1 20.5C13.2 22 15 23 17 23C20.3 23 23 20.3 23 17C23 14 20.8 11.6 18 11.1M11 17C11 17.6 11.1 18.1 11.2 18.6C11 18.7 10.7 18.8 10.5 18.9C7.3 17.9 5 14.7 5 11.2V7.6L10.5 5.2L16 7.6V11.1C13.2 11.6 11 14 11 17M17 21C14.8 21 13 19.2 13 17S14.8 13 17 13 21 14.8 21 17 19.2 21 17 21Z\";\r\nvar mdiShieldAirplane = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1M12,5.68C12.5,5.68 12.95,6.11 12.95,6.63V10.11L18,13.26V14.53L12.95,12.95V16.42L14.21,17.37V18.32L12,17.68L9.79,18.32V17.37L11.05,16.42V12.95L6,14.53V13.26L11.05,10.11V6.63C11.05,6.11 11.5,5.68 12,5.68Z\";\r\nvar mdiShieldAirplaneOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M12,5.68C12.5,5.68 12.95,6.11 12.95,6.63V10.11L18,13.26V14.53L12.95,12.95V16.42L14.21,17.37V18.32L12,17.68L9.79,18.32V17.37L11.05,16.42V12.95L6,14.53V13.26L11.05,10.11V6.63C11.05,6.11 11.5,5.68 12,5.68Z\";\r\nvar mdiShieldAlert = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5M11,7H13V13H11M11,15H13V17H11\";\r\nvar mdiShieldAlertOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M11,7H13V13H11V7M11,15H13V17H11V15Z\";\r\nvar mdiShieldBug = \"M11 13H13V14H11V13M21 5V11C21 16.5 17.2 21.7 12 23C6.8 21.7 3 16.5 3 11V5L12 1L21 5M17 10H14.8C14.6 9.4 14.2 8.9 13.7 8.5L14.9 7.3L14.2 6.6L12.8 8H12C11.8 8 11.5 8 11.3 8.1L9.9 6.6L9.1 7.4L10.3 8.6C9.8 8.9 9.4 9.4 9.2 10H7V11H9V12H7V13H9V14H7V15H9.2C9.6 16.2 10.7 17 12 17S14.4 16.2 14.8 15H17V14H15V13H17V12H15V11H17V10M11 12H13V11H11V12Z\";\r\nvar mdiShieldBugOutline = \"M9.9 6.6L9.1 7.4L10.3 8.6C9.8 8.9 9.4 9.4 9.2 10H7V11H9V12H7V13H9V14H7V15H9.2C9.6 16.2 10.7 17 12 17S14.4 16.2 14.8 15H17V14H15V13H17V12H15V11H17V10H14.8C14.6 9.4 14.2 8.9 13.7 8.5L14.9 7.3L14.2 6.6L12.8 8H12C11.8 8 11.5 8 11.3 8.1L9.9 6.6M11 11H13V12H11V11M11 13H13V14H11V13M21 11C21 16.5 17.2 21.7 12 23C6.8 21.7 3 16.5 3 11V5L12 1L21 5V11M12 21C15.8 20 19 15.5 19 11.2V6.3L12 3.2L5 6.3V11.2C5 15.5 8.2 20 12 21Z\";\r\nvar mdiShieldCar = \"M14.42 7.5L16 11H8L9.42 7.5H14.42M9 12C8.45 12 8 12.45 8 13S8.45 14 9 14 10 13.55 10 13 9.55 12 9 12M15 12C14.45 12 14 12.45 14 13S14.45 14 15 14 16 13.55 16 13 15.55 12 15 12M21 5V11C21 16.55 17.16 21.74 12 23C6.84 21.74 3 16.55 3 11V5L12 1L21 5M18 12L15.84 7C15.64 6.42 15.08 6 14.42 6H9.42C8.76 6 8.2 6.42 8 7L6 12V16C6 16.55 6.45 17 7 17H8C8.55 17 9 16.55 9 16V15H15V16C15 16.55 15.45 17 16 17H17C17.55 17 18 16.55 18 16V12Z\";\r\nvar mdiShieldCheck = \"M10,17L6,13L7.41,11.59L10,14.17L16.59,7.58L18,9M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1Z\";\r\nvar mdiShieldCheckOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M10,17L6,13L7.41,11.59L10,14.17L16.59,7.58L18,9\";\r\nvar mdiShieldCross = \"M12,1L3,5V11C3,16.5 6.8,21.7 12,23C17.2,21.7 21,16.5 21,11V5L12,1M16,10H13V18H11V10H8V8H11V5H13V8H16V10Z\";\r\nvar mdiShieldCrossOutline = \"M21,11C21,16.5 17.2,21.7 12,23C6.8,21.7 3,16.5 3,11V5L12,1L21,5V11M12,21C15.8,20 19,15.5 19,11.2V6.3L12,3.2L5,6.3V11.2C5,15.5 8.3,20 12,21M16,9H13V6H11V9H8V11H11V19H13V11H16V9Z\";\r\nvar mdiShieldEdit = \"M21.7 14.4L20.7 15.4L18.6 13.3L19.6 12.3C19.8 12.1 20.2 12.1 20.4 12.3L21.7 13.6C21.9 13.8 21.9 14.1 21.7 14.4M12 19.9L18.1 13.8L20.2 15.9L14.1 22H12V19.9M10 19.1L21 8.1V5L12 1L3 5V11C3 15.8 5.9 20.3 10 22.3V19.1Z\";\r\nvar mdiShieldEditOutline = \"M21.7 13.6L20.4 12.3C20.3 12.2 20.2 12.1 20 12.1C19.9 12.1 19.7 12.2 19.6 12.3L18.6 13.3L20.6 15.3L21.6 14.3C21.9 14.1 21.9 13.8 21.7 13.6M12 19.9V22H14.1L20.2 15.9L18.2 13.8L12 19.9M10 22.3C5.9 20.3 3 15.8 3 11V5L12 1L21 5V8.1L19 10.1V6.3L12 3.2L5 6.3V11.2C5 14.7 7.2 18.3 10 20.1V22.3Z\";\r\nvar mdiShieldHalf = \"M12 1L3 5V11C3 16.5 6.8 21.7 12 23V1Z\";\r\nvar mdiShieldHalfFull = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18V21Z\";\r\nvar mdiShieldHome = \"M11,13H13V16H16V11H18L12,6L6,11H8V16H11V13M12,1L21,5V11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1Z\";\r\nvar mdiShieldHomeOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M11,14H13V17H16V12H18L12,7L6,12H8V17H11V14\";\r\nvar mdiShieldKey = \"M12,8A1,1 0 0,1 13,9A1,1 0 0,1 12,10A1,1 0 0,1 11,9A1,1 0 0,1 12,8M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,6A3,3 0 0,0 9,9C9,10.31 9.83,11.42 11,11.83V18H13V16H15V14H13V11.83C14.17,11.42 15,10.31 15,9A3,3 0 0,0 12,6Z\";\r\nvar mdiShieldKeyOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M12,6A3,3 0 0,1 15,9C15,10.31 14.17,11.42 13,11.83V14H15V16H13V18H11V11.83C9.83,11.42 9,10.31 9,9A3,3 0 0,1 12,6M12,8A1,1 0 0,0 11,9A1,1 0 0,0 12,10A1,1 0 0,0 13,9A1,1 0 0,0 12,8Z\";\r\nvar mdiShieldLinkVariant = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1M14.28,14.08L12.26,16.1C11.66,16.7 10.87,17 10.08,17C9.29,17 8.5,16.7 7.9,16.1C6.7,14.9 6.7,12.95 7.9,11.74L9.15,10.5L9.14,11.06C9.14,11.5 9.21,11.95 9.36,12.37L9.41,12.5L9.04,12.87C8.76,13.15 8.6,13.53 8.6,13.92C8.6,14.32 8.76,14.69 9.04,14.97C9.6,15.53 10.57,15.53 11.13,14.97L13.14,12.96C13.43,12.67 13.58,12.3 13.58,11.91C13.58,11.5 13.43,11.14 13.15,10.86C13,10.71 12.9,10.5 12.9,10.29C12.9,10.08 13,9.88 13.15,9.73C13.45,9.42 14,9.43 14.28,9.73C14.86,10.31 15.18,11.08 15.18,11.9C15.18,12.73 14.86,13.5 14.28,14.08M17.1,11.26L15.85,12.5L15.86,11.94C15.86,11.5 15.79,11.06 15.64,10.64L15.6,10.5L15.96,10.13C16.25,9.85 16.4,9.5 16.4,9.08C16.4,8.69 16.25,8.32 15.97,8.04C15.4,7.47 14.43,7.47 13.87,8.04L11.86,10.05C11.58,10.33 11.42,10.7 11.42,11.1C11.42,11.5 11.57,11.86 11.86,12.14C12,12.29 12.1,12.5 12.1,12.71C12.1,12.93 12,13.13 11.85,13.28C11.7,13.44 11.5,13.5 11.29,13.5C11.09,13.5 10.88,13.43 10.72,13.28C9.5,12.08 9.5,10.12 10.72,8.92L12.74,6.9C13.95,5.7 15.9,5.7 17.1,6.9C17.68,7.5 18,8.26 18,9.08C18,9.9 17.68,10.68 17.1,11.26Z\";\r\nvar mdiShieldLinkVariantOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M14.28,9.73C14.86,10.31 15.18,11.08 15.18,11.9C15.18,12.73 14.86,13.5 14.28,14.08L12.26,16.1C11.66,16.7 10.87,17 10.08,17C9.29,17 8.5,16.7 7.9,16.1C6.7,14.9 6.7,12.95 7.9,11.74L9.15,10.5L9.14,11.06C9.14,11.5 9.21,11.95 9.36,12.36L9.4,12.5L9.04,12.87C8.75,13.15 8.6,13.5 8.6,13.92C8.6,14.31 8.75,14.68 9.03,14.96C9.6,15.53 10.57,15.53 11.13,14.97L13.14,12.95C13.43,12.67 13.58,12.3 13.58,11.91C13.58,11.5 13.43,11.14 13.14,10.86C13,10.71 12.9,10.5 12.9,10.29C12.9,10.08 13,9.87 13.14,9.72C13.45,9.42 14,9.42 14.28,9.73M18,9.08C18,9.9 17.68,10.68 17.1,11.26L15.85,12.5L15.86,11.94C15.86,11.5 15.79,11.06 15.64,10.64L15.59,10.5L15.96,10.13C16.25,9.85 16.4,9.5 16.4,9.08C16.4,8.69 16.25,8.32 15.96,8.04C15.4,7.47 14.43,7.47 13.87,8.03L11.86,10.05C11.57,10.33 11.42,10.7 11.42,11.1C11.42,11.5 11.57,11.86 11.85,12.14C12,12.29 12.1,12.5 12.1,12.71C12.1,12.93 12,13.13 11.85,13.28C11.7,13.43 11.5,13.5 11.29,13.5C11.09,13.5 10.88,13.43 10.72,13.28C9.5,12.07 9.5,10.12 10.72,8.92L12.74,6.9C13.95,5.7 15.9,5.7 17.1,6.9C17.68,7.5 18,8.26 18,9.08Z\";\r\nvar mdiShieldLock = \"M12,1L3,5V11C3,16.55 6.84,21.74 12,23C17.16,21.74 21,16.55 21,11V5L12,1M12,7C13.4,7 14.8,8.1 14.8,9.5V11C15.4,11 16,11.6 16,12.3V15.8C16,16.4 15.4,17 14.7,17H9.2C8.6,17 8,16.4 8,15.7V12.2C8,11.6 8.6,11 9.2,11V9.5C9.2,8.1 10.6,7 12,7M12,8.2C11.2,8.2 10.5,8.7 10.5,9.5V11H13.5V9.5C13.5,8.7 12.8,8.2 12,8.2Z\";\r\nvar mdiShieldLockOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21M14.8,11V9.5C14.8,8.1 13.4,7 12,7C10.6,7 9.2,8.1 9.2,9.5V11C8.6,11 8,11.6 8,12.2V15.7C8,16.4 8.6,17 9.2,17H14.7C15.4,17 16,16.4 16,15.8V12.3C16,11.6 15.4,11 14.8,11M13.5,11H10.5V9.5C10.5,8.7 11.2,8.2 12,8.2C12.8,8.2 13.5,8.7 13.5,9.5V11Z\";\r\nvar mdiShieldOff = \"M1,4.27L2.28,3L20.5,21.22L19.23,22.5L17,20.25C15.57,21.57 13.87,22.54 12,23C6.84,21.74 3,16.55 3,11V6.27L1,4.27M12,1L21,5V11C21,13.28 20.35,15.5 19.23,17.41L5.65,3.82L12,1Z\";\r\nvar mdiShieldOffOutline = \"M1,4.27L3,6.27V11C3,16.55 6.84,21.74 12,23C13.87,22.54 15.57,21.56 16.97,20.24L19.23,22.5L20.5,21.22L2.28,3L1,4.27M12,21C8.25,20 5,15.54 5,11.22V8.27L15.59,18.86C14.53,19.89 13.3,20.65 12,21M21,5V11C21,13.28 20.35,15.5 19.23,17.4L17.77,15.95C18.54,14.5 19,12.84 19,11.22V6.3L12,3.18L7.16,5.34L5.65,3.82L12,1L21,5Z\";\r\nvar mdiShieldOutline = \"M21,11C21,16.55 17.16,21.74 12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11M12,21C15.75,20 19,15.54 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21Z\";\r\nvar mdiShieldPlus = \"M19,20V22.97H17V20H14V18H17V15H19V18H22V20H19M12,1L21,5V11C21,11.9 20.9,12.78 20.71,13.65C19.9,13.23 19,13 18,13A6,6 0 0,0 12,19C12,20.36 12.45,21.62 13.22,22.62L12,23C6.84,21.74 3,16.55 3,11V5L12,1Z\";\r\nvar mdiShieldPlusOutline = \"M19,20V22.97H17V20H14V18H17V15H19V18H22V20H19M21,11C21,11.9 20.9,12.78 20.71,13.65C20.13,13.35 19.5,13.15 18.81,13.05C18.93,12.45 19,11.83 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21L12.31,20.91C12.5,21.53 12.83,22.11 13.22,22.62L12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11Z\";\r\nvar mdiShieldRefresh = \"M18 12C19 12 20 12.2 20.9 12.7C21 12.1 21 11.6 21 11V5L12 1L3 5V11C3 16.5 6.8 21.7 12 23C12.4 22.9 12.7 22.8 13 22.7C12 21.5 11.5 20 11.5 18.5C11.5 14.9 14.4 12 18 12M18 14.5C19.1 14.5 20.1 14.9 20.8 15.7L22 14.5V18.5H18L19.8 16.7C19.3 16.3 18.7 16 18 16C16.6 16 15.5 17.1 15.5 18.5S16.6 21 18 21C18.8 21 19.5 20.6 20 20H21.7C21.1 21.5 19.7 22.5 18 22.5C15.8 22.5 14 20.7 14 18.5S15.8 14.5 18 14.5Z\";\r\nvar mdiShieldRefreshOutline = \"M12 21C8.2 20 5 15.5 5 11.2V6.3L12 3.2L19 6.3V12.1C19.7 12.2 20.3 12.4 20.9 12.7C21 12.1 21 11.6 21 11V5L12 1L3 5V11C3 16.5 6.8 21.7 12 23C12.4 22.9 12.7 22.8 13 22.7C12.6 22.2 12.2 21.6 12 21M18 14.5C19.1 14.5 20.1 14.9 20.8 15.7L22 14.5V18.5H18L19.8 16.7C19.3 16.3 18.7 16 18 16C16.6 16 15.5 17.1 15.5 18.5S16.6 21 18 21C18.8 21 19.5 20.6 20 20H21.7C21.1 21.5 19.7 22.5 18 22.5C15.8 22.5 14 20.7 14 18.5S15.8 14.5 18 14.5Z\";\r\nvar mdiShieldRemove = \"M19.43,19L21.5,21.11L20.12,22.5L18.03,20.41L15.91,22.53L14.5,21.11L16.61,19L14.5,16.86L15.88,15.47L18,17.59L20.12,15.47L21.55,16.9L19.43,19M12,1L21,5V11C21,11.9 20.9,12.78 20.71,13.65C19.9,13.23 19,13 18,13A6,6 0 0,0 12,19C12,20.36 12.45,21.62 13.22,22.62L12,23C6.84,21.74 3,16.55 3,11V5L12,1Z\";\r\nvar mdiShieldRemoveOutline = \"M19.43,19L21.5,21.11L20.12,22.5L18.03,20.41L15.91,22.53L14.5,21.11L16.61,19L14.5,16.86L15.88,15.47L18,17.59L20.12,15.47L21.55,16.9L19.43,19M21,11C21,11.9 20.9,12.78 20.71,13.65C20.13,13.35 19.5,13.15 18.81,13.05C18.93,12.45 19,11.83 19,11.22V6.3L12,3.18L5,6.3V11.22C5,15.54 8.25,20 12,21L12.31,20.91C12.5,21.53 12.83,22.11 13.22,22.62L12,23C6.84,21.74 3,16.55 3,11V5L12,1L21,5V11Z\";\r\nvar mdiShieldSearch = \"M12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9M17.86,19.31C16.23,21.22 14.28,22.45 12,23C9.44,22.39 7.3,20.93 5.58,18.63C3.86,16.34 3,13.8 3,11V5L12,1L21,5V11C21,13.39 20.36,15.61 19.08,17.67L16.17,14.76C16.69,13.97 17,13 17,12A5,5 0 0,0 12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17C13,17 13.97,16.69 14.76,16.17L17.86,19.31Z\";\r\nvar mdiShieldStar = \"M12 1L3 5V11C3 16.55 6.84 21.74 12 23C17.16 21.74 21 16.55 21 11V5L12 1M15.08 16L12 14.15L8.93 16L9.74 12.5L7.03 10.16L10.61 9.85L12 6.55L13.39 9.84L16.97 10.15L14.26 12.5L15.08 16Z\";\r\nvar mdiShieldStarOutline = \"M21 11C21 16.55 17.16 21.74 12 23C6.84 21.74 3 16.55 3 11V5L12 1L21 5V11M12 21C15.75 20 19 15.54 19 11.22V6.3L12 3.18L5 6.3V11.22C5 15.54 8.25 20 12 21M15.05 16L11.97 14.15L8.9 16L9.71 12.5L7 10.16L10.58 9.85L11.97 6.55L13.37 9.84L16.95 10.15L14.23 12.5L15.05 16\";\r\nvar mdiShieldSun = \"M12 1L3 5V11C3 16.55 6.84 21.74 12 23C17.16 21.74 21 16.55 21 11V5L12 1M12 8.89C13.6 8.89 14.89 10.18 14.89 11.78S13.6 14.67 12 14.67 9.11 13.37 9.11 11.78 10.41 8.89 12 8.89M12 6L13.38 8C12.96 7.82 12.5 7.73 12 7.73S11.05 7.82 10.62 8L12 6M7 8.89L9.4 8.69C9.06 9 8.74 9.34 8.5 9.76C8.25 10.18 8.1 10.62 8 11.08L7 8.89M7 14.67L8.03 12.5C8.11 12.93 8.27 13.38 8.5 13.8C8.75 14.23 9.06 14.59 9.4 14.88L7 14.67M17 8.89L16 11.08C15.9 10.62 15.74 10.18 15.5 9.76C15.26 9.34 14.95 9 14.6 8.68L17 8.89M17 14.67L14.6 14.87C14.94 14.58 15.25 14.22 15.5 13.8C15.74 13.38 15.89 12.93 15.97 12.5L17 14.67M12 17.55L10.61 15.57C11.04 15.72 11.5 15.82 12 15.82C12.5 15.82 12.95 15.72 13.37 15.57L12 17.55Z\";\r\nvar mdiShieldSunOutline = \"M21 11C21 16.55 17.16 21.74 12 23C6.84 21.74 3 16.55 3 11V5L12 1L21 5V11M12 21C15.75 20 19 15.54 19 11.22V6.3L12 3.18L5 6.3V11.22C5 15.54 8.25 20 12 21M12 8.89C13.6 8.89 14.89 10.18 14.89 11.78S13.6 14.67 12 14.67 9.11 13.37 9.11 11.78 10.41 8.89 12 8.89M12 6L13.38 8C12.96 7.82 12.5 7.73 12 7.73S11.05 7.82 10.62 8L12 6M7 8.89L9.4 8.69C9.06 9 8.74 9.34 8.5 9.76C8.25 10.18 8.1 10.62 8 11.08L7 8.89M7 14.67L8.03 12.5C8.11 12.93 8.27 13.38 8.5 13.8C8.75 14.23 9.06 14.59 9.4 14.88L7 14.67M17 8.89L16 11.08C15.9 10.62 15.74 10.18 15.5 9.76C15.26 9.34 14.95 9 14.6 8.68L17 8.89M17 14.67L14.6 14.87C14.94 14.58 15.25 14.22 15.5 13.8C15.74 13.38 15.89 12.93 15.97 12.5L17 14.67M12 17.55L10.61 15.57C11.04 15.72 11.5 15.82 12 15.82C12.5 15.82 12.95 15.72 13.37 15.57L12 17.55Z\";\r\nvar mdiShieldSync = \"M18 12A6.41 6.41 0 0 1 20.87 12.67A11.63 11.63 0 0 0 21 11V5L12 1L3 5V11C3 16.55 6.84 21.74 12 23C12.35 22.91 12.7 22.8 13 22.68A6.42 6.42 0 0 1 11.5 18.5A6.5 6.5 0 0 1 18 12M18 14.5V13L15.75 15.25L18 17.5V16A2.5 2.5 0 0 1 20.24 19.62L21.33 20.71A4 4 0 0 0 18 14.5M18 21A2.5 2.5 0 0 1 15.76 17.38L14.67 16.29A4 4 0 0 0 18 22.5V24L20.25 21.75L18 19.5Z\";\r\nvar mdiShieldSyncOutline = \"M12 21C8.25 20 5 15.54 5 11.22V6.3L12 3.18L19 6.3V12.07A6.45 6.45 0 0 1 20.91 12.67A11.63 11.63 0 0 0 21 11V5L12 1L3 5V11C3 16.55 6.84 21.74 12 23C12.35 22.91 12.7 22.8 13 22.68A6.3 6.3 0 0 1 12 21M18 14.5V13L15.75 15.25L18 17.5V16A2.5 2.5 0 0 1 20.24 19.62L21.33 20.71A4 4 0 0 0 18 14.5M18 21A2.5 2.5 0 0 1 15.76 17.38L14.67 16.29A4 4 0 0 0 18 22.5V24L20.25 21.75L18 19.5Z\";\r\nvar mdiShipWheel = \"M2,11L4.05,11.1C4.3,8.83 5.5,6.85 7.25,5.56L6.13,3.84C5.86,3.36 6,2.75 6.5,2.47C7,2.2 7.59,2.36 7.87,2.84L8.8,4.66C9.78,4.24 10.86,4 12,4C13.14,4 14.22,4.24 15.2,4.66L16.13,2.84C16.41,2.36 17,2.2 17.5,2.47C18,2.75 18.14,3.36 17.87,3.84L16.75,5.56C18.5,6.85 19.7,8.83 19.95,11.1L22,11A1,1 0 0,1 23,12A1,1 0 0,1 22,13L19.95,12.9C19.7,15.17 18.5,17.15 16.75,18.44L17.87,20.16C18.14,20.64 18,21.25 17.5,21.53C17,21.8 16.41,21.64 16.13,21.16L15.2,19.34C14.22,19.76 13.14,20 12,20C10.86,20 9.78,19.76 8.8,19.34L7.87,21.16C7.59,21.64 7,21.8 6.5,21.53C6,21.25 5.86,20.64 6.13,20.16L7.25,18.44C5.5,17.15 4.3,15.17 4.05,12.9L2,13A1,1 0 0,1 1,12A1,1 0 0,1 2,11M9.07,11.35C9.2,10.74 9.53,10.2 10,9.79L8.34,7.25C7.11,8.19 6.27,9.6 6.05,11.2L9.07,11.35M12,9C12.32,9 12.62,9.05 12.9,9.14L14.28,6.45C13.58,6.16 12.81,6 12,6C11.19,6 10.42,6.16 9.72,6.45L11.1,9.14C11.38,9.05 11.68,9 12,9M14.93,11.35L17.95,11.2C17.73,9.6 16.89,8.19 15.66,7.25L14,9.79C14.47,10.2 14.8,10.74 14.93,11.35M14.93,12.65C14.8,13.26 14.47,13.8 14,14.21L15.66,16.75C16.89,15.81 17.73,14.4 17.95,12.8L14.93,12.65M12,15C11.68,15 11.38,14.95 11.09,14.86L9.72,17.55C10.42,17.84 11.19,18 12,18C12.81,18 13.58,17.84 14.28,17.55L12.91,14.86C12.62,14.95 12.32,15 12,15M9.07,12.65L6.05,12.8C6.27,14.4 7.11,15.81 8.34,16.75L10,14.21C9.53,13.8 9.2,13.26 9.07,12.65Z\";\r\nvar mdiShoeBallet = \"M12.78 11.97C12.27 8.54 10.86 2 7.53 2S2.8 8.54 2.28 11.97C2.07 13.42 2 14.89 2.16 16.35C2.5 19.39 3.55 20.84 4.27 21.5C4.64 21.83 5.11 22 5.6 22H9.47C9.96 22 10.43 21.83 10.8 21.5C11.5 20.84 12.55 19.39 12.91 16.35C13.08 14.89 13 13.42 12.78 11.97M7.53 4C7.89 3.87 8.59 4.73 9.27 6.31L4.58 10.33C5.41 6.26 6.94 3.79 7.53 4M9.75 13H5.31C5.1 13 4.92 12.92 4.76 12.81L10 8.33C10.29 9.35 10.56 10.5 10.75 11.83C10.84 12.44 10.37 13 9.75 13M21.78 11.97C21.27 8.54 19.86 2 16.53 2C15.04 2 13.94 3.32 13.13 5.08C13.5 6.04 13.84 7.14 14.13 8.37L19.31 12.81C19.15 12.92 18.97 13 18.75 13H14.92C15.04 14.27 15.03 15.45 14.89 16.59C14.62 18.87 14 20.45 13.32 21.53C13.68 21.84 14.13 22 14.6 22H18.47C18.96 22 19.43 21.83 19.8 21.5C20.5 20.84 21.55 19.39 21.91 16.35C22.08 14.89 22 13.42 21.78 11.97M14.8 6.31C15.5 4.73 16.18 3.87 16.53 4C17.13 3.79 18.65 6.26 19.5 10.33L14.8 6.31Z\";\r\nvar mdiShoeCleat = \"M21 8C20.76 8 20.53 8 20.3 8L20.25 7.97C18.14 7.84 16.38 7.17 15.53 6.23L14 7C13.95 7.1 13.89 7.19 13.84 7.28C14.55 7.89 15 8.65 15 9.5C15 9.83 14.91 10.14 14.79 10.45L12.92 8.58C12.7 8.83 12.47 9.07 12.22 9.29L14.25 11.32C14.04 11.57 13.8 11.79 13.5 12L11.43 9.91C11.14 10.11 10.85 10.28 10.55 10.45L12.58 12.5C12.25 12.63 11.89 12.74 11.5 12.82L9.59 10.91C9.25 11.05 8.91 11.18 8.56 11.29L10.26 13C10.17 13 10.09 13 10 13C8.5 13 7.2 12.54 6.28 11.82C5.46 11.95 4.68 12 4 12C2 12 2 15 2 15V15C2 16.11 2.89 17 4 17H4V18C4 18.55 4.45 19 5 19S6 18.55 6 18V17H7V18C7 18.55 7.45 19 8 19S9 18.55 9 18V17H10V18C10 18.55 10.45 19 11 19S12 18.55 12 18V17H15V18C15 18.55 15.45 19 16 19S17 18.55 17 18V17H18V18C18 18.55 18.45 19 19 19S20 18.55 20 18V17H21C21 17 22 17 22 12.5C22 9 21 8 21 8Z\";\r\nvar mdiShoeFormal = \"M21.5,9V8H20.5L19.5,9H15L14,8H13L7,12H4A2,2 0 0,0 2,14V16H10L13,15H15V16H21.5V14C21.5,14 22,13 22,11.5C22,10 21.5,9 21.5,9Z\";\r\nvar mdiShoeHeel = \"M3,18H11.7L17,14H18V18H20V14C20,14 21,12 21,10C21,8 20.5,6 20.5,6H18.5L18,7L10,14H8L3,16V18Z\";\r\nvar mdiShoePrint = \"M10.74,11.72C11.21,12.95 11.16,14.23 9.75,14.74C6.85,15.81 6.2,13 6.16,12.86L10.74,11.72M5.71,10.91L10.03,9.84C9.84,8.79 10.13,7.74 10.13,6.5C10.13,4.82 8.8,1.53 6.68,2.06C4.26,2.66 3.91,5.35 4,6.65C4.12,7.95 5.64,10.73 5.71,10.91M17.85,19.85C17.82,20 17.16,22.8 14.26,21.74C12.86,21.22 12.8,19.94 13.27,18.71L17.85,19.85M20,13.65C20.1,12.35 19.76,9.65 17.33,9.05C15.22,8.5 13.89,11.81 13.89,13.5C13.89,14.73 14.17,15.78 14,16.83L18.3,17.9C18.38,17.72 19.89,14.94 20,13.65Z\";\r\nvar mdiShoeSneaker = \"M2 15C2 15 2 12 4 12C4.68 12 5.46 11.95 6.28 11.82C7.2 12.54 8.5 13 10 13H10.25L8.56 11.29C8.91 11.18 9.25 11.05 9.59 10.91L11.5 12.82C11.89 12.74 12.25 12.63 12.58 12.5L10.55 10.45C10.85 10.28 11.14 10.11 11.43 9.91L13.5 12C13.8 11.79 14.04 11.56 14.25 11.32L12.22 9.29C12.46 9.07 12.7 8.83 12.92 8.58L14.79 10.45C14.91 10.14 15 9.83 15 9.5C15 8.65 14.55 7.89 13.84 7.28C13.89 7.19 13.95 7.1 14 7L15.53 6.23C16.38 7.17 18.14 7.84 20.25 7.97L20.3 8H21C21 8 22 9 22 12.5C22 13.07 22 13.57 21.96 14H19C17.9 14 16.58 14.26 15.3 14.5C14.12 14.76 12.9 15 12 15H2M21 17C21 17 21.58 17 21.86 15H19C17 15 14 16 12 16H2.28C2.62 16.6 3.26 17 4 17H21Z\";\r\nvar mdiShopping = \"M12,13A5,5 0 0,1 7,8H9A3,3 0 0,0 12,11A3,3 0 0,0 15,8H17A5,5 0 0,1 12,13M12,3A3,3 0 0,1 15,6H9A3,3 0 0,1 12,3M19,6H17A5,5 0 0,0 12,1A5,5 0 0,0 7,6H5C3.89,6 3,6.89 3,8V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V8C21,6.89 20.1,6 19,6Z\";\r\nvar mdiShoppingMusic = \"M12,3A3,3 0 0,0 9,6H15A3,3 0 0,0 12,3M19,6A2,2 0 0,1 21,8V20A2,2 0 0,1 19,22H5C3.89,22 3,21.1 3,20V8C3,6.89 3.89,6 5,6H7A5,5 0 0,1 12,1A5,5 0 0,1 17,6H19M9,19L16.5,14L9,10V19Z\";\r\nvar mdiShoppingOutline = \"M19 6H17C17 3.2 14.8 1 12 1S7 3.2 7 6H5C3.9 6 3 6.9 3 8V20C3 21.1 3.9 22 5 22H19C20.1 22 21 21.1 21 20V8C21 6.9 20.1 6 19 6M12 3C13.7 3 15 4.3 15 6H9C9 4.3 10.3 3 12 3M19 20H5V8H19V20M12 12C10.3 12 9 10.7 9 9H7C7 11.8 9.2 14 12 14S17 11.8 17 9H15C15 10.7 13.7 12 12 12Z\";\r\nvar mdiShoppingSearch = \"M19 6H17A5 5 0 0 0 7 6H5A2 2 0 0 0 3 8V20A2 2 0 0 0 5 22H12.05A6.5 6.5 0 0 1 9 16.5A6.4 6.4 0 0 1 10.25 12.68A5 5 0 0 1 7 8H9A3 3 0 0 0 12 11H12.06A6.22 6.22 0 0 1 14.06 10.16A3 3 0 0 0 15 8H17A4.88 4.88 0 0 1 16.54 10.09A6.5 6.5 0 0 1 21 13.09V8A2 2 0 0 0 19 6M9 6A3 3 0 0 1 15 6M19.31 18.9A4.5 4.5 0 1 0 17.88 20.32L21 23.39L22.39 22M15.5 19A2.5 2.5 0 1 1 18 16.5A2.5 2.5 0 0 1 15.5 19Z\";\r\nvar mdiShore = \"M20 12H22V14H20C18.6 14 17.3 13.6 16 13C13.5 14.3 10.5 14.3 8 13C6.7 13.6 5.4 14 4 14H2V12H4C5.4 12 6.8 11.5 8 10.7C10.4 12.4 13.6 12.4 16 10.7C17.2 11.5 18.6 12 20 12M20 6H22V8H20C18.6 8 17.3 7.7 16 7C13.5 8.3 10.5 8.3 8 7C6.7 7.7 5.4 8 4 8H2V6H4C5.4 6 6.8 5.5 8 4.7C10.4 6.4 13.6 6.4 16 4.7C17.2 5.5 18.6 6 20 6M22 20H2V18H22\";\r\nvar mdiShovel = \"M15.1,1.81L12.27,4.64C11.5,5.42 11.5,6.69 12.27,7.47L13.68,8.88L9.13,13.43L6.31,10.6L4.89,12C-0.06,17 3.5,20.5 3.5,20.5C3.5,20.5 7,24 12,19.09L13.41,17.68L10.61,14.88L15.15,10.34L16.54,11.73C17.32,12.5 18.59,12.5 19.37,11.73L22.2,8.9L15.1,1.81M17.93,10.28L16.55,8.9L15.11,7.46L13.71,6.06L15.12,4.65L19.35,8.88L17.93,10.28Z\";\r\nvar mdiShovelOff = \"M15.1,1.81L12.27,4.65C11.5,5.43 11.5,6.69 12.27,7.47L13.68,8.89L13,9.62L14.44,11.06L15.17,10.33L16.56,11.72C17.34,12.5 18.61,12.5 19.39,11.72L22.22,8.88L15.1,1.81M17.93,10.28L13.7,6.06L15.11,4.65L19.34,8.88L17.93,10.28M20.7,20.24L19.29,21.65L11.5,13.88L10.5,14.88L13.33,17.69L12,19.09C7,24 3.5,20.5 3.5,20.5C3.5,20.5 -0.06,17 4.89,12L6.31,10.6L9.13,13.43L10.13,12.43L2.35,4.68L3.77,3.26L20.7,20.24Z\";\r\nvar mdiShower = \"M21,14V15C21,16.91 19.93,18.57 18.35,19.41L19,22H17L16.5,20C16.33,20 16.17,20 16,20H8C7.83,20 7.67,20 7.5,20L7,22H5L5.65,19.41C4.07,18.57 3,16.91 3,15V14H2V12H20V5A1,1 0 0,0 19,4C18.5,4 18.12,4.34 18,4.79C18.63,5.33 19,6.13 19,7H13A3,3 0 0,1 16,4C16.06,4 16.11,4 16.17,4C16.58,2.84 17.69,2 19,2A3,3 0 0,1 22,5V14H21V14M19,14H5V15A3,3 0 0,0 8,18H16A3,3 0 0,0 19,15V14Z\";\r\nvar mdiShowerHead = \"M20,20A1,1 0 0,1 21,21A1,1 0 0,1 20,22A1,1 0 0,1 19,21A1,1 0 0,1 20,20M16,20A1,1 0 0,1 17,21A1,1 0 0,1 16,22A1,1 0 0,1 15,21A1,1 0 0,1 16,20M12,20A1,1 0 0,1 13,21A1,1 0 0,1 12,22A1,1 0 0,1 11,21A1,1 0 0,1 12,20M8,20A1,1 0 0,1 9,21A1,1 0 0,1 8,22A1,1 0 0,1 7,21A1,1 0 0,1 8,20M4,20A1,1 0 0,1 5,21A1,1 0 0,1 4,22A1,1 0 0,1 3,21A1,1 0 0,1 4,20M6,17A1,1 0 0,1 7,18A1,1 0 0,1 6,19H6A1,1 0 0,1 5,18A1,1 0 0,1 6,17H6M10,17A1,1 0 0,1 11,18A1,1 0 0,1 10,19A1,1 0 0,1 9,18A1,1 0 0,1 10,17M14,17A1,1 0 0,1 15,18A1,1 0 0,1 14,19A1,1 0 0,1 13,18A1,1 0 0,1 14,17M18,17A1,1 0 0,1 19,18A1,1 0 0,1 18,19A1,1 0 0,1 17,18A1,1 0 0,1 18,17M8,14A1,1 0 0,1 9,15A1,1 0 0,1 8,16A1,1 0 0,1 7,15A1,1 0 0,1 8,14M12,14A1,1 0 0,1 13,15A1,1 0 0,1 12,16A1,1 0 0,1 11,15A1,1 0 0,1 12,14M16,14A1,1 0 0,1 17,15A1,1 0 0,1 16,16A1,1 0 0,1 15,15A1,1 0 0,1 16,14M19,12H5V10H19V12M17.92,9H6.08C6.5,6.5 8.5,4.5 11,4.08V2H13V4.08C15.5,4.5 17.5,6.5 17.92,9Z\";\r\nvar mdiShredder = \"M6,3V7H8V5H16V7H18V3H6M5,8A3,3 0 0,0 2,11V17H5V14H19V17H22V11A3,3 0 0,0 19,8H5M18,10A1,1 0 0,1 19,11A1,1 0 0,1 18,12A1,1 0 0,1 17,11A1,1 0 0,1 18,10M7,16V21H9V16H7M11,16V20H13V16H11M15,16V21H17V16H15Z\";\r\nvar mdiShuffle = \"M14.83,13.41L13.42,14.82L16.55,17.95L14.5,20H20V14.5L17.96,16.54L14.83,13.41M14.5,4L16.54,6.04L4,18.59L5.41,20L17.96,7.46L20,9.5V4M10.59,9.17L5.41,4L4,5.41L9.17,10.58L10.59,9.17Z\";\r\nvar mdiShuffleDisabled = \"M16,4.5V7H5V9H16V11.5L19.5,8M16,12.5V15H5V17H16V19.5L19.5,16\";\r\nvar mdiShuffleVariant = \"M17,3L22.25,7.5L17,12L22.25,16.5L17,21V18H14.26L11.44,15.18L13.56,13.06L15.5,15H17V12L17,9H15.5L6.5,18H2V15H5.26L14.26,6H17V3M2,6H6.5L9.32,8.82L7.2,10.94L5.26,9H2V6Z\";\r\nvar mdiShuriken = \"M14.5 9.5L12 2L9.5 9.5L2 12L9.5 14.5L12 22L14.5 14.5L22 12L14.5 9.5M12 13.7C11.1 13.7 10.3 13 10.3 12C10.3 11.1 11 10.3 12 10.3C12.9 10.3 13.7 11 13.7 12C13.7 12.9 12.9 13.7 12 13.7Z\";\r\nvar mdiSigma = \"M18,6H8.83L14.83,12L8.83,18H18V20H6V18L12,12L6,6V4H18V6Z\";\r\nvar mdiSigmaLower = \"M19,12C19,16.42 15.64,20 11.5,20C7.36,20 4,16.42 4,12C4,7.58 7.36,4 11.5,4H20V6H16.46C18,7.47 19,9.61 19,12M11.5,6C8.46,6 6,8.69 6,12C6,15.31 8.46,18 11.5,18C14.54,18 17,15.31 17,12C17,8.69 14.54,6 11.5,6Z\";\r\nvar mdiSignCaution = \"M2,3H22V13H18V21H16V13H8V21H6V13H2V3M18.97,11L20,9.97V7.15L16.15,11H18.97M13.32,11L19.32,5H16.5L10.5,11H13.32M7.66,11L13.66,5H10.83L4.83,11H7.66M5.18,5L4,6.18V9L8,5H5.18Z\";\r\nvar mdiSignDirection = \"M11,12H3.5L6,9.5L3.5,7H11V3L12,2L13,3V7H18L20.5,9.5L18,12H13V20A2,2 0 0,1 15,22H9A2,2 0 0,1 11,20V12Z\";\r\nvar mdiSignDirectionMinus = \"M20.5 9.5L18 12H13V22H9A2 2 0 0 1 11 20V12H3.5L6 9.5L3.5 7H11V3L12 2L13 3V7H18M23 18H15V20H23Z\";\r\nvar mdiSignDirectionPlus = \"M13 20H13.09A5.5 5.5 0 0 0 13.81 22H9A2 2 0 0 1 11 20V12H3.5L6 9.5L3.5 7H11V3L12 2L13 3V7H18L20.5 9.5L18 12H13M18 15V18H15V20H18V23H20V20H23V18H20V15Z\";\r\nvar mdiSignDirectionRemove = \"M13 20H13.09A5.5 5.5 0 0 0 13.81 22H9A2 2 0 0 1 11 20V12H3.5L6 9.5L3.5 7H11V3L12 2L13 3V7H18L20.5 9.5L18 12H13M21.12 15.46L19 17.59L16.88 15.46L15.46 16.88L17.59 19L15.46 21.12L16.88 22.54L19 20.41L21.12 22.54L22.54 21.12L20.41 19L22.54 16.88Z\";\r\nvar mdiSignPole = \"M11 3L12 2L13 3V20C14.11 20 15 20.9 15 22H9C9 20.9 9.9 20 11 20V3Z\";\r\nvar mdiSignRealEstate = \"M18 8H8C6.9 8 6 8.9 6 10V16C6 17.11 6.9 18 8 18H18C19.11 18 20 17.11 20 16V10C20 8.9 19.11 8 18 8M14 16H8V14H14V16M18 12H8V10H18V12M22 6H4V22H2V2H4V4H22V6Z\";\r\nvar mdiSignText = \"M11,3L12,2L13,3V5H20A1,1 0 0,1 21,6V16A1,1 0 0,1 20,17H13V20A2,2 0 0,1 15,22H9A2,2 0 0,1 11,20V17H4A1,1 0 0,1 3,16V6A1,1 0 0,1 4,5H11V3M6,8V10H18V8H6M6,12V14H13V12H6Z\";\r\nvar mdiSignal = \"M3,21H6V18H3M8,21H11V14H8M13,21H16V9H13M18,21H21V3H18V21Z\";\r\nvar mdiSignal2g = \"M11,19.5H2V13.5A3,3 0 0,1 5,10.5H8V7.5H2V4.5H8A3,3 0 0,1 11,7.5V10.5A3,3 0 0,1 8,13.5H5V16.5H11M22,10.5H17.5V13.5H19V16.5H16V7.5H22V4.5H16A3,3 0 0,0 13,7.5V16.5A3,3 0 0,0 16,19.5H19A3,3 0 0,0 22,16.5\";\r\nvar mdiSignal3g = \"M11,16.5V14.25C11,13 10,12 8.75,12C10,12 11,11 11,9.75V7.5A3,3 0 0,0 8,4.5H2V7.5H8V10.5H5V13.5H8V16.5H2V19.5H8A3,3 0 0,0 11,16.5M22,16.5V10.5H17.5V13.5H19V16.5H16V7.5H22V4.5H16A3,3 0 0,0 13,7.5V16.5A3,3 0 0,0 16,19.5H19A3,3 0 0,0 22,16.5Z\";\r\nvar mdiSignal4g = \"M22,16.5V10.5H17.5V13.5H19V16.5H16V7.5H22V4.5H16A3,3 0 0,0 13,7.5V16.5A3,3 0 0,0 16,19.5H19A3,3 0 0,0 22,16.5M8,19.5H11V4.5H8V10.5H5V4.5H2V13.5H8V19.5Z\";\r\nvar mdiSignal5g = \"M22,16.5V10.5H17.5V13.5H19V16.5H16V7.5H22V4.5H16A3,3 0 0,0 13,7.5V16.5A3,3 0 0,0 16,19.5H19A3,3 0 0,0 22,16.5M10,4.5H3V12L3,13.5H7V16.5H3V19.5H8.5A1.5,1.5 0 0,0 10,18V12A1.5,1.5 0 0,0 8.5,10.5H6V7.5H10V4.5Z\";\r\nvar mdiSignalCellular1 = \"M19.5,5.5V18.5H17.5V5.5H19.5M12.5,10.5V18.5H10.5V10.5H12.5M21,4H16V20H21V4M14,9H9V20H14V9M7,14H2V20H7V14Z\";\r\nvar mdiSignalCellular2 = \"M19.5,5.5V18.5H17.5V5.5H19.5M21,4H16V20H21V4M14,9H9V20H14V9M7,14H2V20H7V14Z\";\r\nvar mdiSignalCellular3 = \"M21,4H16V20H21V4M14,9H9V20H14V9M7,14H2V20H7V14Z\";\r\nvar mdiSignalCellularOutline = \"M19.5,5.5V18.5H17.5V5.5H19.5M12.5,10.5V18.5H10.5V10.5H12.5M5.5,15.5V18.5H3.5V15.5H5.5M21,4H16V20H21V4M14,9H9V20H14V9M7,14H2V20H7V14Z\";\r\nvar mdiSignalDistanceVariant = \"M4,6V4A12,12 0 0,1 16,16H14A10,10 0 0,0 4,6M4,10V8A8,8 0 0,1 12,16H10A6,6 0 0,0 4,10M4,12A4,4 0 0,1 8,16H4V12M3,18H19V16L22,19L19,22V20H3V18Z\";\r\nvar mdiSignalHspa = \"M10.5,10.5H13.5V4.5H16.5V19.5H13.5V13.5H10.5V19.5H7.5V4.5H10.5V10.5Z\";\r\nvar mdiSignalHspaPlus = \"M19,8V11H22V14H19V17H16V14H13V11H16V8H19M5,10.5H8V4.5H11V19.5H8V13.5H5V19.5H2V4.5H5V10.5Z\";\r\nvar mdiSignalOff = \"M18,3V16.18L21,19.18V3H18M4.28,5L3,6.27L10.73,14H8V21H11V14.27L13,16.27V21H16V19.27L19.73,23L21,21.72L4.28,5M13,9V11.18L16,14.18V9H13M3,18V21H6V18H3Z\";\r\nvar mdiSignalVariant = \"M4,6V4H4.1C12.9,4 20,11.1 20,19.9V20H18V19.9C18,12.2 11.8,6 4,6M4,10V8A12,12 0 0,1 16,20H14A10,10 0 0,0 4,10M4,14V12A8,8 0 0,1 12,20H10A6,6 0 0,0 4,14M4,16A4,4 0 0,1 8,20H4V16Z\";\r\nvar mdiSignature = \"M22,22H2V20H22V22M2.26,16.83L5.09,14L2.26,11.17L3.67,9.76L6.5,12.59L9.33,9.76L10.74,11.17L7.91,14L10.74,16.83L9.33,18.24L6.5,15.41L3.67,18.24L2.26,16.83Z\";\r\nvar mdiSignatureFreehand = \"M22,22H2V20H22V22M6.2,17.3L5.5,18L4.1,16.6L2.7,18L2,17.3L3.4,15.9L2,14.5L2.7,13.8L4.1,15.2L5.5,13.8L6.2,14.5L4.8,15.9L6.2,17.3M16.22,14.43C16.22,13.85 15.5,13.2 14.06,12.46C12.23,11.54 11,10.79 10.36,10.24C9.71,9.68 9.39,9.06 9.39,8.37C9.39,6.59 10.3,5.12 12.12,3.95C13.94,2.78 15.43,2.19 16.57,2.19C17.31,2.19 17.85,2.32 18.18,2.58C18.5,2.83 18.68,3.27 18.68,3.9C18.68,4.18 18.56,4.42 18.31,4.63C18.07,4.83 17.87,4.93 17.74,4.93C17.63,4.93 17.43,4.83 17.13,4.64L16.55,4.38C16.08,4.38 15.14,4.71 13.71,5.38C12.29,6.04 11.58,6.79 11.58,7.63C11.58,8.14 11.82,8.6 12.32,9C12.82,9.42 13.71,9.93 15,10.53C16.03,11 16.86,11.5 17.5,12.07C18.1,12.61 18.41,13.25 18.41,14C18.41,15.34 17.47,16.41 15.58,17.17C13.7,17.94 11.9,18.32 10.19,18.32C8.75,18.32 8,17.83 8,16.86C8,16.5 8.19,16.27 8.5,16.11C8.83,15.95 9.16,15.87 9.5,15.87L10.25,16L10.97,16.13C11.95,16.13 13,15.97 14.13,15.64C15.26,15.32 15.96,14.91 16.22,14.43Z\";\r\nvar mdiSignatureImage = \"M22,22H2V20H22V22M6.2,17.3L4.8,15.9L6.2,14.5L5.5,13.8L4.1,15.2L2.7,13.8L2,14.5L3.4,15.9L2,17.3L2.7,18L4.1,16.6L5.5,18L6.2,17.3M20,5H10A2,2 0 0,0 8,7V16A2,2 0 0,0 10,18H20A2,2 0 0,0 22,16V7A2,2 0 0,0 20,5M10,16L12.6,12.7L14.4,14.9L16.8,11.6L20,16H10Z\";\r\nvar mdiSignatureText = \"M22,22H2V20H22V22M6.2,17.3L4.8,15.9L6.2,14.5L5.5,13.8L4.1,15.2L2.7,13.8L2,14.5L3.4,15.9L2,17.3L2.7,18L4.1,16.6L5.5,18L6.2,17.3M20.5,3L21.7,7.4L20.7,7.7C20.2,6.8 19.8,6 19.3,5.5C18.7,5 18.1,5 17.5,5H15V15.5C15,16 15,16.5 15.3,16.7C15.6,16.9 16.3,16.9 17,16.9V17.9H11V16.9C11.7,16.9 12.3,16.9 12.7,16.7C13,16.5 13,16 13,15.5V5H10.5C9.9,5 9.3,5 8.7,5.4C8.2,5.8 7.7,6.7 7.3,7.6L6.3,7.3L7.5,3H20.5Z\";\r\nvar mdiSilo = \"M8.5,2C11.85,2 14.6,4.53 14.96,7.78L22,12V14L20,12.8V22H18V11.6L15,9.8V22H13V9H4V22H2V8.5A6.5,6.5 0 0,1 8.5,2M8.5,4C6.54,4 4.87,5.25 4.26,7H12.74C12.13,5.25 10.46,4 8.5,4M6,11H11V13H6V11M6,15H11V17H6V15M6,19H11V21H6V19Z\";\r\nvar mdiSilverware = \"M8.1,13.34L3.91,9.16C2.35,7.59 2.35,5.06 3.91,3.5L10.93,10.5L8.1,13.34M14.88,11.53L13.41,13L20.29,19.88L18.88,21.29L12,14.41L5.12,21.29L3.71,19.88L13.47,10.12C12.76,8.59 13.26,6.44 14.85,4.85C16.76,2.93 19.5,2.57 20.96,4.03C22.43,5.5 22.07,8.24 20.15,10.15C18.56,11.74 16.41,12.24 14.88,11.53Z\";\r\nvar mdiSilverwareClean = \"M15 0L14.38 1.37L13 2L14.38 2.63L15 4L15.63 2.63L17 2L15.63 1.37L15 0M10.5 2L9.41 4.41L7 5.5L9.41 6.59L10.5 9L11.6 6.59L14 5.5L11.6 4.41L10.5 2M18.89 5.14C17.56 5.06 16.04 5.65 14.84 6.84C13.25 8.43 12.75 10.58 13.46 12.11L3.7 21.87L5.11 23.28L12 16.41L18.88 23.29L20.29 21.88L13.41 15L14.88 13.53C16.41 14.24 18.56 13.74 20.15 12.15C22.06 10.24 22.43 7.5 20.96 6.03C20.41 5.5 19.68 5.19 18.89 5.14M3.91 5.5C2.35 7.06 2.35 9.59 3.91 11.16L8.1 15.34L10.93 12.5L3.91 5.5Z\";\r\nvar mdiSilverwareFork = \"M5.12,21.29L3.71,19.88L13.36,10.22L13.16,10C12.38,9.23 12.38,7.97 13.16,7.19L17.5,2.82L18.43,3.74L15.19,7L16.15,7.94L19.39,4.69L20.31,5.61L17.06,8.85L18,9.81L21.26,6.56L22.18,7.5L17.81,11.84C17.03,12.62 15.77,12.62 15,11.84L14.78,11.64L5.12,21.29Z\";\r\nvar mdiSilverwareForkKnife = \"M11,9H9V2H7V9H5V2H3V9C3,11.12 4.66,12.84 6.75,12.97V22H9.25V12.97C11.34,12.84 13,11.12 13,9V2H11V9M16,6V14H18.5V22H21V2C18.24,2 16,4.24 16,6Z\";\r\nvar mdiSilverwareSpoon = \"M14.88,11.53L5.12,21.29L3.71,19.88L13.47,10.12C12.76,8.59 13.26,6.44 14.85,4.85C16.76,2.93 19.5,2.57 20.96,4.03C22.43,5.5 22.07,8.24 20.15,10.15C18.56,11.74 16.41,12.24 14.88,11.53Z\";\r\nvar mdiSilverwareVariant = \"M8.1,13.34L3.91,9.16C2.35,7.59 2.35,5.06 3.91,3.5L10.93,10.5L8.1,13.34M13.41,13L20.29,19.88L18.88,21.29L12,14.41L5.12,21.29L3.71,19.88L13.36,10.22L13.16,10C12.38,9.23 12.38,7.97 13.16,7.19L17.5,2.82L18.43,3.74L15.19,7L16.15,7.94L19.39,4.69L20.31,5.61L17.06,8.85L18,9.81L21.26,6.56L22.18,7.5L17.81,11.84C17.03,12.62 15.77,12.62 15,11.84L14.78,11.64L13.41,13Z\";\r\nvar mdiSim = \"M20,4A2,2 0 0,0 18,2H10L4,8V20A2,2 0 0,0 6,22H18C19.11,22 20,21.1 20,20V4M9,19H7V17H9V19M17,19H15V17H17V19M9,15H7V11H9V15M13,19H11V15H13V19M13,13H11V11H13V13M17,15H15V11H17V15Z\";\r\nvar mdiSimAlert = \"M13 13H11V7H13M13 17H11V15H13M18 2H10L4 8V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V4C20 2.9 19.1 2 18 2Z\";\r\nvar mdiSimAlertOutline = \"M13 13H11V7H13M13 17H11V15H13M18 4V20H6V8.8L10.8 4H18M18 2H10L4 8V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V4C20 2.9 19.1 2 18 2Z\";\r\nvar mdiSimOff = \"M20.84 22.73L19.46 21.35C19.1 21.75 18.58 22 18 22H6C4.89 22 4 21.11 4 20V8L5.06 6.95L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M20 4C20 2.9 19.11 2 18 2H10L7.6 4.4L20 16.8V4Z\";\r\nvar mdiSimOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L5.06 6.95L4 8V20C4 21.11 4.89 22 6 22H18C18.58 22 19.1 21.75 19.46 21.35L20.84 22.73L22.11 21.46M18 20H6V8.83L6.47 8.36L18 19.89V20M10.83 4H18V14.8L20 16.8V4C20 2.9 19.11 2 18 2H10L7.6 4.4L9 5.81L10.83 4Z\";\r\nvar mdiSimOutline = \"M18 4V20H6V8.8L10.8 4H18M18 2H10L4 8V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V4C20 2.9 19.1 2 18 2M9.5 19H7.5V17H9.5V19M16.5 19H14.5V17H16.5V19M9.5 15H7.5V11H9.5V15M13 19H11V15H13V19M13 13H11V11H13V13M16.5 15H14.5V11H16.5V15Z\";\r\nvar mdiSimpleIcons = \"M18.25 17C18.25 17.88 18.07 18.74 17.71 19.53H16.31C17.71 17.15 16.91 14.09 14.53 12.69C13.76 12.24 12.89 12 12 12C9.24 12 7 9.76 7 7C7 4.24 9.24 2 12 2C14.76 2 17 4.24 17 7H15.75C15.75 4.93 14.07 3.25 12 3.25C9.93 3.25 8.25 4.93 8.25 7C8.25 9.07 9.93 10.75 12 10.75C15.45 10.75 18.25 13.56 18.25 17M6.29 19.53C5.93 18.74 5.75 17.87 5.75 17H7C7 17.93 7.25 18.79 7.69 19.53H6.29M18.25 20.75V22H5.75V20.75H9.5V15.75H8.25V14.5H15.75V15.75H14.5V20.75H18.25M13.25 15.75H10.75V20.75H13.25V15.75M14.44 7.07C14.4 8.4 13.33 9.47 12 9.5C10.62 9.46 9.53 8.32 9.57 6.94C9.6 5.61 10.67 4.53 12 4.5C13.38 4.54 14.47 5.68 14.44 7.07M13.25 7C13.25 6.31 12.69 5.75 12 5.75C11.31 5.75 10.75 6.31 10.75 7C10.75 7.69 11.31 8.25 12 8.25C12.69 8.25 13.25 7.69 13.25 7Z\";\r\nvar mdiSinaWeibo = \"M9.82,13.87C10.89,13.87 11.77,14.74 11.77,15.82A1.95,1.95 0 0,1 9.82,17.77C8.74,17.77 7.87,16.89 7.87,15.82C7.87,14.74 8.74,13.87 9.82,13.87M14.5,3.34L15.18,3.31C18.94,3.31 22,6.37 22,10.13L21.95,10.95L20.76,10.58L20.78,10.13C20.78,7.04 18.27,4.53 15.18,4.53L14.83,4.54L14.5,3.34M15.32,6.23C17.38,6.3 19.05,8 19.08,10.06L17.84,9.68C17.65,8.56 16.78,7.68 15.67,7.5L15.32,6.23M2,15.41C1.97,14.8 2.07,12.64 4.95,9.97C8.35,6.81 9.82,7.05 9.82,7.05C9.82,7.05 13,6.75 11.06,10.46H11.13C11.6,9.96 12.62,9.21 14.69,9C16.77,8.79 16.77,10.5 16.5,11.7C18.38,12.64 19.56,14.03 19.56,15.58C19.56,18.4 15.63,20.69 10.78,20.69H10.65L10.5,20.69C7,20.69 4,19.42 2.71,17.59C2.25,16.97 2,16.29 2,15.58V15.41M9.82,11.92C6.59,11.92 3.97,13.67 3.97,15.82C3.97,17.97 6.59,19.72 9.82,19.72C13.05,19.72 15.67,17.97 15.67,15.82C15.67,13.67 13.05,11.92 9.82,11.92Z\";\r\nvar mdiSineWave = \"M16.5,21C13.5,21 12.31,16.76 11.05,12.28C10.14,9.04 9,5 7.5,5C4.11,5 4,11.93 4,12H2C2,11.63 2.06,3 7.5,3C10.5,3 11.71,7.25 12.97,11.74C13.83,14.8 15,19 16.5,19C19.94,19 20.03,12.07 20.03,12H22.03C22.03,12.37 21.97,21 16.5,21Z\";\r\nvar mdiSitemap = \"M9,2V8H11V11H5C3.89,11 3,11.89 3,13V16H1V22H7V16H5V13H11V16H9V22H15V16H13V13H19V16H17V22H23V16H21V13C21,11.89 20.11,11 19,11H13V8H15V2H9Z\";\r\nvar mdiSizeL = \"M9 7V17H15V15H11V7H9Z\";\r\nvar mdiSizeM = \"M9 7C7.9 7 7 7.9 7 9V17H9V9H11V16H13V9H15V17H17V9C17 7.9 16.11 7 15 7H9Z\";\r\nvar mdiSizeS = \"M11 7C9.9 7 9 7.9 9 9V11C9 12.11 9.9 13 11 13H13V15H9V17H13C14.11 17 15 16.11 15 15V13C15 11.9 14.11 11 13 11H11V9H15V7H11Z\";\r\nvar mdiSizeXl = \"M6 7H8L9 9.5L10 7H12L10 12L12 17H10L9 14.5L8 17H6L8 12L6 7M13 7H15V15H19V17H13V7Z\";\r\nvar mdiSizeXs = \"M6 7H8L9 9.5L10 7H12L10 12L12 17H10L9 14.5L8 17H6L8 12L6 7M15 7H19V9H15V11H17C18.11 11 19 11.9 19 13V15C19 16.11 18.11 17 17 17H13V15H17V13H15C13.9 13 13 12.11 13 11V9C13 7.9 13.9 7 15 7Z\";\r\nvar mdiSizeXxl = \"M9 7H11L12 9.5L13 7H15L13 12L15 17H13L12 14.5L11 17H9L11 12L9 7M16 7H18V15H22V17H16V7M2 7H4L5 9.5L6 7H8L6 12L8 17H6L5 14.5L4 17H2L4 12L2 7Z\";\r\nvar mdiSizeXxs = \"M9 7H11L12 9.5L13 7H15L13 12L15 17H13L12 14.5L11 17H9L11 12L9 7M18 7H22V9H18V11H20C21.11 11 22 11.9 22 13V15C22 16.11 21.11 17 20 17H16V15H20V13H18C16.9 13 16 12.11 16 11V9C16 7.9 16.9 7 18 7M2 7H4L5 9.5L6 7H8L6 12L8 17H6L5 14.5L4 17H2L4 12L2 7Z\";\r\nvar mdiSizeXxxl = \"M9 7H11L12 9.5L13 7H15L13 12L15 17H13L12 14.5L11 17H9L11 12L9 7M16 7H18V15H22V17H16V7M8 15C8 16.11 7.11 17 6 17H2V15H6V13H4V11H6V9H2V7H6C7.1 7 8 7.89 8 9V10.5C8 11.33 7.33 12 6.5 12C7.33 12 8 12.67 8 13.5V15Z\";\r\nvar mdiSkate = \"M21.1,16.5C20.36,16.17 19.5,16.5 19.19,17.26C19.06,17.58 18.8,17.87 18.5,18H3V21H17.97C19.68,21 21.22,20 21.88,18.41C22.2,17.67 21.86,16.81 21.1,16.5M19,15C19,15 19,16 17,16C15,16 4,16 4,16V3H11L11.21,4.5H9.24V6H11.43L11.64,7.5H9.24V9H11.86L12,10H14C14,10 19,10 19,15Z\";\r\nvar mdiSkateboard = \"M9 14.5C9 15.33 8.33 16 7.5 16S6 15.33 6 14.5 6.67 13 7.5 13 9 13.67 9 14.5M16.5 13C15.67 13 15 13.67 15 14.5S15.67 16 16.5 16C17.33 16 18 15.33 18 14.5S17.33 13 16.5 13M21.59 9.19C21.14 8.87 20.5 8.97 20.19 9.41L20.06 9.59C19.88 9.85 19.57 10 19.26 10L4.74 10C4.43 10 4.13 9.85 3.94 9.59L3.81 9.41C3.5 8.97 2.86 8.87 2.41 9.19C1.96 9.5 1.87 10.15 2.19 10.59L2.32 10.77C2.88 11.54 3.79 12 4.74 12H19.26C20.21 12 21.12 11.54 21.68 10.77L21.81 10.59C22.13 10.15 22.04 9.5 21.59 9.19Z\";\r\nvar mdiSkewLess = \"M17.5,11L15.41,20H10.5L12.59,11H17.5M20,9H11L8,22H17L20,9M4,6L8,2V5H16V7H8V10L4,6Z\";\r\nvar mdiSkewMore = \"M12.5,11L10.41,20H5.5L7.59,11H12.5M15,9H6L3,22H12L15,9M21,6L17,2V5H9V7H17V10L21,6Z\";\r\nvar mdiSki = \"M15.3 18.3L17 12.9L18.4 13.3L16.7 18.7L15.3 18.3M17.3 5.2C18.2 5.2 19 4.4 19 3.5S18.3 1.8 17.3 1.8C16.4 1.8 15.6 2.6 15.6 3.5S16.4 5.2 17.3 5.2M21.3 19.8C20.7 20.1 20.1 20.4 19.4 20.5C18.7 20.6 18 20.6 17.3 20.4L11 18.5L13.4 11.7L10.9 8.7L13.8 7.1C13.8 7.1 14.9 10 15 10.3S15.3 10.8 15.6 10.9L19.7 12.1L20.2 10.3L19.3 9.9L19.9 7.8L18.5 7.4L18 9.4L16.8 8.9L15.4 5C15 4.2 14 3.8 13.1 4.2L8.5 6.7C7.6 7.2 7.3 8.3 7.8 9.1C7.9 9.3 10.8 12.3 10.8 12.3L9.1 18L2.3 16L2 17.3L16.9 21.7C18.6 22.2 20.4 22 22 21.1L21.3 19.8Z\";\r\nvar mdiSkiCrossCountry = \"M15 1.2C16 1.2 16.8 2 16.8 3S16 4.8 15 4.8 13.2 4 13.2 3 14 1.2 15 1.2M11 23V21.7H9.3L11.7 14.9L14 18V21.7H13V23H20V21.7H15.8V16.5L13.3 12L14 9.2L15.1 11H20V9.1H16.4L14.4 5.8C14.1 5.3 13.5 5 12.9 5C12.7 5 12.6 5.1 12.4 5.1L7 6.8V12H8.8V8.3L11 7.7L7.4 21.7H4V23\";\r\nvar mdiSkiWater = \"M4.2 3.5C4.2 2.7 4.9 1.9 5.8 1.9C6.7 1.9 7.4 2.6 7.4 3.5S6.6 5 5.8 5 4.2 4.3 4.2 3.5M22 3.9L21.5 3L13.5 7.1L14 8L22 3.9M20.8 20.3L21.7 21.2C21.1 21.8 20.5 22.2 19.8 22.5S18.3 23 17.5 23H2V21.7H4.7L6.8 18.2L4.5 15L3.7 7.2C3.7 6.3 4.5 5.5 5.4 5.5C5.7 5.5 6 5.6 6.2 5.7L9.7 8.3L12 7.5L12.8 9.1L9.3 10.6C9.2 10.5 7.7 9.4 6.6 8.5L7 12L12.3 16.5L14 21.7H17.5C18.1 21.7 18.7 21.6 19.3 21.3C19.9 21.1 20.4 20.7 20.8 20.3M7 21.7H12L10.4 17.8L8.1 15.9L9.3 18.4L7 21.7Z\";\r\nvar mdiSkipBackward = \"M20,5V19L13,12M6,5V19H4V5M13,5V19L6,12\";\r\nvar mdiSkipBackwardOutline = \"M18,14.17L15.83,12L18,9.83V14.17M20,19V5L13,12M4,19H6V5H4M11,14.17L8.83,12L11,9.83V14.17M13,19V5L6,12\";\r\nvar mdiSkipForward = \"M4,5V19L11,12M18,5V19H20V5M11,5V19L18,12\";\r\nvar mdiSkipForwardOutline = \"M6,9.83L8.17,12L6,14.17V9.83M4,5V19L11,12M20,5H18V19H20M13,9.83L15.17,12L13,14.17V9.83M11,5V19L18,12\";\r\nvar mdiSkipNext = \"M16,18H18V6H16M6,18L14.5,12L6,6V18Z\";\r\nvar mdiSkipNextCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M8,8L13,12L8,16M14,8H16V16H14\";\r\nvar mdiSkipNextCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4M8,8V16L13,12M14,8V16H16V8\";\r\nvar mdiSkipNextOutline = \"M6,18L14.5,12L6,6M8,9.86L11.03,12L8,14.14M16,6H18V18H16\";\r\nvar mdiSkipPrevious = \"M6,18V6H8V18H6M9.5,12L18,6V18L9.5,12Z\";\r\nvar mdiSkipPreviousCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M8,8H10V16H8M16,8V16L11,12\";\r\nvar mdiSkipPreviousCircleOutline = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4C7.59,4 4,7.59 4,12C4,16.41 7.59,20 12,20C16.41,20 20,16.41 20,12C20,7.59 16.41,4 12,4M16,8V16L11,12M10,8V16H8V8\";\r\nvar mdiSkipPreviousOutline = \"M6,6H8V18H6M9.5,12L18,18V6M16,14.14L12.97,12L16,9.86V14.14Z\";\r\nvar mdiSkull = \"M12,2A9,9 0 0,0 3,11C3,14.03 4.53,16.82 7,18.47V22H9V19H11V22H13V19H15V22H17V18.46C19.47,16.81 21,14 21,11A9,9 0 0,0 12,2M8,11A2,2 0 0,1 10,13A2,2 0 0,1 8,15A2,2 0 0,1 6,13A2,2 0 0,1 8,11M16,11A2,2 0 0,1 18,13A2,2 0 0,1 16,15A2,2 0 0,1 14,13A2,2 0 0,1 16,11M12,14L13.5,17H10.5L12,14Z\";\r\nvar mdiSkullCrossbones = \"M15.8,18.5L21.8,20.1L21.4,22L12,19.5L2.6,22L2.1,20.1L8.1,18.5L2,16.9L2.5,15L11.9,17.5L21.3,15L21.8,16.9L15.8,18.5M18,8C18,9.8 17.2,11.3 16,12.4V15H14V13.7L14,13H13V15H11V13H10V13.7L10,15H8V12.4C6.8,11.3 6,9.8 6,8A6,6 0 0,1 12,2A6,6 0 0,1 18,8M11,7.5C11,6.7 10.3,6 9.5,6C8.7,6 8,6.7 8,7.5C8,8.3 8.7,9 9.5,9C10.3,9 11,8.3 11,7.5M13,11L12,9L11,11H13M16,7.5C16,6.7 15.3,6 14.5,6C13.7,6 13,6.7 13,7.5C13,8.3 13.7,9 14.5,9C15.3,9 16,8.3 16,7.5Z\";\r\nvar mdiSkullCrossbonesOutline = \"M15.8,18.5L21.8,20.1L21.4,22L12,19.5L2.6,22L2.1,20.1L8.1,18.5L2,16.9L2.5,15L11.9,17.5L21.3,15L21.8,16.9L15.8,18.5M9.5,6C8.7,6 8,6.7 8,7.5C8,8.3 8.7,9 9.5,9C10.3,9 11,8.3 11,7.5C11,6.7 10.3,6 9.5,6M14.5,6C13.7,6 13,6.7 13,7.5C13,8.3 13.7,9 14.5,9C15.3,9 16,8.3 16,7.5C16,6.7 15.3,6 14.5,6M13,11L12,9L11,11H13M12,1C8.1,1 5,4.1 5,8C5,9.9 5.8,11.6 7,12.9V16H17V12.9C18.2,11.6 19,9.9 19,8C19,4.1 15.9,1 12,1M15,12V14H14V12H13V14H11V12H10V14H9V12H9C7.8,11.1 7,9.7 7,8C7,5.2 9.2,3 12,3C14.8,3 17,5.2 17,8C17,9.6 16.2,11.1 15,12Z\";\r\nvar mdiSkullOutline = \"M8,15A2,2 0 0,1 6,13A2,2 0 0,1 8,11A2,2 0 0,1 10,13A2,2 0 0,1 8,15M10.5,17L12,14L13.5,17H10.5M16,15A2,2 0 0,1 14,13A2,2 0 0,1 16,11A2,2 0 0,1 18,13A2,2 0 0,1 16,15M22,11A10,10 0 0,0 12,1A10,10 0 0,0 2,11C2,13.8 3.2,16.3 5,18.1V22H19V18.1C20.8,16.3 22,13.8 22,11M17,20H15V18H13V20H11V18H9V20H7V17.2C5.2,15.7 4,13.5 4,11A8,8 0 0,1 12,3A8,8 0 0,1 20,11C20,13.5 18.8,15.8 17,17.2V20Z\";\r\nvar mdiSkullScan = \"M2 0C.9 0 0 .9 0 2V6H2V2H6V0H2M18 0V2H22V6H24V2C24 .9 23.1 0 22 0H18M12 3C7.6 3 4 6.6 4 11C4 13.5 5.2 15.8 7 17.2V21H9V18H11V21H13V18H15V21H17V17.2C18.8 15.7 20 13.5 20 11C20 6.6 16.4 3 12 3M8 14C6.9 14 6 13.1 6 12S6.9 10 8 10 10 10.9 10 12 9.1 14 8 14M10.5 16L12 13L13.5 16H10.5M16 14C14.9 14 14 13.1 14 12S14.9 10 16 10 18 10.9 18 12 17.1 14 16 14M0 18V22C0 23.1 .9 24 2 24H6V22H2V18H0M22 18V22H18V24H22C23.1 24 24 23.1 24 22V18H22Z\";\r\nvar mdiSkullScanOutline = \"M2 0C.9 0 0 .9 0 2V6H2V2H6V0H2M18 0V2H22V6H24V2C24 .9 23.1 0 22 0H18M9.5 13C8.7 13 8 12.3 8 11.5S8.7 10 9.5 10 11 10.7 11 11.5 10.3 13 9.5 13M11 15L12 13L13 15H11M14.5 13C13.7 13 13 12.3 13 11.5S13.7 10 14.5 10 16 10.7 16 11.5 15.3 13 14.5 13M0 18V22C0 23.1 .9 24 2 24H6V22H2V18H0M22 18V22H18V24H22C23.1 24 24 23.1 24 22V18H22M12 3C7.6 3 4 6.6 4 11C4 13 4.8 14.9 6 16.3V21H18V16.3C19.2 14.9 20 13.1 20 11C20 6.6 16.4 3 12 3M16 15.4V19H14V17H13V19H11V17H10V19H8V15.4C6.8 14.3 6 12.7 6 11C6 7.7 8.7 5 12 5S18 7.7 18 11C18 12.8 17.2 14.3 16 15.4Z\";\r\nvar mdiSkype = \"M18,6C20.07,8.04 20.85,10.89 20.36,13.55C20.77,14.27 21,15.11 21,16A5,5 0 0,1 16,21C15.11,21 14.27,20.77 13.55,20.36C10.89,20.85 8.04,20.07 6,18C3.93,15.96 3.15,13.11 3.64,10.45C3.23,9.73 3,8.89 3,8A5,5 0 0,1 8,3C8.89,3 9.73,3.23 10.45,3.64C13.11,3.15 15.96,3.93 18,6M12.04,17.16C14.91,17.16 16.34,15.78 16.34,13.92C16.34,12.73 15.78,11.46 13.61,10.97L11.62,10.53C10.86,10.36 10,10.13 10,9.42C10,8.7 10.6,8.2 11.7,8.2C13.93,8.2 13.72,9.73 14.83,9.73C15.41,9.73 15.91,9.39 15.91,8.8C15.91,7.43 13.72,6.4 11.86,6.4C9.85,6.4 7.7,7.26 7.7,9.54C7.7,10.64 8.09,11.81 10.25,12.35L12.94,13.03C13.75,13.23 13.95,13.68 13.95,14.1C13.95,14.78 13.27,15.45 12.04,15.45C9.63,15.45 9.96,13.6 8.67,13.6C8.09,13.6 7.67,14 7.67,14.57C7.67,15.68 9,17.16 12.04,17.16Z\";\r\nvar mdiSkypeBusiness = \"M12.03,16.53C9.37,16.53 8.18,15.22 8.18,14.24C8.18,13.74 8.55,13.38 9.06,13.38C10.2,13.38 9.91,15 12.03,15C13.12,15 13.73,14.43 13.73,13.82C13.73,13.46 13.55,13.06 12.83,12.88L10.46,12.29C8.55,11.81 8.2,10.78 8.2,9.81C8.2,7.79 10.1,7.03 11.88,7.03C13.5,7.03 15.46,7.94 15.46,9.15C15.46,9.67 15,9.97 14.5,9.97C13.5,9.97 13.7,8.62 11.74,8.62C10.77,8.62 10.23,9.06 10.23,9.69C10.23,10.32 11,10.5 11.66,10.68L13.42,11.07C15.34,11.5 15.83,12.62 15.83,13.67C15.83,15.31 14.57,16.53 12.03,16.53M18,6C20.07,8.04 20.85,10.89 20.36,13.55C20.77,14.27 21,15.11 21,16A5,5 0 0,1 16,21C15.11,21 14.27,20.77 13.55,20.36C10.89,20.85 8.04,20.07 6,18C3.93,15.96 3.15,13.11 3.64,10.45C3.23,9.73 3,8.89 3,8A5,5 0 0,1 8,3C8.89,3 9.73,3.23 10.45,3.64C13.11,3.15 15.96,3.93 18,6M8,5A3,3 0 0,0 5,8C5,8.79 5.3,9.5 5.8,10.04C5.1,12.28 5.63,14.82 7.4,16.6C9.18,18.37 11.72,18.9 13.96,18.2C14.5,18.7 15.21,19 16,19A3,3 0 0,0 19,16C19,15.21 18.7,14.5 18.2,13.96C18.9,11.72 18.37,9.18 16.6,7.4C14.82,5.63 12.28,5.1 10.04,5.8C9.5,5.3 8.79,5 8,5Z\";\r\nvar mdiSlack = \"M6,15A2,2 0 0,1 4,17A2,2 0 0,1 2,15A2,2 0 0,1 4,13H6V15M7,15A2,2 0 0,1 9,13A2,2 0 0,1 11,15V20A2,2 0 0,1 9,22A2,2 0 0,1 7,20V15M9,7A2,2 0 0,1 7,5A2,2 0 0,1 9,3A2,2 0 0,1 11,5V7H9M9,8A2,2 0 0,1 11,10A2,2 0 0,1 9,12H4A2,2 0 0,1 2,10A2,2 0 0,1 4,8H9M17,10A2,2 0 0,1 19,8A2,2 0 0,1 21,10A2,2 0 0,1 19,12H17V10M16,10A2,2 0 0,1 14,12A2,2 0 0,1 12,10V5A2,2 0 0,1 14,3A2,2 0 0,1 16,5V10M14,18A2,2 0 0,1 16,20A2,2 0 0,1 14,22A2,2 0 0,1 12,20V18H14M14,17A2,2 0 0,1 12,15A2,2 0 0,1 14,13H19A2,2 0 0,1 21,15A2,2 0 0,1 19,17H14Z\";\r\nvar mdiSlashForward = \"M7 21L14.9 3H17L9.1 21H7Z\";\r\nvar mdiSlashForwardBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M9.3 19H7L14.7 5H17L9.3 19Z\";\r\nvar mdiSleep = \"M23,12H17V10L20.39,6H17V4H23V6L19.62,10H23V12M15,16H9V14L12.39,10H9V8H15V10L11.62,14H15V16M7,20H1V18L4.39,14H1V12H7V14L3.62,18H7V20Z\";\r\nvar mdiSleepOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L12.73,16H9V14L9.79,13.06L2,5.27M23,12H17V10L20.39,6H17V4H23V6L19.62,10H23V12M9.82,8H15V10L13.54,11.72L9.82,8M7,20H1V18L4.39,14H1V12H7V14L3.62,18H7V20Z\";\r\nvar mdiSlide = \"M14.83 15.45C14.47 14.9 14.18 14.39 13.91 13.92C12.74 11.91 11.79 10.55 9 10.13V5.5C9 3.57 7.43 2 5.5 2S2 3.57 2 5.5V22H4V20H7V22H9V12.16C10.76 12.5 11.29 13.39 12.17 14.92C12.46 15.43 12.78 15.97 13.17 16.56C15.41 19.92 17.67 22 22 22V20C18.53 20 16.8 18.4 14.83 15.45M5.5 4C6.33 4 7 4.67 7 5.5V10H4V5.5C4 4.67 4.67 4 5.5 4M4 18V16H7V18H4M7 14H4V12H7V14Z\";\r\nvar mdiSlopeDownhill = \"M22,19V22H2V13L22,19M19.09,7.5L18.25,10.26L8.13,7.26C8.06,5.66 6.7,4.42 5.1,4.5C3.5,4.57 2.26,5.93 2.34,7.53C2.41,9.13 3.77,10.36 5.37,10.29C6.24,10.25 7.05,9.82 7.57,9.11L17.69,12.11L16.85,14.89L21.67,12.29L19.09,7.5Z\";\r\nvar mdiSlopeUphill = \"M22,13V22H2V19L22,13M21.68,7.06L16.86,4.46L17.7,7.24L7.58,10.24C6.63,8.95 4.82,8.67 3.53,9.62C2.24,10.57 1.96,12.38 2.91,13.67C3.85,14.97 5.67,15.24 6.96,14.29C7.67,13.78 8.1,12.97 8.14,12.09L18.26,9.09L19.1,11.87L21.68,7.06Z\";\r\nvar mdiSlotMachine = \"M5 12L7 8V7H4V8H6L4 12M9 12L11 8V7H8V8H10L8 12M13 12L15 8V7H12V8H14L12 12M21 2C19.9 2 19 2.9 19 4C19 4.7 19.4 5.4 20 5.7V17H17V15C17.6 15 18 14.6 18 14V5C18 4.4 17.6 4 17 4H13.2C12.4 2.8 11 2 9.5 2S6.6 2.8 5.8 4H2C1.4 4 1 4.4 1 5V14C1 14.6 1.4 15 2 15V22H17V19H20C21.1 19 22 18.1 22 17V5.7C22.6 5.4 23 4.7 23 4C23 2.9 22.1 2 21 2M13 19H6V17H13V19M16 13H3V6H16V13Z\";\r\nvar mdiSlotMachineOutline = \"M5 12L7 8V7H4V8H6L4 12M9 12L11 8V7H8V8H10L8 12M13 12L15 8V7H12V8H14L12 12M21 2C19.9 2 19 2.9 19 4C19 4.7 19.4 5.4 20 5.7V17H17V15C17.6 15 18 14.6 18 14V5C18 4.4 17.6 4 17 4H13.2C12.4 2.8 11 2 9.5 2S6.6 2.8 5.8 4H2C1.4 4 1 4.4 1 5V14C1 14.6 1.4 15 2 15V22H17V19H20C21.1 19 22 18.1 22 17V5.7C22.6 5.4 23 4.7 23 4C23 2.9 22.1 2 21 2M3 6H16V13H3V6M15 20H4V15H15V20M13 19H6V17H13V19Z\";\r\nvar mdiSmartCard = \"M2 3H22A2.07 2.07 0 0 1 24 5V19A2.07 2.07 0 0 1 22 21H2A2.07 2.07 0 0 1 0 19V5A2.07 2.07 0 0 1 2 3M8 13.91C6 13.91 2 15 2 17V18H14V17C14 15 10 13.91 8 13.91M8 6A3 3 0 1 0 11 9A3 3 0 0 0 8 6M17 10V13H21V10H17\";\r\nvar mdiSmartCardOutline = \"M22 3H2A2.07 2.07 0 0 0 0 5V19A2.07 2.07 0 0 0 2 21H22A2.07 2.07 0 0 0 24 19V5A2.07 2.07 0 0 0 22 3M22 19H2V5H22M14 17V15.75C14 14.09 10.66 13.25 9 13.25S4 14.09 4 15.75V17H14M9 7A2.5 2.5 0 1 0 11.5 9.5A2.5 2.5 0 0 0 9 7M15 10V13H19V10H15\";\r\nvar mdiSmartCardReader = \"M21 4A2.07 2.07 0 0 0 19 2H5A2.07 2.07 0 0 0 3 4V18H21M8.25 16H7V6H8.25C9.91 6 10.75 9.34 10.75 11S9.91 16 8.25 16M14.5 13.5A2.5 2.5 0 1 1 17 11A2.5 2.5 0 0 1 14.5 13.5M23 21V22H1V21A2 2 0 0 1 3 19H21A2 2 0 0 1 23 21Z\";\r\nvar mdiSmartCardReaderOutline = \"M14.5 8.5A2.5 2.5 0 1 0 17 11A2.5 2.5 0 0 0 14.5 8.5M8.25 6H7V16H8.25C9.91 16 10.75 12.66 10.75 11S9.91 6 8.25 6M19 2H5A2.07 2.07 0 0 0 3 4V18H5V4H19V18H21V4A2.07 2.07 0 0 0 19 2M23 22H1V21A2 2 0 0 1 3 19H21A2 2 0 0 1 23 21Z\";\r\nvar mdiSmog = \"M12,2C10.08,2 8.5,3.35 8.09,5.15C7.45,4.44 6.53,4 5.5,4A3.5,3.5 0 0,0 2,7.5H2A3.5,3.5 0 0,0 5.5,11H6.68V12H10.72V11H13.28V12H17.32V11H18.5A3.5,3.5 0 0,0 22,7.5H22A3.5,3.5 0 0,0 18.5,4H18.5C17.47,4 16.55,4.44 15.91,5.15C15.5,3.35 13.92,2 12,2M7.2,14L6.4,22H11L10.2,14H7.2M13.8,14L13,22H17.6L16.8,14H13.8Z\";\r\nvar mdiSmokeDetector = \"M12,18A6,6 0 0,0 18,12C18,8.68 15.31,6 12,6C8.68,6 6,8.68 6,12A6,6 0 0,0 12,18M19,3A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19M8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12Z\";\r\nvar mdiSmoking = \"M2,16H17V19H2V16M20.5,16H22V19H20.5V16M18,16H19.5V19H18V16M18.85,7.73C19.47,7.12 19.85,6.28 19.85,5.35C19.85,3.5 18.35,2 16.5,2V3.5C17.5,3.5 18.35,4.33 18.35,5.35C18.35,6.37 17.5,7.2 16.5,7.2V8.7C18.74,8.7 20.5,10.53 20.5,12.77V15H22V12.76C22,10.54 20.72,8.62 18.85,7.73M16.03,10.2H14.5C13.5,10.2 12.65,9.22 12.65,8.2C12.65,7.18 13.5,6.45 14.5,6.45V4.95C12.65,4.95 11.15,6.45 11.15,8.3A3.35,3.35 0 0,0 14.5,11.65H16.03C17.08,11.65 18,12.39 18,13.7V15H19.5V13.36C19.5,11.55 17.9,10.2 16.03,10.2Z\";\r\nvar mdiSmokingOff = \"M2,6L9,13H2V16H12L19,23L20.25,21.75L3.25,4.75L2,6M20.5,13H22V16H20.5V13M18,13H19.5V16H18V13M18.85,4.88C19.47,4.27 19.85,3.43 19.85,2.5H18.35C18.35,3.5 17.5,4.35 16.5,4.35V5.85C18.74,5.85 20.5,7.68 20.5,9.92V12H22V9.92C22,7.69 20.72,5.77 18.85,4.88M14.5,8.7H16.03C17.08,8.7 18,9.44 18,10.75V12H19.5V10.41C19.5,8.61 17.9,7.25 16.03,7.25H14.5C13.5,7.25 12.65,6.27 12.65,5.25C12.65,4.23 13.5,3.5 14.5,3.5V2A3.35,3.35 0 0,0 11.15,5.35A3.35,3.35 0 0,0 14.5,8.7M17,15.93V13H14.07L17,15.93Z\";\r\nvar mdiSmokingPipe = \"M16 13C14.89 13 14 13.89 14 15V18H13C12 18 11 17.92 10.3 17.23L6.53 13.47C5.6 12.53 4.33 12 3 12H2V14H3C3.8 14 4.56 14.32 5.12 14.88L8.89 18.65C11.72 21.5 13 22 16 22H18C20.21 22 22 20.21 22 18V15C22 13.89 21.11 13 20 13H16M14 7.2H12.5C11.45 7.12 10.65 6.25 10.65 5.2C10.67 4.22 11.5 3.43 12.46 3.45L12.5 3.45V2C10.65 2 9.15 3.5 9.15 5.35S10.65 8.7 12.5 8.7H14C15.07 8.66 15.96 9.5 16 10.56C16 10.61 16 10.65 16 10.7V12H17.5V10.36C17.42 8.53 15.88 7.12 14.05 7.2L14 7.2M20 9.76V12H18.5V9.77L18.5 9.7C18.5 7.5 16.71 5.7 14.5 5.7V4.2H14.5C15.5 4.2 16.35 3.37 16.35 2.35C16.35 2.23 16.34 2.11 16.32 2H17.79C17.89 3 17.58 4 16.82 4.73H16.85C18.78 5.66 20 7.62 20 9.76Z\";\r\nvar mdiSmokingPipeOff = \"M20.84 22.73L19.71 21.6C19.19 21.85 18.62 22 18 22H16C13 22 11.72 21.5 8.89 18.65L5.12 14.88C4.56 14.32 3.8 14 3 14H2V12H3C4.33 12 5.6 12.53 6.53 13.47L10.3 17.23C11 17.92 12 18 13 18H14V15.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M21.93 18.73C21.97 18.5 22 18.25 22 18V15C22 13.89 21.11 13 20 13H16.2L21.93 18.73M18.5 9.7L18.5 9.77V12H20V9.76C20 7.62 18.78 5.66 16.85 4.73H16.82C17.58 4 17.9 3 17.8 2H16.32C16.34 2.11 16.35 2.23 16.35 2.35C16.35 3.37 15.5 4.2 14.5 4.2H14.5V5.7C16.71 5.7 18.5 7.5 18.5 9.7M11.83 8.63C12.05 8.68 12.27 8.7 12.5 8.7H14C15.07 8.66 15.96 9.5 16 10.56C16 10.61 16 10.65 16 10.7V12H17.5V10.36C17.42 8.53 15.88 7.12 14.05 7.2L14 7.2H12.5C11.45 7.12 10.65 6.25 10.65 5.2C10.67 4.22 11.5 3.43 12.46 3.45L12.5 3.45V2C10.65 2 9.15 3.5 9.15 5.35C9.15 5.58 9.17 5.8 9.22 6L11.83 8.63Z\";\r\nvar mdiSnake = \"M19.5 17H18C19.1 17 20 16.1 20 15S19.1 13 18 13V9C18 8 18 7 16.92 6.14C16.97 5.93 17 5.72 17 5.5C17 3.57 15 2 12.5 2C10.24 2 8.38 3.31 8.07 5H6L3.71 2.79L3 3.5L5 5.5L3 7.5L3.71 8.21L6 6H8.07C8.38 7.69 10.24 9 12.5 9C13 9 13.5 8.92 13.93 8.8C13.97 8.87 14 8.94 14 9V13H8C6.9 13 6 13.9 6 15S6.9 17 8 17H6.5C5.12 17 4 18.12 4 19.5C4 19.67 4 19.84 4.05 20H4C2.9 20 2 20.9 2 22H19.5C20.88 22 22 20.88 22 19.5S20.88 17 19.5 17M12 5C11.45 5 11 4.55 11 4S11.45 3 12 3 13 3.45 13 4 12.55 5 12 5Z\";\r\nvar mdiSnapchat = \"M21.93 16.56C21.79 16.18 21.5 16 21.22 15.81C21.17 15.78 21.11 15.75 21.07 15.73C21 15.68 20.89 15.64 20.8 15.59C19.86 15.09 19.12 14.46 18.61 13.72C18.47 13.5 18.35 13.29 18.24 13.06C18.2 12.93 18.2 12.86 18.23 12.8C18.26 12.75 18.3 12.7 18.35 12.67C18.5 12.56 18.68 12.46 18.79 12.38C19 12.25 19.15 12.15 19.25 12.08C19.64 11.81 19.91 11.5 20.08 11.2C20.32 10.75 20.35 10.22 20.16 9.75C19.91 9.08 19.27 8.66 18.5 8.66C18.34 8.66 18.18 8.68 18 8.71C18 8.72 17.94 8.73 17.9 8.74C17.9 8.28 17.89 7.8 17.85 7.32C17.71 5.64 17.12 4.76 16.5 4.06C16.11 3.62 15.65 3.24 15.14 2.95C14.21 2.42 13.15 2.15 12 2.15S9.8 2.42 8.87 2.95C8.35 3.24 7.89 3.62 7.5 4.06C6.88 4.76 6.3 5.64 6.15 7.32C6.11 7.8 6.1 8.28 6.11 8.74C6.06 8.73 6 8.72 6 8.71C5.82 8.68 5.66 8.66 5.5 8.66C4.73 8.66 4.09 9.08 3.84 9.75C3.65 10.22 3.68 10.75 3.92 11.2C4.09 11.5 4.36 11.81 4.75 12.08C4.85 12.15 5 12.25 5.21 12.39L5.63 12.66C5.69 12.7 5.73 12.75 5.77 12.8C5.8 12.87 5.8 12.94 5.75 13.07C5.65 13.3 5.53 13.5 5.39 13.72C4.89 14.45 4.18 15.07 3.27 15.56C2.78 15.82 2.28 16 2.07 16.56C1.91 17 2 17.5 2.42 17.91C2.57 18.06 2.74 18.19 2.93 18.29C3.33 18.5 3.75 18.68 4.18 18.79C4.27 18.82 4.36 18.85 4.43 18.91C4.58 19.03 4.56 19.23 4.76 19.5C4.86 19.66 5 19.79 5.13 19.89C5.54 20.18 6 20.19 6.5 20.21C6.94 20.23 7.44 20.25 8 20.44C8.26 20.5 8.5 20.67 8.79 20.85C9.5 21.27 10.42 21.85 12 21.85C13.57 21.85 14.5 21.27 15.22 20.84C15.5 20.67 15.75 20.5 16 20.44C16.55 20.25 17.06 20.23 17.5 20.21C18 20.2 18.46 20.18 18.87 19.89C19.04 19.77 19.18 19.61 19.29 19.43C19.43 19.19 19.43 19 19.56 18.91C19.63 18.86 19.71 18.82 19.8 18.8C20.24 18.68 20.66 18.5 21.06 18.29C21.27 18.18 21.45 18.04 21.6 17.87L21.61 17.87C22 17.46 22.08 17 21.93 16.56M20.53 17.31C19.67 17.78 19.1 17.73 18.66 18C18.5 18.12 18.45 18.28 18.42 18.44C18.41 18.5 18.4 18.58 18.39 18.64C18.37 18.78 18.34 18.9 18.24 18.97C17.9 19.2 16.91 18.95 15.63 19.37C14.57 19.72 13.9 20.73 12 20.73C10.1 20.73 9.45 19.73 8.37 19.37C7.1 18.95 6.1 19.2 5.77 18.97C5.5 18.78 5.72 18.26 5.34 18C4.9 17.73 4.33 17.78 3.5 17.31C3.19 17.15 3.14 17 3.18 16.93C3.22 16.84 3.34 16.77 3.42 16.73C5.07 15.94 6 14.91 6.47 14.1C6.91 13.38 7 12.83 7.03 12.75C7.06 12.54 7.09 12.38 6.86 12.17C6.64 11.96 5.66 11.36 5.39 11.17C4.93 10.85 4.74 10.54 4.88 10.15L4.88 10.15V10.15C5 9.88 5.23 9.78 5.5 9.78C5.58 9.78 5.66 9.79 5.74 9.81C6.24 9.91 6.72 10.16 7 10.23C7.03 10.24 7.06 10.24 7.1 10.24C7.19 10.24 7.24 10.21 7.27 10.15C7.28 10.11 7.29 10.06 7.29 10C7.25 9.46 7.18 8.41 7.26 7.42C7.3 7 7.37 6.64 7.46 6.33C7.66 5.65 8 5.2 8.34 4.79C8.59 4.5 9.75 3.27 12 3.27C13.85 3.27 14.96 4.11 15.44 4.56C15.54 4.66 15.62 4.74 15.66 4.79C16.04 5.23 16.38 5.71 16.58 6.47C16.65 6.74 16.71 7.06 16.74 7.42C16.82 8.4 16.75 9.46 16.71 10C16.71 10.04 16.71 10.08 16.72 10.11C16.73 10.2 16.79 10.24 16.9 10.24C16.94 10.24 16.97 10.24 17 10.23C17.28 10.16 17.76 9.91 18.26 9.8C18.34 9.79 18.42 9.78 18.5 9.78C18.75 9.78 19 9.87 19.1 10.1L19.11 10.14L19.12 10.14L19.12 10.15C19.27 10.53 19.07 10.85 18.62 11.16C18.35 11.35 17.36 11.96 17.14 12.16C16.91 12.38 16.94 12.54 16.97 12.75C17 12.85 17.18 13.8 18.08 14.86C18.63 15.5 19.42 16.17 20.58 16.73C20.65 16.76 20.74 16.81 20.79 16.87C20.82 16.92 20.84 16.96 20.83 17C20.82 17.1 20.73 17.2 20.53 17.31Z\";\r\nvar mdiSnowboard = \"M15.4 5.4C15.4 4.3 16.3 3.4 17.4 3.4C18.5 3.4 19.4 4.3 19.4 5.4C19.4 6.5 18.5 7.4 17.4 7.4C16.3 7.4 15.4 6.5 15.4 5.4M22 19.2C21.4 19.8 20.8 20.2 20.1 20.5C19.4 20.8 18.6 21 17.8 21H6.2C5.4 21 4.6 20.8 3.9 20.5C3.2 20.2 2.6 19.8 2 19.2L2.9 18.3C3.3 18.7 3.8 19.1 4.4 19.3C4.9 19.6 5.4 19.7 5.9 19.7L9.7 16L8.5 12.5C8.3 11.9 8.6 11.4 9.1 11L11 9H6V7H14C14.5 7 14.7 7.1 15 7.3L17.3 9.5C18.3 10.5 19.5 11 20.9 11L21 13.1C19.1 13.1 17.4 12.4 15.9 11L15.2 10.3L12.9 12.7L15 15V19.7H17.8C18.4 19.7 19 19.6 19.6 19.3C20.2 19.1 20.7 18.7 21.1 18.3L22 19.2M8.8 19.7H13V15.8L11.7 14.6V16.8L8.8 19.7Z\";\r\nvar mdiSnowflake = \"M20.79,13.95L18.46,14.57L16.46,13.44V10.56L18.46,9.43L20.79,10.05L21.31,8.12L19.54,7.65L20,5.88L18.07,5.36L17.45,7.69L15.45,8.82L13,7.38V5.12L14.71,3.41L13.29,2L12,3.29L10.71,2L9.29,3.41L11,5.12V7.38L8.5,8.82L6.5,7.69L5.92,5.36L4,5.88L4.47,7.65L2.7,8.12L3.22,10.05L5.55,9.43L7.55,10.56V13.45L5.55,14.58L3.22,13.96L2.7,15.89L4.47,16.36L4,18.12L5.93,18.64L6.55,16.31L8.55,15.18L11,16.62V18.88L9.29,20.59L10.71,22L12,20.71L13.29,22L14.7,20.59L13,18.88V16.62L15.5,15.17L17.5,16.3L18.12,18.63L20,18.12L19.53,16.35L21.3,15.88L20.79,13.95M9.5,10.56L12,9.11L14.5,10.56V13.44L12,14.89L9.5,13.44V10.56Z\";\r\nvar mdiSnowflakeAlert = \"M16.46,9.41L13,7.38V5.12L14.71,3.41L13.29,2L12,3.29L10.71,2L9.29,3.41L11,5.12V7.38L8.5,8.82L6.5,7.69L5.92,5.36L4,5.88L4.47,7.65L2.7,8.12L3.22,10.05L5.55,9.43L7.55,10.56V13.45L5.55,14.58L3.22,13.96L2.7,15.89L4.47,16.36L4,18.12L5.93,18.64L6.55,16.31L8.55,15.18L11,16.62V18.88L9.29,20.59L10.71,22L12,20.71L13.29,22L14.7,20.59L13,18.88V16.62L16.46,14.61M9.5,10.56L12,9.11L14.5,10.56V13.44L12,14.89L9.5,13.44M19,13V7H21V13H19M19,17V15H21V17H19Z\";\r\nvar mdiSnowflakeMelt = \"M8 17.85C8 19.04 7.11 20 6 20S4 19.04 4 17.85C4 16.42 6 14 6 14S8 16.42 8 17.85M16.46 12V10.56L18.46 9.43L20.79 10.05L21.31 8.12L19.54 7.65L20 5.88L18.07 5.36L17.45 7.69L15.45 8.82L13 7.38V5.12L14.71 3.41L13.29 2L12 3.29L10.71 2L9.29 3.41L11 5.12V7.38L8.5 8.82L6.5 7.69L5.92 5.36L4 5.88L4.47 7.65L2.7 8.12L3.22 10.05L5.55 9.43L7.55 10.56V12H2V13H22V12H16.46M9.5 12V10.56L12 9.11L14.5 10.56V12H9.5M20 17.85C20 19.04 19.11 20 18 20S16 19.04 16 17.85C16 16.42 18 14 18 14S20 16.42 20 17.85M14 20.85C14 22.04 13.11 23 12 23S10 22.04 10 20.85C10 19.42 12 17 12 17S14 19.42 14 20.85Z\";\r\nvar mdiSnowflakeOff = \"M11 5.12L9.29 3.41L10.71 2L12 3.29L13.29 2L14.71 3.41L13 5.12V7.38L15.45 8.82L17.45 7.69L18.07 5.36L20 5.88L19.54 7.65L21.31 8.12L20.79 10.05L18.46 9.43L16.46 10.56V13.26L14.5 11.3V10.56L12.74 9.54L10.73 7.53L11 7.38V5.12M18.46 14.57L16.87 13.67L19.55 16.35L21.3 15.88L20.79 13.95L18.46 14.57M13 16.62V18.88L14.7 20.59L13.29 22L12 20.71L10.71 22L9.29 20.59L11 18.88V16.62L8.55 15.18L6.55 16.31L5.93 18.64L4 18.12L4.47 16.36L2.7 15.89L3.22 13.96L5.55 14.58L7.55 13.45V10.56L5.55 9.43L3.22 10.05L2.7 8.12L4.47 7.65L4 5.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73L14.1 16L13 16.62M12 14.89L12.63 14.5L9.5 11.39V13.44L12 14.89Z\";\r\nvar mdiSnowflakeVariant = \"M14.25,12L16.27,11H23L22,9H18.03L20.42,5.83L19.43,3.83L15.37,9.2L13.35,10.21L13.75,8L17.83,2.62L15.64,2.22L12,7L8.4,2.2L6.2,2.6L10.26,8L10.66,10.21L8.82,9.29L8.66,9.21L4.6,3.8L3.6,5.8L6,9H2L1,11H7.77L9.75,12L7.73,13H1L2,15H5.97L3.58,18.17L4.57,20.17L8.63,14.8L10.65,13.79L10.25,16L6.17,21.38L8.36,21.79L12,17L15.6,21.8L17.8,21.4L13.74,16L13.34,13.79L15.34,14.79L19.4,20.2L20.4,18.2L18,15H22L23,13H16.23\";\r\nvar mdiSnowman = \"M17,17A5,5 0 0,1 12,22A5,5 0 0,1 7,17C7,15.5 7.65,14.17 8.69,13.25C8.26,12.61 8,11.83 8,11C8,10.86 8,10.73 8,10.59L5.04,8.87L4.83,8.71L2.29,9.39L2.03,8.43L4.24,7.84L2.26,6.69L2.76,5.82L4.74,6.97L4.15,4.75L5.11,4.5L5.8,7.04L6.04,7.14L8.73,8.69C9.11,8.15 9.62,7.71 10.22,7.42C9.5,6.87 9,6 9,5A3,3 0 0,1 12,2A3,3 0 0,1 15,5C15,6 14.5,6.87 13.78,7.42C14.38,7.71 14.89,8.15 15.27,8.69L17.96,7.14L18.2,7.04L18.89,4.5L19.85,4.75L19.26,6.97L21.24,5.82L21.74,6.69L19.76,7.84L21.97,8.43L21.71,9.39L19.17,8.71L18.96,8.87L16,10.59V11C16,11.83 15.74,12.61 15.31,13.25C16.35,14.17 17,15.5 17,17Z\";\r\nvar mdiSoccer = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,3C13.76,3 15.4,3.53 16.78,4.41L16.5,5H13L12,5L10.28,4.16L10.63,3.13C11.08,3.05 11.53,3 12,3M9.53,3.38L9.19,4.41L6.63,5.69L5.38,5.94C6.5,4.73 7.92,3.84 9.53,3.38M13,6H16L18.69,9.59L17.44,12.16L14.81,12.78L11.53,8.94L13,6M6.16,6.66L7,10L5.78,13.06L3.22,13.94C3.08,13.31 3,12.67 3,12C3,10.1 3.59,8.36 4.59,6.91L6.16,6.66M20.56,9.22C20.85,10.09 21,11.03 21,12C21,13.44 20.63,14.79 20.03,16H19L18.16,12.66L19.66,9.66L20.56,9.22M8,10H11L13.81,13.28L12,16L8.84,16.78L6.53,13.69L8,10M12,17L15,19L14.13,20.72C13.44,20.88 12.73,21 12,21C10.25,21 8.63,20.5 7.25,19.63L8.41,17.91L12,17M19,17H19.5C18.5,18.5 17,19.67 15.31,20.34L16,19L19,17Z\";\r\nvar mdiSoccerField = \"M4,4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4H4M4,6H11V8.13C9.24,8.59 8,10.18 8,12C8,13.82 9.24,15.41 11,15.87V18H4V16H7V8H4V6M13,6H20V8H17V16H20V18H13V15.87C14.76,15.41 16,13.82 16,12C16,10.18 14.76,8.59 13,8.13V6M4,10H5V14H4V10M19,10H20V14H19V10M13,10.27C13.62,10.63 14,11.29 14,12C14,12.71 13.62,13.37 13,13.73V10.27M11,10.27V13.73C10.38,13.37 10,12.71 10,12C10,11.29 10.38,10.63 11,10.27Z\";\r\nvar mdiSocialDistance2Meters = \"M6 6C7.1 6 8 5.1 8 4S7.1 2 6 2 4 2.9 4 4 4.9 6 6 6M10 9.43C10 8.62 9.5 7.9 8.78 7.58C7.93 7.21 7 7 6 7S4.07 7.21 3.22 7.58C2.5 7.9 2 8.62 2 9.43V10H10V9.43M18 6C19.1 6 20 5.1 20 4S19.1 2 18 2 16 2.9 16 4 16.9 6 18 6M22 9.43C22 8.62 21.5 7.9 20.78 7.58C19.93 7.21 19 7 18 7S16.07 7.21 15.22 7.58C14.5 7.9 14 8.62 14 9.43V10H22V9.43M19 17V15L5 15V17L2 14L5 11V13L19 13V11L22 14L19 17M9 20.5V21H11V22H8V20.5C8 19.95 8.45 19.5 9 19.5H10V19H8V18H10C10.55 18 11 18.45 11 19V19.5C11 20.05 10.55 20.5 10 20.5H9M16 19V22H15V19H14.5V21H13.5V19H13V22H12V19C12 18.45 12.45 18 13 18H15C15.55 18 16 18.45 16 19Z\";\r\nvar mdiSocialDistance6Feet = \"M6 6C7.1 6 8 5.1 8 4S7.1 2 6 2 4 2.9 4 4 4.9 6 6 6M10 9.43C10 8.62 9.5 7.9 8.78 7.58C7.93 7.21 7 7 6 7S4.07 7.21 3.22 7.58C2.5 7.9 2 8.62 2 9.43V10H10V9.43M18 6C19.1 6 20 5.1 20 4S19.1 2 18 2 16 2.9 16 4 16.9 6 18 6M22 9.43C22 8.62 21.5 7.9 20.78 7.58C19.93 7.21 19 7 18 7S16.07 7.21 15.22 7.58C14.5 7.9 14 8.62 14 9.43V10H22V9.43M19 17V15H5V17L2 14L5 11V13H19V11L22 14L19 17M10 19V18H7.5C7.22 18 7 18.22 7 18.5V21.5C7 21.78 7.22 22 7.5 22H9.5C9.78 22 10 21.78 10 21.5V20C10 19.72 9.78 19.5 9.5 19.5H8V19H10M9 20.5V21H8V20.5H9M17.5 19H16.5V22H15.5V19H14.5V18H17.5V19M12.5 19V19.5H13.5V20.5H12.5V22H11.5V18H14V19H12.5Z\";\r\nvar mdiSofa = \"M12.5 7C12.5 5.89 13.39 5 14.5 5H18C19.1 5 20 5.9 20 7V9.16C18.84 9.57 18 10.67 18 11.97V14H12.5V7M6 11.96V14H11.5V7C11.5 5.89 10.61 5 9.5 5H6C4.9 5 4 5.9 4 7V9.15C5.16 9.56 6 10.67 6 11.96M20.66 10.03C19.68 10.19 19 11.12 19 12.12V15H5V12C5 10.9 4.11 10 3 10S1 10.9 1 12V17C1 18.1 1.9 19 3 19V21H5V19H19V21H21V19C22.1 19 23 18.1 23 17V12C23 10.79 21.91 9.82 20.66 10.03Z\";\r\nvar mdiSofaOutline = \"M21 9V7C21 5.35 19.65 4 18 4H14C13.23 4 12.53 4.3 12 4.78C11.47 4.3 10.77 4 10 4H6C4.35 4 3 5.35 3 7V9C1.35 9 0 10.35 0 12V17C0 18.65 1.35 20 3 20V22H5V20H19V22H21V20C22.65 20 24 18.65 24 17V12C24 10.35 22.65 9 21 9M14 6H18C18.55 6 19 6.45 19 7V9.78C18.39 10.33 18 11.12 18 12V14H13V7C13 6.45 13.45 6 14 6M5 7C5 6.45 5.45 6 6 6H10C10.55 6 11 6.45 11 7V14H6V12C6 11.12 5.61 10.33 5 9.78V7M22 17C22 17.55 21.55 18 21 18H3C2.45 18 2 17.55 2 17V12C2 11.45 2.45 11 3 11S4 11.45 4 12V16H20V12C20 11.45 20.45 11 21 11S22 11.45 22 12V17Z\";\r\nvar mdiSofaSingle = \"M5 9.15V7C5 5.9 5.9 5 7 5H17C18.1 5 19 5.9 19 7V9.16C17.84 9.57 17 10.67 17 11.97V14H7V11.96C7 10.67 6.16 9.56 5 9.15M20 10C18.9 10 18 10.9 18 12V15H6V12C6 10.9 5.11 10 4 10S2 10.9 2 12V17C2 18.1 2.9 19 4 19V21H6V19H18V21H20V19C21.1 19 22 18.1 22 17V12C22 10.9 21.1 10 20 10Z\";\r\nvar mdiSofaSingleOutline = \"M19 9V7C19 5.35 17.65 4 16 4H8C6.35 4 5 5.35 5 7V9C3.35 9 2 10.35 2 12V17C2 18.65 3.35 20 5 20V22H7V20H17V22H19V20C20.65 20 22 18.65 22 17V12C22 10.35 20.65 9 19 9M7 7C7 6.45 7.45 6 8 6H16C16.55 6 17 6.45 17 7V9.78C16.39 10.33 16 11.12 16 12V14H8V12C8 11.12 7.61 10.33 7 9.78V7M20 17C20 17.55 19.55 18 19 18H5C4.45 18 4 17.55 4 17V12C4 11.45 4.45 11 5 11S6 11.45 6 12V16H18V12C18 11.45 18.45 11 19 11S20 11.45 20 12V17Z\";\r\nvar mdiSolarPanel = \"M4,2H20A2,2 0 0,1 22,4V14A2,2 0 0,1 20,16H15V20H18V22H13V16H11V22H6V20H9V16H4A2,2 0 0,1 2,14V4A2,2 0 0,1 4,2M4,4V8H11V4H4M4,14H11V10H4V14M20,14V10H13V14H20M20,4H13V8H20V4Z\";\r\nvar mdiSolarPanelLarge = \"M3,6H6V3H3V6M8,3V6H11V3H8M13,3V6H16V3H13M18,3V6H21V3H18M21,8H18V11H21V8M21,13H18V16H21V13M16,16V13H13V16H16M11,16V13H8V16H11M6,16V13H3V16H6M3,11H6V8H3V11M13,8V11H16V8H13M8,8V11H11V8H8M3,1H21A2,2 0 0,1 23,3V16A2,2 0 0,1 21,18H15V21H18V23H13V18H11V23H6V21H9V18H3A2,2 0 0,1 1,16V3A2,2 0 0,1 3,1Z\";\r\nvar mdiSolarPower = \"M11.45,2V5.55L15,3.77L11.45,2M10.45,8L8,10.46L11.75,11.71L10.45,8M2,11.45L3.77,15L5.55,11.45H2M10,2H2V10C2.57,10.17 3.17,10.25 3.77,10.25C7.35,10.26 10.26,7.35 10.27,3.75C10.26,3.16 10.17,2.57 10,2M17,22V16H14L19,7V13H22L17,22Z\";\r\nvar mdiSolderingIron = \"M4.86 4.03L2.03 6.86L5.21 10.04V12.87L6.63 14.28L12.28 8.63L10.87 7.21H8.04L4.86 4.03M17 6V7.5C18 7.5 18.85 8.33 18.85 9.35C18.85 10.37 18 11.2 17 11.2V12.7C19.24 12.7 21 14.53 21 16.77V21H22.5V16.76C22.5 14.54 21.22 12.62 19.35 11.73C19.97 11.12 20.35 10.28 20.35 9.35C20.35 7.5 18.85 6 17 6M11.93 11.1L9.1 13.93L14.05 18.88L14.76 18.17L16.88 20.29L19 21L18.29 18.88L16.17 16.76L16.88 16.05L11.93 11.1Z\";\r\nvar mdiSolid = \"M0,0H24V24H0\";\r\nvar mdiSonyPlaystation = \"M9.5,4.27C10.88,4.53 12.9,5.14 14,5.5C16.75,6.45 17.69,7.63 17.69,10.29C17.69,12.89 16.09,13.87 14.05,12.89V8.05C14.05,7.5 13.95,6.97 13.41,6.82C13,6.69 12.76,7.07 12.76,7.63V19.73L9.5,18.69V4.27M13.37,17.62L18.62,15.75C19.22,15.54 19.31,15.24 18.83,15.08C18.34,14.92 17.47,14.97 16.87,15.18L13.37,16.41V14.45L13.58,14.38C13.58,14.38 14.59,14 16,13.87C17.43,13.71 19.17,13.89 20.53,14.4C22.07,14.89 22.25,15.61 21.86,16.1C21.46,16.6 20.5,16.95 20.5,16.95L13.37,19.5V17.62M3.5,17.42C1.93,17 1.66,16.05 2.38,15.5C3.05,15 4.18,14.65 4.18,14.65L8.86,13V14.88L5.5,16.09C4.9,16.3 4.81,16.6 5.29,16.76C5.77,16.92 6.65,16.88 7.24,16.66L8.86,16.08V17.77L8.54,17.83C6.92,18.09 5.2,18 3.5,17.42Z\";\r\nvar mdiSort = \"M18 21L14 17H17V7H14L18 3L22 7H19V17H22M2 19V17H12V19M2 13V11H9V13M2 7V5H6V7H2Z\";\r\nvar mdiSortAlphabeticalAscending = \"M19 17H22L18 21L14 17H17V3H19M11 13V15L7.67 19H11V21H5V19L8.33 15H5V13M9 3H7C5.9 3 5 3.9 5 5V11H7V9H9V11H11V5C11 3.9 10.11 3 9 3M9 7H7V5H9Z\";\r\nvar mdiSortAlphabeticalAscendingVariant = \"M9.25 5L12.5 1.75L15.75 5H9.25M8.89 14.3H6L5.28 17H2.91L6 7H9L12.13 17H9.67L8.89 14.3M6.33 12.68H8.56L7.93 10.56L7.67 9.59L7.42 8.63H7.39L7.17 9.6L6.93 10.58L6.33 12.68M13.05 17V15.74L17.8 8.97V8.91H13.5V7H20.73V8.34L16.09 15V15.08H20.8V17H13.05Z\";\r\nvar mdiSortAlphabeticalDescending = \"M19 7H22L18 3L14 7H17V21H19M11 13V15L7.67 19H11V21H5V19L8.33 15H5V13M9 3H7C5.9 3 5 3.9 5 5V11H7V9H9V11H11V5C11 3.9 10.11 3 9 3M9 7H7V5H9Z\";\r\nvar mdiSortAlphabeticalDescendingVariant = \"M15.75 19L12.5 22.25L9.25 19H15.75M8.89 14.3H6L5.28 17H2.91L6 7H9L12.13 17H9.67L8.89 14.3M6.33 12.68H8.56L7.93 10.56L7.67 9.59L7.42 8.63H7.39L7.17 9.6L6.93 10.58L6.33 12.68M13.05 17V15.74L17.8 8.97V8.91H13.5V7H20.73V8.34L16.09 15V15.08H20.8V17H13.05Z\";\r\nvar mdiSortAlphabeticalVariant = \"M9.25,5L12.5,1.75L15.75,5H9.25M15.75,19L12.5,22.25L9.25,19H15.75M8.89,14.3H6L5.28,17H2.91L6,7H9L12.13,17H9.67L8.89,14.3M6.33,12.68H8.56L7.93,10.56L7.67,9.59L7.42,8.63H7.39L7.17,9.6L6.93,10.58L6.33,12.68M13.05,17V15.74L17.8,8.97V8.91H13.5V7H20.73V8.34L16.09,15V15.08H20.8V17H13.05Z\";\r\nvar mdiSortAscending = \"M19 17H22L18 21L14 17H17V3H19M2 17H12V19H2M6 5V7H2V5M2 11H9V13H2V11Z\";\r\nvar mdiSortBoolAscending = \"M19 17H22L18 21L14 17H17V3H19V17M7 3C4.79 3 3 4.79 3 7S4.79 11 7 11 11 9.21 11 7 9.21 3 7 3M7 9C5.9 9 5 8.1 5 7S5.9 5 7 5 9 5.9 9 7 8.1 9 7 9M7 13C4.79 13 3 14.79 3 17S4.79 21 7 21 11 19.21 11 17 9.21 13 7 13Z\";\r\nvar mdiSortBoolAscendingVariant = \"M19 17H22L18 21L14 17H17V3H19V17M9 13H5C3.89 13 3 13.89 3 15V19C3 20.11 3.89 21 5 21H9C10.11 21 11 20.11 11 19V15C11 13.89 10.11 13 9 13M6.27 19.5L3.74 16.95L4.81 15.9L6.28 17.39L9.2 14.5L10.26 15.55L6.27 19.5M9 3H5C3.89 3 3 3.89 3 5V9C3 10.11 3.89 11 5 11H9C10.11 11 11 10.11 11 9V5C11 3.89 10.11 3 9 3M9 9H5V5H9V9Z\";\r\nvar mdiSortBoolDescending = \"M19 7H22L18 3L14 7H17V21H19M5 7C5 8.1 5.9 9 7 9C8.1 9 9 8.1 9 7C9 5.9 8.1 5 7 5C5.9 5 5 5.9 5 7M7 3C9.21 3 11 4.79 11 7C11 9.21 9.21 11 7 11C4.79 11 3 9.21 3 7C3 4.79 4.79 3 7 3M7 13C4.79 13 3 14.79 3 17C3 19.21 4.79 21 7 21C9.21 21 11 19.21 11 17C11 14.79 9.21 13 7 13Z\";\r\nvar mdiSortBoolDescendingVariant = \"M19 7H22L18 3L14 7H17V21H19M5 13C3.89 13 3 13.89 3 15V19C3 20.11 3.89 21 5 21H9C10.11 21 11 20.11 11 19V15C11 13.89 10.11 13 9 13M9.2 14.5L10.26 15.55L6.27 19.5L3.74 16.95L4.81 15.9L6.28 17.39M5 3C3.89 3 3 3.89 3 5V9C3 10.11 3.89 11 5 11H9C10.11 11 11 10.11 11 9V5C11 3.89 10.11 3 9 3M5 5H9V9H5Z\";\r\nvar mdiSortCalendarAscending = \"M21 17H24L20 21L16 17H19V3H21V17M8 16H11V13H8V16M13 5H12V3H10V5H6V3H4V5H3C1.89 5 1 5.89 1 7V18C1 19.11 1.89 20 3 20H13C14.11 20 15 19.11 15 18V7C15 5.89 14.11 5 13 5M3 18L3 11H13L13 18L3 18Z\";\r\nvar mdiSortCalendarDescending = \"M19 7H16L20 3L24 7H21V21H19V7M8 16H11V13H8V16M13 5H12V3H10V5H6V3H4V5H3C1.89 5 1 5.89 1 7V18C1 19.11 1.89 20 3 20H13C14.11 20 15 19.11 15 18V7C15 5.89 14.11 5 13 5M3 18L3 11H13L13 18L3 18Z\";\r\nvar mdiSortClockAscending = \"M20 17H23L19 21L15 17H18V3H20V17M8 5C4.14 5 1 8.13 1 12C1 15.87 4.13 19 8 19C11.86 19 15 15.87 15 12C15 8.13 11.87 5 8 5M10.19 14.53L7 12.69V9H8.5V11.82L10.94 13.23L10.19 14.53Z\";\r\nvar mdiSortClockAscendingOutline = \"M20 17H23L19 21L15 17H18V3H20V17M8 5C4.14 5 1 8.13 1 12C1 15.87 4.13 19 8 19C11.86 19 15 15.87 15 12C15 8.13 11.87 5 8 5M8 7.15C10.67 7.15 12.85 9.32 12.85 12C12.85 14.68 10.68 16.85 8 16.85C5.32 16.85 3.15 14.68 3.15 12C3.15 9.32 5.32 7.15 8 7.15M7 9V12.69L10.19 14.53L10.94 13.23L8.5 11.82V9\";\r\nvar mdiSortClockDescending = \"M18 7H15L19 3L23 7H20V21H18V7M8 5C4.14 5 1 8.13 1 12C1 15.87 4.13 19 8 19C11.86 19 15 15.87 15 12C15 8.13 11.87 5 8 5M10.19 14.53L7 12.69V9H8.5V11.82L10.94 13.23L10.19 14.53Z\";\r\nvar mdiSortClockDescendingOutline = \"M18 7H15L19 3L23 7H20V21H18V7M8 5C4.14 5 1 8.13 1 12C1 15.87 4.13 19 8 19C11.86 19 15 15.87 15 12C15 8.13 11.87 5 8 5M8 7.15C10.67 7.15 12.85 9.32 12.85 12C12.85 14.68 10.68 16.85 8 16.85C5.32 16.85 3.15 14.68 3.15 12C3.15 9.32 5.32 7.15 8 7.15M7 9V12.69L10.19 14.53L10.94 13.23L8.5 11.82V9\";\r\nvar mdiSortDescending = \"M19 7H22L18 3L14 7H17V21H19M2 17H12V19H2M6 5V7H2V5M2 11H9V13H2V11Z\";\r\nvar mdiSortNumericAscending = \"M19 17H22L18 21L14 17H17V3H19V17M9 13H7C5.9 13 5 13.9 5 15V16C5 17.11 5.9 18 7 18H9V19H5V21H9C10.11 21 11 20.11 11 19V15C11 13.9 10.11 13 9 13M9 16H7V15H9V16M9 3H7C5.9 3 5 3.9 5 5V9C5 10.11 5.9 11 7 11H9C10.11 11 11 10.11 11 9V5C11 3.9 10.11 3 9 3M9 9H7V5H9V9Z\";\r\nvar mdiSortNumericAscendingVariant = \"M7.78 7C9.08 7.04 10 7.53 10.57 8.46C11.13 9.4 11.41 10.56 11.39 11.95C11.4 13.5 11.09 14.73 10.5 15.62C9.88 16.5 8.95 16.97 7.71 17C6.45 16.96 5.54 16.5 4.96 15.56C4.38 14.63 4.09 13.45 4.09 12S4.39 9.36 5 8.44C5.59 7.5 6.5 7.04 7.78 7M7.75 8.63C7.31 8.63 6.96 8.9 6.7 9.46C6.44 10 6.32 10.87 6.32 12C6.31 13.15 6.44 14 6.69 14.54C6.95 15.1 7.31 15.37 7.77 15.37C8.69 15.37 9.16 14.24 9.17 12C9.17 9.77 8.7 8.65 7.75 8.63M13.33 17V15.22L13.76 15.24L14.3 15.22L15.34 15.03C15.68 14.92 16 14.78 16.26 14.58C16.59 14.35 16.86 14.08 17.07 13.76C17.29 13.45 17.44 13.12 17.53 12.78L17.5 12.77C17.05 13.19 16.38 13.4 15.47 13.41C14.62 13.4 13.91 13.15 13.34 12.65S12.5 11.43 12.46 10.5C12.47 9.5 12.81 8.69 13.47 8.03C14.14 7.37 15 7.03 16.12 7C17.37 7.04 18.29 7.45 18.88 8.24C19.47 9 19.76 10 19.76 11.19C19.75 12.15 19.61 13 19.32 13.76C19.03 14.5 18.64 15.13 18.12 15.64C17.66 16.06 17.11 16.38 16.47 16.61C15.83 16.83 15.12 16.96 14.34 17H13.33M16.06 8.63C15.65 8.64 15.32 8.8 15.06 9.11C14.81 9.42 14.68 9.84 14.68 10.36C14.68 10.8 14.8 11.16 15.03 11.46C15.27 11.77 15.63 11.92 16.11 11.93C16.43 11.93 16.7 11.86 16.92 11.74C17.14 11.61 17.3 11.46 17.41 11.28C17.5 11.17 17.53 10.97 17.53 10.71C17.54 10.16 17.43 9.69 17.2 9.28C16.97 8.87 16.59 8.65 16.06 8.63M9.25 5L12.5 1.75L15.75 5H9.25\";\r\nvar mdiSortNumericDescending = \"M19 7H22L18 3L14 7H17V21H19M9 21H5V19H9V18H7C5.9 18 5 17.11 5 16V15C5 13.9 5.9 13 7 13H9C10.11 13 11 13.9 11 15V19C11 20.11 10.11 21 9 21M9 15H7V16H9M7 3H9C10.11 3 11 3.9 11 5V9C11 10.11 10.11 11 9 11H7C5.9 11 5 10.11 5 9V5C5 3.9 5.9 3 7 3M7 9H9V5H7Z\";\r\nvar mdiSortNumericDescendingVariant = \"M7.78 7C9.08 7.04 10 7.53 10.57 8.46C11.13 9.4 11.41 10.56 11.39 11.95C11.4 13.5 11.09 14.73 10.5 15.62C9.88 16.5 8.95 16.97 7.71 17C6.45 16.96 5.54 16.5 4.96 15.56C4.38 14.63 4.09 13.45 4.09 12S4.39 9.36 5 8.44C5.59 7.5 6.5 7.04 7.78 7M7.75 8.63C7.31 8.63 6.96 8.9 6.7 9.46C6.44 10 6.32 10.87 6.32 12C6.31 13.15 6.44 14 6.69 14.54C6.95 15.1 7.31 15.37 7.77 15.37C8.69 15.37 9.16 14.24 9.17 12C9.17 9.77 8.7 8.65 7.75 8.63M13.33 17V15.22L13.76 15.24L14.3 15.22L15.34 15.03C15.68 14.92 16 14.78 16.26 14.58C16.59 14.35 16.86 14.08 17.07 13.76C17.29 13.45 17.44 13.12 17.53 12.78L17.5 12.77C17.05 13.19 16.38 13.4 15.47 13.41C14.62 13.4 13.91 13.15 13.34 12.65S12.5 11.43 12.46 10.5C12.47 9.5 12.81 8.69 13.47 8.03C14.14 7.37 15 7.03 16.12 7C17.37 7.04 18.29 7.45 18.88 8.24C19.47 9 19.76 10 19.76 11.19C19.75 12.15 19.61 13 19.32 13.76C19.03 14.5 18.64 15.13 18.12 15.64C17.66 16.06 17.11 16.38 16.47 16.61C15.83 16.83 15.12 16.96 14.34 17H13.33M16.06 8.63C15.65 8.64 15.32 8.8 15.06 9.11C14.81 9.42 14.68 9.84 14.68 10.36C14.68 10.8 14.8 11.16 15.03 11.46C15.27 11.77 15.63 11.92 16.11 11.93C16.43 11.93 16.7 11.86 16.92 11.74C17.14 11.61 17.3 11.46 17.41 11.28C17.5 11.17 17.53 10.97 17.53 10.71C17.54 10.16 17.43 9.69 17.2 9.28C16.97 8.87 16.59 8.65 16.06 8.63M15.75 19L12.5 22.25L9.25 19H15.75Z\";\r\nvar mdiSortNumericVariant = \"M7.78,7C9.08,7.04 10,7.53 10.57,8.46C11.13,9.4 11.41,10.56 11.39,11.95C11.4,13.5 11.09,14.73 10.5,15.62C9.88,16.5 8.95,16.97 7.71,17C6.45,16.96 5.54,16.5 4.96,15.56C4.38,14.63 4.09,13.45 4.09,12C4.09,10.55 4.39,9.36 5,8.44C5.59,7.5 6.5,7.04 7.78,7M7.75,8.63C7.31,8.63 6.96,8.9 6.7,9.46C6.44,10 6.32,10.87 6.32,12C6.31,13.15 6.44,14 6.69,14.54C6.95,15.1 7.31,15.37 7.77,15.37C8.69,15.37 9.16,14.24 9.17,12C9.17,9.77 8.7,8.65 7.75,8.63M13.33,17V15.22L13.76,15.24L14.3,15.22L15.34,15.03C15.68,14.92 16,14.78 16.26,14.58C16.59,14.35 16.86,14.08 17.07,13.76C17.29,13.45 17.44,13.12 17.53,12.78L17.5,12.77C17.05,13.19 16.38,13.4 15.47,13.41C14.62,13.4 13.91,13.15 13.34,12.65C12.77,12.15 12.5,11.43 12.46,10.5C12.47,9.5 12.81,8.69 13.47,8.03C14.14,7.37 15,7.03 16.12,7C17.37,7.04 18.29,7.45 18.88,8.24C19.47,9 19.76,10 19.76,11.19C19.75,12.15 19.61,13 19.32,13.76C19.03,14.5 18.64,15.13 18.12,15.64C17.66,16.06 17.11,16.38 16.47,16.61C15.83,16.83 15.12,16.96 14.34,17H13.33M16.06,8.63C15.65,8.64 15.32,8.8 15.06,9.11C14.81,9.42 14.68,9.84 14.68,10.36C14.68,10.8 14.8,11.16 15.03,11.46C15.27,11.77 15.63,11.92 16.11,11.93C16.43,11.93 16.7,11.86 16.92,11.74C17.14,11.61 17.3,11.46 17.41,11.28C17.5,11.17 17.53,10.97 17.53,10.71C17.54,10.16 17.43,9.69 17.2,9.28C16.97,8.87 16.59,8.65 16.06,8.63M9.25,5L12.5,1.75L15.75,5H9.25M15.75,19L12.5,22.25L9.25,19H15.75Z\";\r\nvar mdiSortReverseVariant = \"M3 11H15V13H3M3 18V16H21V18M3 6H9V8H3Z\";\r\nvar mdiSortVariant = \"M3,13H15V11H3M3,6V8H21V6M3,18H9V16H3V18Z\";\r\nvar mdiSortVariantLock = \"M3,13V11H15V13H3M3,6H21V8H3V6M3,18V16H9V18H3M22,22H14V18H15V17A3,3 0 0,1 18,14A3,3 0 0,1 21,17V18H22V22M18,16A1,1 0 0,0 17,17V18H19V17A1,1 0 0,0 18,16Z\";\r\nvar mdiSortVariantLockOpen = \"M3,13V11H15V13H3M3,6H21V8H3V6M3,18V16H9V18H3M22,22H14V18H15V16A3,3 0 0,1 18,13A3,3 0 0,1 21,16H19A1,1 0 0,0 18,15A1,1 0 0,0 17,16V18H22V22Z\";\r\nvar mdiSortVariantRemove = \"M3 13H15V11H3M3 6V8H21V6M3 18H9V16H3V18M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.47 21.12L17.59 19L15.47 16.88L16.88 15.47L19 17.59L21.12 15.46L22.54 16.88\";\r\nvar mdiSoundcloud = \"M11.56,8.87V17H20.32V17C22.17,16.87 23,15.73 23,14.33C23,12.85 21.88,11.66 20.38,11.66C20,11.66 19.68,11.74 19.35,11.88C19.11,9.54 17.12,7.71 14.67,7.71C13.5,7.71 12.39,8.15 11.56,8.87M10.68,9.89C10.38,9.71 10.06,9.57 9.71,9.5V17H11.1V9.34C10.95,9.5 10.81,9.7 10.68,9.89M8.33,9.35V17H9.25V9.38C9.06,9.35 8.87,9.34 8.67,9.34C8.55,9.34 8.44,9.34 8.33,9.35M6.5,10V17H7.41V9.54C7.08,9.65 6.77,9.81 6.5,10M4.83,12.5C4.77,12.5 4.71,12.44 4.64,12.41V17H5.56V10.86C5.19,11.34 4.94,11.91 4.83,12.5M2.79,12.22V16.91C3,16.97 3.24,17 3.5,17H3.72V12.14C3.64,12.13 3.56,12.12 3.5,12.12C3.24,12.12 3,12.16 2.79,12.22M1,14.56C1,15.31 1.34,15.97 1.87,16.42V12.71C1.34,13.15 1,13.82 1,14.56Z\";\r\nvar mdiSourceBranch = \"M13,14C9.64,14 8.54,15.35 8.18,16.24C9.25,16.7 10,17.76 10,19A3,3 0 0,1 7,22A3,3 0 0,1 4,19C4,17.69 4.83,16.58 6,16.17V7.83C4.83,7.42 4,6.31 4,5A3,3 0 0,1 7,2A3,3 0 0,1 10,5C10,6.31 9.17,7.42 8,7.83V13.12C8.88,12.47 10.16,12 12,12C14.67,12 15.56,10.66 15.85,9.77C14.77,9.32 14,8.25 14,7A3,3 0 0,1 17,4A3,3 0 0,1 20,7C20,8.34 19.12,9.5 17.91,9.86C17.65,11.29 16.68,14 13,14M7,18A1,1 0 0,0 6,19A1,1 0 0,0 7,20A1,1 0 0,0 8,19A1,1 0 0,0 7,18M7,4A1,1 0 0,0 6,5A1,1 0 0,0 7,6A1,1 0 0,0 8,5A1,1 0 0,0 7,4M17,6A1,1 0 0,0 16,7A1,1 0 0,0 17,8A1,1 0 0,0 18,7A1,1 0 0,0 17,6Z\";\r\nvar mdiSourceBranchCheck = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M16.75 21.16L14 18.16L15.16 17L16.75 18.59L20.34 15L21.5 16.41L16.75 21.16\";\r\nvar mdiSourceBranchMinus = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M14 17V19H22V17H14Z\";\r\nvar mdiSourceBranchPlus = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M17 14V17H14V19H17V22H19V19H22V17H19V14H17Z\";\r\nvar mdiSourceBranchRefresh = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M18 14C19.1 14 20.1 14.4 20.8 15.2L22 14V18H18L19.8 16.2C19.3 15.8 18.7 15.5 18 15.5C16.6 15.5 15.5 16.6 15.5 18S16.6 20.5 18 20.5C18.8 20.5 19.5 20.1 20 19.5H21.7C21.1 21 19.7 22 18 22C15.8 22 14 20.2 14 18S15.8 14 18 14Z\";\r\nvar mdiSourceBranchRemove = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M20.12 14.46L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.54L18 19.41L20.12 21.54L21.54 20.12L19.41 18L21.54 15.88L20.12 14.46Z\";\r\nvar mdiSourceBranchSync = \"M13 14C9.64 14 8.54 15.35 8.18 16.24C9.25 16.7 10 17.76 10 19C10 20.66 8.66 22 7 22S4 20.66 4 19C4 17.69 4.83 16.58 6 16.17V7.83C4.83 7.42 4 6.31 4 5C4 3.34 5.34 2 7 2S10 3.34 10 5C10 6.31 9.17 7.42 8 7.83V13.12C8.88 12.47 10.16 12 12 12C14.67 12 15.56 10.66 15.85 9.77C14.77 9.32 14 8.25 14 7C14 5.34 15.34 4 17 4S20 5.34 20 7C20 8.34 19.12 9.5 17.91 9.86C17.65 11.29 16.68 14 13 14M7 18C6.45 18 6 18.45 6 19S6.45 20 7 20 8 19.55 8 19 7.55 18 7 18M7 4C6.45 4 6 4.45 6 5S6.45 6 7 6 8 5.55 8 5 7.55 4 7 4M17 6C16.45 6 16 6.45 16 7S16.45 8 17 8 18 7.55 18 7 17.55 6 17 6M18 13V14.5C20.21 14.5 22 16.29 22 18.5C22 19.32 21.75 20.08 21.33 20.71L20.24 19.62C20.41 19.28 20.5 18.9 20.5 18.5C20.5 17.12 19.38 16 18 16V17.5L15.75 15.25L15.72 15.22C15.78 15.17 15.85 15.13 18 13M18 24V22.5C15.79 22.5 14 20.71 14 18.5C14 17.68 14.25 16.92 14.67 16.29L15.76 17.38C15.59 17.72 15.5 18.1 15.5 18.5C15.5 19.88 16.62 21 18 21V19.5L20.25 21.75L20.28 21.78C20.22 21.83 20.15 21.87 18 24\";\r\nvar mdiSourceCommit = \"M17,12C17,14.42 15.28,16.44 13,16.9V21H11V16.9C8.72,16.44 7,14.42 7,12C7,9.58 8.72,7.56 11,7.1V3H13V7.1C15.28,7.56 17,9.58 17,12M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiSourceCommitEnd = \"M17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12C7,9.58 8.72,7.56 11,7.1V3H13V7.1C15.28,7.56 17,9.58 17,12M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiSourceCommitEndLocal = \"M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M11,5V3H13V5H11Z\";\r\nvar mdiSourceCommitLocal = \"M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M11,5V3H13V5H11M11,21V19H13V21H11Z\";\r\nvar mdiSourceCommitNextLocal = \"M17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12C7,9.58 8.72,7.56 11,7.1V3H13V7.1C15.28,7.56 17,9.58 17,12M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M11,21V19H13V21H11Z\";\r\nvar mdiSourceCommitStart = \"M12,7A5,5 0 0,1 17,12C17,14.42 15.28,16.44 13,16.9V21H11V16.9C8.72,16.44 7,14.42 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9Z\";\r\nvar mdiSourceCommitStartNextLocal = \"M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M11,21V19H13V21H11Z\";\r\nvar mdiSourceFork = \"M6,2A3,3 0 0,1 9,5C9,6.28 8.19,7.38 7.06,7.81C7.15,8.27 7.39,8.83 8,9.63C9,10.92 11,12.83 12,14.17C13,12.83 15,10.92 16,9.63C16.61,8.83 16.85,8.27 16.94,7.81C15.81,7.38 15,6.28 15,5A3,3 0 0,1 18,2A3,3 0 0,1 21,5C21,6.32 20.14,7.45 18.95,7.85C18.87,8.37 18.64,9 18,9.83C17,11.17 15,13.08 14,14.38C13.39,15.17 13.15,15.73 13.06,16.19C14.19,16.62 15,17.72 15,19A3,3 0 0,1 12,22A3,3 0 0,1 9,19C9,17.72 9.81,16.62 10.94,16.19C10.85,15.73 10.61,15.17 10,14.38C9,13.08 7,11.17 6,9.83C5.36,9 5.13,8.37 5.05,7.85C3.86,7.45 3,6.32 3,5A3,3 0 0,1 6,2M6,4A1,1 0 0,0 5,5A1,1 0 0,0 6,6A1,1 0 0,0 7,5A1,1 0 0,0 6,4M18,4A1,1 0 0,0 17,5A1,1 0 0,0 18,6A1,1 0 0,0 19,5A1,1 0 0,0 18,4M12,18A1,1 0 0,0 11,19A1,1 0 0,0 12,20A1,1 0 0,0 13,19A1,1 0 0,0 12,18Z\";\r\nvar mdiSourceMerge = \"M7,3A3,3 0 0,1 10,6C10,7.29 9.19,8.39 8.04,8.81C8.58,13.81 13.08,14.77 15.19,14.96C15.61,13.81 16.71,13 18,13A3,3 0 0,1 21,16A3,3 0 0,1 18,19C16.69,19 15.57,18.16 15.16,17C10.91,16.8 9.44,15.19 8,13.39V15.17C9.17,15.58 10,16.69 10,18A3,3 0 0,1 7,21A3,3 0 0,1 4,18C4,16.69 4.83,15.58 6,15.17V8.83C4.83,8.42 4,7.31 4,6A3,3 0 0,1 7,3M7,5A1,1 0 0,0 6,6A1,1 0 0,0 7,7A1,1 0 0,0 8,6A1,1 0 0,0 7,5M7,17A1,1 0 0,0 6,18A1,1 0 0,0 7,19A1,1 0 0,0 8,18A1,1 0 0,0 7,17M18,15A1,1 0 0,0 17,16A1,1 0 0,0 18,17A1,1 0 0,0 19,16A1,1 0 0,0 18,15Z\";\r\nvar mdiSourcePull = \"M6,3A3,3 0 0,1 9,6C9,7.31 8.17,8.42 7,8.83V15.17C8.17,15.58 9,16.69 9,18A3,3 0 0,1 6,21A3,3 0 0,1 3,18C3,16.69 3.83,15.58 5,15.17V8.83C3.83,8.42 3,7.31 3,6A3,3 0 0,1 6,3M6,5A1,1 0 0,0 5,6A1,1 0 0,0 6,7A1,1 0 0,0 7,6A1,1 0 0,0 6,5M6,17A1,1 0 0,0 5,18A1,1 0 0,0 6,19A1,1 0 0,0 7,18A1,1 0 0,0 6,17M21,18A3,3 0 0,1 18,21A3,3 0 0,1 15,18C15,16.69 15.83,15.58 17,15.17V7H15V10.25L10.75,6L15,1.75V5H17A2,2 0 0,1 19,7V15.17C20.17,15.58 21,16.69 21,18M18,17A1,1 0 0,0 17,18A1,1 0 0,0 18,19A1,1 0 0,0 19,18A1,1 0 0,0 18,17Z\";\r\nvar mdiSourceRepository = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M12.75,13.5C15.5,13.5 16.24,11.47 16.43,10.4C17.34,10.11 18,9.26 18,8.25C18,7 17,6 15.75,6C14.5,6 13.5,7 13.5,8.25C13.5,9.19 14.07,10 14.89,10.33C14.67,11 14,12 12,12C10.62,12 9.66,12.35 9,12.84V8.87C9.87,8.56 10.5,7.73 10.5,6.75C10.5,5.5 9.5,4.5 8.25,4.5C7,4.5 6,5.5 6,6.75C6,7.73 6.63,8.56 7.5,8.87V15.13C6.63,15.44 6,16.27 6,17.25C6,18.5 7,19.5 8.25,19.5C9.5,19.5 10.5,18.5 10.5,17.25C10.5,16.32 9.94,15.5 9.13,15.18C9.41,14.5 10.23,13.5 12.75,13.5M8.25,16.5A0.75,0.75 0 0,1 9,17.25A0.75,0.75 0 0,1 8.25,18A0.75,0.75 0 0,1 7.5,17.25A0.75,0.75 0 0,1 8.25,16.5M8.25,6A0.75,0.75 0 0,1 9,6.75A0.75,0.75 0 0,1 8.25,7.5A0.75,0.75 0 0,1 7.5,6.75A0.75,0.75 0 0,1 8.25,6M15.75,7.5A0.75,0.75 0 0,1 16.5,8.25A0.75,0.75 0 0,1 15.75,9A0.75,0.75 0 0,1 15,8.25A0.75,0.75 0 0,1 15.75,7.5Z\";\r\nvar mdiSourceRepositoryMultiple = \"M8,0H20A2,2 0 0,1 22,2V18A2,2 0 0,1 20,20H8A2,2 0 0,1 6,18V2A2,2 0 0,1 8,0M14.75,11.5C17.5,11.5 18.24,9.47 18.43,8.4C19.34,8.11 20,7.26 20,6.25C20,5 19,4 17.75,4C16.5,4 15.5,5 15.5,6.25C15.5,7.19 16.07,8 16.89,8.33C16.67,9 16,10 14,10C12.62,10 11.66,10.35 11,10.84V6.87C11.87,6.56 12.5,5.73 12.5,4.75C12.5,3.5 11.5,2.5 10.25,2.5C9,2.5 8,3.5 8,4.75C8,5.73 8.63,6.56 9.5,6.87V13.13C8.63,13.44 8,14.27 8,15.25C8,16.5 9,17.5 10.25,17.5C11.5,17.5 12.5,16.5 12.5,15.25C12.5,14.32 11.94,13.5 11.13,13.18C11.41,12.5 12.23,11.5 14.75,11.5M10.25,14.5A0.75,0.75 0 0,1 11,15.25A0.75,0.75 0 0,1 10.25,16A0.75,0.75 0 0,1 9.5,15.25A0.75,0.75 0 0,1 10.25,14.5M10.25,4A0.75,0.75 0 0,1 11,4.75A0.75,0.75 0 0,1 10.25,5.5A0.75,0.75 0 0,1 9.5,4.75A0.75,0.75 0 0,1 10.25,4M17.75,5.5A0.75,0.75 0 0,1 18.5,6.25A0.75,0.75 0 0,1 17.75,7A0.75,0.75 0 0,1 17,6.25A0.75,0.75 0 0,1 17.75,5.5M16,22V24H4A2,2 0 0,1 2,22V6H4V22H16Z\";\r\nvar mdiSoySauce = \"M13.9,7.5C13.9,6.8 14.1,6.3 14.2,6H14.8L15.7,3.5H16.5V2H7.5V3.5H8.3L9.2,6H9.8C10,6.3 10.1,6.8 10.1,7.5C10.1,8.8 6,13.7 6,17.6V19.6C6,21 8.7,21.9 12,21.9C15.3,21.9 18,21 18,19.6V17.6C18,13.7 13.9,8.8 13.9,7.5M12,15A2,2 0 0,1 10,13A2,2 0 0,1 12,11A2,2 0 0,1 14,13A2,2 0 0,1 12,15Z\";\r\nvar mdiSoySauceOff = \"M22.1 21.5L2.4 1.7L1.1 3L8.6 10.5C7.5 12.6 6 15.3 6 17.6V19.6C6 21 8.7 21.9 12 21.9C15.1 21.9 17.7 21.1 18 19.9L20.9 22.8L22.1 21.5M12 15C10.9 15 10 14.1 10 13C10 12.7 10.1 12.4 10.2 12.1L12.9 14.8C12.6 14.9 12.3 15 12 15M8.3 3.5H7.5V2H16.5V3.5H15.7L14.8 6H14.2C14.1 6.3 13.9 6.8 13.9 7.5C13.9 8.4 15.9 11 17.1 13.9L10.1 6.9C10 6.5 9.9 6.2 9.8 6H9.2L8.3 3.5Z\";\r\nvar mdiSpa = \"M15.5,9.63C15.31,6.84 14.18,4.12 12.06,2C9.92,4.14 8.74,6.86 8.5,9.63C9.79,10.31 10.97,11.19 12,12.26C13.03,11.2 14.21,10.32 15.5,9.63M12,15.45C9.85,12.17 6.18,10 2,10C2,20 11.32,21.89 12,22C12.68,21.88 22,20 22,10C17.82,10 14.15,12.17 12,15.45Z\";\r\nvar mdiSpaOutline = \"M15.5,9.63C14.21,10.32 13.03,11.2 12,12.26C10.97,11.19 9.79,10.31 8.5,9.63C8.74,6.86 9.92,4.14 12.06,2C14.18,4.12 15.31,6.84 15.5,9.63M12,15.45C14.15,12.17 17.82,10 22,10C22,20 12.68,21.88 12,22C11.32,21.89 2,20 2,10C6.18,10 9.85,12.17 12,15.45M12.05,5.19C11.39,6.23 10.93,7.38 10.68,8.58L12,9.55L13.35,8.57C13.12,7.37 12.68,6.22 12.05,5.19M12,19.97C12,19.97 18,19 19.74,12.25C14,14 12,19.1 12,19.1C12,19.1 9,13 4.26,12.26C6,19 12,19.97 12,19.97Z\";\r\nvar mdiSpaceInvaders = \"M7,6H5V4H7V6M17,6H19V4H17V6M23,12V18H21V14H19V18H17V16H7V18H5V14H3V18H1V12H3V10H5V8H7V6H9V8H15V6H17V8H19V10H21V12H23M15,10V12H17V10H15M7,12H9V10H7V12M11,18H7V20H11V18M17,18H13V20H17V18Z\";\r\nvar mdiSpaceStation = \"M15.5 19V21H13.73C13.39 21.6 12.74 22 12 22C11.26 22 10.61 21.6 10.27 21H8.5V19H10.27C10.44 18.7 10.7 18.44 11 18.27V17H10C9.45 17 9 16.55 9 16V13H6V17C6 17.55 5.55 18 5 18H3C2.45 18 2 17.55 2 17V8C2 7.45 2.45 7 3 7H5C5.55 7 6 7.45 6 8V11H9V8C9 7.45 9.45 7 10 7H11V6H10C9.45 6 9 5.55 9 5V4C9 3.45 9.45 3 10 3H14C14.55 3 15 3.45 15 4V5C15 5.55 14.55 6 14 6H13V7H14C14.55 7 15 7.45 15 8V11H18V8C18 7.45 18.45 7 19 7H21C21.55 7 22 7.45 22 8V17C22 17.55 21.55 18 21 18H19C18.45 18 18 17.55 18 17V13H15V16C15 16.55 14.55 17 14 17H13V18.27C13.3 18.44 13.56 18.7 13.73 19H15.5M3 16V17H5V16H3M3 14V15H5V14H3M3 12V13H5V12H3M3 10V11H5V10H3M3 8V9H5V8H3M19 16V17H21V16H19M19 14V15H21V14H19M19 12V13H21V12H19M19 10V11H21V10H19M19 8V9H21V8H19Z\";\r\nvar mdiSpade = \"M15.71,1.22L12.88,4.05C12.1,4.83 12.1,6.09 12.88,6.87L14.3,8.29L10.06,12.53L7.58,10.06L1.22,16.42L7.58,22.78L13.94,16.42L11.47,13.94L15.71,9.7L17.13,11.12C17.91,11.9 19.17,11.9 19.95,11.12L22.78,8.29L15.71,1.22M15.71,4.05L19.95,8.29L18.54,9.7L14.3,5.46L15.71,4.05Z\";\r\nvar mdiSparkles = \"M10.6 9.6L9 15L7.4 9.6L2 8L7.4 6.4L9 1L10.6 6.4L16 8L10.6 9.6M17 14.2L21 12L18.8 16L21 20L17 17.8L13 20L15.2 16L13 12L17 14.2M10 16L8.3 19L10 22L7 20.3L4 22L5.7 19L4 16L7 17.7L10 16\";\r\nvar mdiSpeaker = \"M12,12A3,3 0 0,0 9,15A3,3 0 0,0 12,18A3,3 0 0,0 15,15A3,3 0 0,0 12,12M12,20A5,5 0 0,1 7,15A5,5 0 0,1 12,10A5,5 0 0,1 17,15A5,5 0 0,1 12,20M12,4A2,2 0 0,1 14,6A2,2 0 0,1 12,8C10.89,8 10,7.1 10,6C10,4.89 10.89,4 12,4M17,2H7C5.89,2 5,2.89 5,4V20A2,2 0 0,0 7,22H17A2,2 0 0,0 19,20V4C19,2.89 18.1,2 17,2Z\";\r\nvar mdiSpeakerBluetooth = \"M4,3A2,2 0 0,0 2,5V19A2,2 0 0,0 4,21H12A2,2 0 0,0 14,19V5A2,2 0 0,0 12,3H4M8,5A2,2 0 0,1 10,7A2,2 0 0,1 8,9A2,2 0 0,1 6,7A2,2 0 0,1 8,5M19,7V10.79L16.71,8.5L16,9.21L18.79,12L16,14.79L16.71,15.5L19,13.21V17H19.5L22.35,14.14L20.21,12L22.35,9.85L19.5,7H19M20,8.91L20.94,9.85L20,10.79V8.91M8,11A4,4 0 0,1 12,15A4,4 0 0,1 8,19A4,4 0 0,1 4,15A4,4 0 0,1 8,11M8,13A2,2 0 0,0 6,15A2,2 0 0,0 8,17A2,2 0 0,0 10,15A2,2 0 0,0 8,13M20,13.21L20.94,14.14L20,15.08V13.21Z\";\r\nvar mdiSpeakerMultiple = \"M14,10A3,3 0 0,0 11,13A3,3 0 0,0 14,16A3,3 0 0,0 17,13A3,3 0 0,0 14,10M14,18A5,5 0 0,1 9,13A5,5 0 0,1 14,8A5,5 0 0,1 19,13A5,5 0 0,1 14,18M14,2A2,2 0 0,1 16,4A2,2 0 0,1 14,6A2,2 0 0,1 12,4A2,2 0 0,1 14,2M19,0H9A2,2 0 0,0 7,2V18A2,2 0 0,0 9,20H19A2,2 0 0,0 21,18V2A2,2 0 0,0 19,0M5,22H17V24H5A2,2 0 0,1 3,22V4H5\";\r\nvar mdiSpeakerOff = \"M2,5.27L3.28,4L21,21.72L19.73,23L18.27,21.54C17.93,21.83 17.5,22 17,22H7C5.89,22 5,21.1 5,20V8.27L2,5.27M12,18A3,3 0 0,1 9,15C9,14.24 9.28,13.54 9.75,13L8.33,11.6C7.5,12.5 7,13.69 7,15A5,5 0 0,0 12,20C13.31,20 14.5,19.5 15.4,18.67L14,17.25C13.45,17.72 12.76,18 12,18M17,15A5,5 0 0,0 12,10H11.82L5.12,3.3C5.41,2.54 6.14,2 7,2H17A2,2 0 0,1 19,4V17.18L17,15.17V15M12,4C10.89,4 10,4.89 10,6A2,2 0 0,0 12,8A2,2 0 0,0 14,6C14,4.89 13.1,4 12,4Z\";\r\nvar mdiSpeakerWireless = \"M20.07,19.07L18.66,17.66C20.11,16.22 21,14.21 21,12C21,9.78 20.11,7.78 18.66,6.34L20.07,4.93C21.88,6.74 23,9.24 23,12C23,14.76 21.88,17.26 20.07,19.07M17.24,16.24L15.83,14.83C16.55,14.11 17,13.11 17,12C17,10.89 16.55,9.89 15.83,9.17L17.24,7.76C18.33,8.85 19,10.35 19,12C19,13.65 18.33,15.15 17.24,16.24M4,3H12A2,2 0 0,1 14,5V19A2,2 0 0,1 12,21H4A2,2 0 0,1 2,19V5A2,2 0 0,1 4,3M8,5A2,2 0 0,0 6,7A2,2 0 0,0 8,9A2,2 0 0,0 10,7A2,2 0 0,0 8,5M8,11A4,4 0 0,0 4,15A4,4 0 0,0 8,19A4,4 0 0,0 12,15A4,4 0 0,0 8,11M8,13A2,2 0 0,1 10,15A2,2 0 0,1 8,17A2,2 0 0,1 6,15A2,2 0 0,1 8,13Z\";\r\nvar mdiSpeedometer = \"M12,16A3,3 0 0,1 9,13C9,11.88 9.61,10.9 10.5,10.39L20.21,4.77L14.68,14.35C14.18,15.33 13.17,16 12,16M12,3C13.81,3 15.5,3.5 16.97,4.32L14.87,5.53C14,5.19 13,5 12,5A8,8 0 0,0 4,13C4,15.21 4.89,17.21 6.34,18.65H6.35C6.74,19.04 6.74,19.67 6.35,20.06C5.96,20.45 5.32,20.45 4.93,20.07V20.07C3.12,18.26 2,15.76 2,13A10,10 0 0,1 12,3M22,13C22,15.76 20.88,18.26 19.07,20.07V20.07C18.68,20.45 18.05,20.45 17.66,20.06C17.27,19.67 17.27,19.04 17.66,18.65V18.65C19.11,17.2 20,15.21 20,13C20,12 19.81,11 19.46,10.1L20.67,8C21.5,9.5 22,11.18 22,13Z\";\r\nvar mdiSpeedometerMedium = \"M12 1.38L9.14 12.06C8.8 13.1 9.04 14.29 9.86 15.12C11.04 16.29 12.94 16.29 14.11 15.12C14.9 14.33 15.16 13.2 14.89 12.21M14.6 3.35L15.22 5.68C18.04 6.92 20 9.73 20 13C20 15.21 19.11 17.21 17.66 18.65H17.65C17.26 19.04 17.26 19.67 17.65 20.06C18.04 20.45 18.68 20.45 19.07 20.07C20.88 18.26 22 15.76 22 13C22 8.38 18.86 4.5 14.6 3.35M9.4 3.36C5.15 4.5 2 8.4 2 13C2 15.76 3.12 18.26 4.93 20.07C5.32 20.45 5.95 20.45 6.34 20.06C6.73 19.67 6.73 19.04 6.34 18.65C4.89 17.2 4 15.21 4 13C4 9.65 5.94 6.86 8.79 5.65\";\r\nvar mdiSpeedometerSlow = \"M12 16C13.66 16 15 14.66 15 13C15 11.88 14.39 10.9 13.5 10.39L3.79 4.77L9.32 14.35C9.82 15.33 10.83 16 12 16M12 3C10.19 3 8.5 3.5 7.03 4.32L9.13 5.53C10 5.19 11 5 12 5C16.42 5 20 8.58 20 13C20 15.21 19.11 17.21 17.66 18.65H17.65C17.26 19.04 17.26 19.67 17.65 20.06C18.04 20.45 18.68 20.45 19.07 20.07C20.88 18.26 22 15.76 22 13C22 7.5 17.5 3 12 3M2 13C2 15.76 3.12 18.26 4.93 20.07C5.32 20.45 5.95 20.45 6.34 20.06C6.73 19.67 6.73 19.04 6.34 18.65C4.89 17.2 4 15.21 4 13C4 12 4.19 11 4.54 10.1L3.33 8C2.5 9.5 2 11.18 2 13Z\";\r\nvar mdiSpellcheck = \"M21.59,11.59L13.5,19.68L9.83,16L8.42,17.41L13.5,22.5L23,13M6.43,11L8.5,5.5L10.57,11M12.45,16H14.54L9.43,3H7.57L2.46,16H4.55L5.67,13H11.31L12.45,16Z\";\r\nvar mdiSpider = \"M21.29 16.71L22.71 15.29L19.5 12.11L16.5 11.26L18.41 11L22.6 7.8L21.4 6.2L17.59 9.05L14.91 9.5L18.11 6.31L17 1.76L15 2.24L15.86 5.69L14.76 6.83A3 3 0 0 0 9.24 6.83L8.11 5.69L9 2.24L7 1.76L5.89 6.31L9.09 9.5L6.4 9.05L2.6 6.2L1.4 7.8L5.6 11L7.46 11.31L4.46 12.16L1.29 15.29L2.71 16.71L5.5 13.89L7.87 13.22L4 16.54V22H6V17.46L7.56 16.12A4.5 4.5 0 0 0 16.44 16.12L18 17.46V22H20V16.54L16.13 13.22L18.5 13.89Z\";\r\nvar mdiSpiderThread = \"M13 2V7.08A5.47 5.47 0 0 0 12 7A5.47 5.47 0 0 0 11 7.08V2M16.9 15A5 5 0 0 1 16.73 15.55L20 17.42V22H18V18.58L15.74 17.29A4.94 4.94 0 0 1 8.26 17.29L6 18.58V22H4V17.42L7.27 15.55A5 5 0 0 1 7.1 15H5.3L2.55 16.83L1.45 15.17L4.7 13H7.1A5 5 0 0 1 7.37 12.12L5.81 11.12L2.24 12L1.76 10L6.19 8.92L8.5 10.45A5 5 0 0 1 15.5 10.45L17.77 8.92L22.24 10L21.76 12L18.19 11.11L16.63 12.11A5 5 0 0 1 16.9 13H19.3L22.55 15.16L21.45 16.82L18.7 15M11 14A1 1 0 1 0 10 15A1 1 0 0 0 11 14M15 14A1 1 0 1 0 14 15A1 1 0 0 0 15 14Z\";\r\nvar mdiSpiderWeb = \"M13.62,13.28L15.26,15.54C15.29,15 15.38,14.47 15.56,13.93C15.74,13.37 16,12.86 16.3,12.41L13.62,13.28M17.77,19C17.75,17.68 17.95,16.27 18.41,14.85C18.88,13.42 19.56,12.14 20.36,11.09L18.32,11.75C17.54,12.26 16.87,13.14 16.5,14.23C16.17,15.29 16.18,16.36 16.5,17.22L17.77,19M19.25,21C18.75,21.46 18.21,21.86 17.63,22.2L17.31,21.76C15.9,21 14.04,20.5 12,20.5C9.96,20.5 8.1,21 6.69,21.76L6.37,22.2C5.79,21.86 5.25,21.46 4.75,21L5,20.69C5.33,19.08 5.22,17.12 4.58,15.14C3.94,13.19 2.9,11.56 1.71,10.46L1.27,10.32C1.42,9.66 1.63,9 1.89,8.41L2.29,8.54C3.92,8.37 5.74,7.65 7.43,6.43C9.09,5.22 10.32,3.73 11,2.26V1.79L12,1.75L13,1.79V2.21C13.67,3.71 14.91,5.23 16.6,6.45C18.26,7.66 20.06,8.37 21.67,8.56L22.11,8.41C22.37,9 22.58,9.66 22.73,10.32L22.23,10.5C21.04,11.58 20,13.21 19.37,15.16C18.74,17.09 18.62,19 18.92,20.57L19.25,21M11,11.37V8.5C10.66,8.92 10.26,9.32 9.78,9.67C9.29,10 8.77,10.29 8.25,10.5L11,11.37M11,4.22C10.25,5.31 9.24,6.35 8,7.24C6.78,8.14 5.46,8.78 4.18,9.16L6.15,9.8C7.11,9.88 8.22,9.56 9.19,8.86C10.13,8.18 10.76,7.27 11,6.36V4.22M13,11.37L15.74,10.5C15.23,10.3 14.72,10.03 14.25,9.69C13.76,9.33 13.34,8.92 13,8.5V11.37M19.8,9.16C18.53,8.78 17.23,8.15 16,7.26C14.77,6.36 13.76,5.31 13,4.2V6.27C13.22,7.21 13.86,8.17 14.84,8.88C15.77,9.56 16.83,9.87 17.77,9.82L19.8,9.16M10.38,13.28L7.64,12.39C7.95,12.84 8.2,13.35 8.38,13.91C8.57,14.5 8.66,15.06 8.68,15.62L10.38,13.28M3.58,11.07C4.38,12.12 5.06,13.4 5.53,14.83C6,16.29 6.2,17.74 6.17,19.08L7.38,17.41C7.76,16.5 7.8,15.36 7.43,14.22C7.07,13.12 6.4,12.24 5.61,11.73L3.58,11.07M12,14.45L10.35,16.72C10.87,16.58 11.42,16.5 12,16.5C12.58,16.5 13.13,16.58 13.65,16.72L12,14.45M7.84,20.18C9.08,19.75 10.5,19.5 12,19.5C13.5,19.5 14.92,19.75 16.16,20.18L14.88,18.42C14.16,17.85 13.13,17.5 12,17.5C10.87,17.5 9.84,17.85 9.12,18.42L7.84,20.18Z\";\r\nvar mdiSpiritLevel = \"M22 8H2V16H22V8M18 14V10H20V14H18M11 12H13C14.1 12 15 11.11 15 10H17V14H7V10H9C9 11.11 9.9 12 11 12M4 14V10H6V14H4Z\";\r\nvar mdiSpoonSugar = \"M6 13H3V10H6V13M10 10H7V13H10V10M8 6H5V9H8V6M18 12C14.25 12 12.28 13.25 11 14H2C2 16.21 3.79 18 6 18H7C8 18 8.92 17.63 9.62 17C11.06 15.78 12.68 14.74 14.55 14.36C15.61 14.15 16.78 14 18 14H22V12H18Z\";\r\nvar mdiSpotify = \"M17.9,10.9C14.7,9 9.35,8.8 6.3,9.75C5.8,9.9 5.3,9.6 5.15,9.15C5,8.65 5.3,8.15 5.75,8C9.3,6.95 15.15,7.15 18.85,9.35C19.3,9.6 19.45,10.2 19.2,10.65C18.95,11 18.35,11.15 17.9,10.9M17.8,13.7C17.55,14.05 17.1,14.2 16.75,13.95C14.05,12.3 9.95,11.8 6.8,12.8C6.4,12.9 5.95,12.7 5.85,12.3C5.75,11.9 5.95,11.45 6.35,11.35C10,10.25 14.5,10.8 17.6,12.7C17.9,12.85 18.05,13.35 17.8,13.7M16.6,16.45C16.4,16.75 16.05,16.85 15.75,16.65C13.4,15.2 10.45,14.9 6.95,15.7C6.6,15.8 6.3,15.55 6.2,15.25C6.1,14.9 6.35,14.6 6.65,14.5C10.45,13.65 13.75,14 16.35,15.6C16.7,15.75 16.75,16.15 16.6,16.45M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiSpotlight = \"M2,6L7.09,8.55C6.4,9.5 6,10.71 6,12C6,13.29 6.4,14.5 7.09,15.45L2,18V6M6,3H18L15.45,7.09C14.5,6.4 13.29,6 12,6C10.71,6 9.5,6.4 8.55,7.09L6,3M22,6V18L16.91,15.45C17.6,14.5 18,13.29 18,12C18,10.71 17.6,9.5 16.91,8.55L22,6M18,21H6L8.55,16.91C9.5,17.6 10.71,18 12,18C13.29,18 14.5,17.6 15.45,16.91L18,21M12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiSpotlightBeam = \"M9,16.5L9.91,15.59L15.13,20.8L14.21,21.71L9,16.5M15.5,10L16.41,9.09L21.63,14.3L20.71,15.21L15.5,10M6.72,2.72L10.15,6.15L6.15,10.15L2.72,6.72C1.94,5.94 1.94,4.67 2.72,3.89L3.89,2.72C4.67,1.94 5.94,1.94 6.72,2.72M14.57,7.5L15.28,8.21L8.21,15.28L7.5,14.57L6.64,11.07L11.07,6.64L14.57,7.5Z\";\r\nvar mdiSpray = \"M10,4H12V6H10V4M7,3H9V5H7V3M7,6H9V8H7V6M6,8V10H4V8H6M6,5V7H4V5H6M6,2V4H4V2H6M13,22A2,2 0 0,1 11,20V10A2,2 0 0,1 13,8V7H14V4H17V7H18V8A2,2 0 0,1 20,10V20A2,2 0 0,1 18,22H13M13,10V20H18V10H13Z\";\r\nvar mdiSprayBottle = \"M12,7H15C15.66,7.64 16,8.31 16,9V22H8V15C8,14.72 8.11,14.39 8.3,14L12,7M16,4L15,6H12V5L10,7H9L10,5V4H9V2H14.5A1.5,1.5 0 0,1 16,3.5V4Z\";\r\nvar mdiSprinkler = \"M11 7H13V9H11V7M5 22H9V10H5V22M14 11H16V9H14V11M17 10H19V8H17V10M17 5V7H19V5H17M14 8H16V6H14V8M17 13H19V11H17V13M5 7H5.33L6 9H8L8.67 7H9V6H5V7Z\";\r\nvar mdiSprinklerVariant = \"M10 10H14V22H10V10M7 9H9V7H7V9M4 8H6V6H4V8M4 11H6V9H4V11M1 13H3V11H1V13M1 7H3V5H1V7M1 10H3V8H1V10M18 11H20V9H18V11M21 10H23V8H21V10M21 5V7H23V5H21M21 13H23V11H21V13M15 9H17V7H15V9M18 8H20V6H18V8M10 7H10.33L11 9H13L13.67 7H14V6H10V7Z\";\r\nvar mdiSprout = \"M2,22V20C2,20 7,18 12,18C17,18 22,20 22,20V22H2M11.3,9.1C10.1,5.2 4,6.1 4,6.1C4,6.1 4.2,13.9 9.9,12.7C9.5,9.8 8,9 8,9C10.8,9 11,12.4 11,12.4V17C11.3,17 11.7,17 12,17C12.3,17 12.7,17 13,17V12.8C13,12.8 13,8.9 16,7.9C16,7.9 14,10.9 14,12.9C21,13.6 21,4 21,4C21,4 12.1,3 11.3,9.1Z\";\r\nvar mdiSproutOutline = \"M23,4.1V2.3L21.2,2.1C21.1,2.1 20.5,2 19.5,2C15.4,2 12.4,3.2 10.7,5.3C9.4,4.5 7.6,4 5.5,4C4.5,4 3.8,4.1 3.8,4.1L1.9,4.4L2,6.1C2.1,9.1 3.6,14.8 8.8,14.8C8.9,14.8 8.9,14.8 9,14.8V18.2C5.2,18.7 2,20 2,20V22H22V20C22,20 18.8,18.7 15,18.2V15C21.3,14.9 23,7.8 23,4.1M12,18C11.7,18 11.3,18 11,18V12.4C11,12.4 10.8,9 8,9C8,9 9.5,9.8 9.9,12.7C9.5,12.8 9.1,12.8 8.8,12.8C4.2,12.8 4,6.1 4,6.1C4,6.1 4.6,6 5.5,6C7.4,6 10.5,6.4 11.4,9.1C11.9,4.6 17,4 19.5,4C20.4,4 21,4.1 21,4.1C21,4.1 21,13.1 14.7,13.1C14.5,13.1 14.2,13.1 14,13.1C14,11.1 16,8.1 16,8.1C13,9.1 13,13 13,13V18C12.7,18 12.3,18 12,18Z\";\r\nvar mdiSquare = \"M3,3V21H21V3\";\r\nvar mdiSquareCircle = \"M20 4V20H4V4H20M22 2H2V22H22V2M12 6C8.69 6 6 8.69 6 12S8.69 18 12 18 18 15.31 18 12 15.31 6 12 6Z\";\r\nvar mdiSquareEditOutline = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V12H19V19H5V5H12V3H5M17.78,4C17.61,4 17.43,4.07 17.3,4.2L16.08,5.41L18.58,7.91L19.8,6.7C20.06,6.44 20.06,6 19.8,5.75L18.25,4.2C18.12,4.07 17.95,4 17.78,4M15.37,6.12L8,13.5V16H10.5L17.87,8.62L15.37,6.12Z\";\r\nvar mdiSquareMedium = \"M16,8H8V16H16V8Z\";\r\nvar mdiSquareMediumOutline = \"M14,10V14H10V10H14M16,8H8V16H16V8Z\";\r\nvar mdiSquareOff = \"M20.84 22.73L19.11 21H3V4.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M21 3H6.2L21 17.8V3Z\";\r\nvar mdiSquareOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L3 4.89V21H19.11L20.84 22.73L22.11 21.46M5 19V6.89L17.11 19H5M8.2 5L6.2 3H21V17.8L19 15.8V5H8.2Z\";\r\nvar mdiSquareOutline = \"M3,3H21V21H3V3M5,5V19H19V5H5Z\";\r\nvar mdiSquareRoot = \"M11.76,16.83L14.59,14L11.76,11.17L13.17,9.76L16,12.59L18.83,9.76L20.24,11.17L17.41,14L20.24,16.83L18.83,18.24L16,15.41L13.17,18.24L11.76,16.83M2,11H5V11H5L7.29,16.4L10,6H22V8H11.55L8.68,19H6.22L3.68,13H2V11Z\";\r\nvar mdiSquareRootBox = \"M5,3C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M11.24,6H19V8H12.76L10,18H8L6.25,12H5V10H7.75L9,14.28L11.24,6V6M14,10.59L15.79,12.38L17.59,10.59L19,12L17.21,13.79L19,15.59L17.59,17L15.79,15.21L14,17L12.59,15.59L14.38,13.79L12.59,12L14,10.59Z\";\r\nvar mdiSquareRounded = \"M8 3H16C18.76 3 21 5.24 21 8V16C21 18.76 18.76 21 16 21H8C5.24 21 3 18.76 3 16V8C3 5.24 5.24 3 8 3Z\";\r\nvar mdiSquareRoundedOutline = \"M8 3H16C18.76 3 21 5.24 21 8V16C21 18.76 18.76 21 16 21H8C5.24 21 3 18.76 3 16V8C3 5.24 5.24 3 8 3M8 5C6.34 5 5 6.34 5 8V16C5 17.66 6.34 19 8 19H16C17.66 19 19 17.66 19 16V8C19 6.34 17.66 5 16 5H8Z\";\r\nvar mdiSquareSmall = \"M10,14V10H14V14H10Z\";\r\nvar mdiSquareWave = \"M2 2V12H4V4H11V22H22V12H20V20H13V2H2Z\";\r\nvar mdiSqueegee = \"M22,2V5H2V2H22M2,8H7L9,10H10V20A2,2 0 0,0 12,22A2,2 0 0,0 14,20V10H15L17,8H22V6H2V8Z\";\r\nvar mdiSsh = \"M4.5,9C3.9,9 3.5,9.5 3.5,10V11.75C3.5,12.25 3.9,12.75 4.5,12.75H7V13.5H3.5V15H7.5C8.1,15 8.5,14.5 8.5,14V12.25C8.5,11.75 8.1,11.25 7.5,11.25H5V10.5H8.5V9H4.5M10.5,9C9.9,9 9.5,9.5 9.5,10V11.75C9.5,12.25 9.9,12.75 10.5,12.75H13V13.5H9.5V15H13.5C14.1,15 14.5,14.5 14.5,14V12.25C14.5,11.75 14.1,11.25 13.5,11.25H11V10.5H14.5V9H10.5M15.5,9V15H17V12.5H19V15H20.5V9H19V11H17V9H15.5Z\";\r\nvar mdiStackExchange = \"M3.9 10.72H20V14.03H3.9V10.72M3.9 6.44H20V9.75H3.9V6.44M17.5 2H6.5C5.06 2 3.9 3.18 3.9 4.65V5.5H20V4.65C20 3.18 18.88 2 17.5 2M3.9 15V15.84C3.9 17.31 5.06 18.5 6.5 18.5H13.37V22L16.77 18.5H17.5C18.94 18.5 20.11 17.31 20.11 15.84V15H3.9Z\";\r\nvar mdiStackOverflow = \"M17.36,20.2V14.82H19.15V22H3V14.82H4.8V20.2H17.36M6.77,14.32L7.14,12.56L15.93,14.41L15.56,16.17L6.77,14.32M7.93,10.11L8.69,8.5L16.83,12.28L16.07,13.9L7.93,10.11M10.19,6.12L11.34,4.74L18.24,10.5L17.09,11.87L10.19,6.12M14.64,1.87L20,9.08L18.56,10.15L13.2,2.94L14.64,1.87M6.59,18.41V16.61H15.57V18.41H6.59Z\";\r\nvar mdiStackpath = \"M4.91 8C4.04 8 3.32 8.2 2.76 8.61C2.19 9 1.91 9.53 1.91 10.19C1.91 10.85 2.15 11.37 2.62 11.72C3.1 12.07 3.82 12.41 4.8 12.72C5.27 12.88 5.6 13.04 5.78 13.19C5.96 13.34 6.05 13.55 6.05 13.83C6.05 14.07 5.96 14.26 5.78 14.41C5.6 14.56 5.32 14.63 4.94 14.63C4.45 14.63 4.09 14.54 3.85 14.35C3.6 14.16 3.5 13.84 3.5 13.39H1.72L1.71 13.42C1.7 14.25 2 14.89 2.66 15.33C3.3 15.78 4.06 16 4.94 16C5.82 16 6.5 15.8 7.06 15.42C7.59 15.03 7.86 14.5 7.86 13.81C7.86 13.14 7.63 12.61 7.19 12.23C6.74 11.84 6.08 11.5 5.2 11.26C4.62 11.05 4.23 10.88 4 10.74C3.81 10.6 3.71 10.42 3.71 10.2C3.71 9.96 3.81 9.76 4 9.6C4.22 9.44 4.5 9.36 4.87 9.36C5.24 9.36 5.53 9.46 5.74 9.65C5.96 9.84 6.07 10.12 6.06 10.41H7.8L7.82 10.37C7.84 9.68 7.57 9.11 7 8.66C6.47 8.22 5.77 8 4.91 8M9 8.05V15.93H10.84V13.23H11.96C12.89 13.23 13.63 13 14.18 12.5C14.73 12.05 15 11.42 15 10.64C15 9.87 14.73 9.25 14.18 8.77C13.63 8.29 12.89 8.05 11.96 8.05H9M17.24 8.05L14.5 15.93H16.22L19 8.05M20.5 8.05L17.79 15.93H19.5L22.29 8.05M10.84 9.46H11.96C12.35 9.46 12.66 9.57 12.86 9.8C13.07 10 13.17 10.31 13.17 10.65C13.17 11 13.07 11.28 12.86 11.5C12.66 11.71 12.35 11.82 11.96 11.82H10.84\";\r\nvar mdiStadium = \"M22 13.5V17.5C22 19.2 17.5 20.5 12 20.5C10.6 20.5 9.2 20.4 8 20.2V17.5L4 16.5V19.3C2.7 18.8 2 18.2 2 17.5V11.5C2 10.5 4 9.5 6 9.5C12 9.5 14 15 19 15C21 15 22 13.5 22 13.5M5 8L9 9V6L5 5V8M18 6.5L22 7.5V4.5L18 3.5V6.5M22.3 10.8C22.3 9.8 21.5 8 18.7 8S13.4 10.7 13.3 10.9C15.1 12.2 16.5 13.5 19 13.5C22.3 13.5 22.3 10.8 22.3 10.8Z\";\r\nvar mdiStadiumVariant = \"M5,3H7L10,5L7,7V8.33C8.47,8.12 10.18,8 12,8C13.82,8 15.53,8.12 17,8.33V3H19L22,5L19,7V8.71C20.85,9.17 22,9.8 22,10.5C22,11.88 17.5,13 12,13C6.5,13 2,11.88 2,10.5C2,9.8 3.15,9.17 5,8.71V3M12,9.5C8.69,9.5 7,9.67 7,10.5C7,11.33 8.69,11.5 12,11.5C15.31,11.5 17,11.33 17,10.5C17,9.67 15.31,9.5 12,9.5M12,14.75C15.81,14.75 19.2,14.08 21.4,13.05L20,21H15V19A2,2 0 0,0 13,17H11A2,2 0 0,0 9,19V21H4L2.6,13.05C4.8,14.08 8.19,14.75 12,14.75Z\";\r\nvar mdiStairs = \"M15,5V9H11V13H7V17H3V20H10V16H14V12H18V8H22V5H15Z\";\r\nvar mdiStairsBox = \"M5 3C3.89 3 3 3.89 3 5V19C3 20.11 3.89 21 5 21H19C20.11 21 21 20.11 21 19V5C21 3.89 20.11 3 19 3H5M14 7H19V9H16V12H13V15H10V18H5V16H8V13H11V10H14V7Z\";\r\nvar mdiStairsDown = \"M15 6H22V9H18V13H14V17H10V21H3V18H7V14H11V10H15V6M4.83 8.34L10.34 2.83L12.17 4.66L6.66 10.17L8.5 12H3V6.5L4.83 8.34Z\";\r\nvar mdiStairsUp = \"M15 6H22V9H18V13H14V17H10V21H3V18H7V14H11V10H15V6M10.17 6.66L4.66 12.17L2.83 10.34L8.34 4.83L6.5 3H12V8.5L10.17 6.66Z\";\r\nvar mdiStamper = \"M12,3A3,3 0 0,0 9,6C9,9 14,13 6,13A2,2 0 0,0 4,15V17H20V15A2,2 0 0,0 18,13C10,13 15,9 15,6C15,4 13.66,3 12,3M6,19V21H18V19H6Z\";\r\nvar mdiStandardDefinition = \"M13,7H16A3,3 0 0,1 19,10V14A3,3 0 0,1 16,17H13V7M16,15A1,1 0 0,0 17,14V10A1,1 0 0,0 16,9H15V15H16M7,7H11V9H7V11H9A2,2 0 0,1 11,13V15A2,2 0 0,1 9,17H5V15H9V13H7A2,2 0 0,1 5,11V9A2,2 0 0,1 7,7Z\";\r\nvar mdiStar = \"M12,17.27L18.18,21L16.54,13.97L22,9.24L14.81,8.62L12,2L9.19,8.62L2,9.24L7.45,13.97L5.82,21L12,17.27Z\";\r\nvar mdiStarBox = \"M19,3A2,2 0 0,1 21,5V19C21,20.11 20.1,21 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M15.58,17L14.63,12.92L17.79,10.19L13.62,9.83L12,6L10.38,9.84L6.21,10.2L9.37,12.93L8.42,17L12,14.84L15.58,17Z\";\r\nvar mdiStarBoxMultiple = \"M4 6V20H18V22H3C2.4 22 2 21.6 2 21V6H4M8 2H20C21.11 2 22 2.9 22 4V16C22 17.11 21.11 18 20 18H8C6.9 18 6 17.11 6 16V4C6 2.9 6.9 2 8 2M16.3 13.3L15.9 10.7L17.8 8.8L15.2 8.4L14 6L12.8 8.4L10.2 8.8L12.1 10.6L11.6 13.2L14 12L16.3 13.3Z\";\r\nvar mdiStarBoxMultipleOutline = \"M4 6V20H18V22H3C2.4 22 2 21.6 2 21V6H4M12.1 10.6L10.2 8.8L12.8 8.4L14 6L15.2 8.4L17.8 8.8L15.9 10.7L16.3 13.3L14 12L11.6 13.2L12.1 10.6M8 2H20C21.11 2 22 2.9 22 4V16C22 17.11 21.11 18 20 18H8C6.9 18 6 17.11 6 16V4C6 2.9 6.9 2 8 2M8 4V16H20V4H8Z\";\r\nvar mdiStarBoxOutline = \"M15.58,17L12,14.84L8.42,17L9.37,12.93L6.21,10.2L10.38,9.84L12,6L13.62,9.83L17.79,10.19L14.63,12.92L15.58,17M19,3A2,2 0 0,1 21,5V19C21,20.11 20.1,21 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3H19M5,5V19H19V5H5Z\";\r\nvar mdiStarCheck = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C14.9 12 12.4 14.3 12 17.3L5.8 21M17.8 21.2L22.6 16.4L21.3 15L17.7 18.6L16.2 17L15 18.2L17.8 21.2\";\r\nvar mdiStarCheckOutline = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C17.3 12 16.6 12.1 15.9 12.4L18.1 10.5L13.7 10.1L12 6.1L10.3 10.1L5.9 10.5L9.2 13.4L8.2 17.7L12 15.4L12.5 15.7C12.3 16.2 12.1 16.8 12.1 17.3L5.8 21M17.8 21.2L15 18.2L16.2 17L17.8 18.6L21.4 15L22.6 16.4L17.8 21.2\";\r\nvar mdiStarCircle = \"M16.23,18L12,15.45L7.77,18L8.89,13.19L5.16,9.96L10.08,9.54L12,5L13.92,9.53L18.84,9.95L15.11,13.18L16.23,18M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiStarCircleOutline = \"M8.58,17.25L9.5,13.36L6.5,10.78L10.45,10.41L12,6.8L13.55,10.45L17.5,10.78L14.5,13.36L15.42,17.25L12,15.19L8.58,17.25M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A8,8 0 0,0 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiStarFace = \"M12,2.5L8.42,8.06L2,9.74L6.2,14.88L5.82,21.5L12,19.09L18.18,21.5L17.8,14.88L22,9.74L15.58,8.06L12,2.5M9.38,10.5C10,10.5 10.5,11 10.5,11.63A1.12,1.12 0 0,1 9.38,12.75C8.75,12.75 8.25,12.25 8.25,11.63C8.25,11 8.75,10.5 9.38,10.5M14.63,10.5C15.25,10.5 15.75,11 15.75,11.63A1.12,1.12 0 0,1 14.63,12.75C14,12.75 13.5,12.25 13.5,11.63C13.5,11 14,10.5 14.63,10.5M9,15H15C14.5,16.21 13.31,17 12,17C10.69,17 9.5,16.21 9,15Z\";\r\nvar mdiStarFourPoints = \"M12,1L9,9L1,12L9,15L12,23L15,15L23,12L15,9L12,1Z\";\r\nvar mdiStarFourPointsOutline = \"M12,6.7L13.45,10.55L17.3,12L13.45,13.45L12,17.3L10.55,13.45L6.7,12L10.55,10.55L12,6.7M12,1L9,9L1,12L9,15L12,23L15,15L23,12L15,9L12,1Z\";\r\nvar mdiStarHalf = \"M12 2L9.19 8.62L2 9.24L7.45 13.97L5.82 21L12 17.27V2Z\";\r\nvar mdiStarHalfFull = \"M12,15.4V6.1L13.71,10.13L18.09,10.5L14.77,13.39L15.76,17.67M22,9.24L14.81,8.63L12,2L9.19,8.63L2,9.24L7.45,13.97L5.82,21L12,17.27L18.18,21L16.54,13.97L22,9.24Z\";\r\nvar mdiStarMinus = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C14.9 12 12.4 14.3 12 17.3L5.8 21M14 17V19H22V17H14Z\";\r\nvar mdiStarMinusOutline = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C17.3 12 16.6 12.1 15.9 12.4L18.1 10.5L13.7 10.1L12 6.1L10.3 10.1L5.9 10.5L9.2 13.4L8.2 17.7L12 15.4L12.5 15.7C12.3 16.2 12.1 16.8 12.1 17.3L5.8 21M14 17V19H22V17H14Z\";\r\nvar mdiStarOff = \"M20.8 22.7L17.9 19.8L18.2 21L12 17.3L5.8 21L7.4 14L2 9.2L6.9 8.8L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M22 9.2L14.8 8.6L12 2L10 6.8L16.9 13.7L22 9.2Z\";\r\nvar mdiStarOffOutline = \"M22.1 21.5L2.4 1.7L1.1 3L6.9 8.8L2 9.2L7.5 14L5.9 21L12.1 17.3L18.3 21L18 19.8L20.9 22.7L22.1 21.5M15.8 17.7L12 15.4L8.2 17.7L9.2 13.4L5.9 10.5L8.4 10.3L15.8 17.7M11.2 8L10 6.8L12 2L14.8 8.6L22 9.2L16.9 13.6L15.8 12.5L18.2 10.5L13.8 10.1L12.1 6.1L11.2 8Z\";\r\nvar mdiStarOutline = \"M12,15.39L8.24,17.66L9.23,13.38L5.91,10.5L10.29,10.13L12,6.09L13.71,10.13L18.09,10.5L14.77,13.38L15.76,17.66M22,9.24L14.81,8.63L12,2L9.19,8.63L2,9.24L7.45,13.97L5.82,21L12,17.27L18.18,21L16.54,13.97L22,9.24Z\";\r\nvar mdiStarPlus = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C14.9 12 12.4 14.3 12 17.3L5.8 21M17 14V17H14V19H17V22H19V19H22V17H19V14H17Z\";\r\nvar mdiStarPlusOutline = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C17.3 12 16.6 12.1 15.9 12.4L18.1 10.5L13.7 10.1L12 6.1L10.3 10.1L5.9 10.5L9.2 13.4L8.2 17.7L12 15.4L12.5 15.7C12.3 16.2 12.1 16.8 12.1 17.3L5.8 21M17 14V17H14V19H17V22H19V19H22V17H19V14H17Z\";\r\nvar mdiStarRemove = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C14.9 12 12.4 14.3 12 17.3L5.8 21M20.1 14.5L18 16.6L15.9 14.5L14.5 15.9L16.6 18L14.5 20.1L15.9 21.5L18 19.4L20.1 21.5L21.5 20.1L19.4 18L21.5 15.9L20.1 14.5Z\";\r\nvar mdiStarRemoveOutline = \"M5.8 21L7.4 14L2 9.2L9.2 8.6L12 2L14.8 8.6L22 9.2L18.8 12H18C17.3 12 16.6 12.1 15.9 12.4L18.1 10.5L13.7 10.1L12 6.1L10.3 10.1L5.9 10.5L9.2 13.4L8.2 17.7L12 15.4L12.5 15.7C12.3 16.2 12.1 16.8 12.1 17.3L5.8 21M20.1 14.5L18 16.6L15.9 14.5L14.5 15.9L16.6 18L14.5 20.1L15.9 21.5L18 19.4L20.1 21.5L21.5 20.1L19.4 18L21.5 15.9L20.1 14.5Z\";\r\nvar mdiStarThreePoints = \"M12,2.6L9,12.4L2,19.9L12,17.6L22,20L15,12.5L12,2.6Z\";\r\nvar mdiStarThreePointsOutline = \"M12,9.5L13.2,13.5L16,16.5L12,15.6L7.9,16.5L10.7,13.5L12,9.5M12,2.6L9,12.4L2,19.9L12,17.6L22,20L15,12.5L12,2.6Z\";\r\nvar mdiStateMachine = \"M6.27 17.05C6.72 17.58 7 18.25 7 19C7 20.66 5.66 22 4 22S1 20.66 1 19 2.34 16 4 16C4.18 16 4.36 16 4.53 16.05L7.6 10.69L5.86 9.7L9.95 8.58L11.07 12.67L9.33 11.68L6.27 17.05M20 16C18.7 16 17.6 16.84 17.18 18H11V16L8 19L11 22V20H17.18C17.6 21.16 18.7 22 20 22C21.66 22 23 20.66 23 19S21.66 16 20 16M12 8C12.18 8 12.36 8 12.53 7.95L15.6 13.31L13.86 14.3L17.95 15.42L19.07 11.33L17.33 12.32L14.27 6.95C14.72 6.42 15 5.75 15 5C15 3.34 13.66 2 12 2S9 3.34 9 5 10.34 8 12 8Z\";\r\nvar mdiSteam = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22C7.4,22 3.55,18.92 2.36,14.73L6.19,16.31C6.45,17.6 7.6,18.58 8.97,18.58C10.53,18.58 11.8,17.31 11.8,15.75V15.62L15.2,13.19H15.28C17.36,13.19 19.05,11.5 19.05,9.42C19.05,7.34 17.36,5.65 15.28,5.65C13.2,5.65 11.5,7.34 11.5,9.42V9.47L9.13,12.93L8.97,12.92C8.38,12.92 7.83,13.1 7.38,13.41L2,11.2C2.43,6.05 6.73,2 12,2M8.28,17.17C9.08,17.5 10,17.13 10.33,16.33C10.66,15.53 10.28,14.62 9.5,14.29L8.22,13.76C8.71,13.58 9.26,13.57 9.78,13.79C10.31,14 10.72,14.41 10.93,14.94C11.15,15.46 11.15,16.04 10.93,16.56C10.5,17.64 9.23,18.16 8.15,17.71C7.65,17.5 7.27,17.12 7.06,16.67L8.28,17.17M17.8,9.42C17.8,10.81 16.67,11.94 15.28,11.94C13.9,11.94 12.77,10.81 12.77,9.42A2.5,2.5 0 0,1 15.28,6.91C16.67,6.91 17.8,8.04 17.8,9.42M13.4,9.42C13.4,10.46 14.24,11.31 15.29,11.31C16.33,11.31 17.17,10.46 17.17,9.42C17.17,8.38 16.33,7.53 15.29,7.53C14.24,7.53 13.4,8.38 13.4,9.42Z\";\r\nvar mdiSteering = \"M13,19.92C14.8,19.7 16.35,18.95 17.65,17.65C18.95,16.35 19.7,14.8 19.92,13H16.92C16.7,14 16.24,14.84 15.54,15.54C14.84,16.24 14,16.7 13,16.92V19.92M10,8H14L17,11H19.92C19.67,9.05 18.79,7.38 17.27,6C15.76,4.66 14,4 12,4C10,4 8.24,4.66 6.73,6C5.21,7.38 4.33,9.05 4.08,11H7L10,8M11,19.92V16.92C10,16.7 9.16,16.24 8.46,15.54C7.76,14.84 7.3,14 7.08,13H4.08C4.3,14.77 5.05,16.3 6.35,17.6C7.65,18.9 9.2,19.67 11,19.92M12,2C14.75,2 17.1,3 19.05,4.95C21,6.9 22,9.25 22,12C22,14.75 21,17.1 19.05,19.05C17.1,21 14.75,22 12,22C9.25,22 6.9,21 4.95,19.05C3,17.1 2,14.75 2,12C2,9.25 3,6.9 4.95,4.95C6.9,3 9.25,2 12,2Z\";\r\nvar mdiSteeringOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L17.25,20.5C15.7,21.5 13.95,22 12,22C9.25,22 6.9,21 4.95,19.05C3,17.1 2,14.75 2,12C2,10.05 2.5,8.3 3.5,6.75L2,5.27M13,19.92C14,19.8 14.93,19.5 15.78,19.05L13.5,16.78C13.34,16.84 13.16,16.88 13,16.92V19.92M4.08,11H7L7.37,10.63L4.96,8.23C4.5,9.08 4.21,10 4.08,11M19.92,13H16.92C16.8,13.54 16.6,14.05 16.33,14.5L9.91,8.09L10,8H14L17,11H19.92C19.67,9.05 18.79,7.38 17.27,6C15.76,4.66 14,4 12,4C10.26,4 8.71,4.5 7.34,5.5L5.91,4.09C7.66,2.71 9.69,2 12,2C14.75,2 17.1,3 19.05,4.95C21,6.9 22,9.25 22,12C22,14.31 21.29,16.34 19.91,18.09L18.5,16.67C19.28,15.59 19.76,14.36 19.92,13M11,19.92V16.92C10,16.7 9.16,16.24 8.46,15.54C7.76,14.84 7.3,14 7.08,13H4.08C4.3,14.77 5.05,16.3 6.35,17.6C7.65,18.9 9.2,19.67 11,19.92Z\";\r\nvar mdiStepBackward = \"M19,5V19H16V5M14,5V19L3,12\";\r\nvar mdiStepBackward2 = \"M17,5H14V19H17V5M12,5L1,12L12,19V5M22,5H19V19H22V5Z\";\r\nvar mdiStepForward = \"M5,5V19H8V5M10,5V19L21,12\";\r\nvar mdiStepForward2 = \"M7,5H10V19H7V5M12,5L23,12L12,19V5M2,5H5V19H2V5Z\";\r\nvar mdiStethoscope = \"M19,8C19.56,8 20,8.43 20,9A1,1 0 0,1 19,10C18.43,10 18,9.55 18,9C18,8.43 18.43,8 19,8M2,2V11C2,13.96 4.19,16.5 7.14,16.91C7.76,19.92 10.42,22 13.5,22A6.5,6.5 0 0,0 20,15.5V11.81C21.16,11.39 22,10.29 22,9A3,3 0 0,0 19,6A3,3 0 0,0 16,9C16,10.29 16.84,11.4 18,11.81V15.41C18,17.91 16,19.91 13.5,19.91C11.5,19.91 9.82,18.7 9.22,16.9C12,16.3 14,13.8 14,11V2H10V5H12V11A4,4 0 0,1 8,15A4,4 0 0,1 4,11V5H6V2H2Z\";\r\nvar mdiSticker = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerAlert = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M13 17H11V15H13V16M13 13H11V7H13V12M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerAlertOutline = \"M11 15H13V17H11V15M11 13H13V7H11V13M22 5.5V16L16 22H5.5C3.6 22 2 20.4 2 18.5V5.5C2 3.6 3.6 2 5.5 2H18.5C20.4 2 22 3.6 22 5.5M20 5.8C20 4.8 19.2 4 18.2 4H5.8C4.8 4 4 4.8 4 5.8V18.3C4 19.3 4.8 20.1 5.8 20.1H15V18.6C15 16.7 16.6 15.1 18.5 15.1H20V5.8Z\";\r\nvar mdiStickerCheck = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M7 12.5L8.3 11.1L10.4 13.2L15.6 8L17 9.4L10.5 16L7 12.5M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerCheckOutline = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M20 15H18.5C16.6 15 15 16.6 15 18.5V20H5.8C4.8 20 4 19.2 4 18.2V5.8C4 4.8 4.8 4 5.8 4H18.3C19.3 4 20.1 4.8 20.1 5.8V15M15.2 8.2L16.7 9.7L10.7 15.7L7.2 12.2L8.7 10.7L10.7 12.7L15.2 8.2Z\";\r\nvar mdiStickerCircleOutline = \"M12.12,18.46L18.3,12.28C16.94,12.59 15.31,13.2 14.07,14.46C13.04,15.5 12.39,16.83 12.12,18.46M20.75,10H21.05C21.44,10 21.79,10.27 21.93,10.64C22.07,11 22,11.43 21.7,11.71L11.7,21.71C11.5,21.9 11.26,22 11,22L10.64,21.93C10.27,21.79 10,21.44 10,21.05C9.84,17.66 10.73,14.96 12.66,13.03C15.5,10.2 19.62,10 20.75,10M12,2C16.5,2 20.34,5 21.58,9.11L20,9H19.42C18.24,6.07 15.36,4 12,4A8,8 0 0,0 4,12C4,15.36 6.07,18.24 9,19.42C8.97,20.13 9,20.85 9.11,21.57C5,20.33 2,16.5 2,12C2,6.47 6.5,2 12,2Z\";\r\nvar mdiStickerEmoji = \"M5.5,2C3.56,2 2,3.56 2,5.5V18.5C2,20.44 3.56,22 5.5,22H16L22,16V5.5C22,3.56 20.44,2 18.5,2H5.5M5.75,4H18.25A1.75,1.75 0 0,1 20,5.75V15H18.5C16.56,15 15,16.56 15,18.5V20H5.75A1.75,1.75 0 0,1 4,18.25V5.75A1.75,1.75 0 0,1 5.75,4M14.44,6.77C14.28,6.77 14.12,6.79 13.97,6.83C13.03,7.09 12.5,8.05 12.74,9C12.79,9.15 12.86,9.3 12.95,9.44L16.18,8.56C16.18,8.39 16.16,8.22 16.12,8.05C15.91,7.3 15.22,6.77 14.44,6.77M8.17,8.5C8,8.5 7.85,8.5 7.7,8.55C6.77,8.81 6.22,9.77 6.47,10.7C6.5,10.86 6.59,11 6.68,11.16L9.91,10.28C9.91,10.11 9.89,9.94 9.85,9.78C9.64,9 8.95,8.5 8.17,8.5M16.72,11.26L7.59,13.77C8.91,15.3 11,15.94 12.95,15.41C14.9,14.87 16.36,13.25 16.72,11.26Z\";\r\nvar mdiStickerMinus = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M8 11H16V13H8V11M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerMinusOutline = \"M8 11H16V13H8V11M22 5.5V16L16 22H5.5C3.6 22 2 20.4 2 18.5V5.5C2 3.6 3.6 2 5.5 2H18.5C20.4 2 22 3.6 22 5.5M20 5.8C20 4.8 19.2 4 18.2 4H5.8C4.8 4 4 4.8 4 5.8V18.3C4 19.3 4.8 20.1 5.8 20.1H15V18.6C15 16.7 16.6 15.1 18.5 15.1H20V5.8Z\";\r\nvar mdiStickerOutline = \"M5.5 2C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2H5.5M5.8 4H18.3C19.3 4 20.1 4.8 20.1 5.8V15H18.6C16.7 15 15.1 16.6 15.1 18.5V20H5.8C4.8 20 4 19.2 4 18.2V5.8C4 4.8 4.8 4 5.8 4\";\r\nvar mdiStickerPlus = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M13 16H11V13H8V11H11V8H13V11H16V13H13V16M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerPlusOutline = \"M13 11H16V13H13V16H11V13H8V11H11V8H13V11M22 5.5V16L16 22H5.5C3.6 22 2 20.4 2 18.5V5.5C2 3.6 3.6 2 5.5 2H18.5C20.4 2 22 3.6 22 5.5M20 5.8C20 4.8 19.2 4 18.2 4H5.8C4.8 4 4 4.8 4 5.8V18.3C4 19.3 4.8 20.1 5.8 20.1H15V18.6C15 16.7 16.6 15.1 18.5 15.1H20V5.8Z\";\r\nvar mdiStickerRemove = \"M18.5 2H5.5C3.6 2 2 3.6 2 5.5V18.5C2 20.4 3.6 22 5.5 22H16L22 16V5.5C22 3.6 20.4 2 18.5 2M12 13.4L9.9 15.5L8.5 14.1L10.6 12L8.5 9.9L9.9 8.5L12 10.6L14.1 8.5L15.5 9.9L13.4 12L15.5 14.1L14.1 15.5L12 13.4M15 20V18.5C15 16.6 16.6 15 18.5 15H20L15 20Z\";\r\nvar mdiStickerRemoveOutline = \"M16 9.4L13.4 12L16 14.6L14.6 16L12 13.4L9.4 16L8 14.6L10.6 12L8 9.4L9.4 8L12 10.6L14.6 8L16 9.4M22 5.5V16L16 22H5.5C3.6 22 2 20.4 2 18.5V5.5C2 3.6 3.6 2 5.5 2H18.5C20.4 2 22 3.6 22 5.5M20 5.8C20 4.8 19.2 4 18.2 4H5.8C4.8 4 4 4.8 4 5.8V18.3C4 19.3 4.8 20.1 5.8 20.1H15V18.6C15 16.7 16.6 15.1 18.5 15.1H20V5.8Z\";\r\nvar mdiStocking = \"M17,2A2,2 0 0,1 19,4V7A2,2 0 0,1 17,9V17C17,17.85 16.5,18.57 15.74,18.86L9.5,21.77C8.5,22.24 7.29,21.81 6.83,20.81L6,19C5.5,18 5.95,16.8 6.95,16.34L10,14.91V9A2,2 0 0,1 8,7V4A2,2 0 0,1 10,2H17M10,4V7H17V4H10Z\";\r\nvar mdiStomach = \"M4 18C4.67 19.85 6.07 22 12 22C14.36 22 17.07 21.93 19 20C20 19 22 17 22 11S20 4 18 4C16.62 4 15 4 14 6V6.03A1.82 1.82 0 0 1 12.13 6.95C11 6.81 11 6.37 11 6V2H9V6A2.92 2.92 0 0 0 12 9C13 9 13 10.78 13 12C13 13.89 12.5 15.26 11 16C8.69 17.15 6.39 17 5.61 15.47A1.5 1.5 0 0 0 3.14 14.87A3.67 3.67 0 0 0 2 18V22H4Z\";\r\nvar mdiStop = \"M18,18H6V6H18V18Z\";\r\nvar mdiStopCircle = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M9,9H15V15H9\";\r\nvar mdiStopCircleOutline = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M12,4C16.41,4 20,7.59 20,12C20,16.41 16.41,20 12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4M9,9V15H15V9\";\r\nvar mdiStore = \"M12,18H6V14H12M21,14V12L20,7H4L3,12V14H4V20H14V14H18V20H20V14M20,4H4V6H20V4Z\";\r\nvar mdiStore24Hour = \"M16,12H15V10H13V7H14V9H15V7H16M11,10H9V11H11V12H8V9H10V8H8V7H11M19,7V4H5V7H2V20H10V16H14V20H22V7H19Z\";\r\nvar mdiStoreOutline = \"M18.36 9L18.96 12H5.04L5.64 9H18.36M20 4H4V6H20V4M20 7H4L3 12V14H4V20H14V14H18V20H20V14H21V12L20 7M6 18V14H12V18H6Z\";\r\nvar mdiStorefront = \"M5.06 3C4.63 3 4.22 3.14 3.84 3.42C3.46 3.7 3.24 4.06 3.14 4.5L2.11 8.91C1.86 10 2.06 10.92 2.69 11.73C2.81 11.85 2.93 11.97 3.04 12.07C3.63 12.64 4.28 13 5.22 13C6.16 13 6.91 12.59 7.47 12.05C8.1 12.67 8.86 13 9.8 13C10.64 13 11.44 12.63 12 12.07C12.68 12.7 13.45 13 14.3 13C15.17 13 15.91 12.67 16.54 12.05C17.11 12.62 17.86 13 18.81 13C19.76 13 20.43 12.65 21 12.06C21.09 11.97 21.18 11.87 21.28 11.77C21.94 10.95 22.14 10 21.89 8.91L20.86 4.5C20.73 4.06 20.5 3.7 20.13 3.42C19.77 3.14 19.38 3 18.94 3M18.89 4.97L19.97 9.38C20.06 9.81 19.97 10.2 19.69 10.55C19.44 10.86 19.13 11 18.75 11C18.44 11 18.17 10.9 17.95 10.66C17.73 10.43 17.61 10.16 17.58 9.84L16.97 5M5.06 5H7.03L6.42 9.84C6.3 10.63 5.91 11 5.25 11C4.84 11 4.53 10.86 4.31 10.55C4.03 10.2 3.94 9.81 4.03 9.38M9.05 5H11V9.7C11 10.05 10.89 10.35 10.64 10.62C10.39 10.88 10.08 11 9.7 11C9.36 11 9.07 10.88 8.84 10.59C8.61 10.3 8.5 10 8.5 9.66V9.5M13 5H14.95L15.5 9.5C15.58 9.92 15.5 10.27 15.21 10.57C14.95 10.87 14.61 11 14.2 11C13.89 11 13.61 10.88 13.36 10.62C13.11 10.35 13 10.05 13 9.7M3 14.03V19C3 20.11 3.89 21 5 21C9.67 21 14.33 21 19 21C20.1 21 21 20.11 21 19V14.05C20.45 14.63 19.75 14.96 19 15C18 15.03 17.25 14.74 16.54 14.05C15.94 14.65 15.14 15 14.3 15C13.4 15 12.6 14.64 12 14.07C11.43 14.64 10.65 15 9.78 15C8.87 15 8.07 14.65 7.47 14.05C6.89 14.64 6.1 15 5.23 15C4.33 15 3.66 14.65 3 14.03Z\";\r\nvar mdiStorefrontOutline = \"M5.06 3C4.63 3 4.22 3.14 3.84 3.42S3.24 4.06 3.14 4.5L2.11 8.91C1.86 10 2.06 10.95 2.72 11.77L3 12.05V19C3 19.5 3.2 20 3.61 20.39S4.5 21 5 21H19C19.5 21 20 20.8 20.39 20.39S21 19.5 21 19V12.05L21.28 11.77C21.94 10.95 22.14 10 21.89 8.91L20.86 4.5C20.73 4.06 20.5 3.7 20.13 3.42C19.77 3.14 19.38 3 18.94 3H5.06M18.89 4.97L19.97 9.38C20.06 9.81 19.97 10.2 19.69 10.55C19.44 10.86 19.13 11 18.75 11C18.44 11 18.17 10.9 17.95 10.66C17.73 10.43 17.61 10.16 17.58 9.84L16.97 5L18.89 4.97M5.06 5H7.03L6.42 9.84C6.3 10.63 5.91 11 5.25 11C4.84 11 4.53 10.86 4.31 10.55C4.03 10.2 3.94 9.81 4.03 9.38L5.06 5M9.05 5H11V9.7C11 10.05 10.89 10.35 10.64 10.62C10.39 10.88 10.08 11 9.7 11C9.36 11 9.07 10.88 8.84 10.59S8.5 10 8.5 9.66V9.5L9.05 5M13 5H14.95L15.5 9.5C15.58 9.92 15.5 10.27 15.21 10.57C14.95 10.87 14.61 11 14.2 11C13.89 11 13.61 10.88 13.36 10.62C13.11 10.35 13 10.05 13 9.7V5M7.45 12.05C8.08 12.67 8.86 13 9.8 13C10.64 13 11.38 12.67 12 12.05C12.69 12.67 13.45 13 14.3 13C15.17 13 15.92 12.67 16.55 12.05C17.11 12.67 17.86 13 18.8 13H19.03V19H5V13H5.25C6.16 13 6.89 12.67 7.45 12.05Z\";\r\nvar mdiStove = \"M6,14H8L11,17H9L6,14M4,4H5V3A1,1 0 0,1 6,2H10A1,1 0 0,1 11,3V4H13V3A1,1 0 0,1 14,2H18A1,1 0 0,1 19,3V4H20A2,2 0 0,1 22,6V19A2,2 0 0,1 20,21V22H17V21H7V22H4V21A2,2 0 0,1 2,19V6A2,2 0 0,1 4,4M18,7A1,1 0 0,1 19,8A1,1 0 0,1 18,9A1,1 0 0,1 17,8A1,1 0 0,1 18,7M14,7A1,1 0 0,1 15,8A1,1 0 0,1 14,9A1,1 0 0,1 13,8A1,1 0 0,1 14,7M20,6H4V10H20V6M4,19H20V12H4V19M6,7A1,1 0 0,1 7,8A1,1 0 0,1 6,9A1,1 0 0,1 5,8A1,1 0 0,1 6,7M13,14H15L18,17H16L13,14Z\";\r\nvar mdiStrategy = \"M6.91 5.5L9.21 7.79L7.79 9.21L5.5 6.91L3.21 9.21L1.79 7.79L4.09 5.5L1.79 3.21L3.21 1.79L5.5 4.09L7.79 1.79L9.21 3.21M22.21 16.21L20.79 14.79L18.5 17.09L16.21 14.79L14.79 16.21L17.09 18.5L14.79 20.79L16.21 22.21L18.5 19.91L20.79 22.21L22.21 20.79L19.91 18.5M20.4 6.83L17.18 11L15.6 9.73L16.77 8.23A9.08 9.08 0 0 0 10.11 13.85A4.5 4.5 0 1 1 7.5 13A4 4 0 0 1 8.28 13.08A11.27 11.27 0 0 1 16.43 6.26L15 5.18L16.27 3.6M10 17.5A2.5 2.5 0 1 0 7.5 20A2.5 2.5 0 0 0 10 17.5Z\";\r\nvar mdiStretchToPage = \"M20,2H4C2.89,2 2,2.89 2,4V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.11,2 20,2M9,19H5V15L6.29,16.29L7.83,14.75L9.25,16.17L7.71,17.71M7.83,9.25L6.29,7.71L5,9V5H9L7.71,6.29L9.25,7.83M19,19H15L16.29,17.71L14.75,16.17L16.17,14.75L17.71,16.29L19,15M19,9L17.71,7.71L16.17,9.25L14.75,7.83L16.29,6.29L15,5H19\";\r\nvar mdiStretchToPageOutline = \"M20,2H4C2.89,2 2,2.89 2,4V20C2,21.11 2.89,22 4,22H20C21.11,22 22,21.11 22,20V4C22,2.89 21.11,2 20,2M20,20H4V4H20M8.83,10.25L7.29,8.71L6,10V6H10L8.71,7.29L10.25,8.83M13.75,8.83L15.29,7.29L14,6H18V10L16.71,8.71L15.17,10.25M15.17,13.75L16.71,15.29L18,14V18H14L15.29,16.71L13.75,15.17M10.25,15.17L8.71,16.71L10,18H6V14L7.29,15.29L8.83,13.75\";\r\nvar mdiStringLights = \"M22.56 11.39C22.36 10.59 21.82 9.85 21.05 9.44L20.63 7.74C21.11 7.58 21.57 7.41 22 7.23V5C20 6.07 16.53 7.03 12 7.03S4 6.07 2 5V7.23C2.43 7.41 2.89 7.58 3.37 7.74L2.95 9.44C2.18 9.85 1.64 10.59 1.44 11.39C.905 13.57 .385 17.31 2.92 17.93C4 18.2 6 17.89 7.27 12.82C7.46 12 7.33 11.12 6.84 10.39L7.26 8.67C8.14 8.81 9.05 8.9 10 8.96V10.74C9.35 11.33 9 12.17 9 13C9 15.24 9.39 19 12 19C13.12 19 15 18.22 15 13C15 12.17 14.65 11.33 14 10.74V8.96C14.95 8.9 15.86 8.81 16.74 8.67L17.16 10.39C16.67 11.12 16.54 12 16.73 12.82C18 17.89 20 18.2 21.08 17.93C23.61 17.31 23.09 13.57 22.56 11.39M5.81 12.47C5.81 12.47 4.74 16.84 3.28 16.5C1.82 16.12 2.9 11.75 2.9 11.75S3.26 10.29 4.71 10.65 5.81 12.47 5.81 12.47M12 17.5C10.5 17.5 10.5 13 10.5 13S10.5 11.5 12 11.5 13.5 13 13.5 13 13.5 17.5 12 17.5M20.72 16.5C19.27 16.84 18.19 12.47 18.19 12.47S17.83 11 19.29 10.65 21.1 11.75 21.1 11.75 22.18 16.12 20.72 16.5Z\";\r\nvar mdiStringLightsOff = \"M14 10.74V8.96C14.95 8.9 15.86 8.81 16.74 8.67L17.16 10.39C16.67 11.12 16.54 12 16.73 12.82C16.82 13.17 16.91 13.5 17 13.8L21.12 17.92C23.61 17.26 23.09 13.55 22.56 11.39C22.36 10.59 21.82 9.85 21.05 9.44L20.63 7.74C21.11 7.58 21.57 7.41 22 7.23V5C20 6.07 16.53 7.03 12 7.03C11.37 7.03 10.76 7 10.17 6.97M20.72 16.5C19.27 16.84 18.19 12.47 18.19 12.47S17.83 11 19.29 10.65 21.1 11.75 21.1 11.75 22.18 16.12 20.72 16.5M14.95 14.29L13.5 12.83V12.83L12.18 11.5H12.18L10 9.34V9.34L9.58 8.93H9.59L7.32 6.66H7.32L2.39 1.73L1.11 3L3.91 5.8C3.19 5.55 2.53 5.28 2 5V7.23C2.43 7.41 2.89 7.58 3.37 7.74L2.95 9.44C2.18 9.85 1.64 10.59 1.44 11.39C.905 13.57 .385 17.31 2.92 17.93C4 18.2 6 17.89 7.27 12.82C7.46 12 7.33 11.12 6.84 10.39L7.17 9.06L9.5 11.38C9.18 11.87 9 12.44 9 13C9 15.24 9.39 19 12 19C12.8 19 13.97 18.59 14.59 16.5L20.84 22.73L22.11 21.46L14.95 14.3L14.95 14.29M5.81 12.47C5.81 12.47 4.74 16.84 3.28 16.5C1.82 16.12 2.9 11.75 2.9 11.75S3.26 10.29 4.71 10.65 5.81 12.47 5.81 12.47M12 17.5C10.5 17.5 10.5 13 10.5 13S10.5 12.77 10.6 12.5L13.32 15.21C13.13 16.35 12.76 17.5 12 17.5Z\";\r\nvar mdiSubdirectoryArrowLeft = \"M11,9L12.42,10.42L8.83,14H18V4H20V16H8.83L12.42,19.58L11,21L5,15L11,9Z\";\r\nvar mdiSubdirectoryArrowRight = \"M19,15L13,21L11.58,19.58L15.17,16H4V4H6V14H15.17L11.58,10.42L13,9L19,15Z\";\r\nvar mdiSubmarine = \"M8 3.67C6.78 4.53 5.39 4.93 4 5H2V7H4C5.37 7 6.74 6.65 8 6C10.5 7.3 13.5 7.3 16 6C17.26 6.65 18.62 6.94 20 7H22V5H20C18.61 5 17.22 4.53 16 3.67C13.56 5.38 10.44 5.38 8 3.67M16 8.67L15 10V12H14L12 14H9L6 16L5 14H4V16L2 17L4 18V20H5.14L6 18L9 20H20A2 2 0 0 0 22 18V16A2 2 0 0 0 20 14H18L17 13V12H16V10H17V8.67Z\";\r\nvar mdiSubtitles = \"M20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6A2,2 0 0,0 20,4M4,12H8V14H4V12M14,18H4V16H14V18M20,18H16V16H20V18M20,14H10V12H20V14Z\";\r\nvar mdiSubtitlesOutline = \"M20,4A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4H20M20,18V6H4V18H20M6,10H8V12H6V10M6,14H14V16H6V14M16,14H18V16H16V14M10,10H18V12H10V10Z\";\r\nvar mdiSubway = \"M8.5,15A1,1 0 0,1 9.5,16A1,1 0 0,1 8.5,17A1,1 0 0,1 7.5,16A1,1 0 0,1 8.5,15M7,9H17V14H7V9M15.5,15A1,1 0 0,1 16.5,16A1,1 0 0,1 15.5,17A1,1 0 0,1 14.5,16A1,1 0 0,1 15.5,15M18,15.88V9C18,6.38 15.32,6 12,6C9,6 6,6.37 6,9V15.88A2.62,2.62 0 0,0 8.62,18.5L7.5,19.62V20H9.17L10.67,18.5H13.5L15,20H16.5V19.62L15.37,18.5C16.82,18.5 18,17.33 18,15.88M17.8,2.8C20.47,3.84 22,6.05 22,8.86V22H2V8.86C2,6.05 3.53,3.84 6.2,2.8C8,2.09 10.14,2 12,2C13.86,2 16,2.09 17.8,2.8Z\";\r\nvar mdiSubwayAlertVariant = \"M16 11V6H11V11H16M14.5 17C15.3 17 16 16.3 16 15.5C16 14.7 15.3 14 14.5 14S13 14.7 13 15.5C13 16.3 13.7 17 14.5 17M9 11V6H4V11H9M5.5 17C6.3 17 7 16.3 7 15.5C7 14.7 6.3 14 5.5 14S4 14.7 4 15.5C4 16.3 4.7 17 5.5 17M10 2C14.4 2 18 2.5 18 6V15.5C18 17.4 16.4 19 14.5 19L16 20.5V21H4V20.5L5.5 19C3.6 19 2 17.4 2 15.5V6C2 2.5 5.6 2 10 2M20 13V7H22V13H20M20 17V15H22V17H20Z\";\r\nvar mdiSubwayVariant = \"M18,11H13V6H18M16.5,17A1.5,1.5 0 0,1 15,15.5A1.5,1.5 0 0,1 16.5,14A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 16.5,17M11,11H6V6H11M7.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,14A1.5,1.5 0 0,1 9,15.5A1.5,1.5 0 0,1 7.5,17M12,2C7.58,2 4,2.5 4,6V15.5A3.5,3.5 0 0,0 7.5,19L6,20.5V21H18V20.5L16.5,19A3.5,3.5 0 0,0 20,15.5V6C20,2.5 16.42,2 12,2Z\";\r\nvar mdiSummit = \"M15,3H17L22,5L17,7V10.17L22,21H2L8,13L11.5,17.7L15,10.17V3Z\";\r\nvar mdiSunglasses = \"M7,17H4C2.38,17 0.96,15.74 0.76,14.14L0.26,11.15C0.15,10.3 0.39,9.5 0.91,8.92C1.43,8.34 2.19,8 3,8H9C9.83,8 10.58,8.35 11.06,8.96C11.17,9.11 11.27,9.27 11.35,9.45C11.78,9.36 12.22,9.36 12.64,9.45C12.72,9.27 12.82,9.11 12.94,8.96C13.41,8.35 14.16,8 15,8H21C21.81,8 22.57,8.34 23.09,8.92C23.6,9.5 23.84,10.3 23.74,11.11L23.23,14.18C23.04,15.74 21.61,17 20,17H17C15.44,17 13.92,15.81 13.54,14.3L12.64,11.59C12.26,11.31 11.73,11.31 11.35,11.59L10.43,14.37C10.07,15.82 8.56,17 7,17Z\";\r\nvar mdiSurroundSound = \"M20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6A2,2 0 0,0 20,4M7.76,16.24L6.35,17.65C4.78,16.1 4,14.05 4,12C4,9.95 4.78,7.9 6.34,6.34L7.75,7.75C6.59,8.93 6,10.46 6,12C6,13.54 6.59,15.07 7.76,16.24M12,16A4,4 0 0,1 8,12A4,4 0 0,1 12,8A4,4 0 0,1 16,12A4,4 0 0,1 12,16M17.66,17.66L16.25,16.25C17.41,15.07 18,13.54 18,12C18,10.46 17.41,8.93 16.24,7.76L17.65,6.35C19.22,7.9 20,9.95 20,12C20,14.05 19.22,16.1 17.66,17.66M12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10Z\";\r\nvar mdiSurroundSound20 = \"M17,7H19A2,2 0 0,1 21,9V15A2,2 0 0,1 19,17H17A2,2 0 0,1 15,15V9A2,2 0 0,1 17,7M17,9V15H19V9H17M9,17H3V15L7,9H3V7H7A2,2 0 0,1 9,9C9,9.42 8.87,9.81 8.65,10.13L5.41,15H9V17M12,17A1,1 0 0,1 11,16A1,1 0 0,1 12,15A1,1 0 0,1 13,16A1,1 0 0,1 12,17Z\";\r\nvar mdiSurroundSound31 = \"M13,17A1,1 0 0,1 12,16A1,1 0 0,1 13,15A1,1 0 0,1 14,16A1,1 0 0,1 13,17M19,7V15H20V17H16V15H17V9H16L17,7H19M4,7H8A2,2 0 0,1 10,9V15A2,2 0 0,1 8,17H4V15H8V13H5V11H8V9H4V7Z\";\r\nvar mdiSurroundSound51 = \"M13,17A1,1 0 0,1 12,16A1,1 0 0,1 13,15A1,1 0 0,1 14,16A1,1 0 0,1 13,17M19,7V15H20V17H16V15H17V9H16L17,7H19M6,13A2,2 0 0,1 4,11V7H10V9H6V11H8A2,2 0 0,1 10,13V15A2,2 0 0,1 8,17H4V15H8V13H6Z\";\r\nvar mdiSurroundSound71 = \"M12,17A1,1 0 0,1 11,16A1,1 0 0,1 12,15A1,1 0 0,1 13,16A1,1 0 0,1 12,17M18,7V15H19V17H15V15H16V9H15L16,7H18M11,7L8,17H6L8.4,9H5V7H11Z\";\r\nvar mdiSvg = \"M5.13,10.71H8.87L6.22,8.06C5.21,8.06 4.39,7.24 4.39,6.22A1.83,1.83 0 0,1 6.22,4.39C7.24,4.39 8.06,5.21 8.06,6.22L10.71,8.87V5.13C10,4.41 10,3.25 10.71,2.54C11.42,1.82 12.58,1.82 13.29,2.54C14,3.25 14,4.41 13.29,5.13V8.87L15.95,6.22C15.95,5.21 16.76,4.39 17.78,4.39C18.79,4.39 19.61,5.21 19.61,6.22C19.61,7.24 18.79,8.06 17.78,8.06L15.13,10.71H18.87C19.59,10 20.75,10 21.46,10.71C22.18,11.42 22.18,12.58 21.46,13.29C20.75,14 19.59,14 18.87,13.29H15.13L17.78,15.95C18.79,15.95 19.61,16.76 19.61,17.78A1.83,1.83 0 0,1 17.78,19.61C16.76,19.61 15.95,18.79 15.95,17.78L13.29,15.13V18.87C14,19.59 14,20.75 13.29,21.46C12.58,22.18 11.42,22.18 10.71,21.46C10,20.75 10,19.59 10.71,18.87V15.13L8.06,17.78C8.06,18.79 7.24,19.61 6.22,19.61C5.21,19.61 4.39,18.79 4.39,17.78C4.39,16.76 5.21,15.95 6.22,15.95L8.87,13.29H5.13C4.41,14 3.25,14 2.54,13.29C1.82,12.58 1.82,11.42 2.54,10.71C3.25,10 4.41,10 5.13,10.71Z\";\r\nvar mdiSwapHorizontal = \"M21,9L17,5V8H10V10H17V13M7,11L3,15L7,19V16H14V14H7V11Z\";\r\nvar mdiSwapHorizontalBold = \"M8,10V13H14V18H8V21L2,15.5L8,10M22,8.5L16,3V6H10V11H16V14L22,8.5Z\";\r\nvar mdiSwapHorizontalCircle = \"M22 12C22 6.5 17.5 2 12 2S2 6.5 2 12 6.5 22 12 22 22 17.5 22 12M15 6.5L18.5 10L15 13.5V11H11V9H15V6.5M9 17.5L5.5 14L9 10.5V13H13V15H9V17.5Z\";\r\nvar mdiSwapHorizontalCircleOutline = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 20C7.59 20 4 16.41 4 12S7.59 4 12 4 20 7.59 20 12 16.41 20 12 20M15 6.5V9H11V11H15V13.5L18.5 10L15 6.5M9 10.5L5.5 14L9 17.5V15H13V13H9V10.5Z\";\r\nvar mdiSwapHorizontalVariant = \"M4,6L8,10V7H16A2,2 0 0,1 18,9A2,2 0 0,1 16,11H8A4,4 0 0,0 4,15A4,4 0 0,0 8,19H16V22L20,18L16,14V17H8A2,2 0 0,1 6,15A2,2 0 0,1 8,13H16A4,4 0 0,0 20,9A4,4 0 0,0 16,5H8V2L4,6Z\";\r\nvar mdiSwapVertical = \"M9,3L5,7H8V14H10V7H13M16,17V10H14V17H11L15,21L19,17H16Z\";\r\nvar mdiSwapVerticalBold = \"M14,8H11V14H6V8H3L8.5,2L14,8M15.5,22L21,16H18V10H13V16H10L15.5,22Z\";\r\nvar mdiSwapVerticalCircle = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M6.5 9L10 5.5L13.5 9H11V13H9V9H6.5M17.5 15L14 18.5L10.5 15H13V11H15V15H17.5Z\";\r\nvar mdiSwapVerticalCircleOutline = \"M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 20C7.59 20 4 16.41 4 12S7.59 4 12 4 20 7.59 20 12 16.41 20 12 20M6.5 9L10 5.5L13.5 9H11V13H9V9H6.5M17.5 15L14 18.5L10.5 15H13V11H15V15H17.5Z\";\r\nvar mdiSwapVerticalVariant = \"M18,4L14,8H17V16A2,2 0 0,1 15,18A2,2 0 0,1 13,16V8A4,4 0 0,0 9,4A4,4 0 0,0 5,8V16H2L6,20L10,16H7V8A2,2 0 0,1 9,6A2,2 0 0,1 11,8V16A4,4 0 0,0 15,20A4,4 0 0,0 19,16V8H22L18,4Z\";\r\nvar mdiSwim = \"M2,18C4.22,17 6.44,16 8.67,16C10.89,16 13.11,18 15.33,18C17.56,18 19.78,16 22,16V19C19.78,19 17.56,21 15.33,21C13.11,21 10.89,19 8.67,19C6.44,19 4.22,20 2,21V18M8.67,13C7.89,13 7.12,13.12 6.35,13.32L11.27,9.88L10.23,8.64C10.09,8.47 10,8.24 10,8C10,7.66 10.17,7.35 10.44,7.17L16.16,3.17L17.31,4.8L12.47,8.19L17.7,14.42C16.91,14.75 16.12,15 15.33,15C13.11,15 10.89,13 8.67,13M18,7A2,2 0 0,1 20,9A2,2 0 0,1 18,11A2,2 0 0,1 16,9A2,2 0 0,1 18,7Z\";\r\nvar mdiSwitch = \"M13,18H14A1,1 0 0,1 15,19H22V21H15A1,1 0 0,1 14,22H10A1,1 0 0,1 9,21H2V19H9A1,1 0 0,1 10,18H11V16H8A1,1 0 0,1 7,15V3A1,1 0 0,1 8,2H16A1,1 0 0,1 17,3V15A1,1 0 0,1 16,16H13V18M13,6H14V4H13V6M9,4V6H11V4H9M9,8V10H11V8H9M9,12V14H11V12H9Z\";\r\nvar mdiSword = \"M6.92,5H5L14,14L15,13.06M19.96,19.12L19.12,19.96C18.73,20.35 18.1,20.35 17.71,19.96L14.59,16.84L11.91,19.5L10.5,18.09L11.92,16.67L3,7.75V3H7.75L16.67,11.92L18.09,10.5L19.5,11.91L16.83,14.58L19.95,17.7C20.35,18.1 20.35,18.73 19.96,19.12Z\";\r\nvar mdiSwordCross = \"M6.2,2.44L18.1,14.34L20.22,12.22L21.63,13.63L19.16,16.1L22.34,19.28C22.73,19.67 22.73,20.3 22.34,20.69L21.63,21.4C21.24,21.79 20.61,21.79 20.22,21.4L17,18.23L14.56,20.7L13.15,19.29L15.27,17.17L3.37,5.27V2.44H6.2M15.89,10L20.63,5.26V2.44H17.8L13.06,7.18L15.89,10M10.94,15L8.11,12.13L5.9,14.34L3.78,12.22L2.37,13.63L4.84,16.1L1.66,19.29C1.27,19.68 1.27,20.31 1.66,20.7L2.37,21.41C2.76,21.8 3.39,21.8 3.78,21.41L7,18.23L9.44,20.7L10.85,19.29L8.73,17.17L10.94,15Z\";\r\nvar mdiSyllabaryHangul = \"M8 4V6H4V8H6.39C5.55 8.74 5 9.8 5 11C5 13.2 6.8 15 9 15C11.2 15 13 13.2 13 11C13 9.8 12.45 8.74 11.61 8H14V6H10V4M15 4V16H17V11H20V9H17V4M9 9C10.12 9 11 9.88 11 11C11 12.12 10.12 13 9 13C7.88 13 7 12.12 7 11C7 9.88 7.88 9 9 9M7 16V20H17V18H9V16Z\";\r\nvar mdiSyllabaryHiragana = \"M9 4V6H6V8H9V10C6.25 10 4 12.27 4 15.03C4 17.8 6.26 20.06 9.03 20.06C9.89 20.06 10.72 19.77 11.4 19.26C11.63 19.54 11.88 19.82 12.15 20.09L13.56 18.67C13.3 18.42 13.07 18.15 12.86 17.89L13.86 16.89C14.93 15.82 15.78 14.23 16.42 12.59C17.31 13.11 18 13.9 18 15C18 16.32 17.47 17.6 16.54 18.54L17.95 19.95C19.26 18.64 20 16.86 20 15C20 13.04 18.82 11.36 17.15 10.55L17.5 9.29L15.55 8.78L15.21 10.05C15.13 10.05 15.06 10 14.97 10H11V8H16V6H11V4M11 12H14.5C13.94 13.37 13.19 14.72 12.44 15.47L11.79 16.13C11.25 14.93 11 13.59 11 12M9 12C9 14.07 9.41 15.94 10.3 17.59C9.94 17.89 9.5 18.06 9.03 18.06C7.33 18.06 6 16.73 6 15.03C6 13.34 7.32 12 9 12Z\";\r\nvar mdiSyllabaryKatakana = \"M4 4V6H18V6.09L14.29 9.79L15.71 11.21L20 6.91V4M11 9V13C11 15.78 10.25 16.89 8.36 18.46L9.64 20C11.75 18.24 13 16.22 13 13V9Z\";\r\nvar mdiSyllabaryKatakanaHalfwidth = \"M8 4V6H14L13 10.81L15 11.2L16 6.1V4M10 9V12C10 14.86 9.34 17.29 8.08 18.61L9.5 20C11.35 18.08 12 15.15 12 12V9Z\";\r\nvar mdiSymbol = \"M2 7V14H4V7H2M6 7V9H10V11H8V14H10V13C11.11 13 12 12.11 12 11V9C12 7.89 11.11 7 10 7H6M15.8 7L15.6 9H14V11H15.4L15.2 13H14V15H15L14.8 17H16.8L17 15H18.4L18.2 17H20.2L20.4 15H22V13H20.6L20.8 11H22V9H21L21.2 7H19.2L19 9H17.6L17.8 7H15.8M17.4 11H18.8L18.6 13H17.2L17.4 11M2 15V17H4V15H2M8 15V17H10V15H8Z\";\r\nvar mdiSymfony = \"M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M16.37,5.7V5.7C17.39,5.67 18.15,6.13 18.21,6.84C18.22,7.15 18.04,7.75 17.42,7.77C16.95,7.79 16.63,7.5 16.62,7.09C16.61,6.93 16.88,6.42 16.88,6.33C16.87,6.06 16.47,6.05 16.36,6.06C14.86,6.11 14.46,8.13 14.14,9.78L14,10.65C14.84,10.78 15.46,10.62 15.8,10.4C16.28,10.09 15.66,9.77 15.74,9.41C15.82,9.04 16.15,8.87 16.41,8.86C16.78,8.85 17.04,9.23 17.03,9.62C17,10.26 16.17,11.14 14.5,11.1C14.28,11.1 14.09,11.08 13.91,11.06C13.3,14.16 12.92,16 11.56,17.58C10.39,18.97 9.2,19.18 8.67,19.2C7.67,19.24 7,18.71 7,18C6.97,17.32 7.57,16.94 7.97,16.93C8.5,16.91 8.87,17.3 8.88,17.74C8.9,18.11 8.7,18.23 8.57,18.3C8.5,18.37 8.35,18.45 8.36,18.6C8.36,18.67 8.43,18.82 8.65,18.81C9.07,18.8 9.34,18.59 9.54,18.45C10.5,17.65 10.88,16.24 11.37,13.68C11.63,12.23 11.82,11.3 12.1,10.38C11.42,9.87 11,9.23 10.09,9C9.46,8.81 9.08,8.96 8.81,9.3C8.5,9.71 8.6,10.23 8.9,10.54C10.05,11.82 10.39,12.38 10.26,13.14C10.06,14.35 8.62,15.27 6.92,14.75C5.47,14.3 5.2,13.28 5.37,12.71C5.53,12.22 5.92,12.12 6.31,12.24C6.73,12.37 6.89,12.87 6.77,13.26C6.75,13.3 6.55,13.67 6.5,13.79C6.41,14.1 6.83,14.31 7.12,14.4C7.77,14.6 8.4,14.26 8.55,13.73C8.7,13.25 8.4,12.91 8.27,12.78C7.38,11.8 6.76,10.93 7.06,9.95C7.18,9.58 7.42,9.18 7.78,8.91C8.53,8.36 9.35,8.26 10.12,8.5C11.13,8.77 11.61,9.44 12.24,9.95C12.59,8.93 13.08,7.92 13.81,7.07C14.47,6.3 15.35,5.74 16.37,5.7Z\";\r\nvar mdiSync = \"M12,18A6,6 0 0,1 6,12C6,11 6.25,10.03 6.7,9.2L5.24,7.74C4.46,8.97 4,10.43 4,12A8,8 0 0,0 12,20V23L16,19L12,15M12,4V1L8,5L12,9V6A6,6 0 0,1 18,12C18,13 17.75,13.97 17.3,14.8L18.76,16.26C19.54,15.03 20,13.57 20,12A8,8 0 0,0 12,4Z\";\r\nvar mdiSyncAlert = \"M11,13H13V7H11M21,4H15V10L17.24,7.76C18.32,8.85 19,10.34 19,12C19,14.61 17.33,16.83 15,17.65V19.74C18.45,18.85 21,15.73 21,12C21,9.79 20.09,7.8 18.64,6.36M11,17H13V15H11M3,12C3,14.21 3.91,16.2 5.36,17.64L3,20H9V14L6.76,16.24C5.68,15.15 5,13.66 5,12C5,9.39 6.67,7.17 9,6.35V4.26C5.55,5.15 3,8.27 3,12Z\";\r\nvar mdiSyncCircle = \"M2 12A10 10 0 1 0 12 2A10 10 0 0 0 2 12M15.6 13.72A4 4 0 0 0 16 12A4 4 0 0 0 12 8V10L8.88 7L12 4V6A6 6 0 0 1 18 12A5.9 5.9 0 0 1 17.07 15.19M6 12A5.9 5.9 0 0 1 6.93 8.81L8.4 10.28A4 4 0 0 0 8 12A4 4 0 0 0 12 16V14L15 17L12 20V18A6 6 0 0 1 6 12Z\";\r\nvar mdiSyncOff = \"M20,4H14V10L16.24,7.76C17.32,8.85 18,10.34 18,12C18,13 17.75,13.94 17.32,14.77L18.78,16.23C19.55,15 20,13.56 20,12C20,9.79 19.09,7.8 17.64,6.36L20,4M2.86,5.41L5.22,7.77C4.45,9 4,10.44 4,12C4,14.21 4.91,16.2 6.36,17.64L4,20H10V14L7.76,16.24C6.68,15.15 6,13.66 6,12C6,11 6.25,10.06 6.68,9.23L14.76,17.31C14.5,17.44 14.26,17.56 14,17.65V19.74C14.79,19.53 15.54,19.2 16.22,18.78L18.58,21.14L19.85,19.87L4.14,4.14L2.86,5.41M10,6.35V4.26C9.2,4.47 8.45,4.8 7.77,5.22L9.23,6.68C9.5,6.56 9.73,6.44 10,6.35Z\";\r\nvar mdiTab = \"M21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3M21,19H3V5H13V9H21V19Z\";\r\nvar mdiTabMinus = \"M3,3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3H3M3,5H13V9H21V19H3V5M7,13V15H15V13H7Z\";\r\nvar mdiTabPlus = \"M3,3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3H3M3,5H13V9H21V19H3V5M10,10V13H7V15H10V18H12V15H15V13H12V10H10Z\";\r\nvar mdiTabRemove = \"M7.46,11.88L8.88,10.46L11,12.59L13.12,10.46L14.54,11.88L12.41,14L14.54,16.12L13.12,17.54L11,15.41L8.88,17.54L7.46,16.12L9.59,14L7.46,11.88M3,3H21A2,2 0 0,1 23,5V19A2,2 0 0,1 21,21H3A2,2 0 0,1 1,19V5A2,2 0 0,1 3,3M3,5V19H21V9H13V5H3Z\";\r\nvar mdiTabUnselected = \"M1,9H3V7H1V9M1,13H3V11H1V13M1,5H3V3A2,2 0 0,0 1,5M9,21H11V19H9V21M1,17H3V15H1V17M3,21V19H1A2,2 0 0,0 3,21M21,3H13V9H23V5A2,2 0 0,0 21,3M21,17H23V15H21V17M9,5H11V3H9V5M5,21H7V19H5V21M5,5H7V3H5V5M21,21A2,2 0 0,0 23,19H21V21M21,13H23V11H21V13M13,21H15V19H13V21M17,21H19V19H17V21Z\";\r\nvar mdiTable = \"M5,4H19A2,2 0 0,1 21,6V18A2,2 0 0,1 19,20H5A2,2 0 0,1 3,18V6A2,2 0 0,1 5,4M5,8V12H11V8H5M13,8V12H19V8H13M5,14V18H11V14H5M13,14V18H19V14H13Z\";\r\nvar mdiTableAccount = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M23 22V21C23 19.67 20.33 19 19 19S15 19.67 15 21V22H23M19 14C17.9 14 17 14.9 17 16S17.9 18 19 18 21 17.11 21 16 20.11 14 19 14Z\";\r\nvar mdiTableAlert = \"M3 4H17C18.11 4 19 4.89 19 6V18C19 19.11 18.11 20 17 20H3C1.9 20 1 19.11 1 18V6C1 4.89 1.9 4 3 4M3 8V12H9V8H3M11 8V12H17V8H11M3 14V18H9V14H3M11 14V18H17V14H11M23 7H21V13H23V7M23 15H21V17H23V15Z\";\r\nvar mdiTableArrowDown = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M15.94 18.5H17.94V14.5H19.94V18.5H21.94L18.94 21.5L15.94 18.5\";\r\nvar mdiTableArrowLeft = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M18.44 15V17H22.44V19H18.44V21L15.44 18L18.44 15\";\r\nvar mdiTableArrowRight = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M19.44 21V19H15.44V17H19.44V15L22.44 18L19.44 21\";\r\nvar mdiTableArrowUp = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M21.94 17.5H19.94V21.5H17.94V17.5H15.94L18.94 14.5L21.94 17.5\";\r\nvar mdiTableBorder = \"M21,19A1,1 0 0,1 20,20H19V18H21V19M15,20V18H17V20H15M11,20V18H13V20H11M7,20V18H9V20H7M4,20A1,1 0 0,1 3,19V18H5V20H4M19,4H5A2,2 0 0,0 3,6V8H5L11,8H13L19,8H21V6C21,4.89 20.11,4 19,4M5,14H3V16H5V14M5,10H3V12H5V10M21,10H19V12H21V10M21,14H19V16H21V14M11,16V14H13V16H11M11,12V10H13V12H11\";\r\nvar mdiTableCancel = \"M3 3H17C18.11 3 19 3.9 19 5V12.08C17.45 11.82 15.92 12.18 14.68 13H11V17H12.08C11.97 17.68 11.97 18.35 12.08 19H3C1.9 19 1 18.11 1 17V5C1 3.9 1.9 3 3 3M3 7V11H9V7H3M11 7V11H17V7H11M3 13V17H9V13H3M18.5 14C16 14 14 16 14 18.5S16 23 18.5 23 23 21 23 18.5 21 14 18.5 14M18.5 21.5C16.84 21.5 15.5 20.16 15.5 18.5C15.5 17.94 15.65 17.42 15.92 17L20 21.08C19.58 21.35 19.06 21.5 18.5 21.5M21.08 20L17 15.92C17.42 15.65 17.94 15.5 18.5 15.5C20.16 15.5 21.5 16.84 21.5 18.5C21.5 19.06 21.35 19.58 21.08 20Z\";\r\nvar mdiTableChair = \"M12 22H6A2 2 0 0 1 8 20V8H2V5H16V8H10V20A2 2 0 0 1 12 22M22 2V22H20V15H15V22H13V14A2 2 0 0 1 15 12H20V2Z\";\r\nvar mdiTableCheck = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M17.75 21L15 18L16.16 16.84L17.75 18.43L21.34 14.84L22.5 16.25L17.75 21\";\r\nvar mdiTableClock = \"M16.5 15.82L18.94 17.23L18.19 18.53L15 16.69V13H16.5V15.82M20 10.26V5C20 3.9 19.11 3 18 3H4C2.9 3 2 3.9 2 5V17C2 18.11 2.9 19 4 19H9.68C10.81 21.36 13.21 23 16 23C19.87 23 23 19.87 23 16C23 13.62 21.81 11.53 20 10.26M18 7V9.29C17.37 9.11 16.7 9 16 9C14.5 9 13.13 9.47 12 10.26V7H18M4 7H10V11H4V7M4 17V13H9.68C9.25 13.91 9 14.93 9 16C9 16.34 9.03 16.67 9.08 17H4M16 21C13.24 21 11 18.76 11 16S13.24 11 16 11 21 13.24 21 16 18.76 21 16 21Z\";\r\nvar mdiTableCog = \"M3 3H17C18.11 3 19 3.9 19 5V12.08C17.45 11.82 15.92 12.18 14.68 13H11V17H12.08C11.97 17.68 11.97 18.35 12.08 19H3C1.9 19 1 18.11 1 17V5C1 3.9 1.9 3 3 3M3 7V11H9V7H3M11 7V11H17V7H11M3 13V17H9V13H3M22.78 19.32L21.71 18.5C21.73 18.33 21.75 18.17 21.75 18S21.74 17.67 21.71 17.5L22.77 16.68C22.86 16.6 22.89 16.47 22.83 16.36L21.83 14.63C21.77 14.5 21.64 14.5 21.5 14.5L20.28 15C20 14.82 19.74 14.65 19.43 14.53L19.24 13.21C19.23 13.09 19.12 13 19 13H17C16.88 13 16.77 13.09 16.75 13.21L16.56 14.53C16.26 14.66 15.97 14.82 15.71 15L14.47 14.5C14.36 14.5 14.23 14.5 14.16 14.63L13.16 16.36C13.1 16.47 13.12 16.6 13.22 16.68L14.28 17.5C14.26 17.67 14.25 17.83 14.25 18S14.26 18.33 14.28 18.5L13.22 19.32C13.13 19.4 13.1 19.53 13.16 19.64L14.16 21.37C14.22 21.5 14.35 21.5 14.47 21.5L15.71 21C15.97 21.18 16.25 21.35 16.56 21.47L16.75 22.79C16.77 22.91 16.87 23 17 23H19C19.12 23 19.23 22.91 19.25 22.79L19.44 21.47C19.74 21.34 20 21.18 20.28 21L21.5 21.5C21.64 21.5 21.77 21.5 21.84 21.37L22.84 19.64C22.9 19.53 22.87 19.4 22.78 19.32M18 19.5C17.17 19.5 16.5 18.83 16.5 18S17.18 16.5 18 16.5 19.5 17.17 19.5 18 18.84 19.5 18 19.5Z\";\r\nvar mdiTableColumn = \"M8,2H16A2,2 0 0,1 18,4V20A2,2 0 0,1 16,22H8A2,2 0 0,1 6,20V4A2,2 0 0,1 8,2M8,10V14H16V10H8M8,16V20H16V16H8M8,4V8H16V4H8Z\";\r\nvar mdiTableColumnPlusAfter = \"M11,2A2,2 0 0,1 13,4V20A2,2 0 0,1 11,22H2V2H11M4,10V14H11V10H4M4,16V20H11V16H4M4,4V8H11V4H4M15,11H18V8H20V11H23V13H20V16H18V13H15V11Z\";\r\nvar mdiTableColumnPlusBefore = \"M13,2A2,2 0 0,0 11,4V20A2,2 0 0,0 13,22H22V2H13M20,10V14H13V10H20M20,16V20H13V16H20M20,4V8H13V4H20M9,11H6V8H4V11H1V13H4V16H6V13H9V11Z\";\r\nvar mdiTableColumnRemove = \"M4,2H11A2,2 0 0,1 13,4V20A2,2 0 0,1 11,22H4A2,2 0 0,1 2,20V4A2,2 0 0,1 4,2M4,10V14H11V10H4M4,16V20H11V16H4M4,4V8H11V4H4M17.59,12L15,9.41L16.41,8L19,10.59L21.59,8L23,9.41L20.41,12L23,14.59L21.59,16L19,13.41L16.41,16L15,14.59L17.59,12Z\";\r\nvar mdiTableColumnWidth = \"M5,8H19A2,2 0 0,1 21,10V20A2,2 0 0,1 19,22H5A2,2 0 0,1 3,20V10A2,2 0 0,1 5,8M5,12V15H11V12H5M13,12V15H19V12H13M5,17V20H11V17H5M13,17V20H19V17H13M11,2H21V6H19V4H13V6H11V2Z\";\r\nvar mdiTableEdit = \"M21.7,13.35L20.7,14.35L18.65,12.3L19.65,11.3C19.86,11.08 20.21,11.08 20.42,11.3L21.7,12.58C21.92,12.79 21.92,13.14 21.7,13.35M12,18.94L18.07,12.88L20.12,14.93L14.06,21H12V18.94M4,2H18A2,2 0 0,1 20,4V8.17L16.17,12H12V16.17L10.17,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M4,6V10H10V6H4M12,6V10H18V6H12M4,12V16H10V12H4Z\";\r\nvar mdiTableEye = \"M17 16.88C17.56 16.88 18 17.32 18 17.88S17.56 18.88 17 18.88 16 18.43 16 17.88 16.44 16.88 17 16.88M17 13.88C19.73 13.88 22.06 15.54 23 17.88C22.06 20.22 19.73 21.88 17 21.88S11.94 20.22 11 17.88C11.94 15.54 14.27 13.88 17 13.88M17 15.38C15.62 15.38 14.5 16.5 14.5 17.88S15.62 20.38 17 20.38 19.5 19.26 19.5 17.88 18.38 15.38 17 15.38M18 3H4C2.9 3 2 3.9 2 5V17C2 18.1 2.9 19 4 19H9.42C9.26 18.68 9.12 18.34 9 18C9.12 17.66 9.26 17.32 9.42 17H4V13H10V15.97C10.55 15.11 11.23 14.37 12 13.76V13H13.15C14.31 12.36 15.62 12 17 12C18.06 12 19.07 12.21 20 12.59V5C20 3.9 19.1 3 18 3M10 11H4V7H10V11M18 11H12V7H18V11Z\";\r\nvar mdiTableEyeOff = \"M12 8.8L6.2 3H18C19.1 3 20 3.9 20 5V12.59C19.07 12.21 18.06 12 17 12C16.45 12 15.91 12.07 15.38 12.18L14.2 11H18V7H12V8.8M17.09 13.89L22.31 19.11C22.58 18.73 22.82 18.32 23 17.88C22.07 15.57 19.78 13.92 17.09 13.89M22.11 21.46L20.84 22.73L19.5 21.37C18.71 21.69 17.88 21.88 17 21.88C14.27 21.88 11.94 20.22 11 17.88C11.45 16.76 12.23 15.8 13.21 15.1L11.93 13.82C11.19 14.42 10.53 15.14 10 15.97V13H4V17H9.42C9.26 17.32 9.12 17.66 9 18C9.12 18.34 9.26 18.68 9.42 19H4C2.9 19 2 18.1 2 17V5C2 4.68 2.08 4.38 2.22 4.11L1.11 3L2.39 1.73L22.11 21.46M9.11 11L5.11 7H4V11H9.11M18.18 20.07L14.81 16.7C14.61 17.05 14.5 17.45 14.5 17.88C14.5 19.26 15.62 20.38 17 20.38C17.43 20.38 17.83 20.27 18.18 20.07Z\";\r\nvar mdiTableFurniture = \"M2 7H22V10H20L21 19H18.5L17.94 14H6.06L5.5 19H3L4 10H2V7M17.5 10H6.5L6.29 12H17.71L17.5 10Z\";\r\nvar mdiTableHeadersEye = \"M1 6V19A2 2 0 0 0 3 21H9V11H21V6A2 2 0 0 0 19 4H3A2 2 0 0 0 1 6M3 6H7V9H3M7 19H3V16H7M7 14H3V11H7M9 9V6H13V9M19 9H15V6H19M17 16A1 1 0 1 1 16 17A1 1 0 0 1 17 16M17 13A6.45 6.45 0 0 1 23 17A6.5 6.5 0 0 1 11 17A6.45 6.45 0 0 1 17 13M17 14.5A2.5 2.5 0 1 0 19.5 17A2.5 2.5 0 0 0 17 14.5\";\r\nvar mdiTableHeadersEyeOff = \"M2.38 1.73L1.11 3L2.26 4.15A2 2 0 0 0 1 6V19A2 2 0 0 0 3 21H9V11H9.11L12.72 14.61A6.21 6.21 0 0 0 11 17A6.45 6.45 0 0 0 17 21A6.55 6.55 0 0 0 18.84 20.73L20.84 22.73L22.11 21.46L20.58 19.93M7 19H3V16H7M7 14H3V11H7M7 9H3V6H4.11L7 8.89M17 19.5A2.5 2.5 0 0 1 14.56 16.45L17.56 19.45A2.5 2.5 0 0 1 17 19.5M16.24 13L17.85 14.61A2.5 2.5 0 0 1 19.35 16.11L21.94 18.7A6.44 6.44 0 0 0 23 17A6.45 6.45 0 0 0 17 13H16.24M13 6V9H12.2L14.2 11H21V6A2 2 0 0 0 19 4H7.2L9.2 6M15 6H19V9H15Z\";\r\nvar mdiTableHeart = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M19 22.3L18.4 21.8C16.4 19.9 15 18.7 15 17.2C15 16 16 15 17.2 15C17.9 15 18.6 15.3 19 15.8C19.4 15.3 20.1 15 20.8 15C22 15 23 15.9 23 17.2C23 18.7 21.6 19.9 19.6 21.8L19 22.3\";\r\nvar mdiTableKey = \"M16.83 17C16.42 15.83 15.31 15 14 15C12.34 15 11 16.34 11 18S12.34 21 14 21C15.31 21 16.42 20.17 16.83 19H19V21H21V19H22V17H16.83M14 19C13.45 19 13 18.55 13 18S13.45 17 14 17 15 17.45 15 18 14.55 19 14 19M9 18H4V14H10V15.03C10.91 13.81 12.36 13 14 13C15.1 13 16.14 13.37 17 14H18V15L18 15H20V6C20 4.89 19.11 4 18 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H9.42C9.15 19.39 9 18.71 9 18M12 8H18V12H12V8M4 8H10V12H4V8Z\";\r\nvar mdiTableLarge = \"M4,3H20A2,2 0 0,1 22,5V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V5A2,2 0 0,1 4,3M4,7V10H8V7H4M10,7V10H14V7H10M20,10V7H16V10H20M4,12V15H8V12H4M4,20H8V17H4V20M10,12V15H14V12H10M10,20H14V17H10V20M20,20V17H16V20H20M20,12H16V15H20V12Z\";\r\nvar mdiTableLargePlus = \"M12.35 20H10V17H12.09C12.21 16.28 12.46 15.61 12.81 15H10V12H14V13.54C14.58 13 15.25 12.61 16 12.35V12H20V12.35C20.75 12.61 21.42 13 22 13.54V5C22 3.9 21.1 3 20 3H4C2.9 3 2 3.9 2 5V20C2 21.1 2.9 22 4 22H13.54C13 21.42 12.61 20.75 12.35 20M16 7H20V10H16V7M10 7H14V10H10V7M8 20H4V17H8V20M8 15H4V12H8V15M8 10H4V7H8V10M17 14H19V17H22V19H19V22H17V19H14V17H17V14\";\r\nvar mdiTableLargeRemove = \"M12.35 20H10V17H12.09C12.21 16.28 12.46 15.61 12.81 15H10V12H14V13.54C14.58 13 15.25 12.61 16 12.35V12H20V12.35C20.75 12.61 21.42 13 22 13.54V5C22 3.9 21.1 3 20 3H4C2.9 3 2 3.9 2 5V20C2 21.1 2.9 22 4 22H13.54C13 21.42 12.61 20.75 12.35 20M16 7H20V10H16V7M10 7H14V10H10V7M8 20H4V17H8V20M8 15H4V12H8V15M8 10H4V7H8V10M14.46 15.88L15.88 14.46L18 16.59L20.12 14.46L21.54 15.88L19.41 18L21.54 20.12L20.12 21.54L18 19.41L15.88 21.54L14.46 20.12L16.59 18L14.46 15.88\";\r\nvar mdiTableLock = \"M21 16V15.5C21 14.12 19.88 13 18.5 13S16 14.12 16 15.5V16C15.45 16 15 16.45 15 17V21C15 21.55 15.45 22 16 22H21C21.55 22 22 21.55 22 21V17C22 16.45 21.55 16 21 16M20 16H17V15.5C17 14.67 17.67 14 18.5 14S20 14.67 20 15.5V16M13 18H12V14H14.26C14.54 13.21 15.04 12.5 15.69 12H12V8H18V11.05C18.17 11.03 18.33 11 18.5 11C19.03 11 19.53 11.1 20 11.26V6C20 4.89 19.11 4 18 4H4C2.9 4 2 4.89 2 6V18C2 19.11 2.9 20 4 20H13V18M10 18H4V14H10V18M10 12H4V8H10V12Z\";\r\nvar mdiTableMergeCells = \"M5,10H3V4H11V6H5V10M19,18H13V20H21V14H19V18M5,18V14H3V20H11V18H5M21,4H13V6H19V10H21V4M8,13V15L11,12L8,9V11H3V13H8M16,11V9L13,12L16,15V13H21V11H16Z\";\r\nvar mdiTableMinus = \"M15 19V17H23V19H15M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4Z\";\r\nvar mdiTableMultiple = \"M7 2H21C22.11 2 23 2.9 23 4V16C23 17.11 22.11 18 21 18H7C5.9 18 5 17.11 5 16V4C5 2.9 5.9 2 7 2M7 6V10H13V6H7M15 6V10H21V6H15M7 12V16H13V12H7M15 12V16H21V12H15M3 20V6H1V20C1 21.11 1.89 22 3 22H19V20H3Z\";\r\nvar mdiTableNetwork = \"M15 20C15 19.45 14.55 19 14 19H13V17H19C20.11 17 21 16.11 21 15V3C21 1.9 20.11 1 19 1H5C3.9 1 3 1.9 3 3V15C3 16.11 3.9 17 5 17H11V19H10C9.45 19 9 19.45 9 20H2V22H9C9 22.55 9.45 23 10 23H14C14.55 23 15 22.55 15 22H22V20H15M13 5H19V9H13V5M13 11H19V15H13V11M5 5H11V9H5V5M5 15V11H11V15H5Z\";\r\nvar mdiTableOfContents = \"M3,9H17V7H3V9M3,13H17V11H3V13M3,17H17V15H3V17M19,17H21V15H19V17M19,7V9H21V7H19M19,13H21V11H19V13Z\";\r\nvar mdiTableOff = \"M22.11 21.46L2.39 1.73L1.11 3L3.22 5.11C3.08 5.38 3 5.68 3 6V18C3 19.11 3.9 20 5 20H18.11L20.84 22.73L22.11 21.46M10.11 12H5V8H6.11L10.11 12M11 18H5V14H11V18M13 18V14.89L16.11 18H13M13 9.8L7.2 4H19C20.11 4 21 4.89 21 6V17.8L19 15.8V14H17.2L15.2 12H19V8H13V9.8Z\";\r\nvar mdiTablePlus = \"M18,14H20V17H23V19H20V22H18V19H15V17H18V14M4,3H18A2,2 0 0,1 20,5V12.08C18.45,11.82 16.92,12.18 15.68,13H12V17H13.08C12.97,17.68 12.97,18.35 13.08,19H4A2,2 0 0,1 2,17V5A2,2 0 0,1 4,3M4,7V11H10V7H4M12,7V11H18V7H12M4,13V17H10V13H4Z\";\r\nvar mdiTableRefresh = \"M18 14.5C19.11 14.5 20.11 14.95 20.83 15.67L22 14.5V18.5H18L19.77 16.73C19.32 16.28 18.69 16 18 16C16.62 16 15.5 17.12 15.5 18.5C15.5 19.88 16.62 21 18 21C18.82 21 19.55 20.61 20 20H21.71C21.12 21.47 19.68 22.5 18 22.5C15.79 22.5 14 20.71 14 18.5C14 16.29 15.79 14.5 18 14.5M4 3H18C19.11 3 20 3.9 20 5V12.17C19.5 12.06 19 12 18.5 12C17.23 12 16.04 12.37 15.04 13H12V17H12.18C12.06 17.5 12 18 12 18.5L12 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4Z\";\r\nvar mdiTableRemove = \"M15.46,15.88L16.88,14.46L19,16.59L21.12,14.46L22.54,15.88L20.41,18L22.54,20.12L21.12,21.54L19,19.41L16.88,21.54L15.46,20.12L17.59,18L15.46,15.88M4,3H18A2,2 0 0,1 20,5V12.08C18.45,11.82 16.92,12.18 15.68,13H12V17H13.08C12.97,17.68 12.97,18.35 13.08,19H4A2,2 0 0,1 2,17V5A2,2 0 0,1 4,3M4,7V11H10V7H4M12,7V11H18V7H12M4,13V17H10V13H4Z\";\r\nvar mdiTableRow = \"M22,14A2,2 0 0,1 20,16H4A2,2 0 0,1 2,14V10A2,2 0 0,1 4,8H20A2,2 0 0,1 22,10V14M4,14H8V10H4V14M10,14H14V10H10V14M16,14H20V10H16V14Z\";\r\nvar mdiTableRowHeight = \"M3,5H15A2,2 0 0,1 17,7V17A2,2 0 0,1 15,19H3A2,2 0 0,1 1,17V7A2,2 0 0,1 3,5M3,9V12H8V9H3M10,9V12H15V9H10M3,14V17H8V14H3M10,14V17H15V14H10M23,14V7H19V9H21V12H19V14H23Z\";\r\nvar mdiTableRowPlusAfter = \"M22,10A2,2 0 0,1 20,12H4A2,2 0 0,1 2,10V3H4V5H8V3H10V5H14V3H16V5H20V3H22V10M4,10H8V7H4V10M10,10H14V7H10V10M20,10V7H16V10H20M11,14H13V17H16V19H13V22H11V19H8V17H11V14Z\";\r\nvar mdiTableRowPlusBefore = \"M22,14A2,2 0 0,0 20,12H4A2,2 0 0,0 2,14V21H4V19H8V21H10V19H14V21H16V19H20V21H22V14M4,14H8V17H4V14M10,14H14V17H10V14M20,14V17H16V14H20M11,10H13V7H16V5H13V2H11V5H8V7H11V10Z\";\r\nvar mdiTableRowRemove = \"M9.41,13L12,15.59L14.59,13L16,14.41L13.41,17L16,19.59L14.59,21L12,18.41L9.41,21L8,19.59L10.59,17L8,14.41L9.41,13M22,9A2,2 0 0,1 20,11H4A2,2 0 0,1 2,9V6A2,2 0 0,1 4,4H20A2,2 0 0,1 22,6V9M4,9H8V6H4V9M10,9H14V6H10V9M16,9H20V6H16V9Z\";\r\nvar mdiTableSearch = \"M19.3,17.89C20.62,15.79 20,13 17.89,11.68C15.79,10.36 13,11 11.68,13.09C10.36,15.2 11,18 13.09,19.3C14.56,20.22 16.42,20.22 17.89,19.3L21,22.39L22.39,21L19.3,17.89M17.3,17.27C16.32,18.25 14.74,18.24 13.76,17.27C12.79,16.29 12.79,14.71 13.77,13.73C14.74,12.76 16.32,12.76 17.3,13.73C18.26,14.72 18.25,16.3 17.27,17.27H17.3M19,4H5A2,2 0 0,0 3,6V18A2,2 0 0,0 5,20H10.81C10.25,19.42 9.8,18.74 9.5,18H5V14H9.18C9.34,13.29 9.61,12.61 10,12H5V8H11V10.81C11.58,10.25 12.26,9.8 13,9.5V8H19V10C19.4,10.25 19.77,10.55 20.1,10.88C20.44,11.22 20.74,11.59 21,12V6A2,2 0 0,0 19,4Z\";\r\nvar mdiTableSettings = \"M7,22H9V24H7V22M11,22H13V24H11V22M15,22H17V24H15V22M5,4H19A2,2 0 0,1 21,6V18A2,2 0 0,1 19,20H5A2,2 0 0,1 3,18V6A2,2 0 0,1 5,4M5,8V12H11V8H5M13,8V12H19V8H13M5,14V18H11V14H5M13,14V18H19V14H13Z\";\r\nvar mdiTableSplitCell = \"M19 14H21V20H3V14H5V18H19V14M3 4V10H5V6H19V10H21V4H3M11 11V13H8V15L5 12L8 9V11H11M16 11V9L19 12L16 15V13H13V11H16Z\";\r\nvar mdiTableStar = \"M4 3H18C19.11 3 20 3.9 20 5V12.08C18.45 11.82 16.92 12.18 15.68 13H12V17H13.08C12.97 17.68 12.97 18.35 13.08 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4M16.5 21.6L17.2 18.8L15 16.9L17.9 16.7L19 14L20.1 16.6L23 16.8L20.8 18.7L21.5 21.5L19 20.1L16.5 21.6Z\";\r\nvar mdiTableSync = \"M19 12V13.5C21.21 13.5 23 15.29 23 17.5C23 18.32 22.76 19.08 22.33 19.71L21.24 18.62C21.41 18.28 21.5 17.9 21.5 17.5C21.5 16.12 20.38 15 19 15V16.5L16.75 14.25L19 12M19 23V21.5C16.79 21.5 15 19.71 15 17.5C15 16.68 15.25 15.92 15.67 15.29L16.76 16.38C16.59 16.72 16.5 17.1 16.5 17.5C16.5 18.88 17.62 20 19 20V18.5L21.25 20.75L19 23M4 3H18C19.11 3 20 3.9 20 5V11L19.5 11C17.66 11 16 11.77 14.81 13H12V17H13L13 17.5C13 18 13.06 18.5 13.17 19H4C2.9 19 2 18.11 2 17V5C2 3.9 2.9 3 4 3M4 7V11H10V7H4M12 7V11H18V7H12M4 13V17H10V13H4Z\";\r\nvar mdiTableTennis = \"M18.5,14C19.9,14 21,15.1 21,16.5C21,17.9 19.9,19 18.5,19C17.1,19 16,17.9 16,16.5C16,15.1 17.1,14 18.5,14M7,15C7,15 8,16 8,17V20.5C8,21.3 8.7,22 9.5,22C10.3,22 11,21.3 11,20.5V17C11,16 12,15 12,15H7M8,14H11C11,14 16,14 16,9C16,4 12,2 9.5,2C7,2 3,4 3,9C3,14 8,14 8,14Z\";\r\nvar mdiTablet = \"M19,18H5V6H19M21,4H3C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H21A2,2 0 0,0 23,18V6C23,4.89 22.1,4 21,4Z\";\r\nvar mdiTabletAndroid = \"M19.25,19H4.75V3H19.25M14,22H10V21H14M18,0H6A3,3 0 0,0 3,3V21A3,3 0 0,0 6,24H18A3,3 0 0,0 21,21V3A3,3 0 0,0 18,0Z\";\r\nvar mdiTabletCellphone = \"M3,4H20A2,2 0 0,1 22,6V8H18V6H5V18H14V20H3A2,2 0 0,1 1,18V6A2,2 0 0,1 3,4M17,10H23A1,1 0 0,1 24,11V21A1,1 0 0,1 23,22H17A1,1 0 0,1 16,21V11A1,1 0 0,1 17,10M18,12V19H22V12H18Z\";\r\nvar mdiTabletDashboard = \"M19,18H5V6H19M21,4H3C1.89,4 1,4.89 1,6V18A2,2 0 0,0 3,20H21A2,2 0 0,0 23,18V6C23,4.89 22.1,4 21,4M7,8H13V13H7V8M14,8H17V10H14V8M17,11V16H14V11H17M7,14H13V16H7V14Z\";\r\nvar mdiTabletIpad = \"M19,19H4V3H19M11.5,23A1.5,1.5 0 0,1 10,21.5A1.5,1.5 0 0,1 11.5,20A1.5,1.5 0 0,1 13,21.5A1.5,1.5 0 0,1 11.5,23M18.5,0H4.5A2.5,2.5 0 0,0 2,2.5V21.5A2.5,2.5 0 0,0 4.5,24H18.5A2.5,2.5 0 0,0 21,21.5V2.5A2.5,2.5 0 0,0 18.5,0Z\";\r\nvar mdiTaco = \"M19,18H5A4,4 0 0,1 1,14A8,8 0 0,1 9,6C10.06,6 11.07,6.21 12,6.58C12.93,6.21 13.94,6 15,6A8,8 0 0,1 23,14A4,4 0 0,1 19,18M3,14A2,2 0 0,0 5,16A2,2 0 0,0 7,14C7,11.63 8.03,9.5 9.67,8.04L9,8A6,6 0 0,0 3,14M19,16A2,2 0 0,0 21,14A6,6 0 0,0 15,8A6,6 0 0,0 9,14C9,14.73 8.81,15.41 8.46,16H19Z\";\r\nvar mdiTag = \"M5.5,7A1.5,1.5 0 0,1 4,5.5A1.5,1.5 0 0,1 5.5,4A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 5.5,7M21.41,11.58L12.41,2.58C12.05,2.22 11.55,2 11,2H4C2.89,2 2,2.89 2,4V11C2,11.55 2.22,12.05 2.59,12.41L11.58,21.41C11.95,21.77 12.45,22 13,22C13.55,22 14.05,21.77 14.41,21.41L21.41,14.41C21.78,14.05 22,13.55 22,13C22,12.44 21.77,11.94 21.41,11.58Z\";\r\nvar mdiTagFaces = \"M15,18C11.68,18 9,15.31 9,12C9,8.68 11.68,6 15,6A6,6 0 0,1 21,12A6,6 0 0,1 15,18M4,13A1,1 0 0,1 3,12A1,1 0 0,1 4,11A1,1 0 0,1 5,12A1,1 0 0,1 4,13M22,3H7.63C6.97,3 6.38,3.32 6,3.81L0,12L6,20.18C6.38,20.68 6.97,21 7.63,21H22A2,2 0 0,0 24,19V5C24,3.89 23.1,3 22,3M13,11A1,1 0 0,0 14,10A1,1 0 0,0 13,9A1,1 0 0,0 12,10A1,1 0 0,0 13,11M15,16C16.86,16 18.35,14.72 18.8,13H11.2C11.65,14.72 13.14,16 15,16M17,11A1,1 0 0,0 18,10A1,1 0 0,0 17,9A1,1 0 0,0 16,10A1,1 0 0,0 17,11Z\";\r\nvar mdiTagHeart = \"M21.41,11.58L12.41,2.58C12.05,2.22 11.55,2 11,2H4A2,2 0 0,0 2,4V11C2,11.55 2.22,12.05 2.59,12.42L11.59,21.42C11.95,21.78 12.45,22 13,22C13.55,22 14.05,21.78 14.41,21.41L21.41,14.41C21.78,14.05 22,13.55 22,13C22,12.45 21.77,11.94 21.41,11.58M5.5,7A1.5,1.5 0 0,1 4,5.5A1.5,1.5 0 0,1 5.5,4A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 5.5,7M17.27,15.27L13,19.54L8.73,15.27C8.28,14.81 8,14.19 8,13.5A2.5,2.5 0 0,1 10.5,11C11.19,11 11.82,11.28 12.27,11.74L13,12.46L13.73,11.73C14.18,11.28 14.81,11 15.5,11A2.5,2.5 0 0,1 18,13.5C18,14.19 17.72,14.82 17.27,15.27Z\";\r\nvar mdiTagHeartOutline = \"M4,2A2,2 0 0,0 2,4V11C2,11.55 2.22,12.05 2.59,12.42L11.59,21.42C11.95,21.78 12.45,22 13,22C13.55,22 14.05,21.78 14.41,21.41L21.41,14.41C21.78,14.05 22,13.55 22,13C22,12.45 21.77,11.94 21.41,11.58L12.41,2.58C12.05,2.22 11.55,2 11,2H4V2M11,4L20,13L13,20L4,11V4H11V4H11M6.5,5A1.5,1.5 0 0,0 5,6.5A1.5,1.5 0 0,0 6.5,8A1.5,1.5 0 0,0 8,6.5A1.5,1.5 0 0,0 6.5,5M10.95,10.5C9.82,10.5 8.9,11.42 8.9,12.55C8.9,13.12 9.13,13.62 9.5,14L13,17.5L16.5,14C16.87,13.63 17.1,13.11 17.1,12.55A2.05,2.05 0 0,0 15.05,10.5C14.5,10.5 13.97,10.73 13.6,11.1L13,11.7L12.4,11.11C12.03,10.73 11.5,10.5 10.95,10.5Z\";\r\nvar mdiTagMinus = \"M21.41,11.58L12.41,2.58C12.04,2.21 11.53,2 11,2H4A2,2 0 0,0 2,4V11C2,11.53 2.21,12.04 2.59,12.41L3,12.81C3.9,12.27 4.94,12 6,12A6,6 0 0,1 12,18C12,19.06 11.72,20.09 11.18,21L11.58,21.4C11.95,21.78 12.47,22 13,22C13.53,22 14.04,21.79 14.41,21.41L21.41,14.41C21.79,14.04 22,13.53 22,13C22,12.47 21.79,11.96 21.41,11.58M5.5,7A1.5,1.5 0 0,1 4,5.5A1.5,1.5 0 0,1 5.5,4A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 5.5,7M10,19H2V17H10V19Z\";\r\nvar mdiTagMinusOutline = \"M6.5 5C5.67 5 5 5.67 5 6.5S5.67 8 6.5 8 8 7.33 8 6.5 7.33 5 6.5 5M6.5 5C5.67 5 5 5.67 5 6.5S5.67 8 6.5 8 8 7.33 8 6.5 7.33 5 6.5 5M21.41 11.58L12.41 2.58C12.04 2.21 11.53 2 11 2H4C2.9 2 2 2.9 2 4V11C2 11.53 2.21 12.04 2.59 12.42L3 12.82C3.64 12.44 4.35 12.19 5.08 12.08L4 11V4H11L20 13L13 20L11.92 18.92C11.82 19.66 11.56 20.36 11.18 21L11.59 21.41C11.96 21.79 12.47 22 13 22C13.53 22 14.04 21.79 14.41 21.41L21.41 14.41C21.79 14.04 22 13.53 22 13C22 12.47 21.79 11.96 21.41 11.58M6.5 5C5.67 5 5 5.67 5 6.5S5.67 8 6.5 8 8 7.33 8 6.5 7.33 5 6.5 5M10 19H2V17H10V19Z\";\r\nvar mdiTagMultiple = \"M5.5,9A1.5,1.5 0 0,0 7,7.5A1.5,1.5 0 0,0 5.5,6A1.5,1.5 0 0,0 4,7.5A1.5,1.5 0 0,0 5.5,9M17.41,11.58C17.77,11.94 18,12.44 18,13C18,13.55 17.78,14.05 17.41,14.41L12.41,19.41C12.05,19.77 11.55,20 11,20C10.45,20 9.95,19.78 9.58,19.41L2.59,12.42C2.22,12.05 2,11.55 2,11V6C2,4.89 2.89,4 4,4H9C9.55,4 10.05,4.22 10.41,4.58L17.41,11.58M13.54,5.71L14.54,4.71L21.41,11.58C21.78,11.94 22,12.45 22,13C22,13.55 21.78,14.05 21.42,14.41L16.04,19.79L15.04,18.79L20.75,13L13.54,5.71Z\";\r\nvar mdiTagMultipleOutline = \"M6.5 10C7.3 10 8 9.3 8 8.5S7.3 7 6.5 7 5 7.7 5 8.5 5.7 10 6.5 10M9 6L16 13L11 18L4 11V6H9M9 4H4C2.9 4 2 4.9 2 6V11C2 11.6 2.2 12.1 2.6 12.4L9.6 19.4C9.9 19.8 10.4 20 11 20S12.1 19.8 12.4 19.4L17.4 14.4C17.8 14 18 13.5 18 13C18 12.4 17.8 11.9 17.4 11.6L10.4 4.6C10.1 4.2 9.6 4 9 4M13.5 5.7L14.5 4.7L21.4 11.6C21.8 12 22 12.5 22 13S21.8 14.1 21.4 14.4L16 19.8L15 18.8L20.7 13L13.5 5.7Z\";\r\nvar mdiTagOff = \"M18.33 8.5L22.92 3.92L21.5 2.5L2.5 21.5L3.92 22.92L8.5 18.33L11.58 21.41A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M5.61 15.43L15.47 5.65L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.41M5.5 4A1.5 1.5 0 1 1 4 5.5A1.5 1.5 0 0 1 5.5 4Z\";\r\nvar mdiTagOffOutline = \"M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M18.33 8.5L22.92 3.92L21.5 2.5L2.5 21.5L3.92 22.92L8.5 18.33L11.59 21.42A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M13 20L9.92 16.92L16.92 9.92L20 13M5.61 15.43L7 14L4 11V4H11L14.06 7.06L15.47 5.66L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.42M5 6.5A1.5 1.5 0 1 0 6.5 5A1.5 1.5 0 0 0 5 6.5Z\";\r\nvar mdiTagOutline = \"M21.41 11.58L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.42L11.59 21.42A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M13 20L4 11V4H11L20 13M6.5 5A1.5 1.5 0 1 1 5 6.5A1.5 1.5 0 0 1 6.5 5Z\";\r\nvar mdiTagPlus = \"M21.41,11.58L12.41,2.58C12.04,2.21 11.53,2 11,2H4A2,2 0 0,0 2,4V11C2,11.53 2.21,12.04 2.59,12.41L3,12.81C3.9,12.27 4.94,12 6,12A6,6 0 0,1 12,18C12,19.06 11.72,20.09 11.18,21L11.58,21.4C11.95,21.78 12.47,22 13,22C13.53,22 14.04,21.79 14.41,21.41L21.41,14.41C21.79,14.04 22,13.53 22,13C22,12.47 21.79,11.96 21.41,11.58M5.5,7A1.5,1.5 0 0,1 4,5.5A1.5,1.5 0 0,1 5.5,4A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 5.5,7M10,19H7V22H5V19H2V17H5V14H7V17H10V19Z\";\r\nvar mdiTagPlusOutline = \"M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M21.41 11.58L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.42L3 12.82A5.62 5.62 0 0 1 5.08 12.08L4 11V4H11L20 13L13 20L11.92 18.92A5.57 5.57 0 0 1 11.18 21L11.59 21.41A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M10 19H7V22H5V19H2V17H5V14H7V17H10Z\";\r\nvar mdiTagRemove = \"M21.41,11.58L12.41,2.58C12.04,2.21 11.53,2 11,2H4A2,2 0 0,0 2,4V11C2,11.53 2.21,12.04 2.59,12.41L3,12.81C3.9,12.27 4.94,12 6,12A6,6 0 0,1 12,18C12,19.06 11.72,20.09 11.18,21L11.58,21.4C11.95,21.78 12.47,22 13,22C13.53,22 14.04,21.79 14.41,21.41L21.41,14.41C21.79,14.04 22,13.53 22,13C22,12.47 21.79,11.96 21.41,11.58M5.5,7A1.5,1.5 0 0,1 4,5.5A1.5,1.5 0 0,1 5.5,4A1.5,1.5 0 0,1 7,5.5A1.5,1.5 0 0,1 5.5,7M8.12,21.54L6,19.41L3.88,21.54L2.46,20.12L4.59,18L2.46,15.88L3.87,14.47L6,16.59L8.12,14.47L9.53,15.88L7.41,18L9.53,20.12L8.12,21.54Z\";\r\nvar mdiTagRemoveOutline = \"M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M21.41 11.58L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.42L3 12.82A5.62 5.62 0 0 1 5.08 12.08L4 11V4H11L20 13L13 20L11.92 18.92A5.57 5.57 0 0 1 11.18 21L11.59 21.41A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M6.5 5A1.5 1.5 0 1 0 8 6.5A1.5 1.5 0 0 0 6.5 5M8.12 21.54L6 19.41L3.88 21.54L2.46 20.12L4.59 18L2.46 15.88L3.88 14.46L6 16.59L8.12 14.46L9.54 15.88L7.41 18L9.54 20.12Z\";\r\nvar mdiTagText = \"M21.41 11.58L12.41 2.58A2 2 0 0 0 11 2H4A2 2 0 0 0 2 4V11A2 2 0 0 0 2.59 12.41L11.59 21.41A2 2 0 0 0 13 22A2 2 0 0 0 14.41 21.41L21.41 14.41A2 2 0 0 0 22 13A2 2 0 0 0 21.41 11.58M6.5 8A1.5 1.5 0 1 1 8 6.5A1.5 1.5 0 0 1 6.5 8M11.59 15.41L7.59 11.41L9 10L13 14M15.59 14.41L10.09 8.91L11.5 7.5L17 13Z\";\r\nvar mdiTagTextOutline = \"M21.4 11.6L12.4 2.6C12 2.2 11.5 2 11 2H4C2.9 2 2 2.9 2 4V11C2 11.5 2.2 12 2.6 12.4L11.6 21.4C12 21.8 12.5 22 13 22C13.5 22 14 21.8 14.4 21.4L21.4 14.4C21.8 14 22 13.5 22 13C22 12.5 21.8 12 21.4 11.6M13 20L4 11V4H11L20 13M6.5 5C7.3 5 8 5.7 8 6.5S7.3 8 6.5 8 5 7.3 5 6.5 5.7 5 6.5 5M10.1 8.9L11.5 7.5L17 13L15.6 14.4L10.1 8.9M7.6 11.4L9 10L13 14L11.6 15.4L7.6 11.4Z\";\r\nvar mdiTailwind = \"M12 6C9.33 6 7.67 7.33 7 10C8 8.67 9.17 8.17 10.5 8.5C11.26 8.69 11.81 9.24 12.41 9.85C13.39 10.85 14.5 12 17 12C19.67 12 21.33 10.67 22 8C21 9.33 19.83 9.83 18.5 9.5C17.74 9.31 17.2 8.76 16.59 8.15C15.61 7.15 14.5 6 12 6M7 12C4.33 12 2.67 13.33 2 16C3 14.67 4.17 14.17 5.5 14.5C6.26 14.69 6.8 15.24 7.41 15.85C8.39 16.85 9.5 18 12 18C14.67 18 16.33 16.67 17 14C16 15.33 14.83 15.83 13.5 15.5C12.74 15.31 12.2 14.76 11.59 14.15C10.61 13.15 9.5 12 7 12Z\";\r\nvar mdiTank = \"M20,12H4V11H6L7,6H12L13,11H20V12M13.22,7L13.62,9H22V7H13.22M22,16A3,3 0 0,1 19,19H5A3,3 0 0,1 2,16A3,3 0 0,1 5,13H19A3,3 0 0,1 22,16M6,16A1,1 0 0,0 5,15A1,1 0 0,0 4,16A1,1 0 0,0 5,17A1,1 0 0,0 6,16M13,16A1,1 0 0,0 12,15A1,1 0 0,0 11,16A1,1 0 0,0 12,17A1,1 0 0,0 13,16M20,16A1,1 0 0,0 19,15A1,1 0 0,0 18,16A1,1 0 0,0 19,17A1,1 0 0,0 20,16Z\";\r\nvar mdiTankerTruck = \"M20 8H15V14H2V17H3C3 18.7 4.3 20 6 20S9 18.7 9 17H15C15 18.7 16.3 20 18 20S21 18.7 21 17H23V12L20 8M6 18.5C5.2 18.5 4.5 17.8 4.5 17S5.2 15.5 6 15.5 7.5 16.2 7.5 17 6.8 18.5 6 18.5M18 18.5C17.2 18.5 16.5 17.8 16.5 17S17.2 15.5 18 15.5 19.5 16.2 19.5 17 18.8 18.5 18 18.5M17 12V9.5H19.5L21.5 12H17M14 9.5C14 11.4 12.4 13 10.5 13H4.5C2.6 13 1 11.4 1 9.5S2.6 6 4.5 6H5V5H4V4H8V5H7V6H10.5C12.4 6 14 7.6 14 9.5Z\";\r\nvar mdiTapeMeasure = \"M9,5A7,7 0 0,1 16,12H17V15H16V19H9A7,7 0 0,1 2,12A7,7 0 0,1 9,5M9,8A4,4 0 0,0 5,12A4,4 0 0,0 9,16A4,4 0 0,0 13,12A4,4 0 0,0 9,8M17,17H22V19L22,21H20V19H17V17Z\";\r\nvar mdiTarget = \"M11,2V4.07C7.38,4.53 4.53,7.38 4.07,11H2V13H4.07C4.53,16.62 7.38,19.47 11,19.93V22H13V19.93C16.62,19.47 19.47,16.62 19.93,13H22V11H19.93C19.47,7.38 16.62,4.53 13,4.07V2M11,6.08V8H13V6.09C15.5,6.5 17.5,8.5 17.92,11H16V13H17.91C17.5,15.5 15.5,17.5 13,17.92V16H11V17.91C8.5,17.5 6.5,15.5 6.08,13H8V11H6.09C6.5,8.5 8.5,6.5 11,6.08M12,11A1,1 0 0,0 11,12A1,1 0 0,0 12,13A1,1 0 0,0 13,12A1,1 0 0,0 12,11Z\";\r\nvar mdiTargetAccount = \"M20.95,11H22.5V13H20.95C20.5,17.17 17.17,20.5 13,20.95V22.5H11V20.95C6.83,20.5 3.5,17.17 3.05,13H1.5V11H3.05C3.5,6.83 6.83,3.5 11,3.05V1.5H13V3.05C17.17,3.5 20.5,6.83 20.95,11M5.07,11H6.5V13H5.07C5.5,16.07 7.93,18.5 11,18.93V17.5H13V18.93C16.07,18.5 18.5,16.07 18.93,13H17.5V11H18.93C18.5,7.93 16.07,5.5 13,5.07V6.5H11V5.07C7.93,5.5 5.5,7.93 5.07,11M16,16H8V15C8,13.67 10.67,13 12,13C13.33,13 16,13.67 16,15V16M12,8A2,2 0 0,1 14,10A2,2 0 0,1 12,12A2,2 0 0,1 10,10A2,2 0 0,1 12,8Z\";\r\nvar mdiTargetVariant = \"M22.08,11.04H20.08V4H13.05V2H11.04V4H4V11.04H2V13.05H4V20.08H11.04V22.08H13.05V20.08H20.08V13.05H22.08V11.04M18.07,18.07H13.05V16.06H11.04V18.07H6V13.05H8.03V11.04H6V6H11.04V8.03H13.05V6H18.07V11.04H16.06V13.05H18.07V18.07M13.05,12.05A1,1 0 0,1 12.05,13.05C11.5,13.05 11.04,12.6 11.04,12.05C11.04,11.5 11.5,11.04 12.05,11.04C12.6,11.04 13.05,11.5 13.05,12.05Z\";\r\nvar mdiTaxi = \"M5,11L6.5,6.5H17.5L19,11M17.5,16A1.5,1.5 0 0,1 16,14.5A1.5,1.5 0 0,1 17.5,13A1.5,1.5 0 0,1 19,14.5A1.5,1.5 0 0,1 17.5,16M6.5,16A1.5,1.5 0 0,1 5,14.5A1.5,1.5 0 0,1 6.5,13A1.5,1.5 0 0,1 8,14.5A1.5,1.5 0 0,1 6.5,16M18.92,6C18.72,5.42 18.16,5 17.5,5H15V3H9V5H6.5C5.84,5 5.28,5.42 5.08,6L3,12V20A1,1 0 0,0 4,21H5A1,1 0 0,0 6,20V19H18V20A1,1 0 0,0 19,21H20A1,1 0 0,0 21,20V12L18.92,6Z\";\r\nvar mdiTea = \"M4,19H20V21H4V19M20,8V5H18V8H20M20,3C20.6,3 21,3.2 21.4,3.6C21.8,4 22,4.5 22,5V8C22,8.6 21.8,9 21.4,9.4C21,9.8 20.6,10 20,10H18V13C18,14.1 17.6,15 16.8,15.8C16,16.6 15.1,17 14,17H8C6.9,17 6,16.6 5.2,15.8C4.4,15 4,14.1 4,13V3H9V5.4L7.2,6.8C7.1,6.9 7,7.1 7,7.2V11.5C7,11.8 7.2,12 7.5,12H11.5C11.8,12 12,11.8 12,11.5V7.2C12,7 11.9,6.9 11.8,6.8L10,5.4V3H20Z\";\r\nvar mdiTeaOutline = \"M4,19H20V21H4V19M21.4,3.6C21,3.2 20.6,3 20,3H4V13C4,14.1 4.4,15 5.2,15.8C6,16.6 6.9,17 8,17H14C15.1,17 16,16.6 16.8,15.8C17.6,15 18,14.1 18,13V10H20C20.6,10 21,9.8 21.4,9.4C21.8,9 22,8.6 22,8V5C22,4.5 21.8,4 21.4,3.6M16,5V8L16,10V13C16,13.6 15.8,14 15.4,14.4C15,14.8 14.6,15 14,15H8C7.4,15 7,14.8 6.6,14.4C6.2,14 6,13.5 6,13V5H10V6.4L8.2,7.8C8,7.9 8,8.1 8,8.2V12.5C8,12.8 8.2,13 8.5,13H12.5C12.8,13 13,12.8 13,12.5V8.2C13,8 12.9,7.9 12.8,7.8L11,6.4V5H16M20,8H18V5H20V8Z\";\r\nvar mdiTeach = \"M20,17A2,2 0 0,0 22,15V4A2,2 0 0,0 20,2H9.46C9.81,2.61 10,3.3 10,4H20V15H11V17M15,7V9H9V22H7V16H5V22H3V14H1.5V9A2,2 0 0,1 3.5,7H15M8,4A2,2 0 0,1 6,6A2,2 0 0,1 4,4A2,2 0 0,1 6,2A2,2 0 0,1 8,4Z\";\r\nvar mdiTeamviewer = \"M10.04 9.2L9.3 11H14.75L14 9.2L19.55 12L14 14.8L14.75 13H9.3L10.04 14.8L4.5 12L10.04 9.2M20.83 22H3.17C2.53 22 2 21.5 2 20.83V3.17C2 2.53 2.53 2 3.17 2H20.83C21.5 2 22 2.53 22 3.17V20.83C22 21.47 21.5 22 20.83 22M11.93 3.76C7.41 3.82 3.78 7.5 3.76 12C3.72 16.5 7.35 20.2 11.86 20.24H12C16.53 20.18 20.18 16.53 20.24 12C20.31 7.5 16.74 3.83 12.26 3.76C12.15 3.75 12.04 3.76 11.93 3.76Z\";\r\nvar mdiTelegram = \"M9.78,18.65L10.06,14.42L17.74,7.5C18.08,7.19 17.67,7.04 17.22,7.31L7.74,13.3L3.64,12C2.76,11.75 2.75,11.14 3.84,10.7L19.81,4.54C20.54,4.21 21.24,4.72 20.96,5.84L18.24,18.65C18.05,19.56 17.5,19.78 16.74,19.36L12.6,16.3L10.61,18.23C10.38,18.46 10.19,18.65 9.78,18.65Z\";\r\nvar mdiTelescope = \"M21.9,8.9L20.2,9.9L16.2,3L17.9,2L21.9,8.9M9.8,7.9L12.8,13.1L18.9,9.6L15.9,4.4L9.8,7.9M11.4,12.7L9.4,9.2L5.1,11.7L7.1,15.2L11.4,12.7M2.1,14.6L3.1,16.3L5.7,14.8L4.7,13.1L2.1,14.6M12.1,14L11.8,13.6L7.5,16.1L7.8,16.5C8,16.8 8.3,17.1 8.6,17.3L7,22H9L10.4,17.7H10.5L12,22H14L12.1,16.4C12.6,15.7 12.6,14.8 12.1,14Z\";\r\nvar mdiTelevision = \"M21,17H3V5H21M21,3H3A2,2 0 0,0 1,5V17A2,2 0 0,0 3,19H8V21H16V19H21A2,2 0 0,0 23,17V5A2,2 0 0,0 21,3Z\";\r\nvar mdiTelevisionAmbientLight = \"M3 11H0V9H3V11M3 14H0V16H3V14M5 5.12L2.88 3L1.46 4.41L3.59 6.54L5 5.12M10 5V2H8V5H10M24 9H21V11H24V9M16 5V2H14V5H16M20.41 6.54L22.54 4.42L21.12 3L19 5.12L20.41 6.54M24 14H21V16H24V14M19 9V16C19 17.1 18.1 18 17 18H15V20H9V18H7C5.9 18 5 17.1 5 16V9C5 7.9 5.9 7 7 7H17C18.1 7 19 7.9 19 9M17 9H7V16H17V9M19 19.88L21.12 22L22.54 20.59L20.41 18.47L19 19.88M3.59 18.46L1.47 20.59L2.88 22L5 19.88L3.59 18.46Z\";\r\nvar mdiTelevisionBox = \"M5,3H19A2,2 0 0,1 21,5V19A2,2 0 0,1 19,21H5A2,2 0 0,1 3,19V5A2,2 0 0,1 5,3M16,16L19,8H16.5L15,12.5L13.5,8H5V10H8V16H10V10H11.77L14,16H16Z\";\r\nvar mdiTelevisionClassic = \"M8.16,3L6.75,4.41L9.34,7H4C2.89,7 2,7.89 2,9V19C2,20.11 2.89,21 4,21H20C21.11,21 22,20.11 22,19V9C22,7.89 21.11,7 20,7H14.66L17.25,4.41L15.84,3L12,6.84L8.16,3M4,9H17V19H4V9M19.5,9A1,1 0 0,1 20.5,10A1,1 0 0,1 19.5,11A1,1 0 0,1 18.5,10A1,1 0 0,1 19.5,9M19.5,12A1,1 0 0,1 20.5,13A1,1 0 0,1 19.5,14A1,1 0 0,1 18.5,13A1,1 0 0,1 19.5,12Z\";\r\nvar mdiTelevisionClassicOff = \"M2,5.27L3.28,4L21,21.72L19.73,23L17.73,21H4C2.89,21 2,20.11 2,19V9C2,8 2.76,7.14 3.75,7L2,5.27M8.16,3L12,6.84L15.84,3L17.25,4.41L14.66,7H20C21.11,7 22,7.89 22,9V19C22,19.34 21.92,19.66 21.77,19.94L17,15.18V9H10.82L8.82,7H9.34L6.75,4.41L8.16,3M4,9V19H15.73L5.73,9H4M19.5,9A1,1 0 0,0 18.5,10A1,1 0 0,0 19.5,11A1,1 0 0,0 20.5,10A1,1 0 0,0 19.5,9M19.5,12A1,1 0 0,0 18.5,13A1,1 0 0,0 19.5,14A1,1 0 0,0 20.5,13A1,1 0 0,0 19.5,12Z\";\r\nvar mdiTelevisionClean = \"M21 17H3V5H21M21 3H3C1.9 3 1 3.9 1 5V17C1 18.11 1.9 19 3 19H8V21H16V19H21C22.11 19 23 18.11 23 17V5C23 3.9 22.11 3 21 3M15 6.5L14.38 7.87L13 8.5L14.38 9.13L15 10.5L15.63 9.13L17 8.5L15.63 7.87L15 6.5M10.5 8.5L9.41 10.91L7 12L9.41 13.09L10.5 15.5L11.6 13.09L14 12L11.6 10.91L10.5 8.5\";\r\nvar mdiTelevisionGuide = \"M21,17V5H3V17H21M21,3A2,2 0 0,1 23,5V17A2,2 0 0,1 21,19H16V21H8V19H3A2,2 0 0,1 1,17V5A2,2 0 0,1 3,3H21M5,7H11V11H5V7M5,13H11V15H5V13M13,7H19V9H13V7M13,11H19V15H13V11Z\";\r\nvar mdiTelevisionOff = \"M0.5,2.77L1.78,1.5L21,20.72L19.73,22L16.73,19H16V21H8V19H3A2,2 0 0,1 1,17V5C1,4.5 1.17,4.07 1.46,3.73L0.5,2.77M21,17V5H7.82L5.82,3H21A2,2 0 0,1 23,5V17C23,17.85 22.45,18.59 21.7,18.87L19.82,17H21M3,17H14.73L3,5.27V17Z\";\r\nvar mdiTelevisionPause = \"M3 3C1.89 3 1 3.89 1 5V17C1 18.1 1.9 19 3 19H8V21H16V19H21C22.1 19 23 18.1 23 17V5C23 3.89 22.1 3 21 3M3 5H21V17H3M9 8V14H11V8M13 8V14H15V8\";\r\nvar mdiTelevisionPlay = \"M21,3H3C1.89,3 1,3.89 1,5V17A2,2 0 0,0 3,19H8V21H16V19H21A2,2 0 0,0 23,17V5C23,3.89 22.1,3 21,3M21,17H3V5H21M16,11L9,15V7\";\r\nvar mdiTelevisionStop = \"M3 3H21C22.1 3 23 3.89 23 5V17C23 18.1 22.1 19 21 19H16V21H8V19H3C1.9 19 1 18.1 1 17V5C1 3.89 1.89 3 3 3M3 5V17H21V5H3M9 8H15V14H9V8Z\";\r\nvar mdiTemperatureCelsius = \"M16.5,5C18.05,5 19.5,5.47 20.69,6.28L19.53,9.17C18.73,8.44 17.67,8 16.5,8C14,8 12,10 12,12.5C12,15 14,17 16.5,17C17.53,17 18.47,16.66 19.23,16.08L20.37,18.93C19.24,19.61 17.92,20 16.5,20A7.5,7.5 0 0,1 9,12.5A7.5,7.5 0 0,1 16.5,5M6,3A3,3 0 0,1 9,6A3,3 0 0,1 6,9A3,3 0 0,1 3,6A3,3 0 0,1 6,3M6,5A1,1 0 0,0 5,6A1,1 0 0,0 6,7A1,1 0 0,0 7,6A1,1 0 0,0 6,5Z\";\r\nvar mdiTemperatureFahrenheit = \"M11,20V5H20V8H14V11H19V14H14V20H11M6,3A3,3 0 0,1 9,6A3,3 0 0,1 6,9A3,3 0 0,1 3,6A3,3 0 0,1 6,3M6,5A1,1 0 0,0 5,6A1,1 0 0,0 6,7A1,1 0 0,0 7,6A1,1 0 0,0 6,5Z\";\r\nvar mdiTemperatureKelvin = \"M7,5H10V11L15,5H19L13.88,10.78L19,20H15.38L11.76,13.17L10,15.15V20H7V5Z\";\r\nvar mdiTennis = \"M18,15A4,4 0 0,1 22,19A4,4 0 0,1 18,23A4,4 0 0,1 14,19A4,4 0 0,1 18,15M18,17A2,2 0 0,0 16,19A2,2 0 0,0 18,21A2,2 0 0,0 20,19A2,2 0 0,0 18,17M6.05,14.54C6.05,14.54 7.46,13.12 7.47,10.3C7.11,8.11 7.97,5.54 9.94,3.58C12.87,0.65 17.14,0.17 19.5,2.5C21.83,4.86 21.35,9.13 18.42,12.06C16.46,14.03 13.89,14.89 11.7,14.53C8.88,14.54 7.46,15.95 7.46,15.95L3.22,20.19L1.81,18.78L6.05,14.54M18.07,3.93C16.5,2.37 13.5,2.84 11.35,5C9.21,7.14 8.73,10.15 10.29,11.71C11.86,13.27 14.86,12.79 17,10.65C19.16,8.5 19.63,5.5 18.07,3.93Z\";\r\nvar mdiTennisBall = \"M12,2C14.5,2 16.75,2.9 18.5,4.4C16.36,6.23 15,8.96 15,12C15,15.04 16.36,17.77 18.5,19.6C16.75,21.1 14.5,22 12,22C9.5,22 7.25,21.1 5.5,19.6C7.64,17.77 9,15.04 9,12C9,8.96 7.64,6.23 5.5,4.4C7.25,2.9 9.5,2 12,2M22,12C22,14.32 21.21,16.45 19.88,18.15C18.12,16.68 17,14.47 17,12C17,9.53 18.12,7.32 19.88,5.85C21.21,7.55 22,9.68 22,12M2,12C2,9.68 2.79,7.55 4.12,5.85C5.88,7.32 7,9.53 7,12C7,14.47 5.88,16.68 4.12,18.15C2.79,16.45 2,14.32 2,12Z\";\r\nvar mdiTent = \"M4,6C4,7.19 4.39,8.27 5,9A3,3 0 0,1 2,6A3,3 0 0,1 5,3C4.39,3.73 4,4.81 4,6M2,21V19H4.76L12,4.78L19.24,19H22V21H2M12,9.19L7,19H17L12,9.19Z\";\r\nvar mdiTerraform = \"M21 5.4V11.8L15.4 15V8.7L21 5.4M14.8 8.7V15L9.2 11.8V5.4L14.8 8.7M14.8 15.7V22.1L9.2 18.9V12.5L14.8 15.7M8.6 5.1V11.5L3 8.3V1.9L8.6 5.1Z\";\r\nvar mdiTerrain = \"M14,6L10.25,11L13.1,14.8L11.5,16C9.81,13.75 7,10 7,10L1,18H23L14,6Z\";\r\nvar mdiTestTube = \"M7,2V4H8V18A4,4 0 0,0 12,22A4,4 0 0,0 16,18V4H17V2H7M11,16C10.4,16 10,15.6 10,15C10,14.4 10.4,14 11,14C11.6,14 12,14.4 12,15C12,15.6 11.6,16 11,16M13,12C12.4,12 12,11.6 12,11C12,10.4 12.4,10 13,10C13.6,10 14,10.4 14,11C14,11.6 13.6,12 13,12M14,7H10V4H14V7Z\";\r\nvar mdiTestTubeEmpty = \"M7,2H17V4H16V18A4,4 0 0,1 12,22A4,4 0 0,1 8,18V4H7V2M14,4H10V18A2,2 0 0,0 12,20A2,2 0 0,0 14,18V4Z\";\r\nvar mdiTestTubeOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L15.84,19.11C15.36,20.77 13.82,22 12,22A4,4 0 0,1 8,18V11.27L2,5.27M7,2H17V4H16V14.18L13.63,11.81C13.86,11.63 14,11.35 14,11C14,10.4 13.6,10 13,10C12.65,10 12.37,10.14 12.19,10.37L8,6.18V4H7V2M11,16C11.5,16 11.88,15.71 12,15.24L10.76,14C10.29,14.12 10,14.5 10,15C10,15.6 10.4,16 11,16M14,7V4H10V7H14Z\";\r\nvar mdiText = \"M21,6V8H3V6H21M3,18H12V16H3V18M3,13H21V11H3V13Z\";\r\nvar mdiTextAccount = \"M21 5V7H3V5H21M3 17H12V15H3V17M3 12H21V10H3V12M18 14C19.11 14 20 14.9 20 16S19.11 18 18 18 16 17.11 16 16 16.9 14 18 14M14 22V21C14 19.9 15.79 19 18 19S22 19.9 22 21V22H14Z\";\r\nvar mdiTextBox = \"M14,17H7V15H14M17,13H7V11H17M17,9H7V7H17M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiTextBoxCheck = \"M17,21L14.25,18L15.41,16.84L17,18.43L20.59,14.84L21.75,16.25M12.8,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19A2,2 0 0,1 21,5V12.8C20.12,12.29 19.09,12 18,12L17,12.08V11H7V13H14.69C13.07,14.07 12,15.91 12,18C12,19.09 12.29,20.12 12.8,21M12,15H7V17H12M17,7H7V9H17\";\r\nvar mdiTextBoxCheckOutline = \"M17,21L14.25,18L15.41,16.84L17,18.43L20.59,14.84L21.75,16.25M12.8,21H5C3.89,21 3,20.11 3,19V5C3,3.89 3.89,3 5,3H19C20.11,3 21,3.89 21,5V12.8C20.39,12.45 19.72,12.2 19,12.08V5H5V19H12.08C12.2,19.72 12.45,20.39 12.8,21M12,17H7V15H12M14.68,13H7V11H17V12.08C16.15,12.22 15.37,12.54 14.68,13M17,9H7V7H17\";\r\nvar mdiTextBoxMinus = \"M22,17V19H14V17H22M12,17V15H7V17H12M17,11H7V13H14.69C13.07,14.07 12,15.91 12,18C12,19.09 12.29,20.12 12.8,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19A2,2 0 0,1 21,5V12.8C20.12,12.29 19.09,12 18,12L17,12.08V11M17,9V7H7V9H17Z\";\r\nvar mdiTextBoxMinusOutline = \"M22,17V19H14V17H22M5,3H19C20.11,3 21,3.89 21,5V12.8C20.39,12.45 19.72,12.2 19,12.08V5H5V19H12.08C12.2,19.72 12.45,20.39 12.8,21H5C3.89,21 3,20.11 3,19V5C3,3.89 3.89,3 5,3M7,7H17V9H7V7M7,11H17V12.08C16.15,12.22 15.37,12.54 14.68,13H7V11M7,15H12V17H7V15Z\";\r\nvar mdiTextBoxMultiple = \"M16,15H9V13H16M19,11H9V9H19M19,7H9V5H19M21,1H7C5.89,1 5,1.89 5,3V17C5,18.11 5.9,19 7,19H21C22.11,19 23,18.11 23,17V3C23,1.89 22.1,1 21,1M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3Z\";\r\nvar mdiTextBoxMultipleOutline = \"M16,15H9V13H16V15M19,11H9V9H19V11M19,7H9V5H19V7M3,5V21H19V23H3A2,2 0 0,1 1,21V5H3M21,1A2,2 0 0,1 23,3V17C23,18.11 22.11,19 21,19H7A2,2 0 0,1 5,17V3C5,1.89 5.89,1 7,1H21M7,3V17H21V3H7Z\";\r\nvar mdiTextBoxOutline = \"M5,3C3.89,3 3,3.89 3,5V19C3,20.11 3.89,21 5,21H19C20.11,21 21,20.11 21,19V5C21,3.89 20.11,3 19,3H5M5,5H19V19H5V5M7,7V9H17V7H7M7,11V13H17V11H7M7,15V17H14V15H7Z\";\r\nvar mdiTextBoxPlus = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M12,17V15H7V17H12M17,11H7V13H14.69C13.07,14.07 12,15.91 12,18C12,19.09 12.29,20.12 12.8,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19A2,2 0 0,1 21,5V12.8C20.12,12.29 19.09,12 18,12L17,12.08V11M17,9V7H7V9H17Z\";\r\nvar mdiTextBoxPlusOutline = \"M17,14H19V17H22V19H19V22H17V19H14V17H17V14M5,3H19C20.11,3 21,3.89 21,5V12.8C20.39,12.45 19.72,12.2 19,12.08V5H5V19H12.08C12.2,19.72 12.45,20.39 12.8,21H5C3.89,21 3,20.11 3,19V5C3,3.89 3.89,3 5,3M7,7H17V9H7V7M7,11H17V12.08C16.15,12.22 15.37,12.54 14.68,13H7V11M7,15H12V17H7V15Z\";\r\nvar mdiTextBoxRemove = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M12,17V15H7V17H12M17,11H7V13H14.69C13.07,14.07 12,15.91 12,18C12,19.09 12.29,20.12 12.8,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19A2,2 0 0,1 21,5V12.8C20.12,12.29 19.09,12 18,12L17,12.08V11M17,9V7H7V9H17Z\";\r\nvar mdiTextBoxRemoveOutline = \"M14.46,15.88L15.88,14.46L18,16.59L20.12,14.46L21.54,15.88L19.41,18L21.54,20.12L20.12,21.54L18,19.41L15.88,21.54L14.46,20.12L16.59,18L14.46,15.88M5,3H19C20.11,3 21,3.89 21,5V12.8C20.39,12.45 19.72,12.2 19,12.08V5H5V19H12.08C12.2,19.72 12.45,20.39 12.8,21H5C3.89,21 3,20.11 3,19V5C3,3.89 3.89,3 5,3M7,7H17V9H7V7M7,11H17V12.08C16.15,12.22 15.37,12.54 14.68,13H7V11M7,15H12V17H7V15Z\";\r\nvar mdiTextBoxSearch = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M7,15V17H9C9.14,18.55 9.8,19.94 10.81,21H5C3.89,21 3,20.1 3,19V5C3,3.89 3.89,3 5,3H19A2,2 0 0,1 21,5V13.03C19.85,11.21 17.82,10 15.5,10C14.23,10 13.04,10.37 12.04,11H7V13H10C9.64,13.6 9.34,14.28 9.17,15H7M17,9V7H7V9H17Z\";\r\nvar mdiTextBoxSearchOutline = \"M15.5,12C18,12 20,14 20,16.5C20,17.38 19.75,18.21 19.31,18.9L22.39,22L21,23.39L17.88,20.32C17.19,20.75 16.37,21 15.5,21C13,21 11,19 11,16.5C11,14 13,12 15.5,12M15.5,14A2.5,2.5 0 0,0 13,16.5A2.5,2.5 0 0,0 15.5,19A2.5,2.5 0 0,0 18,16.5A2.5,2.5 0 0,0 15.5,14M5,3H19C20.11,3 21,3.89 21,5V13.03C20.5,12.23 19.81,11.54 19,11V5H5V19H9.5C9.81,19.75 10.26,20.42 10.81,21H5C3.89,21 3,20.11 3,19V5C3,3.89 3.89,3 5,3M7,7H17V9H7V7M7,11H12.03C11.23,11.5 10.54,12.19 10,13H7V11M7,15H9.17C9.06,15.5 9,16 9,16.5V17H7V15Z\";\r\nvar mdiTextRecognition = \"M2 4C2 2.9 2.9 2 4 2H8V4H4V8H2V4M22 20C22 21.11 21.11 22 20 22H16V20H20V16H22V20M4 22C2.9 22 2 21.11 2 20V16H4V20H8V22H4M20 2C21.11 2 22 2.9 22 4V8H20V4H16V2H20M9 7V9H11V17H13V9H15V7H9Z\";\r\nvar mdiTextSearch = \"M19.31 18.9L22.39 22L21 23.39L17.88 20.32C17.19 20.75 16.37 21 15.5 21C13 21 11 19 11 16.5C11 14 13 12 15.5 12C18 12 20 14 20 16.5C20 17.38 19.75 18.21 19.31 18.9M15.5 19C16.88 19 18 17.88 18 16.5C18 15.12 16.88 14 15.5 14C14.12 14 13 15.12 13 16.5C13 17.88 14.12 19 15.5 19M21 4V6H3V4H21M3 16V14H9V16H3M3 11V9H21V11H18.97C17.96 10.37 16.77 10 15.5 10C14.23 10 13.04 10.37 12.03 11H3Z\";\r\nvar mdiTextShadow = \"M3,3H16V6H11V18H8V6H3V3M12,7H14V9H12V7M15,7H17V9H15V7M18,7H20V9H18V7M12,10H14V12H12V10M12,13H14V15H12V13M12,16H14V18H12V16M12,19H14V21H12V19Z\";\r\nvar mdiTextShort = \"M4,9H20V11H4V9M4,13H14V15H4V13Z\";\r\nvar mdiTextSubject = \"M4,5H20V7H4V5M4,9H20V11H4V9M4,13H20V15H4V13M4,17H14V19H4V17Z\";\r\nvar mdiTextToSpeech = \"M8,7A2,2 0 0,1 10,9V14A2,2 0 0,1 8,16A2,2 0 0,1 6,14V9A2,2 0 0,1 8,7M14,14C14,16.97 11.84,19.44 9,19.92V22H7V19.92C4.16,19.44 2,16.97 2,14H4A4,4 0 0,0 8,18A4,4 0 0,0 12,14H14M21.41,9.41L17.17,13.66L18.18,10H14A2,2 0 0,1 12,8V4A2,2 0 0,1 14,2H20A2,2 0 0,1 22,4V8C22,8.55 21.78,9.05 21.41,9.41Z\";\r\nvar mdiTextToSpeechOff = \"M2,5.27L3.28,4L20,20.72L18.73,22L13.38,16.65C12.55,18.35 10.93,19.59 9,19.92V22H7V19.92C4.16,19.44 2,16.97 2,14H4A4,4 0 0,0 8,18C9.82,18 11.36,16.78 11.84,15.11L10,13.27V14A2,2 0 0,1 8,16A2,2 0 0,1 6,14V9.27L2,5.27M21.41,9.41L17.17,13.66L18.18,10H14A2,2 0 0,1 12,8V4A2,2 0 0,1 14,2H20A2,2 0 0,1 22,4V8C22,8.55 21.78,9.05 21.41,9.41Z\";\r\nvar mdiTexture = \"M9.29,21H12.12L21,12.12V9.29M19,21C19.55,21 20.05,20.78 20.41,20.41C20.78,20.05 21,19.55 21,19V17L17,21M5,3A2,2 0 0,0 3,5V7L7,3M11.88,3L3,11.88V14.71L14.71,3M19.5,3.08L3.08,19.5C3.17,19.85 3.35,20.16 3.59,20.41C3.84,20.65 4.15,20.83 4.5,20.92L20.93,4.5C20.74,3.8 20.2,3.26 19.5,3.08Z\";\r\nvar mdiTextureBox = \"M20 2H4C2.9 2 2 2.9 2 4V20C2 21.11 2.9 22 4 22H20C21.11 22 22 21.11 22 20V4C22 2.9 21.11 2 20 2M4 6L6 4H10.9L4 10.9V6M4 13.7L13.7 4H18.6L4 18.6V13.7M20 18L18 20H13.1L20 13.1V18M20 10.3L10.3 20H5.4L20 5.4V10.3Z\";\r\nvar mdiTheater = \"M4,15H6A2,2 0 0,1 8,17V19H9V17A2,2 0 0,1 11,15H13A2,2 0 0,1 15,17V19H16V17A2,2 0 0,1 18,15H20A2,2 0 0,1 22,17V19H23V22H1V19H2V17A2,2 0 0,1 4,15M11,7L15,10L11,13V7M4,2H20A2,2 0 0,1 22,4V13.54C21.41,13.19 20.73,13 20,13V4H4V13C3.27,13 2.59,13.19 2,13.54V4A2,2 0 0,1 4,2Z\";\r\nvar mdiThemeLightDark = \"M7.5,2C5.71,3.15 4.5,5.18 4.5,7.5C4.5,9.82 5.71,11.85 7.53,13C4.46,13 2,10.54 2,7.5A5.5,5.5 0 0,1 7.5,2M19.07,3.5L20.5,4.93L4.93,20.5L3.5,19.07L19.07,3.5M12.89,5.93L11.41,5L9.97,6L10.39,4.3L9,3.24L10.75,3.12L11.33,1.47L12,3.1L13.73,3.13L12.38,4.26L12.89,5.93M9.59,9.54L8.43,8.81L7.31,9.59L7.65,8.27L6.56,7.44L7.92,7.35L8.37,6.06L8.88,7.33L10.24,7.36L9.19,8.23L9.59,9.54M19,13.5A5.5,5.5 0 0,1 13.5,19C12.28,19 11.15,18.6 10.24,17.93L17.93,10.24C18.6,11.15 19,12.28 19,13.5M14.6,20.08L17.37,18.93L17.13,22.28L14.6,20.08M18.93,17.38L20.08,14.61L22.28,17.15L18.93,17.38M20.08,12.42L18.94,9.64L22.28,9.88L20.08,12.42M9.63,18.93L12.4,20.08L9.87,22.27L9.63,18.93Z\";\r\nvar mdiThermometer = \"M15 13V5A3 3 0 0 0 9 5V13A5 5 0 1 0 15 13M12 4A1 1 0 0 1 13 5V8H11V5A1 1 0 0 1 12 4Z\";\r\nvar mdiThermometerAlert = \"M17 13V7H19V13H17M17 17V15H19V17H17M13 13V5C13 3.3 11.7 2 10 2S7 3.3 7 5V13C4.8 14.7 4.3 17.8 6 20S10.8 22.7 13 21 15.7 16.2 14 14C13.7 13.6 13.4 13.3 13 13M10 4C10.6 4 11 4.4 11 5V8H9V5C9 4.4 9.4 4 10 4Z\";\r\nvar mdiThermometerChevronDown = \"M17.41 12.17L14.24 9L12.83 10.41L17.41 15L22 10.41L20.58 9M10 13V5C10 3.34 8.66 2 7 2S4 3.34 4 5V13C1.79 14.66 1.34 17.79 3 20S7.79 22.66 10 21 12.66 16.21 11 14C10.72 13.62 10.38 13.28 10 13M7 4C7.55 4 8 4.45 8 5V8H6V5C6 4.45 6.45 4 7 4Z\";\r\nvar mdiThermometerChevronUp = \"M17.41 11.83L20.58 15L22 13.59L17.41 9L12.82 13.59L14.24 15L17.41 11.83M10 13V5C10 3.34 8.66 2 7 2S4 3.34 4 5V13C1.79 14.66 1.34 17.79 3 20S7.79 22.66 10 21 12.66 16.21 11 14C10.72 13.62 10.38 13.28 10 13M7 4C7.55 4 8 4.45 8 5V8H6V5C6 4.45 6.45 4 7 4Z\";\r\nvar mdiThermometerHigh = \"M15 13V5A3 3 0 0 0 9 5V13A5 5 0 1 0 15 13M12 4A1 1 0 0 1 13 5H11A1 1 0 0 1 12 4Z\";\r\nvar mdiThermometerLines = \"M17 3H21V5H17V3M17 7H21V9H17V7M17 11H21V13H17.75L17 12.1V11M21 15V17H19C19 16.31 18.9 15.63 18.71 15H21M7 3V5H3V3H7M7 7V9H3V7H7M7 11V12.1L6.25 13H3V11H7M3 15H5.29C5.1 15.63 5 16.31 5 17H3V15M15 13V5C15 3.34 13.66 2 12 2S9 3.34 9 5V13C6.79 14.66 6.34 17.79 8 20S12.79 22.66 15 21 17.66 16.21 16 14C15.72 13.62 15.38 13.28 15 13M12 4C12.55 4 13 4.45 13 5V8H11V5C11 4.45 11.45 4 12 4Z\";\r\nvar mdiThermometerLow = \"M15 13V5A3 3 0 0 0 9 5V13A5 5 0 1 0 15 13M12 4A1 1 0 0 1 13 5V12H11V5A1 1 0 0 1 12 4Z\";\r\nvar mdiThermometerMinus = \"M22 11H14V13H22V11M11 13V5C11 3.34 9.66 2 8 2S5 3.34 5 5V13C2.79 14.66 2.34 17.79 4 20S8.79 22.66 11 21 13.66 16.21 12 14C11.72 13.62 11.38 13.28 11 13M8 4C8.55 4 9 4.45 9 5V8H7V5C7 4.45 7.45 4 8 4Z\";\r\nvar mdiThermometerOff = \"M11 7.8L9 5.8V5C9 3.34 10.34 2 12 2S15 3.34 15 5V11.8L11.2 8H13V5C13 4.45 12.55 4 12 4S11 4.45 11 5V7.8M22.11 21.46L2.39 1.73L1.11 3L9 10.89V13C6.79 14.66 6.34 17.79 8 20C9.66 22.21 12.79 22.66 15 21C15.84 20.37 16.4 19.5 16.71 18.6L20.84 22.73L22.11 21.46Z\";\r\nvar mdiThermometerPlus = \"M19 11V8H17V11H14V13H17V16H19V13H22V11M11 13V5C11 3.34 9.66 2 8 2S5 3.34 5 5V13C2.79 14.66 2.34 17.79 4 20S8.79 22.66 11 21 13.66 16.21 12 14C11.72 13.62 11.38 13.28 11 13M8 4C8.55 4 9 4.45 9 5V8H7V5C7 4.45 7.45 4 8 4Z\";\r\nvar mdiThermostat = \"M16.95,16.95L14.83,14.83C15.55,14.1 16,13.1 16,12C16,11.26 15.79,10.57 15.43,10L17.6,7.81C18.5,9 19,10.43 19,12C19,13.93 18.22,15.68 16.95,16.95M12,5C13.57,5 15,5.5 16.19,6.4L14,8.56C13.43,8.21 12.74,8 12,8A4,4 0 0,0 8,12C8,13.1 8.45,14.1 9.17,14.83L7.05,16.95C5.78,15.68 5,13.93 5,12A7,7 0 0,1 12,5M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12C22,6.47 17.5,2 12,2Z\";\r\nvar mdiThermostatBox = \"M5,3A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3H5M12,5C13.57,5 15,5.5 16.19,6.4L14,8.56C13.43,8.21 12.74,8 12,8A4,4 0 0,0 8,12C8,13.1 8.45,14.1 9.17,14.83L7.05,16.95C5.78,15.68 5,13.93 5,12A7,7 0 0,1 12,5M17.6,7.81C18.5,9 19,10.43 19,12C19,13.93 18.22,15.68 16.95,16.95L14.83,14.83C15.55,14.1 16,13.1 16,12C16,11.26 15.79,10.57 15.43,10L17.6,7.81Z\";\r\nvar mdiThoughtBubble = \"M3.5,19A1.5,1.5 0 0,1 5,20.5A1.5,1.5 0 0,1 3.5,22A1.5,1.5 0 0,1 2,20.5A1.5,1.5 0 0,1 3.5,19M8.5,16A2.5,2.5 0 0,1 11,18.5A2.5,2.5 0 0,1 8.5,21A2.5,2.5 0 0,1 6,18.5A2.5,2.5 0 0,1 8.5,16M14.5,15C13.31,15 12.23,14.5 11.5,13.65C10.77,14.5 9.69,15 8.5,15C6.54,15 4.91,13.59 4.57,11.74C3.07,11.16 2,9.7 2,8A4,4 0 0,1 6,4C6.26,4 6.5,4.03 6.77,4.07C7.5,3.41 8.45,3 9.5,3C10.69,3 11.77,3.5 12.5,4.35C13.23,3.5 14.31,3 15.5,3C17.46,3 19.09,4.41 19.43,6.26C20.93,6.84 22,8.3 22,10A4,4 0 0,1 18,14L17.23,13.93C16.5,14.59 15.55,15 14.5,15Z\";\r\nvar mdiThoughtBubbleOutline = \"M3.5,19A1.5,1.5 0 0,1 5,20.5A1.5,1.5 0 0,1 3.5,22A1.5,1.5 0 0,1 2,20.5A1.5,1.5 0 0,1 3.5,19M8.5,16A2.5,2.5 0 0,1 11,18.5A2.5,2.5 0 0,1 8.5,21A2.5,2.5 0 0,1 6,18.5A2.5,2.5 0 0,1 8.5,16M14.5,15C13.31,15 12.23,14.5 11.5,13.65C10.77,14.5 9.69,15 8.5,15C6.54,15 4.91,13.59 4.57,11.74C3.07,11.16 2,9.7 2,8A4,4 0 0,1 6,4L6.77,4.07C7.5,3.41 8.45,3 9.5,3C10.69,3 11.77,3.5 12.5,4.35C13.23,3.5 14.31,3 15.5,3C17.46,3 19.09,4.41 19.43,6.26C20.93,6.84 22,8.3 22,10A4,4 0 0,1 18,14L17.23,13.93C16.5,14.59 15.55,15 14.5,15M6,6A2,2 0 0,0 4,8A2,2 0 0,0 6,10C6.33,10 6.64,9.92 6.92,9.78C6.66,10.12 6.5,10.54 6.5,11A2,2 0 0,0 8.5,13C9.1,13 9.64,12.73 10,12.31V12.31L11.47,10.63L13,12.34V12.34C13.38,12.74 13.91,13 14.5,13C15.5,13 16.33,12.26 16.5,11.3C16.84,11.73 17.39,12 18,12A2,2 0 0,0 20,10A2,2 0 0,0 18,8C17.67,8 17.36,8.08 17.08,8.22C17.34,7.88 17.5,7.46 17.5,7A2,2 0 0,0 15.5,5C14.91,5 14.38,5.26 14,5.66L12.47,7.37L11,5.69V5.69C10.64,5.27 10.1,5 9.5,5C8.5,5 7.67,5.74 7.5,6.7C7.16,6.27 6.61,6 6,6M8.5,17.5A1,1 0 0,0 7.5,18.5A1,1 0 0,0 8.5,19.5A1,1 0 0,0 9.5,18.5A1,1 0 0,0 8.5,17.5Z\";\r\nvar mdiThumbDown = \"M19,15H23V3H19M15,3H6C5.17,3 4.46,3.5 4.16,4.22L1.14,11.27C1.05,11.5 1,11.74 1,12V14A2,2 0 0,0 3,16H9.31L8.36,20.57C8.34,20.67 8.33,20.77 8.33,20.88C8.33,21.3 8.5,21.67 8.77,21.94L9.83,23L16.41,16.41C16.78,16.05 17,15.55 17,15V5C17,3.89 16.1,3 15,3Z\";\r\nvar mdiThumbDownOutline = \"M19,15V3H23V15H19M15,3A2,2 0 0,1 17,5V15C17,15.55 16.78,16.05 16.41,16.41L9.83,23L8.77,21.94C8.5,21.67 8.33,21.3 8.33,20.88L8.36,20.57L9.31,16H3C1.89,16 1,15.1 1,14V12C1,11.74 1.05,11.5 1.14,11.27L4.16,4.22C4.46,3.5 5.17,3 6,3H15M15,5H5.97L3,12V14H11.78L10.65,19.32L15,14.97V5Z\";\r\nvar mdiThumbUp = \"M23,10C23,8.89 22.1,8 21,8H14.68L15.64,3.43C15.66,3.33 15.67,3.22 15.67,3.11C15.67,2.7 15.5,2.32 15.23,2.05L14.17,1L7.59,7.58C7.22,7.95 7,8.45 7,9V19A2,2 0 0,0 9,21H18C18.83,21 19.54,20.5 19.84,19.78L22.86,12.73C22.95,12.5 23,12.26 23,12V10M1,21H5V9H1V21Z\";\r\nvar mdiThumbUpOutline = \"M5,9V21H1V9H5M9,21A2,2 0 0,1 7,19V9C7,8.45 7.22,7.95 7.59,7.59L14.17,1L15.23,2.06C15.5,2.33 15.67,2.7 15.67,3.11L15.64,3.43L14.69,8H21C22.11,8 23,8.9 23,10V12C23,12.26 22.95,12.5 22.86,12.73L19.84,19.78C19.54,20.5 18.83,21 18,21H9M9,19H18.03L21,12V10H12.21L13.34,4.68L9,9.03V19Z\";\r\nvar mdiThumbsUpDown = \"M22.5,10H15.75C15.13,10 14.6,10.38 14.37,10.91L12.11,16.2C12.04,16.37 12,16.56 12,16.75V18A1,1 0 0,0 13,19H18.18L17.5,22.18V22.42C17.5,22.73 17.63,23 17.83,23.22L18.62,24L23.56,19.06C23.83,18.79 24,18.41 24,18V11.5A1.5,1.5 0 0,0 22.5,10M12,6A1,1 0 0,0 11,5H5.82L6.5,1.82V1.59C6.5,1.28 6.37,1 6.17,0.79L5.38,0L0.44,4.94C0.17,5.21 0,5.59 0,6V12.5A1.5,1.5 0 0,0 1.5,14H8.25C8.87,14 9.4,13.62 9.63,13.09L11.89,7.8C11.96,7.63 12,7.44 12,7.25V6Z\";\r\nvar mdiTicket = \"M15.58,16.8L12,14.5L8.42,16.8L9.5,12.68L6.21,10L10.46,9.74L12,5.8L13.54,9.74L17.79,10L14.5,12.68M20,12C20,10.89 20.9,10 22,10V6C22,4.89 21.1,4 20,4H4A2,2 0 0,0 2,6V10C3.11,10 4,10.9 4,12A2,2 0 0,1 2,14V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V14A2,2 0 0,1 20,12Z\";\r\nvar mdiTicketAccount = \"M20,12A2,2 0 0,0 22,14V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V14C3.11,14 4,13.1 4,12A2,2 0 0,0 2,10V6C2,4.89 2.9,4 4,4H20A2,2 0 0,1 22,6V10A2,2 0 0,0 20,12M16.5,16.25C16.5,14.75 13.5,14 12,14C10.5,14 7.5,14.75 7.5,16.25V17H16.5V16.25M12,12.25A2.25,2.25 0 0,0 14.25,10A2.25,2.25 0 0,0 12,7.75A2.25,2.25 0 0,0 9.75,10A2.25,2.25 0 0,0 12,12.25Z\";\r\nvar mdiTicketConfirmation = \"M13,8.5H11V6.5H13V8.5M13,13H11V11H13V13M13,17.5H11V15.5H13V17.5M22,10V6C22,4.89 21.1,4 20,4H4A2,2 0 0,0 2,6V10C3.11,10 4,10.9 4,12A2,2 0 0,1 2,14V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V14A2,2 0 0,1 20,12A2,2 0 0,1 22,10Z\";\r\nvar mdiTicketConfirmationOutline = \"M22 10V6C22 4.89 21.1 4 20 4H4C2.9 4 2 4.89 2 6V10C3.11 10 4 10.9 4 12S3.11 14 2 14V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V14C20.9 14 20 13.1 20 12S20.9 10 22 10M20 8.54C18.81 9.23 18 10.53 18 12S18.81 14.77 20 15.46V18H4V15.46C5.19 14.77 6 13.47 6 12C6 10.5 5.2 9.23 4 8.54L4 6H20V8.54M11 15H13V17H11M11 11H13V13H11M11 7H13V9H11Z\";\r\nvar mdiTicketOutline = \"M4,4A2,2 0 0,0 2,6V10A2,2 0 0,1 4,12A2,2 0 0,1 2,14V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V14A2,2 0 0,1 20,12A2,2 0 0,1 22,10V6A2,2 0 0,0 20,4H4M4,6H20V8.54C18.76,9.25 18,10.57 18,12C18,13.43 18.76,14.75 20,15.46V18H4V15.46C5.24,14.75 6,13.43 6,12C6,10.57 5.24,9.25 4,8.54V6Z\";\r\nvar mdiTicketPercent = \"M4,4A2,2 0 0,0 2,6V10C3.11,10 4,10.9 4,12A2,2 0 0,1 2,14V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V14A2,2 0 0,1 20,12C20,10.89 20.9,10 22,10V6C22,4.89 21.1,4 20,4H4M15.5,7L17,8.5L8.5,17L7,15.5L15.5,7M8.81,7.04C9.79,7.04 10.58,7.83 10.58,8.81A1.77,1.77 0 0,1 8.81,10.58C7.83,10.58 7.04,9.79 7.04,8.81A1.77,1.77 0 0,1 8.81,7.04M15.19,13.42C16.17,13.42 16.96,14.21 16.96,15.19A1.77,1.77 0 0,1 15.19,16.96C14.21,16.96 13.42,16.17 13.42,15.19A1.77,1.77 0 0,1 15.19,13.42Z\";\r\nvar mdiTicketPercentOutline = \"M14.8 8L16 9.2L9.2 16L8 14.8L14.8 8M4 4H20C21.11 4 22 4.89 22 6V10C20.9 10 20 10.9 20 12C20 13.11 20.9 14 22 14V18C22 19.11 21.11 20 20 20H4C2.9 20 2 19.11 2 18V14C3.11 14 4 13.11 4 12C4 10.9 3.11 10 2 10V6C2 4.89 2.9 4 4 4M4 6V8.54C5.24 9.26 6 10.57 6 12C6 13.43 5.24 14.75 4 15.46V18H20V15.46C18.76 14.75 18 13.43 18 12C18 10.57 18.76 9.26 20 8.54V6H4M9.5 8C10.33 8 11 8.67 11 9.5C11 10.33 10.33 11 9.5 11C8.67 11 8 10.33 8 9.5C8 8.67 8.67 8 9.5 8M14.5 13C15.33 13 16 13.67 16 14.5C16 15.33 15.33 16 14.5 16C13.67 16 13 15.33 13 14.5C13 13.67 13.67 13 14.5 13Z\";\r\nvar mdiTie = \"M6,2L10,6L7,17L12,22L17,17L14,6L18,2Z\";\r\nvar mdiTilde = \"M2,15C2,15 2,9 8,9C12,9 12.5,12.5 15.5,12.5C19.5,12.5 19.5,9 19.5,9H22C22,9 22,15 16,15C12,15 10.5,11.5 8.5,11.5C4.5,11.5 4.5,15 4.5,15H2\";\r\nvar mdiTimelapse = \"M12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4A8,8 0 0,1 20,12A8,8 0 0,1 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2M16.24,7.76C15.07,6.58 13.53,6 12,6V12L7.76,16.24C10.1,18.58 13.9,18.58 16.24,16.24C18.59,13.9 18.59,10.1 16.24,7.76Z\";\r\nvar mdiTimeline = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6Z\";\r\nvar mdiTimelineAlert = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M15 7V13H17V7H15M15 15V17H17V15H15Z\";\r\nvar mdiTimelineAlertOutline = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M10 6V18H22V6H10M15 7H17V13H15V7M15 15H17V17H15V15Z\";\r\nvar mdiTimelineCheck = \"M4 8H2V2H4V8M2 22H4V16H2V22M3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12C5 10.9 4.11 10 3 10M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M19.75 10.33L18.59 8.92L15 12.5L13.41 10.92L12.25 12.08L15 15.08L19.75 10.33Z\";\r\nvar mdiTimelineCheckOutline = \"M22 4H10C8.9 4 8 4.89 8 6V10L6 12L8 14V18C8 19.11 8.9 20 10 20H22C23.11 20 24 19.11 24 18V6C24 4.89 23.11 4 22 4M22 18H10V6H22V18M4 8H2V2H4V8M2 16H4V22H2V16M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M15 15.08L12.25 12.08L13.41 10.92L15 12.5L18.59 8.92L19.75 10.33L15 15.08Z\";\r\nvar mdiTimelineClock = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M16 4C20.42 4 24 7.58 24 12C24 16.42 20.42 20 16 20C12.4 20 9.36 17.62 8.35 14.35L6 12L8.35 9.65C9.36 6.38 12.4 4 16 4M15 13L19.53 15.79L20.33 14.5L16.5 12.2V7H15V13Z\";\r\nvar mdiTimelineClockOutline = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M16 4C20.42 4 24 7.58 24 12C24 16.42 20.42 20 16 20C12.4 20 9.36 17.62 8.35 14.35L6 12L8.35 9.65C9.36 6.38 12.4 4 16 4M16 6C12.69 6 10 8.69 10 12C10 15.31 12.69 18 16 18C19.31 18 22 15.31 22 12C22 8.69 19.31 6 16 6M15 13V8H16.5V12.2L19.5 14L18.68 15.26L15 13Z\";\r\nvar mdiTimelineHelp = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M16.5 15.5H15V17H16.5V15.5M14.5 10.5V10C14.5 9.17 15.17 8.5 16 8.5C16.83 8.5 17.5 9.18 17.5 10C17.5 10.47 17.27 10.9 16.88 11.16L16.59 11.35C15.6 12 15 13.11 15 14.3V14.5H16.5V14.3C16.5 13.62 16.84 13 17.41 12.6L17.71 12.41C18.5 11.88 19 10.97 19 10C19 8.34 17.66 7 16 7C14.34 7 13 8.34 13 10V10.5H14.5Z\";\r\nvar mdiTimelineHelpOutline = \"M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M4 2V8H2V2H4M2 22V16H4V22H2M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M22 6H10V10.83L8.83 12L10 13.17V18H22V6M16.5 15.5V17H15V15.5H16.5M14.5 10.5H13V10C13 8.34 14.34 7 16 7C17.66 7 19 8.34 19 10C19 10.97 18.5 11.88 17.71 12.41L17.41 12.6C16.84 13 16.5 13.62 16.5 14.3V14.5H15V14.3C15 13.11 15.6 12 16.59 11.35L16.88 11.16C17.27 10.9 17.5 10.47 17.5 10C17.5 9.18 16.83 8.5 16 8.5C15.17 8.5 14.5 9.17 14.5 10V10.5Z\";\r\nvar mdiTimelineMinus = \"M4 8H2V2H4V8M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M20 11H12V13H20V11M2 22H4V16H2V22M3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12C5 10.9 4.11 10 3 10Z\";\r\nvar mdiTimelineMinusOutline = \"M2 16H4V22H2V16M4 2H2V8H4V2M20 11H12V13H20V11M3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12C5 10.9 4.11 10 3 10M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M22 6H10V18H22V6Z\";\r\nvar mdiTimelineOutline = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M10 6V18H22V6H10Z\";\r\nvar mdiTimelinePlus = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M20 11H17V8H15V11H12V13H15V16H17V13H20V11Z\";\r\nvar mdiTimelinePlusOutline = \"M4 2V8H2V2H4M2 22V16H4V22H2M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M20 11V13H17V16H15V13H12V11H15V8H17V11H20M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M10 6V18H22V6H10Z\";\r\nvar mdiTimelineRemove = \"M4 8H2V2H4V8M2 22H4V16H2V22M3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12C5 10.9 4.11 10 3 10M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M17.41 12L19.53 9.88L18.12 8.47L16 10.59L13.88 8.47L12.47 9.88L14.59 12L12.47 14.12L13.88 15.53L16 13.41L18.12 15.53L19.53 14.12L17.41 12Z\";\r\nvar mdiTimelineRemoveOutline = \"M4 8H2V2H4V8M2 22H4V16H2V22M3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12C5 10.9 4.11 10 3 10M13.88 15.54L16 13.41L18.12 15.53L19.53 14.12L17.41 12L19.53 9.88L18.12 8.47L16 10.59L13.88 8.47L12.47 9.88L14.59 12L12.47 14.12L13.88 15.54M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M22 6H10V18H22V6Z\";\r\nvar mdiTimelineText = \"M4 2V8H2V2H4M2 22H4V16H2V22M5 12C5 10.9 4.11 10 3 10C1.9 10 1 10.9 1 12C1 13.11 1.9 14 3 14C4.11 14 5 13.11 5 12M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M19 13H11V15H19V13M21 9H11V11H21V9Z\";\r\nvar mdiTimelineTextOutline = \"M5 12C5 13.11 4.11 14 3 14C1.9 14 1 13.11 1 12C1 10.9 1.9 10 3 10C4.11 10 5 10.9 5 12M4 2V8H2V2H4M2 22V16H4V22H2M24 6V18C24 19.11 23.11 20 22 20H10C8.9 20 8 19.11 8 18V14L6 12L8 10V6C8 4.89 8.9 4 10 4H22C23.11 4 24 4.89 24 6M22 6H10V10.83L8.83 12L10 13.17V18H22V6M12 9H20V11H12V9M12 13H18V15H12V13Z\";\r\nvar mdiTimer = \"M19.03 7.39L20.45 5.97C20 5.46 19.55 5 19.04 4.56L17.62 6C16.07 4.74 14.12 4 12 4C7.03 4 3 8.03 3 13S7.03 22 12 22C17 22 21 17.97 21 13C21 10.88 20.26 8.93 19.03 7.39M13 14H11V7H13V14M15 1H9V3H15V1Z\";\r\nvar mdiTimer10 = \"M12.9,13.22C12.9,13.82 12.86,14.33 12.78,14.75C12.7,15.17 12.58,15.5 12.42,15.77C12.26,16.03 12.06,16.22 11.83,16.34C11.6,16.46 11.32,16.5 11,16.5C10.71,16.5 10.43,16.46 10.19,16.34C9.95,16.22 9.75,16.03 9.59,15.77C9.43,15.5 9.3,15.17 9.21,14.75C9.12,14.33 9.08,13.82 9.08,13.22V10.72C9.08,10.12 9.12,9.61 9.21,9.2C9.3,8.79 9.42,8.46 9.59,8.2C9.75,7.95 9.95,7.77 10.19,7.65C10.43,7.54 10.7,7.5 11,7.5C11.31,7.5 11.58,7.54 11.81,7.65C12.05,7.76 12.25,7.94 12.41,8.2C12.57,8.45 12.7,8.78 12.78,9.19C12.86,9.6 12.91,10.11 12.91,10.71V13.22M13.82,7.05C13.5,6.65 13.07,6.35 12.59,6.17C12.12,6 11.58,5.9 11,5.9C10.42,5.9 9.89,6 9.41,6.17C8.93,6.35 8.5,6.64 8.18,7.05C7.84,7.46 7.58,8 7.39,8.64C7.21,9.29 7.11,10.09 7.11,11.03V12.95C7.11,13.89 7.2,14.69 7.39,15.34C7.58,16 7.84,16.53 8.19,16.94C8.53,17.35 8.94,17.65 9.42,17.83C9.9,18 10.43,18.11 11,18.11C11.6,18.11 12.13,18 12.6,17.83C13.08,17.65 13.5,17.35 13.82,16.94C14.16,16.53 14.42,16 14.6,15.34C14.78,14.69 14.88,13.89 14.88,12.95V11.03C14.88,10.09 14.79,9.29 14.6,8.64C14.42,8 14.16,7.45 13.82,7.05M23.78,14.37C23.64,14.09 23.43,13.84 23.15,13.63C22.87,13.42 22.54,13.24 22.14,13.1C21.74,12.96 21.29,12.83 20.79,12.72C20.44,12.65 20.15,12.57 19.92,12.5C19.69,12.41 19.5,12.33 19.37,12.24C19.23,12.15 19.14,12.05 19.09,11.94C19.04,11.83 19,11.7 19,11.55C19,11.41 19.04,11.27 19.1,11.14C19.16,11 19.25,10.89 19.37,10.8C19.5,10.7 19.64,10.62 19.82,10.56C20,10.5 20.22,10.47 20.46,10.47C20.71,10.47 20.93,10.5 21.12,10.58C21.31,10.65 21.47,10.75 21.6,10.87C21.73,11 21.82,11.13 21.89,11.29C21.95,11.45 22,11.61 22,11.78H23.94C23.94,11.39 23.86,11.03 23.7,10.69C23.54,10.35 23.31,10.06 23,9.81C22.71,9.56 22.35,9.37 21.92,9.22C21.5,9.07 21,9 20.46,9C19.95,9 19.5,9.07 19.07,9.21C18.66,9.35 18.3,9.54 18,9.78C17.72,10 17.5,10.3 17.34,10.62C17.18,10.94 17.11,11.27 17.11,11.63C17.11,12 17.19,12.32 17.34,12.59C17.5,12.87 17.7,13.11 18,13.32C18.25,13.53 18.58,13.7 18.96,13.85C19.34,14 19.77,14.11 20.23,14.21C20.62,14.29 20.94,14.38 21.18,14.47C21.42,14.56 21.61,14.66 21.75,14.76C21.88,14.86 21.97,15 22,15.1C22.07,15.22 22.09,15.35 22.09,15.5C22.09,15.81 21.96,16.06 21.69,16.26C21.42,16.46 21.03,16.55 20.5,16.55C20.3,16.55 20.09,16.53 19.88,16.47C19.67,16.42 19.5,16.34 19.32,16.23C19.15,16.12 19,15.97 18.91,15.79C18.8,15.61 18.74,15.38 18.73,15.12H16.84C16.84,15.5 16.92,15.83 17.08,16.17C17.24,16.5 17.47,16.82 17.78,17.1C18.09,17.37 18.47,17.59 18.93,17.76C19.39,17.93 19.91,18 20.5,18C21.04,18 21.5,17.95 21.95,17.82C22.38,17.69 22.75,17.5 23.06,17.28C23.37,17.05 23.6,16.77 23.77,16.45C23.94,16.13 24,15.78 24,15.39C24,15 23.93,14.65 23.78,14.37M0,7.72V9.4L3,8.4V18H5V6H4.75L0,7.72Z\";\r\nvar mdiTimer3 = \"M20.87,14.37C20.73,14.09 20.5,13.84 20.24,13.63C19.96,13.42 19.63,13.24 19.23,13.1C18.83,12.96 18.38,12.83 17.88,12.72C17.53,12.65 17.24,12.57 17,12.5C16.78,12.41 16.6,12.33 16.46,12.24C16.32,12.15 16.23,12.05 16.18,11.94C16.13,11.83 16.1,11.7 16.1,11.55C16.1,11.4 16.13,11.27 16.19,11.14C16.25,11 16.34,10.89 16.46,10.8C16.58,10.7 16.73,10.62 16.91,10.56C17.09,10.5 17.31,10.47 17.55,10.47C17.8,10.47 18,10.5 18.21,10.58C18.4,10.65 18.56,10.75 18.69,10.87C18.82,11 18.91,11.13 19,11.29C19.04,11.45 19.08,11.61 19.08,11.78H21.03C21.03,11.39 20.95,11.03 20.79,10.69C20.63,10.35 20.4,10.06 20.1,9.81C19.8,9.56 19.44,9.37 19,9.22C18.58,9.07 18.09,9 17.55,9C17.04,9 16.57,9.07 16.16,9.21C15.75,9.35 15.39,9.54 15.1,9.78C14.81,10 14.59,10.3 14.43,10.62C14.27,10.94 14.2,11.27 14.2,11.63C14.2,12 14.28,12.31 14.43,12.59C14.58,12.87 14.8,13.11 15.07,13.32C15.34,13.53 15.67,13.7 16.05,13.85C16.43,14 16.86,14.11 17.32,14.21C17.71,14.29 18.03,14.38 18.27,14.47C18.5,14.56 18.7,14.66 18.84,14.76C18.97,14.86 19.06,15 19.11,15.1C19.16,15.22 19.18,15.35 19.18,15.5C19.18,15.81 19.05,16.06 18.78,16.26C18.5,16.46 18.12,16.55 17.61,16.55C17.39,16.55 17.18,16.53 16.97,16.47C16.76,16.42 16.57,16.34 16.41,16.23C16.24,16.12 16.11,15.97 16,15.79C15.89,15.61 15.83,15.38 15.82,15.12H13.93C13.93,15.5 14,15.83 14.17,16.17C14.33,16.5 14.56,16.82 14.87,17.1C15.18,17.37 15.56,17.59 16,17.76C16.5,17.93 17,18 17.6,18C18.13,18 18.61,17.95 19.04,17.82C19.47,17.69 19.84,17.5 20.15,17.28C20.46,17.05 20.69,16.77 20.86,16.45C21.03,16.13 21.11,15.78 21.11,15.39C21.09,15 21,14.65 20.87,14.37M11.61,12.97C11.45,12.73 11.25,12.5 11,12.32C10.74,12.13 10.43,11.97 10.06,11.84C10.36,11.7 10.63,11.54 10.86,11.34C11.09,11.14 11.28,10.93 11.43,10.7C11.58,10.47 11.7,10.24 11.77,10C11.85,9.75 11.88,9.5 11.88,9.26C11.88,8.71 11.79,8.22 11.6,7.8C11.42,7.38 11.16,7.03 10.82,6.74C10.5,6.46 10.09,6.24 9.62,6.1C9.17,5.97 8.65,5.9 8.09,5.9C7.54,5.9 7.03,6 6.57,6.14C6.1,6.31 5.7,6.54 5.37,6.83C5.04,7.12 4.77,7.46 4.59,7.86C4.39,8.25 4.3,8.69 4.3,9.15H6.28C6.28,8.89 6.33,8.66 6.42,8.46C6.5,8.26 6.64,8.08 6.8,7.94C6.97,7.8 7.16,7.69 7.38,7.61C7.6,7.53 7.84,7.5 8.11,7.5C8.72,7.5 9.17,7.65 9.47,7.96C9.77,8.27 9.91,8.71 9.91,9.28C9.91,9.55 9.87,9.8 9.79,10C9.71,10.24 9.58,10.43 9.41,10.59C9.24,10.75 9.03,10.87 8.78,10.96C8.53,11.05 8.23,11.09 7.89,11.09H6.72V12.66H7.9C8.24,12.66 8.54,12.7 8.81,12.77C9.08,12.85 9.31,12.96 9.5,13.12C9.69,13.28 9.84,13.5 9.94,13.73C10.04,13.97 10.1,14.27 10.1,14.6C10.1,15.22 9.92,15.69 9.57,16C9.22,16.35 8.73,16.5 8.12,16.5C7.83,16.5 7.56,16.47 7.32,16.38C7.08,16.3 6.88,16.18 6.71,16C6.54,15.86 6.41,15.68 6.32,15.46C6.23,15.24 6.18,15 6.18,14.74H4.19C4.19,15.29 4.3,15.77 4.5,16.19C4.72,16.61 5,16.96 5.37,17.24C5.73,17.5 6.14,17.73 6.61,17.87C7.08,18 7.57,18.08 8.09,18.08C8.66,18.08 9.18,18 9.67,17.85C10.16,17.7 10.58,17.47 10.93,17.17C11.29,16.87 11.57,16.5 11.77,16.07C11.97,15.64 12.07,15.14 12.07,14.59C12.07,14.3 12.03,14 11.96,13.73C11.88,13.5 11.77,13.22 11.61,12.97Z\";\r\nvar mdiTimerOff = \"M3 4L1.75 5.27L4.5 8.03C3.55 9.45 3 11.16 3 13C3 17.97 7.03 22 12 22C13.84 22 15.55 21.45 17 20.5L19.5 23L20.75 21.73L13.04 14L3 4M15 1H9V3H15M21 13C21 14.83 20.45 16.53 19.5 17.94L13 11.45V7H11V9.45L7.05 5.5C8.47 4.55 10.17 4 12 4C14.12 4 16.07 4.74 17.62 5.97L19.04 4.55L20.45 5.97L19.03 7.39C20.26 8.93 21 10.88 21 13Z\";\r\nvar mdiTimerOffOutline = \"M12,20A7,7 0 0,1 5,13C5,11.72 5.35,10.5 5.95,9.5L15.5,19.04C14.5,19.65 13.28,20 12,20M3,4L1.75,5.27L4.5,8.03C3.55,9.45 3,11.16 3,13A9,9 0 0,0 12,22C13.84,22 15.55,21.45 17,20.5L19.5,23L20.75,21.73L13.04,14L3,4M11,9.44L13,11.44V8H11M15,1H9V3H15M19.04,4.55L17.62,5.97C16.07,4.74 14.12,4 12,4C10.17,4 8.47,4.55 7.05,5.5L8.5,6.94C9.53,6.35 10.73,6 12,6A7,7 0 0,1 19,13C19,14.27 18.65,15.47 18.06,16.5L19.5,17.94C20.45,16.53 21,14.83 21,13C21,10.88 20.26,8.93 19.03,7.39L20.45,5.97L19.04,4.55Z\";\r\nvar mdiTimerOutline = \"M12,20A7,7 0 0,1 5,13A7,7 0 0,1 12,6A7,7 0 0,1 19,13A7,7 0 0,1 12,20M19.03,7.39L20.45,5.97C20,5.46 19.55,5 19.04,4.56L17.62,6C16.07,4.74 14.12,4 12,4A9,9 0 0,0 3,13A9,9 0 0,0 12,22C17,22 21,17.97 21,13C21,10.88 20.26,8.93 19.03,7.39M11,14H13V8H11M15,1H9V3H15V1Z\";\r\nvar mdiTimerSand = \"M6,2H18V8H18V8L14,12L18,16V16H18V22H6V16H6V16L10,12L6,8V8H6V2M16,16.5L12,12.5L8,16.5V20H16V16.5M12,11.5L16,7.5V4H8V7.5L12,11.5M10,6H14V6.75L12,8.75L10,6.75V6Z\";\r\nvar mdiTimerSandEmpty = \"M6,2V8H6V8L10,12L6,16V16H6V22H18V16H18V16L14,12L18,8V8H18V2H6M16,16.5V20H8V16.5L12,12.5L16,16.5M12,11.5L8,7.5V4H16V7.5L12,11.5Z\";\r\nvar mdiTimerSandFull = \"M6,2V8H6V8L10,12L6,16V16H6V22H18V16H18V16L14,12L18,8V8H18V2H6Z\";\r\nvar mdiTimetable = \"M14,12H15.5V14.82L17.94,16.23L17.19,17.53L14,15.69V12M4,2H18A2,2 0 0,1 20,4V10.1C21.24,11.36 22,13.09 22,15A7,7 0 0,1 15,22C13.09,22 11.36,21.24 10.1,20H4A2,2 0 0,1 2,18V4A2,2 0 0,1 4,2M4,15V18H8.67C8.24,17.09 8,16.07 8,15H4M4,8H10V5H4V8M18,8V5H12V8H18M4,13H8.29C8.63,11.85 9.26,10.82 10.1,10H4V13M15,10.15A4.85,4.85 0 0,0 10.15,15C10.15,17.68 12.32,19.85 15,19.85A4.85,4.85 0 0,0 19.85,15C19.85,12.32 17.68,10.15 15,10.15Z\";\r\nvar mdiToaster = \"M21 11A2 2 0 0 0 19 9H5A2 2 0 0 0 3 11H2V13H3V20H21V13H22V11M17 15A2 2 0 1 1 19 13A2 2 0 0 1 17 15M18 8H6C6.33 5.75 8.88 4 12 4S17.63 5.75 18 8Z\";\r\nvar mdiToasterOff = \"M20.8 22.7L18.1 20H3V13H2V11H3C3 9.9 3.9 9 5 9H7.1L1.1 3L2.4 1.7L22.1 21.4L20.8 22.7M15.3 12.1C15.6 11.5 16.3 11 17 11C18.1 11 19 11.9 19 13C19 13.8 18.6 14.4 17.9 14.7L21 17.8V13H22V11H21C21 9.9 20.1 9 19 9H12.2L15.3 12.1M18 8C17.6 5.8 15.1 4 12 4C10.6 4 9.2 4.4 8.2 5L11.2 8H18Z\";\r\nvar mdiToasterOven = \"M4,5A2,2 0 0,0 2,7V17A2,2 0 0,0 4,19H20A2,2 0 0,0 22,17V7A2,2 0 0,0 20,5H4M4,7H16V17H4V7M19,7A1,1 0 0,1 20,8A1,1 0 0,1 19,9A1,1 0 0,1 18,8A1,1 0 0,1 19,7M6,9V11H14V9H6M19,11A1,1 0 0,1 20,12A1,1 0 0,1 19,13A1,1 0 0,1 18,12A1,1 0 0,1 19,11Z\";\r\nvar mdiToggleSwitch = \"M17,7H7A5,5 0 0,0 2,12A5,5 0 0,0 7,17H17A5,5 0 0,0 22,12A5,5 0 0,0 17,7M17,15A3,3 0 0,1 14,12A3,3 0 0,1 17,9A3,3 0 0,1 20,12A3,3 0 0,1 17,15Z\";\r\nvar mdiToggleSwitchOff = \"M17,7H7A5,5 0 0,0 2,12A5,5 0 0,0 7,17H17A5,5 0 0,0 22,12A5,5 0 0,0 17,7M7,15A3,3 0 0,1 4,12A3,3 0 0,1 7,9A3,3 0 0,1 10,12A3,3 0 0,1 7,15Z\";\r\nvar mdiToggleSwitchOffOutline = \"M7,10A2,2 0 0,1 9,12A2,2 0 0,1 7,14A2,2 0 0,1 5,12A2,2 0 0,1 7,10M17,7A5,5 0 0,1 22,12A5,5 0 0,1 17,17H7A5,5 0 0,1 2,12A5,5 0 0,1 7,7H17M7,9A3,3 0 0,0 4,12A3,3 0 0,0 7,15H17A3,3 0 0,0 20,12A3,3 0 0,0 17,9H7Z\";\r\nvar mdiToggleSwitchOutline = \"M17,10A2,2 0 0,1 19,12A2,2 0 0,1 17,14A2,2 0 0,1 15,12A2,2 0 0,1 17,10M17,7A5,5 0 0,1 22,12A5,5 0 0,1 17,17H7A5,5 0 0,1 2,12A5,5 0 0,1 7,7H17M7,9A3,3 0 0,0 4,12A3,3 0 0,0 7,15H17A3,3 0 0,0 20,12A3,3 0 0,0 17,9H7Z\";\r\nvar mdiToilet = \"M9,22H17V19.5C19.41,17.87 21,15.12 21,12V4A2,2 0 0,0 19,2H15C13.89,2 13,2.9 13,4V12H3C3,15.09 5,18 9,19.5V22M5.29,14H18.71C18.14,15.91 16.77,17.5 15,18.33V20H11V18.33C9,18 5.86,15.91 5.29,14M15,4H19V12H15V4M16,5V8H18V5H16Z\";\r\nvar mdiToolbox = \"M9,5V6H15V5H9M22,18C22,18.53 21.79,19 21.4,19.41C21,19.81 20.55,20 20,20H4C3.45,20 3,19.81 2.6,19.41C2.21,19 2,18.53 2,18V14H7V15H9V14H15V15H17V14H22V18M4.5,7.22C4.84,6.41 5.45,6 6.33,6H7V5C7,4.45 7.18,4 7.57,3.59C7.96,3.2 8.44,3 9,3H15C15.56,3 16.04,3.2 16.43,3.59C16.82,4 17,4.45 17,5V6H17.67C18.55,6 19.16,6.41 19.5,7.22L21.58,12H17V11H15V12H9V11H7V12H2.42L4.5,7.22Z\";\r\nvar mdiToolboxOutline = \"M20,18V14H17V15H15V14H9V15H7V14H4V18H20M6.33,8L4.59,12H7V11H9V12H15V11H17V12H19.41L17.67,8H6.33M9,5V6H15V5H9M21.84,12.61C21.94,12.83 22,13.09 22,13.41V18C22,18.53 21.79,19 21.4,19.41C21,19.81 20.55,20 20,20H4C3.45,20 3,19.81 2.6,19.41C2.21,19 2,18.53 2,18V13.41C2,13.09 2.06,12.83 2.16,12.61L4.5,7.22C4.84,6.41 5.45,6 6.33,6H7V5C7,4.45 7.18,4 7.57,3.59C7.96,3.2 8.44,3 9,3H15C15.56,3 16.04,3.2 16.43,3.59C16.82,4 17,4.45 17,5V6H17.67C18.55,6 19.16,6.41 19.5,7.22L21.84,12.61Z\";\r\nvar mdiTools = \"M21.71 20.29L20.29 21.71A1 1 0 0 1 18.88 21.71L7 9.85A3.81 3.81 0 0 1 6 10A4 4 0 0 1 2.22 4.7L4.76 7.24L5.29 6.71L6.71 5.29L7.24 4.76L4.7 2.22A4 4 0 0 1 10 6A3.81 3.81 0 0 1 9.85 7L21.71 18.88A1 1 0 0 1 21.71 20.29M2.29 18.88A1 1 0 0 0 2.29 20.29L3.71 21.71A1 1 0 0 0 5.12 21.71L10.59 16.25L7.76 13.42M20 2L16 4V6L13.83 8.17L15.83 10.17L18 8H20L22 4Z\";\r\nvar mdiTooltip = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2Z\";\r\nvar mdiTooltipAccount = \"M20,2H4A2,2 0 0,0 2,4V16A2,2 0 0,0 4,18H8L12,22L16,18H20A2,2 0 0,0 22,16V4A2,2 0 0,0 20,2M12,4.3C13.5,4.3 14.7,5.5 14.7,7C14.7,8.5 13.5,9.7 12,9.7C10.5,9.7 9.3,8.5 9.3,7C9.3,5.5 10.5,4.3 12,4.3M18,15H6V14.1C6,12.1 10,11 12,11C14,11 18,12.1 18,14.1V15Z\";\r\nvar mdiTooltipCheck = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M10.46 14L6.96 10.5L8.37 9.08L10.46 11.17L15.64 6L17.05 7.41L10.46 14Z\";\r\nvar mdiTooltipCheckOutline = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H15.17L12 19.17L8.83 16H4V4H20V16M10.75 13.71L7.25 10.21L8.66 8.79L10.75 10.88L15.34 6.3L16.75 7.71L10.75 13.71Z\";\r\nvar mdiTooltipEdit = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M9.08 15H7V12.91L13.17 6.72L15.24 8.8L9.08 15M16.84 7.2L15.83 8.21L13.76 6.18L14.77 5.16C14.97 4.95 15.31 4.94 15.55 5.16L16.84 6.41C17.05 6.62 17.06 6.96 16.84 7.2Z\";\r\nvar mdiTooltipEditOutline = \"M4 2H20C21.11 2 22 2.9 22 4V16C22 17.11 21.11 18 20 18H16L12 22L8 18H4C2.9 18 2 17.11 2 16V4C2 2.9 2.9 2 4 2M4 4V16H8.83L12 19.17L15.17 16H20V4H4M15.84 8.2L14.83 9.21L12.76 7.18L13.77 6.16C13.97 5.95 14.31 5.94 14.55 6.16L15.84 7.41C16.05 7.62 16.06 7.96 15.84 8.2M8 11.91L12.17 7.72L14.24 9.8L10.08 14H8V11.91Z\";\r\nvar mdiTooltipImage = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M19,15V7L15,11L13,9L7,15H19M7,5A2,2 0 0,0 5,7A2,2 0 0,0 7,9A2,2 0 0,0 9,7A2,2 0 0,0 7,5Z\";\r\nvar mdiTooltipImageOutline = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M4,4V16H8.83L12,19.17L15.17,16H20V4H4M7.5,6A1.5,1.5 0 0,1 9,7.5A1.5,1.5 0 0,1 7.5,9A1.5,1.5 0 0,1 6,7.5A1.5,1.5 0 0,1 7.5,6M6,14L11,9L13,11L18,6V14H6Z\";\r\nvar mdiTooltipMinus = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M16 11H8V9H16V11Z\";\r\nvar mdiTooltipMinusOutline = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H15.17L12 19.17L8.83 16H4V4H20V16M16 11H8V9H16V11Z\";\r\nvar mdiTooltipOutline = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M4,4V16H8.83L12,19.17L15.17,16H20V4H4Z\";\r\nvar mdiTooltipPlus = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M11,6V9H8V11H11V14H13V11H16V9H13V6H11Z\";\r\nvar mdiTooltipPlusOutline = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M4,4V16H8.83L12,19.17L15.17,16H20V4H4M11,6H13V9H16V11H13V14H11V11H8V9H11V6Z\";\r\nvar mdiTooltipRemove = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M15.54 12.12L14.12 13.54L12 11.41L9.88 13.54L8.47 12.12L10.59 10L8.46 7.88L9.88 6.47L12 8.59L14.12 6.47L15.54 7.88L13.41 10L15.54 12.12Z\";\r\nvar mdiTooltipRemoveOutline = \"M20 2H4C2.9 2 2 2.9 2 4V16C2 17.11 2.9 18 4 18H8L12 22L16 18H20C21.11 18 22 17.11 22 16V4C22 2.9 21.11 2 20 2M20 16H15.17L12 19.17L8.83 16H4V4H20V16M8.46 12.12L10.59 10L8.46 7.88L9.88 6.47L12 8.59L14.12 6.47L15.54 7.88L13.41 10L15.54 12.12L14.12 13.54L12 11.41L9.88 13.54L8.46 12.12Z\";\r\nvar mdiTooltipText = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M5,5V7H19V5H5M5,9V11H15V9H5M5,13V15H17V13H5Z\";\r\nvar mdiTooltipTextOutline = \"M4,2H20A2,2 0 0,1 22,4V16A2,2 0 0,1 20,18H16L12,22L8,18H4A2,2 0 0,1 2,16V4A2,2 0 0,1 4,2M4,4V16H8.83L12,19.17L15.17,16H20V4H4M6,7H18V9H6V7M6,11H16V13H6V11Z\";\r\nvar mdiTooth = \"M7,2C4,2 2,5 2,8C2,10.11 3,13 4,14C5,15 6,22 8,22C12.54,22 10,15 12,15C14,15 11.46,22 16,22C18,22 19,15 20,14C21,13 22,10.11 22,8C22,5 20,2 17,2C14,2 14,3 12,3C10,3 10,2 7,2Z\";\r\nvar mdiToothOutline = \"M7,2C4,2 2,5 2,8C2,10.11 3,13 4,14C5,15 6,22 8,22C12.54,22 10,15 12,15C14,15 11.46,22 16,22C18,22 19,15 20,14C21,13 22,10.11 22,8C22,5 20,2 17,2C14,2 14,3 12,3C10,3 10,2 7,2M7,4C9,4 10,5 12,5C14,5 15,4 17,4C18.67,4 20,6 20,8C20,9.75 19.14,12.11 18.19,13.06C17.33,13.92 16.06,19.94 15.5,19.94C15.29,19.94 15,18.88 15,17.59C15,15.55 14.43,13 12,13C9.57,13 9,15.55 9,17.59C9,18.88 8.71,19.94 8.5,19.94C7.94,19.94 6.67,13.92 5.81,13.06C4.86,12.11 4,9.75 4,8C4,6 5.33,4 7,4Z\";\r\nvar mdiToothbrush = \"M12.91 6.43L15.03 8.55L16.09 7.5L15.03 6.43L17.86 3.6L18.92 4.66L20 3.6L17.86 1.5M3 20.57L4.43 22L14.5 11.9L16.63 11.19L21.4 6.43C22.18 5.65 22.18 4.38 21.4 3.6L15.55 9.44L13.43 10.15Z\";\r\nvar mdiToothbrushElectric = \"M12 1.5V14C10.34 14 9 15.34 9 17V22H17V17C17 15.34 15.66 14 14 14V3.5C14 2.4 13.11 1.5 12 1.5M7.5 2V9H11V7.5H9V3.5H11V2H7.5M13 17.5C13.83 17.5 14.5 18.17 14.5 19C14.5 19.83 13.83 20.5 13 20.5C12.17 20.5 11.5 19.83 11.5 19C11.5 18.17 12.17 17.5 13 17.5Z\";\r\nvar mdiToothbrushPaste = \"M17.86 1.5L12.91 6.43L15.03 8.55L16.09 7.5L15.03 6.43L17.86 3.6L18.92 4.66L20 3.6M21.4 3.6L15.56 9.44L13.43 10.15L3 20.57L4.43 22L10.08 16.33L14.33 20.57L18.57 16.33L14.33 12.09L14.5 11.9L16.63 11.19L21.4 6.43C22.18 5.65 22.18 4.38 21.4 3.6M6.55 4.31L2.31 8.55L7.26 13.5L11.5 9.26M18.22 18.1L16.09 20.22L17.5 21.63L19.63 19.5Z\";\r\nvar mdiTorch = \"M8.6 9.6C9 10.2 9.5 10.7 10.2 11H14.2C14.5 10.9 14.7 10.7 14.9 10.5C15.9 9.5 16.3 8 15.8 6.7L15.7 6.5C15.6 6.2 15.4 6 15.2 5.8C15.1 5.6 14.9 5.5 14.8 5.3C14.4 5 14 4.7 13.6 4.3C12.7 3.4 12.6 2 13.1 1C12.6 1.1 12.1 1.4 11.7 1.8C10.2 3 9.6 5.1 10.3 7V7.2C10.3 7.3 10.2 7.4 10.1 7.5C10 7.6 9.8 7.5 9.7 7.4L9.6 7.3C9 6.5 8.9 5.3 9.3 4.3C8.4 5.1 7.9 6.4 8 7.7C8 8 8.1 8.3 8.2 8.6C8.2 8.9 8.4 9.3 8.6 9.6M12.3 8.1C12.4 7.6 12.2 7.2 12.1 6.8C12 6.4 12 6 12.2 5.6L12.5 6.2C12.9 6.8 13.6 7 13.8 7.8V8.1C13.8 8.6 13.6 9.1 13.3 9.4C13.1 9.5 12.9 9.7 12.7 9.7C12.1 9.9 11.4 9.6 11 9.2C11.8 9.2 12.2 8.6 12.3 8.1M15 12V14H14L13 22H11L10 14H9V12H15Z\";\r\nvar mdiTortoise = \"M19.31,5.6C18.09,5.56 16.88,6.5 16.5,8C16,10 16,10 15,11C13,13 10,14 4,15C3,15.16 2.5,15.5 2,16C4,16 6,16 4.5,17.5L3,19H6L8,17C10,18 11.33,18 13.33,17L14,19H17L16,16C16,16 17,12 18,11C19,10 19,11 20,11C21,11 22,10 22,8.5C22,8 22,7 20.5,6C20.15,5.76 19.74,5.62 19.31,5.6M9,6A6,6 0 0,0 3,12C3,12.6 3.13,13.08 3.23,13.6C9.15,12.62 12.29,11.59 13.93,9.94L14.43,9.44C13.44,7.34 11.32,6 9,6Z\";\r\nvar mdiToslink = \"M20 10V7L17 4H7L4 7V10C2.9 10 2 10.9 2 12S2.9 14 4 14V18C4 19.1 4.9 20 6 20H18C19.1 20 20 19.1 20 18V14C21.11 14 22 13.11 22 12S21.11 10 20 10M12 16C9.79 16 8 14.21 8 12S9.79 8 12 8 16 9.79 16 12 14.21 16 12 16M14 12C14 13.11 13.11 14 12 14S10 13.11 10 12 10.9 10 12 10 14 10.9 14 12Z\";\r\nvar mdiTournament = \"M2,2V4H7V8H2V10H7C8.11,10 9,9.11 9,8V7H14V17H9V16C9,14.89 8.11,14 7,14H2V16H7V20H2V22H7C8.11,22 9,21.11 9,20V19H14C15.11,19 16,18.11 16,17V13H22V11H16V7C16,5.89 15.11,5 14,5H9V4C9,2.89 8.11,2 7,2H2Z\";\r\nvar mdiTowTruck = \"M15,10H20.39L17.06,6H15V10M17.5,18.5C17.89,18.5 18.24,18.37 18.54,18.07C18.84,17.77 19,17.42 19,17C19,16.61 18.84,16.26 18.54,15.96C18.24,15.66 17.89,15.5 17.5,15.5C17.08,15.5 16.73,15.66 16.43,15.96C16.13,16.26 16,16.61 16,17C16,17.42 16.13,17.77 16.43,18.07C16.73,18.37 17.08,18.5 17.5,18.5M6,18.5C6.44,18.5 6.8,18.37 7.08,18.07C7.36,17.77 7.5,17.42 7.5,17C7.5,16.61 7.36,16.26 7.08,15.96C6.8,15.66 6.44,15.5 6,15.5C5.56,15.5 5.2,15.66 4.92,15.96C4.64,16.26 4.5,16.61 4.5,17C4.5,17.42 4.64,17.77 4.92,18.07C5.2,18.37 5.56,18.5 6,18.5M18,4L23,10V17H20.5C20.5,17.83 20.19,18.53 19.59,19.13C19,19.72 18.3,20 17.5,20C16.67,20 15.97,19.72 15.38,19.13C14.78,18.53 14.5,17.83 14.5,17H9C9,17.83 8.7,18.53 8.11,19.13C7.5,19.72 6.81,20 6,20C5.19,20 4.5,19.72 3.89,19.13C3.3,18.53 3,17.83 3,17H1V13H9.19L3,8.11V11H1V5H2L13,11.06V4H18Z\";\r\nvar mdiTowerBeach = \"M17,4V8H18V10H17.64L21,23H18.93L18.37,20.83L12,17.15L5.63,20.83L5.07,23H3L6.36,10H6V8H7V4H6V3L18,1V4H17M7.28,14.43L6.33,18.12L10,16L7.28,14.43M15.57,10H8.43L7.8,12.42L12,14.85L16.2,12.42L15.57,10M17.67,18.12L16.72,14.43L14,16L17.67,18.12Z\";\r\nvar mdiTowerFire = \"M17,4V8H18V10H17.64L21,23H18.93L18.37,20.83L12,17.15L5.63,20.83L5.07,23H3L6.36,10H6V8H7V4H6V3L12,1L18,3V4H17M7.28,14.43L6.33,18.12L10,16L7.28,14.43M15.57,10H8.43L7.8,12.42L12,14.85L16.2,12.42L15.57,10M17.67,18.12L16.72,14.43L14,16L17.67,18.12Z\";\r\nvar mdiToyBrick = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H21V6Z\";\r\nvar mdiToyBrickMarker = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H14.54A9.55 9.55 0 0 1 13 15.5A5.58 5.58 0 0 1 18.5 10A5.3 5.3 0 0 1 21 10.63V6M18.5 12A3.54 3.54 0 0 0 15 15.5C15 18.1 18.5 22 18.5 22S22 18.1 22 15.5A3.54 3.54 0 0 0 18.5 12M18.5 16.8A1.2 1.2 0 1 1 18.5 14.4A1.29 1.29 0 0 1 19.7 15.6A1.15 1.15 0 0 1 18.5 16.8Z\";\r\nvar mdiToyBrickMarkerOutline = \"M18.5 12A3.54 3.54 0 0 0 15 15.5C15 18.1 18.5 22 18.5 22S22 18.1 22 15.5A3.54 3.54 0 0 0 18.5 12M18.5 16.8A1.2 1.2 0 1 1 18.5 14.4A1.29 1.29 0 0 1 19.7 15.6A1.15 1.15 0 0 1 18.5 16.8M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H14.54A15.55 15.55 0 0 1 13.54 18H5V8H19V10A5.11 5.11 0 0 1 21 10.6V6Z\";\r\nvar mdiToyBrickMinus = \"M23 20H15V18H23V20M13 19C13 15.69 15.69 13 19 13C19.7 13 20.37 13.13 21 13.35V6H19V5C19 3.9 18.11 3 17 3H15C13.9 3 13 3.9 13 5V6H11V5C11 3.9 10.11 3 9 3H7C5.9 3 5 3.9 5 5V6H3V20H13.09C13.04 19.67 13 19.34 13 19Z\";\r\nvar mdiToyBrickMinusOutline = \"M13.09 20H3V6H5V5C5 3.9 5.9 3 7 3H9C10.11 3 11 3.9 11 5V6H13V5C13 3.9 13.9 3 15 3H17C18.11 3 19 3.9 19 5V6H21V13.35C20.37 13.13 19.7 13 19 13V8H5V18H13.09C13.04 18.33 13 18.66 13 19S13.04 19.67 13.09 20M23 18H15V20H23V18Z\";\r\nvar mdiToyBrickOutline = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H21V6M19 18H5V8H19Z\";\r\nvar mdiToyBrickPlus = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H13.09A5.47 5.47 0 0 1 13 19A6 6 0 0 1 21 13.34V6M20 15V18H23V20H20V23H18V20H15V18H18V15Z\";\r\nvar mdiToyBrickPlusOutline = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H14V18H5V8H19V13H21V6M21 15V18H24V20H21V23H19V20H16V18H19V15Z\";\r\nvar mdiToyBrickRemove = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H13.09A5.47 5.47 0 0 1 13 19A6 6 0 0 1 21 13.34V6M22.54 16.88L20.41 19L22.54 21.12L21.12 22.54L19 20.41L16.88 22.54L15.46 21.12L17.59 19L15.46 16.88L16.88 15.46L19 17.59L21.12 15.46Z\";\r\nvar mdiToyBrickRemoveOutline = \"M19 6V5C19 3.9 18.1 3 17 3H15C13.9 3 13 3.9 13 5V6H11V5C11 3.9 10.1 3 9 3H7C5.9 3 5 3.9 5 5V6H3V20H14V18H5V8H19V13H21V6M17.88 15.46L20 17.59L22.12 15.47L23.54 16.88L21.41 19L23.54 21.12L22.12 22.54L20 20.41L17.88 22.54L16.46 21.12L18.59 19L16.47 16.88\";\r\nvar mdiToyBrickSearch = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H11.81A6.5 6.5 0 0 1 21 10.81V6M20.31 17.9A4.5 4.5 0 1 0 18.88 19.32L22 22.39L23.39 21M16.5 18A2.5 2.5 0 1 1 19 15.5A2.5 2.5 0 0 1 16.5 18Z\";\r\nvar mdiToyBrickSearchOutline = \"M19 6V5A2 2 0 0 0 17 3H15A2 2 0 0 0 13 5V6H11V5A2 2 0 0 0 9 3H7A2 2 0 0 0 5 5V6H3V20H11.81A6.59 6.59 0 0 1 10.5 18H5V8H19V9.5A6.59 6.59 0 0 1 21 10.81V6M20.31 17.9A4.5 4.5 0 1 0 18.88 19.32L22 22.39L23.39 21M16.5 18A2.5 2.5 0 1 1 19 15.5A2.5 2.5 0 0 1 16.5 18Z\";\r\nvar mdiTrackLight = \"M6,1V3H9V6.4L4.11,4.38L1.43,10.84L6.97,13.14L11.94,16.82L13.79,17.59L17.62,8.35L15.77,7.58L11,6.87V3H14V1H6M21.81,6.29L19.5,7.25L20.26,9.1L22.57,8.14L21.81,6.29M19.78,13.57L19,15.42L21.79,16.57L22.55,14.72L19.78,13.57M16.19,18.93L14.34,19.69L15.3,22L17.15,21.23L16.19,18.93Z\";\r\nvar mdiTrackpad = \"M4,3H20A2,2 0 0,1 22,5V19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19V5A2,2 0 0,1 4,3M4,5V13H20V5H4M4,19H11V15H4V19M20,19V15H13V19H20Z\";\r\nvar mdiTrackpadLock = \"M3,1C1.89,1 1,1.89 1,3V17C1,18.11 1.89,19 3,19H14V17H12V13H16.68C17.5,12.35 18.47,12 19.5,12C20,12 20.5,12.09 21,12.26V3C21,1.89 20.11,1 19,1H3M3,3H19V11H3V3M3,13H10V17H3V13M19.5,14A2.5,2.5 0 0,0 17,16.5V17A1,1 0 0,0 16,18V22A1,1 0 0,0 17,23H22A1,1 0 0,0 23,22V18A1,1 0 0,0 22,17V16.5A2.5,2.5 0 0,0 19.5,14M19.5,15A1.5,1.5 0 0,1 21,16.5V17H18V16.5A1.5,1.5 0 0,1 19.5,15Z\";\r\nvar mdiTractor = \"M5,4V11.26C3.2,11.9 2,13.6 2,15.5C2,18 4,20 6.5,20C8.79,20 10.71,18.28 10.97,16H15.17C15.06,16.32 15,16.66 15,17A3,3 0 0,0 18,20A3,3 0 0,0 21,17C21,16.66 20.94,16.32 20.82,16H22V13C22,11.89 21.11,11 20,11H15.04L13.65,4H5M7,6H12L13,11V14H10.74C10.16,12.38 8.71,11.23 7,11.03V6M6.5,13.25A2.25,2.25 0 0,1 8.75,15.5A2.25,2.25 0 0,1 6.5,17.75A2.25,2.25 0 0,1 4.25,15.5A2.25,2.25 0 0,1 6.5,13.25M18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5Z\";\r\nvar mdiTractorVariant = \"M13.3 2.79L9.8 6.29L10.5 7L11.9 5.61L13 6.71V9C13 10.11 12.11 11 11 11H10.46A6 6 0 0 1 12 15A6 6 0 0 1 11.91 16H15.03A4.5 4.5 0 0 1 19.5 12A4.5 4.5 0 0 1 22 12.76V8C22 6.89 21.11 6 20 6H13.71L12.61 4.9L14 3.5L13.3 2.79M4 7C3.45 7 3 7.45 3 8C3 8.55 3.45 9 4 9H9C9 7.9 8.11 7 7 7H4M6 10A5 5 0 0 0 4.44 10.25L4.8 11.18L4.33 11.36L4 10.43A5 5 0 0 0 1.54 12.74L2.45 13.15L2.24 13.6L1.34 13.2A5 5 0 0 0 1 15A5 5 0 0 0 1.25 16.56L2.18 16.2L2.36 16.67L1.43 17A5 5 0 0 0 3.74 19.46L4.14 18.55L4.6 18.76L4.2 19.66A5 5 0 0 0 6 20A5 5 0 0 0 7.56 19.75L7.2 18.82L7.67 18.64L8 19.57A5 5 0 0 0 10.46 17.26L9.55 16.86L9.76 16.4L10.66 16.8A5 5 0 0 0 11 15A5 5 0 0 0 10.75 13.44L9.82 13.8L9.64 13.33L10.57 13A5 5 0 0 0 8.26 10.54L7.86 11.45L7.4 11.24L7.8 10.34A5 5 0 0 0 6 10M6 12A3 3 0 0 1 9 15A3 3 0 0 1 6 18A3 3 0 0 1 3 15A3 3 0 0 1 6 12M19.5 13A3.5 3.5 0 0 0 16 16.5A3.5 3.5 0 0 0 19.5 20A3.5 3.5 0 0 0 23 16.5A3.5 3.5 0 0 0 19.5 13M19.5 15A1.5 1.5 0 0 1 21 16.5A1.5 1.5 0 0 1 19.5 18A1.5 1.5 0 0 1 18 16.5A1.5 1.5 0 0 1 19.5 15Z\";\r\nvar mdiTrademark = \"M9.8,8.44H6.87V16H4.89V8.44H2V7H9.8V8.44M13.5,7L15.96,13.5L18.41,7H21V16H19V13.5L19.22,9.24L16.63,16H15.28L12.7,9.25L12.9,13.5V16H10.93V7H13.5Z\";\r\nvar mdiTrafficCone = \"M17 15L18 19H21V22H3V19H6L7 15H17M15 8L16 12H8L9 8H15M13 1L14 5H10L11 1H13Z\";\r\nvar mdiTrafficLight = \"M12,9A2,2 0 0,1 10,7C10,5.89 10.9,5 12,5C13.11,5 14,5.89 14,7A2,2 0 0,1 12,9M12,14A2,2 0 0,1 10,12C10,10.89 10.9,10 12,10C13.11,10 14,10.89 14,12A2,2 0 0,1 12,14M12,19A2,2 0 0,1 10,17C10,15.89 10.9,15 12,15C13.11,15 14,15.89 14,17A2,2 0 0,1 12,19M20,10H17V8.86C18.72,8.41 20,6.86 20,5H17V4A1,1 0 0,0 16,3H8A1,1 0 0,0 7,4V5H4C4,6.86 5.28,8.41 7,8.86V10H4C4,11.86 5.28,13.41 7,13.86V15H4C4,16.86 5.28,18.41 7,18.86V20A1,1 0 0,0 8,21H16A1,1 0 0,0 17,20V18.86C18.72,18.41 20,16.86 20,15H17V13.86C18.72,13.41 20,11.86 20,10Z\";\r\nvar mdiTrain = \"M12,2C8,2 4,2.5 4,6V15.5A3.5,3.5 0 0,0 7.5,19L6,20.5V21H8.23L10.23,19H14L16,21H18V20.5L16.5,19A3.5,3.5 0 0,0 20,15.5V6C20,2.5 16.42,2 12,2M7.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,14A1.5,1.5 0 0,1 9,15.5A1.5,1.5 0 0,1 7.5,17M11,10H6V6H11V10M13,10V6H18V10H13M16.5,17A1.5,1.5 0 0,1 15,15.5A1.5,1.5 0 0,1 16.5,14A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 16.5,17Z\";\r\nvar mdiTrainCar = \"M12,4H5A3,3 0 0,0 2,7V15A3,3 0 0,0 5,18L4,19V20H5L7,17.97L9,18V13H4V6H13V8H15V7A3,3 0 0,0 12,4M5,14A1,1 0 0,1 6,15A1,1 0 0,1 5,16A1,1 0 0,1 4,15A1,1 0 0,1 5,14M20.57,9.66C20.43,9.26 20.05,9 19.6,9H12.41C11.95,9 11.58,9.26 11.43,9.66L10,13.77V19.28C10,19.66 10.32,20 10.7,20H11.32C11.7,20 12,19.62 12,19.24V18H20V19.24C20,19.62 20.31,20 20.69,20H21.3C21.68,20 22,19.66 22,19.28V17.91L22,13.77L20.57,9.66M12.41,10H19.6L20.63,13H11.38L12.41,10M12,16A1,1 0 0,1 11,15A1,1 0 0,1 12,14A1,1 0 0,1 13,15A1,1 0 0,1 12,16M20,16A1,1 0 0,1 19,15A1,1 0 0,1 20,14A1,1 0 0,1 21,15A1,1 0 0,1 20,16Z\";\r\nvar mdiTrainVariant = \"M18,10H6V5H18M12,17C10.89,17 10,16.1 10,15C10,13.89 10.89,13 12,13A2,2 0 0,1 14,15A2,2 0 0,1 12,17M4,15.5A3.5,3.5 0 0,0 7.5,19L6,20.5V21H18V20.5L16.5,19A3.5,3.5 0 0,0 20,15.5V5C20,1.5 16.42,1 12,1C7.58,1 4,1.5 4,5V15.5Z\";\r\nvar mdiTram = \"M19,16.94V8.5C19,5.71 16.39,5.1 13,5L13.75,3.5H17V2H7V3.5H11.75L11,5C7.86,5.11 5,5.73 5,8.5V16.94C5,18.39 6.19,19.6 7.59,19.91L6,21.5V22H8.23L10.23,20H14L16,22H18V21.5L16.5,20H16.42C18.11,20 19,18.63 19,16.94M12,18.5A1.5,1.5 0 0,1 10.5,17A1.5,1.5 0 0,1 12,15.5A1.5,1.5 0 0,1 13.5,17A1.5,1.5 0 0,1 12,18.5M17,14H7V9H17V14Z\";\r\nvar mdiTramSide = \"M9 1L5 4L7.5 6H5C5 6 2 6 2 9V19H7C7 19 7 17 9 17H22V14H18V8H22V6H10.5L13 4L9 1M4 8H9V14H4V8M11 8H16V14H11V8M4 16H5V18H4V16M9 19V19.5C9 20.88 10.12 22 11.5 22C12.5 22 13.39 21.41 13.79 20.5H15.21C15.61 21.41 16.5 22 17.5 22C18.88 22 20 20.88 20 19.5V19H9Z\";\r\nvar mdiTranscribe = \"M20,5A2,2 0 0,1 22,7V17A2,2 0 0,1 20,19H4C2.89,19 2,18.1 2,17V7C2,5.89 2.89,5 4,5H20M18,17V15H12.5L10.5,17H18M6,17H8.5L15.35,10.12C15.55,9.93 15.55,9.61 15.35,9.41L13.59,7.65C13.39,7.45 13.07,7.45 12.88,7.65L6,14.53V17Z\";\r\nvar mdiTranscribeClose = \"M12,23L8,19H16L12,23M20,3A2,2 0 0,1 22,5V15A2,2 0 0,1 20,17H4A2,2 0 0,1 2,15V5A2,2 0 0,1 4,3H20M18,15V13H12.5L10.5,15H18M6,15H8.5L15.35,8.12C15.55,7.93 15.55,7.61 15.35,7.42L13.59,5.65C13.39,5.45 13.07,5.45 12.88,5.65L6,12.53V15Z\";\r\nvar mdiTransfer = \"M8 4A2 2 0 0 0 6 6V10H8V6H16V9H13.5L17 12.5L20.5 9H18V6A2 2 0 0 0 16 4H8M3 12V14H11V12H3M3 15V17H11V15H3M13 15V17H21V15H13M3 18V20H11V18H3M13 18V20H21V18H13Z\";\r\nvar mdiTransferDown = \"M16,3V5H8V3H16M16,7V9H8V7H16M16,11V13H8V11H16M5,15H19L12,22L5,15Z\";\r\nvar mdiTransferLeft = \"M21,16H19V8H21V16M17,16H15V8H17V16M13,16H11V8H13V16M9,5V19L2,12L9,5Z\";\r\nvar mdiTransferRight = \"M3,8H5V16H3V8M7,8H9V16H7V8M11,8H13V16H11V8M15,19.25V4.75L22.25,12L15,19.25Z\";\r\nvar mdiTransferUp = \"M8,21V19H16V21H8M8,17V15H16V17H8M8,13V11H16V13H8M19,9H5L12,2L19,9Z\";\r\nvar mdiTransitConnection = \"M15,12C15,10.7 14.16,9.6 13,9.18V6.82C14.16,6.4 15,5.3 15,4A3,3 0 0,0 12,1A3,3 0 0,0 9,4C9,5.3 9.84,6.4 11,6.82V9.19C9.84,9.6 9,10.7 9,12C9,13.3 9.84,14.4 11,14.82V17.18C9.84,17.6 9,18.7 9,20A3,3 0 0,0 12,23A3,3 0 0,0 15,20C15,18.7 14.16,17.6 13,17.18V14.82C14.16,14.4 15,13.3 15,12M12,3A1,1 0 0,1 13,4A1,1 0 0,1 12,5A1,1 0 0,1 11,4A1,1 0 0,1 12,3M12,21A1,1 0 0,1 11,20A1,1 0 0,1 12,19A1,1 0 0,1 13,20A1,1 0 0,1 12,21Z\";\r\nvar mdiTransitConnectionHorizontal = \"M12 9C10.7 9 9.6 9.8 9.2 11H6.8C6.4 9.8 5.3 9 4 9C2.3 9 1 10.3 1 12S2.3 15 4 15C5.3 15 6.4 14.2 6.8 13H9.2C9.6 14.2 10.7 15 12 15S14.4 14.2 14.8 13H17.2C17.6 14.2 18.7 15 20 15C21.7 15 23 13.7 23 12S21.7 9 20 9C18.7 9 17.6 9.8 17.2 11H14.8C14.4 9.8 13.3 9 12 9M3 12C3 11.4 3.4 11 4 11S5 11.4 5 12 4.6 13 4 13 3 12.6 3 12M21 12C21 12.6 20.6 13 20 13S19 12.6 19 12 19.4 11 20 11 21 11.4 21 12Z\";\r\nvar mdiTransitConnectionVariant = \"M18,11H14.82C14.4,9.84 13.3,9 12,9C10.7,9 9.6,9.84 9.18,11H6C5.67,11 4,10.9 4,9V8C4,6.17 5.54,6 6,6H16.18C16.6,7.16 17.7,8 19,8A3,3 0 0,0 22,5A3,3 0 0,0 19,2C17.7,2 16.6,2.84 16.18,4H6C4.39,4 2,5.06 2,8V9C2,11.94 4.39,13 6,13H9.18C9.6,14.16 10.7,15 12,15C13.3,15 14.4,14.16 14.82,13H18C18.33,13 20,13.1 20,15V16C20,17.83 18.46,18 18,18H7.82C7.4,16.84 6.3,16 5,16A3,3 0 0,0 2,19A3,3 0 0,0 5,22C6.3,22 7.4,21.16 7.82,20H18C19.61,20 22,18.93 22,16V15C22,12.07 19.61,11 18,11M19,4A1,1 0 0,1 20,5A1,1 0 0,1 19,6A1,1 0 0,1 18,5A1,1 0 0,1 19,4M5,20A1,1 0 0,1 4,19A1,1 0 0,1 5,18A1,1 0 0,1 6,19A1,1 0 0,1 5,20Z\";\r\nvar mdiTransitDetour = \"M19 3A3 3 0 0 0 16.61 4.21A11.5 11.5 0 0 0 13.75 4L13.88 6A9.47 9.47 0 0 1 16 6.13A3 3 0 1 0 19 3M19 7A1 1 0 1 1 20 6A1 1 0 0 1 19 7M8.86 7.86L7.67 6.25A11.5 11.5 0 0 1 11.6 4.37L12.1 6.31A9.5 9.5 0 0 0 8.86 7.86M21 18A3 3 0 1 1 15.69 16.11A9.47 9.47 0 0 0 8.59 13.46C8.37 13.47 8.16 13.5 7.94 13.54A3 3 0 1 1 4.39 10.06A11.54 11.54 0 0 1 6.04 7.7L7.5 9.06A9.34 9.34 0 0 0 6.5 10.41A3.04 3.04 0 0 1 7.62 11.56C7.91 11.5 8.19 11.5 8.5 11.46A11.47 11.47 0 0 1 17.46 15.05A2.96 2.96 0 0 1 18 15A3 3 0 0 1 21 18Z\";\r\nvar mdiTransitSkip = \"M21 12C21 8 18.5 4.7 15 3.5C14.7 2.1 13.5 1 12 1C10.3 1 9 2.3 9 4S10.3 7 12 7C13.1 7 14.1 6.4 14.6 5.5C17.2 6.5 19 9 19 12C19 14.9 17.2 17.5 14.6 18.5C14.1 17.6 13.1 17 12 17C10.3 17 9 18.3 9 20S10.3 23 12 23C13.5 23 14.7 21.9 15 20.5C18.5 19.3 21 15.9 21 12M12 5C11.4 5 11 4.6 11 4S11.4 3 12 3 13 3.4 13 4 12.6 5 12 5M12 21C11.4 21 11 20.6 11 20S11.4 19 12 19 13 19.4 13 20 12.6 21 12 21M12 9C13.7 9 15 10.3 15 12S13.7 15 12 15 9 13.7 9 12 10.3 9 12 9Z\";\r\nvar mdiTransitTransfer = \"M16.5,15.5H22V17H16.5V18.75L14,16.25L16.5,13.75V15.5M19.5,19.75V18L22,20.5L19.5,23V21.25H14V19.75H19.5M9.5,5.5A2,2 0 0,1 7.5,3.5A2,2 0 0,1 9.5,1.5A2,2 0 0,1 11.5,3.5A2,2 0 0,1 9.5,5.5M5.75,8.9L4,9.65V13H2V8.3L7.25,6.15C7.5,6.05 7.75,6 8,6C8.7,6 9.35,6.35 9.7,6.95L10.65,8.55C11.55,10 13.15,11 15,11V13C12.8,13 10.85,12 9.55,10.4L8.95,13.4L11,15.45V23H9V17L6.85,15L5.1,23H3L5.75,8.9Z\";\r\nvar mdiTransition = \"M15,2A7,7 0 0,1 22,9C22,11.71 20.46,14.05 18.22,15.22C17.55,16.5 16.5,17.55 15.22,18.22C14.05,20.46 11.71,22 9,22A7,7 0 0,1 2,15C2,12.29 3.54,9.95 5.78,8.78C6.45,7.5 7.5,6.45 8.78,5.78C9.95,3.54 12.29,2 15,2M12,19A7,7 0 0,1 5,12C4.37,12.84 4,13.87 4,15A5,5 0 0,0 9,20C10.13,20 11.16,19.63 12,19M15,16A7,7 0 0,1 8,9H8C7.37,9.84 7,10.87 7,12A5,5 0 0,0 12,17C13.13,17 14.16,16.63 15,16V16M15,4C13.87,4 12.84,4.37 12,5V5A7,7 0 0,1 19,12H19C19.63,11.16 20,10.13 20,9A5,5 0 0,0 15,4M10,9A5,5 0 0,0 15,14C15.6,14 16.17,13.9 16.7,13.7C16.9,13.17 17,12.6 17,12A5,5 0 0,0 12,7C11.4,7 10.83,7.1 10.3,7.3C10.1,7.83 10,8.4 10,9Z\";\r\nvar mdiTransitionMasked = \"M15,2C16.94,2 18.59,2.7 19.95,4.05C21.3,5.41 22,7.06 22,9C22,10.56 21.5,11.96 20.58,13.2C19.64,14.43 18.44,15.27 16.97,15.7L17,15.38V15C17,12.81 16.23,10.93 14.65,9.35C13.07,7.77 11.19,7 9,7H8.63L8.3,7.03C8.73,5.56 9.57,4.36 10.8,3.42C12.04,2.5 13.44,2 15,2M9,8A7,7 0 0,1 16,15A7,7 0 0,1 9,22A7,7 0 0,1 2,15A7,7 0 0,1 9,8M9,10A5,5 0 0,0 4,15A5,5 0 0,0 9,20A5,5 0 0,0 14,15A5,5 0 0,0 9,10Z\";\r\nvar mdiTranslate = \"M12.87,15.07L10.33,12.56L10.36,12.53C12.1,10.59 13.34,8.36 14.07,6H17V4H10V2H8V4H1V6H12.17C11.5,7.92 10.44,9.75 9,11.35C8.07,10.32 7.3,9.19 6.69,8H4.69C5.42,9.63 6.42,11.17 7.67,12.56L2.58,17.58L4,19L9,14L12.11,17.11L12.87,15.07M18.5,10H16.5L12,22H14L15.12,19H19.87L21,22H23L18.5,10M15.88,17L17.5,12.67L19.12,17H15.88Z\";\r\nvar mdiTranslateOff = \"M12.17,5.81C11.87,6.69 11.47,7.55 11,8.39L12.35,9.74C13.11,8.5 13.71,7.18 14.13,5.81H17.16V3.75H9.94V1.69H7.87V3.75H6.37L8.43,5.81H12.17M15.53,12.91L17.03,14.41L17.67,12.69L19.08,16.47L22.39,19.77L18.7,9.94H16.64L15.53,12.91M1.31,1.31L0,2.62L1.13,3.75H0.65V5.81H3.19L5.26,7.88H4.46C5.21,9.56 6.24,11.15 7.53,12.58L2.28,17.76L3.75,19.22L8.91,14.07L12.11,17.27L12.8,15.43L14.1,16.72L12,22.31H14.06L15.22,19.22H16.6L21.38,24L22.69,22.69L1.31,1.31Z\";\r\nvar mdiTransmissionTower = \"M8.28,5.45L6.5,4.55L7.76,2H16.23L17.5,4.55L15.72,5.44L15,4H9L8.28,5.45M18.62,8H14.09L13.3,5H10.7L9.91,8H5.38L4.1,10.55L5.89,11.44L6.62,10H17.38L18.1,11.45L19.89,10.56L18.62,8M17.77,22H15.7L15.46,21.1L12,15.9L8.53,21.1L8.3,22H6.23L9.12,11H11.19L10.83,12.35L12,14.1L13.16,12.35L12.81,11H14.88L17.77,22M11.4,15L10.5,13.65L9.32,18.13L11.4,15M14.68,18.12L13.5,13.64L12.6,15L14.68,18.12Z\";\r\nvar mdiTrashCan = \"M9,3V4H4V6H5V19A2,2 0 0,0 7,21H17A2,2 0 0,0 19,19V6H20V4H15V3H9M9,8H11V17H9V8M13,8H15V17H13V8Z\";\r\nvar mdiTrashCanOutline = \"M9,3V4H4V6H5V19A2,2 0 0,0 7,21H17A2,2 0 0,0 19,19V6H20V4H15V3H9M7,6H17V19H7V6M9,8V17H11V8H9M13,8V17H15V8H13Z\";\r\nvar mdiTray = \"M2 12H4V17H20V12H22V17A2 2 0 0 1 20 19H4A2 2 0 0 1 2 17Z\";\r\nvar mdiTrayAlert = \"M2 12H4V17H20V12H22V17A2 2 0 0 1 20 19H4A2 2 0 0 1 2 17M13 12H11V14H13M13 4H11V10H13Z\";\r\nvar mdiTrayFull = \"M18 5H6V7H18M6 9H18V11H6M2 12H4V17H20V12H22V17A2 2 0 0 1 20 19H4A2 2 0 0 1 2 17M18 13H6V15H18Z\";\r\nvar mdiTrayMinus = \"M16 10H8V8H16M2 17A2 2 0 0 0 4 19H20A2 2 0 0 0 22 17V12H20V17H4V12H2Z\";\r\nvar mdiTrayPlus = \"M2 12H4V17H20V12H22V17A2 2 0 0 1 20 19H4A2 2 0 0 1 2 17M11 5H13V8H16V10H13V13H11V10H8V8H11Z\";\r\nvar mdiTrayRemove = \"M2 17A2 2 0 0 0 4 19H20A2 2 0 0 0 22 17V12H20V17H4V12H2M14.12 5.46L15.54 6.88L13.41 9L15.54 11.12L14.12 12.54L12 10.41L9.88 12.54L8.46 11.12L10.59 9L8.46 6.88L9.88 5.46L12 7.59Z\";\r\nvar mdiTreasureChest = \"M5,4H19A3,3 0 0,1 22,7V11H15V10H9V11H2V7A3,3 0 0,1 5,4M11,11H13V13H11V11M2,12H9V13L11,15H13L15,13V12H22V20H2V12Z\";\r\nvar mdiTree = \"M11,21V16.74C10.53,16.91 10.03,17 9.5,17C7,17 5,15 5,12.5C5,11.23 5.5,10.09 6.36,9.27C6.13,8.73 6,8.13 6,7.5C6,5 8,3 10.5,3C12.06,3 13.44,3.8 14.25,5C14.33,5 14.41,5 14.5,5A5.5,5.5 0 0,1 20,10.5A5.5,5.5 0 0,1 14.5,16C14,16 13.5,15.93 13,15.79V21H11Z\";\r\nvar mdiTreeOutline = \"M10.5,3C8,3 6,5 6,7.5C6,8.11 6.13,8.71 6.37,9.27C5.5,10.12 5,11.28 5,12.5C5,15 7,17 9.5,17C10,17 10.5,16.89 11,16.72V21H13V15.77C13.5,15.91 14,16 14.5,16A5.5,5.5 0 0,0 20,10.5A5.5,5.5 0 0,0 14.5,5C14.41,5 14.33,5 14.24,5C13.41,3.76 12,3 10.5,3M10.5,5C11.82,5 12.91,6.03 13,7.35C13.46,7.12 14,7 14.5,7A3.5,3.5 0 0,1 18,10.5A3.5,3.5 0 0,1 14.5,14C13.54,14 12.63,13.61 11.96,12.91C11.76,14.12 10.72,15 9.5,15A2.5,2.5 0 0,1 7,12.5C7,11.12 7.8,10.54 9,9.79C8.2,8.76 8,8.16 8,7.5A2.5,2.5 0 0,1 10.5,5Z\";\r\nvar mdiTrello = \"M19.5,2H4.5A2.5,2.5 0 0,0 2,4.5V19.5A2.5,2.5 0 0,0 4.5,22H19.5A2.5,2.5 0 0,0 22,19.5V4.5A2.5,2.5 0 0,0 19.5,2M10.7,17.2A1.2,1.2 0 0,1 9.5,18.4H5.8C5.14,18.4 4.6,17.86 4.6,17.2V5.8A1.2,1.2 0 0,1 5.8,4.6H9.5C10.16,4.6 10.7,5.14 10.7,5.8V17.2M19.4,12.2C19.4,12.86 18.86,13.4 18.2,13.4H14.5C13.84,13.4 13.3,12.86 13.3,12.2V5.8C13.3,5.14 13.84,4.6 14.5,4.6H18.2C18.86,4.6 19.4,5.14 19.4,5.8V12.2Z\";\r\nvar mdiTrendingDown = \"M16,18L18.29,15.71L13.41,10.83L9.41,14.83L2,7.41L3.41,6L9.41,12L13.41,8L19.71,14.29L22,12V18H16Z\";\r\nvar mdiTrendingNeutral = \"M22,12L18,8V11H3V13H18V16L22,12Z\";\r\nvar mdiTrendingUp = \"M16,6L18.29,8.29L13.41,13.17L9.41,9.17L2,16.59L3.41,18L9.41,12L13.41,16L19.71,9.71L22,12V6H16Z\";\r\nvar mdiTriangle = \"M1,21H23L12,2\";\r\nvar mdiTriangleOutline = \"M12,2L1,21H23M12,6L19.53,19H4.47\";\r\nvar mdiTriangleWave = \"M22 12L17 22L7.1 6.04L4.24 12H2L7 2L16.9 17.96L19.76 12H22Z\";\r\nvar mdiTriforce = \"M1.5,21L12,3.5L22.5,21H1.5M12,21L17,12H7L12,21Z\";\r\nvar mdiTrophy = \"M18 2C17.1 2 16 3 16 4H8C8 3 6.9 2 6 2H2V11C2 12 3 13 4 13H6.2C6.6 15 7.9 16.7 11 17V19.08C8 19.54 8 22 8 22H16C16 22 16 19.54 13 19.08V17C16.1 16.7 17.4 15 17.8 13H20C21 13 22 12 22 11V2H18M6 11H4V4H6V11M20 11H18V4H20V11Z\";\r\nvar mdiTrophyAward = \"M15.2 10.7L16.6 16L12 12.2L7.4 16L8.8 10.8L4.6 7.3L10 7L12 2L14 7L19.4 7.3L15.2 10.7M14 19H13V16L12 15L11 16V19H10C8.9 19 8 19.9 8 21V22H16V21C16 19.9 15.11 19 14 19Z\";\r\nvar mdiTrophyBroken = \"M6.2 13C6.6 14.8 7.6 16.3 10 16.8V19.34C8 20.12 8 22 8 22H13.2L10.2 15L14.2 10L10.7 4H8C8 3 6.9 2 6 2H2V11C2 12 3 13 4 13H6.2M6 11H4V4H6V11M17.8 13H20C21 13 22 12 22 11V2H18C17.1 2 16 3 16 4H13.9L16.7 10L12.2 15L13.2 22H16C16 22 16 20.12 14 19.34L14 16.85C16.39 16.35 17.5 14.7 17.8 13M20 11H18V4H20V11Z\";\r\nvar mdiTrophyOutline = \"M18 2C17.1 2 16 3 16 4H8C8 3 6.9 2 6 2H2V11C2 12 3 13 4 13H6.2C6.6 15 7.9 16.7 11 17V19.08C8 19.54 8 22 8 22H16C16 22 16 19.54 13 19.08V17C16.1 16.7 17.4 15 17.8 13H20C21 13 22 12 22 11V2H18M6 11H4V4H6V11M16 11.5C16 13.43 15.42 15 12 15C8.59 15 8 13.43 8 11.5V6H16V11.5M20 11H18V4H20V11Z\";\r\nvar mdiTrophyVariant = \"M17 4V2H7V4H2V11C2 12.1 2.9 13 4 13H7.1C7.5 14.96 9.04 16.5 11 16.9V19.08C8 19.54 8 22 8 22H16C16 22 16 19.54 13 19.08V16.9C14.96 16.5 16.5 14.96 16.9 13H20C21.1 13 22 12.1 22 11V4H17M4 11V6H7V11L4 11M20 11L17 11V6H20L20 11Z\";\r\nvar mdiTrophyVariantOutline = \"M17 4V2H7V4H2V11C2 12.1 2.9 13 4 13H7.1C7.5 14.96 9.04 16.5 11 16.9V19.08C8 19.54 8 22 8 22H16C16 22 16 19.54 13 19.08V16.9C14.96 16.5 16.5 14.96 16.9 13H20C21.1 13 22 12.1 22 11V4H17M4 11V6H7V11L4 11M15 12C15 13.65 13.65 15 12 15S9 13.65 9 12V4H15V12M20 11L17 11V6H20L20 11Z\";\r\nvar mdiTruck = \"M18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5M19.5,9.5L21.46,12H17V9.5M6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5M20,8H17V4H3C1.89,4 1,4.89 1,6V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V12L20,8Z\";\r\nvar mdiTruckCheck = \"M3,4H17V8H20L23,12V17H21A3,3 0 0,1 18,20A3,3 0 0,1 15,17H9A3,3 0 0,1 6,20A3,3 0 0,1 3,17H1V6C1,4.89 1.9,4 3,4M17,9.5V12H21.47L19.5,9.5H17M6,15.5A1.5,1.5 0 0,0 4.5,17A1.5,1.5 0 0,0 6,18.5A1.5,1.5 0 0,0 7.5,17A1.5,1.5 0 0,0 6,15.5M18,15.5A1.5,1.5 0 0,0 16.5,17A1.5,1.5 0 0,0 18,18.5A1.5,1.5 0 0,0 19.5,17A1.5,1.5 0 0,0 18,15.5M8,14L14,8L12.59,6.58L8,11.17L5.91,9.08L4.5,10.5L8,14Z\";\r\nvar mdiTruckCheckOutline = \"M18 18.5C18.83 18.5 19.5 17.83 19.5 17C19.5 16.17 18.83 15.5 18 15.5C17.17 15.5 16.5 16.17 16.5 17C16.5 17.83 17.17 18.5 18 18.5M19.5 9.5H17V12H21.46L19.5 9.5M6 18.5C6.83 18.5 7.5 17.83 7.5 17C7.5 16.17 6.83 15.5 6 15.5C5.17 15.5 4.5 16.17 4.5 17C4.5 17.83 5.17 18.5 6 18.5M20 8L23 12V17H21C21 18.66 19.66 20 18 20C16.34 20 15 18.66 15 17H9C9 18.66 7.66 20 6 20C4.34 20 3 18.66 3 17H1V6C1 4.89 1.89 4 3 4H17V8H20M3 6V15H3.76C4.31 14.39 5.11 14 6 14C6.89 14 7.69 14.39 8.24 15H15V6H3M5 10.5L6.5 9L8 10.5L11.5 7L13 8.5L8 13.5L5 10.5Z\";\r\nvar mdiTruckDelivery = \"M3,4A2,2 0 0,0 1,6V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V12L20,8H17V4M10,6L14,10L10,14V11H4V9H10M17,9.5H19.5L21.47,12H17M6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5M18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5Z\";\r\nvar mdiTruckDeliveryOutline = \"M18 18.5C18.83 18.5 19.5 17.83 19.5 17C19.5 16.17 18.83 15.5 18 15.5C17.17 15.5 16.5 16.17 16.5 17C16.5 17.83 17.17 18.5 18 18.5M19.5 9.5H17V12H21.46L19.5 9.5M6 18.5C6.83 18.5 7.5 17.83 7.5 17C7.5 16.17 6.83 15.5 6 15.5C5.17 15.5 4.5 16.17 4.5 17C4.5 17.83 5.17 18.5 6 18.5M20 8L23 12V17H21C21 18.66 19.66 20 18 20C16.34 20 15 18.66 15 17H9C9 18.66 7.66 20 6 20C4.34 20 3 18.66 3 17H1V6C1 4.89 1.89 4 3 4H17V8H20M3 6V15H3.76C4.31 14.39 5.11 14 6 14C6.89 14 7.69 14.39 8.24 15H15V6H3M10 7L13.5 10.5L10 14V11.5H5V9.5H10V7Z\";\r\nvar mdiTruckFast = \"M3,13.5L2.25,12H7.5L6.9,10.5H2L1.25,9H9.05L8.45,7.5H1.11L0.25,6H4A2,2 0 0,1 6,4H18V8H21L24,12V17H22A3,3 0 0,1 19,20A3,3 0 0,1 16,17H12A3,3 0 0,1 9,20A3,3 0 0,1 6,17H4V13.5H3M19,18.5A1.5,1.5 0 0,0 20.5,17A1.5,1.5 0 0,0 19,15.5A1.5,1.5 0 0,0 17.5,17A1.5,1.5 0 0,0 19,18.5M20.5,9.5H18V12H22.46L20.5,9.5M9,18.5A1.5,1.5 0 0,0 10.5,17A1.5,1.5 0 0,0 9,15.5A1.5,1.5 0 0,0 7.5,17A1.5,1.5 0 0,0 9,18.5Z\";\r\nvar mdiTruckFastOutline = \"M.75 7.5H10.5L11.25 9H1.5L.75 7.5M1.75 10.5H11.5L12.25 12H2.5L1.75 10.5M18 18.5C18.83 18.5 19.5 17.83 19.5 17C19.5 16.17 18.83 15.5 18 15.5C17.17 15.5 16.5 16.17 16.5 17C16.5 17.83 17.17 18.5 18 18.5M19.5 9.5H17V12H21.46L19.5 9.5M8 18.5C8.83 18.5 9.5 17.83 9.5 17C9.5 16.17 8.83 15.5 8 15.5C7.17 15.5 6.5 16.17 6.5 17C6.5 17.83 7.17 18.5 8 18.5M20 8L23 12V17H21C21 18.66 19.66 20 18 20C16.34 20 15 18.66 15 17H11C11 18.66 9.65 20 8 20C6.34 20 5 18.66 5 17H3V13.5 13.5H5V15H5.76C6.31 14.39 7.11 14 8 14C8.89 14 9.69 14.39 10.24 15H15V6H3V6C3 4.89 3.89 4 5 4H17V8H20Z\";\r\nvar mdiTruckOutline = \"M18 18.5C18.83 18.5 19.5 17.83 19.5 17C19.5 16.17 18.83 15.5 18 15.5C17.17 15.5 16.5 16.17 16.5 17C16.5 17.83 17.17 18.5 18 18.5M19.5 9.5H17V12H21.46L19.5 9.5M6 18.5C6.83 18.5 7.5 17.83 7.5 17C7.5 16.17 6.83 15.5 6 15.5C5.17 15.5 4.5 16.17 4.5 17C4.5 17.83 5.17 18.5 6 18.5M20 8L23 12V17H21C21 18.66 19.66 20 18 20C16.34 20 15 18.66 15 17H9C9 18.66 7.66 20 6 20C4.34 20 3 18.66 3 17H1V6C1 4.89 1.89 4 3 4H17V8H20M3 6V15H3.76C4.31 14.39 5.11 14 6 14C6.89 14 7.69 14.39 8.24 15H15V6H3Z\";\r\nvar mdiTruckTrailer = \"M22,15V17H10A3,3 0 0,1 7,20A3,3 0 0,1 4,17H2V6A2,2 0 0,1 4,4H17A2,2 0 0,1 19,6V15H22M7,16A1,1 0 0,0 6,17A1,1 0 0,0 7,18A1,1 0 0,0 8,17A1,1 0 0,0 7,16Z\";\r\nvar mdiTrumpet = \"M22 6C21 11 15 11 15 11H4C3 11 2 10 2 10H1V14H2C2 14 3 13 4 13H4.3C4.1 13.3 4 13.6 4 14V16C4 17.1 4.9 18 6 18H7V19H9V18H10V19H12V18H13V19H15V18H16C17.1 18 18 17.1 18 16V14C18 13.9 18 13.7 17.9 13.6C19.6 14.2 21.4 15.4 22 18H23V6H22M6 16.5C5.7 16.5 5.5 16.3 5.5 16V14C5.5 13.7 5.7 13.5 6 13.5H7V16.5H6M9 16.5V13.5H10V16.5H9M12 16.5V13.5H13V16.5H12M16.5 16C16.5 16.3 16.3 16.5 16 16.5H15V13.5H16C16.3 13.5 16.5 13.7 16.5 14V16M9 10H7V9H9V10M12 10H10V9H12V10M15 10H13V9H15V10Z\";\r\nvar mdiTshirtCrew = \"M16,21H8A1,1 0 0,1 7,20V12.07L5.7,13.07C5.31,13.46 4.68,13.46 4.29,13.07L1.46,10.29C1.07,9.9 1.07,9.27 1.46,8.88L7.34,3H9C9,4.1 10.34,5 12,5C13.66,5 15,4.1 15,3H16.66L22.54,8.88C22.93,9.27 22.93,9.9 22.54,10.29L19.71,13.12C19.32,13.5 18.69,13.5 18.3,13.12L17,12.12V20A1,1 0 0,1 16,21\";\r\nvar mdiTshirtCrewOutline = \"M16,21H8A1,1 0 0,1 7,20V12.07L5.7,13.12C5.31,13.5 4.68,13.5 4.29,13.12L1.46,10.29C1.07,9.9 1.07,9.27 1.46,8.88L7.34,3H9C9,4.1 10.34,5 12,5C13.66,5 15,4.1 15,3H16.66L22.54,8.88C22.93,9.27 22.93,9.9 22.54,10.29L19.71,13.12C19.32,13.5 18.69,13.5 18.3,13.12L17,12.07V20A1,1 0 0,1 16,21M20.42,9.58L16.11,5.28C15.8,5.63 15.43,5.94 15,6.2C14.16,6.7 13.13,7 12,7C10.3,7 8.79,6.32 7.89,5.28L3.58,9.58L5,11L8,9H9V19H15V9H16L19,11L20.42,9.58Z\";\r\nvar mdiTshirtV = \"M16,21H8A1,1 0 0,1 7,20V12.07L5.7,13.07C5.31,13.46 4.68,13.46 4.29,13.07L1.46,10.29C1.07,9.9 1.07,9.27 1.46,8.88L7.34,3H9C9.29,4.8 10.4,6.37 12,7.25C13.6,6.37 14.71,4.8 15,3H16.66L22.54,8.88C22.93,9.27 22.93,9.9 22.54,10.29L19.71,13.12C19.32,13.5 18.69,13.5 18.3,13.12L17,12.12V20A1,1 0 0,1 16,21\";\r\nvar mdiTshirtVOutline = \"M16,21H8A1,1 0 0,1 7,20V12.07L5.7,13.12C5.31,13.5 4.68,13.5 4.29,13.12L1.46,10.29C1.07,9.9 1.07,9.27 1.46,8.88L7.34,3H9C9,4.1 10,6 12,7.25C14,6 15,4.1 15,3H16.66L22.54,8.88C22.93,9.27 22.93,9.9 22.54,10.29L19.71,13.12C19.32,13.5 18.69,13.5 18.3,13.12L17,12.07V20A1,1 0 0,1 16,21M20.42,9.58L16.11,5.28C15,7 14,8.25 12,9.25C10,8.25 9,7 7.89,5.28L3.58,9.58L5,11L8,9H9V19H15V9H16L19,11L20.42,9.58Z\";\r\nvar mdiTumbleDryer = \"M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M7,4A1,1 0 0,0 6,5A1,1 0 0,0 7,6A1,1 0 0,0 8,5A1,1 0 0,0 7,4M10,4A1,1 0 0,0 9,5A1,1 0 0,0 10,6A1,1 0 0,0 11,5A1,1 0 0,0 10,4M12,8A6,6 0 0,0 6,14A6,6 0 0,0 12,20A6,6 0 0,0 18,14A6,6 0 0,0 12,8M8.11,10.5H10C9.76,11.88 10,12.67 10.58,13.29C11.68,14.36 12.16,15.71 11.89,17.5H10C10.24,16.12 10,15.33 9.42,14.71C8.32,13.64 7.85,12.29 8.11,10.5M12.11,10.5H14C13.76,11.88 14,12.67 14.58,13.29C15.68,14.36 16.16,15.71 15.89,17.5H14C14.24,16.12 14,15.33 13.42,14.71C12.32,13.64 11.85,12.29 12.11,10.5Z\";\r\nvar mdiTumbleDryerAlert = \"M4 2H16C17.11 2 18 2.9 18 4V20C18 21.11 17.11 22 16 22H4C2.9 22 2 21.11 2 20V4C2 2.9 2.9 2 4 2M5 4C4.45 4 4 4.45 4 5S4.45 6 5 6 6 5.55 6 5 5.55 4 5 4M8 4C7.45 4 7 4.45 7 5S7.45 6 8 6 9 5.55 9 5 8.55 4 8 4M10 8C6.69 8 4 10.69 4 14S6.69 20 10 20 16 17.31 16 14 13.31 8 10 8M6.11 10.5H8C7.76 11.88 8 12.67 8.58 13.29C9.68 14.36 10.16 15.71 9.89 17.5H8C8.24 16.12 8 15.33 7.42 14.71C6.32 13.64 5.85 12.29 6.11 10.5M10.11 10.5H12C11.76 11.88 12 12.67 12.58 13.29C13.68 14.36 14.16 15.71 13.89 17.5H12C12.24 16.12 12 15.33 11.42 14.71C10.32 13.64 9.85 12.29 10.11 10.5M20 15H22V17H20V15M20 7H22V13H20V7Z\";\r\nvar mdiTumbleDryerOff = \"M22.11 21.46L2.39 1.73L1.11 3L4 5.89V20C4 21.11 4.89 22 6 22H18C18.58 22 19.1 21.75 19.46 21.35L20.84 22.73L22.11 21.46M12 20C8.69 20 6 17.31 6 14C6 12.32 6.7 10.8 7.82 9.71L8.61 10.5H8.11C7.85 12.29 8.32 13.64 9.42 14.71C10 15.33 10.24 16.12 10 17.5H11.89C12.16 15.71 11.68 14.36 10.58 13.29C10.22 12.91 10 12.44 9.95 11.84L14.03 15.92C14.11 16.35 14.11 16.86 14 17.5H15.61L16.29 18.18C15.2 19.3 13.69 20 12 20M11.25 8.05C11.5 8 11.75 8 12 8C15.31 8 18 10.69 18 14C18 14.25 18 14.5 17.95 14.75L20 16.8V4C20 2.9 19.11 2 18 2H6C5.76 2 5.54 2.05 5.33 2.13L11.25 8.05M10 4C10.55 4 11 4.45 11 5S10.55 6 10 6 9 5.55 9 5 9.45 4 10 4Z\";\r\nvar mdiTune = \"M3,17V19H9V17H3M3,5V7H13V5H3M13,21V19H21V17H13V15H11V21H13M7,9V11H3V13H7V15H9V9H7M21,13V11H11V13H21M15,9H17V7H21V5H17V3H15V9Z\";\r\nvar mdiTuneVariant = \"M8 13C6.14 13 4.59 14.28 4.14 16H2V18H4.14C4.59 19.72 6.14 21 8 21S11.41 19.72 11.86 18H22V16H11.86C11.41 14.28 9.86 13 8 13M8 19C6.9 19 6 18.1 6 17C6 15.9 6.9 15 8 15S10 15.9 10 17C10 18.1 9.1 19 8 19M19.86 6C19.41 4.28 17.86 3 16 3S12.59 4.28 12.14 6H2V8H12.14C12.59 9.72 14.14 11 16 11S19.41 9.72 19.86 8H22V6H19.86M16 9C14.9 9 14 8.1 14 7C14 5.9 14.9 5 16 5S18 5.9 18 7C18 8.1 17.1 9 16 9Z\";\r\nvar mdiTuneVertical = \"M7 3H5V9H7V3M19 3H17V13H19V3M3 13H5V21H7V13H9V11H3V13M15 7H13V3H11V7H9V9H15V7M11 21H13V11H11V21M15 15V17H17V21H19V17H21V15H15Z\";\r\nvar mdiTuneVerticalVariant = \"M8 12.14V2H6V12.14C4.28 12.59 3 14.14 3 16S4.28 19.41 6 19.86V22H8V19.86C9.72 19.41 11 17.86 11 16S9.72 12.59 8 12.14M7 14C8.1 14 9 14.9 9 16S8.1 18 7 18C5.9 18 5 17.1 5 16S5.9 14 7 14M18 2H16V4.14C14.28 4.59 13 6.14 13 8S14.28 11.41 16 11.86V22H18V11.86C19.72 11.41 21 9.86 21 8S19.72 4.59 18 4.14V2M17 6C18.1 6 19 6.9 19 8S18.1 10 17 10C15.9 10 15 9.1 15 8S15.9 6 17 6Z\";\r\nvar mdiTurnstile = \"M22,22H16V11L10,5V2H22V22M9.17,6.17C8.42,6.92 8,7.94 8,9H2V11H8.55C8.9,11.6 9.4,12.1 10,12.45V19H12V13C13.06,13 14.08,12.58 14.83,11.83L9.17,6.17Z\";\r\nvar mdiTurnstileOutline = \"M13.41,10.41C13.04,10.79 12.53,11 12,11A2,2 0 0,1 10,9C10,8.47 10.21,7.96 10.59,7.59L9.17,6.17C8.42,6.92 8,7.94 8,9H2V11H8.55C8.9,11.6 9.4,12.1 10,12.45V19H12V13C13.06,13 14.08,12.58 14.83,11.83L13.41,10.41M10,2V5L16,11V22H22V2H10M20,20H18V10.17L12,4.17V4H20V20Z\";\r\nvar mdiTurtle = \"M8.47,5.95C8.95,5.67 9.47,5.44 10,5.28V4C10,2.9 10.87,2 11.97,1.97C13.13,2 14,2.9 14,4V5.28C14.53,5.45 15.05,5.67 15.53,5.95L13.93,8.07H10.07L8.47,5.95M19,12C19,12.5 18.95,12.95 18.86,13.4L16.33,12.62L15.14,8.96L16.74,6.85C17.17,7.25 17.55,7.7 17.88,8.2C18.67,8.13 19.43,8.25 20.11,8.59C21.14,9.12 21.84,10.13 22,11.28L19,11.64C19,11.76 19,11.88 19,12M5,12C5,11.88 5,11.76 5,11.65L2,11.28C2.16,10.13 2.86,9.12 3.89,8.59C4.57,8.25 5.34,8.13 6.08,8.26C6.41,7.75 6.79,7.28 7.24,6.87L8.86,8.95L7.67,12.62L5.14,13.4C5.05,12.95 5,12.5 5,12M10.24,9.57H13.76L14.85,12.93L12,15L9.15,12.93L10.24,9.57M8.13,14.05L11.25,16.31V18.96C10.68,18.9 10.13,18.77 9.62,18.58L8.39,21.34C7.33,20.87 6.57,19.9 6.37,18.76C6.23,18 6.35,17.24 6.69,16.56C6.24,16.04 5.87,15.46 5.59,14.82L8.13,14.05M15.87,14.05L18.41,14.82C18.13,15.46 17.76,16.04 17.31,16.56C17.65,17.24 17.77,18 17.64,18.76C17.43,19.9 16.67,20.87 15.61,21.34L14.39,18.58C13.86,18.77 13.33,18.94 12.75,19V16.31L15.87,14.05Z\";\r\nvar mdiTwitch = \"M11.64 5.93H13.07V10.21H11.64M15.57 5.93H17V10.21H15.57M7 2L3.43 5.57V18.43H7.71V22L11.29 18.43H14.14L20.57 12V2M19.14 11.29L16.29 14.14H13.43L10.93 16.64V14.14H7.71V3.43H19.14Z\";\r\nvar mdiTwitter = \"M22.46,6C21.69,6.35 20.86,6.58 20,6.69C20.88,6.16 21.56,5.32 21.88,4.31C21.05,4.81 20.13,5.16 19.16,5.36C18.37,4.5 17.26,4 16,4C13.65,4 11.73,5.92 11.73,8.29C11.73,8.63 11.77,8.96 11.84,9.27C8.28,9.09 5.11,7.38 3,4.79C2.63,5.42 2.42,6.16 2.42,6.94C2.42,8.43 3.17,9.75 4.33,10.5C3.62,10.5 2.96,10.3 2.38,10C2.38,10 2.38,10 2.38,10.03C2.38,12.11 3.86,13.85 5.82,14.24C5.46,14.34 5.08,14.39 4.69,14.39C4.42,14.39 4.15,14.36 3.89,14.31C4.43,16 6,17.26 7.89,17.29C6.43,18.45 4.58,19.13 2.56,19.13C2.22,19.13 1.88,19.11 1.54,19.07C3.44,20.29 5.7,21 8.12,21C16,21 20.33,14.46 20.33,8.79C20.33,8.6 20.33,8.42 20.32,8.23C21.16,7.63 21.88,6.87 22.46,6Z\";\r\nvar mdiTwitterRetweet = \"M6,5.75L10.25,10H7V16H13.5L15.5,18H7A2,2 0 0,1 5,16V10H1.75L6,5.75M18,18.25L13.75,14H17V8H10.5L8.5,6H17A2,2 0 0,1 19,8V14H22.25L18,18.25Z\";\r\nvar mdiTwoFactorAuthentication = \"M2,7V9H6V11H4A2,2 0 0,0 2,13V17H8V15H4V13H6A2,2 0 0,0 8,11V9C8,7.89 7.1,7 6,7H2M9,7V17H11V13H14V11H11V9H15V7H9M18,7A2,2 0 0,0 16,9V17H18V14H20V17H22V9A2,2 0 0,0 20,7H18M18,9H20V12H18V9Z\";\r\nvar mdiTypewriter = \"M20 13H16C16 14.1 15.1 15 14 15H10C8.9 15 8 14.1 8 13H4L2 18V20C2 21.1 2.9 22 4 22H20C21.1 22 22 21.1 22 20V18M6 20C5.11 20 4.66 18.92 5.29 18.29C5.92 17.66 7 18.11 7 19C7 19.55 6.55 20 6 20M10 20C9.11 20 8.66 18.92 9.29 18.29C9.92 17.66 11 18.11 11 19C11 19.55 10.55 20 10 20M14 20C13.11 20 12.66 18.92 13.29 18.29C13.92 17.66 15 18.11 15 19C15 19.55 14.55 20 14 20M18 20C17.11 20 16.66 18.92 17.29 18.29C17.92 17.66 19 18.11 19 19C19 19.55 18.55 20 18 20M18 10V3H6V10H3V12H21V10M8 5H16V6H8M8 7H14V8H8\";\r\nvar mdiUbisoft = \"M11.41,2C5.21,2 2.53,7.53 2.53,7.53L3.32,8.09C3.32,8.09 2.33,10 2.35,12.4C2.35,17.34 6.29,22 12.07,22C17.33,22 21.67,17.71 21.67,12.41C21.67,5.5 16.31,2 11.41,2M11.47,3.69C16.31,3.69 20.07,7.6 20.07,12.14C20.07,16.95 16.45,20.3 12.23,20.3C9.13,20.3 6.33,17.94 6.33,14.7C6.33,12.82 7.32,11.5 8.44,10.82L8.6,11C8.3,11.24 7.43,12.64 7.43,14C7.43,16.56 9.43,18.33 11.95,18.33C15.16,18.33 17.3,15.59 17.3,12.41C17.3,8.71 14.03,5.57 10.1,5.57C7.93,5.57 6.09,6.5 5.03,7.33L4.86,7.18C6.25,5.04 8.65,3.69 11.47,3.69M10,7.23C12.53,7.23 14.97,8.89 15.59,11.25L15.36,11.33C14.27,9.88 12.47,8.68 10.35,8.68C6.44,8.68 4.39,12.23 4.69,15.19L4.46,15.28C4.46,15.28 4.03,14.33 4.03,13.2C4.03,9.93 6.71,7.23 10,7.23M11.68,11.33C12.86,11.33 13.81,12.3 13.81,13.44C13.81,14.38 13.21,14.94 13.21,14.94L13.92,15.45C13.92,15.45 13.21,16.57 11.76,16.57C10.37,16.57 9.13,15.44 9.13,13.93C9.13,12.38 10.47,11.33 11.68,11.33Z\";\r\nvar mdiUbuntu = \"M22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2A10,10 0 0,1 22,12M14.34,7.74C14.92,8.07 15.65,7.87 16,7.3C16.31,6.73 16.12,6 15.54,5.66C14.97,5.33 14.23,5.5 13.9,6.1C13.57,6.67 13.77,7.41 14.34,7.74M11.88,15.5C11.35,15.5 10.85,15.39 10.41,15.18L9.57,16.68C10.27,17 11.05,17.22 11.88,17.22C12.37,17.22 12.83,17.15 13.28,17.03C13.36,16.54 13.64,16.1 14.1,15.84C14.56,15.57 15.08,15.55 15.54,15.72C16.43,14.85 17,13.66 17.09,12.33L15.38,12.31C15.22,14.1 13.72,15.5 11.88,15.5M11.88,8.5C13.72,8.5 15.22,9.89 15.38,11.69L17.09,11.66C17,10.34 16.43,9.15 15.54,8.28C15.08,8.45 14.55,8.42 14.1,8.16C13.64,7.9 13.36,7.45 13.28,6.97C12.83,6.85 12.37,6.78 11.88,6.78C11.05,6.78 10.27,6.97 9.57,7.32L10.41,8.82C10.85,8.61 11.35,8.5 11.88,8.5M8.37,12C8.37,10.81 8.96,9.76 9.86,9.13L9,7.65C7.94,8.36 7.15,9.43 6.83,10.69C7.21,11 7.45,11.47 7.45,12C7.45,12.53 7.21,13 6.83,13.31C7.15,14.56 7.94,15.64 9,16.34L9.86,14.87C8.96,14.24 8.37,13.19 8.37,12M14.34,16.26C13.77,16.59 13.57,17.32 13.9,17.9C14.23,18.47 14.97,18.67 15.54,18.34C16.12,18 16.31,17.27 16,16.7C15.65,16.12 14.92,15.93 14.34,16.26M5.76,10.8C5.1,10.8 4.56,11.34 4.56,12C4.56,12.66 5.1,13.2 5.76,13.2C6.43,13.2 6.96,12.66 6.96,12C6.96,11.34 6.43,10.8 5.76,10.8Z\";\r\nvar mdiUfo = \"M15.94 10.28C15.66 7.87 14 6 12 6S8.34 7.87 8.06 10.28C4.5 10.82 2 12.06 2 13.5C2 15.43 6.5 17 12 17S22 15.43 22 13.5C22 12.06 19.5 10.82 15.94 10.28Z\";\r\nvar mdiUfoOutline = \"M17 10.54C16.78 7.44 14.63 5 12 5S7.22 7.44 7 10.54C4 11.23 2 12.5 2 14C2 16.21 6.5 18 12 18S22 16.21 22 14C22 12.5 20 11.23 17 10.54M14.93 11.84C13.03 12.05 10.97 12.05 9.07 11.84C9.03 11.56 9 11.28 9 11C9 8.8 10.35 7 12 7S15 8.8 15 11C15 11.28 15 11.56 14.93 11.84Z\";\r\nvar mdiUltraHighDefinition = \"M9,7H11V11H13V7H15V17H13V13H11V17H9V7M17,7H20A3,3 0 0,1 23,10V14A3,3 0 0,1 20,17H17V7M20,15A1,1 0 0,0 21,14V10A1,1 0 0,0 20,9H19V15H20M7,14A3,3 0 0,1 4,17A3,3 0 0,1 1,14V7H3V14A1,1 0 0,0 4,15A1,1 0 0,0 5,14V7H7V14Z\";\r\nvar mdiUmbraco = \"M8.6,8.6L7.17,8.38C6.5,11.67 6.46,14.24 7.61,15.5C8.6,16.61 11.89,16.61 11.89,16.61C11.89,16.61 15.29,16.61 16.28,15.5C17.43,14.24 17.38,11.67 16.72,8.38L15.29,8.6C15.29,8.6 16.54,13.88 14.69,14.69C13.81,15.07 11.89,15.07 11.89,15.07C11.89,15.07 10.08,15.07 9.2,14.69C7.35,13.88 8.6,8.6 8.6,8.6M12,3A9,9 0 0,1 21,12A9,9 0 0,1 12,21A9,9 0 0,1 3,12A9,9 0 0,1 12,3Z\";\r\nvar mdiUmbrella = \"M12,2A9,9 0 0,1 21,11H13V19A3,3 0 0,1 10,22A3,3 0 0,1 7,19V18H9V19A1,1 0 0,0 10,20A1,1 0 0,0 11,19V11H3A9,9 0 0,1 12,2Z\";\r\nvar mdiUmbrellaClosed = \"M12 2C11.6 2 11.3 2.2 11.1 2.6L6.5 15H11V19C11 19.6 10.6 20 10 20C9.4 20 9 19.6 9 19V18H7V19C7 20.7 8.3 22 10 22S13 20.7 13 19V15H17.5L12.9 2.6C12.7 2.2 12.4 2 12 2Z\";\r\nvar mdiUmbrellaClosedOutline = \"M12 2C12.4 2 12.8 2.2 12.9 2.6L17.5 15H13V19C13 20.7 11.7 22 10 22S7 20.7 7 19V18H9V19C9 19.6 9.4 20 10 20C10.6 20 11 19.6 11 19V15H6.5L11.1 2.6C11.2 2.2 11.6 2 12 2M12 5.9L9.4 13H14.7L12 5.9Z\";\r\nvar mdiUmbrellaClosedVariant = \"M15 7L13 6V3.5C13 3.2 13.2 3 13.5 3S14 3.2 14 3.5V4H16V3.5C16 2.1 14.9 1 13.5 1S11 2.1 11 3.5V6L9 7L6 6L11.1 21.3C11.4 22.2 12.7 22.2 13 21.3C14.6 16.2 18 6 18 6L15 7M11 15L9 8.9L9.7 9.1L11 8.1V15M13 8.1L14.3 9.1L15 8.9L13 15V8.1Z\";\r\nvar mdiUmbrellaOutline = \"M12,4C8.9,4 6.18,6.03 5.3,9H18.7C17.82,6.04 15.09,4 12,4M12,2A9,9 0 0,1 21,11H13V19A3,3 0 0,1 10,22A3,3 0 0,1 7,19V18H9V19A1,1 0 0,0 10,20A1,1 0 0,0 11,19V11H3A9,9 0 0,1 12,2Z\";\r\nvar mdiUndo = \"M12.5,8C9.85,8 7.45,9 5.6,10.6L2,7V16H11L7.38,12.38C8.77,11.22 10.54,10.5 12.5,10.5C16.04,10.5 19.05,12.81 20.1,16L22.47,15.22C21.08,11.03 17.15,8 12.5,8Z\";\r\nvar mdiUndoVariant = \"M13.5,7A6.5,6.5 0 0,1 20,13.5A6.5,6.5 0 0,1 13.5,20H10V18H13.5C16,18 18,16 18,13.5C18,11 16,9 13.5,9H7.83L10.91,12.09L9.5,13.5L4,8L9.5,2.5L10.92,3.91L7.83,7H13.5M6,18H8V20H6V18Z\";\r\nvar mdiUnfoldLessHorizontal = \"M16.59,5.41L15.17,4L12,7.17L8.83,4L7.41,5.41L12,10M7.41,18.59L8.83,20L12,16.83L15.17,20L16.58,18.59L12,14L7.41,18.59Z\";\r\nvar mdiUnfoldLessVertical = \"M5.41,7.41L10,12L5.41,16.59L4,15.17L7.17,12L4,8.83L5.41,7.41M18.59,16.59L14,12L18.59,7.42L20,8.83L16.83,12L20,15.17L18.59,16.59Z\";\r\nvar mdiUnfoldMoreHorizontal = \"M12,18.17L8.83,15L7.42,16.41L12,21L16.59,16.41L15.17,15M12,5.83L15.17,9L16.58,7.59L12,3L7.41,7.59L8.83,9L12,5.83Z\";\r\nvar mdiUnfoldMoreVertical = \"M18.17,12L15,8.83L16.41,7.41L21,12L16.41,16.58L15,15.17L18.17,12M5.83,12L9,15.17L7.59,16.59L3,12L7.59,7.42L9,8.83L5.83,12Z\";\r\nvar mdiUngroup = \"M2,2H6V3H13V2H17V6H16V9H18V8H22V12H21V18H22V22H18V21H12V22H8V18H9V16H6V17H2V13H3V6H2V2M18,12V11H16V13H17V17H13V16H11V18H12V19H18V18H19V12H18M13,6V5H6V6H5V13H6V14H9V12H8V8H12V9H14V6H13M12,12H11V14H13V13H14V11H12V12Z\";\r\nvar mdiUnicode = \"M22 6A1.46 1.46 0 0 1 20.54 7.44A1.46 1.46 0 0 1 19.09 6A1.46 1.46 0 0 1 20.54 4.5A1.46 1.46 0 0 1 22 6M21.56 8.86H19.53C19.4 8.85 19.34 8.91 19.34 9V12.59C19.34 13.08 19.34 13.5 19.35 13.86L19.37 14.76C19.38 15 19.39 15.21 19.39 15.39C19.4 15.56 19.4 15.72 19.4 15.86H19.38C19.26 15.6 19.07 15.22 18.82 14.74C18.58 14.27 18.29 13.72 17.97 13.11C17.64 12.5 17.29 11.84 16.92 11.15C16.55 10.47 16.18 9.78 15.81 9.11C15.45 8.43 15.09 7.78 14.75 7.16C14.4 6.54 14.1 6 13.85 5.54C13.82 5.5 13.79 5.44 13.77 5.42C13.74 5.4 13.68 5.39 13.6 5.39H10.62C10.5 5.39 10.47 5.44 10.47 5.54H10.5C10.47 5.56 10.47 5.57 10.47 5.58V13.84C10.47 14.5 10.4 15 10.25 15.45C10.1 15.88 9.9 16.23 9.64 16.5C9.38 16.75 9.07 16.93 8.72 17.05C8.36 17.16 8 17.22 7.56 17.22C6.54 17.22 5.79 16.91 5.3 16.31C4.8 15.7 4.56 14.89 4.56 13.88V5.56C4.56 5.45 4.5 5.39 4.39 5.39H2.17C2.06 5.39 2 5.45 2 5.58V14.07C2 15 2.13 15.78 2.38 16.46C2.63 17.13 3 17.69 3.5 18.14C3.96 18.58 4.53 18.92 5.21 19.14C5.89 19.36 6.64 19.5 7.47 19.5C8.24 19.5 8.97 19.38 9.65 19.17C10.34 18.97 10.93 18.64 11.42 18.2C11.91 17.75 12.3 17.18 12.59 16.5C12.88 15.79 13.03 14.95 13.03 13.96V8.62C13.14 8.86 13.28 9.15 13.44 9.47C13.73 10.05 14.05 10.68 14.42 11.38C14.79 12.08 15.17 12.8 15.58 13.56C16 14.32 16.39 15.06 16.77 15.76C17.16 16.46 17.5 17.11 17.83 17.7C18.15 18.29 18.4 18.76 18.58 19.12C18.63 19.22 18.73 19.27 18.85 19.27H21.54C21.68 19.27 21.75 19.2 21.75 19.08V9.05C21.75 8.92 21.68 8.85 21.56 8.85Z\";\r\nvar mdiUnicorn = \"M22 5L21.11 6.34C21.65 6.7 22 7.31 22 8V11.5L20.5 12L18.96 9.54C18.83 9.33 18.5 9.42 18.5 9.67V13.25C18.5 14.23 18.11 15.11 17.5 15.78V22H15V17C14.92 17 14.84 17 14.75 17C14.54 17 14.33 16.97 14.13 16.94L9.45 16.16L8.57 18.12L9.54 22H6.96L6.04 18.3C5.97 18.03 6 17.74 6.11 17.5L7 15.5C6.12 14.92 5.53 13.94 5.5 12.81C5.46 12.96 5.44 13.18 5.47 13.5C5.5 13.94 5.61 14.59 5.54 15.31C5.5 16.03 5.18 16.77 4.76 17.26C4.32 17.75 3.85 18.09 3.35 18.35L2.65 17.65C2.84 17.18 3.03 16.76 3.07 16.37C3.13 16 3.06 15.7 2.95 15.43L2.42 14.3C2.21 13.79 1.95 13.05 2 12.18C2.03 11.33 2.5 10.22 3.39 9.61C4.29 9 5.26 8.91 6.05 9.08C6.55 9.18 7.06 9.42 7.5 9.76C7.87 9.59 8.3 9.5 8.75 9.5H14.5V9C14.5 6.79 16.29 5 18.5 5L22 2L21 5H22Z\";\r\nvar mdiUnicornVariant = \"M20 12V19L17 20L14 15.33C13.71 14.89 13 15.14 13.08 15.67L14 23L4 18L4.96 12.75C5.56 9.42 8.46 7 11.84 7H13L19 1L17 7H20L18.42 9.37C19.36 9.88 20 10.86 20 12Z\";\r\nvar mdiUnicycle = \"M13 9.09V5H14C14.55 5 15 4.55 15 4S14.55 3 14 3H10C9.45 3 9 3.45 9 4S9.45 5 10 5H11V9.09C8.16 9.57 6 12.03 6 15C6 18.31 8.69 21 12 21S18 18.31 18 15C18 12.03 15.84 9.57 13 9.09M12 19C9.79 19 8 17.21 8 15C8 13.14 9.28 11.59 11 11.14V16H13V11.14C14.72 11.59 16 13.14 16 15C16 17.21 14.21 19 12 19Z\";\r\nvar mdiUnity = \"M10.11,17H7.5L2.59,12L7.5,7H10.11L11.42,4.74L18.21,3L20.08,9.74L18.77,12L20.08,14.26L18.21,21L11.42,19.26L10.11,17M10.25,16.75L15.38,18.13L12.42,13H6.5L10.25,16.75M17.12,17.13L18.5,12L17.12,6.87L14.15,12L17.12,17.13M10.25,7.25L6.5,11H12.42L15.38,5.87L10.25,7.25Z\";\r\nvar mdiUnreal = \"M2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2A10,10 0 0,0 2,12M5.24,18.76C3.43,16.95 2.44,14.55 2.44,12C2.44,9.45 3.43,7.05 5.24,5.24C7.05,3.43 9.45,2.44 12,2.44C14.55,2.44 16.95,3.43 18.76,5.24C20.57,7.05 21.56,9.45 21.56,12C21.56,14.55 20.57,16.95 18.76,18.76C16.95,20.57 14.55,21.56 12,21.56C9.45,21.56 7.05,20.57 5.24,18.76M6.35,9.5C4.34,11.79 4.73,13.68 4.73,13.68C4.73,13.68 5.28,12.38 6.61,11C7.25,10.37 7.72,10.15 8.04,10.15C8.4,10.15 8.57,10.41 8.57,10.65V15.29C8.57,15.75 8.27,15.85 8,15.84C7.77,15.84 7.55,15.76 7.55,15.76C8.92,17.73 12.19,18 12.19,18L13.63,16.5H13.67L15,17.63C17.39,16.21 18.55,13.58 18.55,13.58C17.5,14.7 16.79,14.97 16.39,14.96C16.03,14.96 15.88,14.75 15.88,14.75C15.87,14.65 15.82,8.9 15.89,8.9C16.31,8.13 17.63,6.56 17.63,6.56C15.16,7.05 13.81,8.66 13.81,8.66C13.41,8.35 12.59,8.4 12.59,8.4C12.97,8.61 13.35,9.21 13.35,9.72V14.65C13.35,14.65 12.5,15.38 11.88,15.38C11.5,15.38 11.27,15.17 11.14,15C11.05,14.88 11,14.79 11,14.79V8.69C10.93,8.75 10.82,8.8 10.71,8.8C10.57,8.79 10.43,8.73 10.34,8.53C10.26,8.38 10.22,8.15 10.22,7.83C10.22,6.7 11.5,5.96 11.5,5.96C9.87,6.39 8.36,7.22 6.35,9.5\";\r\nvar mdiUntappd = \"M14.41,4C14.41,4 14.94,4.39 14.97,4.71C14.97,4.81 14.73,4.85 14.68,4.93C14.62,5 14.7,5.15 14.65,5.21C14.59,5.26 14.5,5.26 14.41,5.41C14.33,5.56 12.07,10.09 11.73,10.63C11.59,11.03 11.47,12.46 11.37,12.66C11.26,12.85 6.34,19.84 6.16,20.05C5.67,20.63 4.31,20.3 3.28,19.56C2.3,18.86 1.74,17.7 2.11,17.16C2.27,16.93 7.15,9.92 7.29,9.75C7.44,9.58 8.75,9 9.07,8.71C9.47,8.22 12.96,4.54 13.07,4.42C13.18,4.3 13.15,4.2 13.18,4.13C13.22,4.06 13.38,4.08 13.43,4C13.5,3.93 13.39,3.71 13.5,3.68C13.59,3.64 13.96,3.67 14.41,4M10.85,4.44L11.74,5.37L10.26,6.94L9.46,5.37C9.38,5.22 9.28,5.22 9.22,5.17C9.17,5.11 9.24,4.97 9.19,4.89C9.13,4.81 8.9,4.83 8.9,4.73C8.9,4.62 9.05,4.28 9.5,3.96C9.5,3.96 10.06,3.6 10.37,3.68C10.47,3.71 10.43,3.95 10.5,4C10.54,4.1 10.7,4.08 10.73,4.15C10.77,4.21 10.73,4.32 10.85,4.44M21.92,17.15C22.29,17.81 21.53,19 20.5,19.7C19.5,20.39 18.21,20.54 17.83,20C17.66,19.78 12.67,12.82 12.56,12.62C12.45,12.43 12.32,11 12.18,10.59L12.15,10.55C12.45,10 13.07,8.77 13.73,7.47C14.3,8.06 14.75,8.56 14.88,8.72C15.21,9 16.53,9.58 16.68,9.75C16.82,9.92 21.78,16.91 21.92,17.15Z\";\r\nvar mdiUpdate = \"M21,10.12H14.22L16.96,7.3C14.23,4.6 9.81,4.5 7.08,7.2C4.35,9.91 4.35,14.28 7.08,17C9.81,19.7 14.23,19.7 16.96,17C18.32,15.65 19,14.08 19,12.1H21C21,14.08 20.12,16.65 18.36,18.39C14.85,21.87 9.15,21.87 5.64,18.39C2.14,14.92 2.11,9.28 5.62,5.81C9.13,2.34 14.76,2.34 18.27,5.81L21,3V10.12M12.5,8V12.25L16,14.33L15.28,15.54L11,13V8H12.5Z\";\r\nvar mdiUpload = \"M9,16V10H5L12,3L19,10H15V16H9M5,20V18H19V20H5Z\";\r\nvar mdiUploadLock = \"M22 22H17C16.5 22 16 21.5 16 21V17C16 16.5 16.5 16 17 16V14.5C17 13.1 18.1 12 19.5 12C20.9 12 22 13.1 22 14.5V16C22.5 16 23 16.5 23 17V21C23 21.5 22.5 22 22 22M14 20H5V18H14V20M21 16V14.5C21 13.7 20.3 13 19.5 13C18.7 13 18 13.7 18 14.5V16H21M15 16H9V10H5L12 3L19 10H15V16Z\";\r\nvar mdiUploadLockOutline = \"M22 22H17C16.5 22 16 21.5 16 21V17C16 16.5 16.5 16 17 16V14.5C17 13.1 18.1 12 19.5 12C20.9 12 22 13.1 22 14.5V16C22.5 16 23 16.5 23 17V21C23 21.5 22.5 22 22 22M5 18H14V20H5V18M21 16V14.5C21 13.7 20.3 13 19.5 13C18.7 13 18 13.7 18 14.5V16H21M9 16V10H5L12 3L19 10H15V16H9M9.83 8H11V14H13V8H14.17L12 5.83L9.83 8Z\";\r\nvar mdiUploadMultiple = \"M9,14V8H5L12,1L19,8H15V14H9M5,18V16H19V18H5M19,20H5V22H19V20Z\";\r\nvar mdiUploadNetwork = \"M17,3A2,2 0 0,1 19,5V15A2,2 0 0,1 17,17H13V19H14A1,1 0 0,1 15,20H22V22H15A1,1 0 0,1 14,23H10A1,1 0 0,1 9,22H2V20H9A1,1 0 0,1 10,19H11V17H7C5.89,17 5,16.1 5,15V5A2,2 0 0,1 7,3H17M12,5.5L7.5,10H11V14H13V10H16.5L12,5.5Z\";\r\nvar mdiUploadNetworkOutline = \"M15,20A1,1 0 0,0 14,19H13V17H17A2,2 0 0,0 19,15V5A2,2 0 0,0 17,3H7A2,2 0 0,0 5,5V15A2,2 0 0,0 7,17H11V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15M7,15V5H17V15H7M12,6L8,10H11V14H13V10H16L12,6Z\";\r\nvar mdiUploadOff = \"M22.11 21.46L2.39 1.73L1.11 3L6.56 8.45L5 10H8.11L9 10.89V16H14.11L16.11 18H5V20H18.11L20.84 22.73L22.11 21.46M15 10H19L12 3L9.1 5.9L15 11.8V10Z\";\r\nvar mdiUploadOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L6.56 8.45L5 10H8.11L9 10.89V16H14.11L16.11 18H5V20H18.11L20.84 22.73L22.11 21.46M11 14V12.89L12.11 14H11M12 5.8L14.2 8H13V9.8L15 11.8V10H19L12 3L9.1 5.9L10.5 7.3L12 5.8Z\";\r\nvar mdiUploadOutline = \"M9,10V16H15V10H19L12,3L5,10H9M12,5.8L14.2,8H13V14H11V8H9.8L12,5.8M19,18H5V20H19V18Z\";\r\nvar mdiUsb = \"M15,7V11H16V13H13V5H15L12,1L9,5H11V13H8V10.93C8.7,10.56 9.2,9.85 9.2,9C9.2,7.78 8.21,6.8 7,6.8C5.78,6.8 4.8,7.78 4.8,9C4.8,9.85 5.3,10.56 6,10.93V13A2,2 0 0,0 8,15H11V18.05C10.29,18.41 9.8,19.15 9.8,20A2.2,2.2 0 0,0 12,22.2A2.2,2.2 0 0,0 14.2,20C14.2,19.15 13.71,18.41 13,18.05V15H16A2,2 0 0,0 18,13V11H19V7H15Z\";\r\nvar mdiUsbFlashDrive = \"M8 15C8.55 15 9 15.45 9 16C9 16.55 8.55 17 8 17C7.45 17 7 16.55 7 16C7 15.45 7.45 15 8 15M15.07 4.69L16.5 6.1L15.07 7.5L13.66 6.1L15.07 4.69M17.9 7.5L19.31 8.93L17.9 10.34L16.5 8.93L17.9 7.5M8 13C6.34 13 5 14.34 5 16C5 17.66 6.34 19 8 19C9.66 19 11 17.66 11 16C11 14.34 9.66 13 8 13M9.77 4.33L10.5 5.08L14.29 1.29C14.47 1.11 14.72 1 15 1C15.28 1 15.53 1.11 15.71 1.29L22.78 8.36L22.78 8.37C22.92 8.54 23 8.76 23 9C23 9.3 22.87 9.57 22.66 9.76L22.66 9.76L18.93 13.5L19.67 14.23L12.95 20.95C11.68 22.22 9.93 23 8 23C4.13 23 1 19.87 1 16C1 14.07 1.78 12.32 3.05 11.05L9.77 4.33M20.59 9L15 3.41L11.93 6.5L17.5 12.08L20.59 9Z\";\r\nvar mdiUsbFlashDriveOutline = \"M8 13C9.66 13 11 14.34 11 16C11 17.66 9.66 19 8 19C6.34 19 5 17.66 5 16C5 14.34 6.34 13 8 13M8 15C7.45 15 7 15.45 7 16C7 16.55 7.45 17 8 17C8.55 17 9 16.55 9 16C9 15.45 8.55 15 8 15M9.77 4.33L10.5 5.08L14.29 1.29C14.47 1.11 14.72 1 15 1C15.28 1 15.53 1.11 15.71 1.29L22.78 8.36L22.78 8.37C22.92 8.54 23 8.76 23 9C23 9.3 22.87 9.57 22.66 9.76L22.66 9.76L18.93 13.5L19.67 14.23L12.95 20.95C11.68 22.22 9.93 23 8 23C4.13 23 1 19.87 1 16C1 14.07 1.78 12.32 3.05 11.05L9.77 4.33M11.54 19.54L16.84 14.23L9.77 7.16L4.46 12.46C3.56 13.37 3 14.62 3 16C3 18.76 5.24 21 8 21C9.38 21 10.63 20.44 11.54 19.54M15.07 4.69L16.5 6.1L15.07 7.5L13.66 6.1L15.07 4.69M17.9 7.5L19.31 8.93L17.9 10.34L16.5 8.93L17.9 7.5M20.59 9L15 3.41L11.93 6.5L17.5 12.08L20.59 9Z\";\r\nvar mdiUsbPort = \"M8 2C6.9 2 6 2.9 6 4V12H5V16L9 20V22H15V20L19 16V12H18V4C18 2.9 17.11 2 16 2M8 4H16V12H8M9 7V9H11V7M13 7V9H15V7Z\";\r\nvar mdiValve = \"M4 22H2V2H4M22 2H20V22H22M17.24 5.34L13.24 9.34A3 3 0 0 0 9.24 13.34L5.24 17.34L6.66 18.76L10.66 14.76A3 3 0 0 0 14.66 10.76L18.66 6.76Z\";\r\nvar mdiValveClosed = \"M22 2V22H20V13H14.82A3 3 0 0 1 9.18 13H4V22H2V2H4V11H9.18A3 3 0 0 1 14.82 11H20V2Z\";\r\nvar mdiValveOpen = \"M4 22H2V2H4M22 2H20V22H22M11 4V9.18A3 3 0 0 0 11 14.82V20H13V14.82A3 3 0 0 0 13 9.18V4Z\";\r\nvar mdiVanPassenger = \"M3,7C1.89,7 1,7.89 1,9V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V13C23,11.89 22.11,11 21,11L18,7H3M3,8.5H7V11H3V8.5M9,8.5H13V11H9V8.5M15,8.5H17.5L19.46,11H15V8.5M6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5M18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5Z\";\r\nvar mdiVanUtility = \"M3,7C1.89,7 1,7.89 1,9V17H3A3,3 0 0,0 6,20A3,3 0 0,0 9,17H15A3,3 0 0,0 18,20A3,3 0 0,0 21,17H23V13C23,11.89 22.11,11 21,11L18,7H3M15,8.5H17.5L19.46,11H15V8.5M6,15.5A1.5,1.5 0 0,1 7.5,17A1.5,1.5 0 0,1 6,18.5A1.5,1.5 0 0,1 4.5,17A1.5,1.5 0 0,1 6,15.5M18,15.5A1.5,1.5 0 0,1 19.5,17A1.5,1.5 0 0,1 18,18.5A1.5,1.5 0 0,1 16.5,17A1.5,1.5 0 0,1 18,15.5Z\";\r\nvar mdiVanish = \"M16,13V11H21V13H16M14.83,7.76L17.66,4.93L19.07,6.34L16.24,9.17L14.83,7.76M11,16H13V21H11V16M11,3H13V8H11V3M4.93,17.66L7.76,14.83L9.17,16.24L6.34,19.07L4.93,17.66M4.93,6.34L6.34,4.93L9.17,7.76L7.76,9.17L4.93,6.34M8,13H3V11H8V13M19.07,17.66L17.66,19.07L14.83,16.24L16.24,14.83L19.07,17.66Z\";\r\nvar mdiVanishQuarter = \"M11 3H13V8H11V3M4.9 6.3L6.3 4.9L9.1 7.7L7.8 9.2L4.9 6.3M8 13H3V11H8V13\";\r\nvar mdiVanityLight = \"M22 20H16C16 18.34 17.34 13 19 13S22 18.34 22 20M12 13C10.34 13 9 18.34 9 20H15C15 18.34 13.66 13 12 13M5 13C3.34 13 2 18.34 2 20H8C8 18.34 6.66 13 5 13M14.82 6C14.26 4.44 12.53 3.64 11 4.2C10.14 4.5 9.5 5.17 9.18 6H2V8H4V12H6V8H9.18C9.5 8.85 10.15 9.5 11 9.82V12H13V9.82C13.85 9.5 14.5 8.85 14.82 8H18V12H20V8H22V6H14.82Z\";\r\nvar mdiVariable = \"M20.41,3C21.8,5.71 22.35,8.84 22,12C21.8,15.16 20.7,18.29 18.83,21L17.3,20C18.91,17.57 19.85,14.8 20,12C20.34,9.2 19.89,6.43 18.7,4L20.41,3M5.17,3L6.7,4C5.09,6.43 4.15,9.2 4,12C3.66,14.8 4.12,17.57 5.3,20L3.61,21C2.21,18.29 1.65,15.17 2,12C2.2,8.84 3.3,5.71 5.17,3M12.08,10.68L14.4,7.45H16.93L13.15,12.45L15.35,17.37H13.09L11.71,14L9.28,17.33H6.76L10.66,12.21L8.53,7.45H10.8L12.08,10.68Z\";\r\nvar mdiVariableBox = \"M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3M7.4 18C5.9 16.5 5 14.3 5 12S5.9 7.5 7.4 6L9 6.7C7.7 7.9 7 9.9 7 12S7.7 16.1 9 17.3L7.4 18M12.7 15L11.9 13L10.5 15H9L11.3 11.9L10 9H11.3L12.1 11L13.5 9H15L12.8 12L14.1 15H12.7M16.6 18L15 17.3C16.3 16 17 14.1 17 12S16.3 7.9 15 6.7L16.6 6C18.1 7.5 19 9.7 19 12S18.1 16.5 16.6 18Z\";\r\nvar mdiVectorArrangeAbove = \"M3,1C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16C6.67,16 10.33,16 14,16C15.11,16 16,15.11 16,14C16,10.33 16,6.67 16,3C16,1.89 15.11,1 14,1H3M3,3H14V14H3V3M18,7V9H20V20H9V18H7V20C7,21.11 7.89,22 9,22H20C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7H18Z\";\r\nvar mdiVectorArrangeBelow = \"M20,22C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7C16.33,7 12.67,7 9,7C7.89,7 7,7.89 7,9C7,12.67 7,16.33 7,20C7,21.11 7.89,22 9,22H20M20,20H9V9H20V20M5,16V14H3V3H14V5H16V3C16,1.89 15.11,1 14,1H3C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16H5Z\";\r\nvar mdiVectorBezier = \"M7.5,4A1.5,1.5 0 0,0 6,5.5A1.5,1.5 0 0,0 7.5,7C8.13,7 8.7,6.6 8.91,6H13C13.67,5.33 14.33,5 15,5H8.91C8.7,4.4 8.13,4 7.5,4M19,5C8,5 14,17 5,17V19C16,19 10,7 19,7V5M16.5,17C15.87,17 15.3,17.4 15.09,18H11C10.33,18.67 9.67,19 9,19H15.09C15.3,19.6 15.87,20 16.5,20A1.5,1.5 0 0,0 18,18.5A1.5,1.5 0 0,0 16.5,17Z\";\r\nvar mdiVectorCircle = \"M9,2V4.06C6.72,4.92 4.92,6.72 4.05,9H2V15H4.06C4.92,17.28 6.72,19.09 9,19.95V22H15V19.94C17.28,19.08 19.09,17.28 19.95,15H22V9H19.94C19.08,6.72 17.28,4.92 15,4.05V2M11,4H13V6H11M9,6.25V8H15V6.25C16.18,6.86 17.14,7.82 17.75,9H16V15H17.75C17.14,16.18 16.18,17.14 15,17.75V16H9V17.75C7.82,17.14 6.86,16.18 6.25,15H8V9H6.25C6.86,7.82 7.82,6.86 9,6.25M4,11H6V13H4M18,11H20V13H18M11,18H13V20H11\";\r\nvar mdiVectorCircleVariant = \"M22,9H19.97C18.7,5.41 15.31,3 11.5,3A9,9 0 0,0 2.5,12C2.5,17 6.53,21 11.5,21C15.31,21 18.7,18.6 20,15H22M20,11V13H18V11M17.82,15C16.66,17.44 14.2,19 11.5,19C7.64,19 4.5,15.87 4.5,12C4.5,8.14 7.64,5 11.5,5C14.2,5 16.66,6.57 17.81,9H16V15\";\r\nvar mdiVectorCombine = \"M3,1C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16C4.33,16 7,16 7,16C7,16 7,18.67 7,20C7,21.11 7.89,22 9,22H20C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7C18.67,7 16,7 16,7C16,7 16,4.33 16,3C16,1.89 15.11,1 14,1H3M3,3H14C14,4.33 14,7 14,7H9C7.89,7 7,7.89 7,9V14C7,14 4.33,14 3,14V3M9,9H14V14H9V9M16,9C16,9 18.67,9 20,9V20H9C9,18.67 9,16 9,16H14C15.11,16 16,15.11 16,14V9Z\";\r\nvar mdiVectorCurve = \"M18.5,2A1.5,1.5 0 0,1 20,3.5A1.5,1.5 0 0,1 18.5,5C18.27,5 18.05,4.95 17.85,4.85L14.16,8.55L14.5,9C16.69,7.74 19.26,7 22,7L23,7.03V9.04L22,9C19.42,9 17,9.75 15,11.04A3.96,3.96 0 0,1 11.04,15C9.75,17 9,19.42 9,22L9.04,23H7.03L7,22C7,19.26 7.74,16.69 9,14.5L8.55,14.16L4.85,17.85C4.95,18.05 5,18.27 5,18.5A1.5,1.5 0 0,1 3.5,20A1.5,1.5 0 0,1 2,18.5A1.5,1.5 0 0,1 3.5,17C3.73,17 3.95,17.05 4.15,17.15L7.84,13.45C7.31,12.78 7,11.92 7,11A4,4 0 0,1 11,7C11.92,7 12.78,7.31 13.45,7.84L17.15,4.15C17.05,3.95 17,3.73 17,3.5A1.5,1.5 0 0,1 18.5,2M11,9A2,2 0 0,0 9,11A2,2 0 0,0 11,13A2,2 0 0,0 13,11A2,2 0 0,0 11,9Z\";\r\nvar mdiVectorDifference = \"M3,1C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16H5V14H3V3H14V5H16V3C16,1.89 15.11,1 14,1H3M9,7C7.89,7 7,7.89 7,9V11H9V9H11V7H9M13,7V9H14V10H16V7H13M18,7V9H20V20H9V18H7V20C7,21.11 7.89,22 9,22H20C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7H18M14,12V14H12V16H14C15.11,16 16,15.11 16,14V12H14M7,13V16H10V14H9V13H7Z\";\r\nvar mdiVectorDifferenceAb = \"M3,1C1.89,1 1,1.89 1,3V5H3V3H5V1H3M7,1V3H10V1H7M12,1V3H14V5H16V3C16,1.89 15.11,1 14,1H12M1,7V10H3V7H1M14,7C14,7 14,11.67 14,14C11.67,14 7,14 7,14C7,14 7,18 7,20C7,21.11 7.89,22 9,22H20C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7C18,7 14,7 14,7M16,9H20V20H9V16H14C15.11,16 16,15.11 16,14V9M1,12V14C1,15.11 1.89,16 3,16H5V14H3V12H1Z\";\r\nvar mdiVectorDifferenceBa = \"M20,22C21.11,22 22,21.11 22,20V18H20V20H18V22H20M16,22V20H13V22H16M11,22V20H9V18H7V20C7,21.11 7.89,22 9,22H11M22,16V13H20V16H22M9,16C9,16 9,11.33 9,9C11.33,9 16,9 16,9C16,9 16,5 16,3C16,1.89 15.11,1 14,1H3C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16C5,16 9,16 9,16M7,14H3V3H14V7H9C7.89,7 7,7.89 7,9V14M22,11V9C22,7.89 21.11,7 20,7H18V9H20V11H22Z\";\r\nvar mdiVectorEllipse = \"M23,9V15H20.35C19.38,17.12 17.43,18.78 15,19.54V22H9V19.54C5.5,18.45 3,15.5 3,12C3,7.58 7.03,4 12,4C15.78,4 19,6.07 20.35,9H23M17,15V9H18.06C16.85,7.21 14.59,6 12,6C8.13,6 5,8.69 5,12C5,14.39 6.64,16.46 9,17.42V16H15V17.42C16.29,16.9 17.35,16.05 18.06,15H17M19,13H21V11H19V13M11,20H13V18H11V20Z\";\r\nvar mdiVectorIntersection = \"M3.14,1A2.14,2.14 0 0,0 1,3.14V5H3V3H5V1H3.14M7,1V3H10V1H7M12,1V3H14V5H16V3.14C16,1.96 15.04,1 13.86,1H12M1,7V10H3V7H1M9,7C7.89,7 7,7.89 7,9C7,11.33 7,16 7,16C7,16 11.57,16 13.86,16A2.14,2.14 0 0,0 16,13.86C16,11.57 16,7 16,7C16,7 11.33,7 9,7M18,7V9H20V11H22V9C22,7.89 21.11,7 20,7H18M9,9H14V14H9V9M1,12V13.86C1,15.04 1.96,16 3.14,16H5V14H3V12H1M20,13V16H22V13H20M7,18V20C7,21.11 7.89,22 9,22H11V20H9V18H7M20,18V20H18V22H20C21.11,22 22,21.11 22,20V18H20M13,20V22H16V20H13Z\";\r\nvar mdiVectorLine = \"M15,3V7.59L7.59,15H3V21H9V16.42L16.42,9H21V3M17,5H19V7H17M5,17H7V19H5\";\r\nvar mdiVectorLink = \"M3 1C1.89 1 1 1.89 1 3V14C1 15.11 1.89 16 3 16H14C15.11 16 16 15.11 16 14V11H14V14H3V3H14V5H16V3C16 1.89 15.11 1 14 1M9 7C7.89 7 7 7.89 7 9V12H9V9H20V20H9V18H7V20C7 21.11 7.89 22 9 22H20C21.11 22 22 21.11 22 20V9C22 7.89 21.11 7 20 7H9\";\r\nvar mdiVectorPoint = \"M12,20L7,22L12,11L17,22L12,20M8,2H16V5H22V7H16V10H8V7H2V5H8V2M10,4V8H14V4H10Z\";\r\nvar mdiVectorPolygon = \"M2,2V8H4.28L5.57,16H4V22H10V20.06L15,20.05V22H21V16H19.17L20,9H22V3H16V6.53L14.8,8H9.59L8,5.82V2M4,4H6V6H4M18,5H20V7H18M6.31,8H7.11L9,10.59V14H15V10.91L16.57,9H18L17.16,16H15V18.06H10V16H7.6M11,10H13V12H11M6,18H8V20H6M17,18H19V20H17\";\r\nvar mdiVectorPolyline = \"M2 3V9H4.95L6.95 15H6V21H12V16.41L17.41 11H22V5H16V9.57L10.59 15H9.06L7.06 9H8V3M4 5H6V7H4M18 7H20V9H18M8 17H10V19H8Z\";\r\nvar mdiVectorPolylineEdit = \"M2 3V9H4.95L6.95 15H6V21H12V16.41L17.41 11H22V5H16V9.57L10.59 15H9.06L7.06 9H8V3H2M4 5H6V7H4V5M18 7H20V9H18V7M21.15 13C21 13 20.87 13.05 20.76 13.16L19.75 14.18L21.82 16.25L22.84 15.24C23.05 15.03 23.05 14.67 22.84 14.46L21.54 13.16C21.43 13.05 21.29 13 21.15 13M19.15 14.76L13 20.91V23H15.09L21.23 16.84L19.15 14.76M8 17H10V19H8V17Z\";\r\nvar mdiVectorPolylineMinus = \"M2 3V9H4.95L6.95 15H6V21H12V16.41L17.41 11H22V5H16V9.57L10.59 15H9.06L7.06 9H8V3H2M4 5H6V7H4V5M18 7H20V9H18V7M8 17H10V19H8V17M15 18V20H23V18H15Z\";\r\nvar mdiVectorPolylinePlus = \"M2 3V9H4.95L6.95 15H6V21H12V16.41L17.41 11H22V5H16V9.57L10.59 15H9.06L7.06 9H8V3H2M4 5H6V7H4V5M18 7H20V9H18V7M18 15V18H15V20H18V23H20V20H23V18H20V15H18M8 17H10V19H8V17Z\";\r\nvar mdiVectorPolylineRemove = \"M21.1 15.5L19 17.6L16.9 15.5L15.5 16.9L17.6 19L15.5 21.1L16.9 22.5L19 20.4L21.1 22.5L22.5 21.1L20.4 19L22.5 16.9L21.1 15.5M16 5V9.6L10.6 15H9.1L7.1 9H8V3H2V9H5L7 15H6V21H12V16.4L17.4 11H22V5H16M6 7H4V5H6V7M10 19H8V17H10V19M20 9H18V7H20V9\";\r\nvar mdiVectorRadius = \"M2,4H4V2H10V4A10,10 0 0,1 20,14H22V20H20V22H18V20H16V14H18A8,8 0 0,0 10,6V8H4V6H2V4M18,16V18H20V16H18M6,4V6H8V4H6Z\";\r\nvar mdiVectorRectangle = \"M2,4H8V6H16V4H22V10H20V14H22V20H16V18H8V20H2V14H4V10H2V4M16,10V8H8V10H6V14H8V16H16V14H18V10H16M4,6V8H6V6H4M18,6V8H20V6H18M4,16V18H6V16H4M18,16V18H20V16H18Z\";\r\nvar mdiVectorSelection = \"M3,1H5V3H3V5H1V3A2,2 0 0,1 3,1M14,1A2,2 0 0,1 16,3V5H14V3H12V1H14M20,7A2,2 0 0,1 22,9V11H20V9H18V7H20M22,20A2,2 0 0,1 20,22H18V20H20V18H22V20M20,13H22V16H20V13M13,9V7H16V10H14V9H13M13,22V20H16V22H13M9,22A2,2 0 0,1 7,20V18H9V20H11V22H9M7,16V13H9V14H10V16H7M7,3V1H10V3H7M3,16A2,2 0 0,1 1,14V12H3V14H5V16H3M1,7H3V10H1V7M9,7H11V9H9V11H7V9A2,2 0 0,1 9,7M16,14A2,2 0 0,1 14,16H12V14H14V12H16V14Z\";\r\nvar mdiVectorSquare = \"M2,2H8V4H16V2H22V8H20V16H22V22H16V20H8V22H2V16H4V8H2V2M16,8V6H8V8H6V16H8V18H16V16H18V8H16M4,4V6H6V4H4M18,4V6H20V4H18M4,18V20H6V18H4M18,18V20H20V18H18Z\";\r\nvar mdiVectorTriangle = \"M9,3V9H9.73L5.79,16H2V22H8V20H16V22H22V16H18.21L14.27,9H15V3M11,5H13V7H11M12,9.04L16,16.15V18H8V16.15M4,18H6V20H4M18,18H20V20H18\";\r\nvar mdiVectorUnion = \"M3,1C1.89,1 1,1.89 1,3V14C1,15.11 1.89,16 3,16H7V20C7,21.11 7.89,22 9,22H20C21.11,22 22,21.11 22,20V9C22,7.89 21.11,7 20,7H16V3C16,1.89 15.11,1 14,1H3M3,3H14V9H20V20H9V14H3V3Z\";\r\nvar mdiVhs = \"M4,6A2,2 0 0,0 2,8V16A2,2 0 0,0 4,18H20A2,2 0 0,0 22,16V8A2,2 0 0,0 20,6H4M4.54,10H7V14H4.54C4.19,13.39 4,12.7 4,12C4,11.3 4.19,10.61 4.54,10M9,10H15V14H9V10M17,10H19.46C19.81,10.61 20,11.3 20,12C20,12.7 19.81,13.39 19.46,14H17V10Z\";\r\nvar mdiVibrate = \"M16,19H8V5H16M16.5,3H7.5A1.5,1.5 0 0,0 6,4.5V19.5A1.5,1.5 0 0,0 7.5,21H16.5A1.5,1.5 0 0,0 18,19.5V4.5A1.5,1.5 0 0,0 16.5,3M19,17H21V7H19M22,9V15H24V9M3,17H5V7H3M0,15H2V9H0V15Z\";\r\nvar mdiVibrateOff = \"M8.2,5L6.55,3.35C6.81,3.12 7.15,3 7.5,3H16.5A1.5,1.5 0 0,1 18,4.5V14.8L16,12.8V5H8.2M0,15H2V9H0V15M21,17V7H19V15.8L20.2,17H21M3,17H5V7H3V17M18,17.35L22.11,21.46L20.84,22.73L18,19.85C17.83,20.54 17.21,21 16.5,21H7.5A1.5,1.5 0 0,1 6,19.5V7.89L1.11,3L2.39,1.73L6.09,5.44L8,7.34L16,15.34L18,17.34V17.35M16,17.89L8,9.89V19H16V17.89M22,9V15H24V9H22Z\";\r\nvar mdiVideo = \"M17,10.5V7A1,1 0 0,0 16,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16A1,1 0 0,0 17,17V13.5L21,17.5V6.5L17,10.5Z\";\r\nvar mdiVideo3d = \"M5,7H9A2,2 0 0,1 11,9V15A2,2 0 0,1 9,17H5V15H9V13H6V11H9V9H5V7M13,7H16A3,3 0 0,1 19,10V14A3,3 0 0,1 16,17H13V7M16,15A1,1 0 0,0 17,14V10A1,1 0 0,0 16,9H15V15H16Z\";\r\nvar mdiVideo3dOff = \"M2.61 2L21.35 20.74L19.94 22.15L14.8 17H13V15.2L11 13.23V15.21C10.93 15.68 10.74 16.08 10.41 16.41C10.08 16.73 9.68 16.93 9.21 17H5V15H9V13H6V11H8.8L6.79 9H5V7.23L1.2 3.41L2.61 2M16 7H16.22C17 7.07 17.63 7.36 18.14 7.88C18.65 8.39 18.93 9 19 9.76V14.24C18.95 14.63 18.87 15 18.72 15.3L17 13.6V9.85C16.95 9.63 16.84 9.44 16.69 9.28C16.53 9.13 16.34 9.03 16.12 9H15V11.59L13 9.57V7H16Z\";\r\nvar mdiVideo3dVariant = \"M14,10V14A0.5,0.5 0 0,1 13.5,14.5H12.5V9.5H13.5A0.5,0.5 0 0,1 14,10M21,6.5V17.5L17,13.5V17A1,1 0 0,1 16,18H4A1,1 0 0,1 3,17V7A1,1 0 0,1 4,6H16A1,1 0 0,1 17,7V10.5M9.5,9.5A1.5,1.5 0 0,0 8,8H4.5V9.5H8V11.25H5.5V12.75H8V14.5H4.5V16H8A1.5,1.5 0 0,0 9.5,14.5M15.5,9.5A1.5,1.5 0 0,0 14,8H11V16H14A1.5,1.5 0 0,0 15.5,14.5\";\r\nvar mdiVideo4kBox = \"M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M12,13.5H11V15H9.5V13.5H6.5V9H8V12H9.5V9H11V12H12V13.5M18,15H16.2L14.4,12.8V15H13V9H14.5V11.2L16.2,9H18L15.8,12L18,15Z\";\r\nvar mdiVideoAccount = \"M17,10.5L21,6.5V17.5L17,13.5V17A1,1 0 0,1 16,18H4A1,1 0 0,1 3,17V7A1,1 0 0,1 4,6H16A1,1 0 0,1 17,7V10.5M14,16V15C14,13.67 11.33,13 10,13C8.67,13 6,13.67 6,15V16H14M10,8A2,2 0 0,0 8,10A2,2 0 0,0 10,12A2,2 0 0,0 12,10A2,2 0 0,0 10,8Z\";\r\nvar mdiVideoBox = \"M18,16L14,12.8V16H6V8H14V11.2L18,8M20,4H4A2,2 0 0,0 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V6C22,4.89 21.1,4 20,4Z\";\r\nvar mdiVideoBoxOff = \"M6,8H6.73L14,15.27V16H6M2.27,1L1,2.27L3,4.28C2.41,4.62 2,5.26 2,6V18A2,2 0 0,0 4,20H18.73L20.73,22L22,20.73M20,4H7.82L11.82,8H14V10.18L14.57,10.75L18,8V14.18L22,18.17C22,18.11 22,18.06 22,18V6A2,2 0 0,0 20,4Z\";\r\nvar mdiVideoCheck = \"M17 10.5V7C17 6.45 16.55 6 16 6H4C3.45 6 3 6.45 3 7V17C3 17.55 3.45 18 4 18H16C16.55 18 17 17.55 17 17V13.5L21 17.5V6.5L17 10.5M8.93 15L6 11.8L7.24 10.56L8.93 12.26L12.76 8.43L14 9.93L8.93 15Z\";\r\nvar mdiVideoCheckOutline = \"M15 8V16H5V8H15M16 6H4C3.45 6 3 6.45 3 7V17C3 17.55 3.45 18 4 18H16C16.55 18 17 17.55 17 17V13.5L21 17.5V6.5L17 10.5V7C17 6.45 16.55 6 16 6M6.35 12.08L7.5 10.95L9 12.5L12.5 9L13.65 10.37L9 15L6.35 12.08Z\";\r\nvar mdiVideoHighDefinition = \"M14 10V14C14 14.3 13.8 14.5 13.5 14.5H12.5V9.5H13.5C13.8 9.5 14 9.7 14 10M17 10.5V7C17 6.4 16.6 6 16 6H4C3.4 6 3 6.4 3 7V17C3 17.6 3.4 18 4 18H16C16.6 18 17 17.6 17 17V13.5L21 17.5V6.5L17 10.5M9.5 16H8V12.8H6V16H4.5V8H6V11.2H8V8H9.5V16M15.5 14.5C15.5 15.3 14.8 16 14 16H11V8H14C14.8 8 15.5 8.7 15.5 9.5V14.5Z\";\r\nvar mdiVideoImage = \"M17,10.5L21,6.5V17.5L17,13.5V17A1,1 0 0,1 16,18H4A1,1 0 0,1 3,17V7A1,1 0 0,1 4,6H16A1,1 0 0,1 17,7V10.5M10.91,9.55L9.2,11.82L10.5,13.55L9.77,14.09L7.73,11.36L5,15H15L10.91,9.55Z\";\r\nvar mdiVideoInputAntenna = \"M12,5A7,7 0 0,0 5,12H7A5,5 0 0,1 12,7A5,5 0 0,1 17,12H19A7,7 0 0,0 12,5M13,14.29C13.88,13.9 14.5,13.03 14.5,12A2.5,2.5 0 0,0 12,9.5A2.5,2.5 0 0,0 9.5,12C9.5,13 10.12,13.9 11,14.29V17.59L7.59,21L9,22.41L12,19.41L15,22.41L16.41,21L13,17.59V14.29M12,1A11,11 0 0,0 1,12H3A9,9 0 0,1 12,3A9,9 0 0,1 21,12H23A11,11 0 0,0 12,1Z\";\r\nvar mdiVideoInputComponent = \"M5,2A1,1 0 0,0 4,1A1,1 0 0,0 3,2V6H1V12H7V6H5V2M9,16C9,17.3 9.84,18.4 11,18.82V23H13V18.82C14.16,18.41 15,17.31 15,16V14H9V16M1,16C1,17.3 1.84,18.4 3,18.82V23H5V18.82C6.16,18.4 7,17.3 7,16V14H1V16M21,6V2A1,1 0 0,0 20,1A1,1 0 0,0 19,2V6H17V12H23V6H21M13,2A1,1 0 0,0 12,1A1,1 0 0,0 11,2V6H9V12H15V6H13V2M17,16C17,17.3 17.84,18.4 19,18.82V23H21V18.82C22.16,18.41 23,17.31 23,16V14H17V16Z\";\r\nvar mdiVideoInputHdmi = \"M18,7V4A2,2 0 0,0 16,2H8A2,2 0 0,0 6,4V7H5V13L8,19V22H16V19L19,13V7H18M8,4H16V7H14V5H13V7H11V5H10V7H8V4Z\";\r\nvar mdiVideoInputScart = \"M20.6 2.2L17.3 2.4L13.8 4.4L13.3 3.5L2 10V17H3V19C3 20.1 3.9 21 5 21H15C16.1 21 17 20.1 17 19V17H18V10H17L16.8 9.6L20.3 7.6L22.1 4.8L20.6 2.2M15 17V19H5V17H15Z\";\r\nvar mdiVideoInputSvideo = \"M8,11.5A1.5,1.5 0 0,0 6.5,10A1.5,1.5 0 0,0 5,11.5A1.5,1.5 0 0,0 6.5,13A1.5,1.5 0 0,0 8,11.5M15,6.5A1.5,1.5 0 0,0 13.5,5H10.5A1.5,1.5 0 0,0 9,6.5A1.5,1.5 0 0,0 10.5,8H13.5A1.5,1.5 0 0,0 15,6.5M8.5,15A1.5,1.5 0 0,0 7,16.5A1.5,1.5 0 0,0 8.5,18A1.5,1.5 0 0,0 10,16.5A1.5,1.5 0 0,0 8.5,15M12,1A11,11 0 0,0 1,12A11,11 0 0,0 12,23A11,11 0 0,0 23,12A11,11 0 0,0 12,1M12,21C7.04,21 3,16.96 3,12C3,7.04 7.04,3 12,3C16.96,3 21,7.04 21,12C21,16.96 16.96,21 12,21M17.5,10A1.5,1.5 0 0,0 16,11.5A1.5,1.5 0 0,0 17.5,13A1.5,1.5 0 0,0 19,11.5A1.5,1.5 0 0,0 17.5,10M15.5,15A1.5,1.5 0 0,0 14,16.5A1.5,1.5 0 0,0 15.5,18A1.5,1.5 0 0,0 17,16.5A1.5,1.5 0 0,0 15.5,15Z\";\r\nvar mdiVideoMinus = \"M17,10.5V7A1,1 0 0,0 16,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16A1,1 0 0,0 17,17V13.5L21,17.5V6.5L17,10.5M14,13H6V11H14V13Z\";\r\nvar mdiVideoMinusOutline = \"M15 8V16H5V8H15M16 6H4C3.45 6 3 6.45 3 7V17C3 17.55 3.45 18 4 18H16C16.55 18 17 17.55 17 17V13.5L21 17.5V6.5L17 10.5V7C17 6.45 16.55 6 16 6M13 13H7V11H13V13Z\";\r\nvar mdiVideoOff = \"M3.27,2L2,3.27L4.73,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16C16.2,18 16.39,17.92 16.54,17.82L19.73,21L21,19.73M21,6.5L17,10.5V7A1,1 0 0,0 16,6H9.82L21,17.18V6.5Z\";\r\nvar mdiVideoOffOutline = \"M3.41,1.86L2,3.27L4.73,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16C16.21,18 16.39,17.92 16.55,17.82L19.73,21L21.14,19.59L12.28,10.73L3.41,1.86M5,16V8H6.73L14.73,16H5M15,8V10.61L21,16.61V6.5L17,10.5V7A1,1 0 0,0 16,6H10.39L12.39,8H15Z\";\r\nvar mdiVideoOutline = \"M15,8V16H5V8H15M16,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16A1,1 0 0,0 17,17V13.5L21,17.5V6.5L17,10.5V7A1,1 0 0,0 16,6Z\";\r\nvar mdiVideoPlus = \"M17,10.5V7A1,1 0 0,0 16,6H4A1,1 0 0,0 3,7V17A1,1 0 0,0 4,18H16A1,1 0 0,0 17,17V13.5L21,17.5V6.5L17,10.5M14,13H11V16H9V13H6V11H9V8H11V11H14V13Z\";\r\nvar mdiVideoPlusOutline = \"M15 8V16H5V8H15M16 6H4C3.45 6 3 6.45 3 7V17C3 17.55 3.45 18 4 18H16C16.55 18 17 17.55 17 17V13.5L21 17.5V6.5L17 10.5V7C17 6.45 16.55 6 16 6M13 13H11V15H9V13H7V11H9V9H11V11H13V13Z\";\r\nvar mdiVideoStabilization = \"M4,4H20A2,2 0 0,1 22,6V18A2,2 0 0,1 20,20H4A2,2 0 0,1 2,18V6A2,2 0 0,1 4,4M4,6V18H20V6H4M7.24,6.58L18.83,9.69L16.76,17.42L5.17,14.31L7.24,6.58Z\";\r\nvar mdiVideoSwitch = \"M13,15.5V13H7V15.5L3.5,12L7,8.5V11H13V8.5L16.5,12M18,9.5V6A1,1 0 0,0 17,5H3A1,1 0 0,0 2,6V18A1,1 0 0,0 3,19H17A1,1 0 0,0 18,18V14.5L22,18.5V5.5L18,9.5Z\";\r\nvar mdiVideoSwitchOutline = \"M8 13H12V15L15 12L12 9V11H8V9L5 12L8 15V13M18 9.5V6C18 5.4 17.5 5 17 5H3C2.5 5 2 5.4 2 6V18C2 18.5 2.5 19 3 19H17C17.5 19 18 18.5 18 18V14.5L22 18.5V5.5L18 9.5M16 17H4V7H16V17Z\";\r\nvar mdiVideoVintage = \"M18,14.5V11A1,1 0 0,0 17,10H16C18.24,8.39 18.76,5.27 17.15,3C15.54,0.78 12.42,0.26 10.17,1.87C9.5,2.35 8.96,3 8.6,3.73C6.25,2.28 3.17,3 1.72,5.37C0.28,7.72 1,10.8 3.36,12.25C3.57,12.37 3.78,12.5 4,12.58V21A1,1 0 0,0 5,22H17A1,1 0 0,0 18,21V17.5L22,21.5V10.5L18,14.5M13,4A2,2 0 0,1 15,6A2,2 0 0,1 13,8A2,2 0 0,1 11,6A2,2 0 0,1 13,4M6,6A2,2 0 0,1 8,8A2,2 0 0,1 6,10A2,2 0 0,1 4,8A2,2 0 0,1 6,6Z\";\r\nvar mdiVideoWireless = \"M17,14.5V11A1,1 0 0,0 16,10H4A1,1 0 0,0 3,11V21A1,1 0 0,0 4,22H16A1,1 0 0,0 17,21V17.5L21,21.5V10.5M3,3.86L4.4,5.24C7.5,2.19 12.5,2.19 15.6,5.24L17,3.86C13.14,0.05 6.87,0.05 3,3.86M5.8,6.62L7.2,8C8.75,6.5 11.25,6.5 12.8,8L14.2,6.62C11.88,4.34 8.12,4.34 5.8,6.62Z\";\r\nvar mdiVideoWirelessOutline = \"M15,12V20H5V12H15M16,10H4A1,1 0 0,0 3,11V21A1,1 0 0,0 4,22H16A1,1 0 0,0 17,21V17.5L21,21.5V10.5L17,14.5V11A1,1 0 0,0 16,10M3,3.86L4.4,5.24C7.5,2.19 12.5,2.19 15.6,5.24L17,3.86C13.14,0.05 6.87,0.05 3,3.86M5.8,6.63L7.2,8C8.75,6.5 11.25,6.5 12.8,8L14.2,6.63C11.88,4.34 8.12,4.34 5.8,6.63Z\";\r\nvar mdiViewAgenda = \"M21 3H3C2.4 3 2 3.4 2 4V10C2 10.6 2.4 11 3 11H21C21.6 11 22 10.6 22 10V4C22 3.4 21.6 3 21 3M21 13H3C2.4 13 2 13.4 2 14V20C2 20.6 2.4 21 3 21H21C21.6 21 22 20.6 22 20V14C22 13.4 21.6 13 21 13Z\";\r\nvar mdiViewAgendaOutline = \"M21 13H3A1 1 0 0 0 2 14V20A1 1 0 0 0 3 21H21A1 1 0 0 0 22 20V14A1 1 0 0 0 21 13M20 19H4V15H20M21 3H3A1 1 0 0 0 2 4V10A1 1 0 0 0 3 11H21A1 1 0 0 0 22 10V4A1 1 0 0 0 21 3M20 9H4V5H20Z\";\r\nvar mdiViewArray = \"M8,18H17V5H8M18,5V18H21V5M4,18H7V5H4V18Z\";\r\nvar mdiViewArrayOutline = \"M15 7V16H10V7H15M21 5H18V18H21V5M17 5H8V18H17V5M7 5H4V18H7V5Z\";\r\nvar mdiViewCarousel = \"M18,6V17H22V6M2,17H6V6H2M7,19H17V4H7V19Z\";\r\nvar mdiViewCarouselOutline = \"M2 6H6V17H2V6M7 19H17V4H7V19M9 6H15V17H9V6M18 6H22V17H18V6Z\";\r\nvar mdiViewColumn = \"M16,5V18H21V5M4,18H9V5H4M10,18H15V5H10V18Z\";\r\nvar mdiViewColumnOutline = \"M4 5V18H21V5H4M14 7V16H11V7H14M6 7H9V16H6V7M19 16H16V7H19V16Z\";\r\nvar mdiViewComfy = \"M3,9H7V5H3V9M3,14H7V10H3V14M8,14H12V10H8V14M13,14H17V10H13V14M8,9H12V5H8V9M13,5V9H17V5H13M18,14H22V10H18V14M3,19H7V15H3V19M8,19H12V15H8V19M13,19H17V15H13V19M18,19H22V15H18V19M18,5V9H22V5H18Z\";\r\nvar mdiViewComfyOutline = \"M3 5V19H22V5H3M20 9H17.75V7H20V9M9.25 11H11.5V13H9.25V11M7.25 13H5V11H7.25V13M11.5 9H9.25V7H11.5V9M13.5 7H15.75V9H13.5V7M11.5 15V17H9.25V15H11.5M13.5 15H15.75V17H13.5V15M13.5 13V11H15.75V13H13.5M17.75 11H20V13H17.75V11M7.25 7V9H5V7H7.25M5 15H7.25V17H5V15M17.75 17V15H20V17H17.75Z\";\r\nvar mdiViewCompact = \"M3,19H9V12H3V19M10,19H22V12H10V19M3,5V11H22V5H3Z\";\r\nvar mdiViewCompactOutline = \"M3,5V19H22V5H3M5,7H20V11H5V7M5,17V13H9V17H5M11,17V13H20V17H11Z\";\r\nvar mdiViewDashboard = \"M13,3V9H21V3M13,21H21V11H13M3,21H11V15H3M3,13H11V3H3V13Z\";\r\nvar mdiViewDashboardOutline = \"M19,5V7H15V5H19M9,5V11H5V5H9M19,13V19H15V13H19M9,17V19H5V17H9M21,3H13V9H21V3M11,3H3V13H11V3M21,11H13V21H21V11M11,15H3V21H11V15Z\";\r\nvar mdiViewDashboardVariant = \"M2,5V19H8V5H2M9,5V10H15V5H9M16,5V14H22V5H16M9,11V19H15V11H9M16,15V19H22V15H16Z\";\r\nvar mdiViewDashboardVariantOutline = \"M2 5V19H22V5H2M20 12H16V7H20V12M14 10H10V7H14V10M10 12H14V17H10V12M4 7H8V17H4V7M16 17V14H20V17H16Z\";\r\nvar mdiViewDay = \"M2,3V6H21V3M20,8H3A1,1 0 0,0 2,9V15A1,1 0 0,0 3,16H20A1,1 0 0,0 21,15V9A1,1 0 0,0 20,8M2,21H21V18H2V21Z\";\r\nvar mdiViewDayOutline = \"M21 18H2V20H21V18M19 10V14H4V10H19M20 8H3C2.45 8 2 8.45 2 9V15C2 15.55 2.45 16 3 16H20C20.55 16 21 15.55 21 15V9C21 8.45 20.55 8 20 8M21 4H2V6H21V4Z\";\r\nvar mdiViewGrid = \"M3,11H11V3H3M3,21H11V13H3M13,21H21V13H13M13,3V11H21V3\";\r\nvar mdiViewGridOutline = \"M3 11H11V3H3M5 5H9V9H5M13 21H21V13H13M15 15H19V19H15M3 21H11V13H3M5 15H9V19H5M13 3V11H21V3M19 9H15V5H19Z\";\r\nvar mdiViewGridPlus = \"M13 3V11H21V3H13M3 21H11V13H3V21M3 3V11H11V3H3M13 16H16V13H18V16H21V18H18V21H16V18H13V16Z\";\r\nvar mdiViewGridPlusOutline = \"M3 21H11V13H3M5 15H9V19H5M3 11H11V3H3M5 5H9V9H5M13 3V11H21V3M19 9H15V5H19M18 16H21V18H18V21H16V18H13V16H16V13H18Z\";\r\nvar mdiViewHeadline = \"M4,5V7H21V5M4,11H21V9H4M4,19H21V17H4M4,15H21V13H4V15Z\";\r\nvar mdiViewList = \"M9,5V9H21V5M9,19H21V15H9M9,14H21V10H9M4,9H8V5H4M4,19H8V15H4M4,14H8V10H4V14Z\";\r\nvar mdiViewListOutline = \"M3 5V19H20V5H3M7 7V9H5V7H7M5 13V11H7V13H5M5 15H7V17H5V15M18 17H9V15H18V17M18 13H9V11H18V13M18 9H9V7H18V9Z\";\r\nvar mdiViewModule = \"M16,5V11H21V5M10,11H15V5H10M16,18H21V12H16M10,18H15V12H10M4,18H9V12H4M4,11H9V5H4V11Z\";\r\nvar mdiViewModuleOutline = \"M4 5V18H21V5H4M14 7V10.5H11V7H14M6 7H9V10.5H6V7M6 16V12.5H9V16H6M11 16V12.5H14V16H11M19 16H16V12.5H19V16M16 10.5V7H19V10.5H16Z\";\r\nvar mdiViewParallel = \"M19 3V21H15V3H19M14 3V21H10V3H14M9 3V21H5V3H9Z\";\r\nvar mdiViewParallelOutline = \"M19 3H5V21H19V3M17 19H15V5H17V19M13 19H11V5H13V19M7 5H9V19H7V5Z\";\r\nvar mdiViewQuilt = \"M10,5V11H21V5M16,18H21V12H16M4,18H9V5H4M10,18H15V12H10V18Z\";\r\nvar mdiViewQuiltOutline = \"M4 5V18H21V5H4M6 16V7H9V16H6M11 16V12.5H14V16H11M19 16H16V12.5H19V16M11 10.5V7H19V10.5H11Z\";\r\nvar mdiViewSequential = \"M3 5H21V9H3V5M3 10H21V14H3V10M3 15H21V19H3V15Z\";\r\nvar mdiViewSequentialOutline = \"M3 5V19H21V5H3M19 7V9H5V7H19M19 11V13H5V11H19M5 17V15H19V17H5Z\";\r\nvar mdiViewSplitHorizontal = \"M3,5H21V7H3V5M3,11V9H21V11H3M3,19V13H21V19H3Z\";\r\nvar mdiViewSplitVertical = \"M13,5H21V19H13V5M3,5H11V7H3V5M3,11V9H11V11H3M3,19V17H11V19H3M3,15V13H11V15H3Z\";\r\nvar mdiViewStream = \"M4,5V11H21V5M4,18H21V12H4V18Z\";\r\nvar mdiViewStreamOutline = \"M4 6V18H21V6H4M19 16H6V13H19V16M6 11V8H19V11H6Z\";\r\nvar mdiViewWeek = \"M13,5H10A1,1 0 0,0 9,6V18A1,1 0 0,0 10,19H13A1,1 0 0,0 14,18V6A1,1 0 0,0 13,5M20,5H17A1,1 0 0,0 16,6V18A1,1 0 0,0 17,19H20A1,1 0 0,0 21,18V6A1,1 0 0,0 20,5M6,5H3A1,1 0 0,0 2,6V18A1,1 0 0,0 3,19H6A1,1 0 0,0 7,18V6A1,1 0 0,0 6,5Z\";\r\nvar mdiViewWeekOutline = \"M21 4H3C2.45 4 2 4.45 2 5V19C2 19.55 2.45 20 3 20H21C21.55 20 22 19.55 22 19V5C22 4.45 21.55 4 21 4M8 18H4V6H8V18M14 18H10V6H14V18M20 18H16V6H20V18Z\";\r\nvar mdiVimeo = \"M22,7.42C21.91,9.37 20.55,12.04 17.92,15.44C15.2,19 12.9,20.75 11,20.75C9.85,20.75 8.86,19.67 8.05,17.5C7.5,15.54 7,13.56 6.44,11.58C5.84,9.42 5.2,8.34 4.5,8.34C4.36,8.34 3.84,8.66 2.94,9.29L2,8.07C3,7.2 3.96,6.33 4.92,5.46C6.24,4.32 7.23,3.72 7.88,3.66C9.44,3.5 10.4,4.58 10.76,6.86C11.15,9.33 11.42,10.86 11.57,11.46C12,13.5 12.5,14.5 13.05,14.5C13.47,14.5 14.1,13.86 14.94,12.53C15.78,11.21 16.23,10.2 16.29,9.5C16.41,8.36 15.96,7.79 14.94,7.79C14.46,7.79 13.97,7.9 13.46,8.12C14.44,4.89 16.32,3.32 19.09,3.41C21.15,3.47 22.12,4.81 22,7.42Z\";\r\nvar mdiViolin = \"M11,2A1,1 0 0,0 10,3V5L10,9A0.5,0.5 0 0,0 10.5,9.5H12A0.5,0.5 0 0,1 12.5,10A0.5,0.5 0 0,1 12,10.5H10.5C9.73,10.5 9,9.77 9,9V5.16C7.27,5.6 6,7.13 6,9V10.5A2.5,2.5 0 0,1 8.5,13A2.5,2.5 0 0,1 6,15.5V17C6,19.77 8.23,22 11,22H13C15.77,22 18,19.77 18,17V15.5A2.5,2.5 0 0,1 15.5,13A2.5,2.5 0 0,1 18,10.5V9C18,6.78 16.22,5 14,5V3A1,1 0 0,0 13,2H11M10.75,16.5H13.25L12.75,20H11.25L10.75,16.5Z\";\r\nvar mdiVirtualReality = \"M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3H5M6,9H7.5L8.5,12.43L9.5,9H11L9.25,15H7.75L6,9M13,9H16.5C17.35,9 18,9.65 18,10.5V11.5C18,12.1 17.6,12.65 17.1,12.9L18,15H16.5L15.65,13H14.5V15H13V9M14.5,10.5V11.5H16.5V10.5H14.5Z\";\r\nvar mdiVirus = \"M19.82 14C20.13 14.45 20.66 14.75 21.25 14.75C22.22 14.75 23 13.97 23 13S22.22 11.25 21.25 11.25C20.66 11.25 20.13 11.55 19.82 12H19C19 10.43 18.5 9 17.6 7.81L18.94 6.47C19.5 6.57 20.07 6.41 20.5 6C21.17 5.31 21.17 4.2 20.5 3.5C19.81 2.83 18.7 2.83 18 3.5C17.59 3.93 17.43 4.5 17.53 5.06L16.19 6.4C15.27 5.71 14.19 5.25 13 5.08V3.68C13.45 3.37 13.75 2.84 13.75 2.25C13.75 1.28 12.97 .5 12 .5S10.25 1.28 10.25 2.25C10.25 2.84 10.55 3.37 11 3.68V5.08C10.1 5.21 9.26 5.5 8.5 5.94L7.39 4.35C7.58 3.83 7.53 3.23 7.19 2.75C6.63 1.96 5.54 1.76 4.75 2.32C3.96 2.87 3.76 3.96 4.32 4.75C4.66 5.24 5.2 5.5 5.75 5.5L6.93 7.18C6.5 7.61 6.16 8.09 5.87 8.62C5.25 8.38 4.5 8.5 4 9C3.33 9.7 3.33 10.8 4 11.5C4.29 11.77 4.64 11.93 5 12L5 12C5 12.54 5.07 13.06 5.18 13.56L3.87 13.91C3.45 13.56 2.87 13.41 2.29 13.56C1.36 13.81 .808 14.77 1.06 15.71C1.31 16.64 2.28 17.19 3.21 16.94C3.78 16.78 4.21 16.36 4.39 15.84L5.9 15.43C6.35 16.22 6.95 16.92 7.65 17.5L6.55 19.5C6 19.58 5.5 19.89 5.21 20.42C4.75 21.27 5.07 22.33 5.92 22.79C6.77 23.25 7.83 22.93 8.29 22.08C8.57 21.56 8.56 20.96 8.31 20.47L9.38 18.5C10.19 18.82 11.07 19 12 19C12.06 19 12.12 19 12.18 19C12.05 19.26 12 19.56 12 19.88C12.08 20.85 12.92 21.57 13.88 21.5S15.57 20.58 15.5 19.62C15.46 19.12 15.21 18.68 14.85 18.39C15.32 18.18 15.77 17.91 16.19 17.6L18.53 19.94C18.43 20.5 18.59 21.07 19 21.5C19.7 22.17 20.8 22.17 21.5 21.5S22.17 19.7 21.5 19C21.07 18.59 20.5 18.43 19.94 18.53L17.6 16.19C18.09 15.54 18.47 14.8 18.71 14H19.82M10.5 12C9.67 12 9 11.33 9 10.5S9.67 9 10.5 9 12 9.67 12 10.5 11.33 12 10.5 12M14 15C13.45 15 13 14.55 13 14C13 13.45 13.45 13 14 13S15 13.45 15 14C15 14.55 14.55 15 14 15Z\";\r\nvar mdiVirusOutline = \"M12 .5C11.03 .5 10.25 1.28 10.25 2.25C10.25 2.84 10.55 3.37 11 3.68V5.08C10.1 5.21 9.26 5.5 8.5 5.94L7.39 4.35C7.58 3.83 7.53 3.23 7.19 2.75C6.84 2.26 6.3 2 5.75 2C5.4 2 5.05 2.1 4.75 2.32C3.96 2.87 3.76 3.96 4.32 4.75C4.66 5.24 5.2 5.5 5.75 5.5L6.93 7.18C6.5 7.61 6.16 8.09 5.87 8.62C5.67 8.54 5.46 8.5 5.25 8.5C4.8 8.5 4.35 8.67 4 9C3.33 9.7 3.33 10.8 4 11.5C4.29 11.77 4.64 11.92 5 12L5 12C5 12.54 5.07 13.06 5.18 13.56L3.87 13.91C3.56 13.65 3.16 13.5 2.75 13.5C2.6 13.5 2.44 13.5 2.29 13.56C1.36 13.81 .809 14.77 1.06 15.71C1.27 16.5 2 17 2.75 17C2.9 17 3.05 17 3.21 16.94C3.78 16.78 4.21 16.36 4.39 15.84L5.9 15.43C6.35 16.22 6.95 16.92 7.65 17.5L6.55 19.5C6 19.58 5.5 19.89 5.21 20.42C4.75 21.27 5.07 22.33 5.92 22.79C6.18 22.93 6.47 23 6.75 23C7.37 23 7.97 22.67 8.29 22.08C8.57 21.56 8.56 20.96 8.31 20.47L9.38 18.5C10.19 18.82 11.07 19 12 19C12.06 19 12.12 19 12.18 19C12.05 19.26 12 19.56 12 19.88C12.08 20.8 12.84 21.5 13.75 21.5C13.79 21.5 13.84 21.5 13.88 21.5C14.85 21.42 15.57 20.58 15.5 19.62C15.46 19.12 15.21 18.68 14.85 18.39C15.32 18.18 15.77 17.91 16.19 17.6L18.53 19.94C18.43 20.5 18.59 21.07 19 21.5C19.35 21.83 19.8 22 20.25 22S21.15 21.83 21.5 21.5C22.17 20.8 22.17 19.7 21.5 19C21.15 18.67 20.7 18.5 20.25 18.5C20.15 18.5 20.05 18.5 19.94 18.53L17.6 16.19C18.09 15.54 18.47 14.8 18.71 14H19.82C20.13 14.45 20.66 14.75 21.25 14.75C22.22 14.75 23 13.97 23 13S22.22 11.25 21.25 11.25C20.66 11.25 20.13 11.55 19.82 12H19C19 10.43 18.5 9 17.6 7.81L18.94 6.47C19.05 6.5 19.15 6.5 19.25 6.5C19.7 6.5 20.15 6.33 20.5 6C21.17 5.31 21.17 4.2 20.5 3.5C20.15 3.17 19.7 3 19.25 3S18.35 3.17 18 3.5C17.59 3.93 17.43 4.5 17.53 5.06L16.19 6.4C15.27 5.71 14.19 5.25 13 5.08V3.68C13.45 3.37 13.75 2.84 13.75 2.25C13.75 1.28 12.97 .5 12 .5M12 17C9.24 17 7 14.76 7 12S9.24 7 12 7 17 9.24 17 12 14.76 17 12 17M10.5 9C9.67 9 9 9.67 9 10.5S9.67 12 10.5 12 12 11.33 12 10.5 11.33 9 10.5 9M14 13C13.45 13 13 13.45 13 14C13 14.55 13.45 15 14 15C14.55 15 15 14.55 15 14C15 13.45 14.55 13 14 13Z\";\r\nvar mdiVk = \"M15.07 2H8.93C3.33 2 2 3.33 2 8.93V15.07C2 20.67 3.33 22 8.93 22H15.07C20.67 22 22 20.67 22 15.07V8.93C22 3.33 20.67 2 15.07 2M18.15 16.27H16.69C16.14 16.27 15.97 15.82 15 14.83C14.12 14 13.74 13.88 13.53 13.88C13.24 13.88 13.15 13.96 13.15 14.38V15.69C13.15 16.04 13.04 16.26 12.11 16.26C10.57 16.26 8.86 15.32 7.66 13.59C5.85 11.05 5.36 9.13 5.36 8.75C5.36 8.54 5.43 8.34 5.85 8.34H7.32C7.69 8.34 7.83 8.5 7.97 8.9C8.69 11 9.89 12.8 10.38 12.8C10.57 12.8 10.65 12.71 10.65 12.25V10.1C10.6 9.12 10.07 9.03 10.07 8.68C10.07 8.5 10.21 8.34 10.44 8.34H12.73C13.04 8.34 13.15 8.5 13.15 8.88V11.77C13.15 12.08 13.28 12.19 13.38 12.19C13.56 12.19 13.72 12.08 14.05 11.74C15.1 10.57 15.85 8.76 15.85 8.76C15.95 8.55 16.11 8.35 16.5 8.35H17.93C18.37 8.35 18.47 8.58 18.37 8.89C18.19 9.74 16.41 12.25 16.43 12.25C16.27 12.5 16.21 12.61 16.43 12.9C16.58 13.11 17.09 13.55 17.43 13.94C18.05 14.65 18.53 15.24 18.66 15.65C18.77 16.06 18.57 16.27 18.15 16.27Z\";\r\nvar mdiVlc = \"M12,1C11.58,1 11.19,1.23 11,1.75L9.88,4.88C10.36,5.4 11.28,5.5 12,5.5C12.72,5.5 13.64,5.4 14.13,4.88L13,1.75C12.82,1.25 12.42,1 12,1M8.44,8.91L7,12.91C8.07,14.27 10.26,14.5 12,14.5C13.74,14.5 15.93,14.27 17,12.91L15.56,8.91C14.76,9.83 13.24,10 12,10C10.76,10 9.24,9.83 8.44,8.91M5.44,15C4.62,15 3.76,15.65 3.53,16.44L2.06,21.56C1.84,22.35 2.3,23 3.13,23H20.88C21.7,23 22.16,22.35 21.94,21.56L20.47,16.44C20.24,15.65 19.38,15 18.56,15H17.75L18.09,15.97C18.21,16.29 18.29,16.69 18.09,16.97C16.84,18.7 14.14,19 12,19C9.86,19 7.16,18.7 5.91,16.97C5.71,16.69 5.79,16.29 5.91,15.97L6.25,15H5.44Z\";\r\nvar mdiVoiceOff = \"M2,3.27L3.28,2L22,20.72L20.73,22L16.73,18C16.9,18.31 17,18.64 17,19V21H1V19C1,16.34 6.33,15 9,15C10.77,15 13.72,15.59 15.5,16.77L11.12,12.39C10.5,12.78 9.78,13 9,13A4,4 0 0,1 5,9C5,8.22 5.22,7.5 5.61,6.88L2,3.27M9,5A4,4 0 0,1 13,9V9.17L8.83,5H9M16.76,5.36C18.78,7.56 18.78,10.61 16.76,12.63L15.08,10.94C15.92,9.76 15.92,8.23 15.08,7.05L16.76,5.36M20.07,2C24,6.05 23.97,12.11 20.07,16L18.44,14.37C21.21,11.19 21.21,6.65 18.44,3.63L20.07,2Z\";\r\nvar mdiVoicemail = \"M18.5,15A3.5,3.5 0 0,1 15,11.5A3.5,3.5 0 0,1 18.5,8A3.5,3.5 0 0,1 22,11.5A3.5,3.5 0 0,1 18.5,15M5.5,15A3.5,3.5 0 0,1 2,11.5A3.5,3.5 0 0,1 5.5,8A3.5,3.5 0 0,1 9,11.5A3.5,3.5 0 0,1 5.5,15M18.5,6A5.5,5.5 0 0,0 13,11.5C13,12.83 13.47,14.05 14.26,15H9.74C10.53,14.05 11,12.83 11,11.5A5.5,5.5 0 0,0 5.5,6A5.5,5.5 0 0,0 0,11.5A5.5,5.5 0 0,0 5.5,17H18.5A5.5,5.5 0 0,0 24,11.5A5.5,5.5 0 0,0 18.5,6Z\";\r\nvar mdiVolleyball = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M13.6,20.35C15.96,18.04 17.69,15.08 18.5,11.76C17.84,11.62 17.18,11.54 16.5,11.5C15.56,15.11 13.41,18.22 10.5,20.37C11,20.45 11.5,20.5 12,20.5C12.55,20.5 13.08,20.45 13.6,20.35M9.23,20.04C12.23,18.07 14.5,15.05 15.46,11.5C14.71,11.55 13.97,11.65 13.27,11.81C12.18,14.89 9.97,17.44 7.13,18.97C7.77,19.42 8.5,19.78 9.23,20.04M20.5,12.37C20.16,12.23 19.81,12.11 19.46,12C18.76,14.9 17.39,17.53 15.54,19.73C18.36,18.44 20.35,15.64 20.5,12.37M3.56,11.04C3.5,11.35 3.5,11.68 3.5,12C3.5,14.5 4.57,16.73 6.27,18.28C6.86,18 7.41,17.66 7.94,17.29C6.08,15.54 4.58,13.41 3.56,11.04M5.33,6.74C4.73,7.5 4.26,8.35 3.95,9.28C4.92,12.13 6.58,14.66 8.74,16.67C9.25,16.24 9.72,15.77 10.15,15.26C7.74,13.03 6,10.08 5.33,6.74M8.04,4.5C7.36,4.85 6.73,5.3 6.18,5.82C6.71,9.21 8.37,12.23 10.77,14.47C11.17,13.91 11.5,13.32 11.82,12.7C9.68,10.56 8.28,7.69 8.04,4.5M19.96,9.03C18.7,8.68 17.37,8.5 16,8.5C14.1,8.5 12.28,8.85 10.61,9.5C10.96,10.1 11.35,10.67 11.8,11.2C13.12,10.75 14.53,10.5 16,10.5C17.57,10.5 19.08,10.78 20.47,11.29C20.4,10.5 20.23,9.74 19.96,9.03M17.54,5.57C17.03,5.5 16.5,5.5 16,5.5C13.69,5.5 11.47,5.94 9.44,6.73C9.62,7.38 9.86,8 10.14,8.61C11.96,7.89 13.93,7.5 16,7.5C17.18,7.5 18.32,7.63 19.42,7.87C18.93,7 18.29,6.21 17.54,5.57M16,4.5C14.79,3.87 13.44,3.5 12,3.5C10.95,3.5 9.94,3.7 9,4.05C9.04,4.63 9.11,5.2 9.21,5.75C11.31,4.95 13.6,4.5 16,4.5Z\";\r\nvar mdiVolumeHigh = \"M14,3.23V5.29C16.89,6.15 19,8.83 19,12C19,15.17 16.89,17.84 14,18.7V20.77C18,19.86 21,16.28 21,12C21,7.72 18,4.14 14,3.23M16.5,12C16.5,10.23 15.5,8.71 14,7.97V16C15.5,15.29 16.5,13.76 16.5,12M3,9V15H7L12,20V4L7,9H3Z\";\r\nvar mdiVolumeLow = \"M7,9V15H11L16,20V4L11,9H7Z\";\r\nvar mdiVolumeMedium = \"M5,9V15H9L14,20V4L9,9M18.5,12C18.5,10.23 17.5,8.71 16,7.97V16C17.5,15.29 18.5,13.76 18.5,12Z\";\r\nvar mdiVolumeMinus = \"M3,9H7L12,4V20L7,15H3V9M14,11H22V13H14V11Z\";\r\nvar mdiVolumeMute = \"M3,9H7L12,4V20L7,15H3V9M16.59,12L14,9.41L15.41,8L18,10.59L20.59,8L22,9.41L19.41,12L22,14.59L20.59,16L18,13.41L15.41,16L14,14.59L16.59,12Z\";\r\nvar mdiVolumeOff = \"M12,4L9.91,6.09L12,8.18M4.27,3L3,4.27L7.73,9H3V15H7L12,20V13.27L16.25,17.53C15.58,18.04 14.83,18.46 14,18.7V20.77C15.38,20.45 16.63,19.82 17.68,18.96L19.73,21L21,19.73L12,10.73M19,12C19,12.94 18.8,13.82 18.46,14.64L19.97,16.15C20.62,14.91 21,13.5 21,12C21,7.72 18,4.14 14,3.23V5.29C16.89,6.15 19,8.83 19,12M16.5,12C16.5,10.23 15.5,8.71 14,7.97V10.18L16.45,12.63C16.5,12.43 16.5,12.21 16.5,12Z\";\r\nvar mdiVolumePlus = \"M3,9H7L12,4V20L7,15H3V9M14,11H17V8H19V11H22V13H19V16H17V13H14V11Z\";\r\nvar mdiVolumeSource = \"M3 9V15H7L12 20V4L7 9H3M16 15H14V9H16V15M20 19H18V5H20V19Z\";\r\nvar mdiVolumeVariantOff = \"M5.64,3.64L21.36,19.36L19.95,20.78L16,16.83V20L11,15H7V9H8.17L4.22,5.05L5.64,3.64M16,4V11.17L12.41,7.58L16,4Z\";\r\nvar mdiVolumeVibrate = \"M4 9V15H8L13 20V4L8 9H4M16.55 2.47L15.5 3.53L17.93 6L15 9L17.93 12L15 15L17.93 18L15.5 20.47L16.55 21.53L20 18L17.07 15L20 12L17.07 9L20 6L16.55 2.47Z\";\r\nvar mdiVote = \"M18,13H17.32L15.32,15H17.23L19,17H5L6.78,15H8.83L6.83,13H6L3,16V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V16L18,13M17,7.95L12.05,12.9L8.5,9.36L13.46,4.41L17,7.95M12.76,2.29L6.39,8.66C6,9.05 6,9.68 6.39,10.07L11.34,15C11.73,15.41 12.36,15.41 12.75,15L19.11,8.66C19.5,8.27 19.5,7.64 19.11,7.25L14.16,2.3C13.78,1.9 13.15,1.9 12.76,2.29Z\";\r\nvar mdiVoteOutline = \"M18,13L21,16V20C21,21.11 20.1,22 19,22H5C3.89,22 3,21.1 3,20V16L6,13H6.83L8.83,15H6.78L5,17H19L17.23,15H15.32L17.32,13H18M19,20V19H5V20H19M11.34,15L6.39,10.07C6,9.68 6,9.05 6.39,8.66L12.76,2.29C13.15,1.9 13.78,1.9 14.16,2.3L19.11,7.25C19.5,7.64 19.5,8.27 19.11,8.66L12.75,15C12.36,15.41 11.73,15.41 11.34,15M13.46,4.41L8.5,9.36L12.05,12.9L17,7.95L13.46,4.41Z\";\r\nvar mdiVpn = \"M9,5H15L12,8L9,5M10.5,14.66C10.2,15 10,15.5 10,16A2,2 0 0,0 12,18A2,2 0 0,0 14,16C14,15.45 13.78,14.95 13.41,14.59L14.83,13.17C15.55,13.9 16,14.9 16,16A4,4 0 0,1 12,20A4,4 0 0,1 8,16C8,14.93 8.42,13.96 9.1,13.25L9.09,13.24L16.17,6.17V6.17C16.89,5.45 17.89,5 19,5A4,4 0 0,1 23,9A4,4 0 0,1 19,13C17.9,13 16.9,12.55 16.17,11.83L17.59,10.41C17.95,10.78 18.45,11 19,11A2,2 0 0,0 21,9A2,2 0 0,0 19,7C18.45,7 17.95,7.22 17.59,7.59L10.5,14.66M6.41,7.59C6.05,7.22 5.55,7 5,7A2,2 0 0,0 3,9A2,2 0 0,0 5,11C5.55,11 6.05,10.78 6.41,10.41L7.83,11.83C7.1,12.55 6.1,13 5,13A4,4 0 0,1 1,9A4,4 0 0,1 5,5C6.11,5 7.11,5.45 7.83,6.17V6.17L10.59,8.93L9.17,10.35L6.41,7.59Z\";\r\nvar mdiVuejs = \"M2,3H5.5L12,15L18.5,3H22L12,21L2,3M6.5,3H9.5L12,7.58L14.5,3H17.5L12,13.08L6.5,3Z\";\r\nvar mdiVuetify = \"M12,11.64L7.92,2H16.08L12,11.64M12,21.95L3.27,4.91H7.84L12,14.47L16.16,4.91H20.73L12,21.95Z\";\r\nvar mdiWalk = \"M14.12,10H19V8.2H15.38L13.38,4.87C13.08,4.37 12.54,4.03 11.92,4.03C11.74,4.03 11.58,4.06 11.42,4.11L6,5.8V11H7.8V7.33L9.91,6.67L6,22H7.8L10.67,13.89L13,17V22H14.8V15.59L12.31,11.05L13.04,8.18M14,3.8C15,3.8 15.8,3 15.8,2C15.8,1 15,0.2 14,0.2C13,0.2 12.2,1 12.2,2C12.2,3 13,3.8 14,3.8Z\";\r\nvar mdiWall = \"M3,16H12V21H3V16M2,10H8V15H2V10M9,10H15V15H9V10M16,10H22V15H16V10M13,16H21V21H13V16M3,4H11V9H3V4M12,4H21V9H12V4Z\";\r\nvar mdiWallSconce = \"M11,4L7,13H19L15,4H11M4,14V22H6V19H14V14H12V17H6V14H4Z\";\r\nvar mdiWallSconceFlat = \"M5,5V11H19V5H5M5.27,13.32L3.5,15.09L4.91,16.5L6.68,14.73L5.27,13.32M18.73,13.32L17.32,14.73L19.09,16.5L20.5,15.09L18.73,13.32M11,16V19H13V16H11Z\";\r\nvar mdiWallSconceFlatVariant = \"M19 19V13H5V19H19M18.73 10.68L20.5 8.91L19.09 7.5L17.32 9.27L18.73 10.68M5.27 10.68L6.68 9.27L4.91 7.5L3.5 8.91L5.27 10.68M13 8V5H11V8H13Z\";\r\nvar mdiWallSconceRound = \"M13 19V16H11V19H13M19.09 16.5L20.5 15.09L18.73 13.32L17.32 14.73L19.09 16.5M4.91 16.5L6.68 14.73L5.27 13.32L3.5 15.09L4.91 16.5M20 12C20 9.14 18.5 6.5 16 5.07S10.5 3.64 8 5.07 4 9.14 4 12H20Z\";\r\nvar mdiWallSconceRoundVariant = \"M11 5V8H13V5H11M4.91 7.5L3.5 8.91L5.27 10.68L6.68 9.27L4.91 7.5M19.09 7.5L17.32 9.27L18.73 10.68L20.5 8.91L19.09 7.5M4 12C4 14.86 5.5 17.5 8 18.93S13.5 20.36 16 18.93 20 14.86 20 12H4Z\";\r\nvar mdiWallet = \"M21,18V19A2,2 0 0,1 19,21H5C3.89,21 3,20.1 3,19V5A2,2 0 0,1 5,3H19A2,2 0 0,1 21,5V6H12C10.89,6 10,6.9 10,8V16A2,2 0 0,0 12,18M12,16H22V8H12M16,13.5A1.5,1.5 0 0,1 14.5,12A1.5,1.5 0 0,1 16,10.5A1.5,1.5 0 0,1 17.5,12A1.5,1.5 0 0,1 16,13.5Z\";\r\nvar mdiWalletGiftcard = \"M20,14H4V8H9.08L7,10.83L8.62,12L11,8.76L12,7.4L13,8.76L15.38,12L17,10.83L14.92,8H20M20,19H4V17H20M9,4A1,1 0 0,1 10,5A1,1 0 0,1 9,6A1,1 0 0,1 8,5A1,1 0 0,1 9,4M15,4A1,1 0 0,1 16,5A1,1 0 0,1 15,6A1,1 0 0,1 14,5A1,1 0 0,1 15,4M20,6H17.82C17.93,5.69 18,5.35 18,5A3,3 0 0,0 15,2C13.95,2 13.04,2.54 12.5,3.35L12,4L11.5,3.34C10.96,2.54 10.05,2 9,2A3,3 0 0,0 6,5C6,5.35 6.07,5.69 6.18,6H4C2.89,6 2,6.89 2,8V19C2,20.11 2.89,21 4,21H20C21.11,21 22,20.11 22,19V8C22,6.89 21.11,6 20,6Z\";\r\nvar mdiWalletMembership = \"M20,10H4V4H20M20,15H4V13H20M20,2H4C2.89,2 2,2.89 2,4V15C2,16.11 2.89,17 4,17H8V22L12,20L16,22V17H20C21.11,17 22,16.11 22,15V4C22,2.89 21.11,2 20,2Z\";\r\nvar mdiWalletOutline = \"M5,3C3.89,3 3,3.9 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V16.72C21.59,16.37 22,15.74 22,15V9C22,8.26 21.59,7.63 21,7.28V5A2,2 0 0,0 19,3H5M5,5H19V7H13A2,2 0 0,0 11,9V15A2,2 0 0,0 13,17H19V19H5V5M13,9H20V15H13V9M16,10.5A1.5,1.5 0 0,0 14.5,12A1.5,1.5 0 0,0 16,13.5A1.5,1.5 0 0,0 17.5,12A1.5,1.5 0 0,0 16,10.5Z\";\r\nvar mdiWalletPlus = \"M3 0V3H0V5H3V8H5V5H8V3H5V0H3M9 3V6H6V9H3V19C3 20.1 3.89 21 5 21H19C20.11 21 21 20.11 21 19V18H12C10.9 18 10 17.11 10 16V8C10 6.9 10.89 6 12 6H21V5C21 3.9 20.11 3 19 3H9M12 8V16H22V8H12M16 10.5C16.83 10.5 17.5 11.17 17.5 12C17.5 12.83 16.83 13.5 16 13.5C15.17 13.5 14.5 12.83 14.5 12C14.5 11.17 15.17 10.5 16 10.5Z\";\r\nvar mdiWalletPlusOutline = \"M3 0V3H0V5H3V8H5V5H8V3H5V0H3M10 3V5H19V7H13C11.9 7 11 7.9 11 9V15C11 16.1 11.9 17 13 17H19V19H5V10H3V19C3 20.1 3.89 21 5 21H19C20.1 21 21 20.1 21 19V16.72C21.59 16.37 22 15.74 22 15V9C22 8.26 21.59 7.63 21 7.28V5C21 3.9 20.1 3 19 3H10M13 9H20V15H13V9M16 10.5A1.5 1.5 0 0 0 14.5 12A1.5 1.5 0 0 0 16 13.5A1.5 1.5 0 0 0 17.5 12A1.5 1.5 0 0 0 16 10.5Z\";\r\nvar mdiWalletTravel = \"M20,14H4V8H7V10H9V8H15V10H17V8H20M20,19H4V17H20M9,4H15V6H9M20,6H17V4C17,2.89 16.11,2 15,2H9C7.89,2 7,2.89 7,4V6H4C2.89,6 2,6.89 2,8V19C2,20.11 2.89,21 4,21H20C21.11,21 22,20.11 22,19V8C22,6.89 21.11,6 20,6Z\";\r\nvar mdiWallpaper = \"M4,4H11V2H4A2,2 0 0,0 2,4V11H4V4M10,13L6,18H18L15,14L12.97,16.71L10,13M17,8.5A1.5,1.5 0 0,0 15.5,7A1.5,1.5 0 0,0 14,8.5A1.5,1.5 0 0,0 15.5,10A1.5,1.5 0 0,0 17,8.5M20,2H13V4H20V11H22V4A2,2 0 0,0 20,2M20,20H13V22H20A2,2 0 0,0 22,20V13H20V20M4,13H2V20A2,2 0 0,0 4,22H11V20H4V13Z\";\r\nvar mdiWan = \"M12,2A8,8 0 0,0 4,10C4,14.03 7,17.42 11,17.93V19H10A1,1 0 0,0 9,20H2V22H9A1,1 0 0,0 10,23H14A1,1 0 0,0 15,22H22V20H15A1,1 0 0,0 14,19H13V17.93C17,17.43 20,14.03 20,10A8,8 0 0,0 12,2M12,4C12,4 12.74,5.28 13.26,7H10.74C11.26,5.28 12,4 12,4M9.77,4.43C9.5,4.93 9.09,5.84 8.74,7H6.81C7.5,5.84 8.5,4.93 9.77,4.43M14.23,4.44C15.5,4.94 16.5,5.84 17.19,7H15.26C14.91,5.84 14.5,4.93 14.23,4.44M6.09,9H8.32C8.28,9.33 8.25,9.66 8.25,10C8.25,10.34 8.28,10.67 8.32,11H6.09C6.03,10.67 6,10.34 6,10C6,9.66 6.03,9.33 6.09,9M10.32,9H13.68C13.72,9.33 13.75,9.66 13.75,10C13.75,10.34 13.72,10.67 13.68,11H10.32C10.28,10.67 10.25,10.34 10.25,10C10.25,9.66 10.28,9.33 10.32,9M15.68,9H17.91C17.97,9.33 18,9.66 18,10C18,10.34 17.97,10.67 17.91,11H15.68C15.72,10.67 15.75,10.34 15.75,10C15.75,9.66 15.72,9.33 15.68,9M6.81,13H8.74C9.09,14.16 9.5,15.07 9.77,15.56C8.5,15.06 7.5,14.16 6.81,13M10.74,13H13.26C12.74,14.72 12,16 12,16C12,16 11.26,14.72 10.74,13M15.26,13H17.19C16.5,14.16 15.5,15.07 14.23,15.57C14.5,15.07 14.91,14.16 15.26,13Z\";\r\nvar mdiWardrobe = \"M4 4V19C4 20.1 4.9 21 6 21V22H8V21H11.5V2H6C4.9 2 4 2.9 4 4M8 10H10V13H8V10M18 2H12.5V21H16V22H18V21C19.1 21 20 20.1 20 19V4C20 2.9 19.1 2 18 2M16 13H14V10H16V13Z\";\r\nvar mdiWardrobeOutline = \"M6 2C4.89 2 4 2.9 4 4V19C4 20.11 4.89 21 6 21V22H8V21H16V22H18V21C19.11 21 20 20.11 20 19V4C20 2.9 19.11 2 18 2H6M6 4H11V19H6V4M13 4H18V19H13V4M8 10V13H10V10H8M14 10V13H16V10H14Z\";\r\nvar mdiWarehouse = \"M6 19H8V21H6V19M12 3L2 8V21H4V13H20V21H22V8L12 3M8 11H4V9H8V11M14 11H10V9H14V11M20 11H16V9H20V11M6 15H8V17H6V15M10 15H12V17H10V15M10 19H12V21H10V19M14 19H16V21H14V19Z\";\r\nvar mdiWashingMachine = \"M14.83,11.17C16.39,12.73 16.39,15.27 14.83,16.83C13.27,18.39 10.73,18.39 9.17,16.83L14.83,11.17M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2M7,4A1,1 0 0,0 6,5A1,1 0 0,0 7,6A1,1 0 0,0 8,5A1,1 0 0,0 7,4M10,4A1,1 0 0,0 9,5A1,1 0 0,0 10,6A1,1 0 0,0 11,5A1,1 0 0,0 10,4M12,8A6,6 0 0,0 6,14A6,6 0 0,0 12,20A6,6 0 0,0 18,14A6,6 0 0,0 12,8Z\";\r\nvar mdiWashingMachineAlert = \"M12.83 11.17C14.39 12.73 14.39 15.27 12.83 16.83S8.73 18.39 7.17 16.83L12.83 11.17M4 2H16C17.11 2 18 2.9 18 4V20C18 21.11 17.11 22 16 22H4C2.9 22 2 21.11 2 20V4C2 2.9 2.9 2 4 2M5 4C4.45 4 4 4.45 4 5S4.45 6 5 6 6 5.55 6 5 5.55 4 5 4M8 4C7.45 4 7 4.45 7 5S7.45 6 8 6 9 5.55 9 5 8.55 4 8 4M10 8C6.69 8 4 10.69 4 14S6.69 20 10 20 16 17.31 16 14 13.31 8 10 8M20 15H22V17H20V15M20 7H22V13H20V7Z\";\r\nvar mdiWashingMachineOff = \"M22.11 21.46L2.39 1.73L1.11 3L4 5.89V20C4 21.11 4.89 22 6 22H18C18.58 22 19.1 21.75 19.46 21.35L20.84 22.73L22.11 21.46M12 20C8.69 20 6 17.31 6 14C6 12.32 6.7 10.8 7.82 9.71L12.06 13.95L9.17 16.83C10.73 18.39 13.27 18.39 14.83 16.83C14.85 16.81 14.86 16.79 14.88 16.77L16.29 18.18C15.2 19.3 13.69 20 12 20M11.25 8.05C11.5 8 11.75 8 12 8C15.31 8 18 10.69 18 14C18 14.25 18 14.5 17.95 14.75L20 16.8V4C20 2.9 19.11 2 18 2H6C5.76 2 5.54 2.05 5.33 2.13L11.25 8.05M10 4C10.55 4 11 4.45 11 5S10.55 6 10 6 9 5.55 9 5 9.45 4 10 4Z\";\r\nvar mdiWatch = \"M6,12A6,6 0 0,1 12,6A6,6 0 0,1 18,12A6,6 0 0,1 12,18A6,6 0 0,1 6,12M20,12C20,9.45 18.81,7.19 16.95,5.73L16,0H8L7.05,5.73C5.19,7.19 4,9.45 4,12C4,14.54 5.19,16.81 7.05,18.27L8,24H16L16.95,18.27C18.81,16.81 20,14.54 20,12Z\";\r\nvar mdiWatchExport = \"M14,11H19L16.5,8.5L17.92,7.08L22.84,12L17.92,16.92L16.5,15.5L19,13H14V11M12,18A6,6 0 0,1 6,12A6,6 0 0,1 12,6C13.4,6 14.69,6.5 15.71,7.29L17.13,5.87L16.95,5.73L16,0H8L7.05,5.73C5.19,7.19 4,9.46 4,12C4,14.55 5.19,16.81 7.05,18.27L8,24H16L16.95,18.27L17.13,18.13L15.71,16.71C14.69,17.5 13.4,18 12,18Z\";\r\nvar mdiWatchExportVariant = \"M14,11H19L16.5,8.5L17.92,7.08L22.84,12L17.92,16.92L16.5,15.5L19,13H14V11M8,0H16L16.83,5H17C17.28,5 17.54,5.06 17.78,5.16L15.94,7H7V17H15.94L17.78,18.84C17.54,18.94 17.28,19 17,19H16.83L16,24H8L7.17,19H7A2,2 0 0,1 5,17V7C5,5.89 5.9,5 7,5H7.17L8,0Z\";\r\nvar mdiWatchImport = \"M2,11H7L4.5,8.5L5.92,7.08L10.84,12L5.92,16.92L4.5,15.5L7,13H2V11M12,18A6,6 0 0,0 18,12A6,6 0 0,0 12,6C10.6,6 9.31,6.5 8.29,7.29L6.87,5.87L7.05,5.73L8,0H16L16.95,5.73C18.81,7.19 20,9.45 20,12C20,14.54 18.81,16.81 16.95,18.27L16,24H8L7.05,18.27L6.87,18.13L8.29,16.71C9.31,17.5 10.6,18 12,18Z\";\r\nvar mdiWatchImportVariant = \"M1,11H6L3.5,8.5L4.92,7.08L9.84,12L4.92,16.92L3.5,15.5L6,13H1V11M8,0H16L16.83,5H17A2,2 0 0,1 19,7V17C19,18.11 18.1,19 17,19H16.83L16,24H8L7.17,19H7C6.46,19 6,18.79 5.62,18.44L7.06,17H17V7H7.06L5.62,5.56C6,5.21 6.46,5 7,5H7.17L8,0Z\";\r\nvar mdiWatchVariant = \"M8,0L7.17,5H7A2,2 0 0,0 5,7V17C5,18.11 5.9,19 7,19H7.17L8,24H16L16.83,19H17A2,2 0 0,0 19,17V7C19,5.89 18.1,5 17,5H16.83L16,0H8M7,7H17V17H7V7Z\";\r\nvar mdiWatchVibrate = \"M3,17V7H5V17H3M19,17V7H21V17H19M22,9H24V15H22V9M0,15V9H2V15H0M17.96,11.97C17.96,13.87 17.07,15.57 15.68,16.67L14.97,20.95H9L8.27,16.67C6.88,15.57 6,13.87 6,11.97C6,10.07 6.88,8.37 8.27,7.28L9,3H14.97L15.68,7.28C17.07,8.37 17.96,10.07 17.96,11.97M7.5,11.97C7.5,14.45 9.5,16.46 11.97,16.46A4.5,4.5 0 0,0 16.46,11.97C16.46,9.5 14.45,7.5 11.97,7.5A4.47,4.47 0 0,0 7.5,11.97Z\";\r\nvar mdiWatchVibrateOff = \"M0,9H2V15H0V9M12,7.5C14.47,7.5 16.47,9.53 16.46,12C16.45,12.38 16.4,12.76 16.3,13.13L17.5,14.31C17.81,13.58 18,12.8 18,12C18,10.17 17.16,8.44 15.72,7.31L15,3H9L8.59,5.39L10.86,7.66C11.23,7.55 11.61,7.5 12,7.5M21,17V7H19V15.8L20.2,17H21M16.5,15.86L22.11,21.46L20.84,22.73L15.55,17.44L15,21H9L8.27,16.72C5.85,14.82 5.27,11.4 6.91,8.8L1.11,3L2.39,1.73L8.09,7.44L9.17,8.5L15.44,14.79L16.5,15.86M14.05,15.94L8.05,9.94C7.7,10.57 7.5,11.28 7.5,12C7.5,14.47 9.53,16.47 12,16.46C12.72,16.46 13.42,16.28 14.05,15.94M22,9V15H24V9H22M3,17H5V7H3V17Z\";\r\nvar mdiWater = \"M12,20A6,6 0 0,1 6,14C6,10 12,3.25 12,3.25C12,3.25 18,10 18,14A6,6 0 0,1 12,20Z\";\r\nvar mdiWaterAlert = \"M10 3.25C10 3.25 16 10 16 14C16 17.31 13.31 20 10 20S4 17.31 4 14C4 10 10 3.25 10 3.25M20 7V13H18V7H20M18 17H20V15H18V17Z\";\r\nvar mdiWaterAlertOutline = \"M10 3.25C10 3.25 4 10 4 14C4 17.31 6.69 20 10 20S16 17.31 16 14C16 10 10 3.25 10 3.25M10 18C7.79 18 6 16.21 6 14C6 12.23 8 8.96 10 6.39C12 8.95 14 12.23 14 14C14 16.21 12.21 18 10 18M20 7V13H18V7H20M18 17H20V15H18V17Z\";\r\nvar mdiWaterBoiler = \"M8 2C6.89 2 6 2.89 6 4V16C6 17.11 6.89 18 8 18H9V20H6V22H9C10.11 22 11 21.11 11 20V18H13V20C13 21.11 13.89 22 15 22H18V20H15V18H16C17.11 18 18 17.11 18 16V4C18 2.89 17.11 2 16 2H8M12 4.97A2 2 0 0 1 14 6.97A2 2 0 0 1 12 8.97A2 2 0 0 1 10 6.97A2 2 0 0 1 12 4.97M10 14.5H14V16H10V14.5Z\";\r\nvar mdiWaterBoilerAlert = \"M6 2C4.89 2 4 2.89 4 4V16C4 17.11 4.89 18 6 18H7V20H4V22H7C8.11 22 9 21.11 9 20V18H11V20C11 21.11 11.89 22 13 22H16V20H13V18H14C15.11 18 16 17.11 16 16V4C16 2.89 15.11 2 14 2H6M10 4.97C11.11 4.97 12 5.87 12 6.97S11.11 8.97 10 8.97C8.9 8.97 8 8.07 8 6.97C8 5.87 8.9 4.97 10 4.97M8 14.5H12V16H8V14.5M18 15H20V17H18V15M18 7H20V13H18V7Z\";\r\nvar mdiWaterBoilerOff = \"M10 6.82L6.25 3.05C6.59 2.42 7.24 2 8 2H16C17.11 2 18 2.89 18 4V14.8L12.16 8.96C13.19 8.87 14 8 14 6.97C14 5.87 13.11 4.97 12 4.97C10.95 4.97 10.1 5.78 10 6.82M15 18V20H18V22H15C13.89 22 13 21.11 13 20V18H11V20C11 21.11 10.11 22 9 22H6V20H9V18H8C6.89 18 6 17.11 6 16V7.89L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73L16.1 18C16.06 18 16.03 18 16 18H15M14 16V15.89L12.61 14.5H10V16H14Z\";\r\nvar mdiWaterCheck = \"M21.75 16.25L17 21L14.25 18L15.41 16.84L17 18.43L20.59 14.84L21.75 16.25M17.62 12C16.31 8.1 12 3.25 12 3.25S6 10 6 14C6 17.31 8.69 20 12 20H12.34C12.12 19.36 12 18.7 12 18C12 14.82 14.5 12.22 17.62 12Z\";\r\nvar mdiWaterCheckOutline = \"M21.75 16.25L17 21L14.25 18L15.41 16.84L17 18.43L20.59 14.84L21.75 16.25M8 14C8 12.23 10 8.96 12 6.39C13.5 8.33 15 10.67 15.67 12.47C16.27 12.21 16.93 12.06 17.62 12C16.31 8.1 12 3.25 12 3.25S6 10 6 14C6 17.31 8.69 20 12 20C12.12 20 12.23 20 12.34 20C12.12 19.36 12 18.7 12 18C9.79 18 8 16.21 8 14Z\";\r\nvar mdiWaterMinus = \"M22 17V19H14V17H22M17.62 12C16.31 8.1 12 3.25 12 3.25S6 10 6 14C6 17.31 8.69 20 12 20C12.12 20 12.23 20 12.34 20C12.12 19.36 12 18.7 12 18C12 14.82 14.5 12.22 17.62 12Z\";\r\nvar mdiWaterMinusOutline = \"M22 17V19H14V17H22M8 14C8 12.23 10 8.96 12 6.39C13.5 8.33 15 10.67 15.67 12.47C16.27 12.21 16.93 12.06 17.62 12C16.31 8.1 12 3.25 12 3.25S6 10 6 14C6 17.31 8.69 20 12 20C12.12 20 12.23 20 12.34 20C12.12 19.36 12 18.7 12 18C9.79 18 8 16.21 8 14Z\";\r\nvar mdiWaterOff = \"M20.84 22.73L16.29 18.18C15.2 19.3 13.69 20 12 20C8.69 20 6 17.31 6 14C6 12.67 6.67 11.03 7.55 9.44L1.11 3L2.39 1.73L22.11 21.46L20.84 22.73M18 14C18 10 12 3.25 12 3.25S10.84 4.55 9.55 6.35L17.95 14.75C18 14.5 18 14.25 18 14Z\";\r\nvar mdiWaterOffOutline = \"M22.11 21.46L2.39 1.73L1.11 3L7.65 9.54C6.74 11.03 6 12.65 6 14.23C6 17.54 8.69 20.23 12 20.23C13.74 20.23 15.3 19.5 16.4 18.29L20.84 22.73L22.11 21.46M12 18.23C9.78 18.23 8 16.45 8 14.23C8 13.5 8.5 12.27 9.14 11.03L15 16.88C14.26 17.71 13.2 18.23 12 18.23M11.14 7.94L9.71 6.5C10.57 5.38 11.25 4.61 11.25 4.61L12 3.77L12.75 4.61C12.75 4.61 14.03 6.06 15.32 7.94S18 12.07 18 14.23C18 14.41 18 14.59 17.97 14.77L15.46 12.26C15 11.23 14.37 10.07 13.68 9.07C12.84 7.85 12.44 7.42 12 6.9C11.73 7.21 11.5 7.5 11.14 7.94Z\";\r\nvar mdiWaterOutline = \"M12,3.77L11.25,4.61C11.25,4.61 9.97,6.06 8.68,7.94C7.39,9.82 6,12.07 6,14.23A6,6 0 0,0 12,20.23A6,6 0 0,0 18,14.23C18,12.07 16.61,9.82 15.32,7.94C14.03,6.06 12.75,4.61 12.75,4.61L12,3.77M12,6.9C12.44,7.42 12.84,7.85 13.68,9.07C14.89,10.83 16,13.07 16,14.23C16,16.45 14.22,18.23 12,18.23C9.78,18.23 8,16.45 8,14.23C8,13.07 9.11,10.83 10.32,9.07C11.16,7.85 11.56,7.42 12,6.9Z\";\r\nvar mdiWaterPercent = \"M12,3.25C12,3.25 6,10 6,14C6,17.32 8.69,20 12,20A6,6 0 0,0 18,14C18,10 12,3.25 12,3.25M14.47,9.97L15.53,11.03L9.53,17.03L8.47,15.97M9.75,10A1.25,1.25 0 0,1 11,11.25A1.25,1.25 0 0,1 9.75,12.5A1.25,1.25 0 0,1 8.5,11.25A1.25,1.25 0 0,1 9.75,10M14.25,14.5A1.25,1.25 0 0,1 15.5,15.75A1.25,1.25 0 0,1 14.25,17A1.25,1.25 0 0,1 13,15.75A1.25,1.25 0 0,1 14.25,14.5Z\";\r\nvar mdiWaterPercentAlert = \"M20 7V13H18V7H20M18 17H20V15H18V17M10 3.25C10 3.25 4 10 4 14C4 17.32 6.69 20 10 20S16 17.31 16 14C16 10 10 3.25 10 3.25M7.75 10C8.44 10 9 10.56 9 11.25S8.44 12.5 7.75 12.5 6.5 11.94 6.5 11.25 7.06 10 7.75 10M12.25 17C11.56 17 11 16.44 11 15.75S11.56 14.5 12.25 14.5 13.5 15.06 13.5 15.75 12.94 17 12.25 17M7.53 17.03L6.47 15.97L12.47 9.97L13.53 11.03L7.53 17.03Z\";\r\nvar mdiWaterPlus = \"M12 18C12 18.7 12.12 19.36 12.34 20C12.23 20 12.12 20 12 20C8.69 20 6 17.31 6 14C6 10 12 3.25 12 3.25S16.31 8.1 17.62 12C14.5 12.22 12 14.82 12 18M19 17V14H17V17H14V19H17V22H19V19H22V17H19Z\";\r\nvar mdiWaterPlusOutline = \"M12 18C12 18.7 12.12 19.36 12.34 20C12.23 20 12.12 20 12 20C8.69 20 6 17.31 6 14C6 10 12 3.25 12 3.25S16.31 8.1 17.62 12C16.93 12.06 16.28 12.22 15.67 12.47C15 10.68 13.5 8.33 12 6.39C10 8.96 8 12.23 8 14C8 16.21 9.79 18 12 18M19 17V14H17V17H14V19H17V22H19V19H22V17H19Z\";\r\nvar mdiWaterPolo = \"M20 16H22V18H20C18.6 18 17.2 17.6 16 17C13.5 18.3 10.5 18.3 8 17C6.8 17.6 5.4 18 4 18H2V16H4C5.4 16 6.8 15.5 8 14.7C10.4 16.4 13.6 16.4 16 14.7C17.2 15.5 18.6 16 20 16M13 10.6C13.6 10.3 14.3 10 15 9.9V10.2C15.3 11.2 15.3 12.1 15.2 13.1C14.3 13.6 13.2 13.9 12.2 13.9C12.7 12.9 13 11.7 13 10.6M12.9 3.6C11.5 4 10.3 4.7 9.3 5.7C8.9 4.7 8.7 3.7 8.7 2.7C10.9 1.7 13.4 1.8 15.6 2.9C15.9 3 16.2 3.1 16.4 3.3C15.2 3.2 14 3.3 12.9 3.6M6.8 13.3C6.2 13.6 5.6 13.8 5 13.9C4.3 12.6 4 11.2 4 9.8C4.5 10.8 5.2 11.8 6 12.6C6.3 12.8 6.5 13.1 6.8 13.3M19 13.9C18.4 13.8 17.8 13.6 17.3 13.4C17.5 12.2 17.4 11 17.1 9.8C18.2 9.9 19.2 10.2 20.1 10.8C20 11.8 19.7 12.7 19.2 13.6L19 13.9M7.4 11.2C6.2 10.1 5.5 8.5 5.2 6.9L5.1 6C5.6 5.2 6.1 4.6 6.8 4C6.9 5.4 7.4 6.7 8.2 7.8C8.9 8.9 9.9 9.9 11 10.5C11 11.3 10.8 12.1 10.5 12.9C9.3 12.6 8.3 12 7.4 11.2M13.5 5.5C15 5.1 16.7 5.2 18.2 5.7L19 6.1C19.4 6.8 19.6 7.6 19.8 8.4C17.3 7.3 14.4 7.5 12 8.8C11.3 8.5 10.8 8 10.3 7.4L10.4 7.3C11.3 6.5 12.3 5.8 13.5 5.5M16 18.7C17.2 19.5 18.6 20 20 20H22V22H20C18.6 22 17.2 21.6 16 21C13.5 22.3 10.5 22.3 8 21C6.8 21.6 5.4 22 4 22H2V20H4C5.4 20 6.8 19.5 8 18.7C10.4 20.4 13.6 20.4 16 18.7Z\";\r\nvar mdiWaterPump = \"M19,14.5C19,14.5 21,16.67 21,18A2,2 0 0,1 19,20A2,2 0 0,1 17,18C17,16.67 19,14.5 19,14.5M5,18V9A2,2 0 0,1 3,7A2,2 0 0,1 5,5V4A2,2 0 0,1 7,2H9A2,2 0 0,1 11,4V5H19A2,2 0 0,1 21,7V9L21,11A1,1 0 0,1 22,12A1,1 0 0,1 21,13H17A1,1 0 0,1 16,12A1,1 0 0,1 17,11V9H11V18H12A2,2 0 0,1 14,20V22H2V20A2,2 0 0,1 4,18H5Z\";\r\nvar mdiWaterPumpOff = \"M5.7 2.5A2 2 0 0 1 7 2H9A2 2 0 0 1 11 4V5H19A2 2 0 0 1 21 7V11A1 1 0 0 1 21 13H17A1 1 0 0 1 17 11V9H12.2M20.84 22.73L22.11 21.46L11 10.34L2.39 1.73L1.11 3L3.65 5.54A2 2 0 0 0 5 9V18H4A2 2 0 0 0 2 20V22H14V20A2 2 0 0 0 12 18H11V12.89Z\";\r\nvar mdiWaterRemove = \"M12 18C12 18.7 12.12 19.36 12.34 20C12.23 20 12.12 20 12 20C8.69 20 6 17.31 6 14C6 10 12 3.25 12 3.25S16.31 8.1 17.62 12C14.5 12.22 12 14.82 12 18M21.54 15.88L20.13 14.47L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.53L18 19.41L20.12 21.53L21.53 20.12L19.41 18L21.54 15.88Z\";\r\nvar mdiWaterRemoveOutline = \"M12 18C12 18.7 12.12 19.36 12.34 20C12.23 20 12.12 20 12 20C8.69 20 6 17.31 6 14C6 10 12 3.25 12 3.25S16.31 8.1 17.62 12C16.93 12.06 16.28 12.22 15.67 12.47C15 10.68 13.5 8.33 12 6.39C10 8.96 8 12.23 8 14C8 16.21 9.79 18 12 18M21.54 15.88L20.13 14.47L18 16.59L15.88 14.47L14.47 15.88L16.59 18L14.47 20.12L15.88 21.53L18 19.41L20.12 21.53L21.53 20.12L19.41 18L21.54 15.88Z\";\r\nvar mdiWaterWell = \"M22 16H2V18H4V22H20V18H22V16M10.44 15C10.19 15 10 14.81 9.95 14.56L9.57 11.56C9.57 11.54 9.57 11.5 9.57 11.5C9.57 11.22 9.79 11 10.07 11H13.93C13.95 11 13.97 11 14 11C14.27 11.04 14.46 11.29 14.43 11.56L14.05 14.56C14 14.81 13.81 15 13.56 15H10.44M19 2L21.56 6.68C21.6 6.78 21.61 6.89 21.61 7C21.61 7.56 21.16 8 20.61 8H19V15H17V8H13V10H11V8H7V15H5V8H3.62C3.46 8 3.31 7.96 3.16 7.89C2.67 7.64 2.47 7.04 2.72 6.55L5 2H19Z\";\r\nvar mdiWaterWellOutline = \"M3.62 8H5V15H7V8H11V10H13V8H17V15H19V8H20.61C21.16 8 21.61 7.56 21.61 7C21.61 6.89 21.6 6.78 21.56 6.68L19 2H5L2.72 6.55C2.47 7.04 2.67 7.64 3.16 7.89C3.31 7.96 3.46 8 3.62 8M6.24 4H17.76L18.76 6H5.24L6.24 4M2 16V18H4V22H20V18H22V16H2M18 20H6V18H18V20M13.93 11C14.21 11 14.43 11.22 14.43 11.5C14.43 11.5 14.43 11.54 14.43 11.56L14.05 14.56C14 14.81 13.81 15 13.56 15H10.44C10.19 15 10 14.81 9.95 14.56L9.57 11.56C9.54 11.29 9.73 11.04 10 11C10.03 11 10.05 11 10.07 11H13.93Z\";\r\nvar mdiWateringCan = \"M18.5 7.47C17.76 8.2 17.57 9.25 17.92 10.15L15 13.07V11C15 10.45 14.55 10 14 10H12.97C13 9.83 13 9.67 13 9.5C13 6.46 10.54 4 7.5 4S2 6.46 2 9.5C2 11.21 2.78 12.73 4 13.74V20C4 20.55 4.45 21 5 21H14C14.55 21 15 20.55 15 20V15.89L19.33 11.56C20.23 11.91 21.28 11.73 22 11L18.5 7.47M4.05 10C4.03 9.83 4 9.67 4 9.5C4 7.57 5.57 6 7.5 6S11 7.57 11 9.5C11 9.67 10.97 9.83 10.95 10H4.05Z\";\r\nvar mdiWateringCanOutline = \"M18.5 7.47C17.76 8.2 17.57 9.25 17.92 10.15L15 13.07V11C15 10.45 14.55 10 14 10H12.97C13 9.83 13 9.67 13 9.5C13 6.46 10.54 4 7.5 4S2 6.46 2 9.5C2 11.21 2.78 12.73 4 13.74V20C4 20.55 4.45 21 5 21H14C14.55 21 15 20.55 15 20V15.89L19.33 11.56C20.23 11.91 21.28 11.73 22 11L18.5 7.47M4.05 10C4.03 9.83 4 9.67 4 9.5C4 7.57 5.57 6 7.5 6S11 7.57 11 9.5C11 9.67 10.97 9.83 10.95 10M13 19H6V12H13V19Z\";\r\nvar mdiWatermark = \"M21,3H3A2,2 0 0,0 1,5V19A2,2 0 0,0 3,21H21A2,2 0 0,0 23,19V5A2,2 0 0,0 21,3M21,19H12V13H21V19Z\";\r\nvar mdiWave = \"M20,12C18.61,12 17.22,11.53 16,10.67C13.56,12.38 10.44,12.38 8,10.67C6.78,11.53 5.39,12 4,12H2V14H4C5.37,14 6.74,13.65 8,13C10.5,14.3 13.5,14.3 16,13C17.26,13.65 18.62,14 20,14H22V12\";\r\nvar mdiWaveform = \"M22 12L20 13L19 14L18 13L17 16L16 13L15 21L14 13L13 15L12 13L11 17L10 13L9 22L8 13L7 19L6 13L5 14L4 13L2 12L4 11L5 10L6 11L7 5L8 11L9 2L10 11L11 7L12 11L13 9L14 11L15 3L16 11L17 8L18 11L19 10L20 11L22 12Z\";\r\nvar mdiWaves = \"M20,12H22V14H20C18.62,14 17.26,13.65 16,13C13.5,14.3 10.5,14.3 8,13C6.74,13.65 5.37,14 4,14H2V12H4C5.39,12 6.78,11.53 8,10.67C10.44,12.38 13.56,12.38 16,10.67C17.22,11.53 18.61,12 20,12M20,6H22V8H20C18.62,8 17.26,7.65 16,7C13.5,8.3 10.5,8.3 8,7C6.74,7.65 5.37,8 4,8H2V6H4C5.39,6 6.78,5.53 8,4.67C10.44,6.38 13.56,6.38 16,4.67C17.22,5.53 18.61,6 20,6M20,18H22V20H20C18.62,20 17.26,19.65 16,19C13.5,20.3 10.5,20.3 8,19C6.74,19.65 5.37,20 4,20H2V18H4C5.39,18 6.78,17.53 8,16.67C10.44,18.38 13.56,18.38 16,16.67C17.22,17.53 18.61,18 20,18Z\";\r\nvar mdiWaze = \"M20.54,6.63C21.23,7.57 21.69,8.67 21.89,9.82C22.1,11.07 22,12.34 21.58,13.54C21.18,14.71 20.5,15.76 19.58,16.6C18.91,17.24 18.15,17.77 17.32,18.18C17.73,19.25 17.19,20.45 16.12,20.86C15.88,20.95 15.63,21 15.38,21C14.27,21 13.35,20.11 13.31,19C13.05,19 10.73,19 10.24,19C10.13,20.14 9.11,21 7.97,20.87C6.91,20.77 6.11,19.89 6.09,18.83C6.1,18.64 6.13,18.44 6.19,18.26C4.6,17.73 3.21,16.74 2.19,15.41C1.86,14.97 1.96,14.34 2.42,14C2.6,13.86 2.82,13.78 3.05,13.78C3.77,13.78 4.05,13.53 4.22,13.15C4.46,12.43 4.6,11.68 4.61,10.92C4.64,10.39 4.7,9.87 4.78,9.35C5.13,7.62 6.1,6.07 7.5,5C9.16,3.7 11.19,3 13.29,3C14.72,3 16.13,3.35 17.4,4C18.64,4.62 19.71,5.5 20.54,6.63M16.72,17.31C18.5,16.5 19.9,15.04 20.59,13.21C22.21,8.27 18,4.05 13.29,4.05C12.94,4.05 12.58,4.07 12.23,4.12C9.36,4.5 6.4,6.5 5.81,9.5C5.43,11.5 6,14.79 3.05,14.79C4,16 5.32,16.93 6.81,17.37C7.66,16.61 8.97,16.69 9.74,17.55C9.85,17.67 9.94,17.8 10,17.94C10.59,17.94 13.2,17.94 13.55,17.94C14.07,16.92 15.33,16.5 16.35,17.04C16.5,17.12 16.6,17.21 16.72,17.31M10.97,10.31C10.39,10.34 9.88,9.9 9.85,9.31C9.82,8.73 10.27,8.23 10.85,8.19C11.43,8.16 11.94,8.61 11.97,9.25C12,9.8 11.56,10.27 11,10.29L10.97,10.31M15.66,10.31C15.08,10.34 14.57,9.9 14.54,9.31C14.5,8.73 14.96,8.23 15.54,8.19C16.12,8.16 16.63,8.61 16.66,9.25C16.68,9.8 16.25,10.27 15.66,10.29V10.31M9.71,12.07C9.65,11.79 9.84,11.5 10.12,11.45C10.4,11.4 10.68,11.58 10.74,11.86V11.86C11.09,12.97 12.16,13.69 13.32,13.6C14.46,13.66 15.5,12.96 15.89,11.88C16.03,11.62 16.35,11.5 16.6,11.65C16.78,11.75 16.89,11.92 16.89,12.12C16.7,12.83 16.26,13.45 15.66,13.88C14.97,14.36 14.16,14.63 13.32,14.64H13.21C11.58,14.71 10.11,13.64 9.68,12.06L9.71,12.07Z\";\r\nvar mdiWeatherCloudy = \"M6,19A5,5 0 0,1 1,14A5,5 0 0,1 6,9C7,6.65 9.3,5 12,5C15.43,5 18.24,7.66 18.5,11.03L19,11A4,4 0 0,1 23,15A4,4 0 0,1 19,19H6M19,13H17V12A5,5 0 0,0 12,7C9.5,7 7.45,8.82 7.06,11.19C6.73,11.07 6.37,11 6,11A3,3 0 0,0 3,14A3,3 0 0,0 6,17H19A2,2 0 0,0 21,15A2,2 0 0,0 19,13Z\";\r\nvar mdiWeatherCloudyAlert = \"M6,19A5,5 0 0,1 1,14A5,5 0 0,1 6,9C7,6.65 9.3,5 12,5C15.43,5 18.24,7.66 18.5,11.03L19,11A4,4 0 0,1 23,15A4,4 0 0,1 19,19H6M19,13H17V12A5,5 0 0,0 12,7C9.5,7 7.45,8.82 7.06,11.19C6.73,11.07 6.37,11 6,11A3,3 0 0,0 3,14A3,3 0 0,0 6,17H19A2,2 0 0,0 21,15A2,2 0 0,0 19,13M13,12H11V8H13V12M13,16H11V14H13\";\r\nvar mdiWeatherCloudyArrowRight = \"M6,7L6.69,7.06C7.32,4.72 9.46,3 12,3A5.5,5.5 0 0,1 17.5,8.5L17.42,9.45C17.88,9.16 18.42,9 19,9A3,3 0 0,1 22,12A3,3 0 0,1 19,15H6A4,4 0 0,1 2,11A4,4 0 0,1 6,7M6,9A2,2 0 0,0 4,11A2,2 0 0,0 6,13H19A1,1 0 0,0 20,12A1,1 0 0,0 19,11H15.5V8.5A3.5,3.5 0 0,0 12,5A3.5,3.5 0 0,0 8.5,8.5V9H6M22,19L19,22V20H2V18H19V16L22,19\";\r\nvar mdiWeatherFog = \"M3,15H13A1,1 0 0,1 14,16A1,1 0 0,1 13,17H3A1,1 0 0,1 2,16A1,1 0 0,1 3,15M16,15H21A1,1 0 0,1 22,16A1,1 0 0,1 21,17H16A1,1 0 0,1 15,16A1,1 0 0,1 16,15M1,12A5,5 0 0,1 6,7C7,4.65 9.3,3 12,3C15.43,3 18.24,5.66 18.5,9.03L19,9C21.19,9 22.97,10.76 23,13H21A2,2 0 0,0 19,11H17V10A5,5 0 0,0 12,5C9.5,5 7.45,6.82 7.06,9.19C6.73,9.07 6.37,9 6,9A3,3 0 0,0 3,12C3,12.35 3.06,12.69 3.17,13H1.1L1,12M3,19H5A1,1 0 0,1 6,20A1,1 0 0,1 5,21H3A1,1 0 0,1 2,20A1,1 0 0,1 3,19M8,19H21A1,1 0 0,1 22,20A1,1 0 0,1 21,21H8A1,1 0 0,1 7,20A1,1 0 0,1 8,19Z\";\r\nvar mdiWeatherHail = \"M6,14A1,1 0 0,1 7,15A1,1 0 0,1 6,16A5,5 0 0,1 1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16H18A1,1 0 0,1 17,15A1,1 0 0,1 18,14H19A2,2 0 0,0 21,12A2,2 0 0,0 19,10H17V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11A3,3 0 0,0 6,14M10,18A2,2 0 0,1 12,20A2,2 0 0,1 10,22A2,2 0 0,1 8,20A2,2 0 0,1 10,18M14.5,16A1.5,1.5 0 0,1 16,17.5A1.5,1.5 0 0,1 14.5,19A1.5,1.5 0 0,1 13,17.5A1.5,1.5 0 0,1 14.5,16M10.5,12A1.5,1.5 0 0,1 12,13.5A1.5,1.5 0 0,1 10.5,15A1.5,1.5 0 0,1 9,13.5A1.5,1.5 0 0,1 10.5,12Z\";\r\nvar mdiWeatherHazy = \"M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M20.65,7L18.88,10.79C18.74,10 18.47,9.23 18.05,8.5C17.63,7.78 17.1,7.15 16.5,6.64M14,15A1,1 0 0,0 13,14H3A1,1 0 0,0 2,15A1,1 0 0,0 3,16H13A1,1 0 0,0 14,15M22,15A1,1 0 0,0 21,14H17A1,1 0 0,0 16,15A1,1 0 0,0 17,16H21A1,1 0 0,0 22,15M10,19A1,1 0 0,0 11,20H20A1,1 0 0,0 21,19A1,1 0 0,0 20,18H11A1,1 0 0,0 10,19M3,19A1,1 0 0,0 4,20H7A1,1 0 0,0 8,19A1,1 0 0,0 7,18H4A1,1 0 0,0 3,19M12,9A3,3 0 0,1 15,12H17A5,5 0 0,0 12,7A5,5 0 0,0 7,12H9A3,3 0 0,1 12,9Z\";\r\nvar mdiWeatherHurricane = \"M15,6.79C16.86,7.86 18,9.85 18,12C18,22 6,22 6,22C7.25,21.06 8.38,19.95 9.34,18.71C9.38,18.66 9.41,18.61 9.44,18.55C9.69,18.06 9.5,17.46 9,17.21C7.14,16.14 6,14.15 6,12C6,2 18,2 18,2C16.75,2.94 15.62,4.05 14.66,5.29C14.62,5.34 14.59,5.39 14.56,5.45C14.31,5.94 14.5,6.54 15,6.79M12,14A2,2 0 0,0 14,12A2,2 0 0,0 12,10A2,2 0 0,0 10,12A2,2 0 0,0 12,14Z\";\r\nvar mdiWeatherLightning = \"M6,16A5,5 0 0,1 1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16H18A1,1 0 0,1 17,15A1,1 0 0,1 18,14H19A2,2 0 0,0 21,12A2,2 0 0,0 19,10H17V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11A3,3 0 0,0 6,14H7A1,1 0 0,1 8,15A1,1 0 0,1 7,16H6M12,11H15L13,15H15L11.25,22L12,17H9.5L12,11Z\";\r\nvar mdiWeatherLightningRainy = \"M4.5,13.59C5,13.87 5.14,14.5 4.87,14.96C4.59,15.44 4,15.6 3.5,15.33V15.33C2,14.47 1,12.85 1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A1,1 0 0,1 18,15A1,1 0 0,1 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10H17V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11C3,12.11 3.6,13.08 4.5,13.6V13.59M9.5,11H12.5L10.5,15H12.5L8.75,22L9.5,17H7L9.5,11M17.5,18.67C17.5,19.96 16.5,21 15.25,21C14,21 13,19.96 13,18.67C13,17.12 15.25,14.5 15.25,14.5C15.25,14.5 17.5,17.12 17.5,18.67Z\";\r\nvar mdiWeatherNight = \"M17.75,4.09L15.22,6.03L16.13,9.09L13.5,7.28L10.87,9.09L11.78,6.03L9.25,4.09L12.44,4L13.5,1L14.56,4L17.75,4.09M21.25,11L19.61,12.25L20.2,14.23L18.5,13.06L16.8,14.23L17.39,12.25L15.75,11L17.81,10.95L18.5,9L19.19,10.95L21.25,11M18.97,15.95C19.8,15.87 20.69,17.05 20.16,17.8C19.84,18.25 19.5,18.67 19.08,19.07C15.17,23 8.84,23 4.94,19.07C1.03,15.17 1.03,8.83 4.94,4.93C5.34,4.53 5.76,4.17 6.21,3.85C6.96,3.32 8.14,4.21 8.06,5.04C7.79,7.9 8.75,10.87 10.95,13.06C13.14,15.26 16.1,16.22 18.97,15.95M17.33,17.97C14.5,17.81 11.7,16.64 9.53,14.5C7.36,12.31 6.2,9.5 6.04,6.68C3.23,9.82 3.34,14.64 6.35,17.66C9.37,20.67 14.19,20.78 17.33,17.97Z\";\r\nvar mdiWeatherNightPartlyCloudy = \"M22,10.28C21.74,10.3 21.5,10.31 21.26,10.31C19.32,10.31 17.39,9.57 15.91,8.09C14.25,6.44 13.5,4.19 13.72,2C13.77,1.53 13.22,1 12.71,1C12.57,1 12.44,1.04 12.32,1.12C12,1.36 11.66,1.64 11.36,1.94C9.05,4.24 8.55,7.66 9.84,10.46C8.31,11.11 7.13,12.43 6.69,14.06L6,14A4,4 0 0,0 2,18A4,4 0 0,0 6,22H19A3,3 0 0,0 22,19A3,3 0 0,0 19,16C18.42,16 17.88,16.16 17.42,16.45L17.5,15.5C17.5,15.28 17.5,15.05 17.46,14.83C19.14,14.67 20.77,13.94 22.06,12.64C22.38,12.34 22.64,12 22.88,11.68C23.27,11.13 22.65,10.28 22.04,10.28M19,18A1,1 0 0,1 20,19A1,1 0 0,1 19,20H6A2,2 0 0,1 4,18A2,2 0 0,1 6,16H8.5V15.5C8.5,13.94 9.53,12.64 10.94,12.18C11.1,12.13 11.26,12.09 11.43,12.06C11.61,12.03 11.8,12 12,12C12.23,12 12.45,12.03 12.66,12.07C12.73,12.08 12.8,12.1 12.87,12.13C13,12.16 13.15,12.2 13.28,12.25C13.36,12.28 13.44,12.32 13.5,12.36C13.63,12.41 13.74,12.47 13.84,12.54C13.92,12.59 14,12.64 14.07,12.7C14.17,12.77 14.25,12.84 14.34,12.92C14.41,13 14.5,13.05 14.55,13.12C14.63,13.2 14.69,13.29 14.76,13.37C14.82,13.45 14.89,13.53 14.94,13.62C15,13.71 15.04,13.8 15.09,13.9C15.14,14 15.2,14.08 15.24,14.18C15.41,14.59 15.5,15.03 15.5,15.5V18M16.83,12.86C15.9,11.16 14.08,10 12,10H11.87C11.41,9.19 11.14,8.26 11.14,7.29C11.14,6.31 11.39,5.37 11.86,4.55C12.21,6.41 13.12,8.14 14.5,9.5C15.86,10.88 17.58,11.79 19.45,12.14C18.66,12.6 17.76,12.84 16.83,12.86Z\";\r\nvar mdiWeatherPartlyCloudy = \"M12.74,5.47C15.1,6.5 16.35,9.03 15.92,11.46C17.19,12.56 18,14.19 18,16V16.17C18.31,16.06 18.65,16 19,16A3,3 0 0,1 22,19A3,3 0 0,1 19,22H6A4,4 0 0,1 2,18A4,4 0 0,1 6,14H6.27C5,12.45 4.6,10.24 5.5,8.26C6.72,5.5 9.97,4.24 12.74,5.47M11.93,7.3C10.16,6.5 8.09,7.31 7.31,9.07C6.85,10.09 6.93,11.22 7.41,12.13C8.5,10.83 10.16,10 12,10C12.7,10 13.38,10.12 14,10.34C13.94,9.06 13.18,7.86 11.93,7.3M13.55,3.64C13,3.4 12.45,3.23 11.88,3.12L14.37,1.82L15.27,4.71C14.76,4.29 14.19,3.93 13.55,3.64M6.09,4.44C5.6,4.79 5.17,5.19 4.8,5.63L4.91,2.82L7.87,3.5C7.25,3.71 6.65,4.03 6.09,4.44M18,9.71C17.91,9.12 17.78,8.55 17.59,8L19.97,9.5L17.92,11.73C18.03,11.08 18.05,10.4 18,9.71M3.04,11.3C3.11,11.9 3.24,12.47 3.43,13L1.06,11.5L3.1,9.28C3,9.93 2.97,10.61 3.04,11.3M19,18H16V16A4,4 0 0,0 12,12A4,4 0 0,0 8,16H6A2,2 0 0,0 4,18A2,2 0 0,0 6,20H19A1,1 0 0,0 20,19A1,1 0 0,0 19,18Z\";\r\nvar mdiWeatherPartlyLightning = \"M19,15C18.65,15 18.31,15.06 18,15.17V15C18,13.19 17.19,11.56 15.92,10.46C16.35,8.03 15.1,5.5 12.75,4.47C9.97,3.24 6.72,4.5 5.5,7.25C4.6,9.24 5,11.45 6.27,13H6A4,4 0 0,0 2,17A4,4 0 0,0 6,21H7C7,21 8,21 8,20C8,19 7,19 7,19H6A2,2 0 0,1 4,17A2,2 0 0,1 6,15H8A4,4 0 0,1 12,11A4,4 0 0,1 16,15V17H19A1,1 0 0,1 20,18A1,1 0 0,1 19,19H17C17,19 16,19 16,20C16,21 17,21 17,21H19A3,3 0 0,0 22,18A3,3 0 0,0 19,15M12,9C10.16,9 8.5,9.83 7.41,11.13C6.93,10.22 6.85,9.09 7.31,8.07C8.09,6.31 10.16,5.5 11.93,6.3C13.18,6.86 13.94,8.06 14,9.34C13.38,9.12 12.7,9 12,9M13.55,2.63C13,2.4 12.45,2.23 11.88,2.12L14.37,0.82L15.27,3.71C14.76,3.29 14.19,2.93 13.55,2.63M6.09,3.44C5.6,3.79 5.17,4.19 4.8,4.63L4.91,1.82L7.87,2.5C7.25,2.71 6.65,3.03 6.09,3.44M18,8.71C17.91,8.12 17.78,7.55 17.59,7L19.97,8.5L17.92,10.73C18.03,10.08 18.05,9.4 18,8.71M3.04,10.3C3.11,10.9 3.25,11.47 3.43,12L1.06,10.5L3.1,8.28C3,8.93 2.97,9.61 3.04,10.3M11.8,15H14.25L12.61,18.27H14.25L11.18,24L11.8,19.91H9.75\";\r\nvar mdiWeatherPartlyRainy = \"M12.75,4.47C15.1,5.5 16.35,8.03 15.92,10.46C17.19,11.56 18,13.19 18,15V15.17C18.31,15.06 18.65,15 19,15A3,3 0 0,1 22,18A3,3 0 0,1 19,21H17C17,21 16,21 16,20C16,19 17,19 17,19H19A1,1 0 0,0 20,18A1,1 0 0,0 19,17H16V15A4,4 0 0,0 12,11A4,4 0 0,0 8,15H6A2,2 0 0,0 4,17A2,2 0 0,0 6,19H7C7,19 8,19 8,20C8,21 7,21 7,21H6A4,4 0 0,1 2,17A4,4 0 0,1 6,13H6.27C5,11.45 4.6,9.24 5.5,7.25C6.72,4.5 9.97,3.24 12.75,4.47M11.93,6.3C10.16,5.5 8.09,6.31 7.31,8.07C6.85,9.09 6.93,10.22 7.41,11.13C8.5,9.83 10.16,9 12,9C12.7,9 13.38,9.12 14,9.34C13.94,8.06 13.18,6.86 11.93,6.3M13.55,2.63C13,2.4 12.45,2.23 11.88,2.12L14.37,0.82L15.27,3.71C14.76,3.29 14.19,2.93 13.55,2.63M6.09,3.44C5.6,3.79 5.17,4.19 4.8,4.63L4.91,1.82L7.87,2.5C7.25,2.71 6.65,3.03 6.09,3.44M18,8.71C17.91,8.12 17.78,7.55 17.59,7L19.97,8.5L17.92,10.73C18.03,10.08 18.05,9.4 18,8.71M3.04,10.3C3.11,10.9 3.25,11.47 3.43,12L1.06,10.5L3.1,8.28C3,8.93 2.97,9.61 3.04,10.3M12,18.91C12.59,19.82 13,20.63 13,21A1,1 0 0,1 12,22A1,1 0 0,1 11,21C11,20.63 11.41,19.82 12,18.91M12,15.62C12,15.62 9,19 9,21A3,3 0 0,0 12,24A3,3 0 0,0 15,21C15,19 12,15.62 12,15.62Z\";\r\nvar mdiWeatherPartlySnowy = \"M6,19.03A2,2 0 0,1 4,17.03C4,15.92 4.9,15.03 6,15.03H8C8,12.81 9.79,11.03 12,11.03A4,4 0 0,1 16,15.03V17.03H19A1,1 0 0,1 20,18.03C20,18.57 19.55,19.03 19,19.03H17C17,19.03 16,19.03 16,20.03C16,21.03 17,21.03 17,21.03H19A3,3 0 0,0 22,18.03C22,16.37 20.66,15.03 19,15.03C18.65,15.03 18.31,15.08 18,15.19V15.03C18,13.21 17.19,11.58 15.92,10.5C16.35,8.05 15.1,5.53 12.75,4.5C9.97,3.27 6.72,4.53 5.5,7.28C4.6,9.27 5,11.47 6.27,13.03H6C3.79,13.03 2,14.81 2,17.03A4,4 0 0,0 6,21.03C6,21.03 7,21.03 7,20.03C7,19.03 6,19.03 6,19.03M12,9.03C10.16,9.03 8.5,9.85 7.41,11.16C6.93,10.25 6.85,9.11 7.31,8.09C8.09,6.33 10.16,5.53 11.93,6.32C13.18,6.89 13.94,8.08 14,9.37C13.38,9.15 12.7,9.03 12,9.03M13.55,2.66C13,2.42 12.45,2.26 11.88,2.15L14.37,0.84L15.27,3.73C14.76,3.31 14.19,2.95 13.55,2.66M6.09,3.46C5.6,3.81 5.17,4.21 4.8,4.66L4.91,1.84L7.87,2.53C7.25,2.73 6.65,3.05 6.09,3.46M18,8.73C17.91,8.15 17.78,7.57 17.59,7.03L19.97,8.53L17.92,10.76C18.03,10.1 18.05,9.42 18,8.73M3.04,10.32C3.11,10.92 3.25,11.5 3.43,12.03L1.06,10.53L3.1,8.3C3,8.95 2.97,9.64 3.04,10.32M8.03,21.45C8.13,21.84 8.53,22.06 8.91,21.96L10.5,21.54L10.06,23.11C9.96,23.5 10.19,23.9 10.57,24C10.95,24.1 11.35,23.87 11.45,23.5L11.87,21.91L13.03,23.07C13.3,23.35 13.77,23.35 14.05,23.07C14.33,22.79 14.33,22.32 14.05,22.05L12.89,20.88L14.47,20.47C14.85,20.37 15.08,19.97 15,19.59C14.88,19.21 14.5,19 14.09,19.08L12.5,19.5L12.94,17.93C13.04,17.54 12.82,17.15 12.43,17.05C12.05,16.95 11.66,17.17 11.55,17.56L11.14,19.14L10,17.97C9.7,17.69 9.23,17.69 8.95,17.97C8.68,18.27 8.68,18.72 8.95,19L10.11,20.16L8.54,20.57C8.15,20.68 7.93,21.07 8.03,21.45Z\";\r\nvar mdiWeatherPartlySnowyRainy = \"M13.55,2.66C13,2.42 12.45,2.26 11.88,2.15L14.37,0.84L15.27,3.73C14.76,3.31 14.19,2.95 13.55,2.66M6.09,3.46C5.6,3.81 5.17,4.21 4.8,4.66L4.91,1.84L7.87,2.53C7.25,2.73 6.65,3.05 6.09,3.46M18,8.73C17.91,8.15 17.78,7.57 17.59,7.03L19.97,8.53L17.92,10.76C18.03,10.1 18.05,9.42 18,8.73M3.04,10.32C3.11,10.92 3.25,11.5 3.43,12.03L1.06,10.53L3.1,8.3C3,8.95 2.97,9.64 3.04,10.32M16.68,22.21C16.68,23.2 15.91,24 14.95,24C14,24 13.23,23.2 13.23,22.21C13.23,21.03 14.95,19.03 14.95,19.03C14.95,19.03 16.68,21.03 16.68,22.21M6.03,21.45C5.93,21.07 6.15,20.68 6.54,20.58L8.13,20.15L6.96,19C6.68,18.72 6.68,18.27 6.96,18C7.23,17.7 7.7,17.7 8,18L9.14,19.14L9.55,17.56C9.65,17.17 10.05,16.94 10.43,17.05C10.82,17.15 11.05,17.55 10.93,17.93L10.5,19.5L12.1,19.1C12.5,19 12.88,19.21 13,19.6C13.08,19.97 12.86,20.37 12.47,20.47L10.89,20.89L12.05,22.05C12.33,22.32 12.33,22.79 12.05,23.07C11.77,23.35 11.31,23.35 11.03,23.07L9.87,21.9L9.45,23.5C9.35,23.88 8.95,24.1 8.57,24C8.18,23.9 7.97,23.5 8.06,23.12L8.5,21.55L6.91,21.96C6.5,22.06 6.13,21.84 6.03,21.45M19,15.03C18.65,15.03 18.31,15.08 18,15.19V15.03C18,13.21 17.19,11.58 15.92,10.5C16.35,8.05 15.1,5.53 12.75,4.5C9.97,3.27 6.72,4.53 5.5,7.28C4.6,9.27 5,11.47 6.27,13.03H6C3.79,13.03 2,14.81 2,17.03C2,18.17 2.5,19.2 3.27,19.93V19.93C3.27,19.93 3.97,20.64 4.68,19.93C5.39,19.22 4.68,18.5 4.68,18.5C4.27,18.15 4,17.62 4,17.03C4,15.92 4.9,15.03 6,15.03H8C8,12.81 9.79,11.03 12,11.03A4,4 0 0,1 16,15.03V17.03H19A1,1 0 0,1 20,18.03C20,18.57 19.55,19.03 19,19.03H18C18,19.03 17,19.03 17,20.03C17,21.03 18,21.03 18,21.03H19A3,3 0 0,0 22,18.03C22,16.37 20.66,15.03 19,15.03M12,9.03C10.16,9.03 8.5,9.85 7.41,11.16C6.93,10.25 6.85,9.11 7.31,8.09C8.09,6.33 10.16,5.53 11.93,6.32C13.18,6.89 13.94,8.08 14,9.37C13.38,9.15 12.7,9.03 12,9.03Z\";\r\nvar mdiWeatherPouring = \"M9,12C9.53,12.14 9.85,12.69 9.71,13.22L8.41,18.05C8.27,18.59 7.72,18.9 7.19,18.76C6.65,18.62 6.34,18.07 6.5,17.54L7.78,12.71C7.92,12.17 8.47,11.86 9,12M13,12C13.53,12.14 13.85,12.69 13.71,13.22L11.64,20.95C11.5,21.5 10.95,21.8 10.41,21.66C9.88,21.5 9.56,20.97 9.7,20.43L11.78,12.71C11.92,12.17 12.47,11.86 13,12M17,12C17.53,12.14 17.85,12.69 17.71,13.22L16.41,18.05C16.27,18.59 15.72,18.9 15.19,18.76C14.65,18.62 14.34,18.07 14.5,17.54L15.78,12.71C15.92,12.17 16.47,11.86 17,12M17,10V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11C3,12.11 3.6,13.08 4.5,13.6V13.59C5,13.87 5.14,14.5 4.87,14.96C4.59,15.43 4,15.6 3.5,15.32V15.33C2,14.47 1,12.85 1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12C23,13.5 22.2,14.77 21,15.46V15.46C20.5,15.73 19.91,15.57 19.63,15.09C19.36,14.61 19.5,14 20,13.72V13.73C20.6,13.39 21,12.74 21,12A2,2 0 0,0 19,10H17Z\";\r\nvar mdiWeatherRainy = \"M6,14.03A1,1 0 0,1 7,15.03C7,15.58 6.55,16.03 6,16.03C3.24,16.03 1,13.79 1,11.03C1,8.27 3.24,6.03 6,6.03C7,3.68 9.3,2.03 12,2.03C15.43,2.03 18.24,4.69 18.5,8.06L19,8.03A4,4 0 0,1 23,12.03C23,14.23 21.21,16.03 19,16.03H18C17.45,16.03 17,15.58 17,15.03C17,14.47 17.45,14.03 18,14.03H19A2,2 0 0,0 21,12.03A2,2 0 0,0 19,10.03H17V9.03C17,6.27 14.76,4.03 12,4.03C9.5,4.03 7.45,5.84 7.06,8.21C6.73,8.09 6.37,8.03 6,8.03A3,3 0 0,0 3,11.03A3,3 0 0,0 6,14.03M12,14.15C12.18,14.39 12.37,14.66 12.56,14.94C13,15.56 14,17.03 14,18C14,19.11 13.1,20 12,20A2,2 0 0,1 10,18C10,17.03 11,15.56 11.44,14.94C11.63,14.66 11.82,14.4 12,14.15M12,11.03L11.5,11.59C11.5,11.59 10.65,12.55 9.79,13.81C8.93,15.06 8,16.56 8,18A4,4 0 0,0 12,22A4,4 0 0,0 16,18C16,16.56 15.07,15.06 14.21,13.81C13.35,12.55 12.5,11.59 12.5,11.59\";\r\nvar mdiWeatherSnowy = \"M6,14A1,1 0 0,1 7,15A1,1 0 0,1 6,16A5,5 0 0,1 1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16H18A1,1 0 0,1 17,15A1,1 0 0,1 18,14H19A2,2 0 0,0 21,12A2,2 0 0,0 19,10H17V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11A3,3 0 0,0 6,14M7.88,18.07L10.07,17.5L8.46,15.88C8.07,15.5 8.07,14.86 8.46,14.46C8.85,14.07 9.5,14.07 9.88,14.46L11.5,16.07L12.07,13.88C12.21,13.34 12.76,13.03 13.29,13.17C13.83,13.31 14.14,13.86 14,14.4L13.41,16.59L15.6,16C16.14,15.86 16.69,16.17 16.83,16.71C16.97,17.24 16.66,17.79 16.12,17.93L13.93,18.5L15.54,20.12C15.93,20.5 15.93,21.15 15.54,21.54C15.15,21.93 14.5,21.93 14.12,21.54L12.5,19.93L11.93,22.12C11.79,22.66 11.24,22.97 10.71,22.83C10.17,22.69 9.86,22.14 10,21.6L10.59,19.41L8.4,20C7.86,20.14 7.31,19.83 7.17,19.29C7.03,18.76 7.34,18.21 7.88,18.07Z\";\r\nvar mdiWeatherSnowyHeavy = \"M4,16.36C3.86,15.82 4.18,15.25 4.73,15.11L7,14.5L5.33,12.86C4.93,12.46 4.93,11.81 5.33,11.4C5.73,11 6.4,11 6.79,11.4L8.45,13.05L9.04,10.8C9.18,10.24 9.75,9.92 10.29,10.07C10.85,10.21 11.17,10.78 11,11.33L10.42,13.58L12.67,13C13.22,12.83 13.79,13.15 13.93,13.71C14.08,14.25 13.76,14.82 13.2,14.96L10.95,15.55L12.6,17.21C13,17.6 13,18.27 12.6,18.67C12.2,19.07 11.54,19.07 11.15,18.67L9.5,17L8.89,19.27C8.75,19.83 8.18,20.14 7.64,20C7.08,19.86 6.77,19.29 6.91,18.74L7.5,16.5L5.26,17.09C4.71,17.23 4.14,16.92 4,16.36M1,10A5,5 0 0,1 6,5C7,2.65 9.3,1 12,1C15.43,1 18.24,3.66 18.5,7.03L19,7A4,4 0 0,1 23,11A4,4 0 0,1 19,15A1,1 0 0,1 18,14A1,1 0 0,1 19,13A2,2 0 0,0 21,11A2,2 0 0,0 19,9H17V8A5,5 0 0,0 12,3C9.5,3 7.45,4.82 7.06,7.19C6.73,7.07 6.37,7 6,7A3,3 0 0,0 3,10C3,10.85 3.35,11.61 3.91,12.16C4.27,12.55 4.26,13.16 3.88,13.54C3.5,13.93 2.85,13.93 2.47,13.54C1.56,12.63 1,11.38 1,10M14.03,20.43C14.13,20.82 14.5,21.04 14.91,20.94L16.5,20.5L16.06,22.09C15.96,22.5 16.18,22.87 16.57,22.97C16.95,23.08 17.35,22.85 17.45,22.46L17.86,20.89L19.03,22.05C19.3,22.33 19.77,22.33 20.05,22.05C20.33,21.77 20.33,21.3 20.05,21.03L18.89,19.86L20.46,19.45C20.85,19.35 21.08,18.95 20.97,18.57C20.87,18.18 20.5,17.96 20.09,18.06L18.5,18.5L18.94,16.91C19.04,16.5 18.82,16.13 18.43,16.03C18.05,15.92 17.65,16.15 17.55,16.54L17.14,18.11L15.97,16.95C15.7,16.67 15.23,16.67 14.95,16.95C14.67,17.24 14.67,17.7 14.95,17.97L16.11,19.14L14.54,19.55C14.15,19.65 13.92,20.05 14.03,20.43Z\";\r\nvar mdiWeatherSnowyRainy = \"M18.5,18.67C18.5,19.96 17.5,21 16.25,21C15,21 14,19.96 14,18.67C14,17.12 16.25,14.5 16.25,14.5C16.25,14.5 18.5,17.12 18.5,18.67M4,17.36C3.86,16.82 4.18,16.25 4.73,16.11L7,15.5L5.33,13.86C4.93,13.46 4.93,12.81 5.33,12.4C5.73,12 6.4,12 6.79,12.4L8.45,14.05L9.04,11.8C9.18,11.24 9.75,10.92 10.29,11.07C10.85,11.21 11.17,11.78 11,12.33L10.42,14.58L12.67,14C13.22,13.83 13.79,14.15 13.93,14.71C14.08,15.25 13.76,15.82 13.2,15.96L10.95,16.55L12.6,18.21C13,18.6 13,19.27 12.6,19.67C12.2,20.07 11.54,20.07 11.15,19.67L9.5,18L8.89,20.27C8.75,20.83 8.18,21.14 7.64,21C7.08,20.86 6.77,20.29 6.91,19.74L7.5,17.5L5.26,18.09C4.71,18.23 4.14,17.92 4,17.36M1,11A5,5 0 0,1 6,6C7,3.65 9.3,2 12,2C15.43,2 18.24,4.66 18.5,8.03L19,8A4,4 0 0,1 23,12A4,4 0 0,1 19,16A1,1 0 0,1 18,15A1,1 0 0,1 19,14A2,2 0 0,0 21,12A2,2 0 0,0 19,10H17V9A5,5 0 0,0 12,4C9.5,4 7.45,5.82 7.06,8.19C6.73,8.07 6.37,8 6,8A3,3 0 0,0 3,11C3,11.85 3.35,12.61 3.91,13.16C4.27,13.55 4.26,14.16 3.88,14.54C3.5,14.93 2.85,14.93 2.47,14.54C1.56,13.63 1,12.38 1,11Z\";\r\nvar mdiWeatherSunny = \"M12,7A5,5 0 0,1 17,12A5,5 0 0,1 12,17A5,5 0 0,1 7,12A5,5 0 0,1 12,7M12,9A3,3 0 0,0 9,12A3,3 0 0,0 12,15A3,3 0 0,0 15,12A3,3 0 0,0 12,9M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M3.36,17L5.12,13.23C5.26,14 5.53,14.78 5.95,15.5C6.37,16.24 6.91,16.86 7.5,17.37L3.36,17M20.65,7L18.88,10.79C18.74,10 18.47,9.23 18.05,8.5C17.63,7.78 17.1,7.15 16.5,6.64L20.65,7M20.64,17L16.5,17.36C17.09,16.85 17.62,16.22 18.04,15.5C18.46,14.77 18.73,14 18.87,13.21L20.64,17M12,22L9.59,18.56C10.33,18.83 11.14,19 12,19C12.82,19 13.63,18.83 14.37,18.56L12,22Z\";\r\nvar mdiWeatherSunnyAlert = \"M12,7A5,5 0 0,0 7,12A5,5 0 0,0 12,17A5,5 0 0,0 17,12A5,5 0 0,0 12,7M12,15A3,3 0 0,1 9,12A3,3 0 0,1 12,9A3,3 0 0,1 15,12A3,3 0 0,1 12,15M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M3.36,17L5.12,13.23C5.26,14 5.53,14.78 5.95,15.5C6.37,16.24 6.91,16.86 7.5,17.37L3.36,17M12,22L9.59,18.56C10.33,18.83 11.14,19 12,19C12.82,19 13.63,18.83 14.37,18.56M19,13V7H21V13H19M19,17V15H21V17\";\r\nvar mdiWeatherSunnyOff = \"M22.11 21.46L2.39 1.73L1.11 3L4.97 6.86L3.34 7L5.11 10.79C5.25 10 5.5 9.24 5.94 8.5C6 8.36 6.13 8.24 6.22 8.11L7.66 9.55C7.25 10.27 7 11.11 7 12C7 14.76 9.24 17 12 17C12.9 17 13.73 16.75 14.45 16.34L20.84 22.73L22.11 21.46M12 15C10.34 15 9 13.66 9 12C9 11.67 9.07 11.36 9.17 11.06L12.94 14.83C12.64 14.93 12.33 15 12 15M18.05 8.5C17.63 7.78 17.1 7.15 16.5 6.64L20.65 7L18.88 10.79C18.74 10 18.47 9.23 18.05 8.5M12 7C14.76 7 17 9.24 17 12C17 12.54 16.89 13.05 16.74 13.54L15 11.78C14.87 10.3 13.7 9.13 12.22 9L10.47 7.27C10.95 7.11 11.46 7 12 7M12 5C11.16 5 10.35 5.15 9.61 5.42L12 2L14.39 5.42C13.65 5.15 12.84 5 12 5M18.87 13.21L20.64 17L20.24 17.04L18.25 15.05C18.54 14.45 18.76 13.84 18.87 13.21M12 19C12.82 19 13.63 18.83 14.37 18.56L12 22L9.59 18.56C10.33 18.83 11.14 19 12 19M5.95 15.5C6.37 16.24 6.91 16.86 7.5 17.37L3.36 17L5.12 13.23C5.26 14 5.53 14.78 5.95 15.5Z\";\r\nvar mdiWeatherSunset = \"M3,12H7A5,5 0 0,1 12,7A5,5 0 0,1 17,12H21A1,1 0 0,1 22,13A1,1 0 0,1 21,14H3A1,1 0 0,1 2,13A1,1 0 0,1 3,12M5,16H19A1,1 0 0,1 20,17A1,1 0 0,1 19,18H5A1,1 0 0,1 4,17A1,1 0 0,1 5,16M17,20A1,1 0 0,1 18,21A1,1 0 0,1 17,22H7A1,1 0 0,1 6,21A1,1 0 0,1 7,20H17M15,12A3,3 0 0,0 12,9A3,3 0 0,0 9,12H15M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M20.65,7L18.88,10.79C18.74,10 18.47,9.23 18.05,8.5C17.63,7.78 17.1,7.15 16.5,6.64L20.65,7Z\";\r\nvar mdiWeatherSunsetDown = \"M3,12H7A5,5 0 0,1 12,7A5,5 0 0,1 17,12H21A1,1 0 0,1 22,13A1,1 0 0,1 21,14H3A1,1 0 0,1 2,13A1,1 0 0,1 3,12M15,12A3,3 0 0,0 12,9A3,3 0 0,0 9,12H15M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M20.65,7L18.88,10.79C18.74,10 18.47,9.23 18.05,8.5C17.63,7.78 17.1,7.15 16.5,6.64L20.65,7M12.71,20.71L15.82,17.6C16.21,17.21 16.21,16.57 15.82,16.18C15.43,15.79 14.8,15.79 14.41,16.18L12,18.59L9.59,16.18C9.2,15.79 8.57,15.79 8.18,16.18C7.79,16.57 7.79,17.21 8.18,17.6L11.29,20.71C11.5,20.9 11.74,21 12,21C12.26,21 12.5,20.9 12.71,20.71Z\";\r\nvar mdiWeatherSunsetUp = \"M3,12H7A5,5 0 0,1 12,7A5,5 0 0,1 17,12H21A1,1 0 0,1 22,13A1,1 0 0,1 21,14H3A1,1 0 0,1 2,13A1,1 0 0,1 3,12M15,12A3,3 0 0,0 12,9A3,3 0 0,0 9,12H15M12,2L14.39,5.42C13.65,5.15 12.84,5 12,5C11.16,5 10.35,5.15 9.61,5.42L12,2M3.34,7L7.5,6.65C6.9,7.16 6.36,7.78 5.94,8.5C5.5,9.24 5.25,10 5.11,10.79L3.34,7M20.65,7L18.88,10.79C18.74,10 18.47,9.23 18.05,8.5C17.63,7.78 17.1,7.15 16.5,6.64L20.65,7M12.71,16.3L15.82,19.41C16.21,19.8 16.21,20.43 15.82,20.82C15.43,21.21 14.8,21.21 14.41,20.82L12,18.41L9.59,20.82C9.2,21.21 8.57,21.21 8.18,20.82C7.79,20.43 7.79,19.8 8.18,19.41L11.29,16.3C11.5,16.1 11.74,16 12,16C12.26,16 12.5,16.1 12.71,16.3Z\";\r\nvar mdiWeatherTornado = \"M21,5H3A1,1 0 0,1 2,4A1,1 0 0,1 3,3H21A1,1 0 0,1 22,4A1,1 0 0,1 21,5M20,8A1,1 0 0,0 19,7H5A1,1 0 0,0 4,8A1,1 0 0,0 5,9H19A1,1 0 0,0 20,8M21,12A1,1 0 0,0 20,11H10A1,1 0 0,0 9,12A1,1 0 0,0 10,13H20A1,1 0 0,0 21,12M16,16A1,1 0 0,0 15,15H9A1,1 0 0,0 8,16A1,1 0 0,0 9,17H15A1,1 0 0,0 16,16M13,20A1,1 0 0,0 12,19H10A1,1 0 0,0 9,20A1,1 0 0,0 10,21H12A1,1 0 0,0 13,20Z\";\r\nvar mdiWeatherWindy = \"M4,10A1,1 0 0,1 3,9A1,1 0 0,1 4,8H12A2,2 0 0,0 14,6A2,2 0 0,0 12,4C11.45,4 10.95,4.22 10.59,4.59C10.2,5 9.56,5 9.17,4.59C8.78,4.2 8.78,3.56 9.17,3.17C9.9,2.45 10.9,2 12,2A4,4 0 0,1 16,6A4,4 0 0,1 12,10H4M19,12A1,1 0 0,0 20,11A1,1 0 0,0 19,10C18.72,10 18.47,10.11 18.29,10.29C17.9,10.68 17.27,10.68 16.88,10.29C16.5,9.9 16.5,9.27 16.88,8.88C17.42,8.34 18.17,8 19,8A3,3 0 0,1 22,11A3,3 0 0,1 19,14H5A1,1 0 0,1 4,13A1,1 0 0,1 5,12H19M18,18H4A1,1 0 0,1 3,17A1,1 0 0,1 4,16H18A3,3 0 0,1 21,19A3,3 0 0,1 18,22C17.17,22 16.42,21.66 15.88,21.12C15.5,20.73 15.5,20.1 15.88,19.71C16.27,19.32 16.9,19.32 17.29,19.71C17.47,19.89 17.72,20 18,20A1,1 0 0,0 19,19A1,1 0 0,0 18,18Z\";\r\nvar mdiWeatherWindyVariant = \"M6,6L6.69,6.06C7.32,3.72 9.46,2 12,2A5.5,5.5 0 0,1 17.5,7.5L17.42,8.45C17.88,8.16 18.42,8 19,8A3,3 0 0,1 22,11A3,3 0 0,1 19,14H6A4,4 0 0,1 2,10A4,4 0 0,1 6,6M6,8A2,2 0 0,0 4,10A2,2 0 0,0 6,12H19A1,1 0 0,0 20,11A1,1 0 0,0 19,10H15.5V7.5A3.5,3.5 0 0,0 12,4A3.5,3.5 0 0,0 8.5,7.5V8H6M18,18H4A1,1 0 0,1 3,17A1,1 0 0,1 4,16H18A3,3 0 0,1 21,19A3,3 0 0,1 18,22C17.17,22 16.42,21.66 15.88,21.12C15.5,20.73 15.5,20.1 15.88,19.71C16.27,19.32 16.9,19.32 17.29,19.71C17.47,19.89 17.72,20 18,20A1,1 0 0,0 19,19A1,1 0 0,0 18,18Z\";\r\nvar mdiWeb = \"M16.36,14C16.44,13.34 16.5,12.68 16.5,12C16.5,11.32 16.44,10.66 16.36,10H19.74C19.9,10.64 20,11.31 20,12C20,12.69 19.9,13.36 19.74,14M14.59,19.56C15.19,18.45 15.65,17.25 15.97,16H18.92C17.96,17.65 16.43,18.93 14.59,19.56M14.34,14H9.66C9.56,13.34 9.5,12.68 9.5,12C9.5,11.32 9.56,10.65 9.66,10H14.34C14.43,10.65 14.5,11.32 14.5,12C14.5,12.68 14.43,13.34 14.34,14M12,19.96C11.17,18.76 10.5,17.43 10.09,16H13.91C13.5,17.43 12.83,18.76 12,19.96M8,8H5.08C6.03,6.34 7.57,5.06 9.4,4.44C8.8,5.55 8.35,6.75 8,8M5.08,16H8C8.35,17.25 8.8,18.45 9.4,19.56C7.57,18.93 6.03,17.65 5.08,16M4.26,14C4.1,13.36 4,12.69 4,12C4,11.31 4.1,10.64 4.26,10H7.64C7.56,10.66 7.5,11.32 7.5,12C7.5,12.68 7.56,13.34 7.64,14M12,4.03C12.83,5.23 13.5,6.57 13.91,8H10.09C10.5,6.57 11.17,5.23 12,4.03M18.92,8H15.97C15.65,6.75 15.19,5.55 14.59,4.44C16.43,5.07 17.96,6.34 18.92,8M12,2C6.47,2 2,6.5 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z\";\r\nvar mdiWebBox = \"M8.95 13.4H6.58A5.5 5.5 0 0 1 6.58 10.6H8.95A11.56 11.56 0 0 0 8.85 12A11.56 11.56 0 0 0 8.95 13.4M7.16 9.2H9.2A12.06 12.06 0 0 1 10.18 6.71A5.55 5.55 0 0 0 7.16 9.2M16.84 9.2A5.59 5.59 0 0 0 13.81 6.71A10.95 10.95 0 0 1 14.78 9.2M12 17.57A9.5 9.5 0 0 0 13.34 14.8H10.66A9.5 9.5 0 0 0 12 17.57M12 6.42A9.53 9.53 0 0 0 10.66 9.2H13.34A9.53 9.53 0 0 0 12 6.42M7.16 14.8A5.61 5.61 0 0 0 10.18 17.29A12.06 12.06 0 0 1 9.2 14.8M21 5V19A2 2 0 0 1 19 21H5A2 2 0 0 1 3 19V5A2 2 0 0 1 5 3H19A2 2 0 0 1 21 5M19 12A7 7 0 1 0 12 19A7 7 0 0 0 19 12M15.15 12A11.56 11.56 0 0 1 15.05 13.4H17.42A5.5 5.5 0 0 0 17.42 10.6H15.05A11.56 11.56 0 0 1 15.15 12M13.81 17.29A5.62 5.62 0 0 0 16.84 14.8H14.78A10.95 10.95 0 0 1 13.81 17.29M10.36 10.6A8.81 8.81 0 0 0 10.36 13.4H13.64A10.3 10.3 0 0 0 13.75 12A10.21 10.21 0 0 0 13.64 10.6Z\";\r\nvar mdiWebClock = \"M15 12.5V16.5L18 18.5L18.75 17.25L16.5 15.75V12.5H15M22 12.39C22 12.26 22 12.13 22 12C22 6.5 17.5 2 12 2C6.47 2 2 6.5 2 12C2 17.5 6.5 22 12 22C12.13 22 12.24 22 12.37 21.97C13.43 22.62 14.67 23 16 23C19.86 23 23 19.86 23 16C23 14.68 22.62 13.44 22 12.39M19.76 10.11C19.7 10.07 19.65 10.04 19.59 10H19.74C19.75 10.03 19.75 10.07 19.76 10.11M18.92 8H15.97C15.65 6.75 15.19 5.55 14.59 4.44C16.43 5.07 17.96 6.34 18.92 8M12 4.03C12.83 5.23 13.5 6.57 13.91 8H10.09C10.5 6.57 11.17 5.23 12 4.03M9.66 10H12.41C11.16 10.75 10.15 11.88 9.57 13.24C9.53 12.83 9.5 12.42 9.5 12C9.5 11.32 9.56 10.65 9.66 10M9.4 4.44C8.8 5.55 8.35 6.75 8 8H5.08C6.03 6.34 7.57 5.06 9.4 4.44M4.26 14C4.1 13.36 4 12.69 4 12S4.1 10.64 4.26 10H7.64C7.56 10.66 7.5 11.32 7.5 12S7.56 13.34 7.64 14H4.26M5.08 16H8C8.35 17.25 8.8 18.45 9.4 19.56C7.57 18.93 6.03 17.65 5.08 16M16 21C13.24 21 11 18.76 11 16S13.24 11 16 11 21 13.24 21 16 18.76 21 16 21Z\";\r\nvar mdiWebcam = \"M12,2A7,7 0 0,1 19,9A7,7 0 0,1 12,16A7,7 0 0,1 5,9A7,7 0 0,1 12,2M12,4A5,5 0 0,0 7,9A5,5 0 0,0 12,14A5,5 0 0,0 17,9A5,5 0 0,0 12,4M12,6A3,3 0 0,1 15,9A3,3 0 0,1 12,12A3,3 0 0,1 9,9A3,3 0 0,1 12,6M6,22A2,2 0 0,1 4,20C4,19.62 4.1,19.27 4.29,18.97L6.11,15.81C7.69,17.17 9.75,18 12,18C14.25,18 16.31,17.17 17.89,15.81L19.71,18.97C19.9,19.27 20,19.62 20,20A2,2 0 0,1 18,22H6Z\";\r\nvar mdiWebhook = \"M10.46,19C9,21.07 6.15,21.59 4.09,20.15C2.04,18.71 1.56,15.84 3,13.75C3.87,12.5 5.21,11.83 6.58,11.77L6.63,13.2C5.72,13.27 4.84,13.74 4.27,14.56C3.27,16 3.58,17.94 4.95,18.91C6.33,19.87 8.26,19.5 9.26,18.07C9.57,17.62 9.75,17.13 9.82,16.63V15.62L15.4,15.58L15.47,15.47C16,14.55 17.15,14.23 18.05,14.75C18.95,15.27 19.26,16.43 18.73,17.35C18.2,18.26 17.04,18.58 16.14,18.06C15.73,17.83 15.44,17.46 15.31,17.04L11.24,17.06C11.13,17.73 10.87,18.38 10.46,19M17.74,11.86C20.27,12.17 22.07,14.44 21.76,16.93C21.45,19.43 19.15,21.2 16.62,20.89C15.13,20.71 13.9,19.86 13.19,18.68L14.43,17.96C14.92,18.73 15.75,19.28 16.75,19.41C18.5,19.62 20.05,18.43 20.26,16.76C20.47,15.09 19.23,13.56 17.5,13.35C16.96,13.29 16.44,13.36 15.97,13.53L15.12,13.97L12.54,9.2H12.32C11.26,9.16 10.44,8.29 10.47,7.25C10.5,6.21 11.4,5.4 12.45,5.44C13.5,5.5 14.33,6.35 14.3,7.39C14.28,7.83 14.11,8.23 13.84,8.54L15.74,12.05C16.36,11.85 17.04,11.78 17.74,11.86M8.25,9.14C7.25,6.79 8.31,4.1 10.62,3.12C12.94,2.14 15.62,3.25 16.62,5.6C17.21,6.97 17.09,8.47 16.42,9.67L15.18,8.95C15.6,8.14 15.67,7.15 15.27,6.22C14.59,4.62 12.78,3.85 11.23,4.5C9.67,5.16 8.97,7 9.65,8.6C9.93,9.26 10.4,9.77 10.97,10.11L11.36,10.32L8.29,15.31C8.32,15.36 8.36,15.42 8.39,15.5C8.88,16.41 8.54,17.56 7.62,18.05C6.71,18.54 5.56,18.18 5.06,17.24C4.57,16.31 4.91,15.16 5.83,14.67C6.22,14.46 6.65,14.41 7.06,14.5L9.37,10.73C8.9,10.3 8.5,9.76 8.25,9.14Z\";\r\nvar mdiWebpack = \"M20.45 17.39L12.36 21.97V18.4L17.4 15.63L20.45 17.39M21 16.89V7.31L18.04 9V15.18L21 16.89M3.55 17.39L11.64 21.96V18.4L6.6 15.63L3.55 17.39M3 16.89V7.31L5.96 9V15.18L3 16.89M3.35 6.69L11.64 2V5.45L6.33 8.37L6.28 8.39L3.35 6.69M20.65 6.69L12.36 2V5.45L17.67 8.38L17.71 8.4L20.65 6.69M11.64 17.59L6.67 14.85V9.44L11.64 12.31V17.59M12.36 17.59L17.33 14.86V9.44L12.36 12.31V17.59M7 8.81L12 6.06L17 8.81L12 11.69L7 8.81Z\";\r\nvar mdiWebrtc = \"M12 2C14.44 2 16.5 3.75 16.91 6.07L17.75 6C20.5 6 22.75 8.24 22.75 11C22.75 12.89 21.7 14.53 20.16 15.38C20.54 16.09 20.75 16.89 20.75 17.75C20.75 20.5 18.5 22.75 15.75 22.75C14.26 22.75 12.92 22.1 12 21.06C11.08 22.1 9.74 22.75 8.25 22.75C5.5 22.75 3.25 20.5 3.25 17.75C3.25 16.89 3.47 16.09 3.84 15.38C2.3 14.53 1.25 12.89 1.25 11C1.25 8.24 3.5 6 6.25 6L7.09 6.07C7.5 3.75 9.56 2 12 2M6.75 20.25L13.66 17H17C17.55 17 18 16.55 18 16V9C18 8.45 17.55 8 17 8H7C6.45 8 6 8.45 6 9V16C6 16.55 6.45 17 7 17H7.77L6.75 20.25Z\";\r\nvar mdiWechat = \"M9.5,4C5.36,4 2,6.69 2,10C2,11.89 3.08,13.56 4.78,14.66L4,17L6.5,15.5C7.39,15.81 8.37,16 9.41,16C9.15,15.37 9,14.7 9,14C9,10.69 12.13,8 16,8C16.19,8 16.38,8 16.56,8.03C15.54,5.69 12.78,4 9.5,4M6.5,6.5A1,1 0 0,1 7.5,7.5A1,1 0 0,1 6.5,8.5A1,1 0 0,1 5.5,7.5A1,1 0 0,1 6.5,6.5M11.5,6.5A1,1 0 0,1 12.5,7.5A1,1 0 0,1 11.5,8.5A1,1 0 0,1 10.5,7.5A1,1 0 0,1 11.5,6.5M16,9C12.69,9 10,11.24 10,14C10,16.76 12.69,19 16,19C16.67,19 17.31,18.92 17.91,18.75L20,20L19.38,18.13C20.95,17.22 22,15.71 22,14C22,11.24 19.31,9 16,9M14,11.5A1,1 0 0,1 15,12.5A1,1 0 0,1 14,13.5A1,1 0 0,1 13,12.5A1,1 0 0,1 14,11.5M18,11.5A1,1 0 0,1 19,12.5A1,1 0 0,1 18,13.5A1,1 0 0,1 17,12.5A1,1 0 0,1 18,11.5Z\";\r\nvar mdiWeight = \"M12,3A4,4 0 0,1 16,7C16,7.73 15.81,8.41 15.46,9H18C18.95,9 19.75,9.67 19.95,10.56C21.96,18.57 22,18.78 22,19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19C2,18.78 2.04,18.57 4.05,10.56C4.25,9.67 5.05,9 6,9H8.54C8.19,8.41 8,7.73 8,7A4,4 0 0,1 12,3M12,5A2,2 0 0,0 10,7A2,2 0 0,0 12,9A2,2 0 0,0 14,7A2,2 0 0,0 12,5Z\";\r\nvar mdiWeightGram = \"M19.95,10.56C19.75,9.67 18.95,9 18,9H15.46C15.81,8.41 16,7.73 16,7A4,4 0 0,0 12,3A4,4 0 0,0 8,7C8,7.73 8.19,8.41 8.54,9H6C5.05,9 4.25,9.67 4.05,10.56C2.04,18.57 2,18.78 2,19A2,2 0 0,0 4,21H20A2,2 0 0,0 22,19C22,18.78 21.96,18.57 19.95,10.56M12,5A2,2 0 0,1 14,7A2,2 0 0,1 12,9A2,2 0 0,1 10,7A2,2 0 0,1 12,5M15,13H11V17H13V14H15V19H11C9.89,19 9,18.11 9,17V13C9,11.89 9.89,11 11,11H15V13Z\";\r\nvar mdiWeightKilogram = \"M12,3A4,4 0 0,1 16,7C16,7.73 15.81,8.41 15.46,9H18C18.95,9 19.75,9.67 19.95,10.56C21.96,18.57 22,18.78 22,19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19C2,18.78 2.04,18.57 4.05,10.56C4.25,9.67 5.05,9 6,9H8.54C8.19,8.41 8,7.73 8,7A4,4 0 0,1 12,3M12,5A2,2 0 0,0 10,7A2,2 0 0,0 12,9A2,2 0 0,0 14,7A2,2 0 0,0 12,5M6,11V19H8V16.5L9,17.5V19H11V17L9,15L11,13V11H9V12.5L8,13.5V11H6M15,11C13.89,11 13,11.89 13,13V17C13,18.11 13.89,19 15,19H18V14H16V17H15V13H18V11H15Z\";\r\nvar mdiWeightLifter = \"M12 5C10.89 5 10 5.89 10 7S10.89 9 12 9 14 8.11 14 7 13.11 5 12 5M22 1V6H20V4H4V6H2V1H4V3H20V1H22M15 11.26V23H13V18H11V23H9V11.26C6.93 10.17 5.5 8 5.5 5.5L5.5 5H7.5L7.5 5.5C7.5 8 9.5 10 12 10S16.5 8 16.5 5.5L16.5 5H18.5L18.5 5.5C18.5 8 17.07 10.17 15 11.26Z\";\r\nvar mdiWeightPound = \"M12,3A4,4 0 0,1 16,7C16,7.73 15.81,8.41 15.46,9H18C18.95,9 19.75,9.67 19.95,10.56C21.96,18.57 22,18.78 22,19A2,2 0 0,1 20,21H4A2,2 0 0,1 2,19C2,18.78 2.04,18.57 4.05,10.56C4.25,9.67 5.05,9 6,9H8.54C8.19,8.41 8,7.73 8,7A4,4 0 0,1 12,3M12,5A2,2 0 0,0 10,7A2,2 0 0,0 12,9A2,2 0 0,0 14,7A2,2 0 0,0 12,5M6,11V19H11V17H8V11H6M13,11V19H16C17.11,19 18,18.11 18,17V16.5C18,15.93 17.75,15.38 17.32,15C17.75,14.62 18,14.07 18,13.5V13C18,11.89 17.11,11 16,11H13M15,13H16V14H15V13M15,16H16V17H15V16Z\";\r\nvar mdiWhatsapp = \"M12.04 2C6.58 2 2.13 6.45 2.13 11.91C2.13 13.66 2.59 15.36 3.45 16.86L2.05 22L7.3 20.62C8.75 21.41 10.38 21.83 12.04 21.83C17.5 21.83 21.95 17.38 21.95 11.92C21.95 9.27 20.92 6.78 19.05 4.91C17.18 3.03 14.69 2 12.04 2M12.05 3.67C14.25 3.67 16.31 4.53 17.87 6.09C19.42 7.65 20.28 9.72 20.28 11.92C20.28 16.46 16.58 20.15 12.04 20.15C10.56 20.15 9.11 19.76 7.85 19L7.55 18.83L4.43 19.65L5.26 16.61L5.06 16.29C4.24 15 3.8 13.47 3.8 11.91C3.81 7.37 7.5 3.67 12.05 3.67M8.53 7.33C8.37 7.33 8.1 7.39 7.87 7.64C7.65 7.89 7 8.5 7 9.71C7 10.93 7.89 12.1 8 12.27C8.14 12.44 9.76 14.94 12.25 16C12.84 16.27 13.3 16.42 13.66 16.53C14.25 16.72 14.79 16.69 15.22 16.63C15.7 16.56 16.68 16.03 16.89 15.45C17.1 14.87 17.1 14.38 17.04 14.27C16.97 14.17 16.81 14.11 16.56 14C16.31 13.86 15.09 13.26 14.87 13.18C14.64 13.1 14.5 13.06 14.31 13.3C14.15 13.55 13.67 14.11 13.53 14.27C13.38 14.44 13.24 14.46 13 14.34C12.74 14.21 11.94 13.95 11 13.11C10.26 12.45 9.77 11.64 9.62 11.39C9.5 11.15 9.61 11 9.73 10.89C9.84 10.78 10 10.6 10.1 10.45C10.23 10.31 10.27 10.2 10.35 10.04C10.43 9.87 10.39 9.73 10.33 9.61C10.27 9.5 9.77 8.26 9.56 7.77C9.36 7.29 9.16 7.35 9 7.34C8.86 7.34 8.7 7.33 8.53 7.33Z\";\r\nvar mdiWheelBarrow = \"M18 15.5C18.83 15.5 19.5 16.17 19.5 17S18.83 18.5 18 18.5 16.5 17.83 16.5 17 17.17 15.5 18 15.5M18 14C16.34 14 15 15.34 15 17S16.34 20 18 20C19.66 20 21 18.66 21 17S19.66 14 18 14M7 8L5 5H2V7H5.13L8 11.3V20H10L12.57 15H14.55C15.25 13.81 16.5 13 18 13C18.88 13 19.69 13.29 20.35 13.78L22 8H7M9.39 19H9V12.8L9.87 14.11C10.23 14.64 10.82 14.96 11.45 15L9.39 19Z\";\r\nvar mdiWheelchairAccessibility = \"M18.4,11.2L14.3,11.4L16.6,8.8C16.8,8.5 16.9,8 16.8,7.5C16.7,7.2 16.6,6.9 16.3,6.7L10.9,3.5C10.5,3.2 9.9,3.3 9.5,3.6L6.8,6.1C6.3,6.6 6.2,7.3 6.7,7.8C7.1,8.3 7.9,8.3 8.4,7.9L10.4,6.1L12.3,7.2L8.1,11.5C8,11.6 8,11.7 7.9,11.7C7.4,11.9 6.9,12.1 6.5,12.4L8,13.9C8.5,13.7 9,13.5 9.5,13.5C11.4,13.5 13,15.1 13,17C13,17.6 12.9,18.1 12.6,18.5L14.1,20C14.7,19.1 15,18.1 15,17C15,15.8 14.6,14.6 13.9,13.7L17.2,13.4L17,18.2C16.9,18.9 17.4,19.4 18.1,19.5H18.2C18.8,19.5 19.3,19 19.4,18.4L19.6,12.5C19.6,12.2 19.5,11.8 19.3,11.6C19,11.3 18.7,11.2 18.4,11.2M18,5.5A2,2 0 0,0 20,3.5A2,2 0 0,0 18,1.5A2,2 0 0,0 16,3.5A2,2 0 0,0 18,5.5M12.5,21.6C11.6,22.2 10.6,22.5 9.5,22.5C6.5,22.5 4,20 4,17C4,15.9 4.3,14.9 4.9,14L6.4,15.5C6.2,16 6,16.5 6,17C6,18.9 7.6,20.5 9.5,20.5C10.1,20.5 10.6,20.4 11,20.1L12.5,21.6Z\";\r\nvar mdiWhistle = \"M8.5,9A6.5,6.5 0 0,0 2,15.5A6.5,6.5 0 0,0 8.5,22A6.5,6.5 0 0,0 15,15.5V13.91L22,12V9H11V11H9V9H8.5M11,2V7H9V2H11M6.35,7.28C5.68,7.44 5.04,7.68 4.43,8L2.14,4.88L3.76,3.7L6.35,7.28M17.86,4.88L16.32,7H13.85L16.24,3.7L17.86,4.88Z\";\r\nvar mdiWhistleOutline = \"M3.76 3.7L2.14 4.88L4.43 8A8.23 8.23 0 0 1 6.35 7.28M11 9V11H18V11.29L13 12.71V15.5A4.5 4.5 0 1 1 8.5 11H9V9H8.5A6.5 6.5 0 1 0 15 15.5V13.91L22 12V9M16.24 3.7L13.85 7H16.32L17.86 4.88M9 2V7H11V2Z\";\r\nvar mdiWhiteBalanceAuto = \"M10.3,16L9.6,14H6.4L5.7,16H3.8L7,7H9L12.2,16M22,7L20.8,13.29L19.3,7H17.7L16.21,13.29L15,7H14.24C12.77,5.17 10.5,4 8,4A8,8 0 0,0 0,12A8,8 0 0,0 8,20C11.13,20 13.84,18.19 15.15,15.57L15.25,16H17L18.5,9.9L20,16H21.75L23.8,7M6.85,12.65H9.15L8,9L6.85,12.65Z\";\r\nvar mdiWhiteBalanceIncandescent = \"M17.24,18.15L19.04,19.95L20.45,18.53L18.66,16.74M20,12.5H23V10.5H20M15,6.31V1.5H9V6.31C7.21,7.35 6,9.28 6,11.5A6,6 0 0,0 12,17.5A6,6 0 0,0 18,11.5C18,9.28 16.79,7.35 15,6.31M4,10.5H1V12.5H4M11,22.45C11.32,22.45 13,22.45 13,22.45V19.5H11M3.55,18.53L4.96,19.95L6.76,18.15L5.34,16.74L3.55,18.53Z\";\r\nvar mdiWhiteBalanceIridescent = \"M4.96,19.95L6.76,18.15L5.34,16.74L3.55,18.53M3.55,4.46L5.34,6.26L6.76,4.84L4.96,3.05M20.45,18.53L18.66,16.74L17.24,18.15L19.04,19.95M13,22.45V19.5H11V22.45C11.32,22.45 13,22.45 13,22.45M19.04,3.05L17.24,4.84L18.66,6.26L20.45,4.46M11,3.5H13V0.55H11M5,14.5H19V8.5H5V14.5Z\";\r\nvar mdiWhiteBalanceSunny = \"M3.55,18.54L4.96,19.95L6.76,18.16L5.34,16.74M11,22.45C11.32,22.45 13,22.45 13,22.45V19.5H11M12,5.5A6,6 0 0,0 6,11.5A6,6 0 0,0 12,17.5A6,6 0 0,0 18,11.5C18,8.18 15.31,5.5 12,5.5M20,12.5H23V10.5H20M17.24,18.16L19.04,19.95L20.45,18.54L18.66,16.74M20.45,4.46L19.04,3.05L17.24,4.84L18.66,6.26M13,0.55H11V3.5H13M4,10.5H1V12.5H4M6.76,4.84L4.96,3.05L3.55,4.46L5.34,6.26L6.76,4.84Z\";\r\nvar mdiWidgets = \"M3,3H11V7.34L16.66,1.69L22.31,7.34L16.66,13H21V21H13V13H16.66L11,7.34V11H3V3M3,13H11V21H3V13Z\";\r\nvar mdiWidgetsOutline = \"M16.7 4.5L19.5 7.3L16.7 10.1L13.9 7.3L16.7 4.5M9 5V9H5V5H9M19 15V19H15V15H19M16.7 1.7L11 7.3L16.7 13H13V21H21V13H16.7L22.3 7.3L16.7 1.7M11 3H3V11H11V3M9 15V19H5V15H9M11 13H3V21H11V13Z\";\r\nvar mdiWifi = \"M12,21L15.6,16.2C14.6,15.45 13.35,15 12,15C10.65,15 9.4,15.45 8.4,16.2L12,21M12,3C7.95,3 4.21,4.34 1.2,6.6L3,9C5.5,7.12 8.62,6 12,6C15.38,6 18.5,7.12 21,9L22.8,6.6C19.79,4.34 16.05,3 12,3M12,9C9.3,9 6.81,9.89 4.8,11.4L6.6,13.8C8.1,12.67 9.97,12 12,12C14.03,12 15.9,12.67 17.4,13.8L19.2,11.4C17.19,9.89 14.7,9 12,9Z\";\r\nvar mdiWifiOff = \"M2.28,3L1,4.27L2.47,5.74C2.04,6 1.61,6.29 1.2,6.6L3,9C3.53,8.6 4.08,8.25 4.66,7.93L6.89,10.16C6.15,10.5 5.44,10.91 4.8,11.4L6.6,13.8C7.38,13.22 8.26,12.77 9.2,12.47L11.75,15C10.5,15.07 9.34,15.5 8.4,16.2L12,21L14.46,17.73L17.74,21L19,19.72M12,3C9.85,3 7.8,3.38 5.9,4.07L8.29,6.47C9.5,6.16 10.72,6 12,6C15.38,6 18.5,7.11 21,9L22.8,6.6C19.79,4.34 16.06,3 12,3M12,9C11.62,9 11.25,9 10.88,9.05L14.07,12.25C15.29,12.53 16.43,13.07 17.4,13.8L19.2,11.4C17.2,9.89 14.7,9 12,9Z\";\r\nvar mdiWifiStar = \"M12,6C8.6,6 5.5,7.1 3,9L1.2,6.6C4.2,4.3 8,3 12,3C16,3 19.8,4.3 22.8,6.6L21,9C18.5,7.1 15.4,6 12,6M13,19C13,17.7 13.4,16.4 14.2,15.4C13.5,15.2 12.8,15 12,15C10.7,15 9.4,15.5 8.4,16.2L12,21L13,19.6C13,19.4 13,19.2 13,19M16.8,13.4C17.1,13.3 17.5,13.2 17.9,13.1L19.2,11.4C17.2,9.9 14.7,9 12,9C9.3,9 6.8,9.9 4.8,11.4L6.6,13.8C8.1,12.7 10,12 12,12C13.8,12 15.4,12.5 16.8,13.4M16.5,22.6L17.2,19.8L15,17.9L17.9,17.7L19,15L20.1,17.6L23,17.8L20.8,19.7L21.5,22.5L19,21.1L16.5,22.6Z\";\r\nvar mdiWifiStrength1 = \"M12,3C7.79,3 3.7,4.41 0.38,7C4.41,12.06 7.89,16.37 12,21.5C16.08,16.42 20.24,11.24 23.65,7C20.32,4.41 16.22,3 12,3M12,5C15.07,5 18.09,5.86 20.71,7.45L15.61,13.81C14.5,13.28 13.25,13 12,13C10.75,13 9.5,13.28 8.39,13.8L3.27,7.44C5.91,5.85 8.93,5 12,5Z\";\r\nvar mdiWifiStrength1Alert = \"M12 3C7.8 3 3.7 4.4 .4 7C4.4 12.1 7.9 16.4 12 21.5C14.4 18.5 16.7 15.7 19 12.8V9.6L15.6 13.8C14.5 13.3 13.2 13 12 13S9.5 13.3 8.4 13.8L3.3 7.4C5.9 5.8 8.9 5 12 5S18.1 5.9 20.7 7.4L20.3 8H22.9C23.1 7.7 23.5 7.3 23.7 7C20.3 4.4 16.2 3 12 3M21 10V16H23V10M21 18V20H23V18\";\r\nvar mdiWifiStrength1Lock = \"M12,3C16.22,3 20.32,4.41 23.65,7L21.54,9.62L20.5,9.5C19.93,9.5 19.37,9.6 18.83,9.79L20.71,7.45C18.08,5.86 15.07,5 12,5C8.92,5 5.91,5.85 3.27,7.44L8.39,13.8C9.5,13.28 10.75,13 12,13C13.23,13 14.44,13.28 15.55,13.79L15.5,14.5V17.14L12,21.5L0.38,7C3.7,4.42 7.79,3 12,3M23,16C23.5,16 24,16.5 24,17V21C24,21.5 23.5,22 23,22H18C17.5,22 17,21.5 17,21V17C17,16.5 17.5,16 18,16V14.5C18,13.1 19.1,12 20.5,12C21.9,12 23,13.1 23,14.5V16M22,16V14.5C22,13.7 21.3,13 20.5,13C19.7,13 19,13.7 19,14.5V16H22Z\";\r\nvar mdiWifiStrength2 = \"M12,3C7.79,3 3.7,4.41 0.38,7C4.41,12.06 7.89,16.37 12,21.5C16.08,16.42 20.24,11.24 23.65,7C20.32,4.41 16.22,3 12,3M12,5C15.07,5 18.09,5.86 20.71,7.45L17.5,11.43C16.26,10.74 14.37,10 12,10C9.62,10 7.74,10.75 6.5,11.43L3.27,7.44C5.91,5.85 8.93,5 12,5Z\";\r\nvar mdiWifiStrength2Alert = \"M12 3C7.8 3 3.7 4.4 .4 7C4.4 12.1 7.9 16.4 12 21.5C14.4 18.5 16.7 15.7 19 12.8V9.6L17.5 11.4C16.3 10.7 14.4 10 12 10C9.6 10 7.7 10.8 6.5 11.4L3.3 7.4C5.9 5.8 8.9 5 12 5S18.1 5.9 20.7 7.4L20.3 8H22.9C23.1 7.7 23.5 7.3 23.7 7C20.3 4.4 16.2 3 12 3M21 10V16H23V10M21 18V20H23V18\";\r\nvar mdiWifiStrength2Lock = \"M12,3C7.79,3 3.7,4.42 0.38,7C4.42,12.06 7.89,16.37 12,21.5C13.23,19.97 14.29,18.66 15.5,17.14V14.5C15.5,13.24 16,12 16.84,11.1C15.62,10.53 14,10 12,10C9.62,10 7.74,10.75 6.5,11.43L3.27,7.44C5.91,5.85 8.92,5 12,5C15.07,5 18.08,5.86 20.71,7.45L18.83,9.79C19.37,9.6 19.93,9.5 20.5,9.5C20.85,9.5 21.2,9.54 21.54,9.62C22.2,8.8 23.03,7.76 23.65,7C20.32,4.41 16.22,3 12,3M20.5,12C19.1,12 18,13.1 18,14.5V16C17.5,16 17,16.5 17,17V21C17,21.5 17.5,22 18,22H23C23.5,22 24,21.5 24,21V17C24,16.5 23.5,16 23,16V14.5C23,13.1 21.9,12 20.5,12M20.5,13C21.3,13 22,13.7 22,14.5V16H19V14.5C19,13.7 19.7,13 20.5,13Z\";\r\nvar mdiWifiStrength3 = \"M12,3C7.79,3 3.7,4.41 0.38,7C4.41,12.06 7.89,16.37 12,21.5C16.08,16.42 20.24,11.24 23.65,7C20.32,4.41 16.22,3 12,3M12,5C15.07,5 18.09,5.86 20.71,7.45L18.77,9.88C17.26,9 14.88,8 12,8C9,8 6.68,9 5.21,9.84L3.27,7.44C5.91,5.85 8.93,5 12,5Z\";\r\nvar mdiWifiStrength3Alert = \"M12 3C7.8 3 3.7 4.4 .4 7C4.4 12.1 7.9 16.4 12 21.5C14.4 18.5 16.7 15.7 19 12.8V9.6L18.8 9.9C17.3 9 14.9 8 12 8C9 8 6.7 9 5.2 9.8L3.3 7.4C5.9 5.8 8.9 5 12 5S18.1 5.9 20.7 7.4L20.3 8H22.9C23.1 7.7 23.5 7.3 23.7 7C20.3 4.4 16.2 3 12 3M21 10V16H23V10M21 18V20H23V18\";\r\nvar mdiWifiStrength3Lock = \"M12,3C7.79,3 3.7,4.42 0.38,7C4.42,12.06 7.89,16.37 12,21.5C13.23,19.97 14.29,18.66 15.5,17.14V14.5C15.5,12.44 16.77,10.59 18.69,9.84C17.19,8.96 14.84,8 12,8C9,8 6.68,9 5.2,9.84L3.27,7.44C5.91,5.85 8.92,5 12,5C15.07,5 18.08,5.86 20.71,7.45L18.84,9.79C19.37,9.6 19.93,9.5 20.5,9.5C20.85,9.5 21.2,9.54 21.54,9.62C22.2,8.8 23.03,7.76 23.65,7C20.32,4.41 16.22,3 12,3M20.5,12C19.1,12 18,13.1 18,14.5V16C17.5,16 17,16.5 17,17V21C17,21.5 17.5,22 18,22H23C23.5,22 24,21.5 24,21V17C24,16.5 23.5,16 23,16V14.5C23,13.1 21.9,12 20.5,12M20.5,13C21.3,13 22,13.7 22,14.5V16H19V14.5C19,13.7 19.7,13 20.5,13Z\";\r\nvar mdiWifiStrength4 = \"M12,3C7.79,3 3.7,4.41 0.38,7C4.41,12.06 7.89,16.37 12,21.5C16.08,16.42 20.24,11.24 23.65,7C20.32,4.41 16.22,3 12,3Z\";\r\nvar mdiWifiStrength4Alert = \"M12 3C7.8 3 3.7 4.4 .4 7C4.4 12.1 7.9 16.4 12 21.5C14.4 18.5 16.7 15.7 19 12.8V8H22.8C23 7.7 23.4 7.3 23.6 7C20.3 4.4 16.2 3 12 3M21 10V16H23V10M21 18V20H23V18\";\r\nvar mdiWifiStrength4Lock = \"M12,3C7.79,3 3.7,4.42 0.38,7C4.42,12.06 7.89,16.37 12,21.5C13.23,19.97 14.29,18.66 15.5,17.14V14.5A5,5 0 0,1 20.5,9.5C20.85,9.5 21.2,9.54 21.54,9.62C22.2,8.8 23.03,7.76 23.65,7C20.32,4.41 16.22,3 12,3M20.5,12C19.1,12 18,13.1 18,14.5V16C17.5,16 17,16.5 17,17V21C17,21.5 17.5,22 18,22H23C23.5,22 24,21.5 24,21V17C24,16.5 23.5,16 23,16V14.5C23,13.1 21.9,12 20.5,12M20.5,13C21.3,13 22,13.7 22,14.5V16H19V14.5C19,13.7 19.7,13 20.5,13Z\";\r\nvar mdiWifiStrengthAlertOutline = \"M12 3C7.8 3 3.7 4.4 .4 7C4.3 11.8 8.2 16.7 12 21.5C14.3 18.6 16.7 15.7 19 12.8V9.6L12 18.3L3.3 7.4C5.9 5.8 8.9 5 12 5C15.1 5 18.1 5.9 20.7 7.4L20.3 8H22.9C23.2 7.7 23.4 7.3 23.7 7C20.3 4.4 16.2 3 12 3M21 10V16H23V10M21 18V20H23V18\";\r\nvar mdiWifiStrengthLockOutline = \"M12,3C7.79,3 3.7,4.42 0.38,7C4.61,12.3 8.16,16.7 12,21.5C13.21,20 14.29,18.65 15.5,17.14V14.5C15.5,14.3 15.5,14.09 15.54,13.89L12,18.3L3.27,7.44C5.91,5.85 8.92,5 12,5C15.07,5 18.08,5.86 20.71,7.45L18.83,9.79C19.37,9.6 19.93,9.5 20.5,9.5C20.85,9.5 21.2,9.54 21.55,9.62C22.21,8.79 23,7.77 23.65,7C20.32,4.41 16.22,3 12,3M20.5,12C19.1,12 18,13.1 18,14.5V16C17.5,16 17,16.5 17,17V21C17,21.5 17.5,22 18,22H23C23.5,22 24,21.5 24,21V17C24,16.5 23.5,16 23,16V14.5C23,13.1 21.9,12 20.5,12M20.5,13C21.3,13 22,13.7 22,14.5V16H19V14.5C19,13.7 19.7,13 20.5,13Z\";\r\nvar mdiWifiStrengthOff = \"M3.27,1.44L2,2.72L4.05,4.77C2.75,5.37 1.5,6.11 0.38,7C4.41,12.06 12,21.5 12,21.5L15.91,16.63L19.23,19.95L20.5,18.68M12,3C10.6,3 9.21,3.17 7.86,3.5L18.18,13.81C20,11.5 22.05,9 23.65,7C20.32,4.41 16.22,3 12,3Z\";\r\nvar mdiWifiStrengthOffOutline = \"M3.27,1.44L2,2.72L4.05,4.77C2.75,5.37 1.5,6.11 0.38,7C4.2,11.8 8.14,16.67 12,21.5L15.91,16.63L19.23,19.95L20.5,18.68C14.87,13.04 3.27,1.44 3.27,1.44M12,3C10.6,3 9.21,3.17 7.86,3.5L9.56,5.19C10.37,5.07 11.18,5 12,5C15.07,5 18.09,5.86 20.71,7.45L16.76,12.38L18.18,13.8C20.08,11.43 22,9 23.65,7C20.32,4.41 16.22,3 12,3M5.57,6.29L14.5,15.21L12,18.3L3.27,7.44C4,7 4.78,6.61 5.57,6.29Z\";\r\nvar mdiWifiStrengthOutline = \"M12,3C7.79,3 3.7,4.41 0.38,7H0.36C4.24,11.83 8.13,16.66 12,21.5C15.89,16.66 19.77,11.83 23.64,7H23.65C20.32,4.41 16.22,3 12,3M12,5C15.07,5 18.09,5.86 20.71,7.45L12,18.3L3.27,7.44C5.9,5.85 8.92,5 12,5Z\";\r\nvar mdiWikipedia = \"M14.97,18.95L12.41,12.92C11.39,14.91 10.27,17 9.31,18.95C9.3,18.96 8.84,18.95 8.84,18.95C7.37,15.5 5.85,12.1 4.37,8.68C4.03,7.84 2.83,6.5 2,6.5C2,6.4 2,6.18 2,6.05H7.06V6.5C6.46,6.5 5.44,6.9 5.7,7.55C6.42,9.09 8.94,15.06 9.63,16.58C10.1,15.64 11.43,13.16 12,12.11C11.55,11.23 10.13,7.93 9.71,7.11C9.39,6.57 8.58,6.5 7.96,6.5C7.96,6.35 7.97,6.25 7.96,6.06L12.42,6.07V6.47C11.81,6.5 11.24,6.71 11.5,7.29C12.1,8.53 12.45,9.42 13,10.57C13.17,10.23 14.07,8.38 14.5,7.41C14.76,6.76 14.37,6.5 13.29,6.5C13.3,6.38 13.3,6.17 13.3,6.07C14.69,6.06 16.78,6.06 17.15,6.05V6.47C16.44,6.5 15.71,6.88 15.33,7.46L13.5,11.3C13.68,11.81 15.46,15.76 15.65,16.2L19.5,7.37C19.2,6.65 18.34,6.5 18,6.5C18,6.37 18,6.2 18,6.05L22,6.08V6.1L22,6.5C21.12,6.5 20.57,7 20.25,7.75C19.45,9.54 17,15.24 15.4,18.95C15.4,18.95 14.97,18.95 14.97,18.95Z\";\r\nvar mdiWindTurbine = \"M13.33,11.67L16.21,14.58C17.62,13.16 16.21,11.75 16.21,11.75L14.72,10.24C14.9,9.86 15,9.44 15,9C15,7.95 14.46,7.03 13.64,6.5L15,2.11C13.09,1.53 12.5,3.44 12.5,3.44L11.69,6.03C10.46,6.16 9.46,7 9.13,8.18L4.67,9.63C5.31,11.53 7.2,10.9 7.2,10.9L9.27,10.23C9.61,10.97 10.23,11.54 11,11.82V19C11,19 9,19 9,21C9,21.5 9,21.81 9,22H15V21C15,21 15,19 13,19V11.82C13.12,11.78 13.23,11.72 13.33,11.67M10.5,9A1.5,1.5 0 0,1 12,7.5A1.5,1.5 0 0,1 13.5,9A1.5,1.5 0 0,1 12,10.5A1.5,1.5 0 0,1 10.5,9Z\";\r\nvar mdiWindowClose = \"M13.46,12L19,17.54V19H17.54L12,13.46L6.46,19H5V17.54L10.54,12L5,6.46V5H6.46L12,10.54L17.54,5H19V6.46L13.46,12Z\";\r\nvar mdiWindowClosed = \"M6,11H10V9H14V11H18V4H6V11M18,13H6V20H18V13M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2Z\";\r\nvar mdiWindowClosedVariant = \"M21 20V2H3V20H1V23H23V20M19 4V11H13V4M5 4H11V11H5M5 20V13H11V20M13 20V13H19V20Z\";\r\nvar mdiWindowMaximize = \"M4,4H20V20H4V4M6,8V18H18V8H6Z\";\r\nvar mdiWindowMinimize = \"M20,14H4V10H20\";\r\nvar mdiWindowOpen = \"M6,8H10V6H14V8H18V4H6V8M18,10H6V15H18V10M6,20H18V17H6V20M6,2H18A2,2 0 0,1 20,4V20A2,2 0 0,1 18,22H6A2,2 0 0,1 4,20V4A2,2 0 0,1 6,2Z\";\r\nvar mdiWindowOpenVariant = \"M21 20V2H3V20H1V23H23V20M19 4V11H17V4M5 4H7V11H5M5 20V13H7V20M9 20V4H15V20M17 20V13H19V20Z\";\r\nvar mdiWindowRestore = \"M4,8H8V4H20V16H16V20H4V8M16,8V14H18V6H10V8H16M6,12V18H14V12H6Z\";\r\nvar mdiWindowShutter = \"M3 4H21V8H19V20H17V8H7V20H5V8H3V4M8 9H16V11H8V9M8 12H16V14H8V12M8 15H16V17H8V15M8 18H16V20H8V18Z\";\r\nvar mdiWindowShutterAlert = \"M2 4H20V8H18V20H16V8H6V20H4V8H2V4M7 9H15V11H7V9M7 12H15V14H7V12M20 19V17H22V19H20M20 15V10H22V15H20Z\";\r\nvar mdiWindowShutterOpen = \"M3 4H21V8H19V20H17V8H7V20H5V8H3V4M8 9H16V11H8V9Z\";\r\nvar mdiWindsock = \"M7 5V13L22 11V7L7 5M10 6.91L13 7.31V10.69L10 11.09V6.91M16 7.71L19 8.11V9.89L16 10.29V7.71M5 10V11H6V12H5V21H3V4C3 3.45 3.45 3 4 3S5 3.45 5 4V6H6V7H5V10Z\";\r\nvar mdiWiper = \"M12,4C5,4 2,9 2,9L9,16C9,16 9.5,15.1 10.4,14.5L10.7,16.5C10.3,16.8 10,17.4 10,18A2,2 0 0,0 12,20A2,2 0 0,0 14,18C14,17.1 13.5,16.4 12.7,16.1L12.3,14C14.1,14.2 15,16 15,16L22,9C22,9 19,4 12,4M15.1,13.1C14.3,12.5 13.3,12 12,12L11,6.1C11.3,6 11.7,6 12,6C15.7,6 18.1,7.7 19.3,8.9L15.1,13.1M8.9,13.1L4.7,8.9C5.5,8 7,7 9,6.4L10,12.4C9.6,12.6 9.2,12.8 8.9,13.1Z\";\r\nvar mdiWiperWash = \"M13,6C13,5.7 13.1,4.6 13.8,3.8L12,2.4L10.2,3.9C10.9,4.6 11,5.7 11,6C4.7,6.4 2,11 2,11L9,18C9,18 9.7,16.7 11,16.2V18.3C10.4,18.6 10,19.3 10,20A2,2 0 0,0 12,22A2,2 0 0,0 14,20C14,19.3 13.6,18.6 13,18.3V16.2C14.3,16.7 15,18 15,18L22,11C22,11 19.3,6.5 13,6M11,14.1C10.2,14.3 9.5,14.6 8.9,15.1L4.7,10.9C5.8,9.8 7.8,8.3 11,8.1V14.1M15.1,15.1C14.5,14.7 13.8,14.3 13,14.1V8.1C16.2,8.4 18.2,9.8 19.3,10.9L15.1,15.1M18,1.3L17.3,3.2C16.6,2.9 15.5,2.9 14.7,3.2L14,1.3C15.2,0.9 16.8,0.9 18,1.3M21,6H19C19,6 19,4.7 18.2,3.9L19.7,2.6C21,4 21,5.9 21,6M4.2,2.6L5.7,3.9C5,4.7 5,6 5,6H3C3,5.9 3,4 4.2,2.6M10,1.3L9.3,3.2C8.6,2.9 7.5,2.9 6.7,3.2L6,1.3C7.2,0.9 8.8,0.9 10,1.3Z\";\r\nvar mdiWizardHat = \"M21 22H3V20H21V22M19 19H5L11.1 2.6C11.3 2.2 11.6 2 12 2L18 5H13.9L19 19M10 7.5L11.04 7.97L11.5 9L11.97 7.97L13 7.5L11.97 7.03L11.5 6L11.04 7.03L10 7.5M13 15L10.94 14.07L10 12L9.07 14.07L7 15L9.07 15.93L10 18L10.94 15.93L13 15M13.97 11.97L15 11.5L13.97 11.03L13.5 10L13.04 11.03L12 11.5L13.04 11.97L13.5 13L13.97 11.97M15.97 15.97L17 15.5L15.97 15.03L15.5 14L15.04 15.03L14 15.5L15.04 15.97L15.5 17L15.97 15.97Z\";\r\nvar mdiWordpress = \"M3.42,12C3.42,10.76 3.69,9.58 4.16,8.5L8.26,19.72C5.39,18.33 3.42,15.4 3.42,12M17.79,11.57C17.79,12.3 17.5,13.15 17.14,14.34L16.28,17.2L13.18,8L14.16,7.9C14.63,7.84 14.57,7.16 14.11,7.19C14.11,7.19 12.72,7.3 11.82,7.3L9.56,7.19C9.1,7.16 9.05,7.87 9.5,7.9L10.41,8L11.75,11.64L9.87,17.27L6.74,8L7.73,7.9C8.19,7.84 8.13,7.16 7.67,7.19C7.67,7.19 6.28,7.3 5.38,7.3L4.83,7.29C6.37,4.96 9,3.42 12,3.42C14.23,3.42 16.27,4.28 17.79,5.67H17.68C16.84,5.67 16.24,6.4 16.24,7.19C16.24,7.9 16.65,8.5 17.08,9.2C17.41,9.77 17.79,10.5 17.79,11.57M12.15,12.75L14.79,19.97L14.85,20.09C13.96,20.41 13,20.58 12,20.58C11.16,20.58 10.35,20.46 9.58,20.23L12.15,12.75M19.53,7.88C20.2,9.11 20.58,10.5 20.58,12C20.58,15.16 18.86,17.93 16.31,19.41L18.93,11.84C19.42,10.62 19.59,9.64 19.59,8.77L19.53,7.88M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,21.54C17.26,21.54 21.54,17.26 21.54,12C21.54,6.74 17.26,2.46 12,2.46C6.74,2.46 2.46,6.74 2.46,12C2.46,17.26 6.74,21.54 12,21.54Z\";\r\nvar mdiWrap = \"M21,5H3V7H21V5M3,19H10V17H3V19M3,13H18C19,13 20,13.43 20,15C20,16.57 19,17 18,17H16V15L12,18L16,21V19H18C20.95,19 22,17.73 22,15C22,12.28 21,11 18,11H3V13Z\";\r\nvar mdiWrapDisabled = \"M16,7H3V5H16V7M3,19H16V17H3V19M22,12L18,9V11H3V13H18V15L22,12Z\";\r\nvar mdiWrench = \"M22.7,19L13.6,9.9C14.5,7.6 14,4.9 12.1,3C10.1,1 7.1,0.6 4.7,1.7L9,6L6,9L1.6,4.7C0.4,7.1 0.9,10.1 2.9,12.1C4.8,14 7.5,14.5 9.8,13.6L18.9,22.7C19.3,23.1 19.9,23.1 20.3,22.7L22.6,20.4C23.1,20 23.1,19.3 22.7,19Z\";\r\nvar mdiWrenchOutline = \"M22.61,19L13.53,9.91C14.46,7.57 14,4.81 12.09,2.91C9.79,0.61 6.21,0.4 3.66,2.26L7.5,6.11L6.08,7.5L2.25,3.69C0.39,6.23 0.6,9.82 2.9,12.11C4.76,13.97 7.47,14.46 9.79,13.59L18.9,22.7C19.29,23.09 19.92,23.09 20.31,22.7L22.61,20.4C23,20 23,19.39 22.61,19M19.61,20.59L10.15,11.13C9.54,11.58 8.86,11.85 8.15,11.95C6.79,12.15 5.36,11.74 4.32,10.7C3.37,9.76 2.93,8.5 3,7.26L6.09,10.35L10.33,6.11L7.24,3C8.5,2.95 9.73,3.39 10.68,4.33C11.76,5.41 12.17,6.9 11.92,8.29C11.8,9 11.5,9.66 11.04,10.25L20.5,19.7L19.61,20.59Z\";\r\nvar mdiXamarin = \"M22.75,11.07C22.91,11.35 23,11.67 23,12C23,12.33 22.91,12.65 22.75,12.93L18.08,21C17.72,21.62 17.06,22 16.35,22H7.65C6.94,22 6.28,21.62 5.92,21L1.25,12.93C1.09,12.65 1,12.33 1,12C1,11.67 1.09,11.35 1.25,11.07L5.92,3C6.28,2.38 6.94,2 7.65,2H16.35C17.06,2 17.72,2.38 18.08,3L22.75,11.07M12,12V11.9L9.42,7.1L9.25,7H7.66L7.5,7.1V7.3L10,12L7.5,16.7V16.9L7.66,17H9.25L9.42,16.9L12,12.1V12L12.03,12.1L14.58,16.9L14.75,17H16.34L16.5,16.9V16.7L14,12L16.5,7.3V7.1L16.34,7H14.75L14.58,7.1L12.03,11.9L12,12Z\";\r\nvar mdiXamarinOutline = \"M12,12L12.03,11.9L14.58,7.1L14.75,7H16.34L16.5,7.1V7.3L14,12L16.5,16.7V16.9L16.34,17H14.75L14.58,16.9L12.03,12.1L12,12V12.1L9.42,16.9L9.25,17H7.66L7.5,16.9V16.7L10,12L7.5,7.3V7.1L7.66,7H9.25L9.42,7.1L12,11.9V12M22.75,11.07C22.91,11.35 23,11.67 23,12C23,12.33 22.91,12.65 22.75,12.93L18.08,21C17.72,21.62 17.06,22 16.35,22H7.65C6.94,22 6.28,21.62 5.92,21L1.25,12.93C1.09,12.65 1,12.33 1,12C1,11.67 1.09,11.35 1.25,11.07L5.92,3C6.28,2.38 6.94,2 7.65,2H16.35C17.06,2 17.72,2.38 18.08,3L22.75,11.07M20.8,11.25L16.97,4.8C16.68,4.3 16.14,4 15.56,4H8.44C7.86,4 7.32,4.3 7.03,4.8L3.2,11.25C3.07,11.5 3,11.74 3,12C3,12.26 3.07,12.5 3.2,12.75L7.03,19.2C7.32,19.7 7.86,20 8.44,20H15.56C16.14,20 16.68,19.7 16.97,19.2L20.8,12.75C20.93,12.5 21,12.26 21,12C21,11.74 20.93,11.5 20.8,11.25Z\";\r\nvar mdiXing = \"M4.8,3C3.8,3 3,3.8 3,4.8V19.2C3,20.2 3.8,21 4.8,21H19.2C20.2,21 21,20.2 21,19.2V4.8C21,3.8 20.2,3 19.2,3M16.07,5H18.11C18.23,5 18.33,5.04 18.37,5.13C18.43,5.22 18.43,5.33 18.37,5.44L13.9,13.36L16.75,18.56C16.81,18.67 16.81,18.78 16.75,18.87C16.7,18.95 16.61,19 16.5,19H14.47C14.16,19 14,18.79 13.91,18.61L11.04,13.35C11.18,13.1 15.53,5.39 15.53,5.39C15.64,5.19 15.77,5 16.07,5M7.09,7.76H9.1C9.41,7.76 9.57,7.96 9.67,8.15L11.06,10.57C10.97,10.71 8.88,14.42 8.88,14.42C8.77,14.61 8.63,14.81 8.32,14.81H6.3C6.18,14.81 6.09,14.76 6.04,14.67C6,14.59 6,14.47 6.04,14.36L8.18,10.57L6.82,8.2C6.77,8.09 6.75,8 6.81,7.89C6.86,7.81 6.96,7.76 7.09,7.76Z\";\r\nvar mdiXml = \"M12.89,3L14.85,3.4L11.11,21L9.15,20.6L12.89,3M19.59,12L16,8.41V5.58L22.42,12L16,18.41V15.58L19.59,12M1.58,12L8,5.58V8.41L4.41,12L8,15.58V18.41L1.58,12Z\";\r\nvar mdiXmpp = \"M12,15.4C9.75,13.09 8,9.54 8,6C2,4 8,6 2,4C2,9.65 6.33,14.11 10.55,16.66C9.38,17.5 8.15,18 7,18C7,19 7,18 7,19C8.2,19 10.03,18.46 12,17.46C13.97,18.46 15.8,19 17,19C17,18 17,19 17,18C15.85,18 14.62,17.5 13.45,16.66C17.66,14.11 22,9.65 22,4C16,6 22,4 16,6C16,9.54 14.25,13.09 12,15.4Z\";\r\nvar mdiYCombinator = \"M2,2H22V22H2V2M11.25,17.5H12.75V13.06L16,7H14.5L12,11.66L9.5,7H8L11.25,13.06V17.5Z\";\r\nvar mdiYahoo = \"M10.5 7.59L8.16 13.2L5.85 7.59H2L6.29 17.23L4.75 20.7H8.5L14.24 7.59H10.5M15 12.73C13.63 12.73 12.59 13.77 12.59 15C12.59 16.17 13.59 17.16 14.93 17.16C16.32 17.16 17.36 16.13 17.36 14.9C17.36 13.69 16.36 12.73 15 12.73M17.72 3.3L13.89 11.89H18.17L22 3.3H17.72Z\";\r\nvar mdiYeast = \"M18,14A4,4 0 0,1 22,18A4,4 0 0,1 18,22A4,4 0 0,1 14,18L14.09,17.15C14.05,16.45 13.92,15.84 13.55,15.5C13.35,15.3 13.07,15.19 12.75,15.13C11.79,15.68 10.68,16 9.5,16A6.5,6.5 0 0,1 3,9.5A6.5,6.5 0 0,1 9.5,3A6.5,6.5 0 0,1 16,9.5C16,10.68 15.68,11.79 15.13,12.75C15.19,13.07 15.3,13.35 15.5,13.55C15.84,13.92 16.45,14.05 17.15,14.09L18,14M7.5,10A1.5,1.5 0 0,1 9,11.5A1.5,1.5 0 0,1 7.5,13A1.5,1.5 0 0,1 6,11.5A1.5,1.5 0 0,1 7.5,10M9.5,5C7,5 5,7 5,9.5C5,12 7,14 9.5,14C12,14 14,12 14,9.5C14,7 12,5 9.5,5Z\";\r\nvar mdiYinYang = \"M12,2A10,10 0 0,1 22,12A10,10 0 0,1 12,22A10,10 0 0,1 2,12A10,10 0 0,1 12,2M12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20A4,4 0 0,1 8,16A4,4 0 0,1 12,12A4,4 0 0,0 16,8A4,4 0 0,0 12,4M12,6.5A1.5,1.5 0 0,1 13.5,8A1.5,1.5 0 0,1 12,9.5A1.5,1.5 0 0,1 10.5,8A1.5,1.5 0 0,1 12,6.5M12,14.5A1.5,1.5 0 0,0 10.5,16A1.5,1.5 0 0,0 12,17.5A1.5,1.5 0 0,0 13.5,16A1.5,1.5 0 0,0 12,14.5Z\";\r\nvar mdiYoga = \"M13 2C11.9 2 11 2.9 11 4C11 5.11 11.9 6 13 6C14.11 6 15 5.11 15 4C15 2.9 14.11 2 13 2M4 7V9H10V15L4.93 20.07L6.34 21.5L13.06 14.77L17 17.13V21H19V16.57C19 16.21 18.82 15.89 18.5 15.71L15 13.6V9H21V7H4Z\";\r\nvar mdiYoutube = \"M10,15L15.19,12L10,9V15M21.56,7.17C21.69,7.64 21.78,8.27 21.84,9.07C21.91,9.87 21.94,10.56 21.94,11.16L22,12C22,14.19 21.84,15.8 21.56,16.83C21.31,17.73 20.73,18.31 19.83,18.56C19.36,18.69 18.5,18.78 17.18,18.84C15.88,18.91 14.69,18.94 13.59,18.94L12,19C7.81,19 5.2,18.84 4.17,18.56C3.27,18.31 2.69,17.73 2.44,16.83C2.31,16.36 2.22,15.73 2.16,14.93C2.09,14.13 2.06,13.44 2.06,12.84L2,12C2,9.81 2.16,8.2 2.44,7.17C2.69,6.27 3.27,5.69 4.17,5.44C4.64,5.31 5.5,5.22 6.82,5.16C8.12,5.09 9.31,5.06 10.41,5.06L12,5C16.19,5 18.8,5.16 19.83,5.44C20.73,5.69 21.31,6.27 21.56,7.17Z\";\r\nvar mdiYoutubeGaming = \"M22 13V8L17 5L12 8L7 5L2 8V13L12 19L22 13M9 11H7V13H6V11H4V10H6V8H7V10H9V11M15 13C14.45 13 14 12.55 14 12S14.45 11 15 11 16 11.45 16 12 15.55 13 15 13M18 11C17.45 11 17 10.55 17 10S17.45 9 18 9 19 9.45 19 10 18.55 11 18 11Z\";\r\nvar mdiYoutubeStudio = \"M10,15L15,12L10,9V15M19.45,13L21.56,14.63C21.78,14.78 21.81,15 21.66,15.28L19.64,18.75C19.5,18.97 19.31,19.03 19.03,18.94L16.55,17.95C15.89,18.42 15.33,18.75 14.86,18.94L14.5,21.56C14.42,21.84 14.27,22 14,22H10C9.73,22 9.58,21.84 9.5,21.56L9.14,18.94C8.55,18.69 8,18.36 7.45,17.95L4.97,18.94C4.69,19.03 4.5,18.97 4.36,18.75L2.34,15.28C2.19,15 2.22,14.78 2.44,14.63L4.55,13C4.5,12.77 4.5,12.44 4.5,12C4.5,11.56 4.5,11.23 4.55,11L2.44,9.38C2.22,9.22 2.19,9 2.34,8.72L4.36,5.25C4.5,5.03 4.69,4.97 4.97,5.06L7.45,6.05C8.11,5.58 8.67,5.25 9.14,5.06L9.5,2.44C9.58,2.16 9.73,2 10,2H14C14.27,2 14.42,2.16 14.5,2.44L14.86,5.06C15.45,5.31 16,5.64 16.55,6.05L19.03,5.06C19.31,4.97 19.5,5.03 19.64,5.25L21.66,8.72C21.81,9 21.78,9.22 21.56,9.38L19.45,11C19.5,11.23 19.5,11.56 19.5,12C19.5,12.44 19.5,12.77 19.45,13Z\";\r\nvar mdiYoutubeSubscription = \"M20,8H4V6H20V8M18,2H6V4H18V2M22,12V20A2,2 0 0,1 20,22H4A2,2 0 0,1 2,20V12A2,2 0 0,1 4,10H20A2,2 0 0,1 22,12M16,16L10,12.73V19.26L16,16Z\";\r\nvar mdiYoutubeTv = \"M2.5,4.5H21.5C22.34,4.5 23,5.15 23,6V17.5C23,18.35 22.34,19 21.5,19H2.5C1.65,19 1,18.35 1,17.5V6C1,5.15 1.65,4.5 2.5,4.5M9.71,8.5V15L15.42,11.7L9.71,8.5M17.25,21H6.65C6.35,21 6.15,20.8 6.15,20.5C6.15,20.2 6.35,20 6.65,20H17.35C17.65,20 17.85,20.2 17.85,20.5C17.85,20.8 17.55,21 17.25,21Z\";\r\nvar mdiYurt = \"M22 14.87V22H14V16H10V22H2V14.87C2 14.33 2.29 13.83 2.76 13.57L8.66 10.2C8.88 10.07 9.14 10 9.4 10H12.5V9H14V10H14.59C14.85 10 15.11 10.07 15.33 10.2L21.23 13.57C21.71 13.84 22 14.33 22 14.87M7.86 6.25H9.4C10.73 6.25 11.92 6.95 12.5 8H14C13.6 6.2 12 4.85 10.1 4.85V3.35C11.1 3.35 11.95 2.5 11.95 1.5V1H7.86V2.5C6.86 2.5 6 3.23 6 4.25S6.86 6.25 7.86 6.25Z\";\r\nvar mdiZWave = \"M16.3,10.58C13.14,10.58 10.6,13.13 10.6,16.28C10.6,19.43 13.15,22 16.3,22C19.45,22 22,19.43 22,16.28C22,13.13 19.45,10.58 16.3,10.58M18,19.08H13.19L15.81,15H13.31L14.4,13.23H19.18L16.63,17.28H19.18L18,19.08M16.3,3.93V2C8.41,2 2,8.42 2,16.31H3.92C3.94,9.46 9.5,3.93 16.3,3.93M16.3,7.74V5.82C10.5,5.82 5.81,10.53 5.81,16.31H7.73C7.75,11.58 11.59,7.74 16.3,7.74\";\r\nvar mdiZend = \"M11.28,9.81C11.28,9.81 11.28,7 14.09,7H22.5C22.5,7 22.5,9.81 19.71,9.81H11.28M11.28,13.41C11.28,13.41 11.28,10.6 14.09,10.6H18.31C18.31,10.6 18.31,13.41 15.5,13.41H11.28M11.28,17C11.28,17 11.28,14.19 14.09,14.19H15.5C15.5,14.19 15.5,17 12.68,17H11.28M10.46,14.8V17H1.58L7.3,9.21H2.4V7H11.66L5.96,14.8H10.46Z\";\r\nvar mdiZigbee = \"M4.06,6.15C3.97,6.17 3.88,6.22 3.8,6.28C2.66,7.9 2,9.87 2,12A10,10 0 0,0 12,22C15,22 17.68,20.68 19.5,18.6L17,18.85C14.25,19.15 11.45,19.19 8.66,18.96C7.95,18.94 7.24,18.76 6.59,18.45C5.73,18.06 5.15,17.23 5.07,16.29C5.06,16.13 5.12,16 5.23,15.87L7.42,13.6L15.03,5.7V5.6H10.84C8.57,5.64 6.31,5.82 4.06,6.15M20.17,17.5C20.26,17.47 20.35,17.44 20.43,17.39C21.42,15.83 22,14 22,12A10,10 0 0,0 12,2C9.22,2 6.7,3.13 4.89,4.97H5.17C8.28,4.57 11.43,4.47 14.56,4.65C15.5,4.64 16.45,4.82 17.33,5.17C18.25,5.53 18.89,6.38 19,7.37C19,7.53 18.93,7.7 18.82,7.82L9.71,17.19L9,17.95V18.06H13.14C15.5,18 17.84,17.81 20.17,17.5Z\";\r\nvar mdiZipBox = \"M14,17H12V15H10V13H12V15H14M14,9H12V11H14V13H12V11H10V9H12V7H10V5H12V7H14M19,3H5C3.89,3 3,3.89 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5C21,3.89 20.1,3 19,3Z\";\r\nvar mdiZipBoxOutline = \"M12 17V15H14V17H12M14 13V11H12V13H14M14 9V7H12V9H14M10 11H12V9H10V11M10 15H12V13H10V15M21 5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H19C20.1 3 21 3.9 21 5M19 5H12V7H10V5H5V19H19V5Z\";\r\nvar mdiZipDisk = \"M7,3L3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5L17,3V5A1,1 0 0,1 16,6H10A1,1 0 0,1 9,5V3H7M8,10H16A1,1 0 0,1 17,11V19H7V11A1,1 0 0,1 8,10Z\";\r\nvar mdiZodiacAquarius = \"M15,12.41L12,9.41L9,12.41L6,9.41L3.71,11.71L2.29,10.29L6,6.59L9,9.59L12,6.59L15,9.59L18,6.59L21.71,10.29L20.29,11.71L18,9.41L15,12.41M18,15.41L20.29,17.71L21.71,16.29L18,12.59L15,15.59L12,12.59L9,15.59L6,12.59L2.29,16.29L3.71,17.71L6,15.41L9,18.41L12,15.41L15,18.41L18,15.41Z\";\r\nvar mdiZodiacAries = \"M16,2C14.95,2 13.91,2.27 13,2.81C12.64,3 12.3,3.26 12,3.54C11.7,3.26 11.36,3 11,2.81C10.09,2.27 9.05,2 8,2A6,6 0 0,0 2,8A6,6 0 0,0 8,14V12A4,4 0 0,1 4,8A4,4 0 0,1 8,4C9,4 10,4.39 10.75,5.1C10.84,5.18 10.92,5.27 11,5.36V22H13V5.36C13.08,5.27 13.16,5.18 13.25,5.1C14.85,3.58 17.38,3.64 18.91,5.25C20.43,6.85 20.36,9.38 18.76,10.9C18,11.61 17.03,12 16,12V14A6,6 0 0,0 22,8A6,6 0 0,0 16,2Z\";\r\nvar mdiZodiacCancer = \"M12,4C6.5,4 2,7.58 2,12C2,14.12 3.65,15.87 5.76,16H6A4,4 0 0,0 10,12A4,4 0 0,0 6,8H5.76C7.44,6.41 9.69,5.55 12,5.6C13.77,5.58 15.5,6.07 17,7L18.25,5.75C16.38,4.58 14.21,3.97 12,4M6,10A2,2 0 0,1 8,12C8,13.11 7.08,14 6,14C4.96,14 4.1,13.22 4,12.2C4,12.07 4,11.93 4,11.8C4.1,10.77 4.97,10 6,10M18.24,8H18A4,4 0 0,0 14,12A4,4 0 0,0 18,16H18.24C16.56,17.59 14.31,18.45 12,18.4C10.23,18.42 8.5,17.93 7,17L5.76,18.24C7.63,19.41 9.79,20 12,20C17.5,20 22,16.42 22,12C22,9.88 20.35,8.13 18.24,8M18,14A2,2 0 0,1 16,12C16,10.89 16.92,10 18,10C19.04,10 19.9,10.78 20,11.8C20,11.93 20,12.07 20,12.2C19.9,13.23 19.03,14 18,14Z\";\r\nvar mdiZodiacCapricorn = \"M15,13C14.3,13 13.61,13.19 13,13.55V6A3,3 0 0,0 10,3C9.25,3 8.55,3.29 8,3.78C7.45,3.28 6.74,3 6,3V5A1,1 0 0,1 7,6V16H9V6A1,1 0 0,1 10,5A1,1 0 0,1 11,6V17A2,2 0 0,1 9,19V21C10.15,21 11.25,20.5 12,19.62C13.45,21.29 15.97,21.47 17.64,20C19.31,18.58 19.5,16.05 18.04,14.38C17.28,13.5 16.17,13 15,13M15,19A2,2 0 0,1 13,17A2,2 0 0,1 15,15A2,2 0 0,1 17,17A2,2 0 0,1 15,19Z\";\r\nvar mdiZodiacGemini = \"M18,5.3C19.35,4.97 20.66,4.54 21.94,4L21.18,2.14C18.27,3.36 15.15,4 12,4C8.85,4 5.73,3.38 2.82,2.17L2.06,4C3.34,4.54 4.65,4.97 6,5.3V18.7C4.65,19.03 3.34,19.46 2.06,20L2.82,21.86C8.7,19.42 15.3,19.42 21.18,21.86L21.94,20C20.66,19.46 19.35,19.03 18,18.7V5.3M8,18.3V5.69C9.32,5.89 10.66,6 12,6C13.34,6 14.68,5.89 16,5.69V18.31C13.35,17.9 10.65,17.9 8,18.31V18.3Z\";\r\nvar mdiZodiacLeo = \"M20,17A3,3 0 0,1 17,20C15.38,19.92 14.08,18.62 14,17C14.16,15.39 14.5,13.8 15,12.26C15.54,10.55 15.87,8.79 16,7C15.93,4.27 13.73,2.07 11,2C8.27,2.07 6.07,4.27 6,7C6.15,8.53 6.5,10.03 7,11.5L7.21,12.2C5.1,11.53 2.86,12.7 2.19,14.8C1.5,16.91 2.68,19.16 4.79,19.83C6.9,20.5 9.14,19.33 9.81,17.22C9.94,16.83 10,16.41 10,16C9.84,14.27 9.5,12.56 8.91,10.92C8.47,9.65 8.16,8.34 8,7C8.08,5.38 9.38,4.08 11,4C12.62,4.08 13.92,5.38 14,7C13.84,8.61 13.5,10.2 13,11.74C12.46,13.45 12.13,15.21 12,17C12.07,19.73 14.27,21.93 17,22A5,5 0 0,0 22,17H20M6,18A2,2 0 0,1 4,16A2,2 0 0,1 6,14A2,2 0 0,1 8,16A2,2 0 0,1 6,18Z\";\r\nvar mdiZodiacLibra = \"M20,16V18H13V15.91C16,15.36 17.96,12.5 17.41,9.5C16.86,6.5 14,4.54 11,5.09C8,5.65 6.04,8.5 6.59,11.5C7,13.74 8.76,15.5 11,15.91V18H4V16H6.92C5.37,14.59 4.5,12.59 4.5,10.5A7.5,7.5 0 0,1 12,3A7.5,7.5 0 0,1 19.5,10.5C19.5,12.59 18.63,14.59 17.08,16H20M20,19H4V21H20V19Z\";\r\nvar mdiZodiacPisces = \"M20,11H18C18.11,8.19 18.73,5.42 19.81,2.82L18,2.06C16.81,4.9 16.13,7.92 16,11H8C7.87,7.92 7.19,4.9 6,2.06L4.14,2.82C5.24,5.41 5.87,8.18 6,11H4V13H6C5.89,15.81 5.27,18.58 4.19,21.18L6,21.94C7.19,19.1 7.87,16.08 8,13H16C16.13,16.08 16.81,19.1 18,21.94L19.86,21.18C18.76,18.59 18.13,15.82 18,13H20V11Z\";\r\nvar mdiZodiacSagittarius = \"M22,2V12H20V5.41L10.41,15L12.71,17.29L11.29,18.71L9,16.41L3.71,21.71L2.29,20.29L7.59,15L5.29,12.71L6.71,11.29L9,13.59L18.59,4H12V2H22Z\";\r\nvar mdiZodiacScorpio = \"M17.71,15.29L16.29,16.71L17.59,18H16A2,2 0 0,1 14,16V6A3,3 0 0,0 11,3C10.25,3 9.55,3.29 9,3.78C7.86,2.76 6.14,2.76 5,3.78C4.45,3.28 3.74,3 3,3V5A1,1 0 0,1 4,6V16H6V6A1,1 0 0,1 7,5A1,1 0 0,1 8,6V16H10V6A1,1 0 0,1 11,5A1,1 0 0,1 12,6V16A4,4 0 0,0 16,20H17.59L16.29,21.29L17.71,22.71L21.41,19L17.71,15.29Z\";\r\nvar mdiZodiacTaurus = \"M15.59,9C17.7,7.74 19,5.46 19,3H17A5,5 0 0,1 12,8A5,5 0 0,1 7,3H5C5,5.46 6.3,7.74 8.41,9C5.09,11 4,15.28 6,18.6C7.97,21.92 12.27,23 15.59,21C18.91,19.04 20,14.74 18,11.42C17.42,10.43 16.58,9.59 15.59,9M12,20A5,5 0 0,1 7,15A5,5 0 0,1 12,10A5,5 0 0,1 17,15A5,5 0 0,1 12,20Z\";\r\nvar mdiZodiacVirgo = \"M18.5,19.13C20,17.77 20,15.18 20,14A4,4 0 0,0 16,10C15.3,10 14.6,10.2 14,10.56V6A3,3 0 0,0 11,3C10.25,3 9.55,3.29 9,3.78C7.86,2.76 6.14,2.76 5,3.78C4.45,3.28 3.74,3 3,3V5A1,1 0 0,1 4,6V16H6V6A1,1 0 0,1 7,5A1,1 0 0,1 8,6V16H10V6A1,1 0 0,1 11,5A1,1 0 0,1 12,6V14C12,15.18 12,17.77 13.5,19.13C12.72,19.54 11.88,19.84 11,20V22C12.29,22 14.84,20.74 16,20.13C17.16,20.74 19.71,22 21,22V20C20.12,19.84 19.28,19.54 18.5,19.13M16,12A2,2 0 0,1 18,14C18,16.92 17.46,18 16,18C14.54,18 14,16.92 14,14A2,2 0 0,1 16,12Z\";\r\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@mdi/js/mdi.js\n");

/***/ }),

/***/ "./node_modules/@formatjs/intl-pluralrules/should-polyfill.js":
/*!********************************************************************!*\
  !*** ./node_modules/@formatjs/intl-pluralrules/should-polyfill.js ***!
  \********************************************************************/
/*! flagged exports */
/*! export __esModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export shouldPolyfill [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__ */
/***/ ((__unused_webpack_module, exports) => {

"use strict";
eval("\n\nObject.defineProperty(exports, \"__esModule\", ({\n  value: true\n}));\nexports.shouldPolyfill = void 0;\n\nfunction shouldPolyfill() {\n  return typeof Intl === 'undefined' || !('PluralRules' in Intl) || new Intl.PluralRules('en', {\n    minimumFractionDigits: 2\n  }).select(1) === 'one';\n}\n\nexports.shouldPolyfill = shouldPolyfill;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQGZvcm1hdGpzL2ludGwtcGx1cmFscnVsZXMvc2hvdWxkLXBvbHlmaWxsLmpzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9ub2RlX21vZHVsZXMvQGZvcm1hdGpzL2ludGwtcGx1cmFscnVsZXMvc2hvdWxkLXBvbHlmaWxsLmpzP2E5OGIiXSwic291cmNlc0NvbnRlbnQiOlsiXCJ1c2Ugc3RyaWN0XCI7XG5PYmplY3QuZGVmaW5lUHJvcGVydHkoZXhwb3J0cywgXCJfX2VzTW9kdWxlXCIsIHsgdmFsdWU6IHRydWUgfSk7XG5leHBvcnRzLnNob3VsZFBvbHlmaWxsID0gdm9pZCAwO1xuZnVuY3Rpb24gc2hvdWxkUG9seWZpbGwoKSB7XG4gICAgcmV0dXJuICh0eXBlb2YgSW50bCA9PT0gJ3VuZGVmaW5lZCcgfHxcbiAgICAgICAgISgnUGx1cmFsUnVsZXMnIGluIEludGwpIHx8XG4gICAgICAgIG5ldyBJbnRsLlBsdXJhbFJ1bGVzKCdlbicsIHsgbWluaW11bUZyYWN0aW9uRGlnaXRzOiAyIH0pLnNlbGVjdCgxKSA9PT1cbiAgICAgICAgICAgICdvbmUnKTtcbn1cbmV4cG9ydHMuc2hvdWxkUG9seWZpbGwgPSBzaG91bGRQb2x5ZmlsbDtcbiJdLCJtYXBwaW5ncyI6IkFBQUE7QUFDQTtBQUFBO0FBQUE7QUFBQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBRUE7QUFBQTtBQUVBO0FBQ0E7QUFBQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/@formatjs/intl-pluralrules/should-polyfill.js\n");

/***/ }),

/***/ "./node_modules/@material/base/foundation.js":
/*!***************************************************!*\
  !*** ./node_modules/@material/base/foundation.js ***!
  \***************************************************/
/*! namespace exports */
/*! export MDCFoundation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"MDCFoundation\": () => /* binding */ MDCFoundation,\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/**\n * @license\n * Copyright 2016 Google Inc.\n *\n * Permission is hereby granted, free of charge, to any person obtaining a copy\n * of this software and associated documentation files (the \"Software\"), to deal\n * in the Software without restriction, including without limitation the rights\n * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n * copies of the Software, and to permit persons to whom the Software is\n * furnished to do so, subject to the following conditions:\n *\n * The above copyright notice and this permission notice shall be included in\n * all copies or substantial portions of the Software.\n *\n * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n * THE SOFTWARE.\n */\nvar MDCFoundation =\n/** @class */\nfunction () {\n  function MDCFoundation(adapter) {\n    if (adapter === void 0) {\n      adapter = {};\n    }\n\n    this.adapter = adapter;\n  }\n\n  Object.defineProperty(MDCFoundation, \"cssClasses\", {\n    get: function () {\n      // Classes extending MDCFoundation should implement this method to return an object which exports every\n      // CSS class the foundation class needs as a property. e.g. {ACTIVE: 'mdc-component--active'}\n      return {};\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCFoundation, \"strings\", {\n    get: function () {\n      // Classes extending MDCFoundation should implement this method to return an object which exports all\n      // semantic strings as constants. e.g. {ARIA_ROLE: 'tablist'}\n      return {};\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCFoundation, \"numbers\", {\n    get: function () {\n      // Classes extending MDCFoundation should implement this method to return an object which exports all\n      // of its semantic numbers as constants. e.g. {ANIMATION_DELAY_MS: 350}\n      return {};\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCFoundation, \"defaultAdapter\", {\n    get: function () {\n      // Classes extending MDCFoundation may choose to implement this getter in order to provide a convenient\n      // way of viewing the necessary methods of an adapter. In the future, this could also be used for adapter\n      // validation.\n      return {};\n    },\n    enumerable: true,\n    configurable: true\n  });\n\n  MDCFoundation.prototype.init = function () {// Subclasses should override this method to perform initialization routines (registering events, etc.)\n  };\n\n  MDCFoundation.prototype.destroy = function () {// Subclasses should override this method to perform de-initialization routines (de-registering events, etc.)\n  };\n\n  return MDCFoundation;\n}();\n\n // tslint:disable-next-line:no-default-export Needed for backward compatibility with MDC Web v0.44.0 and earlier.\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MDCFoundation);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/base/foundation.js\n");

/***/ }),

/***/ "./node_modules/@material/dom/ponyfill.js":
/*!************************************************!*\
  !*** ./node_modules/@material/dom/ponyfill.js ***!
  \************************************************/
/*! namespace exports */
/*! export closest [provided] [no usage info] [missing usage info prevents renaming] */
/*! export estimateScrollWidth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export matches [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"closest\": () => /* binding */ closest,\n/* harmony export */   \"matches\": () => /* binding */ matches,\n/* harmony export */   \"estimateScrollWidth\": () => /* binding */ estimateScrollWidth\n/* harmony export */ });\n/**\n * @license\n * Copyright 2018 Google Inc.\n *\n * Permission is hereby granted, free of charge, to any person obtaining a copy\n * of this software and associated documentation files (the \"Software\"), to deal\n * in the Software without restriction, including without limitation the rights\n * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n * copies of the Software, and to permit persons to whom the Software is\n * furnished to do so, subject to the following conditions:\n *\n * The above copyright notice and this permission notice shall be included in\n * all copies or substantial portions of the Software.\n *\n * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n * THE SOFTWARE.\n */\n\n/**\n * @fileoverview A \"ponyfill\" is a polyfill that doesn't modify the global prototype chain.\n * This makes ponyfills safer than traditional polyfills, especially for libraries like MDC.\n */\nfunction closest(element, selector) {\n  if (element.closest) {\n    return element.closest(selector);\n  }\n\n  var el = element;\n\n  while (el) {\n    if (matches(el, selector)) {\n      return el;\n    }\n\n    el = el.parentElement;\n  }\n\n  return null;\n}\nfunction matches(element, selector) {\n  var nativeMatches = element.matches || element.webkitMatchesSelector || element.msMatchesSelector;\n  return nativeMatches.call(element, selector);\n}\n/**\n * Used to compute the estimated scroll width of elements. When an element is\n * hidden due to display: none; being applied to a parent element, the width is\n * returned as 0. However, the element will have a true width once no longer\n * inside a display: none context. This method computes an estimated width when\n * the element is hidden or returns the true width when the element is visble.\n * @param {Element} element the element whose width to estimate\n */\n\nfunction estimateScrollWidth(element) {\n  // Check the offsetParent. If the element inherits display: none from any\n  // parent, the offsetParent property will be null (see\n  // https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/offsetParent).\n  // This check ensures we only clone the node when necessary.\n  var htmlEl = element;\n\n  if (htmlEl.offsetParent !== null) {\n    return htmlEl.scrollWidth;\n  }\n\n  var clone = htmlEl.cloneNode(true);\n  clone.style.setProperty('position', 'absolute');\n  clone.style.setProperty('transform', 'translate(-9999px, -9999px)');\n  document.documentElement.appendChild(clone);\n  var scrollWidth = clone.scrollWidth;\n  document.documentElement.removeChild(clone);\n  return scrollWidth;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/dom/ponyfill.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-base/base-element.js":
/*!*********************************************************!*\
  !*** ./node_modules/@material/mwc-base/base-element.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export BaseElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export addHasRemoveClass [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@material/mwc-base/utils.js .addHasRemoveClass */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"addHasRemoveClass\": () => /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_1__.addHasRemoveClass,\n/* harmony export */   \"BaseElement\": () => /* binding */ BaseElement\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./utils */ \"./node_modules/@material/mwc-base/utils.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n/** @soyCompatible */\n\nclass BaseElement extends lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement {\n  click() {\n    if (this.mdcRoot) {\n      this.mdcRoot.focus();\n      this.mdcRoot.click();\n      return;\n    }\n\n    super.click();\n  }\n  /**\n   * Create and attach the MDC Foundation to the instance\n   */\n\n\n  createFoundation() {\n    if (this.mdcFoundation !== undefined) {\n      this.mdcFoundation.destroy();\n    }\n\n    if (this.mdcFoundationClass) {\n      this.mdcFoundation = new this.mdcFoundationClass(this.createAdapter());\n      this.mdcFoundation.init();\n    }\n  }\n\n  firstUpdated() {\n    this.createFoundation();\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-base/base-element.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-base/utils.js":
/*!**************************************************!*\
  !*** ./node_modules/@material/mwc-base/utils.js ***!
  \**************************************************/
/*! namespace exports */
/*! export addHasRemoveClass [provided] [no usage info] [missing usage info prevents renaming] */
/*! export deepActiveElementPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export doesElementContainFocus [provided] [no usage info] [missing usage info prevents renaming] */
/*! export findAssignedElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isNodeElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export supportsPassiveEventListener [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"isNodeElement\": () => /* binding */ isNodeElement,\n/* harmony export */   \"findAssignedElement\": () => /* binding */ findAssignedElement,\n/* harmony export */   \"addHasRemoveClass\": () => /* binding */ addHasRemoveClass,\n/* harmony export */   \"supportsPassiveEventListener\": () => /* binding */ supportsPassiveEventListener,\n/* harmony export */   \"deepActiveElementPath\": () => /* binding */ deepActiveElementPath,\n/* harmony export */   \"doesElementContainFocus\": () => /* binding */ doesElementContainFocus\n/* harmony export */ });\n/* harmony import */ var _material_dom_ponyfill__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/dom/ponyfill */ \"./node_modules/@material/dom/ponyfill.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n/**\n * Return an element assigned to a given slot that matches the given selector\n */\n\n/**\n * Determines whether a node is an element.\n *\n * @param node Node to check\n */\n\nconst isNodeElement = node => {\n  return node.nodeType === Node.ELEMENT_NODE;\n};\nfunction findAssignedElement(slot, selector) {\n  for (const node of slot.assignedNodes({\n    flatten: true\n  })) {\n    if (isNodeElement(node)) {\n      const el = node;\n\n      if ((0,_material_dom_ponyfill__WEBPACK_IMPORTED_MODULE_0__.matches)(el, selector)) {\n        return el;\n      }\n    }\n  }\n\n  return null;\n}\nfunction addHasRemoveClass(element) {\n  return {\n    addClass: className => {\n      element.classList.add(className);\n    },\n    removeClass: className => {\n      element.classList.remove(className);\n    },\n    hasClass: className => element.classList.contains(className)\n  };\n}\nlet supportsPassive = false;\n\nconst fn = () => {};\n\nconst optionsBlock = {\n  get passive() {\n    supportsPassive = true;\n    return false;\n  }\n\n};\ndocument.addEventListener('x', fn, optionsBlock);\ndocument.removeEventListener('x', fn);\n/**\n * Do event listeners suport the `passive` option?\n */\n\nconst supportsPassiveEventListener = supportsPassive;\nconst deepActiveElementPath = (doc = window.document) => {\n  let activeElement = doc.activeElement;\n  const path = [];\n\n  if (!activeElement) {\n    return path;\n  }\n\n  while (activeElement) {\n    path.push(activeElement);\n\n    if (activeElement.shadowRoot) {\n      activeElement = activeElement.shadowRoot.activeElement;\n    } else {\n      break;\n    }\n  }\n\n  return path;\n};\nconst doesElementContainFocus = element => {\n  const activePath = deepActiveElementPath();\n\n  if (!activePath.length) {\n    return false;\n  }\n\n  const deepActiveElement = activePath[activePath.length - 1];\n  const focusEv = new Event('check-if-focused', {\n    bubbles: true,\n    composed: true\n  });\n  let composedPath = [];\n\n  const listener = ev => {\n    composedPath = ev.composedPath();\n  };\n\n  document.body.addEventListener('check-if-focused', listener);\n  deepActiveElement.dispatchEvent(focusEv);\n  document.body.removeEventListener('check-if-focused', listener);\n  return composedPath.indexOf(element) !== -1;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-base/utils.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-button/mwc-button-base.js":
/*!**************************************************************!*\
  !*** ./node_modules/@material/mwc-button/mwc-button-base.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export ButtonBase [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"ButtonBase\": () => /* binding */ ButtonBase\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var _material_mwc_icon_mwc_icon__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-icon/mwc-icon */ \"./node_modules/@material/mwc-icon/mwc-icon.js\");\n/* harmony import */ var _material_mwc_ripple_mwc_ripple__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @material/mwc-ripple/mwc-ripple */ \"./node_modules/@material/mwc-ripple/mwc-ripple.js\");\n/* harmony import */ var _material_mwc_ripple_ripple_handlers__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @material/mwc-ripple/ripple-handlers */ \"./node_modules/@material/mwc-ripple/ripple-handlers.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! lit-html/directives/class-map */ \"./node_modules/lit-html/directives/class-map.js\");\n\n/**\n@license\nCopyright 2019 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n\n\n/** @soyCompatible */\n\nclass ButtonBase extends lit_element__WEBPACK_IMPORTED_MODULE_2__.LitElement {\n  constructor() {\n    super(...arguments);\n    this.raised = false;\n    this.unelevated = false;\n    this.outlined = false;\n    this.dense = false;\n    this.disabled = false;\n    this.trailingIcon = false;\n    this.fullwidth = false;\n    this.icon = '';\n    this.label = '';\n    this.expandContent = false;\n    this.shouldRenderRipple = false;\n    this.rippleHandlers = new _material_mwc_ripple_ripple_handlers__WEBPACK_IMPORTED_MODULE_4__.RippleHandlers(() => {\n      this.shouldRenderRipple = true;\n      return this.ripple;\n    });\n  }\n  /** @soyTemplate */\n\n\n  renderRipple() {\n    const filled = this.raised || this.unelevated;\n    return this.shouldRenderRipple ? lit_element__WEBPACK_IMPORTED_MODULE_2__.html`<mwc-ripple .primary=\"${!filled}\" .disabled=\"${this.disabled}\"></mwc-ripple>` : '';\n  }\n\n  createRenderRoot() {\n    return this.attachShadow({\n      mode: 'open',\n      delegatesFocus: true\n    });\n  }\n\n  focus() {\n    const buttonElement = this.buttonElement;\n\n    if (buttonElement) {\n      this.rippleHandlers.startFocus();\n      buttonElement.focus();\n    }\n  }\n\n  blur() {\n    const buttonElement = this.buttonElement;\n\n    if (buttonElement) {\n      this.rippleHandlers.endFocus();\n      buttonElement.blur();\n    }\n  }\n  /** @soyTemplate */\n\n\n  getRenderClasses() {\n    return (0,lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_3__.classMap)({\n      'mdc-button--raised': this.raised,\n      'mdc-button--unelevated': this.unelevated,\n      'mdc-button--outlined': this.outlined,\n      'mdc-button--dense': this.dense\n    });\n  }\n  /** @soyTemplate */\n\n\n  render() {\n    return lit_element__WEBPACK_IMPORTED_MODULE_2__.html`\n      <button\n          id=\"button\"\n          class=\"mdc-button ${this.getRenderClasses()}\"\n          ?disabled=\"${this.disabled}\"\n          aria-label=\"${this.label || this.icon}\"\n          @focus=\"${this.handleRippleFocus}\"\n          @blur=\"${this.handleRippleBlur}\"\n          @mousedown=\"${this.handleRippleActivate}\"\n          @mouseenter=\"${this.handleRippleMouseEnter}\"\n          @mouseleave=\"${this.handleRippleMouseLeave}\"\n          @touchstart=\"${this.handleRippleActivate}\"\n          @touchend=\"${this.handleRippleDeactivate}\"\n          @touchcancel=\"${this.handleRippleDeactivate}\">\n        ${this.renderRipple()}\n        <span class=\"leading-icon\">\n          <slot name=\"icon\">\n            ${this.icon && !this.trailingIcon ? this.renderIcon() : ''}\n          </slot>\n        </span>\n        <span class=\"mdc-button__label\">${this.label}</span>\n        <span class=\"slot-container ${(0,lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_3__.classMap)({\n      flex: this.expandContent\n    })}\">\n          <slot></slot>\n        </span>\n        <span class=\"trailing-icon\">\n          <slot name=\"trailingIcon\">\n            ${this.icon && this.trailingIcon ? this.renderIcon() : ''}\n          </slot>\n        </span>\n      </button>`;\n  }\n  /** @soyTemplate */\n\n\n  renderIcon() {\n    return lit_element__WEBPACK_IMPORTED_MODULE_2__.html`\n    <mwc-icon class=\"mdc-button__icon\">\n      ${this.icon}\n    </mwc-icon>`;\n  }\n\n  handleRippleActivate(evt) {\n    const onUp = () => {\n      window.removeEventListener('mouseup', onUp);\n      this.handleRippleDeactivate();\n    };\n\n    window.addEventListener('mouseup', onUp);\n    this.rippleHandlers.startPress(evt);\n  }\n\n  handleRippleDeactivate() {\n    this.rippleHandlers.endPress();\n  }\n\n  handleRippleMouseEnter() {\n    this.rippleHandlers.startHover();\n  }\n\n  handleRippleMouseLeave() {\n    this.rippleHandlers.endHover();\n  }\n\n  handleRippleFocus() {\n    this.rippleHandlers.startFocus();\n  }\n\n  handleRippleBlur() {\n    this.rippleHandlers.endFocus();\n  }\n\n}\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean\n})], ButtonBase.prototype, \"raised\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean\n})], ButtonBase.prototype, \"unelevated\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean\n})], ButtonBase.prototype, \"outlined\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean\n})], ButtonBase.prototype, \"dense\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean,\n  reflect: true\n})], ButtonBase.prototype, \"disabled\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean,\n  attribute: 'trailingicon'\n})], ButtonBase.prototype, \"trailingIcon\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean,\n  reflect: true\n})], ButtonBase.prototype, \"fullwidth\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: String\n})], ButtonBase.prototype, \"icon\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: String\n})], ButtonBase.prototype, \"label\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n  type: Boolean\n})], ButtonBase.prototype, \"expandContent\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.query)('#button')], ButtonBase.prototype, \"buttonElement\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.queryAsync)('mwc-ripple')], ButtonBase.prototype, \"ripple\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.internalProperty)()], ButtonBase.prototype, \"shouldRenderRipple\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.eventOptions)({\n  passive: true\n})], ButtonBase.prototype, \"handleRippleActivate\", null);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-button/mwc-button-base.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-button/mwc-button.js":
/*!*********************************************************!*\
  !*** ./node_modules/@material/mwc-button/mwc-button.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export Button [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Button\": () => /* binding */ Button\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mwc_button_base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mwc-button-base */ \"./node_modules/@material/mwc-button/mwc-button-base.js\");\n/* harmony import */ var _styles_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./styles-css */ \"./node_modules/@material/mwc-button/styles-css.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n/** @soyCompatible */\n\nlet Button = class Button extends _mwc_button_base__WEBPACK_IMPORTED_MODULE_1__.ButtonBase {};\nButton.styles = _styles_css__WEBPACK_IMPORTED_MODULE_2__.style;\nButton = (0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)('mwc-button')], Button);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1idXR0b24vbXdjLWJ1dHRvbi5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kL213Yy1idXR0b24udHM/YTMwNyJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5pbXBvcnQge2N1c3RvbUVsZW1lbnR9IGZyb20gJ2xpdC1lbGVtZW50JztcblxuaW1wb3J0IHtCdXR0b25CYXNlfSBmcm9tICcuL213Yy1idXR0b24tYmFzZSc7XG5pbXBvcnQge3N0eWxlfSBmcm9tICcuL3N0eWxlcy1jc3MnO1xuXG4vKiogQHNveUNvbXBhdGlibGUgKi9cbkBjdXN0b21FbGVtZW50KCdtd2MtYnV0dG9uJylcbmV4cG9ydCBjbGFzcyBCdXR0b24gZXh0ZW5kcyBCdXR0b25CYXNlIHtcbiAgc3RhdGljIHN0eWxlcyA9IHN0eWxlO1xufVxuXG5kZWNsYXJlIGdsb2JhbCB7XG4gIGludGVyZmFjZSBIVE1MRWxlbWVudFRhZ05hbWVNYXAge1xuICAgICdtd2MtYnV0dG9uJzogQnV0dG9uO1xuICB9XG59XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7OztBQUFBOzs7Ozs7Ozs7Ozs7Ozs7OztBQWdCQTtBQUVBO0FBQ0E7QUFFQTtBQUNBO0FBQ0E7QUFDQTtBQURBOyIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-button/mwc-button.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-button/styles-css.js":
/*!*********************************************************!*\
  !*** ./node_modules/@material/mwc-button/styles-css.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export style [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"style\": () => /* binding */ style\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\nconst style = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`.mdc-touch-target-wrapper{display:inline}.mdc-elevation-overlay{position:absolute;border-radius:inherit;pointer-events:none;opacity:0;opacity:var(--mdc-elevation-overlay-opacity, 0);transition:opacity 280ms cubic-bezier(0.4, 0, 0.2, 1);background-color:#fff;background-color:var(--mdc-elevation-overlay-color, #fff)}.mdc-button{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto, sans-serif;font-family:var(--mdc-typography-button-font-family, var(--mdc-typography-font-family, Roboto, sans-serif));font-size:0.875rem;font-size:var(--mdc-typography-button-font-size, 0.875rem);line-height:2.25rem;line-height:var(--mdc-typography-button-line-height, 2.25rem);font-weight:500;font-weight:var(--mdc-typography-button-font-weight, 500);letter-spacing:0.0892857143em;letter-spacing:var(--mdc-typography-button-letter-spacing, 0.0892857143em);text-decoration:none;text-decoration:var(--mdc-typography-button-text-decoration, none);text-transform:uppercase;text-transform:var(--mdc-typography-button-text-transform, uppercase);padding:0 8px 0 8px;position:relative;display:inline-flex;align-items:center;justify-content:center;box-sizing:border-box;min-width:64px;border:none;outline:none;line-height:inherit;user-select:none;-webkit-appearance:none;overflow:visible;vertical-align:middle;border-radius:4px;border-radius:var(--mdc-shape-small, 4px);height:36px}.mdc-button .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}.mdc-button::-moz-focus-inner{padding:0;border:0}.mdc-button:active{outline:none}.mdc-button:hover{cursor:pointer}.mdc-button:disabled{cursor:default;pointer-events:none}.mdc-button .mdc-button__ripple{border-radius:4px;border-radius:var(--mdc-shape-small, 4px)}.mdc-button:not(:disabled){background-color:transparent}.mdc-button:disabled{background-color:transparent}.mdc-button .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .mdc-button .mdc-button__icon,.mdc-button .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.mdc-button .mdc-button__touch{position:absolute;top:50%;right:0;height:48px;left:0;transform:translateY(-50%)}.mdc-button:not(:disabled){color:#6200ee;color:var(--mdc-theme-primary, #6200ee)}.mdc-button:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .mdc-button__label+.mdc-button__icon,.mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}svg.mdc-button__icon{fill:currentColor}.mdc-button--raised .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon,.mdc-button--outlined .mdc-button__icon{margin-left:-4px;margin-right:8px}[dir=rtl] .mdc-button--raised .mdc-button__icon,.mdc-button--raised .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__icon,.mdc-button--unelevated .mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__icon,.mdc-button--outlined .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:-4px}.mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:-4px}[dir=rtl] .mdc-button--raised .mdc-button__label+.mdc-button__icon,.mdc-button--raised .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--unelevated .mdc-button__label+.mdc-button__icon,.mdc-button--unelevated .mdc-button__label+.mdc-button__icon[dir=rtl],[dir=rtl] .mdc-button--outlined .mdc-button__label+.mdc-button__icon,.mdc-button--outlined .mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:-4px;margin-right:8px}.mdc-button--raised,.mdc-button--unelevated{padding:0 16px 0 16px}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){background-color:#6200ee;background-color:var(--mdc-theme-primary, #6200ee)}.mdc-button--raised:not(:disabled),.mdc-button--unelevated:not(:disabled){color:#fff;color:var(--mdc-theme-on-primary, #fff)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{background-color:rgba(0, 0, 0, 0.12)}.mdc-button--raised:disabled,.mdc-button--unelevated:disabled{color:rgba(0, 0, 0, 0.38)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2),0px 2px 2px 0px rgba(0, 0, 0, 0.14),0px 1px 5px 0px rgba(0,0,0,.12);transition:box-shadow 280ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-button--raised:hover,.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),0px 4px 5px 0px rgba(0, 0, 0, 0.14),0px 1px 10px 0px rgba(0,0,0,.12)}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),0px 8px 10px 1px rgba(0, 0, 0, 0.14),0px 3px 14px 2px rgba(0,0,0,.12)}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2),0px 0px 0px 0px rgba(0, 0, 0, 0.14),0px 0px 0px 0px rgba(0,0,0,.12)}.mdc-button--outlined{padding:0 15px 0 15px;border-width:1px;border-style:solid}.mdc-button--outlined .mdc-button__ripple{top:-1px;left:-1px;border:1px solid transparent}.mdc-button--outlined .mdc-button__touch{left:-1px;width:calc(100% + 2 * 1px)}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12)}.mdc-button--outlined:disabled{border-color:rgba(0, 0, 0, 0.12)}.mdc-button--touch{margin-top:6px;margin-bottom:6px}:host{display:inline-flex;outline:none;vertical-align:top}:host([fullwidth]){width:100%}:host([raised]),:host([unelevated]){--mdc-ripple-color: #fff;--mdc-ripple-focus-opacity: 0.24;--mdc-ripple-hover-opacity: 0.08;--mdc-ripple-press-opacity: 0.24}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon,.leading-icon ::slotted(*),.leading-icon .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;width:18px;height:18px;font-size:18px;vertical-align:top}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl],[dir=rtl] .leading-icon ::slotted(*),.leading-icon ::slotted(*)[dir=rtl],[dir=rtl] .leading-icon .mdc-button__icon,.leading-icon .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.trailing-icon ::slotted(*),.trailing-icon .mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .trailing-icon ::slotted(*),.trailing-icon ::slotted(*)[dir=rtl],[dir=rtl] .trailing-icon .mdc-button__icon,.trailing-icon .mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}.slot-container{display:inline-flex;align-items:center;justify-content:center}.slot-container.flex{flex:auto}.mdc-button{flex:auto;overflow:hidden;padding-left:8px;padding-left:var(--mdc-button-horizontal-padding, 8px);padding-right:8px;padding-right:var(--mdc-button-horizontal-padding, 8px)}.mdc-button--raised{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow, 0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:hover,.mdc-button--raised:focus{box-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-hover, 0px 2px 4px -1px rgba(0, 0, 0, 0.2), 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised:active{box-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-active, 0px 5px 5px -3px rgba(0, 0, 0, 0.2), 0px 8px 10px 1px rgba(0, 0, 0, 0.14), 0px 3px 14px 2px rgba(0, 0, 0, 0.12))}.mdc-button--raised:disabled{box-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12);box-shadow:var(--mdc-button-raised-box-shadow-disabled, 0px 0px 0px 0px rgba(0, 0, 0, 0.2), 0px 0px 0px 0px rgba(0, 0, 0, 0.14), 0px 0px 0px 0px rgba(0, 0, 0, 0.12))}.mdc-button--raised,.mdc-button--unelevated{padding-left:16px;padding-left:var(--mdc-button-horizontal-padding, 16px);padding-right:16px;padding-right:var(--mdc-button-horizontal-padding, 16px)}.mdc-button--outlined{border-width:1px;border-width:var(--mdc-button-outline-width, 1px);padding-left:calc(16px - 1px);padding-left:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px));padding-right:calc(16px - 1px);padding-right:calc(var(--mdc-button-horizontal-padding, 16px) - var(--mdc-button-outline-width, 1px))}.mdc-button--outlined:not(:disabled){border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-outline-color, rgba(0, 0, 0, 0.12))}.mdc-button--outlined mwc-ripple{top:calc(-1 * 1px);top:calc(-1 * var(--mdc-button-outline-width, 1px));left:calc(-1 * 1px);left:calc(-1 * var(--mdc-button-outline-width, 1px));right:initial;border-width:1px;border-width:var(--mdc-button-outline-width, 1px);border-style:solid;border-color:transparent}[dir=rtl] .mdc-button--outlined mwc-ripple,.mdc-button--outlined mwc-ripple[dir=rtl]{left:initial;right:calc(-1 * 1px);right:calc(-1 * var(--mdc-button-outline-width, 1px))}.mdc-button--dense{height:28px;margin-top:0;margin-bottom:0}.mdc-button--dense .mdc-button__touch{display:none}:host([disabled]){pointer-events:none}:host([disabled]) .mdc-button{color:rgba(0, 0, 0, 0.38);color:var(--mdc-button-disabled-ink-color, rgba(0, 0, 0, 0.38))}:host([disabled]) .mdc-button--raised,:host([disabled]) .mdc-button--unelevated{background-color:rgba(0, 0, 0, 0.12);background-color:var(--mdc-button-disabled-fill-color, rgba(0, 0, 0, 0.12))}:host([disabled]) .mdc-button--outlined{border-color:rgba(0, 0, 0, 0.12);border-color:var(--mdc-button-disabled-outline-color, rgba(0, 0, 0, 0.12))}`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-button/styles-css.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-circular-progress/mwc-circular-progress-base.js":
/*!************************************************************************************!*\
  !*** ./node_modules/@material/mwc-circular-progress/mwc-circular-progress-base.js ***!
  \************************************************************************************/
/*! namespace exports */
/*! export CircularProgressBase [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"CircularProgressBase\": () => /* binding */ CircularProgressBase\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-html/directives/class-map */ \"./node_modules/lit-html/directives/class-map.js\");\n/* harmony import */ var lit_html_directives_if_defined__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! lit-html/directives/if-defined */ \"./node_modules/lit-html/directives/if-defined.js\");\n/* harmony import */ var lit_html_directives_style_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! lit-html/directives/style-map */ \"./node_modules/lit-html/directives/style-map.js\");\n\n/**\n@license\nCopyright 2020 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n\n/** @soyCompatible */\n\nclass CircularProgressBase extends lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement {\n  constructor() {\n    super(...arguments);\n    this.indeterminate = false;\n    this.progress = 0;\n    this.density = 0;\n    this.closed = false;\n    this.ariaLabel = '';\n  }\n\n  open() {\n    this.closed = false;\n  }\n\n  close() {\n    this.closed = true;\n  }\n  /**\n   * @soyTemplate\n   */\n\n\n  render() {\n    /** @classMap */\n    const classes = {\n      'mdc-circular-progress--closed': this.closed,\n      'mdc-circular-progress--indeterminate': this.indeterminate\n    };\n    const containerSideLength = 48 + this.density * 4;\n    const styles = {\n      'width': `${containerSideLength}px`,\n      'height': `${containerSideLength}px`\n    };\n    return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n      <div\n        class=\"mdc-circular-progress ${(0,lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_1__.classMap)(classes)}\"\n        style=\"${(0,lit_html_directives_style_map__WEBPACK_IMPORTED_MODULE_3__.styleMap)(styles)}\"\n        role=\"progressbar\"\n        aria-label=\"${this.ariaLabel}\"\n        aria-valuemin=\"0\"\n        aria-valuemax=\"1\"\n        aria-valuenow=\"${(0,lit_html_directives_if_defined__WEBPACK_IMPORTED_MODULE_2__.ifDefined)(this.indeterminate ? undefined : this.progress)}\">\n        ${this.renderDeterminateContainer()}\n        ${this.renderIndeterminateContainer()}\n      </div>`;\n  }\n  /**\n   * @soyTemplate\n   */\n\n\n  renderDeterminateContainer() {\n    const sideLength = 48 + this.density * 4;\n    const center = sideLength / 2;\n    const circleRadius = this.density >= -3 ? 18 + this.density * 11 / 6 : 12.5 + (this.density + 3) * 5 / 4;\n    const circumference = 2 * 3.1415926 * circleRadius;\n    const determinateStrokeDashOffset = (1 - this.progress) * circumference;\n    const strokeWidth = this.density >= -3 ? 4 + this.density * (1 / 3) : 3 + (this.density + 3) * (1 / 6);\n    return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n      <div class=\"mdc-circular-progress__determinate-container\">\n        <svg class=\"mdc-circular-progress__determinate-circle-graphic\"\n             viewBox=\"0 0 ${sideLength} ${sideLength}\">\n          <circle class=\"mdc-circular-progress__determinate-track\"\n                  cx=\"${center}\" cy=\"${center}\" r=\"${circleRadius}\"\n                  stroke-width=\"${strokeWidth}\"></circle>\n          <circle class=\"mdc-circular-progress__determinate-circle\"\n                  cx=\"${center}\" cy=\"${center}\" r=\"${circleRadius}\"\n                  stroke-dasharray=\"${2 * 3.1415926 * circleRadius}\"\n                  stroke-dashoffset=\"${determinateStrokeDashOffset}\"\n                  stroke-width=\"${strokeWidth}\"></circle>\n        </svg>\n      </div>`;\n  }\n  /**\n   * @soyTemplate\n   */\n\n\n  renderIndeterminateContainer() {\n    return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n      <div class=\"mdc-circular-progress__indeterminate-container\">\n        <div class=\"mdc-circular-progress__spinner-layer\">\n          ${this.renderIndeterminateSpinnerLayer()}\n        </div>\n      </div>`;\n  }\n  /**\n   * @soyTemplate\n   */\n\n\n  renderIndeterminateSpinnerLayer() {\n    const sideLength = 48 + this.density * 4;\n    const center = sideLength / 2;\n    const circleRadius = this.density >= -3 ? 18 + this.density * 11 / 6 : 12.5 + (this.density + 3) * 5 / 4;\n    const circumference = 2 * 3.1415926 * circleRadius;\n    const halfCircumference = 0.5 * circumference;\n    const strokeWidth = this.density >= -3 ? 4 + this.density * (1 / 3) : 3 + (this.density + 3) * (1 / 6);\n    return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n        <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-left\">\n          <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\"\n               viewBox=\"0 0 ${sideLength} ${sideLength}\">\n            <circle cx=\"${center}\" cy=\"${center}\" r=\"${circleRadius}\"\n                    stroke-dasharray=\"${circumference}\"\n                    stroke-dashoffset=\"${halfCircumference}\"\n                    stroke-width=\"${strokeWidth}\"></circle>\n          </svg>\n        </div><div class=\"mdc-circular-progress__gap-patch\">\n          <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\"\n               viewBox=\"0 0 ${sideLength} ${sideLength}\">\n            <circle cx=\"${center}\" cy=\"${center}\" r=\"${circleRadius}\"\n                    stroke-dasharray=\"${circumference}\"\n                    stroke-dashoffset=\"${halfCircumference}\"\n                    stroke-width=\"${strokeWidth * 0.8}\"></circle>\n          </svg>\n        </div><div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-right\">\n          <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\"\n               viewBox=\"0 0 ${sideLength} ${sideLength}\">\n            <circle cx=\"${center}\" cy=\"${center}\" r=\"${circleRadius}\"\n                    stroke-dasharray=\"${circumference}\"\n                    stroke-dashoffset=\"${halfCircumference}\"\n                    stroke-width=\"${strokeWidth}\"></circle>\n          </svg>\n        </div>`;\n  }\n\n  update(changedProperties) {\n    super.update(changedProperties); // Bound progress value in interval [0, 1].\n\n    if (changedProperties.has('progress')) {\n      if (this.progress > 1) {\n        this.progress = 1;\n      }\n\n      if (this.progress < 0) {\n        this.progress = 0;\n      }\n    }\n  }\n\n}\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_4__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n  type: Boolean,\n  reflect: true\n})], CircularProgressBase.prototype, \"indeterminate\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_4__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n  type: Number,\n  reflect: true\n})], CircularProgressBase.prototype, \"progress\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_4__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n  type: Number,\n  reflect: true\n})], CircularProgressBase.prototype, \"density\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_4__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n  type: Boolean,\n  reflect: true\n})], CircularProgressBase.prototype, \"closed\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_4__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n  type: String\n})], CircularProgressBase.prototype, \"ariaLabel\", void 0);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-circular-progress/mwc-circular-progress-base.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-circular-progress/mwc-circular-progress-css.js":
/*!***********************************************************************************!*\
  !*** ./node_modules/@material/mwc-circular-progress/mwc-circular-progress-css.js ***!
  \***********************************************************************************/
/*! namespace exports */
/*! export style [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"style\": () => /* binding */ style\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\nconst style = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`.mdc-circular-progress__determinate-circle,.mdc-circular-progress__indeterminate-circle-graphic{stroke:#6200ee;stroke:var(--mdc-theme-primary, #6200ee)}.mdc-circular-progress__determinate-track{stroke:transparent}@keyframes mdc-circular-progress-container-rotate{to{transform:rotate(360deg)}}@keyframes mdc-circular-progress-spinner-layer-rotate{12.5%{transform:rotate(135deg)}25%{transform:rotate(270deg)}37.5%{transform:rotate(405deg)}50%{transform:rotate(540deg)}62.5%{transform:rotate(675deg)}75%{transform:rotate(810deg)}87.5%{transform:rotate(945deg)}100%{transform:rotate(1080deg)}}@keyframes mdc-circular-progress-color-1-fade-in-out{from{opacity:.99}25%{opacity:.99}26%{opacity:0}89%{opacity:0}90%{opacity:.99}to{opacity:.99}}@keyframes mdc-circular-progress-color-2-fade-in-out{from{opacity:0}15%{opacity:0}25%{opacity:.99}50%{opacity:.99}51%{opacity:0}to{opacity:0}}@keyframes mdc-circular-progress-color-3-fade-in-out{from{opacity:0}40%{opacity:0}50%{opacity:.99}75%{opacity:.99}76%{opacity:0}to{opacity:0}}@keyframes mdc-circular-progress-color-4-fade-in-out{from{opacity:0}65%{opacity:0}75%{opacity:.99}90%{opacity:.99}to{opacity:0}}@keyframes mdc-circular-progress-left-spin{from{transform:rotate(265deg)}50%{transform:rotate(130deg)}to{transform:rotate(265deg)}}@keyframes mdc-circular-progress-right-spin{from{transform:rotate(-265deg)}50%{transform:rotate(-130deg)}to{transform:rotate(-265deg)}}.mdc-circular-progress{display:inline-flex;position:relative;direction:ltr;transition:opacity 250ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-circular-progress__determinate-container,.mdc-circular-progress__indeterminate-circle-graphic,.mdc-circular-progress__indeterminate-container,.mdc-circular-progress__spinner-layer{position:absolute;width:100%;height:100%}.mdc-circular-progress__determinate-container{transform:rotate(-90deg)}.mdc-circular-progress__indeterminate-container{opacity:0}.mdc-circular-progress__determinate-circle-graphic,.mdc-circular-progress__indeterminate-circle-graphic{fill:transparent}.mdc-circular-progress__determinate-circle{transition:stroke-dashoffset 500ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-circular-progress__gap-patch{position:absolute;top:0;left:47.5%;box-sizing:border-box;width:5%;height:100%;overflow:hidden}.mdc-circular-progress__gap-patch .mdc-circular-progress__indeterminate-circle-graphic{left:-900%;width:2000%;transform:rotate(180deg)}.mdc-circular-progress__circle-clipper{display:inline-flex;position:relative;width:50%;height:100%;overflow:hidden}.mdc-circular-progress__circle-clipper .mdc-circular-progress__indeterminate-circle-graphic{width:200%}.mdc-circular-progress__circle-right .mdc-circular-progress__indeterminate-circle-graphic{left:-100%}.mdc-circular-progress--indeterminate .mdc-circular-progress__determinate-container{opacity:0}.mdc-circular-progress--indeterminate .mdc-circular-progress__indeterminate-container{opacity:1}.mdc-circular-progress--indeterminate .mdc-circular-progress__indeterminate-container{animation:mdc-circular-progress-container-rotate 1568.2352941176ms linear infinite}.mdc-circular-progress--indeterminate .mdc-circular-progress__spinner-layer{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-1{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-1-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-2{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-2-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-3{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-3-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-4{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-4-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__circle-left .mdc-circular-progress__indeterminate-circle-graphic{animation:mdc-circular-progress-left-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__circle-right .mdc-circular-progress__indeterminate-circle-graphic{animation:mdc-circular-progress-right-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--closed{opacity:0}:host{display:inline-flex}.mdc-circular-progress__determinate-track{stroke:transparent;stroke:var(--mdc-circular-progress-track-color, transparent)}`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-circular-progress/mwc-circular-progress-css.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-circular-progress/mwc-circular-progress.js":
/*!*******************************************************************************!*\
  !*** ./node_modules/@material/mwc-circular-progress/mwc-circular-progress.js ***!
  \*******************************************************************************/
/*! namespace exports */
/*! export CircularProgress [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"CircularProgress\": () => /* binding */ CircularProgress\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mwc_circular_progress_base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mwc-circular-progress-base */ \"./node_modules/@material/mwc-circular-progress/mwc-circular-progress-base.js\");\n/* harmony import */ var _mwc_circular_progress_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mwc-circular-progress-css */ \"./node_modules/@material/mwc-circular-progress/mwc-circular-progress-css.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n/** @soyCompatible */\n\nlet CircularProgress = class CircularProgress extends _mwc_circular_progress_base__WEBPACK_IMPORTED_MODULE_1__.CircularProgressBase {};\nCircularProgress.styles = _mwc_circular_progress_css__WEBPACK_IMPORTED_MODULE_2__.style;\nCircularProgress = (0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)('mwc-circular-progress')], CircularProgress);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1jaXJjdWxhci1wcm9ncmVzcy9td2MtY2lyY3VsYXItcHJvZ3Jlc3MuanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC9td2MtY2lyY3VsYXItcHJvZ3Jlc3MudHM/ZmMxZiJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5pbXBvcnQge2N1c3RvbUVsZW1lbnR9IGZyb20gJ2xpdC1lbGVtZW50JztcblxuaW1wb3J0IHtDaXJjdWxhclByb2dyZXNzQmFzZX0gZnJvbSAnLi9td2MtY2lyY3VsYXItcHJvZ3Jlc3MtYmFzZSc7XG5pbXBvcnQge3N0eWxlfSBmcm9tICcuL213Yy1jaXJjdWxhci1wcm9ncmVzcy1jc3MnO1xuXG5kZWNsYXJlIGdsb2JhbCB7XG4gIGludGVyZmFjZSBIVE1MRWxlbWVudFRhZ05hbWVNYXAge1xuICAgICdtd2MtY2lyY3VsYXItcHJvZ3Jlc3MnOiBDaXJjdWxhclByb2dyZXNzQmFzZTtcbiAgfVxufVxuXG4vKiogQHNveUNvbXBhdGlibGUgKi9cbkBjdXN0b21FbGVtZW50KCdtd2MtY2lyY3VsYXItcHJvZ3Jlc3MnKVxuZXhwb3J0IGNsYXNzIENpcmN1bGFyUHJvZ3Jlc3MgZXh0ZW5kcyBDaXJjdWxhclByb2dyZXNzQmFzZSB7XG4gIHN0YXRpYyBzdHlsZXMgPSBzdHlsZTtcbn1cbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7Ozs7O0FBQUE7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBZ0JBO0FBRUE7QUFDQTtBQVFBO0FBQ0E7QUFDQTtBQUNBO0FBREE7Iiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-circular-progress/mwc-circular-progress.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-icon-button/mwc-icon-button-base.js":
/*!************************************************************************!*\
  !*** ./node_modules/@material/mwc-icon-button/mwc-icon-button-base.js ***!
  \************************************************************************/
/*! namespace exports */
/*! export IconButtonBase [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"IconButtonBase\": () => /* binding */ IconButtonBase\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var _material_mwc_ripple_mwc_ripple__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-ripple/mwc-ripple */ \"./node_modules/@material/mwc-ripple/mwc-ripple.js\");\n/* harmony import */ var _material_mwc_ripple_ripple_handlers__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @material/mwc-ripple/ripple-handlers */ \"./node_modules/@material/mwc-ripple/ripple-handlers.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n/** @soyCompatible */\n\nclass IconButtonBase extends lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement {\n  constructor() {\n    super(...arguments);\n    this.disabled = false;\n    this.icon = '';\n    this.label = '';\n    this.shouldRenderRipple = false;\n    this.rippleHandlers = new _material_mwc_ripple_ripple_handlers__WEBPACK_IMPORTED_MODULE_2__.RippleHandlers(() => {\n      this.shouldRenderRipple = true;\n      return this.ripple;\n    });\n  }\n  /** @soyTemplate */\n\n\n  renderRipple() {\n    return this.shouldRenderRipple ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n            <mwc-ripple\n                .disabled=\"${this.disabled}\"\n                unbounded>\n            </mwc-ripple>` : '';\n  }\n\n  focus() {\n    const buttonElement = this.buttonElement;\n\n    if (buttonElement) {\n      this.rippleHandlers.startFocus();\n      buttonElement.focus();\n    }\n  }\n\n  blur() {\n    const buttonElement = this.buttonElement;\n\n    if (buttonElement) {\n      this.rippleHandlers.endFocus();\n      buttonElement.blur();\n    }\n  }\n  /** @soyTemplate */\n\n\n  render() {\n    return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`<button\n        class=\"mdc-icon-button\"\n        aria-label=\"${this.label || this.icon}\"\n        ?disabled=\"${this.disabled}\"\n        @focus=\"${this.handleRippleFocus}\"\n        @blur=\"${this.handleRippleBlur}\"\n        @mousedown=\"${this.handleRippleMouseDown}\"\n        @mouseenter=\"${this.handleRippleMouseEnter}\"\n        @mouseleave=\"${this.handleRippleMouseLeave}\"\n        @touchstart=\"${this.handleRippleTouchStart}\"\n        @touchend=\"${this.handleRippleDeactivate}\"\n        @touchcancel=\"${this.handleRippleDeactivate}\">\n      ${this.renderRipple()}\n    <i class=\"material-icons\">${this.icon}</i>\n    <span class=\"default-slot-container\">\n        <slot></slot>\n    </span>\n  </button>`;\n  }\n\n  handleRippleMouseDown(event) {\n    const onUp = () => {\n      window.removeEventListener('mouseup', onUp);\n      this.handleRippleDeactivate();\n    };\n\n    window.addEventListener('mouseup', onUp);\n    this.rippleHandlers.startPress(event);\n  }\n\n  handleRippleTouchStart(event) {\n    this.rippleHandlers.startPress(event);\n  }\n\n  handleRippleDeactivate() {\n    this.rippleHandlers.endPress();\n  }\n\n  handleRippleMouseEnter() {\n    this.rippleHandlers.startHover();\n  }\n\n  handleRippleMouseLeave() {\n    this.rippleHandlers.endHover();\n  }\n\n  handleRippleFocus() {\n    this.rippleHandlers.startFocus();\n  }\n\n  handleRippleBlur() {\n    this.rippleHandlers.endFocus();\n  }\n\n}\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean,\n  reflect: true\n})], IconButtonBase.prototype, \"disabled\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: String\n})], IconButtonBase.prototype, \"icon\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: String\n})], IconButtonBase.prototype, \"label\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.query)('button')], IconButtonBase.prototype, \"buttonElement\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.queryAsync)('mwc-ripple')], IconButtonBase.prototype, \"ripple\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], IconButtonBase.prototype, \"shouldRenderRipple\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.eventOptions)({\n  passive: true\n})], IconButtonBase.prototype, \"handleRippleMouseDown\", null);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.eventOptions)({\n  passive: true\n})], IconButtonBase.prototype, \"handleRippleTouchStart\", null);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-icon-button/mwc-icon-button-base.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-icon-button/mwc-icon-button-css.js":
/*!***********************************************************************!*\
  !*** ./node_modules/@material/mwc-icon-button/mwc-icon-button-css.js ***!
  \***********************************************************************/
/*! namespace exports */
/*! export style [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"style\": () => /* binding */ style\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\nconst style = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`.material-icons{font-family:var(--mdc-icon-font, \"Material Icons\");font-weight:normal;font-style:normal;font-size:var(--mdc-icon-size, 24px);line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}.mdc-icon-button{display:inline-block;position:relative;box-sizing:border-box;border:none;outline:none;background-color:transparent;fill:currentColor;color:inherit;font-size:24px;text-decoration:none;cursor:pointer;user-select:none;width:48px;height:48px;padding:12px}.mdc-icon-button svg,.mdc-icon-button img{width:24px;height:24px}.mdc-icon-button:disabled{color:rgba(0, 0, 0, 0.38);color:var(--mdc-theme-text-disabled-on-light, rgba(0, 0, 0, 0.38))}.mdc-icon-button:disabled{cursor:default;pointer-events:none}.mdc-icon-button__icon{display:inline-block}.mdc-icon-button__icon.mdc-icon-button__icon--on{display:none}.mdc-icon-button--on .mdc-icon-button__icon{display:none}.mdc-icon-button--on .mdc-icon-button__icon.mdc-icon-button__icon--on{display:inline-block}:host{display:inline-block;outline:none;--mdc-ripple-color: currentcolor}:host([disabled]){pointer-events:none}:host,.mdc-icon-button{vertical-align:top}.mdc-icon-button{width:var(--mdc-icon-button-size, 48px);height:var(--mdc-icon-button-size, 48px);padding:calc((var(--mdc-icon-button-size, 48px) - var(--mdc-icon-size, 24px)) / 2)}.mdc-icon-button>i{position:absolute;top:0;padding-top:inherit}.mdc-icon-button i,.mdc-icon-button svg,.mdc-icon-button img,.mdc-icon-button ::slotted(*){display:block;width:var(--mdc-icon-size, 24px);height:var(--mdc-icon-size, 24px)}`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-icon-button/mwc-icon-button-css.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-icon-button/mwc-icon-button.js":
/*!*******************************************************************!*\
  !*** ./node_modules/@material/mwc-icon-button/mwc-icon-button.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export IconButton [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"IconButton\": () => /* binding */ IconButton\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mwc_icon_button_base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mwc-icon-button-base */ \"./node_modules/@material/mwc-icon-button/mwc-icon-button-base.js\");\n/* harmony import */ var _mwc_icon_button_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mwc-icon-button-css */ \"./node_modules/@material/mwc-icon-button/mwc-icon-button-css.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n/** @soyCompatible */\n\nlet IconButton = class IconButton extends _mwc_icon_button_base__WEBPACK_IMPORTED_MODULE_1__.IconButtonBase {};\nIconButton.styles = _mwc_icon_button_css__WEBPACK_IMPORTED_MODULE_2__.style;\nIconButton = (0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)('mwc-icon-button')], IconButton);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1pY29uLWJ1dHRvbi9td2MtaWNvbi1idXR0b24uanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC9td2MtaWNvbi1idXR0b24udHM/MjA5NCJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5cbmltcG9ydCB7Y3VzdG9tRWxlbWVudH0gZnJvbSAnbGl0LWVsZW1lbnQnO1xuXG5pbXBvcnQge0ljb25CdXR0b25CYXNlfSBmcm9tICcuL213Yy1pY29uLWJ1dHRvbi1iYXNlJztcbmltcG9ydCB7c3R5bGV9IGZyb20gJy4vbXdjLWljb24tYnV0dG9uLWNzcyc7XG5cbmRlY2xhcmUgZ2xvYmFsIHtcbiAgaW50ZXJmYWNlIEhUTUxFbGVtZW50VGFnTmFtZU1hcCB7XG4gICAgJ213Yy1pY29uLWJ1dHRvbic6IEljb25CdXR0b247XG4gIH1cbn1cblxuLyoqIEBzb3lDb21wYXRpYmxlICovXG5AY3VzdG9tRWxlbWVudCgnbXdjLWljb24tYnV0dG9uJylcbmV4cG9ydCBjbGFzcyBJY29uQnV0dG9uIGV4dGVuZHMgSWNvbkJ1dHRvbkJhc2Uge1xuICBzdGF0aWMgc3R5bGVzID0gc3R5bGU7XG59XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7O0FBQUE7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBaUJBO0FBRUE7QUFDQTtBQVFBO0FBQ0E7QUFDQTtBQUNBO0FBREE7Iiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-icon-button/mwc-icon-button.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-icon/mwc-icon-host-css.js":
/*!**************************************************************!*\
  !*** ./node_modules/@material/mwc-icon/mwc-icon-host-css.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export style [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"style\": () => /* binding */ style\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\nconst style = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`:host{font-family:var(--mdc-icon-font, \"Material Icons\");font-weight:normal;font-style:normal;font-size:var(--mdc-icon-size, 24px);line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1pY29uL213Yy1pY29uLWhvc3QtY3NzLmpzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvbXdjLWljb24taG9zdC1jc3MudHM/ZDliMiJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5pbXBvcnQge2Nzc30gZnJvbSAnbGl0LWVsZW1lbnQnO1xuXG5leHBvcnQgY29uc3Qgc3R5bGUgPSBjc3NgOmhvc3R7Zm9udC1mYW1pbHk6dmFyKC0tbWRjLWljb24tZm9udCwgXCJNYXRlcmlhbCBJY29uc1wiKTtmb250LXdlaWdodDpub3JtYWw7Zm9udC1zdHlsZTpub3JtYWw7Zm9udC1zaXplOnZhcigtLW1kYy1pY29uLXNpemUsIDI0cHgpO2xpbmUtaGVpZ2h0OjE7bGV0dGVyLXNwYWNpbmc6bm9ybWFsO3RleHQtdHJhbnNmb3JtOm5vbmU7ZGlzcGxheTppbmxpbmUtYmxvY2s7d2hpdGUtc3BhY2U6bm93cmFwO3dvcmQtd3JhcDpub3JtYWw7ZGlyZWN0aW9uOmx0cjstd2Via2l0LWZvbnQtc21vb3RoaW5nOmFudGlhbGlhc2VkO3RleHQtcmVuZGVyaW5nOm9wdGltaXplTGVnaWJpbGl0eTstbW96LW9zeC1mb250LXNtb290aGluZzpncmF5c2NhbGU7Zm9udC1mZWF0dXJlLXNldHRpbmdzOlwibGlnYVwifWA7XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7Ozs7Ozs7Ozs7Ozs7Ozs7QUFnQkE7QUFFQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-icon/mwc-icon-host-css.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-icon/mwc-icon.js":
/*!*****************************************************!*\
  !*** ./node_modules/@material/mwc-icon/mwc-icon.js ***!
  \*****************************************************/
/*! namespace exports */
/*! export Icon [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Icon\": () => /* binding */ Icon\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mwc_icon_host_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mwc-icon-host-css */ \"./node_modules/@material/mwc-icon/mwc-icon-host-css.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n/** @soyCompatible */\n\nlet Icon = class Icon extends lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement {\n  /** @soyTemplate */\n  render() {\n    return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`<slot></slot>`;\n  }\n\n};\nIcon.styles = _mwc_icon_host_css__WEBPACK_IMPORTED_MODULE_1__.style;\nIcon = (0,tslib__WEBPACK_IMPORTED_MODULE_2__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)('mwc-icon')], Icon);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1pY29uL213Yy1pY29uLmpzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvbXdjLWljb24udHM/NTkxMSJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5pbXBvcnQge2N1c3RvbUVsZW1lbnQsIGh0bWwsIExpdEVsZW1lbnR9IGZyb20gJ2xpdC1lbGVtZW50JztcblxuaW1wb3J0IHtzdHlsZX0gZnJvbSAnLi9td2MtaWNvbi1ob3N0LWNzcyc7XG5cbi8qKiBAc295Q29tcGF0aWJsZSAqL1xuQGN1c3RvbUVsZW1lbnQoJ213Yy1pY29uJylcbmV4cG9ydCBjbGFzcyBJY29uIGV4dGVuZHMgTGl0RWxlbWVudCB7XG4gIHN0YXRpYyBzdHlsZXMgPSBzdHlsZTtcblxuICAvKiogQHNveVRlbXBsYXRlICovXG4gIHByb3RlY3RlZCByZW5kZXIoKSB7XG4gICAgcmV0dXJuIGh0bWxgPHNsb3Q+PC9zbG90PmA7XG4gIH1cbn1cblxuZGVjbGFyZSBnbG9iYWwge1xuICBpbnRlcmZhY2UgSFRNTEVsZW1lbnRUYWdOYW1lTWFwIHtcbiAgICAnbXdjLWljb24nOiBJY29uO1xuICB9XG59XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7O0FBQUE7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBZ0JBO0FBRUE7QUFFQTtBQUNBO0FBQ0E7QUFHQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBUEE7QUFDQTtBQURBOyIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-icon/mwc-icon.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-ripple/mwc-ripple-base.js":
/*!**************************************************************!*\
  !*** ./node_modules/@material/mwc-ripple/mwc-ripple-base.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export RippleBase [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"RippleBase\": () => /* binding */ RippleBase\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var _material_mwc_base_base_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-base/base-element */ \"./node_modules/@material/mwc-base/base-element.js\");\n/* harmony import */ var _material_ripple_foundation__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @material/ripple/foundation */ \"./node_modules/@material/ripple/foundation.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! lit-html/directives/class-map */ \"./node_modules/lit-html/directives/class-map.js\");\n/* harmony import */ var lit_html_directives_style_map__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! lit-html/directives/style-map */ \"./node_modules/lit-html/directives/style-map.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n\n\n/** @soyCompatible */\n\nclass RippleBase extends _material_mwc_base_base_element__WEBPACK_IMPORTED_MODULE_0__.BaseElement {\n  constructor() {\n    super(...arguments);\n    this.primary = false;\n    this.accent = false;\n    this.unbounded = false;\n    this.disabled = false;\n    this.activated = false;\n    this.selected = false;\n    this.hovering = false;\n    this.bgFocused = false;\n    this.fgActivation = false;\n    this.fgDeactivation = false;\n    this.fgScale = '';\n    this.fgSize = '';\n    this.translateStart = '';\n    this.translateEnd = '';\n    this.leftPos = '';\n    this.topPos = '';\n    this.mdcFoundationClass = _material_ripple_foundation__WEBPACK_IMPORTED_MODULE_4__.default;\n  }\n\n  get isActive() {\n    return (this.parentElement || this).matches(':active');\n  }\n\n  createAdapter() {\n    return {\n      browserSupportsCssVars: () => true,\n      isUnbounded: () => this.unbounded,\n      isSurfaceActive: () => this.isActive,\n      isSurfaceDisabled: () => this.disabled,\n      addClass: className => {\n        switch (className) {\n          case 'mdc-ripple-upgraded--background-focused':\n            this.bgFocused = true;\n            break;\n\n          case 'mdc-ripple-upgraded--foreground-activation':\n            this.fgActivation = true;\n            break;\n\n          case 'mdc-ripple-upgraded--foreground-deactivation':\n            this.fgDeactivation = true;\n            break;\n\n          default:\n            break;\n        }\n      },\n      removeClass: className => {\n        switch (className) {\n          case 'mdc-ripple-upgraded--background-focused':\n            this.bgFocused = false;\n            break;\n\n          case 'mdc-ripple-upgraded--foreground-activation':\n            this.fgActivation = false;\n            break;\n\n          case 'mdc-ripple-upgraded--foreground-deactivation':\n            this.fgDeactivation = false;\n            break;\n\n          default:\n            break;\n        }\n      },\n      containsEventTarget: () => true,\n      registerInteractionHandler: () => undefined,\n      deregisterInteractionHandler: () => undefined,\n      registerDocumentInteractionHandler: () => undefined,\n      deregisterDocumentInteractionHandler: () => undefined,\n      registerResizeHandler: () => undefined,\n      deregisterResizeHandler: () => undefined,\n      updateCssVariable: (varName, value) => {\n        switch (varName) {\n          case '--mdc-ripple-fg-scale':\n            this.fgScale = value;\n            break;\n\n          case '--mdc-ripple-fg-size':\n            this.fgSize = value;\n            break;\n\n          case '--mdc-ripple-fg-translate-end':\n            this.translateEnd = value;\n            break;\n\n          case '--mdc-ripple-fg-translate-start':\n            this.translateStart = value;\n            break;\n\n          case '--mdc-ripple-left':\n            this.leftPos = value;\n            break;\n\n          case '--mdc-ripple-top':\n            this.topPos = value;\n            break;\n\n          default:\n            break;\n        }\n      },\n      computeBoundingRect: () => (this.parentElement || this).getBoundingClientRect(),\n      getWindowPageOffset: () => ({\n        x: window.pageXOffset,\n        y: window.pageYOffset\n      })\n    };\n  }\n\n  startPress(ev) {\n    this.waitForFoundation(() => {\n      this.mdcFoundation.activate(ev);\n    });\n  }\n\n  endPress() {\n    this.waitForFoundation(() => {\n      this.mdcFoundation.deactivate();\n    });\n  }\n\n  startFocus() {\n    this.waitForFoundation(() => {\n      this.mdcFoundation.handleFocus();\n    });\n  }\n\n  endFocus() {\n    this.waitForFoundation(() => {\n      this.mdcFoundation.handleBlur();\n    });\n  }\n\n  startHover() {\n    this.hovering = true;\n  }\n\n  endHover() {\n    this.hovering = false;\n  }\n  /**\n   * Wait for the MDCFoundation to be created by `firstUpdated`\n   */\n\n\n  waitForFoundation(fn) {\n    if (this.mdcFoundation) {\n      fn();\n    } else {\n      this.updateComplete.then(fn);\n    }\n  }\n  /** @soyTemplate */\n\n\n  render() {\n    /** @classMap */\n    const classes = {\n      'mdc-ripple-upgraded--unbounded': this.unbounded,\n      'mdc-ripple-upgraded--background-focused': this.bgFocused,\n      'mdc-ripple-upgraded--foreground-activation': this.fgActivation,\n      'mdc-ripple-upgraded--foreground-deactivation': this.fgDeactivation,\n      'hover': this.hovering,\n      'primary': this.primary,\n      'accent': this.accent,\n      'disabled': this.disabled,\n      'activated': this.activated,\n      'selected': this.selected\n    };\n    return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n        <div class=\"mdc-ripple-surface mdc-ripple-upgraded ${(0,lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_2__.classMap)(classes)}\"\n          style=\"${(0,lit_html_directives_style_map__WEBPACK_IMPORTED_MODULE_3__.styleMap)({\n      '--mdc-ripple-fg-scale': this.fgScale,\n      '--mdc-ripple-fg-size': this.fgSize,\n      '--mdc-ripple-fg-translate-end': this.translateEnd,\n      '--mdc-ripple-fg-translate-start': this.translateStart,\n      '--mdc-ripple-left': this.leftPos,\n      '--mdc-ripple-top': this.topPos\n    })}\"></div>`;\n  }\n\n}\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.query)('.mdc-ripple-surface')], RippleBase.prototype, \"mdcRoot\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"primary\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"accent\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"unbounded\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"disabled\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"activated\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n  type: Boolean\n})], RippleBase.prototype, \"selected\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"hovering\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"bgFocused\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"fgActivation\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"fgDeactivation\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"fgScale\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"fgSize\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"translateStart\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"translateEnd\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"leftPos\", void 0);\n\n(0,tslib__WEBPACK_IMPORTED_MODULE_5__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()], RippleBase.prototype, \"topPos\", void 0);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-ripple/mwc-ripple-base.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-ripple/mwc-ripple-css.js":
/*!*************************************************************!*\
  !*** ./node_modules/@material/mwc-ripple/mwc-ripple-css.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export style [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"style\": () => /* binding */ style\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\nconst style = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`:host{display:block;position:absolute;top:0;bottom:0;left:0;right:0;width:100%;height:100%;pointer-events:none}@keyframes mdc-ripple-fg-radius-in{from{animation-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transform:translate(var(--mdc-ripple-fg-translate-start, 0)) scale(1)}to{transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}}@keyframes mdc-ripple-fg-opacity-in{from{animation-timing-function:linear;opacity:0}to{opacity:var(--mdc-ripple-fg-opacity, 0)}}@keyframes mdc-ripple-fg-opacity-out{from{animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity, 0)}to{opacity:0}}:host .primary{--mdc-ripple-color: var(--mdc-theme-primary, #6200ee)}:host .accent{--mdc-ripple-color: var( --mdc-theme-secondary, #018786 )}:host .mdc-ripple-surface{top:0;bottom:0;left:0;right:0;width:100%;height:100%;pointer-events:none;--mdc-ripple-fg-size: 0;--mdc-ripple-left: 0;--mdc-ripple-top: 0;--mdc-ripple-fg-scale: 1;--mdc-ripple-fg-translate-end: 0;--mdc-ripple-fg-translate-start: 0;-webkit-tap-highlight-color:rgba(0,0,0,0);will-change:transform,opacity;position:relative;outline:none;overflow:hidden;--mdc-ripple-fg-opacity: var( --mdc-ripple-press-opacity, 0.12 )}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:\"\"}:host .mdc-ripple-surface::before{transition:opacity 15ms linear,background-color 15ms linear;z-index:1}:host .mdc-ripple-surface.mdc-ripple-upgraded::before{transform:scale(var(--mdc-ripple-fg-scale, 1))}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{top:0;left:0;transform:scale(0);transform-origin:center center}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top, 0);left:var(--mdc-ripple-left, 0)}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-activation::after{animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-deactivation::after{animation:mdc-ripple-fg-opacity-out 150ms;transform:translate(var(--mdc-ripple-fg-translate-end, 0)) scale(var(--mdc-ripple-fg-scale, 1))}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded{overflow:visible}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::before,:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:calc(50% - 50%);left:calc(50% - 50%);width:100%;height:100%}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::before,:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{top:var(--mdc-ripple-top, calc(50% - 50%));left:var(--mdc-ripple-left, calc(50% - 50%));width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size, 100%);height:var(--mdc-ripple-fg-size, 100%)}:host .mdc-ripple-surface.hover::before{opacity:0.04;opacity:var(--mdc-ripple-hover-opacity, 0.04)}:host .mdc-ripple-surface.mdc-ripple-upgraded--background-focused::before{opacity:0.12;opacity:var(--mdc-ripple-focus-opacity, 0.12)}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{background-color:#000;background-color:var(--mdc-ripple-color, #000)}:host .mdc-ripple-surface.activated{--mdc-ripple-press-opacity: calc( var(--mdc-ripple-press-opacity, 0.12) + 0.12 )}:host .mdc-ripple-surface.activated::before{opacity:0.12;opacity:var(--mdc-ripple-activated-opacity, 0.12)}:host .mdc-ripple-surface.activated.hover::before{opacity:.16;opacity:calc( var(--mdc-ripple-hover-opacity, 0.04) + var(--mdc-ripple-activated-opacity, 0.12) )}:host .mdc-ripple-surface.activated.mdc-ripple-upgraded--background-focused::before{opacity:.24;opacity:calc( var(--mdc-ripple-focus-opacity, 0.12) + var(--mdc-ripple-activated-opacity, 0.12) )}:host .mdc-ripple-surface.selected{--mdc-ripple-press-opacity: calc( var(--mdc-ripple-press-opacity, 0.12) + 0.08 )}:host .mdc-ripple-surface.selected::before{opacity:0.08;opacity:var(--mdc-ripple-selected-opacity, 0.08)}:host .mdc-ripple-surface.selected.hover::before{opacity:.12;opacity:calc( var(--mdc-ripple-hover-opacity, 0.04) + var(--mdc-ripple-selected-opacity, 0.08) )}:host .mdc-ripple-surface.selected.mdc-ripple-upgraded--background-focused::before{opacity:.2;opacity:calc( var(--mdc-ripple-focus-opacity, 0.12) + var(--mdc-ripple-selected-opacity, 0.08) )}:host .mdc-ripple-surface.disabled{--mdc-ripple-color: transparent}:host .mdc-ripple-surface::before{z-index:1;z-index:var(--m-ripple-z-index, 1)}:host .mdc-ripple-surface::after{z-index:0;z-index:var(--m-ripple-z-index, 0)}`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-ripple/mwc-ripple-css.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-ripple/mwc-ripple.js":
/*!*********************************************************!*\
  !*** ./node_modules/@material/mwc-ripple/mwc-ripple.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export Ripple [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Ripple\": () => /* binding */ Ripple\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mwc_ripple_base__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mwc-ripple-base */ \"./node_modules/@material/mwc-ripple/mwc-ripple-base.js\");\n/* harmony import */ var _mwc_ripple_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mwc-ripple-css */ \"./node_modules/@material/mwc-ripple/mwc-ripple-css.js\");\n\n/**\n@license\nCopyright 2018 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n\n\n\n/** @soyCompatible */\n\nlet Ripple = class Ripple extends _mwc_ripple_base__WEBPACK_IMPORTED_MODULE_1__.RippleBase {};\nRipple.styles = _mwc_ripple_css__WEBPACK_IMPORTED_MODULE_2__.style;\nRipple = (0,tslib__WEBPACK_IMPORTED_MODULE_3__.__decorate)([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)('mwc-ripple')], Ripple);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQG1hdGVyaWFsL213Yy1yaXBwbGUvbXdjLXJpcHBsZS5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kL213Yy1yaXBwbGUudHM/NjNlZCJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgMjAxOCBHb29nbGUgSW5jLiBBbGwgUmlnaHRzIFJlc2VydmVkLlxuXG5MaWNlbnNlZCB1bmRlciB0aGUgQXBhY2hlIExpY2Vuc2UsIFZlcnNpb24gMi4wICh0aGUgXCJMaWNlbnNlXCIpO1xueW91IG1heSBub3QgdXNlIHRoaXMgZmlsZSBleGNlcHQgaW4gY29tcGxpYW5jZSB3aXRoIHRoZSBMaWNlbnNlLlxuWW91IG1heSBvYnRhaW4gYSBjb3B5IG9mIHRoZSBMaWNlbnNlIGF0XG5cbiAgICBodHRwOi8vd3d3LmFwYWNoZS5vcmcvbGljZW5zZXMvTElDRU5TRS0yLjBcblxuVW5sZXNzIHJlcXVpcmVkIGJ5IGFwcGxpY2FibGUgbGF3IG9yIGFncmVlZCB0byBpbiB3cml0aW5nLCBzb2Z0d2FyZVxuZGlzdHJpYnV0ZWQgdW5kZXIgdGhlIExpY2Vuc2UgaXMgZGlzdHJpYnV0ZWQgb24gYW4gXCJBUyBJU1wiIEJBU0lTLFxuV0lUSE9VVCBXQVJSQU5USUVTIE9SIENPTkRJVElPTlMgT0YgQU5ZIEtJTkQsIGVpdGhlciBleHByZXNzIG9yIGltcGxpZWQuXG5TZWUgdGhlIExpY2Vuc2UgZm9yIHRoZSBzcGVjaWZpYyBsYW5ndWFnZSBnb3Zlcm5pbmcgcGVybWlzc2lvbnMgYW5kXG5saW1pdGF0aW9ucyB1bmRlciB0aGUgTGljZW5zZS5cbiovXG5pbXBvcnQge2N1c3RvbUVsZW1lbnR9IGZyb20gJ2xpdC1lbGVtZW50JztcblxuaW1wb3J0IHtSaXBwbGVCYXNlfSBmcm9tICcuL213Yy1yaXBwbGUtYmFzZSc7XG5pbXBvcnQge3N0eWxlfSBmcm9tICcuL213Yy1yaXBwbGUtY3NzJztcblxuZGVjbGFyZSBnbG9iYWwge1xuICBpbnRlcmZhY2UgSFRNTEVsZW1lbnRUYWdOYW1lTWFwIHtcbiAgICAnbXdjLXJpcHBsZSc6IFJpcHBsZTtcbiAgfVxufVxuXG4vKiogQHNveUNvbXBhdGlibGUgKi9cbkBjdXN0b21FbGVtZW50KCdtd2MtcmlwcGxlJylcbmV4cG9ydCBjbGFzcyBSaXBwbGUgZXh0ZW5kcyBSaXBwbGVCYXNlIHtcbiAgc3RhdGljIHN0eWxlcyA9IHN0eWxlO1xufVxuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7Ozs7QUFBQTs7Ozs7Ozs7Ozs7Ozs7Ozs7QUFnQkE7QUFFQTtBQUNBO0FBUUE7QUFDQTtBQUNBO0FBQ0E7QUFEQTsiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-ripple/mwc-ripple.js\n");

/***/ }),

/***/ "./node_modules/@material/mwc-ripple/ripple-handlers.js":
/*!**************************************************************!*\
  !*** ./node_modules/@material/mwc-ripple/ripple-handlers.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export RippleHandlers [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"RippleHandlers\": () => /* binding */ RippleHandlers\n/* harmony export */ });\n/**\n@license\nCopyright 2020 Google Inc. All Rights Reserved.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.\n*/\n\n/**\n * Class that encapsulates the events handlers for `mwc-ripple`\n *\n *\n * Example:\n * ```\n * class XFoo extends LitElement {\n *   async getRipple() {\n *     this.renderRipple = true;\n *     await this.updateComplete;\n *     return this.renderRoot.querySelector('mwc-ripple');\n *   }\n *   rippleHandlers = new RippleHandlers(() => this.getRipple());\n *\n *   render() {\n *     return html`\n *       <div @mousedown=${this.rippleHandlers.startPress}></div>\n *       ${this.renderRipple ? html`<mwc-ripple></mwc-ripple>` : ''}\n *     `;\n *   }\n * }\n * ```\n */\nclass RippleHandlers {\n  constructor(\n  /** Function that returns a `mwc-ripple` */\n  rippleFn) {\n    this.startPress = ev => {\n      rippleFn().then(r => {\n        r && r.startPress(ev);\n      });\n    };\n\n    this.endPress = () => {\n      rippleFn().then(r => {\n        r && r.endPress();\n      });\n    };\n\n    this.startFocus = () => {\n      rippleFn().then(r => {\n        r && r.startFocus();\n      });\n    };\n\n    this.endFocus = () => {\n      rippleFn().then(r => {\n        r && r.endFocus();\n      });\n    };\n\n    this.startHover = () => {\n      rippleFn().then(r => {\n        r && r.startHover();\n      });\n    };\n\n    this.endHover = () => {\n      rippleFn().then(r => {\n        r && r.endHover();\n      });\n    };\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@material/mwc-ripple/ripple-handlers.js\n");

/***/ }),

/***/ "./node_modules/@material/ripple/constants.js":
/*!****************************************************!*\
  !*** ./node_modules/@material/ripple/constants.js ***!
  \****************************************************/
/*! namespace exports */
/*! export cssClasses [provided] [no usage info] [missing usage info prevents renaming] */
/*! export numbers [provided] [no usage info] [missing usage info prevents renaming] */
/*! export strings [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"cssClasses\": () => /* binding */ cssClasses,\n/* harmony export */   \"strings\": () => /* binding */ strings,\n/* harmony export */   \"numbers\": () => /* binding */ numbers\n/* harmony export */ });\n/**\n * @license\n * Copyright 2016 Google Inc.\n *\n * Permission is hereby granted, free of charge, to any person obtaining a copy\n * of this software and associated documentation files (the \"Software\"), to deal\n * in the Software without restriction, including without limitation the rights\n * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n * copies of the Software, and to permit persons to whom the Software is\n * furnished to do so, subject to the following conditions:\n *\n * The above copyright notice and this permission notice shall be included in\n * all copies or substantial portions of the Software.\n *\n * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n * THE SOFTWARE.\n */\nvar cssClasses = {\n  // Ripple is a special case where the \"root\" component is really a \"mixin\" of sorts,\n  // given that it's an 'upgrade' to an existing component. That being said it is the root\n  // CSS class that all other CSS classes derive from.\n  BG_FOCUSED: 'mdc-ripple-upgraded--background-focused',\n  FG_ACTIVATION: 'mdc-ripple-upgraded--foreground-activation',\n  FG_DEACTIVATION: 'mdc-ripple-upgraded--foreground-deactivation',\n  ROOT: 'mdc-ripple-upgraded',\n  UNBOUNDED: 'mdc-ripple-upgraded--unbounded'\n};\nvar strings = {\n  VAR_FG_SCALE: '--mdc-ripple-fg-scale',\n  VAR_FG_SIZE: '--mdc-ripple-fg-size',\n  VAR_FG_TRANSLATE_END: '--mdc-ripple-fg-translate-end',\n  VAR_FG_TRANSLATE_START: '--mdc-ripple-fg-translate-start',\n  VAR_LEFT: '--mdc-ripple-left',\n  VAR_TOP: '--mdc-ripple-top'\n};\nvar numbers = {\n  DEACTIVATION_TIMEOUT_MS: 225,\n  FG_DEACTIVATION_MS: 150,\n  INITIAL_ORIGIN_SCALE: 0.6,\n  PADDING: 10,\n  TAP_DELAY_MS: 300\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@material/ripple/constants.js\n");

/***/ }),

/***/ "./node_modules/@material/ripple/foundation.js":
/*!*****************************************************!*\
  !*** ./node_modules/@material/ripple/foundation.js ***!
  \*****************************************************/
/*! namespace exports */
/*! export MDCRippleFoundation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"MDCRippleFoundation\": () => /* binding */ MDCRippleFoundation,\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! tslib */ \"./node_modules/tslib/tslib.es6.js\");\n/* harmony import */ var _material_base_foundation__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @material/base/foundation */ \"./node_modules/@material/base/foundation.js\");\n/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./constants */ \"./node_modules/@material/ripple/constants.js\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./util */ \"./node_modules/@material/ripple/util.js\");\n/**\n * @license\n * Copyright 2016 Google Inc.\n *\n * Permission is hereby granted, free of charge, to any person obtaining a copy\n * of this software and associated documentation files (the \"Software\"), to deal\n * in the Software without restriction, including without limitation the rights\n * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n * copies of the Software, and to permit persons to whom the Software is\n * furnished to do so, subject to the following conditions:\n *\n * The above copyright notice and this permission notice shall be included in\n * all copies or substantial portions of the Software.\n *\n * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n * THE SOFTWARE.\n */\n\n\n\n // Activation events registered on the root element of each instance for activation\n\nvar ACTIVATION_EVENT_TYPES = ['touchstart', 'pointerdown', 'mousedown', 'keydown']; // Deactivation events registered on documentElement when a pointer-related down event occurs\n\nvar POINTER_DEACTIVATION_EVENT_TYPES = ['touchend', 'pointerup', 'mouseup', 'contextmenu']; // simultaneous nested activations\n\nvar activatedTargets = [];\n\nvar MDCRippleFoundation =\n/** @class */\nfunction (_super) {\n  (0,tslib__WEBPACK_IMPORTED_MODULE_0__.__extends)(MDCRippleFoundation, _super);\n\n  function MDCRippleFoundation(adapter) {\n    var _this = _super.call(this, (0,tslib__WEBPACK_IMPORTED_MODULE_0__.__assign)((0,tslib__WEBPACK_IMPORTED_MODULE_0__.__assign)({}, MDCRippleFoundation.defaultAdapter), adapter)) || this;\n\n    _this.activationAnimationHasEnded_ = false;\n    _this.activationTimer_ = 0;\n    _this.fgDeactivationRemovalTimer_ = 0;\n    _this.fgScale_ = '0';\n    _this.frame_ = {\n      width: 0,\n      height: 0\n    };\n    _this.initialSize_ = 0;\n    _this.layoutFrame_ = 0;\n    _this.maxRadius_ = 0;\n    _this.unboundedCoords_ = {\n      left: 0,\n      top: 0\n    };\n    _this.activationState_ = _this.defaultActivationState_();\n\n    _this.activationTimerCallback_ = function () {\n      _this.activationAnimationHasEnded_ = true;\n\n      _this.runDeactivationUXLogicIfReady_();\n    };\n\n    _this.activateHandler_ = function (e) {\n      return _this.activate_(e);\n    };\n\n    _this.deactivateHandler_ = function () {\n      return _this.deactivate_();\n    };\n\n    _this.focusHandler_ = function () {\n      return _this.handleFocus();\n    };\n\n    _this.blurHandler_ = function () {\n      return _this.handleBlur();\n    };\n\n    _this.resizeHandler_ = function () {\n      return _this.layout();\n    };\n\n    return _this;\n  }\n\n  Object.defineProperty(MDCRippleFoundation, \"cssClasses\", {\n    get: function () {\n      return _constants__WEBPACK_IMPORTED_MODULE_1__.cssClasses;\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCRippleFoundation, \"strings\", {\n    get: function () {\n      return _constants__WEBPACK_IMPORTED_MODULE_1__.strings;\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCRippleFoundation, \"numbers\", {\n    get: function () {\n      return _constants__WEBPACK_IMPORTED_MODULE_1__.numbers;\n    },\n    enumerable: true,\n    configurable: true\n  });\n  Object.defineProperty(MDCRippleFoundation, \"defaultAdapter\", {\n    get: function () {\n      return {\n        addClass: function () {\n          return undefined;\n        },\n        browserSupportsCssVars: function () {\n          return true;\n        },\n        computeBoundingRect: function () {\n          return {\n            top: 0,\n            right: 0,\n            bottom: 0,\n            left: 0,\n            width: 0,\n            height: 0\n          };\n        },\n        containsEventTarget: function () {\n          return true;\n        },\n        deregisterDocumentInteractionHandler: function () {\n          return undefined;\n        },\n        deregisterInteractionHandler: function () {\n          return undefined;\n        },\n        deregisterResizeHandler: function () {\n          return undefined;\n        },\n        getWindowPageOffset: function () {\n          return {\n            x: 0,\n            y: 0\n          };\n        },\n        isSurfaceActive: function () {\n          return true;\n        },\n        isSurfaceDisabled: function () {\n          return true;\n        },\n        isUnbounded: function () {\n          return true;\n        },\n        registerDocumentInteractionHandler: function () {\n          return undefined;\n        },\n        registerInteractionHandler: function () {\n          return undefined;\n        },\n        registerResizeHandler: function () {\n          return undefined;\n        },\n        removeClass: function () {\n          return undefined;\n        },\n        updateCssVariable: function () {\n          return undefined;\n        }\n      };\n    },\n    enumerable: true,\n    configurable: true\n  });\n\n  MDCRippleFoundation.prototype.init = function () {\n    var _this = this;\n\n    var supportsPressRipple = this.supportsPressRipple_();\n    this.registerRootHandlers_(supportsPressRipple);\n\n    if (supportsPressRipple) {\n      var _a = MDCRippleFoundation.cssClasses,\n          ROOT_1 = _a.ROOT,\n          UNBOUNDED_1 = _a.UNBOUNDED;\n      requestAnimationFrame(function () {\n        _this.adapter.addClass(ROOT_1);\n\n        if (_this.adapter.isUnbounded()) {\n          _this.adapter.addClass(UNBOUNDED_1); // Unbounded ripples need layout logic applied immediately to set coordinates for both shade and ripple\n\n\n          _this.layoutInternal_();\n        }\n      });\n    }\n  };\n\n  MDCRippleFoundation.prototype.destroy = function () {\n    var _this = this;\n\n    if (this.supportsPressRipple_()) {\n      if (this.activationTimer_) {\n        clearTimeout(this.activationTimer_);\n        this.activationTimer_ = 0;\n        this.adapter.removeClass(MDCRippleFoundation.cssClasses.FG_ACTIVATION);\n      }\n\n      if (this.fgDeactivationRemovalTimer_) {\n        clearTimeout(this.fgDeactivationRemovalTimer_);\n        this.fgDeactivationRemovalTimer_ = 0;\n        this.adapter.removeClass(MDCRippleFoundation.cssClasses.FG_DEACTIVATION);\n      }\n\n      var _a = MDCRippleFoundation.cssClasses,\n          ROOT_2 = _a.ROOT,\n          UNBOUNDED_2 = _a.UNBOUNDED;\n      requestAnimationFrame(function () {\n        _this.adapter.removeClass(ROOT_2);\n\n        _this.adapter.removeClass(UNBOUNDED_2);\n\n        _this.removeCssVars_();\n      });\n    }\n\n    this.deregisterRootHandlers_();\n    this.deregisterDeactivationHandlers_();\n  };\n  /**\n   * @param evt Optional event containing position information.\n   */\n\n\n  MDCRippleFoundation.prototype.activate = function (evt) {\n    this.activate_(evt);\n  };\n\n  MDCRippleFoundation.prototype.deactivate = function () {\n    this.deactivate_();\n  };\n\n  MDCRippleFoundation.prototype.layout = function () {\n    var _this = this;\n\n    if (this.layoutFrame_) {\n      cancelAnimationFrame(this.layoutFrame_);\n    }\n\n    this.layoutFrame_ = requestAnimationFrame(function () {\n      _this.layoutInternal_();\n\n      _this.layoutFrame_ = 0;\n    });\n  };\n\n  MDCRippleFoundation.prototype.setUnbounded = function (unbounded) {\n    var UNBOUNDED = MDCRippleFoundation.cssClasses.UNBOUNDED;\n\n    if (unbounded) {\n      this.adapter.addClass(UNBOUNDED);\n    } else {\n      this.adapter.removeClass(UNBOUNDED);\n    }\n  };\n\n  MDCRippleFoundation.prototype.handleFocus = function () {\n    var _this = this;\n\n    requestAnimationFrame(function () {\n      return _this.adapter.addClass(MDCRippleFoundation.cssClasses.BG_FOCUSED);\n    });\n  };\n\n  MDCRippleFoundation.prototype.handleBlur = function () {\n    var _this = this;\n\n    requestAnimationFrame(function () {\n      return _this.adapter.removeClass(MDCRippleFoundation.cssClasses.BG_FOCUSED);\n    });\n  };\n  /**\n   * We compute this property so that we are not querying information about the client\n   * until the point in time where the foundation requests it. This prevents scenarios where\n   * client-side feature-detection may happen too early, such as when components are rendered on the server\n   * and then initialized at mount time on the client.\n   */\n\n\n  MDCRippleFoundation.prototype.supportsPressRipple_ = function () {\n    return this.adapter.browserSupportsCssVars();\n  };\n\n  MDCRippleFoundation.prototype.defaultActivationState_ = function () {\n    return {\n      activationEvent: undefined,\n      hasDeactivationUXRun: false,\n      isActivated: false,\n      isProgrammatic: false,\n      wasActivatedByPointer: false,\n      wasElementMadeActive: false\n    };\n  };\n  /**\n   * supportsPressRipple Passed from init to save a redundant function call\n   */\n\n\n  MDCRippleFoundation.prototype.registerRootHandlers_ = function (supportsPressRipple) {\n    var _this = this;\n\n    if (supportsPressRipple) {\n      ACTIVATION_EVENT_TYPES.forEach(function (evtType) {\n        _this.adapter.registerInteractionHandler(evtType, _this.activateHandler_);\n      });\n\n      if (this.adapter.isUnbounded()) {\n        this.adapter.registerResizeHandler(this.resizeHandler_);\n      }\n    }\n\n    this.adapter.registerInteractionHandler('focus', this.focusHandler_);\n    this.adapter.registerInteractionHandler('blur', this.blurHandler_);\n  };\n\n  MDCRippleFoundation.prototype.registerDeactivationHandlers_ = function (evt) {\n    var _this = this;\n\n    if (evt.type === 'keydown') {\n      this.adapter.registerInteractionHandler('keyup', this.deactivateHandler_);\n    } else {\n      POINTER_DEACTIVATION_EVENT_TYPES.forEach(function (evtType) {\n        _this.adapter.registerDocumentInteractionHandler(evtType, _this.deactivateHandler_);\n      });\n    }\n  };\n\n  MDCRippleFoundation.prototype.deregisterRootHandlers_ = function () {\n    var _this = this;\n\n    ACTIVATION_EVENT_TYPES.forEach(function (evtType) {\n      _this.adapter.deregisterInteractionHandler(evtType, _this.activateHandler_);\n    });\n    this.adapter.deregisterInteractionHandler('focus', this.focusHandler_);\n    this.adapter.deregisterInteractionHandler('blur', this.blurHandler_);\n\n    if (this.adapter.isUnbounded()) {\n      this.adapter.deregisterResizeHandler(this.resizeHandler_);\n    }\n  };\n\n  MDCRippleFoundation.prototype.deregisterDeactivationHandlers_ = function () {\n    var _this = this;\n\n    this.adapter.deregisterInteractionHandler('keyup', this.deactivateHandler_);\n    POINTER_DEACTIVATION_EVENT_TYPES.forEach(function (evtType) {\n      _this.adapter.deregisterDocumentInteractionHandler(evtType, _this.deactivateHandler_);\n    });\n  };\n\n  MDCRippleFoundation.prototype.removeCssVars_ = function () {\n    var _this = this;\n\n    var rippleStrings = MDCRippleFoundation.strings;\n    var keys = Object.keys(rippleStrings);\n    keys.forEach(function (key) {\n      if (key.indexOf('VAR_') === 0) {\n        _this.adapter.updateCssVariable(rippleStrings[key], null);\n      }\n    });\n  };\n\n  MDCRippleFoundation.prototype.activate_ = function (evt) {\n    var _this = this;\n\n    if (this.adapter.isSurfaceDisabled()) {\n      return;\n    }\n\n    var activationState = this.activationState_;\n\n    if (activationState.isActivated) {\n      return;\n    } // Avoid reacting to follow-on events fired by touch device after an already-processed user interaction\n\n\n    var previousActivationEvent = this.previousActivationEvent_;\n    var isSameInteraction = previousActivationEvent && evt !== undefined && previousActivationEvent.type !== evt.type;\n\n    if (isSameInteraction) {\n      return;\n    }\n\n    activationState.isActivated = true;\n    activationState.isProgrammatic = evt === undefined;\n    activationState.activationEvent = evt;\n    activationState.wasActivatedByPointer = activationState.isProgrammatic ? false : evt !== undefined && (evt.type === 'mousedown' || evt.type === 'touchstart' || evt.type === 'pointerdown');\n    var hasActivatedChild = evt !== undefined && activatedTargets.length > 0 && activatedTargets.some(function (target) {\n      return _this.adapter.containsEventTarget(target);\n    });\n\n    if (hasActivatedChild) {\n      // Immediately reset activation state, while preserving logic that prevents touch follow-on events\n      this.resetActivationState_();\n      return;\n    }\n\n    if (evt !== undefined) {\n      activatedTargets.push(evt.target);\n      this.registerDeactivationHandlers_(evt);\n    }\n\n    activationState.wasElementMadeActive = this.checkElementMadeActive_(evt);\n\n    if (activationState.wasElementMadeActive) {\n      this.animateActivation_();\n    }\n\n    requestAnimationFrame(function () {\n      // Reset array on next frame after the current event has had a chance to bubble to prevent ancestor ripples\n      activatedTargets = [];\n\n      if (!activationState.wasElementMadeActive && evt !== undefined && (evt.key === ' ' || evt.keyCode === 32)) {\n        // If space was pressed, try again within an rAF call to detect :active, because different UAs report\n        // active states inconsistently when they're called within event handling code:\n        // - https://bugs.chromium.org/p/chromium/issues/detail?id=635971\n        // - https://bugzilla.mozilla.org/show_bug.cgi?id=1293741\n        // We try first outside rAF to support Edge, which does not exhibit this problem, but will crash if a CSS\n        // variable is set within a rAF callback for a submit button interaction (#2241).\n        activationState.wasElementMadeActive = _this.checkElementMadeActive_(evt);\n\n        if (activationState.wasElementMadeActive) {\n          _this.animateActivation_();\n        }\n      }\n\n      if (!activationState.wasElementMadeActive) {\n        // Reset activation state immediately if element was not made active.\n        _this.activationState_ = _this.defaultActivationState_();\n      }\n    });\n  };\n\n  MDCRippleFoundation.prototype.checkElementMadeActive_ = function (evt) {\n    return evt !== undefined && evt.type === 'keydown' ? this.adapter.isSurfaceActive() : true;\n  };\n\n  MDCRippleFoundation.prototype.animateActivation_ = function () {\n    var _this = this;\n\n    var _a = MDCRippleFoundation.strings,\n        VAR_FG_TRANSLATE_START = _a.VAR_FG_TRANSLATE_START,\n        VAR_FG_TRANSLATE_END = _a.VAR_FG_TRANSLATE_END;\n    var _b = MDCRippleFoundation.cssClasses,\n        FG_DEACTIVATION = _b.FG_DEACTIVATION,\n        FG_ACTIVATION = _b.FG_ACTIVATION;\n    var DEACTIVATION_TIMEOUT_MS = MDCRippleFoundation.numbers.DEACTIVATION_TIMEOUT_MS;\n    this.layoutInternal_();\n    var translateStart = '';\n    var translateEnd = '';\n\n    if (!this.adapter.isUnbounded()) {\n      var _c = this.getFgTranslationCoordinates_(),\n          startPoint = _c.startPoint,\n          endPoint = _c.endPoint;\n\n      translateStart = startPoint.x + \"px, \" + startPoint.y + \"px\";\n      translateEnd = endPoint.x + \"px, \" + endPoint.y + \"px\";\n    }\n\n    this.adapter.updateCssVariable(VAR_FG_TRANSLATE_START, translateStart);\n    this.adapter.updateCssVariable(VAR_FG_TRANSLATE_END, translateEnd); // Cancel any ongoing activation/deactivation animations\n\n    clearTimeout(this.activationTimer_);\n    clearTimeout(this.fgDeactivationRemovalTimer_);\n    this.rmBoundedActivationClasses_();\n    this.adapter.removeClass(FG_DEACTIVATION); // Force layout in order to re-trigger the animation.\n\n    this.adapter.computeBoundingRect();\n    this.adapter.addClass(FG_ACTIVATION);\n    this.activationTimer_ = setTimeout(function () {\n      return _this.activationTimerCallback_();\n    }, DEACTIVATION_TIMEOUT_MS);\n  };\n\n  MDCRippleFoundation.prototype.getFgTranslationCoordinates_ = function () {\n    var _a = this.activationState_,\n        activationEvent = _a.activationEvent,\n        wasActivatedByPointer = _a.wasActivatedByPointer;\n    var startPoint;\n\n    if (wasActivatedByPointer) {\n      startPoint = (0,_util__WEBPACK_IMPORTED_MODULE_2__.getNormalizedEventCoords)(activationEvent, this.adapter.getWindowPageOffset(), this.adapter.computeBoundingRect());\n    } else {\n      startPoint = {\n        x: this.frame_.width / 2,\n        y: this.frame_.height / 2\n      };\n    } // Center the element around the start point.\n\n\n    startPoint = {\n      x: startPoint.x - this.initialSize_ / 2,\n      y: startPoint.y - this.initialSize_ / 2\n    };\n    var endPoint = {\n      x: this.frame_.width / 2 - this.initialSize_ / 2,\n      y: this.frame_.height / 2 - this.initialSize_ / 2\n    };\n    return {\n      startPoint: startPoint,\n      endPoint: endPoint\n    };\n  };\n\n  MDCRippleFoundation.prototype.runDeactivationUXLogicIfReady_ = function () {\n    var _this = this; // This method is called both when a pointing device is released, and when the activation animation ends.\n    // The deactivation animation should only run after both of those occur.\n\n\n    var FG_DEACTIVATION = MDCRippleFoundation.cssClasses.FG_DEACTIVATION;\n    var _a = this.activationState_,\n        hasDeactivationUXRun = _a.hasDeactivationUXRun,\n        isActivated = _a.isActivated;\n    var activationHasEnded = hasDeactivationUXRun || !isActivated;\n\n    if (activationHasEnded && this.activationAnimationHasEnded_) {\n      this.rmBoundedActivationClasses_();\n      this.adapter.addClass(FG_DEACTIVATION);\n      this.fgDeactivationRemovalTimer_ = setTimeout(function () {\n        _this.adapter.removeClass(FG_DEACTIVATION);\n      }, _constants__WEBPACK_IMPORTED_MODULE_1__.numbers.FG_DEACTIVATION_MS);\n    }\n  };\n\n  MDCRippleFoundation.prototype.rmBoundedActivationClasses_ = function () {\n    var FG_ACTIVATION = MDCRippleFoundation.cssClasses.FG_ACTIVATION;\n    this.adapter.removeClass(FG_ACTIVATION);\n    this.activationAnimationHasEnded_ = false;\n    this.adapter.computeBoundingRect();\n  };\n\n  MDCRippleFoundation.prototype.resetActivationState_ = function () {\n    var _this = this;\n\n    this.previousActivationEvent_ = this.activationState_.activationEvent;\n    this.activationState_ = this.defaultActivationState_(); // Touch devices may fire additional events for the same interaction within a short time.\n    // Store the previous event until it's safe to assume that subsequent events are for new interactions.\n\n    setTimeout(function () {\n      return _this.previousActivationEvent_ = undefined;\n    }, MDCRippleFoundation.numbers.TAP_DELAY_MS);\n  };\n\n  MDCRippleFoundation.prototype.deactivate_ = function () {\n    var _this = this;\n\n    var activationState = this.activationState_; // This can happen in scenarios such as when you have a keyup event that blurs the element.\n\n    if (!activationState.isActivated) {\n      return;\n    }\n\n    var state = (0,tslib__WEBPACK_IMPORTED_MODULE_0__.__assign)({}, activationState);\n\n    if (activationState.isProgrammatic) {\n      requestAnimationFrame(function () {\n        return _this.animateDeactivation_(state);\n      });\n      this.resetActivationState_();\n    } else {\n      this.deregisterDeactivationHandlers_();\n      requestAnimationFrame(function () {\n        _this.activationState_.hasDeactivationUXRun = true;\n\n        _this.animateDeactivation_(state);\n\n        _this.resetActivationState_();\n      });\n    }\n  };\n\n  MDCRippleFoundation.prototype.animateDeactivation_ = function (_a) {\n    var wasActivatedByPointer = _a.wasActivatedByPointer,\n        wasElementMadeActive = _a.wasElementMadeActive;\n\n    if (wasActivatedByPointer || wasElementMadeActive) {\n      this.runDeactivationUXLogicIfReady_();\n    }\n  };\n\n  MDCRippleFoundation.prototype.layoutInternal_ = function () {\n    var _this = this;\n\n    this.frame_ = this.adapter.computeBoundingRect();\n    var maxDim = Math.max(this.frame_.height, this.frame_.width); // Surface diameter is treated differently for unbounded vs. bounded ripples.\n    // Unbounded ripple diameter is calculated smaller since the surface is expected to already be padded appropriately\n    // to extend the hitbox, and the ripple is expected to meet the edges of the padded hitbox (which is typically\n    // square). Bounded ripples, on the other hand, are fully expected to expand beyond the surface's longest diameter\n    // (calculated based on the diagonal plus a constant padding), and are clipped at the surface's border via\n    // `overflow: hidden`.\n\n    var getBoundedRadius = function () {\n      var hypotenuse = Math.sqrt(Math.pow(_this.frame_.width, 2) + Math.pow(_this.frame_.height, 2));\n      return hypotenuse + MDCRippleFoundation.numbers.PADDING;\n    };\n\n    this.maxRadius_ = this.adapter.isUnbounded() ? maxDim : getBoundedRadius(); // Ripple is sized as a fraction of the largest dimension of the surface, then scales up using a CSS scale transform\n\n    var initialSize = Math.floor(maxDim * MDCRippleFoundation.numbers.INITIAL_ORIGIN_SCALE); // Unbounded ripple size should always be even number to equally center align.\n\n    if (this.adapter.isUnbounded() && initialSize % 2 !== 0) {\n      this.initialSize_ = initialSize - 1;\n    } else {\n      this.initialSize_ = initialSize;\n    }\n\n    this.fgScale_ = \"\" + this.maxRadius_ / this.initialSize_;\n    this.updateLayoutCssVars_();\n  };\n\n  MDCRippleFoundation.prototype.updateLayoutCssVars_ = function () {\n    var _a = MDCRippleFoundation.strings,\n        VAR_FG_SIZE = _a.VAR_FG_SIZE,\n        VAR_LEFT = _a.VAR_LEFT,\n        VAR_TOP = _a.VAR_TOP,\n        VAR_FG_SCALE = _a.VAR_FG_SCALE;\n    this.adapter.updateCssVariable(VAR_FG_SIZE, this.initialSize_ + \"px\");\n    this.adapter.updateCssVariable(VAR_FG_SCALE, this.fgScale_);\n\n    if (this.adapter.isUnbounded()) {\n      this.unboundedCoords_ = {\n        left: Math.round(this.frame_.width / 2 - this.initialSize_ / 2),\n        top: Math.round(this.frame_.height / 2 - this.initialSize_ / 2)\n      };\n      this.adapter.updateCssVariable(VAR_LEFT, this.unboundedCoords_.left + \"px\");\n      this.adapter.updateCssVariable(VAR_TOP, this.unboundedCoords_.top + \"px\");\n    }\n  };\n\n  return MDCRippleFoundation;\n}(_material_base_foundation__WEBPACK_IMPORTED_MODULE_3__.MDCFoundation);\n\n // tslint:disable-next-line:no-default-export Needed for backward compatibility with MDC Web v0.44.0 and earlier.\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (MDCRippleFoundation);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@material/ripple/foundation.js\n");

/***/ }),

/***/ "./node_modules/@material/ripple/util.js":
/*!***********************************************!*\
  !*** ./node_modules/@material/ripple/util.js ***!
  \***********************************************/
/*! namespace exports */
/*! export getNormalizedEventCoords [provided] [no usage info] [missing usage info prevents renaming] */
/*! export supportsCssVariables [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"supportsCssVariables\": () => /* binding */ supportsCssVariables,\n/* harmony export */   \"getNormalizedEventCoords\": () => /* binding */ getNormalizedEventCoords\n/* harmony export */ });\n/**\n * Stores result from supportsCssVariables to avoid redundant processing to\n * detect CSS custom variable support.\n */\nvar supportsCssVariables_;\nfunction supportsCssVariables(windowObj, forceRefresh) {\n  if (forceRefresh === void 0) {\n    forceRefresh = false;\n  }\n\n  var CSS = windowObj.CSS;\n  var supportsCssVars = supportsCssVariables_;\n\n  if (typeof supportsCssVariables_ === 'boolean' && !forceRefresh) {\n    return supportsCssVariables_;\n  }\n\n  var supportsFunctionPresent = CSS && typeof CSS.supports === 'function';\n\n  if (!supportsFunctionPresent) {\n    return false;\n  }\n\n  var explicitlySupportsCssVars = CSS.supports('--css-vars', 'yes'); // See: https://bugs.webkit.org/show_bug.cgi?id=154669\n  // See: README section on Safari\n\n  var weAreFeatureDetectingSafari10plus = CSS.supports('(--css-vars: yes)') && CSS.supports('color', '#00000000');\n  supportsCssVars = explicitlySupportsCssVars || weAreFeatureDetectingSafari10plus;\n\n  if (!forceRefresh) {\n    supportsCssVariables_ = supportsCssVars;\n  }\n\n  return supportsCssVars;\n}\nfunction getNormalizedEventCoords(evt, pageOffset, clientRect) {\n  if (!evt) {\n    return {\n      x: 0,\n      y: 0\n    };\n  }\n\n  var x = pageOffset.x,\n      y = pageOffset.y;\n  var documentX = x + clientRect.left;\n  var documentY = y + clientRect.top;\n  var normalizedX;\n  var normalizedY; // Determine touch point relative to the ripple container.\n\n  if (evt.type === 'touchstart') {\n    var touchEvent = evt;\n    normalizedX = touchEvent.changedTouches[0].pageX - documentX;\n    normalizedY = touchEvent.changedTouches[0].pageY - documentY;\n  } else {\n    var mouseEvent = evt;\n    normalizedX = mouseEvent.pageX - documentX;\n    normalizedY = mouseEvent.pageY - documentY;\n  }\n\n  return {\n    x: normalizedX,\n    y: normalizedY\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@material/ripple/util.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-layout/app-drawer-layout/app-drawer-layout.js":
/*!*********************************************************************************!*\
  !*** ./node_modules/@polymer/app-layout/app-drawer-layout/app-drawer-layout.js ***!
  \*********************************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_iron_media_query_iron_media_query_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/iron-media-query/iron-media-query.js */ \"./node_modules/@polymer/iron-media-query/iron-media-query.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_render_status_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @polymer/polymer/lib/utils/render-status.js */ \"./node_modules/@polymer/polymer/lib/utils/render-status.js\");\n/* harmony import */ var _app_layout_behavior_app_layout_behavior_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../app-layout-behavior/app-layout-behavior.js */ \"./node_modules/@polymer/app-layout/app-layout-behavior/app-layout-behavior.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n\n/**\napp-drawer-layout is a wrapper element that positions an app-drawer and other\ncontent. When the viewport width is smaller than `responsiveWidth`, this element\nchanges to narrow layout. In narrow layout, the drawer will be stacked on top of\nthe main content. The drawer will slide in/out to hide/reveal the main content.\n\nBy default the drawer is aligned to the start, which is left in LTR layouts:\n\n```html\n<app-drawer-layout>\n  <app-drawer slot=\"drawer\">\n    drawer content\n  </app-drawer>\n  <div>\n    main content\n  </div>\n</app-drawer-layout>\n```\n\nAlign the drawer at the end:\n\n```html\n<app-drawer-layout>\n  <app-drawer slot=\"drawer\" align=\"end\">\n     drawer content\n  </app-drawer>\n  <div>\n    main content\n  </div>\n</app-drawer-layout>\n```\n\nWith an app-header-layout:\n\n```html\n<app-drawer-layout>\n  <app-drawer slot=\"drawer\">\n    drawer-content\n  </app-drawer>\n  <app-header-layout>\n    <app-header slot=\"header\">\n      <app-toolbar>\n        <div main-title>App name</div>\n      </app-toolbar>\n    </app-header>\n\n    main content\n\n  </app-header-layout>\n</app-drawer-layout>\n```\n\nAdd the `drawer-toggle` attribute to elements inside `app-drawer-layout` that\ntoggle the drawer on click events:\n\n```html\n<app-drawer-layout>\n  <app-drawer slot=\"drawer\">\n    drawer-content\n  </app-drawer>\n  <app-header-layout>\n    <app-header slot=\"header\">\n      <app-toolbar>\n        <paper-icon-button icon=\"menu\" drawer-toggle></paper-icon-button>\n        <div main-title>App name</div>\n      </app-toolbar>\n    </app-header>\n\n    main content\n\n  </app-header-layout>\n</app-drawer-layout>\n```\n\n**NOTE:** With app-layout 2.0, the `drawer-toggle` element needs to be manually\nhidden when app-drawer-layout is not in narrow layout. To add this, add the\nfollowing CSS rule where app-drawer-layout is used:\n\n```css\napp-drawer-layout:not([narrow]) [drawer-toggle] {\n  display: none;\n}\n```\n\nAdd the `fullbleed` attribute to app-drawer-layout to make it fit the size of\nits container:\n\n```html\n<app-drawer-layout fullbleed>\n  <app-drawer slot=\"drawer\">\n     drawer content\n  </app-drawer>\n  <div>\n    main content\n  </div>\n</app-drawer-layout>\n```\n\n### Styling\n\nCustom property                          | Description                          | Default\n-----------------------------------------|--------------------------------------|---------\n`--app-drawer-width`                     | Width of the drawer                  | 256px\n`--app-drawer-layout-content-transition` | Transition for the content container | none\n\n**NOTE:** If you use <app-drawer> with <app-drawer-layout> and specify a value\nfor\n`--app-drawer-width`, that value must be accessible by both elements. This can\nbe done by defining the value on the `:host` that contains <app-drawer-layout>\n(or `html` if outside a shadow root):\n\n```css\n:host {\n  --app-drawer-width: 300px;\n}\n```\n\n@group App Elements\n@element app-drawer-layout\n@demo app-drawer-layout/demo/index.html\n*/\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__.Polymer)({\n  _template: _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__.html`\n    <style>\n      :host {\n        display: block;\n        /**\n         * Force app-drawer-layout to have its own stacking context so that its parent can\n         * control the stacking of it relative to other elements.\n         */\n        position: relative;\n        z-index: 0;\n      }\n\n      :host ::slotted([slot=drawer]) {\n        z-index: 1;\n      }\n\n      :host([fullbleed]) {\n        @apply --layout-fit;\n      }\n\n      #contentContainer {\n        /* Create a stacking context here so that all children appear below the header. */\n        position: relative;\n        z-index: 0;\n        height: 100%;\n        transition: var(--app-drawer-layout-content-transition, none);\n      }\n\n      #contentContainer[drawer-position=left] {\n        margin-left: var(--app-drawer-width, 256px);\n      }\n\n      #contentContainer[drawer-position=right] {\n        margin-right: var(--app-drawer-width, 256px);\n      }\n    </style>\n\n    <slot id=\"drawerSlot\" name=\"drawer\"></slot>\n\n    <div id=\"contentContainer\" drawer-position\\$=\"[[_drawerPosition]]\">\n      <slot></slot>\n    </div>\n\n    <iron-media-query query=\"[[_computeMediaQuery(forceNarrow, responsiveWidth)]]\" on-query-matches-changed=\"_onQueryMatchesChanged\"></iron-media-query>\n`,\n  is: 'app-drawer-layout',\n  behaviors: [_app_layout_behavior_app_layout_behavior_js__WEBPACK_IMPORTED_MODULE_6__.AppLayoutBehavior],\n  properties: {\n    /**\n     * If true, ignore `responsiveWidth` setting and force the narrow layout.\n     */\n    forceNarrow: {\n      type: Boolean,\n      value: false\n    },\n\n    /**\n     * If the viewport's width is smaller than this value, the panel will change\n     * to narrow layout. In the mode the drawer will be closed.\n     */\n    responsiveWidth: {\n      type: String,\n      value: '640px'\n    },\n\n    /**\n     * Returns true if it is in narrow layout. This is useful if you need to\n     * show/hide elements based on the layout.\n     */\n    narrow: {\n      type: Boolean,\n      reflectToAttribute: true,\n      readOnly: true,\n      notify: true\n    },\n\n    /**\n     * If true, the drawer will initially be opened when in narrow layout mode.\n     */\n    openedWhenNarrow: {\n      type: Boolean,\n      value: false\n    },\n    _drawerPosition: {\n      type: String\n    }\n  },\n  listeners: {\n    'click': '_clickHandler'\n  },\n  observers: ['_narrowChanged(narrow)'],\n\n  /**\n   * A reference to the app-drawer element.\n   *\n   * @property drawer\n   */\n  get drawer() {\n    return (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__.dom)(this.$.drawerSlot).getDistributedNodes()[0];\n  },\n\n  attached: function () {\n    // Disable drawer transitions until after app-drawer-layout sets the initial\n    // opened state.\n    var drawer = this.drawer;\n\n    if (drawer) {\n      drawer.setAttribute('no-transition', '');\n    }\n  },\n  _clickHandler: function (e) {\n    var target = (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__.dom)(e).localTarget;\n\n    if (target && target.hasAttribute('drawer-toggle')) {\n      var drawer = this.drawer;\n\n      if (drawer && !drawer.persistent) {\n        drawer.toggle();\n      }\n    }\n  },\n  _updateLayoutStates: function () {\n    var drawer = this.drawer;\n\n    if (!this.isAttached || !drawer) {\n      return;\n    }\n\n    this._drawerPosition = this.narrow ? null : drawer.position;\n\n    if (this._drawerNeedsReset) {\n      if (this.narrow) {\n        drawer.opened = this.openedWhenNarrow;\n        drawer.persistent = false;\n      } else {\n        drawer.opened = drawer.persistent = true;\n      }\n\n      if (drawer.hasAttribute('no-transition')) {\n        // Enable drawer transitions after app-drawer-layout sets the initial\n        // opened state.\n        (0,_polymer_polymer_lib_utils_render_status_js__WEBPACK_IMPORTED_MODULE_5__.afterNextRender)(this, function () {\n          drawer.removeAttribute('no-transition');\n        });\n      }\n\n      this._drawerNeedsReset = false;\n    }\n  },\n  _narrowChanged: function () {\n    this._drawerNeedsReset = true;\n    this.resetLayout();\n  },\n  _onQueryMatchesChanged: function (event) {\n    this._setNarrow(event.detail.value);\n  },\n  _computeMediaQuery: function (forceNarrow, responsiveWidth) {\n    return forceNarrow ? '(min-width: 0px)' : '(max-width: ' + responsiveWidth + ')';\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-layout/app-drawer-layout/app-drawer-layout.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-layout/app-drawer/app-drawer.js":
/*!*******************************************************************!*\
  !*** ./node_modules/@polymer/app-layout/app-drawer/app-drawer.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_iron_flex_layout_iron_flex_layout_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/iron-flex-layout/iron-flex-layout.js */ \"./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_render_status_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @polymer/polymer/lib/utils/render-status.js */ \"./node_modules/@polymer/polymer/lib/utils/render-status.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n/**\napp-drawer is a navigation drawer that can slide in from the left or right.\n\nExample:\n\nAlign the drawer at the start, which is left in LTR layouts (default):\n\n```html\n<app-drawer opened></app-drawer>\n```\n\nAlign the drawer at the end:\n\n```html\n<app-drawer align=\"end\" opened></app-drawer>\n```\n\nTo make the contents of the drawer scrollable, create a wrapper for the scroll\ncontent, and apply height and overflow styles to it.\n\n```html\n<app-drawer>\n  <div style=\"height: 100%; overflow: auto;\"></div>\n</app-drawer>\n```\n\n### Styling\n\nCustom property                  | Description                            | Default\n---------------------------------|----------------------------------------|--------------------\n`--app-drawer-width`             | Width of the drawer                    | 256px\n`--app-drawer-content-container` | Mixin for the drawer content container | {}\n`--app-drawer-scrim-background`  | Background for the scrim               | rgba(0, 0, 0, 0.5)\n\n**NOTE:** If you use `<app-drawer>` with `<app-drawer-layout>` and specify a\nvalue for\n`--app-drawer-width`, that value must be accessible by both elements. This can\nbe done by defining the value on the `:host` that contains `<app-drawer-layout>`\n(or `html` if outside a shadow root):\n\n```css\n:host {\n  --app-drawer-width: 300px;\n}\n```\n\n@group App Elements\n@element app-drawer\n@demo app-drawer/demo/left-drawer.html Simple Left Drawer\n@demo app-drawer/demo/right-drawer.html Right Drawer with Icons\n*/\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__.Polymer)({\n  _template: _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__.html`\n    <style>\n      :host {\n        position: fixed;\n        top: -120px;\n        right: 0;\n        bottom: -120px;\n        left: 0;\n\n        visibility: hidden;\n\n        transition-property: visibility;\n      }\n\n      :host([opened]) {\n        visibility: visible;\n      }\n\n      :host([persistent]) {\n        width: var(--app-drawer-width, 256px);\n      }\n\n      :host([persistent][position=left]) {\n        right: auto;\n      }\n\n      :host([persistent][position=right]) {\n        left: auto;\n      }\n\n      #contentContainer {\n        position: absolute;\n        top: 0;\n        bottom: 0;\n        left: 0;\n\n        width: var(--app-drawer-width, 256px);\n        padding: 120px 0;\n\n        transition-property: -webkit-transform;\n        transition-property: transform;\n        -webkit-transform: translate3d(-100%, 0, 0);\n        transform: translate3d(-100%, 0, 0);\n\n        background-color: #FFF;\n\n        @apply --app-drawer-content-container;\n      }\n\n      #contentContainer[persistent] {\n        width: 100%;\n      }\n\n      #contentContainer[position=right] {\n        right: 0;\n        left: auto;\n\n        -webkit-transform: translate3d(100%, 0, 0);\n        transform: translate3d(100%, 0, 0);\n      }\n\n      #contentContainer[swipe-open]::after {\n        position: fixed;\n        top: 0;\n        bottom: 0;\n        left: 100%;\n\n        visibility: visible;\n\n        width: 20px;\n\n        content: '';\n      }\n\n      #contentContainer[swipe-open][position=right]::after {\n        right: 100%;\n        left: auto;\n      }\n\n      #contentContainer[opened] {\n        -webkit-transform: translate3d(0, 0, 0);\n        transform: translate3d(0, 0, 0);\n      }\n\n      #scrim {\n        position: absolute;\n        top: 0;\n        right: 0;\n        bottom: 0;\n        left: 0;\n\n        transition-property: opacity;\n        -webkit-transform: translateZ(0);\n        transform:  translateZ(0);\n\n        opacity: 0;\n        background: var(--app-drawer-scrim-background, rgba(0, 0, 0, 0.5));\n      }\n\n      #scrim.visible {\n        opacity: 1;\n      }\n\n      :host([no-transition]) #contentContainer {\n        transition-property: none;\n      }\n    </style>\n\n    <div id=\"scrim\" on-click=\"close\"></div>\n\n    <!-- HACK(keanulee): Bind attributes here (in addition to :host) for styling to workaround Safari\n    bug. https://bugs.webkit.org/show_bug.cgi?id=170762 -->\n    <div id=\"contentContainer\" opened\\$=\"[[opened]]\" persistent\\$=\"[[persistent]]\" position\\$=\"[[position]]\" swipe-open\\$=\"[[swipeOpen]]\">\n      <slot></slot>\n    </div>\n`,\n  is: 'app-drawer',\n  properties: {\n    /**\n     * The opened state of the drawer.\n     */\n    opened: {\n      type: Boolean,\n      value: false,\n      notify: true,\n      reflectToAttribute: true\n    },\n\n    /**\n     * The drawer does not have a scrim and cannot be swiped close.\n     */\n    persistent: {\n      type: Boolean,\n      value: false,\n      reflectToAttribute: true\n    },\n\n    /**\n     * The transition duration of the drawer in milliseconds.\n     */\n    transitionDuration: {\n      type: Number,\n      value: 200\n    },\n\n    /**\n     * The alignment of the drawer on the screen ('left', 'right', 'start' or\n     * 'end'). 'start' computes to left and 'end' to right in LTR layout and\n     * vice versa in RTL layout.\n     */\n    align: {\n      type: String,\n      value: 'left'\n    },\n\n    /**\n     * The computed, read-only position of the drawer on the screen ('left' or\n     * 'right').\n     */\n    position: {\n      type: String,\n      readOnly: true,\n      reflectToAttribute: true\n    },\n\n    /**\n     * Create an area at the edge of the screen to swipe open the drawer.\n     */\n    swipeOpen: {\n      type: Boolean,\n      value: false,\n      reflectToAttribute: true\n    },\n\n    /**\n     * Trap keyboard focus when the drawer is opened and not persistent.\n     */\n    noFocusTrap: {\n      type: Boolean,\n      value: false\n    },\n\n    /**\n     * Disables swiping on the drawer.\n     */\n    disableSwipe: {\n      type: Boolean,\n      value: false\n    }\n  },\n  observers: ['resetLayout(position, isAttached)', '_resetPosition(align, isAttached)', '_styleTransitionDuration(transitionDuration)', '_openedPersistentChanged(opened, persistent)'],\n  _translateOffset: 0,\n  _trackDetails: null,\n  _drawerState: 0,\n  _boundEscKeydownHandler: null,\n  _firstTabStop: null,\n  _lastTabStop: null,\n  attached: function () {\n    (0,_polymer_polymer_lib_utils_render_status_js__WEBPACK_IMPORTED_MODULE_5__.afterNextRender)(this, function () {\n      this._boundEscKeydownHandler = this._escKeydownHandler.bind(this);\n      this.addEventListener('keydown', this._tabKeydownHandler.bind(this)); // Only listen for horizontal track so you can vertically scroll\n      // inside the drawer.\n\n      this.listen(this, 'track', '_track');\n      this.setScrollDirection('y');\n    });\n    this.fire('app-reset-layout');\n  },\n  detached: function () {\n    document.removeEventListener('keydown', this._boundEscKeydownHandler);\n  },\n\n  /**\n   * Opens the drawer.\n   */\n  open: function () {\n    this.opened = true;\n  },\n\n  /**\n   * Closes the drawer.\n   */\n  close: function () {\n    this.opened = false;\n  },\n\n  /**\n   * Toggles the drawer open and close.\n   */\n  toggle: function () {\n    this.opened = !this.opened;\n  },\n\n  /**\n   * Gets the width of the drawer.\n   *\n   * @return {number} The width of the drawer in pixels.\n   */\n  getWidth: function () {\n    return this._savedWidth || this.$.contentContainer.offsetWidth;\n  },\n  _isRTL: function () {\n    return window.getComputedStyle(this).direction === 'rtl';\n  },\n  _resetPosition: function () {\n    switch (this.align) {\n      case 'start':\n        this._setPosition(this._isRTL() ? 'right' : 'left');\n\n        return;\n\n      case 'end':\n        this._setPosition(this._isRTL() ? 'left' : 'right');\n\n        return;\n    }\n\n    this._setPosition(this.align);\n  },\n  _escKeydownHandler: function (event) {\n    var ESC_KEYCODE = 27;\n\n    if (event.keyCode === ESC_KEYCODE) {\n      // Prevent any side effects if app-drawer closes.\n      event.preventDefault();\n      this.close();\n    }\n  },\n  _track: function (event) {\n    if (this.persistent || this.disableSwipe) {\n      return;\n    } // Disable user selection on desktop.\n\n\n    event.preventDefault();\n\n    switch (event.detail.state) {\n      case 'start':\n        this._trackStart(event);\n\n        break;\n\n      case 'track':\n        this._trackMove(event);\n\n        break;\n\n      case 'end':\n        this._trackEnd(event);\n\n        break;\n    }\n  },\n  _trackStart: function (event) {\n    this._drawerState = this._DRAWER_STATE.TRACKING;\n    var rect = this.$.contentContainer.getBoundingClientRect();\n    this._savedWidth = rect.width;\n\n    if (this.position === 'left') {\n      this._translateOffset = rect.left;\n    } else {\n      this._translateOffset = rect.right - window.innerWidth;\n    }\n\n    this._trackDetails = []; // Disable transitions since style attributes will reflect user track\n    // events.\n\n    this._styleTransitionDuration(0);\n\n    this.style.visibility = 'visible';\n  },\n  _trackMove: function (event) {\n    this._translateDrawer(event.detail.dx + this._translateOffset); // Use Date.now() since event.timeStamp is inconsistent across browsers\n    // (e.g. most browsers use milliseconds but FF 44 uses microseconds).\n\n\n    this._trackDetails.push({\n      dx: event.detail.dx,\n      timeStamp: Date.now()\n    });\n  },\n  _trackEnd: function (event) {\n    var x = event.detail.dx + this._translateOffset;\n    var drawerWidth = this.getWidth();\n    var isPositionLeft = this.position === 'left';\n    var isInEndState = isPositionLeft ? x >= 0 || x <= -drawerWidth : x <= 0 || x >= drawerWidth;\n\n    if (!isInEndState) {\n      // No longer need the track events after this method returns - allow them\n      // to be GC'd.\n      var trackDetails = this._trackDetails;\n      this._trackDetails = null;\n\n      this._flingDrawer(event, trackDetails);\n\n      if (this._drawerState === this._DRAWER_STATE.FLINGING) {\n        return;\n      }\n    } // If the drawer is not flinging, toggle the opened state based on the\n    // position of the drawer.\n\n\n    var halfWidth = drawerWidth / 2;\n\n    if (event.detail.dx < -halfWidth) {\n      this.opened = this.position === 'right';\n    } else if (event.detail.dx > halfWidth) {\n      this.opened = this.position === 'left';\n    }\n\n    if (isInEndState) {\n      this.debounce('_resetDrawerState', this._resetDrawerState);\n    } else {\n      this.debounce('_resetDrawerState', this._resetDrawerState, this.transitionDuration);\n    }\n\n    this._styleTransitionDuration(this.transitionDuration);\n\n    this._resetDrawerTranslate();\n\n    this.style.visibility = '';\n  },\n  _calculateVelocity: function (event, trackDetails) {\n    // Find the oldest track event that is within 100ms using binary search.\n    var now = Date.now();\n    var timeLowerBound = now - 100;\n    var trackDetail;\n    var min = 0;\n    var max = trackDetails.length - 1;\n\n    while (min <= max) {\n      // Floor of average of min and max.\n      var mid = min + max >> 1;\n      var d = trackDetails[mid];\n\n      if (d.timeStamp >= timeLowerBound) {\n        trackDetail = d;\n        max = mid - 1;\n      } else {\n        min = mid + 1;\n      }\n    }\n\n    if (trackDetail) {\n      var dx = event.detail.dx - trackDetail.dx;\n      var dt = now - trackDetail.timeStamp || 1;\n      return dx / dt;\n    }\n\n    return 0;\n  },\n  _flingDrawer: function (event, trackDetails) {\n    var velocity = this._calculateVelocity(event, trackDetails); // Do not fling if velocity is not above a threshold.\n\n\n    if (Math.abs(velocity) < this._MIN_FLING_THRESHOLD) {\n      return;\n    }\n\n    this._drawerState = this._DRAWER_STATE.FLINGING;\n    var x = event.detail.dx + this._translateOffset;\n    var drawerWidth = this.getWidth();\n    var isPositionLeft = this.position === 'left';\n    var isVelocityPositive = velocity > 0;\n    var isClosingLeft = !isVelocityPositive && isPositionLeft;\n    var isClosingRight = isVelocityPositive && !isPositionLeft;\n    var dx;\n\n    if (isClosingLeft) {\n      dx = -(x + drawerWidth);\n    } else if (isClosingRight) {\n      dx = drawerWidth - x;\n    } else {\n      dx = -x;\n    } // Enforce a minimum transition velocity to make the drawer feel snappy.\n\n\n    if (isVelocityPositive) {\n      velocity = Math.max(velocity, this._MIN_TRANSITION_VELOCITY);\n      this.opened = this.position === 'left';\n    } else {\n      velocity = Math.min(velocity, -this._MIN_TRANSITION_VELOCITY);\n      this.opened = this.position === 'right';\n    } // Calculate the amount of time needed to finish the transition based on the\n    // initial slope of the timing function.\n\n\n    var t = this._FLING_INITIAL_SLOPE * dx / velocity;\n\n    this._styleTransitionDuration(t);\n\n    this._styleTransitionTimingFunction(this._FLING_TIMING_FUNCTION);\n\n    this._resetDrawerTranslate();\n\n    this.debounce('_resetDrawerState', this._resetDrawerState, t);\n  },\n  _styleTransitionDuration: function (duration) {\n    this.style.transitionDuration = duration + 'ms';\n    this.$.contentContainer.style.transitionDuration = duration + 'ms';\n    this.$.scrim.style.transitionDuration = duration + 'ms';\n  },\n  _styleTransitionTimingFunction: function (timingFunction) {\n    this.$.contentContainer.style.transitionTimingFunction = timingFunction;\n    this.$.scrim.style.transitionTimingFunction = timingFunction;\n  },\n  _translateDrawer: function (x) {\n    var drawerWidth = this.getWidth();\n\n    if (this.position === 'left') {\n      x = Math.max(-drawerWidth, Math.min(x, 0));\n      this.$.scrim.style.opacity = 1 + x / drawerWidth;\n    } else {\n      x = Math.max(0, Math.min(x, drawerWidth));\n      this.$.scrim.style.opacity = 1 - x / drawerWidth;\n    }\n\n    this.translate3d(x + 'px', '0', '0', this.$.contentContainer);\n  },\n  _resetDrawerTranslate: function () {\n    this.$.scrim.style.opacity = '';\n    this.transform('', this.$.contentContainer);\n  },\n  _resetDrawerState: function () {\n    var oldState = this._drawerState; // If the drawer was flinging, we need to reset the style attributes.\n\n    if (oldState === this._DRAWER_STATE.FLINGING) {\n      this._styleTransitionDuration(this.transitionDuration);\n\n      this._styleTransitionTimingFunction('');\n\n      this.style.visibility = '';\n    }\n\n    this._savedWidth = null;\n\n    if (this.opened) {\n      this._drawerState = this.persistent ? this._DRAWER_STATE.OPENED_PERSISTENT : this._DRAWER_STATE.OPENED;\n    } else {\n      this._drawerState = this._DRAWER_STATE.CLOSED;\n    }\n\n    if (oldState !== this._drawerState) {\n      if (this._drawerState === this._DRAWER_STATE.OPENED) {\n        this._setKeyboardFocusTrap();\n\n        document.addEventListener('keydown', this._boundEscKeydownHandler);\n        document.body.style.overflow = 'hidden';\n      } else {\n        document.removeEventListener('keydown', this._boundEscKeydownHandler);\n        document.body.style.overflow = '';\n      } // Don't fire the event on initial load.\n\n\n      if (oldState !== this._DRAWER_STATE.INIT) {\n        this.fire('app-drawer-transitioned');\n      }\n    }\n  },\n\n  /**\n   * Resets the layout.\n   *\n   * @method resetLayout\n   */\n  resetLayout: function () {\n    this.fire('app-reset-layout');\n  },\n  _setKeyboardFocusTrap: function () {\n    if (this.noFocusTrap) {\n      return;\n    } // NOTE: Unless we use /deep/ (which we shouldn't since it's deprecated),\n    // this will not select focusable elements inside shadow roots.\n\n\n    var focusableElementsSelector = ['a[href]:not([tabindex=\"-1\"])', 'area[href]:not([tabindex=\"-1\"])', 'input:not([disabled]):not([tabindex=\"-1\"])', 'select:not([disabled]):not([tabindex=\"-1\"])', 'textarea:not([disabled]):not([tabindex=\"-1\"])', 'button:not([disabled]):not([tabindex=\"-1\"])', 'iframe:not([tabindex=\"-1\"])', '[tabindex]:not([tabindex=\"-1\"])', '[contentEditable=true]:not([tabindex=\"-1\"])'].join(',');\n    var focusableElements = (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__.dom)(this).querySelectorAll(focusableElementsSelector);\n\n    if (focusableElements.length > 0) {\n      this._firstTabStop = focusableElements[0];\n      this._lastTabStop = focusableElements[focusableElements.length - 1];\n    } else {\n      // Reset saved tab stops when there are no focusable elements in the\n      // drawer.\n      this._firstTabStop = null;\n      this._lastTabStop = null;\n    } // Focus on app-drawer if it has non-zero tabindex. Otherwise, focus the\n    // first focusable element in the drawer, if it exists. Use the tabindex\n    // attribute since the this.tabIndex property in IE/Edge returns 0 (instead\n    // of -1) when the attribute is not set.\n\n\n    var tabindex = this.getAttribute('tabindex');\n\n    if (tabindex && parseInt(tabindex, 10) > -1) {\n      this.focus();\n    } else if (this._firstTabStop) {\n      this._firstTabStop.focus();\n    }\n  },\n  _tabKeydownHandler: function (event) {\n    if (this.noFocusTrap) {\n      return;\n    }\n\n    var TAB_KEYCODE = 9;\n\n    if (this._drawerState === this._DRAWER_STATE.OPENED && event.keyCode === TAB_KEYCODE) {\n      if (event.shiftKey) {\n        if (this._firstTabStop && (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__.dom)(event).localTarget === this._firstTabStop) {\n          event.preventDefault();\n\n          this._lastTabStop.focus();\n        }\n      } else {\n        if (this._lastTabStop && (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_3__.dom)(event).localTarget === this._lastTabStop) {\n          event.preventDefault();\n\n          this._firstTabStop.focus();\n        }\n      }\n    }\n  },\n  _openedPersistentChanged: function (opened, persistent) {\n    this.toggleClass('visible', opened && !persistent, this.$.scrim); // Use a debounce timer instead of transitionend since transitionend won't\n    // fire when app-drawer is display: none.\n\n    this.debounce('_resetDrawerState', this._resetDrawerState, this.transitionDuration);\n  },\n  _MIN_FLING_THRESHOLD: 0.2,\n  _MIN_TRANSITION_VELOCITY: 1.2,\n  _FLING_TIMING_FUNCTION: 'cubic-bezier(0.667, 1, 0.667, 1)',\n  _FLING_INITIAL_SLOPE: 1.5,\n  _DRAWER_STATE: {\n    INIT: 0,\n    OPENED: 1,\n    OPENED_PERSISTENT: 2,\n    CLOSED: 3,\n    TRACKING: 4,\n    FLINGING: 5\n  }\n  /**\n   * Fired when the layout of app-drawer has changed.\n   *\n   * @event app-reset-layout\n   */\n\n  /**\n   * Fired when app-drawer has finished transitioning.\n   *\n   * @event app-drawer-transitioned\n   */\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-layout/app-drawer/app-drawer.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-layout/app-layout-behavior/app-layout-behavior.js":
/*!*************************************************************************************!*\
  !*** ./node_modules/@polymer/app-layout/app-layout-behavior/app-layout-behavior.js ***!
  \*************************************************************************************/
/*! namespace exports */
/*! export AppLayoutBehavior [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"AppLayoutBehavior\": () => /* binding */ AppLayoutBehavior\n/* harmony export */ });\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_iron_resizable_behavior_iron_resizable_behavior_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/iron-resizable-behavior/iron-resizable-behavior.js */ \"./node_modules/@polymer/iron-resizable-behavior/iron-resizable-behavior.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_async_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @polymer/polymer/lib/utils/async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_debounce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @polymer/polymer/lib/utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_flush_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @polymer/polymer/lib/utils/flush.js */ \"./node_modules/@polymer/polymer/lib/utils/flush.js\");\n/**\n@license\nCopyright (c) 2016 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n/**\n * @polymerBehavior\n */\n\nconst AppLayoutBehavior = [_polymer_iron_resizable_behavior_iron_resizable_behavior_js__WEBPACK_IMPORTED_MODULE_1__.IronResizableBehavior, {\n  listeners: {\n    'app-reset-layout': '_appResetLayoutHandler',\n    'iron-resize': 'resetLayout'\n  },\n  attached: function () {\n    this.fire('app-reset-layout');\n  },\n  _appResetLayoutHandler: function (e) {\n    if ((0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_2__.dom)(e).path[0] === this) {\n      return;\n    }\n\n    this.resetLayout();\n    e.stopPropagation();\n  },\n  _updateLayoutStates: function () {\n    console.error('unimplemented');\n  },\n\n  /**\n   * Resets the layout. If you changed the size of this element via CSS\n   * you can notify the changes by either firing the `iron-resize` event\n   * or calling `resetLayout` directly.\n   *\n   * @method resetLayout\n   */\n  resetLayout: function () {\n    var self = this;\n\n    var cb = this._updateLayoutStates.bind(this);\n\n    this._layoutDebouncer = _polymer_polymer_lib_utils_debounce_js__WEBPACK_IMPORTED_MODULE_4__.Debouncer.debounce(this._layoutDebouncer, _polymer_polymer_lib_utils_async_js__WEBPACK_IMPORTED_MODULE_3__.animationFrame, cb);\n    (0,_polymer_polymer_lib_utils_flush_js__WEBPACK_IMPORTED_MODULE_5__.enqueueDebouncer)(this._layoutDebouncer);\n\n    this._notifyDescendantResize();\n  },\n  _notifyLayoutChanged: function () {\n    var self = this; // TODO: the event `app-reset-layout` can be fired synchronously\n    // as long as `_updateLayoutStates` waits for all the microtasks after\n    // rAF. E.g. requestAnimationFrame(setTimeOut())\n\n    requestAnimationFrame(function () {\n      self.fire('app-reset-layout');\n    });\n  },\n  _notifyDescendantResize: function () {\n    if (!this.isAttached) {\n      return;\n    }\n\n    this._interestedResizables.forEach(function (resizable) {\n      if (this.resizerShouldNotify(resizable)) {\n        this._notifyDescendant(resizable);\n      }\n    }, this);\n  }\n}];//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-layout/app-layout-behavior/app-layout-behavior.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-layout/app-toolbar/app-toolbar.js":
/*!*********************************************************************!*\
  !*** ./node_modules/@polymer/app-layout/app-toolbar/app-toolbar.js ***!
  \*********************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_iron_flex_layout_iron_flex_layout_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/iron-flex-layout/iron-flex-layout.js */ \"./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n/**\napp-toolbar is a horizontal toolbar containing items that can be used for\nlabel, navigation, search and actions.\n\n### Example\n\nAdd a title to the toolbar.\n\n```html\n<app-toolbar>\n  <div main-title>App name</div>\n</app-toolbar>\n```\n\nAdd a button to the left and right side of the toolbar.\n\n```html\n<app-toolbar>\n  <paper-icon-button icon=\"menu\"></paper-icon-button>\n  <div main-title>App name</div>\n  <paper-icon-button icon=\"search\"></paper-icon-button>\n</app-toolbar>\n```\n\nYou can use the attributes `top-item` or `bottom-item` to completely fit an\nelement to the top or bottom of the toolbar respectively.\n\n### Content attributes\n\nAttribute            | Description\n---------------------|---------------------------------------------------------\n`main-title`         | The main title element.\n`condensed-title`    | The title element if used inside a condensed app-header.\n`spacer`             | Adds a left margin of `64px`.\n`bottom-item`        | Sticks the element to the bottom of the toolbar.\n`top-item`           | Sticks the element to the top of the toolbar.\n\n### Styling\n\nCustom property              | Description                  | Default\n-----------------------------|------------------------------|-----------------------\n`--app-toolbar-font-size`    | Toolbar font size            | 20px\n\n@group App Elements\n@element app-toolbar\n@demo app-toolbar/demo/index.html\n*/\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_2__.Polymer)({\n  _template: _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_3__.html`\n    <style>\n\n      :host {\n        @apply --layout-horizontal;\n        @apply --layout-center;\n        position: relative;\n        height: 64px;\n        padding: 0 16px;\n        pointer-events: none;\n        font-size: var(--app-toolbar-font-size, 20px);\n      }\n\n      :host ::slotted(*) {\n        pointer-events: auto;\n      }\n\n      :host ::slotted(paper-icon-button) {\n        /* paper-icon-button/issues/33 */\n        font-size: 0;\n      }\n\n      :host ::slotted([main-title]),\n      :host ::slotted([condensed-title]) {\n        pointer-events: none;\n        @apply --layout-flex;\n      }\n\n      :host ::slotted([bottom-item]) {\n        position: absolute;\n        right: 0;\n        bottom: 0;\n        left: 0;\n      }\n\n      :host ::slotted([top-item]) {\n        position: absolute;\n        top: 0;\n        right: 0;\n        left: 0;\n      }\n\n      :host ::slotted([spacer]) {\n        margin-left: 64px;\n      }\n    </style>\n\n    <slot></slot>\n`,\n  is: 'app-toolbar'\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-layout/app-toolbar/app-toolbar.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-route/app-location.js":
/*!*********************************************************!*\
  !*** ./node_modules/@polymer/app-route/app-location.js ***!
  \*********************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_iron_location_iron_location_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/iron-location/iron-location.js */ \"./node_modules/@polymer/iron-location/iron-location.js\");\n/* harmony import */ var _polymer_iron_location_iron_query_params_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/iron-location/iron-query-params.js */ \"./node_modules/@polymer/iron-location/iron-query-params.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/* harmony import */ var _app_route_converter_behavior_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./app-route-converter-behavior.js */ \"./node_modules/@polymer/app-route/app-route-converter-behavior.js\");\n/**\n@license\nCopyright (c) 2016 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n/**\n`app-location` is an element that provides synchronization between the\nbrowser location bar and the state of an app. When created, `app-location`\nelements will automatically watch the global location for changes. As changes\noccur, `app-location` produces and updates an object called `route`. This\n`route` object is suitable for passing into a `app-route`, and other similar\nelements.\n\nAn example of the public API of a route object that describes the URL\n`https://elements.polymer-project.org/elements/app-location`:\n\n    {\n      prefix: '',\n      path: '/elements/app-location'\n    }\n\nExample Usage:\n\n    <app-location route=\"{{route}}\"></app-location>\n    <app-route route=\"{{route}}\" pattern=\"/:page\" data=\"{{data}}\"></app-route>\n\nAs you can see above, the `app-location` element produces a `route` and that\nproperty is then bound into the `app-route` element. The bindings are two-\ndirectional, so when changes to the `route` object occur within `app-route`,\nthey automatically reflect back to the global location.\n\n### Hashes vs Paths\n\nBy default `app-location` routes using the pathname portion of the URL. This has\nbroad browser support but it does require cooperation of the backend server. An\n`app-location` can be configured to use the hash part of a URL instead using\nthe `use-hash-as-path` attribute, like so:\n\n    <app-location route=\"{{route}}\" use-hash-as-path></app-location>\n\n### Integrating with other routing code\n\nThere is no standard event that is fired when window.location is modified.\n`app-location` fires a `location-changed` event on `window` when it updates the\nlocation. It also listens for that same event, and re-reads the URL when it's\nfired. This makes it very easy to interop with other routing code.\n\nSo for example if you want to navigate to `/new_path` imperatively you could\ncall `window.location.pushState` or `window.location.replaceState` followed by\nfiring a `location-changed` event on `window`. i.e.\n\n    window.history.pushState({}, null, '/new_path');\n    window.dispatchEvent(new CustomEvent('location-changed'));\n\n@element app-location\n@demo demo/index.html\n*/\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_3__.Polymer)({\n  _template: _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_4__.html`\n    <iron-query-params params-string=\"{{__query}}\" params-object=\"{{queryParams}}\">\n    </iron-query-params>\n    <iron-location path=\"{{__path}}\" query=\"{{__query}}\" hash=\"{{__hash}}\" url-space-regex=\"[[urlSpaceRegex]]\" dwell-time=\"[[dwellTime]]\">\n    </iron-location>\n  `,\n  is: 'app-location',\n  properties: {\n    /**\n     * A model representing the deserialized path through the route tree, as\n     * well as the current queryParams.\n     */\n    route: {\n      type: Object,\n      notify: true\n    },\n\n    /**\n     * In many scenarios, it is convenient to treat the `hash` as a stand-in\n     * alternative to the `path`. For example, if deploying an app to a static\n     * web server (e.g., Github Pages) - where one does not have control over\n     * server-side routing - it is usually a better experience to use the hash\n     * to represent paths through one's app.\n     *\n     * When this property is set to true, the `hash` will be used in place of\n      * the `path` for generating a `route`.\n     */\n    useHashAsPath: {\n      type: Boolean,\n      value: false\n    },\n\n    /**\n     * A regexp that defines the set of URLs that should be considered part\n     * of this web app.\n     *\n     * Clicking on a link that matches this regex won't result in a full page\n     * navigation, but will instead just update the URL state in place.\n     *\n     * This regexp is given everything after the origin in an absolute\n     * URL. So to match just URLs that start with /search/ do:\n     *     url-space-regex=\"^/search/\"\n     *\n     * @type {string|RegExp}\n     */\n    urlSpaceRegex: {\n      type: String,\n      notify: true\n    },\n\n    /**\n     * A set of key/value pairs that are universally accessible to branches\n     * of the route tree.\n     */\n    __queryParams: {\n      type: Object\n    },\n\n    /**\n     * The pathname component of the current URL.\n     */\n    __path: {\n      type: String\n    },\n\n    /**\n     * The query string portion of the current URL.\n     */\n    __query: {\n      type: String\n    },\n\n    /**\n     * The hash portion of the current URL.\n     */\n    __hash: {\n      type: String\n    },\n\n    /**\n     * The route path, which will be either the hash or the path, depending\n     * on useHashAsPath.\n     */\n    path: {\n      type: String,\n      observer: '__onPathChanged'\n    },\n\n    /**\n     * Whether or not the ready function has been called.\n     */\n    _isReady: {\n      type: Boolean\n    },\n\n    /**\n     * If the user was on a URL for less than `dwellTime` milliseconds, it\n     * won't be added to the browser's history, but instead will be\n     * replaced by the next entry.\n     *\n     * This is to prevent large numbers of entries from clogging up the\n     * user's browser history. Disable by setting to a negative number.\n     *\n     * See `iron-location` for more information.\n     */\n    dwellTime: {\n      type: Number\n    }\n  },\n  behaviors: [_app_route_converter_behavior_js__WEBPACK_IMPORTED_MODULE_5__.AppRouteConverterBehavior],\n  observers: ['__computeRoutePath(useHashAsPath, __hash, __path)'],\n  ready: function () {\n    this._isReady = true;\n  },\n  __computeRoutePath: function () {\n    this.path = this.useHashAsPath ? this.__hash : this.__path;\n  },\n  __onPathChanged: function () {\n    if (!this._isReady) {\n      return;\n    }\n\n    if (this.useHashAsPath) {\n      this.__hash = this.path;\n    } else {\n      this.__path = this.path;\n    }\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-route/app-location.js\n");

/***/ }),

/***/ "./node_modules/@polymer/app-route/app-route-converter-behavior.js":
/*!*************************************************************************!*\
  !*** ./node_modules/@polymer/app-route/app-route-converter-behavior.js ***!
  \*************************************************************************/
/*! namespace exports */
/*! export AppRouteConverterBehavior [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"AppRouteConverterBehavior\": () => /* binding */ AppRouteConverterBehavior\n/* harmony export */ });\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/**\n@license\nCopyright (c) 2016 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Provides bidirectional mapping between `path` and `queryParams` and a\n * app-route compatible `route` object.\n *\n * For more information, see the docs for `app-route-converter`.\n *\n * @polymerBehavior\n */\n\nconst AppRouteConverterBehavior = {\n  properties: {\n    /**\n     * A model representing the deserialized path through the route tree, as\n     * well as the current queryParams.\n     *\n     * A route object is the kernel of the routing system. It is intended to\n     * be fed into consuming elements such as `app-route`.\n     *\n     * @type {?Object|undefined}\n     */\n    route: {\n      type: Object,\n      notify: true\n    },\n\n    /**\n     * A set of key/value pairs that are universally accessible to branches of\n     * the route tree.\n     *\n     * @type {?Object}\n     */\n    queryParams: {\n      type: Object,\n      notify: true\n    },\n\n    /**\n     * The serialized path through the route tree. This corresponds to the\n     * `window.location.pathname` value, and will update to reflect changes\n     * to that value.\n     */\n    path: {\n      type: String,\n      notify: true\n    }\n  },\n  observers: ['_locationChanged(path, queryParams)', '_routeChanged(route.prefix, route.path)', '_routeQueryParamsChanged(route.__queryParams)'],\n  created: function () {\n    this.linkPaths('route.__queryParams', 'queryParams');\n    this.linkPaths('queryParams', 'route.__queryParams');\n  },\n\n  /**\n   * Handler called when the path or queryParams change.\n   */\n  _locationChanged: function () {\n    if (this.route && this.route.path === this.path && this.queryParams === this.route.__queryParams) {\n      return;\n    }\n\n    this.route = {\n      prefix: '',\n      path: this.path,\n      __queryParams: this.queryParams\n    };\n  },\n\n  /**\n   * Handler called when the route prefix and route path change.\n   */\n  _routeChanged: function () {\n    if (!this.route) {\n      return;\n    }\n\n    this.path = this.route.prefix + this.route.path;\n  },\n\n  /**\n   * Handler called when the route queryParams change.\n   *\n   * @param  {Object} queryParams A set of key/value pairs that are\n   * universally accessible to branches of the route tree.\n   */\n  _routeQueryParamsChanged: function (queryParams) {\n    if (!this.route) {\n      return;\n    }\n\n    this.queryParams = queryParams;\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/app-route/app-route-converter-behavior.js\n");

/***/ }),

/***/ "./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js":
/*!********************************************************************!*\
  !*** ./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js ***!
  \********************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n/**\nThe `<iron-flex-layout>` component provides simple ways to use\n[CSS flexible box\nlayout](https://developer.mozilla.org/en-US/docs/Web/Guide/CSS/Flexible_boxes),\nalso known as flexbox. Note that this is an old element, that was written\nbefore all modern browsers had non-prefixed flex styles. As such, nowadays you\ndon't really need to use this element anymore, and can use CSS flex styles\ndirectly in your code.\n\nThis component provides two different ways to use flexbox:\n\n1. [Layout\nclasses](https://github.com/PolymerElements/iron-flex-layout/tree/master/iron-flex-layout-classes.html).\nThe layout class stylesheet provides a simple set of class-based flexbox rules,\nthat let you specify layout properties directly in markup. You must include this\nfile in every element that needs to use them.\n\n    Sample use:\n\n    ```\n    <custom-element-demo>\n      <template>\n        <script src=\"../webcomponentsjs/webcomponents-lite.js\"></script>\n        <next-code-block></next-code-block>\n      </template>\n    </custom-element-demo>\n    ```\n\n    ```js\n    import {html} from '@polymer/polymer/lib/utils/html-tag.js';\n    import '@polymer/iron-flex-layout/iron-flex-layout-classes.js';\n\n    const template = html`\n      <style is=\"custom-style\" include=\"iron-flex iron-flex-alignment\"></style>\n      <style>\n        .test { width: 100px; }\n      </style>\n      <div class=\"layout horizontal center-center\">\n        <div class=\"test\">horizontal layout center alignment</div>\n      </div>\n    `;\n    document.body.appendChild(template.content);\n    ```\n\n2. [Custom CSS\nmixins](https://github.com/PolymerElements/iron-flex-layout/blob/master/iron-flex-layout.html).\nThe mixin stylesheet includes custom CSS mixins that can be applied inside a CSS\nrule using the `@apply` function.\n\nPlease note that the old [/deep/ layout\nclasses](https://github.com/PolymerElements/iron-flex-layout/tree/master/classes)\nare deprecated, and should not be used. To continue using layout properties\ndirectly in markup, please switch to using the new `dom-module`-based\n[layout\nclasses](https://github.com/PolymerElements/iron-flex-layout/tree/master/iron-flex-layout-classes.html).\nPlease note that the new version does not use `/deep/`, and therefore requires\nyou to import the `dom-modules` in every element that needs to use them.\n\n@group Iron Elements\n@pseudoElement iron-flex-layout\n@demo demo/index.html\n*/\n\nconst template = _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__.html`\n<custom-style>\n  <style is=\"custom-style\">\n    [hidden] {\n      display: none !important;\n    }\n  </style>\n</custom-style>\n<custom-style>\n  <style is=\"custom-style\">\n    html {\n\n      --layout: {\n        display: -ms-flexbox;\n        display: -webkit-flex;\n        display: flex;\n      };\n\n      --layout-inline: {\n        display: -ms-inline-flexbox;\n        display: -webkit-inline-flex;\n        display: inline-flex;\n      };\n\n      --layout-horizontal: {\n        @apply --layout;\n\n        -ms-flex-direction: row;\n        -webkit-flex-direction: row;\n        flex-direction: row;\n      };\n\n      --layout-horizontal-reverse: {\n        @apply --layout;\n\n        -ms-flex-direction: row-reverse;\n        -webkit-flex-direction: row-reverse;\n        flex-direction: row-reverse;\n      };\n\n      --layout-vertical: {\n        @apply --layout;\n\n        -ms-flex-direction: column;\n        -webkit-flex-direction: column;\n        flex-direction: column;\n      };\n\n      --layout-vertical-reverse: {\n        @apply --layout;\n\n        -ms-flex-direction: column-reverse;\n        -webkit-flex-direction: column-reverse;\n        flex-direction: column-reverse;\n      };\n\n      --layout-wrap: {\n        -ms-flex-wrap: wrap;\n        -webkit-flex-wrap: wrap;\n        flex-wrap: wrap;\n      };\n\n      --layout-wrap-reverse: {\n        -ms-flex-wrap: wrap-reverse;\n        -webkit-flex-wrap: wrap-reverse;\n        flex-wrap: wrap-reverse;\n      };\n\n      --layout-flex-auto: {\n        -ms-flex: 1 1 auto;\n        -webkit-flex: 1 1 auto;\n        flex: 1 1 auto;\n      };\n\n      --layout-flex-none: {\n        -ms-flex: none;\n        -webkit-flex: none;\n        flex: none;\n      };\n\n      --layout-flex: {\n        -ms-flex: 1 1 0.000000001px;\n        -webkit-flex: 1;\n        flex: 1;\n        -webkit-flex-basis: 0.000000001px;\n        flex-basis: 0.000000001px;\n      };\n\n      --layout-flex-2: {\n        -ms-flex: 2;\n        -webkit-flex: 2;\n        flex: 2;\n      };\n\n      --layout-flex-3: {\n        -ms-flex: 3;\n        -webkit-flex: 3;\n        flex: 3;\n      };\n\n      --layout-flex-4: {\n        -ms-flex: 4;\n        -webkit-flex: 4;\n        flex: 4;\n      };\n\n      --layout-flex-5: {\n        -ms-flex: 5;\n        -webkit-flex: 5;\n        flex: 5;\n      };\n\n      --layout-flex-6: {\n        -ms-flex: 6;\n        -webkit-flex: 6;\n        flex: 6;\n      };\n\n      --layout-flex-7: {\n        -ms-flex: 7;\n        -webkit-flex: 7;\n        flex: 7;\n      };\n\n      --layout-flex-8: {\n        -ms-flex: 8;\n        -webkit-flex: 8;\n        flex: 8;\n      };\n\n      --layout-flex-9: {\n        -ms-flex: 9;\n        -webkit-flex: 9;\n        flex: 9;\n      };\n\n      --layout-flex-10: {\n        -ms-flex: 10;\n        -webkit-flex: 10;\n        flex: 10;\n      };\n\n      --layout-flex-11: {\n        -ms-flex: 11;\n        -webkit-flex: 11;\n        flex: 11;\n      };\n\n      --layout-flex-12: {\n        -ms-flex: 12;\n        -webkit-flex: 12;\n        flex: 12;\n      };\n\n      /* alignment in cross axis */\n\n      --layout-start: {\n        -ms-flex-align: start;\n        -webkit-align-items: flex-start;\n        align-items: flex-start;\n      };\n\n      --layout-center: {\n        -ms-flex-align: center;\n        -webkit-align-items: center;\n        align-items: center;\n      };\n\n      --layout-end: {\n        -ms-flex-align: end;\n        -webkit-align-items: flex-end;\n        align-items: flex-end;\n      };\n\n      --layout-baseline: {\n        -ms-flex-align: baseline;\n        -webkit-align-items: baseline;\n        align-items: baseline;\n      };\n\n      /* alignment in main axis */\n\n      --layout-start-justified: {\n        -ms-flex-pack: start;\n        -webkit-justify-content: flex-start;\n        justify-content: flex-start;\n      };\n\n      --layout-center-justified: {\n        -ms-flex-pack: center;\n        -webkit-justify-content: center;\n        justify-content: center;\n      };\n\n      --layout-end-justified: {\n        -ms-flex-pack: end;\n        -webkit-justify-content: flex-end;\n        justify-content: flex-end;\n      };\n\n      --layout-around-justified: {\n        -ms-flex-pack: distribute;\n        -webkit-justify-content: space-around;\n        justify-content: space-around;\n      };\n\n      --layout-justified: {\n        -ms-flex-pack: justify;\n        -webkit-justify-content: space-between;\n        justify-content: space-between;\n      };\n\n      --layout-center-center: {\n        @apply --layout-center;\n        @apply --layout-center-justified;\n      };\n\n      /* self alignment */\n\n      --layout-self-start: {\n        -ms-align-self: flex-start;\n        -webkit-align-self: flex-start;\n        align-self: flex-start;\n      };\n\n      --layout-self-center: {\n        -ms-align-self: center;\n        -webkit-align-self: center;\n        align-self: center;\n      };\n\n      --layout-self-end: {\n        -ms-align-self: flex-end;\n        -webkit-align-self: flex-end;\n        align-self: flex-end;\n      };\n\n      --layout-self-stretch: {\n        -ms-align-self: stretch;\n        -webkit-align-self: stretch;\n        align-self: stretch;\n      };\n\n      --layout-self-baseline: {\n        -ms-align-self: baseline;\n        -webkit-align-self: baseline;\n        align-self: baseline;\n      };\n\n      /* multi-line alignment in main axis */\n\n      --layout-start-aligned: {\n        -ms-flex-line-pack: start;  /* IE10 */\n        -ms-align-content: flex-start;\n        -webkit-align-content: flex-start;\n        align-content: flex-start;\n      };\n\n      --layout-end-aligned: {\n        -ms-flex-line-pack: end;  /* IE10 */\n        -ms-align-content: flex-end;\n        -webkit-align-content: flex-end;\n        align-content: flex-end;\n      };\n\n      --layout-center-aligned: {\n        -ms-flex-line-pack: center;  /* IE10 */\n        -ms-align-content: center;\n        -webkit-align-content: center;\n        align-content: center;\n      };\n\n      --layout-between-aligned: {\n        -ms-flex-line-pack: justify;  /* IE10 */\n        -ms-align-content: space-between;\n        -webkit-align-content: space-between;\n        align-content: space-between;\n      };\n\n      --layout-around-aligned: {\n        -ms-flex-line-pack: distribute;  /* IE10 */\n        -ms-align-content: space-around;\n        -webkit-align-content: space-around;\n        align-content: space-around;\n      };\n\n      /*******************************\n                Other Layout\n      *******************************/\n\n      --layout-block: {\n        display: block;\n      };\n\n      --layout-invisible: {\n        visibility: hidden !important;\n      };\n\n      --layout-relative: {\n        position: relative;\n      };\n\n      --layout-fit: {\n        position: absolute;\n        top: 0;\n        right: 0;\n        bottom: 0;\n        left: 0;\n      };\n\n      --layout-scroll: {\n        -webkit-overflow-scrolling: touch;\n        overflow: auto;\n      };\n\n      --layout-fullbleed: {\n        margin: 0;\n        height: 100vh;\n      };\n\n      /* fixed position */\n\n      --layout-fixed-top: {\n        position: fixed;\n        top: 0;\n        left: 0;\n        right: 0;\n      };\n\n      --layout-fixed-right: {\n        position: fixed;\n        top: 0;\n        right: 0;\n        bottom: 0;\n      };\n\n      --layout-fixed-bottom: {\n        position: fixed;\n        right: 0;\n        bottom: 0;\n        left: 0;\n      };\n\n      --layout-fixed-left: {\n        position: fixed;\n        top: 0;\n        bottom: 0;\n        left: 0;\n      };\n\n    }\n  </style>\n</custom-style>`;\ntemplate.setAttribute('style', 'display: none;');\ndocument.head.appendChild(template.content);\nvar style = document.createElement('style');\nstyle.textContent = '[hidden] { display: none !important; }';\ndocument.head.appendChild(style);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js\n");

/***/ }),

/***/ "./node_modules/@polymer/iron-location/iron-location.js":
/*!**************************************************************!*\
  !*** ./node_modules/@polymer/iron-location/iron-location.js ***!
  \**************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n\nThe `iron-location` element manages binding to and from the current URL.\n\niron-location is the first, and lowest level element in the Polymer team's\nrouting system. This is a beta release of iron-location as we continue work\non higher level elements, and as such iron-location may undergo breaking\nchanges.\n\n#### Properties\n\nWhen the URL is: `/search?query=583#details` iron-location's properties will be:\n\n  - path: `'/search'`\n  - query: `'query=583'`\n  - hash: `'details'`\n\nThese bindings are bidirectional. Modifying them will in turn modify the URL.\n\niron-location is only active while it is attached to the document.\n\n#### Links\n\nWhile iron-location is active in the document it will intercept clicks on links\nwithin your site, updating the URL pushing the updated URL out through the\ndatabinding system. iron-location only intercepts clicks with the intent to\nopen in the same window, so middle mouse clicks and ctrl/cmd clicks work fine.\n\nYou can customize this behavior with the `urlSpaceRegex`.\n\n#### Dwell Time\n\niron-location protects against accidental history spamming by only adding\nentries to the user's history if the URL stays unchanged for `dwellTime`\nmilliseconds.\n\n@demo demo/index.html\n\n */\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__.Polymer)({\n  is: 'iron-location',\n  properties: {\n    /**\n     * The pathname component of the URL.\n     */\n    path: {\n      type: String,\n      notify: true,\n      value: function () {\n        return window.decodeURIComponent(window.location.pathname);\n      }\n    },\n\n    /**\n     * The query string portion of the URL.\n     */\n    query: {\n      type: String,\n      notify: true,\n      value: function () {\n        return window.location.search.slice(1);\n      }\n    },\n\n    /**\n     * The hash component of the URL.\n     */\n    hash: {\n      type: String,\n      notify: true,\n      value: function () {\n        return window.decodeURIComponent(window.location.hash.slice(1));\n      }\n    },\n\n    /**\n     * If the user was on a URL for less than `dwellTime` milliseconds, it\n     * won't be added to the browser's history, but instead will be replaced\n     * by the next entry.\n     *\n     * This is to prevent large numbers of entries from clogging up the user's\n     * browser history. Disable by setting to a negative number.\n     */\n    dwellTime: {\n      type: Number,\n      value: 2000\n    },\n\n    /**\n     * A regexp that defines the set of URLs that should be considered part\n     * of this web app.\n     *\n     * Clicking on a link that matches this regex won't result in a full page\n     * navigation, but will instead just update the URL state in place.\n     *\n     * This regexp is given everything after the origin in an absolute\n     * URL. So to match just URLs that start with /search/ do:\n     *     url-space-regex=\"^/search/\"\n     *\n     * @type {string|RegExp}\n     */\n    urlSpaceRegex: {\n      type: String,\n      value: ''\n    },\n\n    /**\n     * A flag that specifies whether the spaces in query that would normally be\n     * encoded as %20 should be encoded as +.\n     *\n     * Given an example text \"hello world\", it is encoded in query as\n     * - \"hello%20world\" without the parameter\n     * - \"hello+world\" with the parameter\n     */\n    encodeSpaceAsPlusInQuery: {\n      type: Boolean,\n      value: false\n    },\n\n    /**\n     * urlSpaceRegex, but coerced into a regexp.\n     *\n     * @type {RegExp}\n     */\n    _urlSpaceRegExp: {\n      computed: '_makeRegExp(urlSpaceRegex)'\n    },\n    _lastChangedAt: {\n      type: Number\n    },\n    _initialized: {\n      type: Boolean,\n      value: false\n    }\n  },\n  hostAttributes: {\n    hidden: true\n  },\n  observers: ['_updateUrl(path, query, hash)'],\n  created: function () {\n    this.__location = window.location;\n  },\n  attached: function () {\n    this.listen(window, 'hashchange', '_hashChanged');\n    this.listen(window, 'location-changed', '_urlChanged');\n    this.listen(window, 'popstate', '_urlChanged');\n    this.listen(\n    /** @type {!HTMLBodyElement} */\n    document.body, 'click', '_globalOnClick'); // Give a 200ms grace period to make initial redirects without any\n    // additions to the user's history.\n\n    this._lastChangedAt = window.performance.now() - (this.dwellTime - 200);\n    this._initialized = true;\n\n    this._urlChanged();\n  },\n  detached: function () {\n    this.unlisten(window, 'hashchange', '_hashChanged');\n    this.unlisten(window, 'location-changed', '_urlChanged');\n    this.unlisten(window, 'popstate', '_urlChanged');\n    this.unlisten(\n    /** @type {!HTMLBodyElement} */\n    document.body, 'click', '_globalOnClick');\n    this._initialized = false;\n  },\n  _hashChanged: function () {\n    this.hash = window.decodeURIComponent(this.__location.hash.substring(1));\n  },\n  _urlChanged: function () {\n    // We want to extract all info out of the updated URL before we\n    // try to write anything back into it.\n    //\n    // i.e. without _dontUpdateUrl we'd overwrite the new path with the old\n    // one when we set this.hash. Likewise for query.\n    this._dontUpdateUrl = true;\n\n    this._hashChanged();\n\n    this.path = window.decodeURIComponent(this.__location.pathname);\n    this.query = this.__location.search.substring(1);\n    this._dontUpdateUrl = false;\n\n    this._updateUrl();\n  },\n  _getUrl: function () {\n    var partiallyEncodedPath = window.encodeURI(this.path).replace(/\\#/g, '%23').replace(/\\?/g, '%3F');\n    var partiallyEncodedQuery = '';\n\n    if (this.query) {\n      partiallyEncodedQuery = '?' + this.query.replace(/\\#/g, '%23');\n\n      if (this.encodeSpaceAsPlusInQuery) {\n        partiallyEncodedQuery = partiallyEncodedQuery.replace(/\\+/g, '%2B').replace(/ /g, '+').replace(/%20/g, '+');\n      } else {\n        // required for edge\n        partiallyEncodedQuery = partiallyEncodedQuery.replace(/\\+/g, '%2B').replace(/ /g, '%20');\n      }\n    }\n\n    var partiallyEncodedHash = '';\n\n    if (this.hash) {\n      partiallyEncodedHash = '#' + window.encodeURI(this.hash);\n    }\n\n    return partiallyEncodedPath + partiallyEncodedQuery + partiallyEncodedHash;\n  },\n  _updateUrl: function () {\n    if (this._dontUpdateUrl || !this._initialized) {\n      return;\n    }\n\n    if (this.path === window.decodeURIComponent(this.__location.pathname) && this.query === this.__location.search.substring(1) && this.hash === window.decodeURIComponent(this.__location.hash.substring(1))) {\n      // Nothing to do, the current URL is a representation of our properties.\n      return;\n    }\n\n    var newUrl = this._getUrl(); // Need to use a full URL in case the containing page has a base URI.\n\n\n    var fullNewUrl = new URL(newUrl, this.__location.protocol + '//' + this.__location.host).href;\n    var now = window.performance.now();\n    var shouldReplace = this._lastChangedAt + this.dwellTime > now;\n    this._lastChangedAt = now;\n\n    if (shouldReplace) {\n      window.history.replaceState({}, '', fullNewUrl);\n    } else {\n      window.history.pushState({}, '', fullNewUrl);\n    }\n\n    this.fire('location-changed', {}, {\n      node: window\n    });\n  },\n\n  /**\n   * A necessary evil so that links work as expected. Does its best to\n   * bail out early if possible.\n   *\n   * @param {MouseEvent} event .\n   */\n  _globalOnClick: function (event) {\n    // If another event handler has stopped this event then there's nothing\n    // for us to do. This can happen e.g. when there are multiple\n    // iron-location elements in a page.\n    if (event.defaultPrevented) {\n      return;\n    }\n\n    var href = this._getSameOriginLinkHref(event);\n\n    if (!href) {\n      return;\n    }\n\n    event.preventDefault(); // If the navigation is to the current page we shouldn't add a history\n    // entry or fire a change event.\n\n    if (href === this.__location.href) {\n      return;\n    }\n\n    window.history.pushState({}, '', href);\n    this.fire('location-changed', {}, {\n      node: window\n    });\n  },\n\n  /**\n   * Returns the absolute URL of the link (if any) that this click event\n   * is clicking on, if we can and should override the resulting full\n   * page navigation. Returns null otherwise.\n   *\n   * @param {MouseEvent} event .\n   * @return {string?} .\n   */\n  _getSameOriginLinkHref: function (event) {\n    // We only care about left-clicks.\n    if (event.button !== 0) {\n      return null;\n    } // We don't want modified clicks, where the intent is to open the page\n    // in a new tab.\n\n\n    if (event.metaKey || event.ctrlKey) {\n      return null;\n    }\n\n    var eventPath = (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_2__.dom)(event).path;\n    var anchor = null;\n\n    for (var i = 0; i < eventPath.length; i++) {\n      var element = eventPath[i];\n\n      if (element.tagName === 'A' && element.href) {\n        anchor = element;\n        break;\n      }\n    } // If there's no link there's nothing to do.\n\n\n    if (!anchor) {\n      return null;\n    } // Target blank is a new tab, don't intercept.\n\n\n    if (anchor.target === '_blank') {\n      return null;\n    } // If the link is for an existing parent frame, don't intercept.\n\n\n    if ((anchor.target === '_top' || anchor.target === '_parent') && window.top !== window) {\n      return null;\n    } // If the link is a download, don't intercept.\n\n\n    if (anchor.download) {\n      return null;\n    }\n\n    var href = anchor.href; // It only makes sense for us to intercept same-origin navigations.\n    // pushState/replaceState don't work with cross-origin links.\n\n    var url;\n\n    if (document.baseURI != null) {\n      url = new URL(href,\n      /** @type {string} */\n      document.baseURI);\n    } else {\n      url = new URL(href);\n    }\n\n    var origin; // IE Polyfill\n\n    if (this.__location.origin) {\n      origin = this.__location.origin;\n    } else {\n      origin = this.__location.protocol + '//' + this.__location.host;\n    }\n\n    var urlOrigin;\n\n    if (url.origin) {\n      urlOrigin = url.origin;\n    } else {\n      // IE always adds port number on HTTP and HTTPS on <a>.host but not on\n      // window.location.host\n      var urlHost = url.host;\n      var urlPort = url.port;\n      var urlProtocol = url.protocol;\n      var isExtraneousHTTPS = urlProtocol === 'https:' && urlPort === '443';\n      var isExtraneousHTTP = urlProtocol === 'http:' && urlPort === '80';\n\n      if (isExtraneousHTTPS || isExtraneousHTTP) {\n        urlHost = url.hostname;\n      }\n\n      urlOrigin = urlProtocol + '//' + urlHost;\n    }\n\n    if (urlOrigin !== origin) {\n      return null;\n    }\n\n    var normalizedHref = url.pathname + url.search + url.hash; // pathname should start with '/', but may not if `new URL` is not supported\n\n    if (normalizedHref[0] !== '/') {\n      normalizedHref = '/' + normalizedHref;\n    } // If we've been configured not to handle this url... don't handle it!\n\n\n    if (this._urlSpaceRegExp && !this._urlSpaceRegExp.test(normalizedHref)) {\n      return null;\n    } // Need to use a full URL in case the containing page has a base URI.\n\n\n    var fullNormalizedHref = new URL(normalizedHref, this.__location.href).href;\n    return fullNormalizedHref;\n  },\n  _makeRegExp: function (urlSpaceRegex) {\n    return RegExp(urlSpaceRegex);\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/iron-location/iron-location.js\n");

/***/ }),

/***/ "./node_modules/@polymer/iron-location/iron-query-params.js":
/*!******************************************************************!*\
  !*** ./node_modules/@polymer/iron-location/iron-query-params.js ***!
  \******************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n/**\n * @demo demo/iron-query-params.html\n */\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__.Polymer)({\n  is: 'iron-query-params',\n  properties: {\n    /**\n     * @type{string|undefined}\n     */\n    paramsString: {\n      type: String,\n      notify: true,\n      observer: 'paramsStringChanged'\n    },\n\n    /**\n     * @type{Object|undefined}\n     */\n    paramsObject: {\n      type: Object,\n      notify: true\n    },\n    _dontReact: {\n      type: Boolean,\n      value: false\n    }\n  },\n  hostAttributes: {\n    hidden: true\n  },\n  observers: ['paramsObjectChanged(paramsObject.*)'],\n  paramsStringChanged: function () {\n    this._dontReact = true;\n    this.paramsObject = this._decodeParams(this.paramsString);\n    this._dontReact = false;\n  },\n  paramsObjectChanged: function () {\n    if (this._dontReact) {\n      return;\n    }\n\n    this.paramsString = this._encodeParams(this.paramsObject).replace(/%3F/g, '?').replace(/%2F/g, '/').replace(/'/g, '%27');\n  },\n  _encodeParams: function (params) {\n    var encodedParams = [];\n\n    for (var key in params) {\n      var value = params[key];\n\n      if (value === '') {\n        encodedParams.push(encodeURIComponent(key));\n      } else if (value) {\n        encodedParams.push(encodeURIComponent(key) + '=' + encodeURIComponent(value.toString()));\n      }\n    }\n\n    return encodedParams.join('&');\n  },\n  _decodeParams: function (paramString) {\n    var params = {}; // Work around a bug in decodeURIComponent where + is not\n    // converted to spaces:\n\n    paramString = (paramString || '').replace(/\\+/g, '%20');\n    var paramList = paramString.split('&');\n\n    for (var i = 0; i < paramList.length; i++) {\n      var param = paramList[i].split('=');\n\n      if (param[0]) {\n        params[decodeURIComponent(param[0])] = decodeURIComponent(param[1] || '');\n      }\n    }\n\n    return params;\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/iron-location/iron-query-params.js\n");

/***/ }),

/***/ "./node_modules/@polymer/iron-media-query/iron-media-query.js":
/*!********************************************************************!*\
  !*** ./node_modules/@polymer/iron-media-query/iron-media-query.js ***!
  \********************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n/**\n`iron-media-query` can be used to data bind to a CSS media query.\nThe `query` property is a bare CSS media query.\nThe `query-matches` property is a boolean representing whether the page matches\nthat media query.\n\nExample:\n\n```html\n<iron-media-query query=\"(min-width: 600px)\" query-matches=\"{{queryMatches}}\">\n</iron-media-query>\n```\n\n@group Iron Elements\n@demo demo/index.html\n@hero hero.svg\n@element iron-media-query\n*/\n\n(0,_polymer_polymer_lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__.Polymer)({\n  is: 'iron-media-query',\n  properties: {\n    /**\n     * The Boolean return value of the media query.\n     */\n    queryMatches: {\n      type: Boolean,\n      value: false,\n      readOnly: true,\n      notify: true\n    },\n\n    /**\n     * The CSS media query to evaluate.\n     */\n    query: {\n      type: String,\n      observer: 'queryChanged'\n    },\n\n    /**\n     * If true, the query attribute is assumed to be a complete media query\n     * string rather than a single media feature.\n     */\n    full: {\n      type: Boolean,\n      value: false\n    },\n\n    /**\n     * @type {function(MediaQueryList)}\n     */\n    _boundMQHandler: {\n      value: function () {\n        return this.queryHandler.bind(this);\n      }\n    },\n\n    /**\n     * @type {MediaQueryList}\n     */\n    _mq: {\n      value: null\n    }\n  },\n  attached: function () {\n    this.style.display = 'none';\n    this.queryChanged();\n  },\n  detached: function () {\n    this._remove();\n  },\n  _add: function () {\n    if (this._mq) {\n      this._mq.addListener(this._boundMQHandler);\n    }\n  },\n  _remove: function () {\n    if (this._mq) {\n      this._mq.removeListener(this._boundMQHandler);\n    }\n\n    this._mq = null;\n  },\n  queryChanged: function () {\n    this._remove();\n\n    var query = this.query;\n\n    if (!query) {\n      return;\n    }\n\n    if (!this.full && query[0] !== '(') {\n      query = '(' + query + ')';\n    }\n\n    this._mq = window.matchMedia(query);\n\n    this._add();\n\n    this.queryHandler(this._mq);\n  },\n  queryHandler: function (mq) {\n    this._setQueryMatches(mq.matches);\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/iron-media-query/iron-media-query.js\n");

/***/ }),

/***/ "./node_modules/@polymer/iron-resizable-behavior/iron-resizable-behavior.js":
/*!**********************************************************************************!*\
  !*** ./node_modules/@polymer/iron-resizable-behavior/iron-resizable-behavior.js ***!
  \**********************************************************************************/
/*! namespace exports */
/*! export IronResizableBehavior [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"IronResizableBehavior\": () => /* binding */ IronResizableBehavior\n/* harmony export */ });\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/legacy/polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_settings_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\n // Contains all connected resizables that do not have a parent.\n\nvar ORPHANS = new Set();\n/**\n * `IronResizableBehavior` is a behavior that can be used in Polymer elements to\n * coordinate the flow of resize events between \"resizers\" (elements that\n *control the size or hidden state of their children) and \"resizables\" (elements\n *that need to be notified when they are resized or un-hidden by their parents\n *in order to take action on their new measurements).\n *\n * Elements that perform measurement should add the `IronResizableBehavior`\n *behavior to their element definition and listen for the `iron-resize` event on\n *themselves. This event will be fired when they become showing after having\n *been hidden, when they are resized explicitly by another resizable, or when\n *the window has been resized.\n *\n * Note, the `iron-resize` event is non-bubbling.\n *\n * @polymerBehavior\n * @demo demo/index.html\n **/\n\nconst IronResizableBehavior = {\n  properties: {\n    /**\n     * The closest ancestor element that implements `IronResizableBehavior`.\n     */\n    _parentResizable: {\n      type: Object,\n      observer: '_parentResizableChanged'\n    },\n\n    /**\n     * True if this element is currently notifying its descendant elements of\n     * resize.\n     */\n    _notifyingDescendant: {\n      type: Boolean,\n      value: false\n    }\n  },\n  listeners: {\n    'iron-request-resize-notifications': '_onIronRequestResizeNotifications'\n  },\n  created: function () {\n    // We don't really need property effects on these, and also we want them\n    // to be created before the `_parentResizable` observer fires:\n    this._interestedResizables = [];\n    this._boundNotifyResize = this.notifyResize.bind(this);\n    this._boundOnDescendantIronResize = this._onDescendantIronResize.bind(this);\n  },\n  attached: function () {\n    this._requestResizeNotifications();\n  },\n  detached: function () {\n    if (this._parentResizable) {\n      this._parentResizable.stopResizeNotificationsFor(this);\n    } else {\n      ORPHANS.delete(this);\n      window.removeEventListener('resize', this._boundNotifyResize);\n    }\n\n    this._parentResizable = null;\n  },\n\n  /**\n   * Can be called to manually notify a resizable and its descendant\n   * resizables of a resize change.\n   */\n  notifyResize: function () {\n    if (!this.isAttached) {\n      return;\n    }\n\n    this._interestedResizables.forEach(function (resizable) {\n      if (this.resizerShouldNotify(resizable)) {\n        this._notifyDescendant(resizable);\n      }\n    }, this);\n\n    this._fireResize();\n  },\n\n  /**\n   * Used to assign the closest resizable ancestor to this resizable\n   * if the ancestor detects a request for notifications.\n   */\n  assignParentResizable: function (parentResizable) {\n    if (this._parentResizable) {\n      this._parentResizable.stopResizeNotificationsFor(this);\n    }\n\n    this._parentResizable = parentResizable;\n\n    if (parentResizable && parentResizable._interestedResizables.indexOf(this) === -1) {\n      parentResizable._interestedResizables.push(this);\n\n      parentResizable._subscribeIronResize(this);\n    }\n  },\n\n  /**\n   * Used to remove a resizable descendant from the list of descendants\n   * that should be notified of a resize change.\n   */\n  stopResizeNotificationsFor: function (target) {\n    var index = this._interestedResizables.indexOf(target);\n\n    if (index > -1) {\n      this._interestedResizables.splice(index, 1);\n\n      this._unsubscribeIronResize(target);\n    }\n  },\n\n  /**\n   * Subscribe this element to listen to iron-resize events on the given target.\n   *\n   * Preferred over target.listen because the property renamer does not\n   * understand to rename when the target is not specifically \"this\"\n   *\n   * @param {!HTMLElement} target Element to listen to for iron-resize events.\n   */\n  _subscribeIronResize: function (target) {\n    target.addEventListener('iron-resize', this._boundOnDescendantIronResize);\n  },\n\n  /**\n   * Unsubscribe this element from listening to to iron-resize events on the\n   * given target.\n   *\n   * Preferred over target.unlisten because the property renamer does not\n   * understand to rename when the target is not specifically \"this\"\n   *\n   * @param {!HTMLElement} target Element to listen to for iron-resize events.\n   */\n  _unsubscribeIronResize: function (target) {\n    target.removeEventListener('iron-resize', this._boundOnDescendantIronResize);\n  },\n\n  /**\n   * This method can be overridden to filter nested elements that should or\n   * should not be notified by the current element. Return true if an element\n   * should be notified, or false if it should not be notified.\n   *\n   * @param {HTMLElement} element A candidate descendant element that\n   * implements `IronResizableBehavior`.\n   * @return {boolean} True if the `element` should be notified of resize.\n   */\n  resizerShouldNotify: function (element) {\n    return true;\n  },\n  _onDescendantIronResize: function (event) {\n    if (this._notifyingDescendant) {\n      event.stopPropagation();\n      return;\n    } // no need to use this during shadow dom because of event retargeting\n\n\n    if (!_polymer_polymer_lib_utils_settings_js__WEBPACK_IMPORTED_MODULE_2__.useShadow) {\n      this._fireResize();\n    }\n  },\n  _fireResize: function () {\n    this.fire('iron-resize', null, {\n      node: this,\n      bubbles: false\n    });\n  },\n  _onIronRequestResizeNotifications: function (event) {\n    var target =\n    /** @type {!EventTarget} */\n    (0,_polymer_polymer_lib_legacy_polymer_dom_js__WEBPACK_IMPORTED_MODULE_1__.dom)(event).rootTarget;\n\n    if (target === this) {\n      return;\n    }\n\n    target.assignParentResizable(this);\n\n    this._notifyDescendant(target);\n\n    event.stopPropagation();\n  },\n  _parentResizableChanged: function (parentResizable) {\n    if (parentResizable) {\n      window.removeEventListener('resize', this._boundNotifyResize);\n    }\n  },\n  _notifyDescendant: function (descendant) {\n    // NOTE(cdata): In IE10, attached is fired on children first, so it's\n    // important not to notify them if the parent is not attached yet (or\n    // else they will get redundantly notified when the parent attaches).\n    if (!this.isAttached) {\n      return;\n    }\n\n    this._notifyingDescendant = true;\n    descendant.notifyResize();\n    this._notifyingDescendant = false;\n  },\n  _requestResizeNotifications: function () {\n    if (!this.isAttached) {\n      return;\n    }\n\n    if (document.readyState === 'loading') {\n      var _requestResizeNotifications = this._requestResizeNotifications.bind(this);\n\n      document.addEventListener('readystatechange', function readystatechanged() {\n        document.removeEventListener('readystatechange', readystatechanged);\n\n        _requestResizeNotifications();\n      });\n    } else {\n      this._findParent();\n\n      if (!this._parentResizable) {\n        // If this resizable is an orphan, tell other orphans to try to find\n        // their parent again, in case it's this resizable.\n        ORPHANS.forEach(function (orphan) {\n          if (orphan !== this) {\n            orphan._findParent();\n          }\n        }, this);\n        window.addEventListener('resize', this._boundNotifyResize);\n        this.notifyResize();\n      } else {\n        // If this resizable has a parent, tell other child resizables of\n        // that parent to try finding their parent again, in case it's this\n        // resizable.\n        this._parentResizable._interestedResizables.forEach(function (resizable) {\n          if (resizable !== this) {\n            resizable._findParent();\n          }\n        }, this);\n      }\n    }\n  },\n  _findParent: function () {\n    this.assignParentResizable(null);\n    this.fire('iron-request-resize-notifications', null, {\n      node: this,\n      bubbles: true,\n      cancelable: true\n    });\n\n    if (!this._parentResizable) {\n      ORPHANS.add(this);\n    } else {\n      ORPHANS.delete(this);\n    }\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/iron-resizable-behavior/iron-resizable-behavior.js\n");

/***/ }),

/***/ "./node_modules/@polymer/paper-styles/paper-styles.js":
/*!************************************************************!*\
  !*** ./node_modules/@polymer/paper-styles/paper-styles.js ***!
  \************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_iron_flex_layout_iron_flex_layout_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/iron-flex-layout/iron-flex-layout.js */ \"./node_modules/@polymer/iron-flex-layout/iron-flex-layout.js\");\n/* harmony import */ var _shadow_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./shadow.js */ \"./node_modules/@polymer/paper-styles/shadow.js\");\n/* harmony import */ var _typography_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./typography.js */ \"./node_modules/@polymer/paper-styles/typography.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\nThe `<paper-styles>` component provides simple ways to use Material Design CSS\nstyles in your application. The following imports are available:\n\n1.\n[color.js](https://github.com/PolymerElements/paper-styles/blob/master/color.html):\na complete list of the colors defined in the Material Design\n[palette](https://www.google.com/design/spec/style/color.html)\n\n2.\n[default-theme.js](https://github.com/PolymerElements/paper-styles/blob/master/default-theme.html):\ntext, background and accent colors that match the default Material Design theme\n\n3.\n[shadow.js](https://material.io/design/environment/light-shadows.html#shadows):\nMaterial Design\n[elevation](https://material.io/design/environment/light-shadows.html#shadows)\nand shadow styles\n\n4.\n[typography.js](https://github.com/PolymerElements/paper-styles/blob/master/typography.html):\nMaterial Design\n[font](http://www.google.com/design/spec/style/typography.html#typography-styles)\nstyles and sizes\n\n5.\n[demo-pages.js](https://github.com/PolymerElements/paper-styles/blob/master/demo-pages.html):\ngeneric styles used in the PolymerElements demo pages\n\nWe recommend importing each of these individual files, and using the style\nmixins available in each ones, rather than the aggregated `paper-styles.html` as\na whole.\n\n@group Paper Elements\n@pseudoElement paper-styles\n@demo demo/index.html\n*/\n\n\n\n\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/paper-styles/paper-styles.js\n");

/***/ }),

/***/ "./node_modules/@polymer/paper-styles/shadow.js":
/*!******************************************************!*\
  !*** ./node_modules/@polymer/paper-styles/shadow.js ***!
  \******************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n\nconst template = _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__.html`\n<custom-style>\n  <style is=\"custom-style\">\n    html {\n\n      --shadow-transition: {\n        transition: box-shadow 0.28s cubic-bezier(0.4, 0, 0.2, 1);\n      };\n\n      --shadow-none: {\n        box-shadow: none;\n      };\n\n      /* from http://codepen.io/shyndman/pen/c5394ddf2e8b2a5c9185904b57421cdb */\n\n      --shadow-elevation-2dp: {\n        box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14),\n                    0 1px 5px 0 rgba(0, 0, 0, 0.12),\n                    0 3px 1px -2px rgba(0, 0, 0, 0.2);\n      };\n\n      --shadow-elevation-3dp: {\n        box-shadow: 0 3px 4px 0 rgba(0, 0, 0, 0.14),\n                    0 1px 8px 0 rgba(0, 0, 0, 0.12),\n                    0 3px 3px -2px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-4dp: {\n        box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14),\n                    0 1px 10px 0 rgba(0, 0, 0, 0.12),\n                    0 2px 4px -1px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-6dp: {\n        box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14),\n                    0 1px 18px 0 rgba(0, 0, 0, 0.12),\n                    0 3px 5px -1px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-8dp: {\n        box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14),\n                    0 3px 14px 2px rgba(0, 0, 0, 0.12),\n                    0 5px 5px -3px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-12dp: {\n        box-shadow: 0 12px 16px 1px rgba(0, 0, 0, 0.14),\n                    0 4px 22px 3px rgba(0, 0, 0, 0.12),\n                    0 6px 7px -4px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-16dp: {\n        box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14),\n                    0  6px 30px 5px rgba(0, 0, 0, 0.12),\n                    0  8px 10px -5px rgba(0, 0, 0, 0.4);\n      };\n\n      --shadow-elevation-24dp: {\n        box-shadow: 0 24px 38px 3px rgba(0, 0, 0, 0.14),\n                    0 9px 46px 8px rgba(0, 0, 0, 0.12),\n                    0 11px 15px -7px rgba(0, 0, 0, 0.4);\n      };\n    }\n  </style>\n</custom-style>`;\ntemplate.setAttribute('style', 'display: none;');\ndocument.head.appendChild(template.content);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/paper-styles/shadow.js\n");

/***/ }),

/***/ "./node_modules/@polymer/paper-styles/typography.js":
/*!**********************************************************!*\
  !*** ./node_modules/@polymer/paper-styles/typography.js ***!
  \**********************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_polymer_legacy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy.js */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n/*\nTypographic styles are provided matching the Material Design standard styles:\nhttp://www.google.com/design/spec/style/typography.html#typography-standard-styles\n\nNote that these are English/Latin centric styles. You may need to further adjust\nline heights and weights for CJK typesetting. See the notes in the Material\nDesign typography section.\n*/\n\n\n\nconst template = _polymer_polymer_lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__.html`<custom-style>\n  <style is=\"custom-style\">\n    html {\n\n      /* Shared Styles */\n      --paper-font-common-base: {\n        font-family: 'Roboto', 'Noto', sans-serif;\n        -webkit-font-smoothing: antialiased;\n      };\n\n      --paper-font-common-code: {\n        font-family: 'Roboto Mono', 'Consolas', 'Menlo', monospace;\n        -webkit-font-smoothing: antialiased;\n      };\n\n      --paper-font-common-expensive-kerning: {\n        text-rendering: optimizeLegibility;\n      };\n\n      --paper-font-common-nowrap: {\n        white-space: nowrap;\n        overflow: hidden;\n        text-overflow: ellipsis;\n      };\n\n      /* Material Font Styles */\n\n      --paper-font-display4: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 112px;\n        font-weight: 300;\n        letter-spacing: -.044em;\n        line-height: 120px;\n      };\n\n      --paper-font-display3: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 56px;\n        font-weight: 400;\n        letter-spacing: -.026em;\n        line-height: 60px;\n      };\n\n      --paper-font-display2: {\n        @apply --paper-font-common-base;\n\n        font-size: 45px;\n        font-weight: 400;\n        letter-spacing: -.018em;\n        line-height: 48px;\n      };\n\n      --paper-font-display1: {\n        @apply --paper-font-common-base;\n\n        font-size: 34px;\n        font-weight: 400;\n        letter-spacing: -.01em;\n        line-height: 40px;\n      };\n\n      --paper-font-headline: {\n        @apply --paper-font-common-base;\n\n        font-size: 24px;\n        font-weight: 400;\n        letter-spacing: -.012em;\n        line-height: 32px;\n      };\n\n      --paper-font-title: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 20px;\n        font-weight: 500;\n        line-height: 28px;\n      };\n\n      --paper-font-subhead: {\n        @apply --paper-font-common-base;\n\n        font-size: 16px;\n        font-weight: 400;\n        line-height: 24px;\n      };\n\n      --paper-font-body2: {\n        @apply --paper-font-common-base;\n\n        font-size: 14px;\n        font-weight: 500;\n        line-height: 24px;\n      };\n\n      --paper-font-body1: {\n        @apply --paper-font-common-base;\n\n        font-size: 14px;\n        font-weight: 400;\n        line-height: 20px;\n      };\n\n      --paper-font-caption: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 12px;\n        font-weight: 400;\n        letter-spacing: 0.011em;\n        line-height: 20px;\n      };\n\n      --paper-font-menu: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 13px;\n        font-weight: 500;\n        line-height: 24px;\n      };\n\n      --paper-font-button: {\n        @apply --paper-font-common-base;\n        @apply --paper-font-common-nowrap;\n\n        font-size: 14px;\n        font-weight: 500;\n        letter-spacing: 0.018em;\n        line-height: 24px;\n        text-transform: uppercase;\n      };\n\n      --paper-font-code2: {\n        @apply --paper-font-common-code;\n\n        font-size: 14px;\n        font-weight: 700;\n        line-height: 20px;\n      };\n\n      --paper-font-code1: {\n        @apply --paper-font-common-code;\n\n        font-size: 14px;\n        font-weight: 500;\n        line-height: 20px;\n      };\n\n    }\n\n  </style>\n</custom-style>`;\ntemplate.setAttribute('style', 'display: none;');\ndocument.head.appendChild(template.content);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/paper-styles/typography.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/array-selector.js":
/*!**********************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/array-selector.js ***!
  \**********************************************************************/
/*! namespace exports */
/*! export ArraySelector [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ArraySelectorMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"ArraySelectorMixin\": () => /* binding */ ArraySelectorMixin,\n/* harmony export */   \"ArraySelector\": () => /* binding */ ArraySelector\n/* harmony export */ });\n/* harmony import */ var _polymer_element_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../polymer-element.js */ \"./node_modules/@polymer/polymer/polymer-element.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_array_splice_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/array-splice.js */ \"./node_modules/@polymer/polymer/lib/utils/array-splice.js\");\n/* harmony import */ var _mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../mixins/element-mixin.js */ \"./node_modules/@polymer/polymer/lib/mixins/element-mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n/**\n * Element mixin for recording dynamic associations between item paths in a\n * master `items` array and a `selected` array such that path changes to the\n * master array (at the host) element or elsewhere via data-binding) are\n * correctly propagated to items in the selected array and vice-versa.\n *\n * The `items` property accepts an array of user data, and via the\n * `select(item)` and `deselect(item)` API, updates the `selected` property\n * which may be bound to other parts of the application, and any changes to\n * sub-fields of `selected` item(s) will be kept in sync with items in the\n * `items` array.  When `multi` is false, `selected` is a property\n * representing the last selected item.  When `multi` is true, `selected`\n * is an array of multiply selected items.\n *\n * @polymer\n * @mixinFunction\n * @appliesMixin ElementMixin\n * @summary Element mixin for recording dynamic associations between item paths in a\n * master `items` array and a `selected` array\n */\n\nlet ArraySelectorMixin = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(superClass => {\n  /**\n   * @constructor\n   * @extends {superClass}\n   * @implements {Polymer_ElementMixin}\n   * @private\n   */\n  let elementBase = (0,_mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_3__.ElementMixin)(superClass);\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_ArraySelectorMixin}\n   * @unrestricted\n   */\n\n  class ArraySelectorMixin extends elementBase {\n    static get properties() {\n      return {\n        /**\n         * An array containing items from which selection will be made.\n         */\n        items: {\n          type: Array\n        },\n\n        /**\n         * When `true`, multiple items may be selected at once (in this case,\n         * `selected` is an array of currently selected items).  When `false`,\n         * only one item may be selected at a time.\n         */\n        multi: {\n          type: Boolean,\n          value: false\n        },\n\n        /**\n         * When `multi` is true, this is an array that contains any selected.\n         * When `multi` is false, this is the currently selected item, or `null`\n         * if no item is selected.\n         * @type {?(Object|Array<!Object>)}\n         */\n        selected: {\n          type: Object,\n          notify: true\n        },\n\n        /**\n         * When `multi` is false, this is the currently selected item, or `null`\n         * if no item is selected.\n         * @type {?Object}\n         */\n        selectedItem: {\n          type: Object,\n          notify: true\n        },\n\n        /**\n         * When `true`, calling `select` on an item that is already selected\n         * will deselect the item.\n         */\n        toggle: {\n          type: Boolean,\n          value: false\n        }\n      };\n    }\n\n    static get observers() {\n      return ['__updateSelection(multi, items.*)'];\n    }\n\n    constructor() {\n      super();\n      this.__lastItems = null;\n      this.__lastMulti = null;\n      this.__selectedMap = null;\n    }\n\n    __updateSelection(multi, itemsInfo) {\n      let path = itemsInfo.path;\n\n      if (path == 'items') {\n        // Case 1 - items array changed, so diff against previous array and\n        // deselect any removed items and adjust selected indices\n        let newItems = itemsInfo.base || [];\n        let lastItems = this.__lastItems;\n        let lastMulti = this.__lastMulti;\n\n        if (multi !== lastMulti) {\n          this.clearSelection();\n        }\n\n        if (lastItems) {\n          let splices = (0,_utils_array_splice_js__WEBPACK_IMPORTED_MODULE_2__.calculateSplices)(newItems, lastItems);\n\n          this.__applySplices(splices);\n        }\n\n        this.__lastItems = newItems;\n        this.__lastMulti = multi;\n      } else if (itemsInfo.path == 'items.splices') {\n        // Case 2 - got specific splice information describing the array mutation:\n        // deselect any removed items and adjust selected indices\n        this.__applySplices(itemsInfo.value.indexSplices);\n      } else {\n        // Case 3 - an array element was changed, so deselect the previous\n        // item for that index if it was previously selected\n        let part = path.slice('items.'.length);\n        let idx = parseInt(part, 10);\n\n        if (part.indexOf('.') < 0 && part == idx) {\n          this.__deselectChangedIdx(idx);\n        }\n      }\n    }\n\n    __applySplices(splices) {\n      let selected = this.__selectedMap; // Adjust selected indices and mark removals\n\n      for (let i = 0; i < splices.length; i++) {\n        let s = splices[i];\n        selected.forEach((idx, item) => {\n          if (idx < s.index) {// no change\n          } else if (idx >= s.index + s.removed.length) {\n            // adjust index\n            selected.set(item, idx + s.addedCount - s.removed.length);\n          } else {\n            // remove index\n            selected.set(item, -1);\n          }\n        });\n\n        for (let j = 0; j < s.addedCount; j++) {\n          let idx = s.index + j;\n\n          if (selected.has(this.items[idx])) {\n            selected.set(this.items[idx], idx);\n          }\n        }\n      } // Update linked paths\n\n\n      this.__updateLinks(); // Remove selected items that were removed from the items array\n\n\n      let sidx = 0;\n      selected.forEach((idx, item) => {\n        if (idx < 0) {\n          if (this.multi) {\n            this.splice('selected', sidx, 1);\n          } else {\n            this.selected = this.selectedItem = null;\n          }\n\n          selected.delete(item);\n        } else {\n          sidx++;\n        }\n      });\n    }\n\n    __updateLinks() {\n      this.__dataLinkedPaths = {};\n\n      if (this.multi) {\n        let sidx = 0;\n\n        this.__selectedMap.forEach(idx => {\n          if (idx >= 0) {\n            this.linkPaths('items.' + idx, 'selected.' + sidx++);\n          }\n        });\n      } else {\n        this.__selectedMap.forEach(idx => {\n          this.linkPaths('selected', 'items.' + idx);\n          this.linkPaths('selectedItem', 'items.' + idx);\n        });\n      }\n    }\n    /**\n     * Clears the selection state.\n     * @return {void}\n     */\n\n\n    clearSelection() {\n      // Unbind previous selection\n      this.__dataLinkedPaths = {}; // The selected map stores 3 pieces of information:\n      // key: items array object\n      // value: items array index\n      // order: selected array index\n\n      this.__selectedMap = new Map(); // Initialize selection\n\n      this.selected = this.multi ? [] : null;\n      this.selectedItem = null;\n    }\n    /**\n     * Returns whether the item is currently selected.\n     *\n     * @param {*} item Item from `items` array to test\n     * @return {boolean} Whether the item is selected\n     */\n\n\n    isSelected(item) {\n      return this.__selectedMap.has(item);\n    }\n    /**\n     * Returns whether the item is currently selected.\n     *\n     * @param {number} idx Index from `items` array to test\n     * @return {boolean} Whether the item is selected\n     */\n\n\n    isIndexSelected(idx) {\n      return this.isSelected(this.items[idx]);\n    }\n\n    __deselectChangedIdx(idx) {\n      let sidx = this.__selectedIndexForItemIndex(idx);\n\n      if (sidx >= 0) {\n        let i = 0;\n\n        this.__selectedMap.forEach((idx, item) => {\n          if (sidx == i++) {\n            this.deselect(item);\n          }\n        });\n      }\n    }\n\n    __selectedIndexForItemIndex(idx) {\n      let selected = this.__dataLinkedPaths['items.' + idx];\n\n      if (selected) {\n        return parseInt(selected.slice('selected.'.length), 10);\n      }\n    }\n    /**\n     * Deselects the given item if it is already selected.\n     *\n     * @param {*} item Item from `items` array to deselect\n     * @return {void}\n     */\n\n\n    deselect(item) {\n      let idx = this.__selectedMap.get(item);\n\n      if (idx >= 0) {\n        this.__selectedMap.delete(item);\n\n        let sidx;\n\n        if (this.multi) {\n          sidx = this.__selectedIndexForItemIndex(idx);\n        }\n\n        this.__updateLinks();\n\n        if (this.multi) {\n          this.splice('selected', sidx, 1);\n        } else {\n          this.selected = this.selectedItem = null;\n        }\n      }\n    }\n    /**\n     * Deselects the given index if it is already selected.\n     *\n     * @param {number} idx Index from `items` array to deselect\n     * @return {void}\n     */\n\n\n    deselectIndex(idx) {\n      this.deselect(this.items[idx]);\n    }\n    /**\n     * Selects the given item.  When `toggle` is true, this will automatically\n     * deselect the item if already selected.\n     *\n     * @param {*} item Item from `items` array to select\n     * @return {void}\n     */\n\n\n    select(item) {\n      this.selectIndex(this.items.indexOf(item));\n    }\n    /**\n     * Selects the given index.  When `toggle` is true, this will automatically\n     * deselect the item if already selected.\n     *\n     * @param {number} idx Index from `items` array to select\n     * @return {void}\n     */\n\n\n    selectIndex(idx) {\n      let item = this.items[idx];\n\n      if (!this.isSelected(item)) {\n        if (!this.multi) {\n          this.__selectedMap.clear();\n        }\n\n        this.__selectedMap.set(item, idx);\n\n        this.__updateLinks();\n\n        if (this.multi) {\n          this.push('selected', item);\n        } else {\n          this.selected = this.selectedItem = item;\n        }\n      } else if (this.toggle) {\n        this.deselectIndex(idx);\n      }\n    }\n\n  }\n\n  return ArraySelectorMixin;\n}); // export mixin\n\n\n/**\n * @constructor\n * @extends {PolymerElement}\n * @implements {Polymer_ArraySelectorMixin}\n * @private\n */\n\nlet baseArraySelector = ArraySelectorMixin(_polymer_element_js__WEBPACK_IMPORTED_MODULE_0__.PolymerElement);\n/**\n * Element implementing the `ArraySelector` mixin, which records\n * dynamic associations between item paths in a master `items` array and a\n * `selected` array such that path changes to the master array (at the host)\n * element or elsewhere via data-binding) are correctly propagated to items\n * in the selected array and vice-versa.\n *\n * The `items` property accepts an array of user data, and via the\n * `select(item)` and `deselect(item)` API, updates the `selected` property\n * which may be bound to other parts of the application, and any changes to\n * sub-fields of `selected` item(s) will be kept in sync with items in the\n * `items` array.  When `multi` is false, `selected` is a property\n * representing the last selected item.  When `multi` is true, `selected`\n * is an array of multiply selected items.\n *\n * Example:\n *\n * ```js\n * import {PolymerElement} from '@polymer/polymer';\n * import '@polymer/polymer/lib/elements/array-selector.js';\n *\n * class EmployeeList extends PolymerElement {\n *   static get _template() {\n *     return html`\n *         <div> Employee list: </div>\n *         <dom-repeat id=\"employeeList\" items=\"{{employees}}\">\n *           <template>\n *             <div>First name: <span>{{item.first}}</span></div>\n *               <div>Last name: <span>{{item.last}}</span></div>\n *               <button on-click=\"toggleSelection\">Select</button>\n *           </template>\n *         </dom-repeat>\n *\n *         <array-selector id=\"selector\"\n *                         items=\"{{employees}}\"\n *                         selected=\"{{selected}}\"\n *                         multi toggle></array-selector>\n *\n *         <div> Selected employees: </div>\n *         <dom-repeat items=\"{{selected}}\">\n *           <template>\n *             <div>First name: <span>{{item.first}}</span></div>\n *             <div>Last name: <span>{{item.last}}</span></div>\n *           </template>\n *         </dom-repeat>`;\n *   }\n *   static get is() { return 'employee-list'; }\n *   static get properties() {\n *     return {\n *       employees: {\n *         value() {\n *           return [\n *             {first: 'Bob', last: 'Smith'},\n *             {first: 'Sally', last: 'Johnson'},\n *             ...\n *           ];\n *         }\n *       }\n *     };\n *   }\n *   toggleSelection(e) {\n *     const item = this.$.employeeList.itemForElement(e.target);\n *     this.$.selector.select(item);\n *   }\n * }\n * ```\n *\n * @polymer\n * @customElement\n * @extends {baseArraySelector}\n * @appliesMixin ArraySelectorMixin\n * @summary Custom element that links paths between an input `items` array and\n *   an output `selected` item or array based on calls to its selection API.\n */\n\nclass ArraySelector extends baseArraySelector {\n  // Not needed to find template; can be removed once the analyzer\n  // can find the tag name from customElements.define call\n  static get is() {\n    return 'array-selector';\n  }\n\n}\n\ncustomElements.define(ArraySelector.is, ArraySelector);\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/array-selector.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/custom-style.js":
/*!********************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/custom-style.js ***!
  \********************************************************************/
/*! namespace exports */
/*! export CustomStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"CustomStyle\": () => /* binding */ CustomStyle\n/* harmony export */ });\n/* harmony import */ var _webcomponents_shadycss_entrypoints_custom_style_interface_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @webcomponents/shadycss/entrypoints/custom-style-interface.js */ \"./node_modules/@webcomponents/shadycss/entrypoints/custom-style-interface.js\");\n/* harmony import */ var _utils_style_gather_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/style-gather.js */ \"./node_modules/@polymer/polymer/lib/utils/style-gather.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\nconst attr = 'include';\nconst CustomStyleInterface = window.ShadyCSS.CustomStyleInterface;\n/**\n * Custom element for defining styles in the main document that can take\n * advantage of [shady DOM](https://github.com/webcomponents/shadycss) shims\n * for style encapsulation, custom properties, and custom mixins.\n *\n * - Document styles defined in a `<custom-style>` are shimmed to ensure they\n *   do not leak into local DOM when running on browsers without native\n *   Shadow DOM.\n * - Custom properties can be defined in a `<custom-style>`. Use the `html` selector\n *   to define custom properties that apply to all custom elements.\n * - Custom mixins can be defined in a `<custom-style>`, if you import the optional\n *   [apply shim](https://github.com/webcomponents/shadycss#about-applyshim)\n *   (`shadycss/apply-shim.html`).\n *\n * To use:\n *\n * - Import `custom-style.html`.\n * - Place a `<custom-style>` element in the main document, wrapping an inline `<style>` tag that\n *   contains the CSS rules you want to shim.\n *\n * For example:\n *\n * ```html\n * <!-- import apply shim--only required if using mixins -->\n * <link rel=\"import\" href=\"bower_components/shadycss/apply-shim.html\">\n * <!-- import custom-style element -->\n * <link rel=\"import\" href=\"bower_components/polymer/lib/elements/custom-style.html\">\n *\n * <custom-style>\n *   <style>\n *     html {\n *       --custom-color: blue;\n *       --custom-mixin: {\n *         font-weight: bold;\n *         color: red;\n *       };\n *     }\n *   </style>\n * </custom-style>\n * ```\n *\n * @customElement\n * @extends HTMLElement\n * @summary Custom element for defining styles in the main document that can\n *   take advantage of Polymer's style scoping and custom properties shims.\n */\n\nclass CustomStyle extends HTMLElement {\n  constructor() {\n    super();\n    this._style = null;\n    CustomStyleInterface.addCustomStyle(this);\n  }\n  /**\n   * Returns the light-DOM `<style>` child this element wraps.  Upon first\n   * call any style modules referenced via the `include` attribute will be\n   * concatenated to this element's `<style>`.\n   *\n   * @export\n   * @return {HTMLStyleElement} This element's light-DOM `<style>`\n   */\n\n\n  getStyle() {\n    if (this._style) {\n      return this._style;\n    }\n\n    const style =\n    /** @type {HTMLStyleElement} */\n    this.querySelector('style');\n\n    if (!style) {\n      return null;\n    }\n\n    this._style = style;\n    const include = style.getAttribute(attr);\n\n    if (include) {\n      style.removeAttribute(attr);\n      style.textContent = (0,_utils_style_gather_js__WEBPACK_IMPORTED_MODULE_1__.cssFromModules)(include) + style.textContent;\n    }\n    /*\n    HTML Imports styling the main document are deprecated in Chrome\n    https://crbug.com/523952\n     If this element is not in the main document, then it must be in an HTML Import document.\n    In that case, move the custom style to the main document.\n     The ordering of `<custom-style>` should stay the same as when loaded by HTML Imports, but there may be odd\n    cases of ordering w.r.t the main document styles.\n    */\n\n\n    if (this.ownerDocument !== window.document) {\n      window.document.head.appendChild(this);\n    }\n\n    return this._style;\n  }\n\n}\nwindow.customElements.define('custom-style', CustomStyle);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/custom-style.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/dom-bind.js":
/*!****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/dom-bind.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export DomBind [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DomBind\": () => /* binding */ DomBind\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _mixins_property_effects_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../mixins/property-effects.js */ \"./node_modules/@polymer/polymer/lib/mixins/property-effects.js\");\n/* harmony import */ var _mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../mixins/mutable-data.js */ \"./node_modules/@polymer/polymer/lib/mixins/mutable-data.js\");\n/* harmony import */ var _mixins_gesture_event_listeners_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../mixins/gesture-event-listeners.js */ \"./node_modules/@polymer/polymer/lib/mixins/gesture-event-listeners.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n/**\n * @constructor\n * @extends {HTMLElement}\n * @implements {Polymer_PropertyEffects}\n * @implements {Polymer_OptionalMutableData}\n * @implements {Polymer_GestureEventListeners}\n * @private\n */\n\nconst domBindBase = (0,_mixins_gesture_event_listeners_js__WEBPACK_IMPORTED_MODULE_3__.GestureEventListeners)((0,_mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_2__.OptionalMutableData)((0,_mixins_property_effects_js__WEBPACK_IMPORTED_MODULE_1__.PropertyEffects)(HTMLElement)));\n/**\n * Custom element to allow using Polymer's template features (data binding,\n * declarative event listeners, etc.) in the main document without defining\n * a new custom element.\n *\n * `<template>` tags utilizing bindings may be wrapped with the `<dom-bind>`\n * element, which will immediately stamp the wrapped template into the main\n * document and bind elements to the `dom-bind` element itself as the\n * binding scope.\n *\n * @polymer\n * @customElement\n * @appliesMixin PropertyEffects\n * @appliesMixin OptionalMutableData\n * @appliesMixin GestureEventListeners\n * @extends {domBindBase}\n * @summary Custom element to allow using Polymer's template features (data\n *   binding, declarative event listeners, etc.) in the main document.\n */\n\nclass DomBind extends domBindBase {\n  static get observedAttributes() {\n    return ['mutable-data'];\n  }\n\n  constructor() {\n    super();\n\n    if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_4__.strictTemplatePolicy) {\n      throw new Error(`strictTemplatePolicy: dom-bind not allowed`);\n    }\n\n    this.root = null;\n    this.$ = null;\n    this.__children = null;\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  attributeChangedCallback() {\n    // assumes only one observed attribute\n    this.mutableData = true;\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  connectedCallback() {\n    this.style.display = 'none';\n    this.render();\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  disconnectedCallback() {\n    this.__removeChildren();\n  }\n\n  __insertChildren() {\n    this.parentNode.insertBefore(this.root, this);\n  }\n\n  __removeChildren() {\n    if (this.__children) {\n      for (let i = 0; i < this.__children.length; i++) {\n        this.root.appendChild(this.__children[i]);\n      }\n    }\n  }\n  /**\n   * Forces the element to render its content. This is typically only\n   * necessary to call if HTMLImports with the async attribute are used.\n   * @return {void}\n   */\n\n\n  render() {\n    let template;\n\n    if (!this.__children) {\n      template =\n      /** @type {HTMLTemplateElement} */\n      template || this.querySelector('template');\n\n      if (!template) {\n        // Wait until childList changes and template should be there by then\n        let observer = new MutationObserver(() => {\n          template =\n          /** @type {HTMLTemplateElement} */\n          this.querySelector('template');\n\n          if (template) {\n            observer.disconnect();\n            this.render();\n          } else {\n            throw new Error('dom-bind requires a <template> child');\n          }\n        });\n        observer.observe(this, {\n          childList: true\n        });\n        return;\n      }\n\n      this.root = this._stampTemplate(\n      /** @type {!HTMLTemplateElement} */\n      template);\n      this.$ = this.root.$;\n      this.__children = [];\n\n      for (let n = this.root.firstChild; n; n = n.nextSibling) {\n        this.__children[this.__children.length] = n;\n      }\n\n      this._enableProperties();\n    }\n\n    this.__insertChildren();\n\n    this.dispatchEvent(new CustomEvent('dom-change', {\n      bubbles: true,\n      composed: true\n    }));\n  }\n\n}\ncustomElements.define('dom-bind', DomBind);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/dom-bind.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/dom-if.js":
/*!**************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/dom-if.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export DomIf [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DomIf\": () => /* binding */ DomIf\n/* harmony export */ });\n/* harmony import */ var _polymer_element_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../polymer-element.js */ \"./node_modules/@polymer/polymer/polymer-element.js\");\n/* harmony import */ var _utils_templatize_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/templatize.js */ \"./node_modules/@polymer/polymer/lib/utils/templatize.js\");\n/* harmony import */ var _utils_debounce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/* harmony import */ var _utils_flush_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/flush.js */ \"./node_modules/@polymer/polymer/lib/utils/flush.js\");\n/* harmony import */ var _utils_async_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../utils/async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/* harmony import */ var _utils_path_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../utils/path.js */ \"./node_modules/@polymer/polymer/lib/utils/path.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n/**\n * The `<dom-if>` element will stamp a light-dom `<template>` child when\n * the `if` property becomes truthy, and the template can use Polymer\n * data-binding and declarative event features when used in the context of\n * a Polymer element's template.\n *\n * When `if` becomes falsy, the stamped content is hidden but not\n * removed from dom. When `if` subsequently becomes truthy again, the content\n * is simply re-shown. This approach is used due to its favorable performance\n * characteristics: the expense of creating template content is paid only\n * once and lazily.\n *\n * Set the `restamp` property to true to force the stamped content to be\n * created / destroyed when the `if` condition changes.\n *\n * @customElement\n * @polymer\n * @extends PolymerElement\n * @summary Custom element that conditionally stamps and hides or removes\n *   template content based on a boolean flag.\n */\n\nclass DomIf extends _polymer_element_js__WEBPACK_IMPORTED_MODULE_0__.PolymerElement {\n  // Not needed to find template; can be removed once the analyzer\n  // can find the tag name from customElements.define call\n  static get is() {\n    return 'dom-if';\n  }\n\n  static get template() {\n    return null;\n  }\n\n  static get properties() {\n    return {\n      /**\n       * Fired whenever DOM is added or removed/hidden by this template (by\n       * default, rendering occurs lazily).  To force immediate rendering, call\n       * `render`.\n       *\n       * @event dom-change\n       */\n\n      /**\n       * A boolean indicating whether this template should stamp.\n       */\n      if: {\n        type: Boolean,\n        observer: '__debounceRender'\n      },\n\n      /**\n       * When true, elements will be removed from DOM and discarded when `if`\n       * becomes false and re-created and added back to the DOM when `if`\n       * becomes true.  By default, stamped elements will be hidden but left\n       * in the DOM when `if` becomes false, which is generally results\n       * in better performance.\n       */\n      restamp: {\n        type: Boolean,\n        observer: '__debounceRender'\n      }\n    };\n  }\n\n  constructor() {\n    super();\n    this.__renderDebouncer = null;\n    this.__invalidProps = null;\n    this.__instance = null;\n    this._lastIf = false;\n    this.__ctor = null;\n    this.__hideTemplateChildren__ = false;\n  }\n\n  __debounceRender() {\n    // Render is async for 2 reasons:\n    // 1. To eliminate dom creation trashing if user code thrashes `if` in the\n    //    same turn. This was more common in 1.x where a compound computed\n    //    property could result in the result changing multiple times, but is\n    //    mitigated to a large extent by batched property processing in 2.x.\n    // 2. To avoid double object propagation when a bag including values bound\n    //    to the `if` property as well as one or more hostProps could enqueue\n    //    the <dom-if> to flush before the <template>'s host property\n    //    forwarding. In that scenario creating an instance would result in\n    //    the host props being set once, and then the enqueued changes on the\n    //    template would set properties a second time, potentially causing an\n    //    object to be set to an instance more than once.  Creating the\n    //    instance async from flushing data ensures this doesn't happen. If\n    //    we wanted a sync option in the future, simply having <dom-if> flush\n    //    (or clear) its template's pending host properties before creating\n    //    the instance would also avoid the problem.\n    this.__renderDebouncer = _utils_debounce_js__WEBPACK_IMPORTED_MODULE_2__.Debouncer.debounce(this.__renderDebouncer, _utils_async_js__WEBPACK_IMPORTED_MODULE_4__.microTask, () => this.__render());\n    (0,_utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.enqueueDebouncer)(this.__renderDebouncer);\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  disconnectedCallback() {\n    super.disconnectedCallback();\n\n    if (!this.parentNode || this.parentNode.nodeType == Node.DOCUMENT_FRAGMENT_NODE && !this.parentNode.host) {\n      this.__teardownInstance();\n    }\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  connectedCallback() {\n    super.connectedCallback();\n    this.style.display = 'none';\n\n    if (this.if) {\n      this.__debounceRender();\n    }\n  }\n  /**\n   * Forces the element to render its content. Normally rendering is\n   * asynchronous to a provoking change. This is done for efficiency so\n   * that multiple changes trigger only a single render. The render method\n   * should be called if, for example, template rendering is required to\n   * validate application state.\n   * @return {void}\n   */\n\n\n  render() {\n    (0,_utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.flush)();\n  }\n\n  __render() {\n    if (this.if) {\n      if (!this.__ensureInstance()) {\n        // No template found yet\n        return;\n      }\n\n      this._showHideChildren();\n    } else if (this.restamp) {\n      this.__teardownInstance();\n    }\n\n    if (!this.restamp && this.__instance) {\n      this._showHideChildren();\n    }\n\n    if (this.if != this._lastIf) {\n      this.dispatchEvent(new CustomEvent('dom-change', {\n        bubbles: true,\n        composed: true\n      }));\n      this._lastIf = this.if;\n    }\n  }\n\n  __ensureInstance() {\n    let parentNode = this.parentNode; // Guard against element being detached while render was queued\n\n    if (parentNode) {\n      if (!this.__ctor) {\n        let template =\n        /** @type {HTMLTemplateElement} */\n        this.querySelector('template');\n\n        if (!template) {\n          // Wait until childList changes and template should be there by then\n          let observer = new MutationObserver(() => {\n            if (this.querySelector('template')) {\n              observer.disconnect();\n\n              this.__render();\n            } else {\n              throw new Error('dom-if requires a <template> child');\n            }\n          });\n          observer.observe(this, {\n            childList: true\n          });\n          return false;\n        }\n\n        this.__ctor = (0,_utils_templatize_js__WEBPACK_IMPORTED_MODULE_1__.templatize)(template, this, {\n          // dom-if templatizer instances require `mutable: true`, as\n          // `__syncHostProperties` relies on that behavior to sync objects\n          mutableData: true,\n\n          /**\n           * @param {string} prop Property to forward\n           * @param {*} value Value of property\n           * @this {DomIf}\n           */\n          forwardHostProp: function (prop, value) {\n            if (this.__instance) {\n              if (this.if) {\n                this.__instance.forwardHostProp(prop, value);\n              } else {\n                // If we have an instance but are squelching host property\n                // forwarding due to if being false, note the invalidated\n                // properties so `__syncHostProperties` can sync them the next\n                // time `if` becomes true\n                this.__invalidProps = this.__invalidProps || Object.create(null);\n                this.__invalidProps[(0,_utils_path_js__WEBPACK_IMPORTED_MODULE_5__.root)(prop)] = true;\n              }\n            }\n          }\n        });\n      }\n\n      if (!this.__instance) {\n        this.__instance = new this.__ctor();\n        parentNode.insertBefore(this.__instance.root, this);\n      } else {\n        this.__syncHostProperties();\n\n        let c$ = this.__instance.children;\n\n        if (c$ && c$.length) {\n          // Detect case where dom-if was re-attached in new position\n          let lastChild = this.previousSibling;\n\n          if (lastChild !== c$[c$.length - 1]) {\n            for (let i = 0, n; i < c$.length && (n = c$[i]); i++) {\n              parentNode.insertBefore(n, this);\n            }\n          }\n        }\n      }\n    }\n\n    return true;\n  }\n\n  __syncHostProperties() {\n    let props = this.__invalidProps;\n\n    if (props) {\n      for (let prop in props) {\n        this.__instance._setPendingProperty(prop, this.__dataHost[prop]);\n      }\n\n      this.__invalidProps = null;\n\n      this.__instance._flushProperties();\n    }\n  }\n\n  __teardownInstance() {\n    if (this.__instance) {\n      let c$ = this.__instance.children;\n\n      if (c$ && c$.length) {\n        // use first child parent, for case when dom-if may have been detached\n        let parent = c$[0].parentNode; // Instance children may be disconnected from parents when dom-if\n        // detaches if a tree was innerHTML'ed\n\n        if (parent) {\n          for (let i = 0, n; i < c$.length && (n = c$[i]); i++) {\n            parent.removeChild(n);\n          }\n        }\n      }\n\n      this.__instance = null;\n      this.__invalidProps = null;\n    }\n  }\n  /**\n   * Shows or hides the template instance top level child elements. For\n   * text nodes, `textContent` is removed while \"hidden\" and replaced when\n   * \"shown.\"\n   * @return {void}\n   * @protected\n   * @suppress {visibility}\n   */\n\n\n  _showHideChildren() {\n    let hidden = this.__hideTemplateChildren__ || !this.if;\n\n    if (this.__instance) {\n      this.__instance._showHideChildren(hidden);\n    }\n  }\n\n}\ncustomElements.define(DomIf.is, DomIf);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/dom-if.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/dom-module.js":
/*!******************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/dom-module.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export DomModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DomModule\": () => /* binding */ DomModule\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/resolve-url.js */ \"./node_modules/@polymer/polymer/lib/utils/resolve-url.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\nlet modules = {};\nlet lcModules = {};\n/**\n * Sets a dom-module into the global registry by id.\n *\n * @param {string} id dom-module id\n * @param {DomModule} module dom-module instance\n * @return {void}\n */\n\nfunction setModule(id, module) {\n  // store id separate from lowercased id so that\n  // in all cases mixedCase id will stored distinctly\n  // and lowercase version is a fallback\n  modules[id] = lcModules[id.toLowerCase()] = module;\n}\n/**\n * Retrieves a dom-module from the global registry by id.\n *\n * @param {string} id dom-module id\n * @return {DomModule!} dom-module instance\n */\n\n\nfunction findModule(id) {\n  return modules[id] || lcModules[id.toLowerCase()];\n}\n\nfunction styleOutsideTemplateCheck(inst) {\n  if (inst.querySelector('style')) {\n    console.warn('dom-module %s has style outside template', inst.id);\n  }\n}\n/**\n * The `dom-module` element registers the dom it contains to the name given\n * by the module's id attribute. It provides a unified database of dom\n * accessible via its static `import` API.\n *\n * A key use case of `dom-module` is for providing custom element `<template>`s\n * via HTML imports that are parsed by the native HTML parser, that can be\n * relocated during a bundling pass and still looked up by `id`.\n *\n * Example:\n *\n *     <dom-module id=\"foo\">\n *       <img src=\"stuff.png\">\n *     </dom-module>\n *\n * Then in code in some other location that cannot access the dom-module above\n *\n *     let img = customElements.get('dom-module').import('foo', 'img');\n *\n * @customElement\n * @extends HTMLElement\n * @summary Custom element that provides a registry of relocatable DOM content\n *   by `id` that is agnostic to bundling.\n * @unrestricted\n */\n\n\nclass DomModule extends HTMLElement {\n  static get observedAttributes() {\n    return ['id'];\n  }\n  /**\n   * Retrieves the element specified by the css `selector` in the module\n   * registered by `id`. For example, this.import('foo', 'img');\n   * @param {string} id The id of the dom-module in which to search.\n   * @param {string=} selector The css selector by which to find the element.\n   * @return {Element} Returns the element which matches `selector` in the\n   * module registered at the specified `id`.\n   *\n   * @export\n   * @nocollapse Referred to indirectly in style-gather.js\n   */\n\n\n  static import(id, selector) {\n    if (id) {\n      let m = findModule(id);\n\n      if (m && selector) {\n        return m.querySelector(selector);\n      }\n\n      return m;\n    }\n\n    return null;\n  }\n  /* eslint-disable no-unused-vars */\n\n  /**\n   * @param {string} name Name of attribute.\n   * @param {?string} old Old value of attribute.\n   * @param {?string} value Current value of attribute.\n   * @param {?string} namespace Attribute namespace.\n   * @return {void}\n   * @override\n   */\n\n\n  attributeChangedCallback(name, old, value, namespace) {\n    if (old !== value) {\n      this.register();\n    }\n  }\n  /* eslint-enable no-unused-args */\n\n  /**\n   * The absolute URL of the original location of this `dom-module`.\n   *\n   * This value will differ from this element's `ownerDocument` in the\n   * following ways:\n   * - Takes into account any `assetpath` attribute added during bundling\n   *   to indicate the original location relative to the bundled location\n   * - Uses the HTMLImports polyfill's `importForElement` API to ensure\n   *   the path is relative to the import document's location since\n   *   `ownerDocument` is not currently polyfilled\n   */\n\n\n  get assetpath() {\n    // Don't override existing assetpath.\n    if (!this.__assetpath) {\n      // note: assetpath set via an attribute must be relative to this\n      // element's location; accomodate polyfilled HTMLImports\n      const owner = window.HTMLImports && HTMLImports.importForElement ? HTMLImports.importForElement(this) || document : this.ownerDocument;\n      const url = (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__.resolveUrl)(this.getAttribute('assetpath') || '', owner.baseURI);\n      this.__assetpath = (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__.pathFromUrl)(url);\n    }\n\n    return this.__assetpath;\n  }\n  /**\n   * Registers the dom-module at a given id. This method should only be called\n   * when a dom-module is imperatively created. For\n   * example, `document.createElement('dom-module').register('foo')`.\n   * @param {string=} id The id at which to register the dom-module.\n   * @return {void}\n   */\n\n\n  register(id) {\n    id = id || this.id;\n\n    if (id) {\n      // Under strictTemplatePolicy, reject and null out any re-registered\n      // dom-module since it is ambiguous whether first-in or last-in is trusted\n      if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_2__.strictTemplatePolicy && findModule(id) !== undefined) {\n        setModule(id, null);\n        throw new Error(`strictTemplatePolicy: dom-module ${id} re-registered`);\n      }\n\n      this.id = id;\n      setModule(id, this);\n      styleOutsideTemplateCheck(this);\n    }\n  }\n\n}\nDomModule.prototype['modules'] = modules;\ncustomElements.define('dom-module', DomModule);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/dom-module.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/elements/dom-repeat.js":
/*!******************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/elements/dom-repeat.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export DomRepeat [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DomRepeat\": () => /* binding */ DomRepeat\n/* harmony export */ });\n/* harmony import */ var _polymer_element_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../polymer-element.js */ \"./node_modules/@polymer/polymer/polymer-element.js\");\n/* harmony import */ var _utils_templatize_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/templatize.js */ \"./node_modules/@polymer/polymer/lib/utils/templatize.js\");\n/* harmony import */ var _utils_debounce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/* harmony import */ var _utils_flush_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/flush.js */ \"./node_modules/@polymer/polymer/lib/utils/flush.js\");\n/* harmony import */ var _mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../mixins/mutable-data.js */ \"./node_modules/@polymer/polymer/lib/mixins/mutable-data.js\");\n/* harmony import */ var _utils_path_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../utils/path.js */ \"./node_modules/@polymer/polymer/lib/utils/path.js\");\n/* harmony import */ var _utils_async_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../utils/async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n // eslint-disable-line no-unused-vars\n\n\n\n\n\n\n/**\n * @constructor\n * @implements {Polymer_OptionalMutableData}\n * @extends {PolymerElement}\n * @private\n */\n\nconst domRepeatBase = (0,_mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_4__.OptionalMutableData)(_polymer_element_js__WEBPACK_IMPORTED_MODULE_0__.PolymerElement);\n/**\n * The `<dom-repeat>` element will automatically stamp and binds one instance\n * of template content to each object in a user-provided array.\n * `dom-repeat` accepts an `items` property, and one instance of the template\n * is stamped for each item into the DOM at the location of the `dom-repeat`\n * element.  The `item` property will be set on each instance's binding\n * scope, thus templates should bind to sub-properties of `item`.\n *\n * Example:\n *\n * ```html\n * <dom-module id=\"employee-list\">\n *\n *   <template>\n *\n *     <div> Employee list: </div>\n *     <dom-repeat items=\"{{employees}}\">\n *       <template>\n *         <div>First name: <span>{{item.first}}</span></div>\n *         <div>Last name: <span>{{item.last}}</span></div>\n *       </template>\n *     </dom-repeat>\n *\n *   </template>\n *\n * </dom-module>\n * ```\n *\n * With the following custom element definition:\n *\n * ```js\n * class EmployeeList extends PolymerElement {\n *   static get is() { return 'employee-list'; }\n *   static get properties() {\n *     return {\n *       employees: {\n *         value() {\n *           return [\n *             {first: 'Bob', last: 'Smith'},\n *             {first: 'Sally', last: 'Johnson'},\n *             ...\n *           ];\n *         }\n *       }\n *     };\n *   }\n * }\n * ```\n *\n * Notifications for changes to items sub-properties will be forwarded to template\n * instances, which will update via the normal structured data notification system.\n *\n * Mutations to the `items` array itself should be made using the Array\n * mutation API's on the PropertyEffects mixin (`push`, `pop`, `splice`,\n * `shift`, `unshift`), and template instances will be kept in sync with the\n * data in the array.\n *\n * Events caught by event handlers within the `dom-repeat` template will be\n * decorated with a `model` property, which represents the binding scope for\n * each template instance.  The model should be used to manipulate data on the\n * instance, for example `event.model.set('item.checked', true);`.\n *\n * Alternatively, the model for a template instance for an element stamped by\n * a `dom-repeat` can be obtained using the `modelForElement` API on the\n * `dom-repeat` that stamped it, for example\n * `this.$.domRepeat.modelForElement(event.target).set('item.checked', true);`.\n * This may be useful for manipulating instance data of event targets obtained\n * by event handlers on parents of the `dom-repeat` (event delegation).\n *\n * A view-specific filter/sort may be applied to each `dom-repeat` by supplying a\n * `filter` and/or `sort` property.  This may be a string that names a function on\n * the host, or a function may be assigned to the property directly.  The functions\n * should implemented following the standard `Array` filter/sort API.\n *\n * In order to re-run the filter or sort functions based on changes to sub-fields\n * of `items`, the `observe` property may be set as a space-separated list of\n * `item` sub-fields that should cause a re-filter/sort when modified.  If\n * the filter or sort function depends on properties not contained in `items`,\n * the user should observe changes to those properties and call `render` to update\n * the view based on the dependency change.\n *\n * For example, for an `dom-repeat` with a filter of the following:\n *\n * ```js\n * isEngineer(item) {\n *   return item.type == 'engineer' || item.manager.type == 'engineer';\n * }\n * ```\n *\n * Then the `observe` property should be configured as follows:\n *\n * ```html\n * <dom-repeat items=\"{{employees}}\" filter=\"isEngineer\" observe=\"type manager.type\">\n * ```\n *\n * @customElement\n * @polymer\n * @extends {domRepeatBase}\n * @appliesMixin OptionalMutableData\n * @summary Custom element for stamping instance of a template bound to\n *   items in an array.\n */\n\nclass DomRepeat extends domRepeatBase {\n  // Not needed to find template; can be removed once the analyzer\n  // can find the tag name from customElements.define call\n  static get is() {\n    return 'dom-repeat';\n  }\n\n  static get template() {\n    return null;\n  }\n\n  static get properties() {\n    /**\n     * Fired whenever DOM is added or removed by this template (by\n     * default, rendering occurs lazily).  To force immediate rendering, call\n     * `render`.\n     *\n     * @event dom-change\n     */\n    return {\n      /**\n       * An array containing items determining how many instances of the template\n       * to stamp and that that each template instance should bind to.\n       */\n      items: {\n        type: Array\n      },\n\n      /**\n       * The name of the variable to add to the binding scope for the array\n       * element associated with a given template instance.\n       */\n      as: {\n        type: String,\n        value: 'item'\n      },\n\n      /**\n       * The name of the variable to add to the binding scope with the index\n       * of the instance in the sorted and filtered list of rendered items.\n       * Note, for the index in the `this.items` array, use the value of the\n       * `itemsIndexAs` property.\n       */\n      indexAs: {\n        type: String,\n        value: 'index'\n      },\n\n      /**\n       * The name of the variable to add to the binding scope with the index\n       * of the instance in the `this.items` array. Note, for the index of\n       * this instance in the sorted and filtered list of rendered items,\n       * use the value of the `indexAs` property.\n       */\n      itemsIndexAs: {\n        type: String,\n        value: 'itemsIndex'\n      },\n\n      /**\n       * A function that should determine the sort order of the items.  This\n       * property should either be provided as a string, indicating a method\n       * name on the element's host, or else be an actual function.  The\n       * function should match the sort function passed to `Array.sort`.\n       * Using a sort function has no effect on the underlying `items` array.\n       */\n      sort: {\n        type: Function,\n        observer: '__sortChanged'\n      },\n\n      /**\n       * A function that can be used to filter items out of the view.  This\n       * property should either be provided as a string, indicating a method\n       * name on the element's host, or else be an actual function.  The\n       * function should match the sort function passed to `Array.filter`.\n       * Using a filter function has no effect on the underlying `items` array.\n       */\n      filter: {\n        type: Function,\n        observer: '__filterChanged'\n      },\n\n      /**\n       * When using a `filter` or `sort` function, the `observe` property\n       * should be set to a space-separated list of the names of item\n       * sub-fields that should trigger a re-sort or re-filter when changed.\n       * These should generally be fields of `item` that the sort or filter\n       * function depends on.\n       */\n      observe: {\n        type: String,\n        observer: '__observeChanged'\n      },\n\n      /**\n       * When using a `filter` or `sort` function, the `delay` property\n       * determines a debounce time in ms after a change to observed item\n       * properties that must pass before the filter or sort is re-run.\n       * This is useful in rate-limiting shuffling of the view when\n       * item changes may be frequent.\n       */\n      delay: Number,\n\n      /**\n       * Count of currently rendered items after `filter` (if any) has been applied.\n       * If \"chunking mode\" is enabled, `renderedItemCount` is updated each time a\n       * set of template instances is rendered.\n       *\n       */\n      renderedItemCount: {\n        type: Number,\n        notify: true,\n        readOnly: true\n      },\n\n      /**\n       * Defines an initial count of template instances to render after setting\n       * the `items` array, before the next paint, and puts the `dom-repeat`\n       * into \"chunking mode\".  The remaining items will be created and rendered\n       * incrementally at each animation frame therof until all instances have\n       * been rendered.\n       */\n      initialCount: {\n        type: Number,\n        observer: '__initializeChunking'\n      },\n\n      /**\n       * When `initialCount` is used, this property defines a frame rate (in\n       * fps) to target by throttling the number of instances rendered each\n       * frame to not exceed the budget for the target frame rate.  The\n       * framerate is effectively the number of `requestAnimationFrame`s that\n       * it tries to allow to actually fire in a given second. It does this\n       * by measuring the time between `rAF`s and continuously adjusting the\n       * number of items created each `rAF` to maintain the target framerate.\n       * Setting this to a higher number allows lower latency and higher\n       * throughput for event handlers and other tasks, but results in a\n       * longer time for the remaining items to complete rendering.\n       */\n      targetFramerate: {\n        type: Number,\n        value: 20\n      },\n      _targetFrameTime: {\n        type: Number,\n        computed: '__computeFrameTime(targetFramerate)'\n      }\n    };\n  }\n\n  static get observers() {\n    return ['__itemsChanged(items.*)'];\n  }\n\n  constructor() {\n    super();\n    this.__instances = [];\n    this.__limit = Infinity;\n    this.__pool = [];\n    this.__renderDebouncer = null;\n    this.__itemsIdxToInstIdx = {};\n    this.__chunkCount = null;\n    this.__lastChunkTime = null;\n    this.__sortFn = null;\n    this.__filterFn = null;\n    this.__observePaths = null;\n    /** @type {?function(new:Polymer.TemplateInstanceBase, *)} */\n\n    this.__ctor = null;\n    this.__isDetached = true;\n    this.template = null;\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  disconnectedCallback() {\n    super.disconnectedCallback();\n    this.__isDetached = true;\n\n    for (let i = 0; i < this.__instances.length; i++) {\n      this.__detachInstance(i);\n    }\n  }\n  /**\n   * @override\n   * @return {void}\n   */\n\n\n  connectedCallback() {\n    super.connectedCallback();\n    this.style.display = 'none'; // only perform attachment if the element was previously detached.\n\n    if (this.__isDetached) {\n      this.__isDetached = false;\n      let parent = this.parentNode;\n\n      for (let i = 0; i < this.__instances.length; i++) {\n        this.__attachInstance(i, parent);\n      }\n    }\n  }\n\n  __ensureTemplatized() {\n    // Templatizing (generating the instance constructor) needs to wait\n    // until ready, since won't have its template content handed back to\n    // it until then\n    if (!this.__ctor) {\n      let template = this.template =\n      /** @type {HTMLTemplateElement} */\n      this.querySelector('template');\n\n      if (!template) {\n        // // Wait until childList changes and template should be there by then\n        let observer = new MutationObserver(() => {\n          if (this.querySelector('template')) {\n            observer.disconnect();\n\n            this.__render();\n          } else {\n            throw new Error('dom-repeat requires a <template> child');\n          }\n        });\n        observer.observe(this, {\n          childList: true\n        });\n        return false;\n      } // Template instance props that should be excluded from forwarding\n\n\n      let instanceProps = {};\n      instanceProps[this.as] = true;\n      instanceProps[this.indexAs] = true;\n      instanceProps[this.itemsIndexAs] = true;\n      this.__ctor = (0,_utils_templatize_js__WEBPACK_IMPORTED_MODULE_1__.templatize)(template, this, {\n        mutableData: this.mutableData,\n        parentModel: true,\n        instanceProps: instanceProps,\n\n        /**\n         * @this {DomRepeat}\n         * @param {string} prop Property to set\n         * @param {*} value Value to set property to\n         */\n        forwardHostProp: function (prop, value) {\n          let i$ = this.__instances;\n\n          for (let i = 0, inst; i < i$.length && (inst = i$[i]); i++) {\n            inst.forwardHostProp(prop, value);\n          }\n        },\n\n        /**\n         * @this {DomRepeat}\n         * @param {Object} inst Instance to notify\n         * @param {string} prop Property to notify\n         * @param {*} value Value to notify\n         */\n        notifyInstanceProp: function (inst, prop, value) {\n          if ((0,_utils_path_js__WEBPACK_IMPORTED_MODULE_5__.matches)(this.as, prop)) {\n            let idx = inst[this.itemsIndexAs];\n\n            if (prop == this.as) {\n              this.items[idx] = value;\n            }\n\n            let path = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_5__.translate)(this.as, 'items.' + idx, prop);\n            this.notifyPath(path, value);\n          }\n        }\n      });\n    }\n\n    return true;\n  }\n\n  __getMethodHost() {\n    // Technically this should be the owner of the outermost template.\n    // In shadow dom, this is always getRootNode().host, but we can\n    // approximate this via cooperation with our dataHost always setting\n    // `_methodHost` as long as there were bindings (or id's) on this\n    // instance causing it to get a dataHost.\n    return this.__dataHost._methodHost || this.__dataHost;\n  }\n\n  __functionFromPropertyValue(functionOrMethodName) {\n    if (typeof functionOrMethodName === 'string') {\n      let methodName = functionOrMethodName;\n\n      let obj = this.__getMethodHost();\n\n      return function () {\n        return obj[methodName].apply(obj, arguments);\n      };\n    }\n\n    return functionOrMethodName;\n  }\n\n  __sortChanged(sort) {\n    this.__sortFn = this.__functionFromPropertyValue(sort);\n\n    if (this.items) {\n      this.__debounceRender(this.__render);\n    }\n  }\n\n  __filterChanged(filter) {\n    this.__filterFn = this.__functionFromPropertyValue(filter);\n\n    if (this.items) {\n      this.__debounceRender(this.__render);\n    }\n  }\n\n  __computeFrameTime(rate) {\n    return Math.ceil(1000 / rate);\n  }\n\n  __initializeChunking() {\n    if (this.initialCount) {\n      this.__limit = this.initialCount;\n      this.__chunkCount = this.initialCount;\n      this.__lastChunkTime = performance.now();\n    }\n  }\n\n  __tryRenderChunk() {\n    // Debounced so that multiple calls through `_render` between animation\n    // frames only queue one new rAF (e.g. array mutation & chunked render)\n    if (this.items && this.__limit < this.items.length) {\n      this.__debounceRender(this.__requestRenderChunk);\n    }\n  }\n\n  __requestRenderChunk() {\n    requestAnimationFrame(() => this.__renderChunk());\n  }\n\n  __renderChunk() {\n    // Simple auto chunkSize throttling algorithm based on feedback loop:\n    // measure actual time between frames and scale chunk count by ratio\n    // of target/actual frame time\n    let currChunkTime = performance.now();\n    let ratio = this._targetFrameTime / (currChunkTime - this.__lastChunkTime);\n    this.__chunkCount = Math.round(this.__chunkCount * ratio) || 1;\n    this.__limit += this.__chunkCount;\n    this.__lastChunkTime = currChunkTime;\n\n    this.__debounceRender(this.__render);\n  }\n\n  __observeChanged() {\n    this.__observePaths = this.observe && this.observe.replace('.*', '.').split(' ');\n  }\n\n  __itemsChanged(change) {\n    if (this.items && !Array.isArray(this.items)) {\n      console.warn('dom-repeat expected array for `items`, found', this.items);\n    } // If path was to an item (e.g. 'items.3' or 'items.3.foo'), forward the\n    // path to that instance synchronously (returns false for non-item paths)\n\n\n    if (!this.__handleItemPath(change.path, change.value)) {\n      // Otherwise, the array was reset ('items') or spliced ('items.splices'),\n      // so queue a full refresh\n      this.__initializeChunking();\n\n      this.__debounceRender(this.__render);\n    }\n  }\n\n  __handleObservedPaths(path) {\n    // Handle cases where path changes should cause a re-sort/filter\n    if (this.__sortFn || this.__filterFn) {\n      if (!path) {\n        // Always re-render if the item itself changed\n        this.__debounceRender(this.__render, this.delay);\n      } else if (this.__observePaths) {\n        // Otherwise, re-render if the path changed matches an observed path\n        let paths = this.__observePaths;\n\n        for (let i = 0; i < paths.length; i++) {\n          if (path.indexOf(paths[i]) === 0) {\n            this.__debounceRender(this.__render, this.delay);\n          }\n        }\n      }\n    }\n  }\n  /**\n   * @param {function(this:DomRepeat)} fn Function to debounce.\n   * @param {number=} delay Delay in ms to debounce by.\n   */\n\n\n  __debounceRender(fn, delay = 0) {\n    this.__renderDebouncer = _utils_debounce_js__WEBPACK_IMPORTED_MODULE_2__.Debouncer.debounce(this.__renderDebouncer, delay > 0 ? _utils_async_js__WEBPACK_IMPORTED_MODULE_6__.timeOut.after(delay) : _utils_async_js__WEBPACK_IMPORTED_MODULE_6__.microTask, fn.bind(this));\n    (0,_utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.enqueueDebouncer)(this.__renderDebouncer);\n  }\n  /**\n   * Forces the element to render its content. Normally rendering is\n   * asynchronous to a provoking change. This is done for efficiency so\n   * that multiple changes trigger only a single render. The render method\n   * should be called if, for example, template rendering is required to\n   * validate application state.\n   * @return {void}\n   */\n\n\n  render() {\n    // Queue this repeater, then flush all in order\n    this.__debounceRender(this.__render);\n\n    (0,_utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.flush)();\n  }\n\n  __render() {\n    if (!this.__ensureTemplatized()) {\n      // No template found yet\n      return;\n    }\n\n    this.__applyFullRefresh(); // Reset the pool\n    // TODO(kschaaf): Reuse pool across turns and nested templates\n    // Now that objects/arrays are re-evaluated when set, we can safely\n    // reuse pooled instances across turns, however we still need to decide\n    // semantics regarding how long to hold, how many to hold, etc.\n\n\n    this.__pool.length = 0; // Set rendered item count\n\n    this._setRenderedItemCount(this.__instances.length); // Notify users\n\n\n    this.dispatchEvent(new CustomEvent('dom-change', {\n      bubbles: true,\n      composed: true\n    })); // Check to see if we need to render more items\n\n    this.__tryRenderChunk();\n  }\n\n  __applyFullRefresh() {\n    let items = this.items || [];\n    let isntIdxToItemsIdx = new Array(items.length);\n\n    for (let i = 0; i < items.length; i++) {\n      isntIdxToItemsIdx[i] = i;\n    } // Apply user filter\n\n\n    if (this.__filterFn) {\n      isntIdxToItemsIdx = isntIdxToItemsIdx.filter((i, idx, array) => this.__filterFn(items[i], idx, array));\n    } // Apply user sort\n\n\n    if (this.__sortFn) {\n      isntIdxToItemsIdx.sort((a, b) => this.__sortFn(items[a], items[b]));\n    } // items->inst map kept for item path forwarding\n\n\n    const itemsIdxToInstIdx = this.__itemsIdxToInstIdx = {};\n    let instIdx = 0; // Generate instances and assign items\n\n    const limit = Math.min(isntIdxToItemsIdx.length, this.__limit);\n\n    for (; instIdx < limit; instIdx++) {\n      let inst = this.__instances[instIdx];\n      let itemIdx = isntIdxToItemsIdx[instIdx];\n      let item = items[itemIdx];\n      itemsIdxToInstIdx[itemIdx] = instIdx;\n\n      if (inst) {\n        inst._setPendingProperty(this.as, item);\n\n        inst._setPendingProperty(this.indexAs, instIdx);\n\n        inst._setPendingProperty(this.itemsIndexAs, itemIdx);\n\n        inst._flushProperties();\n      } else {\n        this.__insertInstance(item, instIdx, itemIdx);\n      }\n    } // Remove any extra instances from previous state\n\n\n    for (let i = this.__instances.length - 1; i >= instIdx; i--) {\n      this.__detachAndRemoveInstance(i);\n    }\n  }\n\n  __detachInstance(idx) {\n    let inst = this.__instances[idx];\n\n    for (let i = 0; i < inst.children.length; i++) {\n      let el = inst.children[i];\n      inst.root.appendChild(el);\n    }\n\n    return inst;\n  }\n\n  __attachInstance(idx, parent) {\n    let inst = this.__instances[idx];\n    parent.insertBefore(inst.root, this);\n  }\n\n  __detachAndRemoveInstance(idx) {\n    let inst = this.__detachInstance(idx);\n\n    if (inst) {\n      this.__pool.push(inst);\n    }\n\n    this.__instances.splice(idx, 1);\n  }\n\n  __stampInstance(item, instIdx, itemIdx) {\n    let model = {};\n    model[this.as] = item;\n    model[this.indexAs] = instIdx;\n    model[this.itemsIndexAs] = itemIdx;\n    return new this.__ctor(model);\n  }\n\n  __insertInstance(item, instIdx, itemIdx) {\n    let inst = this.__pool.pop();\n\n    if (inst) {\n      // TODO(kschaaf): If the pool is shared across turns, hostProps\n      // need to be re-set to reused instances in addition to item\n      inst._setPendingProperty(this.as, item);\n\n      inst._setPendingProperty(this.indexAs, instIdx);\n\n      inst._setPendingProperty(this.itemsIndexAs, itemIdx);\n\n      inst._flushProperties();\n    } else {\n      inst = this.__stampInstance(item, instIdx, itemIdx);\n    }\n\n    let beforeRow = this.__instances[instIdx + 1];\n    let beforeNode = beforeRow ? beforeRow.children[0] : this;\n    this.parentNode.insertBefore(inst.root, beforeNode);\n    this.__instances[instIdx] = inst;\n    return inst;\n  } // Implements extension point from Templatize mixin\n\n  /**\n   * Shows or hides the template instance top level child elements. For\n   * text nodes, `textContent` is removed while \"hidden\" and replaced when\n   * \"shown.\"\n   * @param {boolean} hidden Set to true to hide the children;\n   * set to false to show them.\n   * @return {void}\n   * @protected\n   */\n\n\n  _showHideChildren(hidden) {\n    for (let i = 0; i < this.__instances.length; i++) {\n      this.__instances[i]._showHideChildren(hidden);\n    }\n  } // Called as a side effect of a host items.<key>.<path> path change,\n  // responsible for notifying item.<path> changes to inst for key\n\n\n  __handleItemPath(path, value) {\n    let itemsPath = path.slice(6); // 'items.'.length == 6\n\n    let dot = itemsPath.indexOf('.');\n    let itemsIdx = dot < 0 ? itemsPath : itemsPath.substring(0, dot); // If path was index into array...\n\n    if (itemsIdx == parseInt(itemsIdx, 10)) {\n      let itemSubPath = dot < 0 ? '' : itemsPath.substring(dot + 1); // If the path is observed, it will trigger a full refresh\n\n      this.__handleObservedPaths(itemSubPath); // Note, even if a rull refresh is triggered, always do the path\n      // notification because unless mutableData is used for dom-repeat\n      // and all elements in the instance subtree, a full refresh may\n      // not trigger the proper update.\n\n\n      let instIdx = this.__itemsIdxToInstIdx[itemsIdx];\n      let inst = this.__instances[instIdx];\n\n      if (inst) {\n        let itemPath = this.as + (itemSubPath ? '.' + itemSubPath : ''); // This is effectively `notifyPath`, but avoids some of the overhead\n        // of the public API\n\n        inst._setPendingPropertyOrPath(itemPath, value, false, true);\n\n        inst._flushProperties();\n      }\n\n      return true;\n    }\n  }\n  /**\n   * Returns the item associated with a given element stamped by\n   * this `dom-repeat`.\n   *\n   * Note, to modify sub-properties of the item,\n   * `modelForElement(el).set('item.<sub-prop>', value)`\n   * should be used.\n   *\n   * @param {!HTMLElement} el Element for which to return the item.\n   * @return {*} Item associated with the element.\n   */\n\n\n  itemForElement(el) {\n    let instance = this.modelForElement(el);\n    return instance && instance[this.as];\n  }\n  /**\n   * Returns the inst index for a given element stamped by this `dom-repeat`.\n   * If `sort` is provided, the index will reflect the sorted order (rather\n   * than the original array order).\n   *\n   * @param {!HTMLElement} el Element for which to return the index.\n   * @return {?number} Row index associated with the element (note this may\n   *   not correspond to the array index if a user `sort` is applied).\n   */\n\n\n  indexForElement(el) {\n    let instance = this.modelForElement(el);\n    return instance && instance[this.indexAs];\n  }\n  /**\n   * Returns the template \"model\" associated with a given element, which\n   * serves as the binding scope for the template instance the element is\n   * contained in. A template model\n   * should be used to manipulate data associated with this template instance.\n   *\n   * Example:\n   *\n   *   let model = modelForElement(el);\n   *   if (model.index < 10) {\n   *     model.set('item.checked', true);\n   *   }\n   *\n   * @param {!HTMLElement} el Element for which to return a template model.\n   * @return {TemplateInstanceBase} Model representing the binding scope for\n   *   the element.\n   */\n\n\n  modelForElement(el) {\n    return (0,_utils_templatize_js__WEBPACK_IMPORTED_MODULE_1__.modelForElement)(this.template, el);\n  }\n\n}\ncustomElements.define(DomRepeat.is, DomRepeat);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/elements/dom-repeat.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/class.js":
/*!***********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/class.js ***!
  \***********************************************************/
/*! namespace exports */
/*! export Class [provided] [no usage info] [missing usage info prevents renaming] */
/*! export mixinBehaviors [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"mixinBehaviors\": () => /* binding */ mixinBehaviors,\n/* harmony export */   \"Class\": () => /* binding */ Class\n/* harmony export */ });\n/* harmony import */ var _legacy_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./legacy-element-mixin.js */ \"./node_modules/@polymer/polymer/lib/legacy/legacy-element-mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\nlet metaProps = {\n  attached: true,\n  detached: true,\n  ready: true,\n  created: true,\n  beforeRegister: true,\n  registered: true,\n  attributeChanged: true,\n  // meta objects\n  behaviors: true\n};\n/**\n * Applies a \"legacy\" behavior or array of behaviors to the provided class.\n *\n * Note: this method will automatically also apply the `LegacyElementMixin`\n * to ensure that any legacy behaviors can rely on legacy Polymer API on\n * the underlying element.\n *\n * @function\n * @template T\n * @param {!Object|!Array<!Object>} behaviors Behavior object or array of behaviors.\n * @param {function(new:T)} klass Element class.\n * @return {?} Returns a new Element class extended by the\n * passed in `behaviors` and also by `LegacyElementMixin`.\n * @suppress {invalidCasts, checkTypes}\n */\n\nfunction mixinBehaviors(behaviors, klass) {\n  if (!behaviors) {\n    klass =\n    /** @type {HTMLElement} */\n    klass; // eslint-disable-line no-self-assign\n\n    return klass;\n  } // NOTE: ensure the behavior is extending a class with\n  // legacy element api. This is necessary since behaviors expect to be able\n  // to access 1.x legacy api.\n\n\n  klass = (0,_legacy_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__.LegacyElementMixin)(klass);\n\n  if (!Array.isArray(behaviors)) {\n    behaviors = [behaviors];\n  }\n\n  let superBehaviors = klass.prototype.behaviors; // get flattened, deduped list of behaviors *not* already on super class\n\n  behaviors = flattenBehaviors(behaviors, null, superBehaviors); // mixin new behaviors\n\n  klass = _mixinBehaviors(behaviors, klass);\n\n  if (superBehaviors) {\n    behaviors = superBehaviors.concat(behaviors);\n  } // Set behaviors on prototype for BC...\n\n\n  klass.prototype.behaviors = behaviors;\n  return klass;\n} // NOTE:\n// 1.x\n// Behaviors were mixed in *in reverse order* and de-duped on the fly.\n// The rule was that behavior properties were copied onto the element\n// prototype if and only if the property did not already exist.\n// Given: Polymer{ behaviors: [A, B, C, A, B]}, property copy order was:\n// (1), B, (2), A, (3) C. This means prototype properties win over\n// B properties win over A win over C. This mirrors what would happen\n// with inheritance if element extended B extended A extended C.\n//\n// Again given, Polymer{ behaviors: [A, B, C, A, B]}, the resulting\n// `behaviors` array was [C, A, B].\n// Behavior lifecycle methods were called in behavior array order\n// followed by the element, e.g. (1) C.created, (2) A.created,\n// (3) B.created, (4) element.created. There was no support for\n// super, and \"super-behavior\" methods were callable only by name).\n//\n// 2.x\n// Behaviors are made into proper mixins which live in the\n// element's prototype chain. Behaviors are placed in the element prototype\n// eldest to youngest and de-duped youngest to oldest:\n// So, first [A, B, C, A, B] becomes [C, A, B] then,\n// the element prototype becomes (oldest) (1) PolymerElement, (2) class(C),\n// (3) class(A), (4) class(B), (5) class(Polymer({...})).\n// Result:\n// This means element properties win over B properties win over A win\n// over C. (same as 1.x)\n// If lifecycle is called (super then me), order is\n// (1) C.created, (2) A.created, (3) B.created, (4) element.created\n// (again same as 1.x)\n\nfunction _mixinBehaviors(behaviors, klass) {\n  for (let i = 0; i < behaviors.length; i++) {\n    let b = behaviors[i];\n\n    if (b) {\n      klass = Array.isArray(b) ? _mixinBehaviors(b, klass) : GenerateClassFromInfo(b, klass);\n    }\n  }\n\n  return klass;\n}\n/**\n * @param {Array} behaviors List of behaviors to flatten.\n * @param {Array=} list Target list to flatten behaviors into.\n * @param {Array=} exclude List of behaviors to exclude from the list.\n * @return {!Array} Returns the list of flattened behaviors.\n */\n\n\nfunction flattenBehaviors(behaviors, list, exclude) {\n  list = list || [];\n\n  for (let i = behaviors.length - 1; i >= 0; i--) {\n    let b = behaviors[i];\n\n    if (b) {\n      if (Array.isArray(b)) {\n        flattenBehaviors(b, list);\n      } else {\n        // dedup\n        if (list.indexOf(b) < 0 && (!exclude || exclude.indexOf(b) < 0)) {\n          list.unshift(b);\n        }\n      }\n    } else {\n      console.warn('behavior is null, check for missing or 404 import');\n    }\n  }\n\n  return list;\n}\n/**\n * @param {!PolymerInit} info Polymer info object\n * @param {function(new:HTMLElement)} Base base class to extend with info object\n * @return {function(new:HTMLElement)} Generated class\n * @suppress {checkTypes}\n * @private\n */\n\n\nfunction GenerateClassFromInfo(info, Base) {\n  /** @private */\n  class PolymerGenerated extends Base {\n    static get properties() {\n      return info.properties;\n    }\n\n    static get observers() {\n      return info.observers;\n    }\n    /**\n     * @return {void}\n     */\n\n\n    created() {\n      super.created();\n\n      if (info.created) {\n        info.created.call(this);\n      }\n    }\n    /**\n     * @return {void}\n     */\n\n\n    _registered() {\n      super._registered();\n      /* NOTE: `beforeRegister` is called here for bc, but the behavior\n       is different than in 1.x. In 1.0, the method was called *after*\n       mixing prototypes together but *before* processing of meta-objects.\n       However, dynamic effects can still be set here and can be done either\n       in `beforeRegister` or `registered`. It is no longer possible to set\n       `is` in `beforeRegister` as you could in 1.x.\n      */\n\n\n      if (info.beforeRegister) {\n        info.beforeRegister.call(Object.getPrototypeOf(this));\n      }\n\n      if (info.registered) {\n        info.registered.call(Object.getPrototypeOf(this));\n      }\n    }\n    /**\n     * @return {void}\n     */\n\n\n    _applyListeners() {\n      super._applyListeners();\n\n      if (info.listeners) {\n        for (let l in info.listeners) {\n          this._addMethodEventListenerToNode(this, l, info.listeners[l]);\n        }\n      }\n    } // note: exception to \"super then me\" rule;\n    // do work before calling super so that super attributes\n    // only apply if not already set.\n\n    /**\n     * @return {void}\n     */\n\n\n    _ensureAttributes() {\n      if (info.hostAttributes) {\n        for (let a in info.hostAttributes) {\n          this._ensureAttribute(a, info.hostAttributes[a]);\n        }\n      }\n\n      super._ensureAttributes();\n    }\n    /**\n     * @return {void}\n     */\n\n\n    ready() {\n      super.ready();\n\n      if (info.ready) {\n        info.ready.call(this);\n      }\n    }\n    /**\n     * @return {void}\n     */\n\n\n    attached() {\n      super.attached();\n\n      if (info.attached) {\n        info.attached.call(this);\n      }\n    }\n    /**\n     * @return {void}\n     */\n\n\n    detached() {\n      super.detached();\n\n      if (info.detached) {\n        info.detached.call(this);\n      }\n    }\n    /**\n     * Implements native Custom Elements `attributeChangedCallback` to\n     * set an attribute value to a property via `_attributeToProperty`.\n     *\n     * @param {string} name Name of attribute that changed\n     * @param {?string} old Old attribute value\n     * @param {?string} value New attribute value\n     * @return {void}\n     */\n\n\n    attributeChanged(name, old, value) {\n      super.attributeChanged(name, old, value);\n\n      if (info.attributeChanged) {\n        info.attributeChanged.call(this, name, old, value);\n      }\n    }\n\n  }\n\n  PolymerGenerated.generatedFrom = info;\n\n  for (let p in info) {\n    // NOTE: cannot copy `metaProps` methods onto prototype at least because\n    // `super.ready` must be called and is not included in the user fn.\n    if (!(p in metaProps)) {\n      let pd = Object.getOwnPropertyDescriptor(info, p);\n\n      if (pd) {\n        Object.defineProperty(PolymerGenerated.prototype, p, pd);\n      }\n    }\n  }\n\n  return PolymerGenerated;\n}\n/**\n * Generates a class that extends `LegacyElement` based on the\n * provided info object.  Metadata objects on the `info` object\n * (`properties`, `observers`, `listeners`, `behaviors`, `is`) are used\n * for Polymer's meta-programming systems, and any functions are copied\n * to the generated class.\n *\n * Valid \"metadata\" values are as follows:\n *\n * `is`: String providing the tag name to register the element under. In\n * addition, if a `dom-module` with the same id exists, the first template\n * in that `dom-module` will be stamped into the shadow root of this element,\n * with support for declarative event listeners (`on-...`), Polymer data\n * bindings (`[[...]]` and `{{...}}`), and id-based node finding into\n * `this.$`.\n *\n * `properties`: Object describing property-related metadata used by Polymer\n * features (key: property names, value: object containing property metadata).\n * Valid keys in per-property metadata include:\n * - `type` (String|Number|Object|Array|...): Used by\n *   `attributeChangedCallback` to determine how string-based attributes\n *   are deserialized to JavaScript property values.\n * - `notify` (boolean): Causes a change in the property to fire a\n *   non-bubbling event called `<property>-changed`. Elements that have\n *   enabled two-way binding to the property use this event to observe changes.\n * - `readOnly` (boolean): Creates a getter for the property, but no setter.\n *   To set a read-only property, use the private setter method\n *   `_setProperty(property, value)`.\n * - `observer` (string): Observer method name that will be called when\n *   the property changes. The arguments of the method are\n *   `(value, previousValue)`.\n * - `computed` (string): String describing method and dependent properties\n *   for computing the value of this property (e.g. `'computeFoo(bar, zot)'`).\n *   Computed properties are read-only by default and can only be changed\n *   via the return value of the computing method.\n *\n * `observers`: Array of strings describing multi-property observer methods\n *  and their dependent properties (e.g. `'observeABC(a, b, c)'`).\n *\n * `listeners`: Object describing event listeners to be added to each\n *  instance of this element (key: event name, value: method name).\n *\n * `behaviors`: Array of additional `info` objects containing metadata\n * and callbacks in the same format as the `info` object here which are\n * merged into this element.\n *\n * `hostAttributes`: Object listing attributes to be applied to the host\n *  once created (key: attribute name, value: attribute value).  Values\n *  are serialized based on the type of the value.  Host attributes should\n *  generally be limited to attributes such as `tabIndex` and `aria-...`.\n *  Attributes in `hostAttributes` are only applied if a user-supplied\n *  attribute is not already present (attributes in markup override\n *  `hostAttributes`).\n *\n * In addition, the following Polymer-specific callbacks may be provided:\n * - `registered`: called after first instance of this element,\n * - `created`: called during `constructor`\n * - `attached`: called during `connectedCallback`\n * - `detached`: called during `disconnectedCallback`\n * - `ready`: called before first `attached`, after all properties of\n *   this element have been propagated to its template and all observers\n *   have run\n *\n * @param {!PolymerInit} info Object containing Polymer metadata and functions\n *   to become class methods.\n * @template T\n * @param {function(T):T} mixin Optional mixin to apply to legacy base class\n *   before extending with Polymer metaprogramming.\n * @return {function(new:HTMLElement)} Generated class\n */\n\n\nconst Class = function (info, mixin) {\n  if (!info) {\n    console.warn(`Polymer's Class function requires \\`info\\` argument`);\n  }\n\n  const baseWithBehaviors = info.behaviors ? // note: mixinBehaviors ensures `LegacyElementMixin`.\n  mixinBehaviors(info.behaviors, HTMLElement) : (0,_legacy_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__.LegacyElementMixin)(HTMLElement);\n  const baseWithMixin = mixin ? mixin(baseWithBehaviors) : baseWithBehaviors;\n  const klass = GenerateClassFromInfo(info, baseWithMixin); // decorate klass with registration info\n\n  klass.is = info.is;\n  return klass;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/class.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/legacy-element-mixin.js":
/*!**************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/legacy-element-mixin.js ***!
  \**************************************************************************/
/*! namespace exports */
/*! export LegacyElementMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"LegacyElementMixin\": () => /* binding */ LegacyElementMixin\n/* harmony export */ });\n/* harmony import */ var _webcomponents_shadycss_entrypoints_apply_shim_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @webcomponents/shadycss/entrypoints/apply-shim.js */ \"./node_modules/@webcomponents/shadycss/entrypoints/apply-shim.js\");\n/* harmony import */ var _mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../mixins/element-mixin.js */ \"./node_modules/@polymer/polymer/lib/mixins/element-mixin.js\");\n/* harmony import */ var _mixins_gesture_event_listeners_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../mixins/gesture-event-listeners.js */ \"./node_modules/@polymer/polymer/lib/mixins/gesture-event-listeners.js\");\n/* harmony import */ var _mixins_dir_mixin_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../mixins/dir-mixin.js */ \"./node_modules/@polymer/polymer/lib/mixins/dir-mixin.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_render_status_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../utils/render-status.js */ \"./node_modules/@polymer/polymer/lib/utils/render-status.js\");\n/* harmony import */ var _utils_unresolved_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../utils/unresolved.js */ \"./node_modules/@polymer/polymer/lib/utils/unresolved.js\");\n/* harmony import */ var _polymer_dom_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./polymer.dom.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\");\n/* harmony import */ var _utils_gestures_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../utils/gestures.js */ \"./node_modules/@polymer/polymer/lib/utils/gestures.js\");\n/* harmony import */ var _utils_debounce_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/* harmony import */ var _utils_async_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../utils/async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/* harmony import */ var _utils_path_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../utils/path.js */ \"./node_modules/@polymer/polymer/lib/utils/path.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n\n\n\n\n\n\nlet styleInterface = window.ShadyCSS;\n/**\n * Element class mixin that provides Polymer's \"legacy\" API intended to be\n * backward-compatible to the greatest extent possible with the API\n * found on the Polymer 1.x `Polymer.Base` prototype applied to all elements\n * defined using the `Polymer({...})` function.\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin ElementMixin\n * @appliesMixin GestureEventListeners\n * @property isAttached {boolean} Set to `true` in this element's\n *   `connectedCallback` and `false` in `disconnectedCallback`\n * @summary Element class mixin that provides Polymer's \"legacy\" API\n */\n\nconst LegacyElementMixin = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_4__.dedupingMixin)(base => {\n  /**\n   * @constructor\n   * @extends {base}\n   * @implements {Polymer_ElementMixin}\n   * @implements {Polymer_GestureEventListeners}\n   * @implements {Polymer_DirMixin}\n   * @private\n   */\n  const legacyElementBase = (0,_mixins_dir_mixin_js__WEBPACK_IMPORTED_MODULE_3__.DirMixin)((0,_mixins_gesture_event_listeners_js__WEBPACK_IMPORTED_MODULE_2__.GestureEventListeners)((0,_mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_1__.ElementMixin)(base)));\n  /**\n   * Map of simple names to touch action names\n   * @dict\n   */\n\n  const DIRECTION_MAP = {\n    'x': 'pan-x',\n    'y': 'pan-y',\n    'none': 'none',\n    'all': 'auto'\n  };\n  /**\n   * @polymer\n   * @mixinClass\n   * @extends {legacyElementBase}\n   * @implements {Polymer_LegacyElementMixin}\n   * @unrestricted\n   */\n\n  class LegacyElement extends legacyElementBase {\n    constructor() {\n      super();\n      /** @type {boolean} */\n\n      this.isAttached;\n      /** @type {WeakMap<!Element, !Object<string, !Function>>} */\n\n      this.__boundListeners;\n      /** @type {Object<string, Function>} */\n\n      this._debouncers; // Ensure listeners are applied immediately so that they are\n      // added before declarative event listeners. This allows an element to\n      // decorate itself via an event prior to any declarative listeners\n      // seeing the event. Note, this ensures compatibility with 1.x ordering.\n\n      this._applyListeners();\n    }\n    /**\n     * Forwards `importMeta` from the prototype (i.e. from the info object\n     * passed to `Polymer({...})`) to the static API.\n     *\n     * @return {!Object} The `import.meta` object set on the prototype\n     * @suppress {missingProperties} `this` is always in the instance in\n     *  closure for some reason even in a static method, rather than the class\n     */\n\n\n    static get importMeta() {\n      return this.prototype.importMeta;\n    }\n    /**\n     * Legacy callback called during the `constructor`, for overriding\n     * by the user.\n     * @return {void}\n     */\n\n\n    created() {}\n    /**\n     * Provides an implementation of `connectedCallback`\n     * which adds Polymer legacy API's `attached` method.\n     * @return {void}\n     * @override\n     */\n\n\n    connectedCallback() {\n      super.connectedCallback();\n      this.isAttached = true;\n      this.attached();\n    }\n    /**\n     * Legacy callback called during `connectedCallback`, for overriding\n     * by the user.\n     * @return {void}\n     */\n\n\n    attached() {}\n    /**\n     * Provides an implementation of `disconnectedCallback`\n     * which adds Polymer legacy API's `detached` method.\n     * @return {void}\n     * @override\n     */\n\n\n    disconnectedCallback() {\n      super.disconnectedCallback();\n      this.isAttached = false;\n      this.detached();\n    }\n    /**\n     * Legacy callback called during `disconnectedCallback`, for overriding\n     * by the user.\n     * @return {void}\n     */\n\n\n    detached() {}\n    /**\n     * Provides an override implementation of `attributeChangedCallback`\n     * which adds the Polymer legacy API's `attributeChanged` method.\n     * @param {string} name Name of attribute.\n     * @param {?string} old Old value of attribute.\n     * @param {?string} value Current value of attribute.\n     * @param {?string} namespace Attribute namespace.\n     * @return {void}\n     * @override\n     */\n\n\n    attributeChangedCallback(name, old, value, namespace) {\n      if (old !== value) {\n        super.attributeChangedCallback(name, old, value, namespace);\n        this.attributeChanged(name, old, value);\n      }\n    }\n    /**\n     * Legacy callback called during `attributeChangedChallback`, for overriding\n     * by the user.\n     * @param {string} name Name of attribute.\n     * @param {?string} old Old value of attribute.\n     * @param {?string} value Current value of attribute.\n     * @return {void}\n     */\n\n\n    attributeChanged(name, old, value) {} // eslint-disable-line no-unused-vars\n\n    /**\n     * Overrides the default `Polymer.PropertyEffects` implementation to\n     * add support for class initialization via the `_registered` callback.\n     * This is called only when the first instance of the element is created.\n     *\n     * @return {void}\n     * @override\n     * @suppress {invalidCasts}\n     */\n\n\n    _initializeProperties() {\n      let proto = Object.getPrototypeOf(this);\n\n      if (!proto.hasOwnProperty('__hasRegisterFinished')) {\n        proto.__hasRegisterFinished = true;\n\n        this._registered();\n      }\n\n      super._initializeProperties();\n\n      this.root =\n      /** @type {HTMLElement} */\n      this;\n      this.created();\n    }\n    /**\n     * Called automatically when an element is initializing.\n     * Users may override this method to perform class registration time\n     * work. The implementation should ensure the work is performed\n     * only once for the class.\n     * @protected\n     * @return {void}\n     */\n\n\n    _registered() {}\n    /**\n     * Overrides the default `Polymer.PropertyEffects` implementation to\n     * add support for installing `hostAttributes` and `listeners`.\n     *\n     * @return {void}\n     * @override\n     */\n\n\n    ready() {\n      this._ensureAttributes();\n\n      super.ready();\n    }\n    /**\n     * Ensures an element has required attributes. Called when the element\n     * is being readied via `ready`. Users should override to set the\n     * element's required attributes. The implementation should be sure\n     * to check and not override existing attributes added by\n     * the user of the element. Typically, setting attributes should be left\n     * to the element user and not done here; reasonable exceptions include\n     * setting aria roles and focusability.\n     * @protected\n     * @return {void}\n     */\n\n\n    _ensureAttributes() {}\n    /**\n     * Adds element event listeners. Called when the element\n     * is being readied via `ready`. Users should override to\n     * add any required element event listeners.\n     * In performance critical elements, the work done here should be kept\n     * to a minimum since it is done before the element is rendered. In\n     * these elements, consider adding listeners asynchronously so as not to\n     * block render.\n     * @protected\n     * @return {void}\n     */\n\n\n    _applyListeners() {}\n    /**\n     * Converts a typed JavaScript value to a string.\n     *\n     * Note this method is provided as backward-compatible legacy API\n     * only.  It is not directly called by any Polymer features. To customize\n     * how properties are serialized to attributes for attribute bindings and\n     * `reflectToAttribute: true` properties as well as this method, override\n     * the `_serializeValue` method provided by `Polymer.PropertyAccessors`.\n     *\n     * @param {*} value Value to deserialize\n     * @return {string | undefined} Serialized value\n     */\n\n\n    serialize(value) {\n      return this._serializeValue(value);\n    }\n    /**\n     * Converts a string to a typed JavaScript value.\n     *\n     * Note this method is provided as backward-compatible legacy API\n     * only.  It is not directly called by any Polymer features.  To customize\n     * how attributes are deserialized to properties for in\n     * `attributeChangedCallback`, override `_deserializeValue` method\n     * provided by `Polymer.PropertyAccessors`.\n     *\n     * @param {string} value String to deserialize\n     * @param {*} type Type to deserialize the string to\n     * @return {*} Returns the deserialized value in the `type` given.\n     */\n\n\n    deserialize(value, type) {\n      return this._deserializeValue(value, type);\n    }\n    /**\n     * Serializes a property to its associated attribute.\n     *\n     * Note this method is provided as backward-compatible legacy API\n     * only.  It is not directly called by any Polymer features.\n     *\n     * @param {string} property Property name to reflect.\n     * @param {string=} attribute Attribute name to reflect.\n     * @param {*=} value Property value to reflect.\n     * @return {void}\n     */\n\n\n    reflectPropertyToAttribute(property, attribute, value) {\n      this._propertyToAttribute(property, attribute, value);\n    }\n    /**\n     * Sets a typed value to an HTML attribute on a node.\n     *\n     * Note this method is provided as backward-compatible legacy API\n     * only.  It is not directly called by any Polymer features.\n     *\n     * @param {*} value Value to serialize.\n     * @param {string} attribute Attribute name to serialize to.\n     * @param {Element} node Element to set attribute to.\n     * @return {void}\n     */\n\n\n    serializeValueToAttribute(value, attribute, node) {\n      this._valueToNodeAttribute(\n      /** @type {Element} */\n      node || this, value, attribute);\n    }\n    /**\n     * Copies own properties (including accessor descriptors) from a source\n     * object to a target object.\n     *\n     * @param {Object} prototype Target object to copy properties to.\n     * @param {Object} api Source object to copy properties from.\n     * @return {Object} prototype object that was passed as first argument.\n     */\n\n\n    extend(prototype, api) {\n      if (!(prototype && api)) {\n        return prototype || api;\n      }\n\n      let n$ = Object.getOwnPropertyNames(api);\n\n      for (let i = 0, n; i < n$.length && (n = n$[i]); i++) {\n        let pd = Object.getOwnPropertyDescriptor(api, n);\n\n        if (pd) {\n          Object.defineProperty(prototype, n, pd);\n        }\n      }\n\n      return prototype;\n    }\n    /**\n     * Copies props from a source object to a target object.\n     *\n     * Note, this method uses a simple `for...in` strategy for enumerating\n     * properties.  To ensure only `ownProperties` are copied from source\n     * to target and that accessor implementations are copied, use `extend`.\n     *\n     * @param {!Object} target Target object to copy properties to.\n     * @param {!Object} source Source object to copy properties from.\n     * @return {!Object} Target object that was passed as first argument.\n     */\n\n\n    mixin(target, source) {\n      for (let i in source) {\n        target[i] = source[i];\n      }\n\n      return target;\n    }\n    /**\n     * Sets the prototype of an object.\n     *\n     * Note this method is provided as backward-compatible legacy API\n     * only.  It is not directly called by any Polymer features.\n     * @param {Object} object The object on which to set the prototype.\n     * @param {Object} prototype The prototype that will be set on the given\n     * `object`.\n     * @return {Object} Returns the given `object` with its prototype set\n     * to the given `prototype` object.\n     */\n\n\n    chainObject(object, prototype) {\n      if (object && prototype && object !== prototype) {\n        object.__proto__ = prototype;\n      }\n\n      return object;\n    }\n    /* **** Begin Template **** */\n\n    /**\n     * Calls `importNode` on the `content` of the `template` specified and\n     * returns a document fragment containing the imported content.\n     *\n     * @param {HTMLTemplateElement} template HTML template element to instance.\n     * @return {!DocumentFragment} Document fragment containing the imported\n     *   template content.\n    */\n\n\n    instanceTemplate(template) {\n      let content = this.constructor._contentForTemplate(template);\n\n      let dom =\n      /** @type {!DocumentFragment} */\n      document.importNode(content, true);\n      return dom;\n    }\n    /* **** Begin Events **** */\n\n    /**\n     * Dispatches a custom event with an optional detail value.\n     *\n     * @param {string} type Name of event type.\n     * @param {*=} detail Detail value containing event-specific\n     *   payload.\n     * @param {{ bubbles: (boolean|undefined), cancelable: (boolean|undefined), composed: (boolean|undefined) }=}\n     *  options Object specifying options.  These may include:\n     *  `bubbles` (boolean, defaults to `true`),\n     *  `cancelable` (boolean, defaults to false), and\n     *  `node` on which to fire the event (HTMLElement, defaults to `this`).\n     * @return {!Event} The new event that was fired.\n     */\n\n\n    fire(type, detail, options) {\n      options = options || {};\n      detail = detail === null || detail === undefined ? {} : detail;\n      let event = new Event(type, {\n        bubbles: options.bubbles === undefined ? true : options.bubbles,\n        cancelable: Boolean(options.cancelable),\n        composed: options.composed === undefined ? true : options.composed\n      });\n      event.detail = detail;\n      let node = options.node || this;\n      node.dispatchEvent(event);\n      return event;\n    }\n    /**\n     * Convenience method to add an event listener on a given element,\n     * late bound to a named method on this element.\n     *\n     * @param {?EventTarget} node Element to add event listener to.\n     * @param {string} eventName Name of event to listen for.\n     * @param {string} methodName Name of handler method on `this` to call.\n     * @return {void}\n     */\n\n\n    listen(node, eventName, methodName) {\n      node =\n      /** @type {!EventTarget} */\n      node || this;\n      let hbl = this.__boundListeners || (this.__boundListeners = new WeakMap());\n      let bl = hbl.get(node);\n\n      if (!bl) {\n        bl = {};\n        hbl.set(node, bl);\n      }\n\n      let key = eventName + methodName;\n\n      if (!bl[key]) {\n        bl[key] = this._addMethodEventListenerToNode(node, eventName, methodName, this);\n      }\n    }\n    /**\n     * Convenience method to remove an event listener from a given element,\n     * late bound to a named method on this element.\n     *\n     * @param {?EventTarget} node Element to remove event listener from.\n     * @param {string} eventName Name of event to stop listening to.\n     * @param {string} methodName Name of handler method on `this` to not call\n     anymore.\n     * @return {void}\n     */\n\n\n    unlisten(node, eventName, methodName) {\n      node =\n      /** @type {!EventTarget} */\n      node || this;\n\n      let bl = this.__boundListeners && this.__boundListeners.get(node);\n\n      let key = eventName + methodName;\n      let handler = bl && bl[key];\n\n      if (handler) {\n        this._removeEventListenerFromNode(node, eventName, handler);\n\n        bl[key] = null;\n      }\n    }\n    /**\n     * Override scrolling behavior to all direction, one direction, or none.\n     *\n     * Valid scroll directions:\n     *   - 'all': scroll in any direction\n     *   - 'x': scroll only in the 'x' direction\n     *   - 'y': scroll only in the 'y' direction\n     *   - 'none': disable scrolling for this node\n     *\n     * @param {string=} direction Direction to allow scrolling\n     * Defaults to `all`.\n     * @param {Element=} node Element to apply scroll direction setting.\n     * Defaults to `this`.\n     * @return {void}\n     */\n\n\n    setScrollDirection(direction, node) {\n      (0,_utils_gestures_js__WEBPACK_IMPORTED_MODULE_8__.setTouchAction)(\n      /** @type {Element} */\n      node || this, DIRECTION_MAP[direction] || 'auto');\n    }\n    /* **** End Events **** */\n\n    /**\n     * Convenience method to run `querySelector` on this local DOM scope.\n     *\n     * This function calls `Polymer.dom(this.root).querySelector(slctr)`.\n     *\n     * @param {string} slctr Selector to run on this local DOM scope\n     * @return {Element} Element found by the selector, or null if not found.\n     */\n\n\n    $$(slctr) {\n      return this.root.querySelector(slctr);\n    }\n    /**\n     * Return the element whose local dom within which this element\n     * is contained. This is a shorthand for\n     * `this.getRootNode().host`.\n     * @this {Element}\n     */\n\n\n    get domHost() {\n      let root = this.getRootNode();\n      return root instanceof DocumentFragment ?\n      /** @type {ShadowRoot} */\n      root.host : root;\n    }\n    /**\n     * Force this element to distribute its children to its local dom.\n     * This should not be necessary as of Polymer 2.0.2 and is provided only\n     * for backwards compatibility.\n     * @return {void}\n     */\n\n\n    distributeContent() {\n      if (window.ShadyDOM && this.shadowRoot) {\n        ShadyDOM.flush();\n      }\n    }\n    /**\n     * Returns a list of nodes that are the effective childNodes. The effective\n     * childNodes list is the same as the element's childNodes except that\n     * any `<content>` elements are replaced with the list of nodes distributed\n     * to the `<content>`, the result of its `getDistributedNodes` method.\n     * @return {!Array<!Node>} List of effective child nodes.\n     * @suppress {invalidCasts} LegacyElementMixin must be applied to an HTMLElement\n     */\n\n\n    getEffectiveChildNodes() {\n      const thisEl =\n      /** @type {Element} */\n      this;\n      const domApi =\n      /** @type {DomApi} */\n      (0,_polymer_dom_js__WEBPACK_IMPORTED_MODULE_7__.dom)(thisEl);\n      return domApi.getEffectiveChildNodes();\n    }\n    /**\n     * Returns a list of nodes distributed within this element that match\n     * `selector`. These can be dom children or elements distributed to\n     * children that are insertion points.\n     * @param {string} selector Selector to run.\n     * @return {!Array<!Node>} List of distributed elements that match selector.\n     * @suppress {invalidCasts} LegacyElementMixin must be applied to an HTMLElement\n     */\n\n\n    queryDistributedElements(selector) {\n      const thisEl =\n      /** @type {Element} */\n      this;\n      const domApi =\n      /** @type {DomApi} */\n      (0,_polymer_dom_js__WEBPACK_IMPORTED_MODULE_7__.dom)(thisEl);\n      return domApi.queryDistributedElements(selector);\n    }\n    /**\n     * Returns a list of elements that are the effective children. The effective\n     * children list is the same as the element's children except that\n     * any `<content>` elements are replaced with the list of elements\n     * distributed to the `<content>`.\n     *\n     * @return {!Array<!Node>} List of effective children.\n     */\n\n\n    getEffectiveChildren() {\n      let list = this.getEffectiveChildNodes();\n      return list.filter(function (\n      /** @type {!Node} */\n      n) {\n        return n.nodeType === Node.ELEMENT_NODE;\n      });\n    }\n    /**\n     * Returns a string of text content that is the concatenation of the\n     * text content's of the element's effective childNodes (the elements\n     * returned by <a href=\"#getEffectiveChildNodes>getEffectiveChildNodes</a>.\n     *\n     * @return {string} List of effective children.\n     */\n\n\n    getEffectiveTextContent() {\n      let cn = this.getEffectiveChildNodes();\n      let tc = [];\n\n      for (let i = 0, c; c = cn[i]; i++) {\n        if (c.nodeType !== Node.COMMENT_NODE) {\n          tc.push(c.textContent);\n        }\n      }\n\n      return tc.join('');\n    }\n    /**\n     * Returns the first effective childNode within this element that\n     * match `selector`. These can be dom child nodes or elements distributed\n     * to children that are insertion points.\n     * @param {string} selector Selector to run.\n     * @return {Node} First effective child node that matches selector.\n     */\n\n\n    queryEffectiveChildren(selector) {\n      let e$ = this.queryDistributedElements(selector);\n      return e$ && e$[0];\n    }\n    /**\n     * Returns a list of effective childNodes within this element that\n     * match `selector`. These can be dom child nodes or elements distributed\n     * to children that are insertion points.\n     * @param {string} selector Selector to run.\n     * @return {!Array<!Node>} List of effective child nodes that match selector.\n     */\n\n\n    queryAllEffectiveChildren(selector) {\n      return this.queryDistributedElements(selector);\n    }\n    /**\n     * Returns a list of nodes distributed to this element's `<slot>`.\n     *\n     * If this element contains more than one `<slot>` in its local DOM,\n     * an optional selector may be passed to choose the desired content.\n     *\n     * @param {string=} slctr CSS selector to choose the desired\n     *   `<slot>`.  Defaults to `content`.\n     * @return {!Array<!Node>} List of distributed nodes for the `<slot>`.\n     */\n\n\n    getContentChildNodes(slctr) {\n      let content = this.root.querySelector(slctr || 'slot');\n      return content ?\n      /** @type {DomApi} */\n      (0,_polymer_dom_js__WEBPACK_IMPORTED_MODULE_7__.dom)(content).getDistributedNodes() : [];\n    }\n    /**\n     * Returns a list of element children distributed to this element's\n     * `<slot>`.\n     *\n     * If this element contains more than one `<slot>` in its\n     * local DOM, an optional selector may be passed to choose the desired\n     * content.  This method differs from `getContentChildNodes` in that only\n     * elements are returned.\n     *\n     * @param {string=} slctr CSS selector to choose the desired\n     *   `<content>`.  Defaults to `content`.\n     * @return {!Array<!HTMLElement>} List of distributed nodes for the\n     *   `<slot>`.\n     * @suppress {invalidCasts}\n     */\n\n\n    getContentChildren(slctr) {\n      let children =\n      /** @type {!Array<!HTMLElement>} */\n      this.getContentChildNodes(slctr).filter(function (n) {\n        return n.nodeType === Node.ELEMENT_NODE;\n      });\n      return children;\n    }\n    /**\n     * Checks whether an element is in this element's light DOM tree.\n     *\n     * @param {?Node} node The element to be checked.\n     * @return {boolean} true if node is in this element's light DOM tree.\n     * @suppress {invalidCasts} LegacyElementMixin must be applied to an HTMLElement\n     */\n\n\n    isLightDescendant(node) {\n      const thisNode =\n      /** @type {Node} */\n      this;\n      return thisNode !== node && thisNode.contains(node) && thisNode.getRootNode() === node.getRootNode();\n    }\n    /**\n     * Checks whether an element is in this element's local DOM tree.\n     *\n     * @param {!Element} node The element to be checked.\n     * @return {boolean} true if node is in this element's local DOM tree.\n     */\n\n\n    isLocalDescendant(node) {\n      return this.root === node.getRootNode();\n    }\n    /**\n     * No-op for backwards compatibility. This should now be handled by\n     * ShadyCss library.\n     * @param  {*} container Unused\n     * @param  {*} shouldObserve Unused\n     * @return {void}\n     */\n\n\n    scopeSubtree(container, shouldObserve) {// eslint-disable-line no-unused-vars\n    }\n    /**\n     * Returns the computed style value for the given property.\n     * @param {string} property The css property name.\n     * @return {string} Returns the computed css property value for the given\n     * `property`.\n     * @suppress {invalidCasts} LegacyElementMixin must be applied to an HTMLElement\n     */\n\n\n    getComputedStyleValue(property) {\n      return styleInterface.getComputedStyleValue(\n      /** @type {!Element} */\n      this, property);\n    } // debounce\n\n    /**\n     * Call `debounce` to collapse multiple requests for a named task into\n     * one invocation which is made after the wait time has elapsed with\n     * no new request.  If no wait time is given, the callback will be called\n     * at microtask timing (guaranteed before paint).\n     *\n     *     debouncedClickAction(e) {\n     *       // will not call `processClick` more than once per 100ms\n     *       this.debounce('click', function() {\n     *        this.processClick();\n     *       } 100);\n     *     }\n     *\n     * @param {string} jobName String to identify the debounce job.\n     * @param {function():void} callback Function that is called (with `this`\n     *   context) when the wait time elapses.\n     * @param {number} wait Optional wait time in milliseconds (ms) after the\n     *   last signal that must elapse before invoking `callback`\n     * @return {!Object} Returns a debouncer object on which exists the\n     * following methods: `isActive()` returns true if the debouncer is\n     * active; `cancel()` cancels the debouncer if it is active;\n     * `flush()` immediately invokes the debounced callback if the debouncer\n     * is active.\n     */\n\n\n    debounce(jobName, callback, wait) {\n      this._debouncers = this._debouncers || {};\n      return this._debouncers[jobName] = _utils_debounce_js__WEBPACK_IMPORTED_MODULE_9__.Debouncer.debounce(this._debouncers[jobName], wait > 0 ? _utils_async_js__WEBPACK_IMPORTED_MODULE_10__.timeOut.after(wait) : _utils_async_js__WEBPACK_IMPORTED_MODULE_10__.microTask, callback.bind(this));\n    }\n    /**\n     * Returns whether a named debouncer is active.\n     *\n     * @param {string} jobName The name of the debouncer started with `debounce`\n     * @return {boolean} Whether the debouncer is active (has not yet fired).\n     */\n\n\n    isDebouncerActive(jobName) {\n      this._debouncers = this._debouncers || {};\n      let debouncer = this._debouncers[jobName];\n      return !!(debouncer && debouncer.isActive());\n    }\n    /**\n     * Immediately calls the debouncer `callback` and inactivates it.\n     *\n     * @param {string} jobName The name of the debouncer started with `debounce`\n     * @return {void}\n     */\n\n\n    flushDebouncer(jobName) {\n      this._debouncers = this._debouncers || {};\n      let debouncer = this._debouncers[jobName];\n\n      if (debouncer) {\n        debouncer.flush();\n      }\n    }\n    /**\n     * Cancels an active debouncer.  The `callback` will not be called.\n     *\n     * @param {string} jobName The name of the debouncer started with `debounce`\n     * @return {void}\n     */\n\n\n    cancelDebouncer(jobName) {\n      this._debouncers = this._debouncers || {};\n      let debouncer = this._debouncers[jobName];\n\n      if (debouncer) {\n        debouncer.cancel();\n      }\n    }\n    /**\n     * Runs a callback function asynchronously.\n     *\n     * By default (if no waitTime is specified), async callbacks are run at\n     * microtask timing, which will occur before paint.\n     *\n     * @param {!Function} callback The callback function to run, bound to `this`.\n     * @param {number=} waitTime Time to wait before calling the\n     *   `callback`.  If unspecified or 0, the callback will be run at microtask\n     *   timing (before paint).\n     * @return {number} Handle that may be used to cancel the async job.\n     */\n\n\n    async(callback, waitTime) {\n      return waitTime > 0 ? _utils_async_js__WEBPACK_IMPORTED_MODULE_10__.timeOut.run(callback.bind(this), waitTime) : ~_utils_async_js__WEBPACK_IMPORTED_MODULE_10__.microTask.run(callback.bind(this));\n    }\n    /**\n     * Cancels an async operation started with `async`.\n     *\n     * @param {number} handle Handle returned from original `async` call to\n     *   cancel.\n     * @return {void}\n     */\n\n\n    cancelAsync(handle) {\n      handle < 0 ? _utils_async_js__WEBPACK_IMPORTED_MODULE_10__.microTask.cancel(~handle) : _utils_async_js__WEBPACK_IMPORTED_MODULE_10__.timeOut.cancel(handle);\n    } // other\n\n    /**\n     * Convenience method for creating an element and configuring it.\n     *\n     * @param {string} tag HTML element tag to create.\n     * @param {Object=} props Object of properties to configure on the\n     *    instance.\n     * @return {!Element} Newly created and configured element.\n     */\n\n\n    create(tag, props) {\n      let elt = document.createElement(tag);\n\n      if (props) {\n        if (elt.setProperties) {\n          elt.setProperties(props);\n        } else {\n          for (let n in props) {\n            elt[n] = props[n];\n          }\n        }\n      }\n\n      return elt;\n    }\n    /**\n     * Polyfill for Element.prototype.matches, which is sometimes still\n     * prefixed.\n     *\n     * @param {string} selector Selector to test.\n     * @param {!Element=} node Element to test the selector against.\n     * @return {boolean} Whether the element matches the selector.\n     */\n\n\n    elementMatches(selector, node) {\n      return (0,_polymer_dom_js__WEBPACK_IMPORTED_MODULE_7__.matchesSelector)(node || this, selector);\n    }\n    /**\n     * Toggles an HTML attribute on or off.\n     *\n     * @param {string} name HTML attribute name\n     * @param {boolean=} bool Boolean to force the attribute on or off.\n     *    When unspecified, the state of the attribute will be reversed.\n     * @return {boolean} true if the attribute now exists\n     */\n\n\n    toggleAttribute(name, bool) {\n      let node =\n      /** @type {Element} */\n      this;\n\n      if (arguments.length === 3) {\n        node =\n        /** @type {Element} */\n        arguments[2];\n      }\n\n      if (arguments.length == 1) {\n        bool = !node.hasAttribute(name);\n      }\n\n      if (bool) {\n        node.setAttribute(name, '');\n        return true;\n      } else {\n        node.removeAttribute(name);\n        return false;\n      }\n    }\n    /**\n     * Toggles a CSS class on or off.\n     *\n     * @param {string} name CSS class name\n     * @param {boolean=} bool Boolean to force the class on or off.\n     *    When unspecified, the state of the class will be reversed.\n     * @param {Element=} node Node to target.  Defaults to `this`.\n     * @return {void}\n     */\n\n\n    toggleClass(name, bool, node) {\n      node =\n      /** @type {Element} */\n      node || this;\n\n      if (arguments.length == 1) {\n        bool = !node.classList.contains(name);\n      }\n\n      if (bool) {\n        node.classList.add(name);\n      } else {\n        node.classList.remove(name);\n      }\n    }\n    /**\n     * Cross-platform helper for setting an element's CSS `transform` property.\n     *\n     * @param {string} transformText Transform setting.\n     * @param {Element=} node Element to apply the transform to.\n     * Defaults to `this`\n     * @return {void}\n     */\n\n\n    transform(transformText, node) {\n      node =\n      /** @type {Element} */\n      node || this;\n      node.style.webkitTransform = transformText;\n      node.style.transform = transformText;\n    }\n    /**\n     * Cross-platform helper for setting an element's CSS `translate3d`\n     * property.\n     *\n     * @param {number} x X offset.\n     * @param {number} y Y offset.\n     * @param {number} z Z offset.\n     * @param {Element=} node Element to apply the transform to.\n     * Defaults to `this`.\n     * @return {void}\n     */\n\n\n    translate3d(x, y, z, node) {\n      node =\n      /** @type {Element} */\n      node || this;\n      this.transform('translate3d(' + x + ',' + y + ',' + z + ')', node);\n    }\n    /**\n     * Removes an item from an array, if it exists.\n     *\n     * If the array is specified by path, a change notification is\n     * generated, so that observers, data bindings and computed\n     * properties watching that path can update.\n     *\n     * If the array is passed directly, **no change\n     * notification is generated**.\n     *\n     * @param {string | !Array<number|string>} arrayOrPath Path to array from which to remove the item\n     *   (or the array itself).\n     * @param {*} item Item to remove.\n     * @return {Array} Array containing item removed.\n     */\n\n\n    arrayDelete(arrayOrPath, item) {\n      let index;\n\n      if (Array.isArray(arrayOrPath)) {\n        index = arrayOrPath.indexOf(item);\n\n        if (index >= 0) {\n          return arrayOrPath.splice(index, 1);\n        }\n      } else {\n        let arr = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_11__.get)(this, arrayOrPath);\n        index = arr.indexOf(item);\n\n        if (index >= 0) {\n          return this.splice(arrayOrPath, index, 1);\n        }\n      }\n\n      return null;\n    } // logging\n\n    /**\n     * Facades `console.log`/`warn`/`error` as override point.\n     *\n     * @param {string} level One of 'log', 'warn', 'error'\n     * @param {Array} args Array of strings or objects to log\n     * @return {void}\n     */\n\n\n    _logger(level, args) {\n      // accept ['foo', 'bar'] and [['foo', 'bar']]\n      if (Array.isArray(args) && args.length === 1 && Array.isArray(args[0])) {\n        args = args[0];\n      }\n\n      switch (level) {\n        case 'log':\n        case 'warn':\n        case 'error':\n          console[level](...args);\n      }\n    }\n    /**\n     * Facades `console.log` as an override point.\n     *\n     * @param {...*} args Array of strings or objects to log\n     * @return {void}\n     */\n\n\n    _log(...args) {\n      this._logger('log', args);\n    }\n    /**\n     * Facades `console.warn` as an override point.\n     *\n     * @param {...*} args Array of strings or objects to log\n     * @return {void}\n     */\n\n\n    _warn(...args) {\n      this._logger('warn', args);\n    }\n    /**\n     * Facades `console.error` as an override point.\n     *\n     * @param {...*} args Array of strings or objects to log\n     * @return {void}\n     */\n\n\n    _error(...args) {\n      this._logger('error', args);\n    }\n    /**\n     * Formats a message using the element type an a method name.\n     *\n     * @param {string} methodName Method name to associate with message\n     * @param {...*} args Array of strings or objects to log\n     * @return {Array} Array with formatting information for `console`\n     *   logging.\n     */\n\n\n    _logf(methodName, ...args) {\n      return ['[%s::%s]', this.is, methodName, ...args];\n    }\n\n  }\n\n  LegacyElement.prototype.is = '';\n  return LegacyElement;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/legacy-element-mixin.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/mutable-data-behavior.js":
/*!***************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/mutable-data-behavior.js ***!
  \***************************************************************************/
/*! namespace exports */
/*! export MutableDataBehavior [provided] [no usage info] [missing usage info prevents renaming] */
/*! export OptionalMutableDataBehavior [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"MutableDataBehavior\": () => /* binding */ MutableDataBehavior,\n/* harmony export */   \"OptionalMutableDataBehavior\": () => /* binding */ OptionalMutableDataBehavior\n/* harmony export */ });\n/* harmony import */ var _mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../mixins/mutable-data.js */ \"./node_modules/@polymer/polymer/lib/mixins/mutable-data.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\nlet mutablePropertyChange;\n/** @suppress {missingProperties} */\n\n(() => {\n  mutablePropertyChange = _mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_0__.MutableData._mutablePropertyChange;\n})();\n/**\n * Legacy element behavior to skip strict dirty-checking for objects and arrays,\n * (always consider them to be \"dirty\") for use on legacy API Polymer elements.\n *\n * By default, `Polymer.PropertyEffects` performs strict dirty checking on\n * objects, which means that any deep modifications to an object or array will\n * not be propagated unless \"immutable\" data patterns are used (i.e. all object\n * references from the root to the mutation were changed).\n *\n * Polymer also provides a proprietary data mutation and path notification API\n * (e.g. `notifyPath`, `set`, and array mutation API's) that allow efficient\n * mutation and notification of deep changes in an object graph to all elements\n * bound to the same object graph.\n *\n * In cases where neither immutable patterns nor the data mutation API can be\n * used, applying this mixin will cause Polymer to skip dirty checking for\n * objects and arrays (always consider them to be \"dirty\").  This allows a\n * user to make a deep modification to a bound object graph, and then either\n * simply re-set the object (e.g. `this.items = this.items`) or call `notifyPath`\n * (e.g. `this.notifyPath('items')`) to update the tree.  Note that all\n * elements that wish to be updated based on deep mutations must apply this\n * mixin or otherwise skip strict dirty checking for objects/arrays.\n * Specifically, any elements in the binding tree between the source of a\n * mutation and the consumption of it must apply this behavior or enable the\n * `Polymer.OptionalMutableDataBehavior`.\n *\n * In order to make the dirty check strategy configurable, see\n * `Polymer.OptionalMutableDataBehavior`.\n *\n * Note, the performance characteristics of propagating large object graphs\n * will be worse as opposed to using strict dirty checking with immutable\n * patterns or Polymer's path notification API.\n *\n * @polymerBehavior\n * @summary Behavior to skip strict dirty-checking for objects and\n *   arrays\n */\n\n\nconst MutableDataBehavior = {\n  /**\n   * Overrides `Polymer.PropertyEffects` to provide option for skipping\n   * strict equality checking for Objects and Arrays.\n   *\n   * This method pulls the value to dirty check against from the `__dataTemp`\n   * cache (rather than the normal `__data` cache) for Objects.  Since the temp\n   * cache is cleared at the end of a turn, this implementation allows\n   * side-effects of deep object changes to be processed by re-setting the\n   * same object (using the temp cache as an in-turn backstop to prevent\n   * cycles due to 2-way notification).\n   *\n   * @param {string} property Property name\n   * @param {*} value New property value\n   * @param {*} old Previous property value\n   * @return {boolean} Whether the property should be considered a change\n   * @protected\n   */\n  _shouldPropertyChange(property, value, old) {\n    return mutablePropertyChange(this, property, value, old, true);\n  }\n\n};\n/**\n * Legacy element behavior to add the optional ability to skip strict\n * dirty-checking for objects and arrays (always consider them to be\n * \"dirty\") by setting a `mutable-data` attribute on an element instance.\n *\n * By default, `Polymer.PropertyEffects` performs strict dirty checking on\n * objects, which means that any deep modifications to an object or array will\n * not be propagated unless \"immutable\" data patterns are used (i.e. all object\n * references from the root to the mutation were changed).\n *\n * Polymer also provides a proprietary data mutation and path notification API\n * (e.g. `notifyPath`, `set`, and array mutation API's) that allow efficient\n * mutation and notification of deep changes in an object graph to all elements\n * bound to the same object graph.\n *\n * In cases where neither immutable patterns nor the data mutation API can be\n * used, applying this mixin will allow Polymer to skip dirty checking for\n * objects and arrays (always consider them to be \"dirty\").  This allows a\n * user to make a deep modification to a bound object graph, and then either\n * simply re-set the object (e.g. `this.items = this.items`) or call `notifyPath`\n * (e.g. `this.notifyPath('items')`) to update the tree.  Note that all\n * elements that wish to be updated based on deep mutations must apply this\n * mixin or otherwise skip strict dirty checking for objects/arrays.\n * Specifically, any elements in the binding tree between the source of a\n * mutation and the consumption of it must enable this behavior or apply the\n * `Polymer.OptionalMutableDataBehavior`.\n *\n * While this behavior adds the ability to forgo Object/Array dirty checking,\n * the `mutableData` flag defaults to false and must be set on the instance.\n *\n * Note, the performance characteristics of propagating large object graphs\n * will be worse by relying on `mutableData: true` as opposed to using\n * strict dirty checking with immutable patterns or Polymer's path notification\n * API.\n *\n * @polymerBehavior\n * @summary Behavior to optionally skip strict dirty-checking for objects and\n *   arrays\n */\n\nconst OptionalMutableDataBehavior = {\n  properties: {\n    /**\n     * Instance-level flag for configuring the dirty-checking strategy\n     * for this element.  When true, Objects and Arrays will skip dirty\n     * checking, otherwise strict equality checking will be used.\n     */\n    mutableData: Boolean\n  },\n\n  /**\n   * Overrides `Polymer.PropertyEffects` to skip strict equality checking\n   * for Objects and Arrays.\n   *\n   * Pulls the value to dirty check against from the `__dataTemp` cache\n   * (rather than the normal `__data` cache) for Objects.  Since the temp\n   * cache is cleared at the end of a turn, this implementation allows\n   * side-effects of deep object changes to be processed by re-setting the\n   * same object (using the temp cache as an in-turn backstop to prevent\n   * cycles due to 2-way notification).\n   *\n   * @param {string} property Property name\n   * @param {*} value New property value\n   * @param {*} old Previous property value\n   * @return {boolean} Whether the property should be considered a change\n   * @this {this}\n   * @protected\n   */\n  _shouldPropertyChange(property, value, old) {\n    return mutablePropertyChange(this, property, value, old, this.mutableData);\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/mutable-data-behavior.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js":
/*!****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export Polymer [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Polymer\": () => /* binding */ Polymer\n/* harmony export */ });\n/* harmony import */ var _class_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./class.js */ \"./node_modules/@polymer/polymer/lib/legacy/class.js\");\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n/**\n * Legacy class factory and registration helper for defining Polymer\n * elements.\n *\n * This method is equivalent to\n *\n *     import {Class} from '@polymer/polymer/lib/legacy/class.js';\n *     customElements.define(info.is, Class(info));\n *\n * See `Class` for details on valid legacy metadata format for `info`.\n *\n * @global\n * @override\n * @function\n * @param {!PolymerInit} info Object containing Polymer metadata and functions\n *   to become class methods.\n * @return {function(new: HTMLElement)} Generated class\n * @suppress {duplicate, invalidCasts, checkTypes}\n */\n\nconst Polymer = function (info) {\n  // if input is a `class` (aka a function with a prototype), use the prototype\n  // remember that the `constructor` will never be called\n  let klass;\n\n  if (typeof info === 'function') {\n    klass = info;\n  } else {\n    klass = Polymer.Class(info);\n  }\n\n  customElements.define(klass.is,\n  /** @type {!HTMLElement} */\n  klass);\n  return klass;\n};\n\nPolymer.Class = _class_js__WEBPACK_IMPORTED_MODULE_0__.Class;\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js":
/*!*****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export DomApi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export EventApi [provided] [no usage info] [missing usage info prevents renaming] */
/*! export addDebouncer [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/utils/flush.js .enqueueDebouncer */
/*! export dom [provided] [no usage info] [missing usage info prevents renaming] */
/*! export flush [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/utils/flush.js .flush */
/*! export matchesSelector [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"flush\": () => /* reexport safe */ _utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.flush,\n/* harmony export */   \"addDebouncer\": () => /* reexport safe */ _utils_flush_js__WEBPACK_IMPORTED_MODULE_3__.enqueueDebouncer,\n/* harmony export */   \"matchesSelector\": () => /* binding */ matchesSelector,\n/* harmony export */   \"DomApi\": () => /* binding */ DomApi,\n/* harmony export */   \"EventApi\": () => /* binding */ EventApi,\n/* harmony export */   \"dom\": () => /* binding */ dom\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/* harmony import */ var _utils_flattened_nodes_observer_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/flattened-nodes-observer.js */ \"./node_modules/@polymer/polymer/lib/utils/flattened-nodes-observer.js\");\n/* harmony import */ var _utils_flush_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/flush.js */ \"./node_modules/@polymer/polymer/lib/utils/flush.js\");\n/* harmony import */ var _utils_debounce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n/* eslint-disable no-unused-vars */\n\n // used in type annotations\n\n/* eslint-enable no-unused-vars */\n\nconst p = Element.prototype;\n/**\n * @const {function(this:Node, string): boolean}\n */\n\nconst normalizedMatchesSelector = p.matches || p.matchesSelector || p.mozMatchesSelector || p.msMatchesSelector || p.oMatchesSelector || p.webkitMatchesSelector;\n/**\n * Cross-platform `element.matches` shim.\n *\n * @function matchesSelector\n * @param {!Node} node Node to check selector against\n * @param {string} selector Selector to match\n * @return {boolean} True if node matched selector\n */\n\nconst matchesSelector = function (node, selector) {\n  return normalizedMatchesSelector.call(node, selector);\n};\n/**\n * Node API wrapper class returned from `Polymer.dom.(target)` when\n * `target` is a `Node`.\n *\n */\n\nclass DomApi {\n  /**\n   * @param {Node} node Node for which to create a Polymer.dom helper object.\n   */\n  constructor(node) {\n    this.node = node;\n  }\n  /**\n   * Returns an instance of `FlattenedNodesObserver` that\n   * listens for node changes on this element.\n   *\n   * @param {function(this:HTMLElement, { target: !HTMLElement, addedNodes: !Array<!Element>, removedNodes: !Array<!Element> }):void} callback Called when direct or distributed children\n   *   of this element changes\n   * @return {!FlattenedNodesObserver} Observer instance\n   */\n\n\n  observeNodes(callback) {\n    return new _utils_flattened_nodes_observer_js__WEBPACK_IMPORTED_MODULE_2__.FlattenedNodesObserver(\n    /** @type {!HTMLElement} */\n    this.node, callback);\n  }\n  /**\n   * Disconnects an observer previously created via `observeNodes`\n   *\n   * @param {!FlattenedNodesObserver} observerHandle Observer instance\n   *   to disconnect.\n   * @return {void}\n   */\n\n\n  unobserveNodes(observerHandle) {\n    observerHandle.disconnect();\n  }\n  /**\n   * Provided as a backwards-compatible API only.  This method does nothing.\n   * @return {void}\n   */\n\n\n  notifyObserver() {}\n  /**\n   * Returns true if the provided node is contained with this element's\n   * light-DOM children or shadow root, including any nested shadow roots\n   * of children therein.\n   *\n   * @param {Node} node Node to test\n   * @return {boolean} Returns true if the given `node` is contained within\n   *   this element's light or shadow DOM.\n   */\n\n\n  deepContains(node) {\n    if (this.node.contains(node)) {\n      return true;\n    }\n\n    let n = node;\n    let doc = node.ownerDocument; // walk from node to `this` or `document`\n\n    while (n && n !== doc && n !== this.node) {\n      // use logical parentnode, or native ShadowRoot host\n      n = n.parentNode || n.host;\n    }\n\n    return n === this.node;\n  }\n  /**\n   * Returns the root node of this node.  Equivalent to `getRootNode()`.\n   *\n   * @return {Node} Top most element in the dom tree in which the node\n   * exists. If the node is connected to a document this is either a\n   * shadowRoot or the document; otherwise, it may be the node\n   * itself or a node or document fragment containing it.\n   */\n\n\n  getOwnerRoot() {\n    return this.node.getRootNode();\n  }\n  /**\n   * For slot elements, returns the nodes assigned to the slot; otherwise\n   * an empty array. It is equivalent to `<slot>.addignedNodes({flatten:true})`.\n   *\n   * @return {!Array<!Node>} Array of assigned nodes\n   */\n\n\n  getDistributedNodes() {\n    return this.node.localName === 'slot' ? this.node.assignedNodes({\n      flatten: true\n    }) : [];\n  }\n  /**\n   * Returns an array of all slots this element was distributed to.\n   *\n   * @return {!Array<!HTMLSlotElement>} Description\n   */\n\n\n  getDestinationInsertionPoints() {\n    let ip$ = [];\n    let n = this.node.assignedSlot;\n\n    while (n) {\n      ip$.push(n);\n      n = n.assignedSlot;\n    }\n\n    return ip$;\n  }\n  /**\n   * Calls `importNode` on the `ownerDocument` for this node.\n   *\n   * @param {!Node} node Node to import\n   * @param {boolean} deep True if the node should be cloned deeply during\n   *   import\n   * @return {Node} Clone of given node imported to this owner document\n   */\n\n\n  importNode(node, deep) {\n    let doc = this.node instanceof Document ? this.node : this.node.ownerDocument;\n    return doc.importNode(node, deep);\n  }\n  /**\n   * @return {!Array<!Node>} Returns a flattened list of all child nodes and\n   * nodes assigned to child slots.\n   */\n\n\n  getEffectiveChildNodes() {\n    return _utils_flattened_nodes_observer_js__WEBPACK_IMPORTED_MODULE_2__.FlattenedNodesObserver.getFlattenedNodes(\n    /** @type {!HTMLElement} */\n    this.node);\n  }\n  /**\n   * Returns a filtered list of flattened child elements for this element based\n   * on the given selector.\n   *\n   * @param {string} selector Selector to filter nodes against\n   * @return {!Array<!HTMLElement>} List of flattened child elements\n   */\n\n\n  queryDistributedElements(selector) {\n    let c$ = this.getEffectiveChildNodes();\n    let list = [];\n\n    for (let i = 0, l = c$.length, c; i < l && (c = c$[i]); i++) {\n      if (c.nodeType === Node.ELEMENT_NODE && matchesSelector(c, selector)) {\n        list.push(c);\n      }\n    }\n\n    return list;\n  }\n  /**\n   * For shadow roots, returns the currently focused element within this\n   * shadow root.\n   *\n   * @return {Node|undefined} Currently focused element\n   */\n\n\n  get activeElement() {\n    let node = this.node;\n    return node._activeElement !== undefined ? node._activeElement : node.activeElement;\n  }\n\n}\n\nfunction forwardMethods(proto, methods) {\n  for (let i = 0; i < methods.length; i++) {\n    let method = methods[i];\n    /* eslint-disable valid-jsdoc */\n\n    proto[method] =\n    /** @this {DomApi} */\n    function () {\n      return this.node[method].apply(this.node, arguments);\n    };\n    /* eslint-enable */\n\n  }\n}\n\nfunction forwardReadOnlyProperties(proto, properties) {\n  for (let i = 0; i < properties.length; i++) {\n    let name = properties[i];\n    Object.defineProperty(proto, name, {\n      get: function () {\n        const domApi =\n        /** @type {DomApi} */\n        this;\n        return domApi.node[name];\n      },\n      configurable: true\n    });\n  }\n}\n\nfunction forwardProperties(proto, properties) {\n  for (let i = 0; i < properties.length; i++) {\n    let name = properties[i];\n    Object.defineProperty(proto, name, {\n      /**\n       * @this {DomApi}\n       * @return {*} .\n       */\n      get: function () {\n        return this.node[name];\n      },\n\n      /**\n       * @this {DomApi}\n       * @param {*} value .\n       */\n      set: function (value) {\n        this.node[name] = value;\n      },\n      configurable: true\n    });\n  }\n}\n/**\n * Event API wrapper class returned from `dom.(target)` when\n * `target` is an `Event`.\n */\n\n\nclass EventApi {\n  constructor(event) {\n    this.event = event;\n  }\n  /**\n   * Returns the first node on the `composedPath` of this event.\n   *\n   * @return {!EventTarget} The node this event was dispatched to\n   */\n\n\n  get rootTarget() {\n    return this.event.composedPath()[0];\n  }\n  /**\n   * Returns the local (re-targeted) target for this event.\n   *\n   * @return {!EventTarget} The local (re-targeted) target for this event.\n   */\n\n\n  get localTarget() {\n    return this.event.target;\n  }\n  /**\n   * Returns the `composedPath` for this event.\n   * @return {!Array<!EventTarget>} The nodes this event propagated through\n   */\n\n\n  get path() {\n    return this.event.composedPath();\n  }\n\n}\n/**\n * @function\n * @param {boolean=} deep\n * @return {!Node}\n */\n\nDomApi.prototype.cloneNode;\n/**\n * @function\n * @param {!Node} node\n * @return {!Node}\n */\n\nDomApi.prototype.appendChild;\n/**\n * @function\n * @param {!Node} newChild\n * @param {Node} refChild\n * @return {!Node}\n */\n\nDomApi.prototype.insertBefore;\n/**\n * @function\n * @param {!Node} node\n * @return {!Node}\n */\n\nDomApi.prototype.removeChild;\n/**\n * @function\n * @param {!Node} oldChild\n * @param {!Node} newChild\n * @return {!Node}\n */\n\nDomApi.prototype.replaceChild;\n/**\n * @function\n * @param {string} name\n * @param {string} value\n * @return {void}\n */\n\nDomApi.prototype.setAttribute;\n/**\n * @function\n * @param {string} name\n * @return {void}\n */\n\nDomApi.prototype.removeAttribute;\n/**\n * @function\n * @param {string} selector\n * @return {?Element}\n */\n\nDomApi.prototype.querySelector;\n/**\n * @function\n * @param {string} selector\n * @return {!NodeList<!Element>}\n */\n\nDomApi.prototype.querySelectorAll;\n/** @type {?Node} */\n\nDomApi.prototype.parentNode;\n/** @type {?Node} */\n\nDomApi.prototype.firstChild;\n/** @type {?Node} */\n\nDomApi.prototype.lastChild;\n/** @type {?Node} */\n\nDomApi.prototype.nextSibling;\n/** @type {?Node} */\n\nDomApi.prototype.previousSibling;\n/** @type {?HTMLElement} */\n\nDomApi.prototype.firstElementChild;\n/** @type {?HTMLElement} */\n\nDomApi.prototype.lastElementChild;\n/** @type {?HTMLElement} */\n\nDomApi.prototype.nextElementSibling;\n/** @type {?HTMLElement} */\n\nDomApi.prototype.previousElementSibling;\n/** @type {!Array<!Node>} */\n\nDomApi.prototype.childNodes;\n/** @type {!Array<!HTMLElement>} */\n\nDomApi.prototype.children;\n/** @type {?DOMTokenList} */\n\nDomApi.prototype.classList;\n/** @type {string} */\n\nDomApi.prototype.textContent;\n/** @type {string} */\n\nDomApi.prototype.innerHTML;\nforwardMethods(DomApi.prototype, ['cloneNode', 'appendChild', 'insertBefore', 'removeChild', 'replaceChild', 'setAttribute', 'removeAttribute', 'querySelector', 'querySelectorAll']);\nforwardReadOnlyProperties(DomApi.prototype, ['parentNode', 'firstChild', 'lastChild', 'nextSibling', 'previousSibling', 'firstElementChild', 'lastElementChild', 'nextElementSibling', 'previousElementSibling', 'childNodes', 'children', 'classList']);\nforwardProperties(DomApi.prototype, ['textContent', 'innerHTML']);\n/**\n * Legacy DOM and Event manipulation API wrapper factory used to abstract\n * differences between native Shadow DOM and \"Shady DOM\" when polyfilling on\n * older browsers.\n *\n * Note that in Polymer 2.x use of `Polymer.dom` is no longer required and\n * in the majority of cases simply facades directly to the standard native\n * API.\n *\n * @summary Legacy DOM and Event manipulation API wrapper factory used to\n * abstract differences between native Shadow DOM and \"Shady DOM.\"\n * @param {(Node|Event)=} obj Node or event to operate on\n * @return {!DomApi|!EventApi} Wrapper providing either node API or event API\n */\n\nconst dom = function (obj) {\n  obj = obj || document;\n\n  if (!obj.__domApi) {\n    let helper;\n\n    if (obj instanceof Event) {\n      helper = new EventApi(obj);\n    } else {\n      helper = new DomApi(obj);\n    }\n\n    obj.__domApi = helper;\n  }\n\n  return obj.__domApi;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/polymer.dom.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/legacy/templatizer-behavior.js":
/*!**************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/legacy/templatizer-behavior.js ***!
  \**************************************************************************/
/*! namespace exports */
/*! export Templatizer [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Templatizer\": () => /* binding */ Templatizer\n/* harmony export */ });\n/* harmony import */ var _utils_templatize_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/templatize.js */ \"./node_modules/@polymer/polymer/lib/utils/templatize.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n // eslint-disable-line no-unused-vars\n\n/**\n * @typedef {{\n *   _templatizerTemplate: HTMLTemplateElement,\n *   _parentModel: boolean,\n *   _instanceProps: Object,\n *   _forwardHostPropV2: Function,\n *   _notifyInstancePropV2: Function,\n *   ctor: TemplateInstanceBase\n * }}\n */\n\nlet TemplatizerUser; // eslint-disable-line\n\n/**\n * The `Templatizer` behavior adds methods to generate instances of\n * templates that are each managed by an anonymous `PropertyEffects`\n * instance where data-bindings in the stamped template content are bound to\n * accessors on itself.\n *\n * This behavior is provided in Polymer 2.x-3.x as a hybrid-element convenience\n * only.  For non-hybrid usage, the `Templatize` library\n * should be used instead.\n *\n * Example:\n *\n *     import {dom} from '@polymer/polymer/lib/legacy/polymer.dom.js';\n *     // Get a template from somewhere, e.g. light DOM\n *     let template = this.querySelector('template');\n *     // Prepare the template\n *     this.templatize(template);\n *     // Instance the template with an initial data model\n *     let instance = this.stamp({myProp: 'initial'});\n *     // Insert the instance's DOM somewhere, e.g. light DOM\n *     dom(this).appendChild(instance.root);\n *     // Changing a property on the instance will propagate to bindings\n *     // in the template\n *     instance.myProp = 'new value';\n *\n * Users of `Templatizer` may need to implement the following abstract\n * API's to determine how properties and paths from the host should be\n * forwarded into to instances:\n *\n *     _forwardHostPropV2: function(prop, value)\n *\n * Likewise, users may implement these additional abstract API's to determine\n * how instance-specific properties that change on the instance should be\n * forwarded out to the host, if necessary.\n *\n *     _notifyInstancePropV2: function(inst, prop, value)\n *\n * In order to determine which properties are instance-specific and require\n * custom notification via `_notifyInstanceProp`, define an `_instanceProps`\n * object containing keys for each instance prop, for example:\n *\n *     _instanceProps: {\n *       item: true,\n *       index: true\n *     }\n *\n * Any properties used in the template that are not defined in _instanceProp\n * will be forwarded out to the Templatize `owner` automatically.\n *\n * Users may also implement the following abstract function to show or\n * hide any DOM generated using `stamp`:\n *\n *     _showHideChildren: function(shouldHide)\n *\n * Note that some callbacks are suffixed with `V2` in the Polymer 2.x behavior\n * as the implementations will need to differ from the callbacks required\n * by the 1.x Templatizer API due to changes in the `TemplateInstance` API\n * between versions 1.x and 2.x.\n *\n * @polymerBehavior\n */\n\nconst Templatizer = {\n  /**\n   * Generates an anonymous `TemplateInstance` class (stored as `this.ctor`)\n   * for the provided template.  This method should be called once per\n   * template to prepare an element for stamping the template, followed\n   * by `stamp` to create new instances of the template.\n   *\n   * @param {!HTMLTemplateElement} template Template to prepare\n   * @param {boolean=} mutableData When `true`, the generated class will skip\n   *   strict dirty-checking for objects and arrays (always consider them to\n   *   be \"dirty\"). Defaults to false.\n   * @return {void}\n   * @this {TemplatizerUser}\n   */\n  templatize(template, mutableData) {\n    this._templatizerTemplate = template;\n    this.ctor = (0,_utils_templatize_js__WEBPACK_IMPORTED_MODULE_0__.templatize)(template, this, {\n      mutableData: Boolean(mutableData),\n      parentModel: this._parentModel,\n      instanceProps: this._instanceProps,\n      forwardHostProp: this._forwardHostPropV2,\n      notifyInstanceProp: this._notifyInstancePropV2\n    });\n  },\n\n  /**\n   * Creates an instance of the template prepared by `templatize`.  The object\n   * returned is an instance of the anonymous class generated by `templatize`\n   * whose `root` property is a document fragment containing newly cloned\n   * template content, and which has property accessors corresponding to\n   * properties referenced in template bindings.\n   *\n   * @param {Object=} model Object containing initial property values to\n   *   populate into the template bindings.\n   * @return {TemplateInstanceBase} Returns the created instance of\n   * the template prepared by `templatize`.\n   * @this {TemplatizerUser}\n   */\n  stamp(model) {\n    return new this.ctor(model);\n  },\n\n  /**\n   * Returns the template \"model\" (`TemplateInstance`) associated with\n   * a given element, which serves as the binding scope for the template\n   * instance the element is contained in.  A template model should be used\n   * to manipulate data associated with this template instance.\n   *\n   * @param {HTMLElement} el Element for which to return a template model.\n   * @return {TemplateInstanceBase} Model representing the binding scope for\n   *   the element.\n   * @this {TemplatizerUser}\n   */\n  modelForElement(el) {\n    return (0,_utils_templatize_js__WEBPACK_IMPORTED_MODULE_0__.modelForElement)(this._templatizerTemplate, el);\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/legacy/templatizer-behavior.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/dir-mixin.js":
/*!***************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/dir-mixin.js ***!
  \***************************************************************/
/*! namespace exports */
/*! export DirMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DirMixin\": () => /* binding */ DirMixin\n/* harmony export */ });\n/* harmony import */ var _property_accessors_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./property-accessors.js */ \"./node_modules/@polymer/polymer/lib/mixins/property-accessors.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\nconst HOST_DIR = /:host\\(:dir\\((ltr|rtl)\\)\\)/g;\nconst HOST_DIR_REPLACMENT = ':host([dir=\"$1\"])';\nconst EL_DIR = /([\\s\\w-#\\.\\[\\]\\*]*):dir\\((ltr|rtl)\\)/g;\nconst EL_DIR_REPLACMENT = ':host([dir=\"$2\"]) $1';\n/**\n * @type {!Array<!Polymer_DirMixin>}\n */\n\nconst DIR_INSTANCES = [];\n/** @type {MutationObserver} */\n\nlet observer = null;\nlet DOCUMENT_DIR = '';\n\nfunction getRTL() {\n  DOCUMENT_DIR = document.documentElement.getAttribute('dir');\n}\n/**\n * @param {!Polymer_DirMixin} instance Instance to set RTL status on\n */\n\n\nfunction setRTL(instance) {\n  if (!instance.__autoDirOptOut) {\n    const el =\n    /** @type {!HTMLElement} */\n    instance;\n    el.setAttribute('dir', DOCUMENT_DIR);\n  }\n}\n\nfunction updateDirection() {\n  getRTL();\n  DOCUMENT_DIR = document.documentElement.getAttribute('dir');\n\n  for (let i = 0; i < DIR_INSTANCES.length; i++) {\n    setRTL(DIR_INSTANCES[i]);\n  }\n}\n\nfunction takeRecords() {\n  if (observer && observer.takeRecords().length) {\n    updateDirection();\n  }\n}\n/**\n * Element class mixin that allows elements to use the `:dir` CSS Selector to\n * have text direction specific styling.\n *\n * With this mixin, any stylesheet provided in the template will transform\n * `:dir` into `:host([dir])` and sync direction with the page via the\n * element's `dir` attribute.\n *\n * Elements can opt out of the global page text direction by setting the `dir`\n * attribute directly in `ready()` or in HTML.\n *\n * Caveats:\n * - Applications must set `<html dir=\"ltr\">` or `<html dir=\"rtl\">` to sync\n *   direction\n * - Automatic left-to-right or right-to-left styling is sync'd with the\n *   `<html>` element only.\n * - Changing `dir` at runtime is supported.\n * - Opting out of the global direction styling is permanent\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin PropertyAccessors\n */\n\n\nconst DirMixin = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(base => {\n  if (!observer) {\n    getRTL();\n    observer = new MutationObserver(updateDirection);\n    observer.observe(document.documentElement, {\n      attributes: true,\n      attributeFilter: ['dir']\n    });\n  }\n  /**\n   * @constructor\n   * @extends {base}\n   * @implements {Polymer_PropertyAccessors}\n   * @private\n   */\n\n\n  const elementBase = (0,_property_accessors_js__WEBPACK_IMPORTED_MODULE_0__.PropertyAccessors)(base);\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_DirMixin}\n   */\n\n  class Dir extends elementBase {\n    /**\n     * @override\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n    static _processStyleText(cssText, baseURI) {\n      cssText = super._processStyleText(cssText, baseURI);\n      cssText = this._replaceDirInCssText(cssText);\n      return cssText;\n    }\n    /**\n     * Replace `:dir` in the given CSS text\n     *\n     * @param {string} text CSS text to replace DIR\n     * @return {string} Modified CSS\n     */\n\n\n    static _replaceDirInCssText(text) {\n      let replacedText = text;\n      replacedText = replacedText.replace(HOST_DIR, HOST_DIR_REPLACMENT);\n      replacedText = replacedText.replace(EL_DIR, EL_DIR_REPLACMENT);\n\n      if (text !== replacedText) {\n        this.__activateDir = true;\n      }\n\n      return replacedText;\n    }\n\n    constructor() {\n      super();\n      /** @type {boolean} */\n\n      this.__autoDirOptOut = false;\n    }\n    /**\n     * @suppress {invalidCasts} Closure doesn't understand that `this` is an HTMLElement\n     * @return {void}\n     */\n\n\n    ready() {\n      super.ready();\n      this.__autoDirOptOut =\n      /** @type {!HTMLElement} */\n      this.hasAttribute('dir');\n    }\n    /**\n     * @suppress {missingProperties} If it exists on elementBase, it can be super'd\n     * @return {void}\n     */\n\n\n    connectedCallback() {\n      if (elementBase.prototype.connectedCallback) {\n        super.connectedCallback();\n      }\n\n      if (this.constructor.__activateDir) {\n        takeRecords();\n        DIR_INSTANCES.push(this);\n        setRTL(this);\n      }\n    }\n    /**\n     * @suppress {missingProperties} If it exists on elementBase, it can be super'd\n     * @return {void}\n     */\n\n\n    disconnectedCallback() {\n      if (elementBase.prototype.disconnectedCallback) {\n        super.disconnectedCallback();\n      }\n\n      if (this.constructor.__activateDir) {\n        const idx = DIR_INSTANCES.indexOf(this);\n\n        if (idx > -1) {\n          DIR_INSTANCES.splice(idx, 1);\n        }\n      }\n    }\n\n  }\n\n  Dir.__activateDir = false;\n  return Dir;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/dir-mixin.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/element-mixin.js":
/*!*******************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/element-mixin.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export ElementMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export dumpRegistrations [provided] [no usage info] [missing usage info prevents renaming] */
/*! export instanceCount [provided] [no usage info] [missing usage info prevents renaming] */
/*! export register [provided] [no usage info] [missing usage info prevents renaming] */
/*! export registrations [provided] [no usage info] [missing usage info prevents renaming] */
/*! export updateStyles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export version [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"version\": () => /* binding */ version,\n/* harmony export */   \"ElementMixin\": () => /* binding */ ElementMixin,\n/* harmony export */   \"instanceCount\": () => /* binding */ instanceCount,\n/* harmony export */   \"registrations\": () => /* binding */ registrations,\n/* harmony export */   \"register\": () => /* binding */ register,\n/* harmony export */   \"dumpRegistrations\": () => /* binding */ dumpRegistrations,\n/* harmony export */   \"updateStyles\": () => /* binding */ updateStyles\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_style_gather_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/style-gather.js */ \"./node_modules/@polymer/polymer/lib/utils/style-gather.js\");\n/* harmony import */ var _utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../utils/resolve-url.js */ \"./node_modules/@polymer/polymer/lib/utils/resolve-url.js\");\n/* harmony import */ var _elements_dom_module_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../elements/dom-module.js */ \"./node_modules/@polymer/polymer/lib/elements/dom-module.js\");\n/* harmony import */ var _property_effects_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./property-effects.js */ \"./node_modules/@polymer/polymer/lib/mixins/property-effects.js\");\n/* harmony import */ var _properties_mixin_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./properties-mixin.js */ \"./node_modules/@polymer/polymer/lib/mixins/properties-mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n\n\n/**\n * Current Polymer version in Semver notation.\n * @type {string} Semver notation of the current version of Polymer.\n */\n\nconst version = '3.0.5';\n/**\n * Element class mixin that provides the core API for Polymer's meta-programming\n * features including template stamping, data-binding, attribute deserialization,\n * and property change observation.\n *\n * Subclassers may provide the following static getters to return metadata\n * used to configure Polymer's features for the class:\n *\n * - `static get is()`: When the template is provided via a `dom-module`,\n *   users should return the `dom-module` id from a static `is` getter.  If\n *   no template is needed or the template is provided directly via the\n *   `template` getter, there is no need to define `is` for the element.\n *\n * - `static get template()`: Users may provide the template directly (as\n *   opposed to via `dom-module`) by implementing a static `template` getter.\n *   The getter must return an `HTMLTemplateElement`.\n *\n * - `static get properties()`: Should return an object describing\n *   property-related metadata used by Polymer features (key: property name\n *   value: object containing property metadata). Valid keys in per-property\n *   metadata include:\n *   - `type` (String|Number|Object|Array|...): Used by\n *     `attributeChangedCallback` to determine how string-based attributes\n *     are deserialized to JavaScript property values.\n *   - `notify` (boolean): Causes a change in the property to fire a\n *     non-bubbling event called `<property>-changed`. Elements that have\n *     enabled two-way binding to the property use this event to observe changes.\n *   - `readOnly` (boolean): Creates a getter for the property, but no setter.\n *     To set a read-only property, use the private setter method\n *     `_setProperty(property, value)`.\n *   - `observer` (string): Observer method name that will be called when\n *     the property changes. The arguments of the method are\n *     `(value, previousValue)`.\n *   - `computed` (string): String describing method and dependent properties\n *     for computing the value of this property (e.g. `'computeFoo(bar, zot)'`).\n *     Computed properties are read-only by default and can only be changed\n *     via the return value of the computing method.\n *\n * - `static get observers()`: Array of strings describing multi-property\n *   observer methods and their dependent properties (e.g.\n *   `'observeABC(a, b, c)'`).\n *\n * The base class provides default implementations for the following standard\n * custom element lifecycle callbacks; users may override these, but should\n * call the super method to ensure\n * - `constructor`: Run when the element is created or upgraded\n * - `connectedCallback`: Run each time the element is connected to the\n *   document\n * - `disconnectedCallback`: Run each time the element is disconnected from\n *   the document\n * - `attributeChangedCallback`: Run each time an attribute in\n *   `observedAttributes` is set or removed (note: this element's default\n *   `observedAttributes` implementation will automatically return an array\n *   of dash-cased attributes based on `properties`)\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin PropertyEffects\n * @appliesMixin PropertiesMixin\n * @property rootPath {string} Set to the value of `rootPath`,\n *   which defaults to the main document path\n * @property importPath {string} Set to the value of the class's static\n *   `importPath` property, which defaults to the path of this element's\n *   `dom-module` (when `is` is used), but can be overridden for other\n *   import strategies.\n * @summary Element class mixin that provides the core API for Polymer's\n * meta-programming features.\n */\n\nconst ElementMixin = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_2__.dedupingMixin)(base => {\n  /**\n   * @constructor\n   * @extends {base}\n   * @implements {Polymer_PropertyEffects}\n   * @implements {Polymer_PropertiesMixin}\n   * @private\n   */\n  const polymerElementBase = (0,_properties_mixin_js__WEBPACK_IMPORTED_MODULE_7__.PropertiesMixin)((0,_property_effects_js__WEBPACK_IMPORTED_MODULE_6__.PropertyEffects)(base));\n  /**\n   * Returns a list of properties with default values.\n   * This list is created as an optimization since it is a subset of\n   * the list returned from `_properties`.\n   * This list is used in `_initializeProperties` to set property defaults.\n   *\n   * @param {PolymerElementConstructor} constructor Element class\n   * @return {PolymerElementProperties} Flattened properties for this class\n   *   that have default values\n   * @private\n   */\n\n  function propertyDefaults(constructor) {\n    if (!constructor.hasOwnProperty(JSCompiler_renameProperty('__propertyDefaults', constructor))) {\n      constructor.__propertyDefaults = null;\n      let props = constructor._properties;\n\n      for (let p in props) {\n        let info = props[p];\n\n        if ('value' in info) {\n          constructor.__propertyDefaults = constructor.__propertyDefaults || {};\n          constructor.__propertyDefaults[p] = info;\n        }\n      }\n    }\n\n    return constructor.__propertyDefaults;\n  }\n  /**\n   * Returns a memoized version of the `observers` array.\n   * @param {PolymerElementConstructor} constructor Element class\n   * @return {Array} Array containing own observers for the given class\n   * @protected\n   */\n\n\n  function ownObservers(constructor) {\n    if (!constructor.hasOwnProperty(JSCompiler_renameProperty('__ownObservers', constructor))) {\n      constructor.__ownObservers = constructor.hasOwnProperty(JSCompiler_renameProperty('observers', constructor)) ?\n      /** @type {PolymerElementConstructor} */\n      constructor.observers : null;\n    }\n\n    return constructor.__ownObservers;\n  }\n  /**\n   * Creates effects for a property.\n   *\n   * Note, once a property has been set to\n   * `readOnly`, `computed`, `reflectToAttribute`, or `notify`\n   * these values may not be changed. For example, a subclass cannot\n   * alter these settings. However, additional `observers` may be added\n   * by subclasses.\n   *\n   * The info object should contain property metadata as follows:\n   *\n   * * `type`: {function} type to which an attribute matching the property\n   * is deserialized. Note the property is camel-cased from a dash-cased\n   * attribute. For example, 'foo-bar' attribute is deserialized to a\n   * property named 'fooBar'.\n   *\n   * * `readOnly`: {boolean} creates a readOnly property and\n   * makes a private setter for the private of the form '_setFoo' for a\n   * property 'foo',\n   *\n   * * `computed`: {string} creates a computed property. A computed property\n   * is also automatically set to `readOnly: true`. The value is calculated\n   * by running a method and arguments parsed from the given string. For\n   * example 'compute(foo)' will compute a given property when the\n   * 'foo' property changes by executing the 'compute' method. This method\n   * must return the computed value.\n   *\n   * * `reflectToAttribute`: {boolean} If true, the property value is reflected\n   * to an attribute of the same name. Note, the attribute is dash-cased\n   * so a property named 'fooBar' is reflected as 'foo-bar'.\n   *\n   * * `notify`: {boolean} sends a non-bubbling notification event when\n   * the property changes. For example, a property named 'foo' sends an\n   * event named 'foo-changed' with `event.detail` set to the value of\n   * the property.\n   *\n   * * observer: {string} name of a method that runs when the property\n   * changes. The arguments of the method are (value, previousValue).\n   *\n   * Note: Users may want control over modifying property\n   * effects via subclassing. For example, a user might want to make a\n   * reflectToAttribute property not do so in a subclass. We've chosen to\n   * disable this because it leads to additional complication.\n   * For example, a readOnly effect generates a special setter. If a subclass\n   * disables the effect, the setter would fail unexpectedly.\n   * Based on feedback, we may want to try to make effects more malleable\n   * and/or provide an advanced api for manipulating them.\n   * Also consider adding warnings when an effect cannot be changed.\n   *\n   * @param {!PolymerElement} proto Element class prototype to add accessors\n   *   and effects to\n   * @param {string} name Name of the property.\n   * @param {Object} info Info object from which to create property effects.\n   * Supported keys:\n   * @param {Object} allProps Flattened map of all properties defined in this\n   *   element (including inherited properties)\n   * @return {void}\n   * @private\n   */\n\n\n  function createPropertyFromConfig(proto, name, info, allProps) {\n    // computed forces readOnly...\n    if (info.computed) {\n      info.readOnly = true;\n    } // Note, since all computed properties are readOnly, this prevents\n    // adding additional computed property effects (which leads to a confusing\n    // setup where multiple triggers for setting a property)\n    // While we do have `hasComputedEffect` this is set on the property's\n    // dependencies rather than itself.\n\n\n    if (info.computed && !proto._hasReadOnlyEffect(name)) {\n      proto._createComputedProperty(name, info.computed, allProps);\n    }\n\n    if (info.readOnly && !proto._hasReadOnlyEffect(name)) {\n      proto._createReadOnlyProperty(name, !info.computed);\n    }\n\n    if (info.reflectToAttribute && !proto._hasReflectEffect(name)) {\n      proto._createReflectedProperty(name);\n    }\n\n    if (info.notify && !proto._hasNotifyEffect(name)) {\n      proto._createNotifyingProperty(name);\n    } // always add observer\n\n\n    if (info.observer) {\n      proto._createPropertyObserver(name, info.observer, allProps[info.observer]);\n    } // always create the mapping from attribute back to property for deserialization.\n\n\n    proto._addPropertyToAttributeMap(name);\n  }\n  /**\n   * Process all style elements in the element template. Styles with the\n   * `include` attribute are processed such that any styles in\n   * the associated \"style modules\" are included in the element template.\n   * @param {PolymerElementConstructor} klass Element class\n   * @param {!HTMLTemplateElement} template Template to process\n   * @param {string} is Name of element\n   * @param {string} baseURI Base URI for element\n   * @private\n   */\n\n\n  function processElementStyles(klass, template, is, baseURI) {\n    const templateStyles = template.content.querySelectorAll('style');\n    const stylesWithImports = (0,_utils_style_gather_js__WEBPACK_IMPORTED_MODULE_3__.stylesFromTemplate)(template); // insert styles from <link rel=\"import\" type=\"css\"> at the top of the template\n\n    const linkedStyles = (0,_utils_style_gather_js__WEBPACK_IMPORTED_MODULE_3__.stylesFromModuleImports)(is);\n    const firstTemplateChild = template.content.firstElementChild;\n\n    for (let idx = 0; idx < linkedStyles.length; idx++) {\n      let s = linkedStyles[idx];\n      s.textContent = klass._processStyleText(s.textContent, baseURI);\n      template.content.insertBefore(s, firstTemplateChild);\n    } // keep track of the last \"concrete\" style in the template we have encountered\n\n\n    let templateStyleIndex = 0; // ensure all gathered styles are actually in this template.\n\n    for (let i = 0; i < stylesWithImports.length; i++) {\n      let s = stylesWithImports[i];\n      let templateStyle = templateStyles[templateStyleIndex]; // if the style is not in this template, it's been \"included\" and\n      // we put a clone of it in the template before the style that included it\n\n      if (templateStyle !== s) {\n        s = s.cloneNode(true);\n        templateStyle.parentNode.insertBefore(s, templateStyle);\n      } else {\n        templateStyleIndex++;\n      }\n\n      s.textContent = klass._processStyleText(s.textContent, baseURI);\n    }\n\n    if (window.ShadyCSS) {\n      window.ShadyCSS.prepareTemplate(template, is);\n    }\n  }\n  /**\n   * Look up template from dom-module for element\n   *\n   * @param {!string} is Element name to look up\n   * @return {!HTMLTemplateElement} Template found in dom module, or\n   *   undefined if not found\n   * @protected\n   */\n\n\n  function getTemplateFromDomModule(is) {\n    let template = null; // Under strictTemplatePolicy in 3.x+, dom-module lookup is only allowed\n    // when opted-in via allowTemplateFromDomModule\n\n    if (is && (!_utils_settings_js__WEBPACK_IMPORTED_MODULE_1__.strictTemplatePolicy || _utils_settings_js__WEBPACK_IMPORTED_MODULE_1__.allowTemplateFromDomModule)) {\n      template = _elements_dom_module_js__WEBPACK_IMPORTED_MODULE_5__.DomModule.import(is, 'template'); // Under strictTemplatePolicy, require any element with an `is`\n      // specified to have a dom-module\n\n      if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_1__.strictTemplatePolicy && !template) {\n        throw new Error(`strictTemplatePolicy: expecting dom-module or null template for ${is}`);\n      }\n    }\n\n    return template;\n  }\n  /**\n   * @polymer\n   * @mixinClass\n   * @unrestricted\n   * @implements {Polymer_ElementMixin}\n   */\n\n\n  class PolymerElement extends polymerElementBase {\n    /**\n     * Current Polymer version in Semver notation.\n     * @type {string} Semver notation of the current version of Polymer.\n     */\n    static get polymerElementVersion() {\n      return version;\n    }\n    /**\n     * Override of PropertiesMixin _finalizeClass to create observers and\n     * find the template.\n     * @return {void}\n     * @protected\n     * @override\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n\n\n    static _finalizeClass() {\n      super._finalizeClass();\n\n      if (this.hasOwnProperty(JSCompiler_renameProperty('is', this)) && this.is) {\n        register(this.prototype);\n      }\n\n      const observers = ownObservers(this);\n\n      if (observers) {\n        this.createObservers(observers, this._properties);\n      } // note: create \"working\" template that is finalized at instance time\n\n\n      let template =\n      /** @type {PolymerElementConstructor} */\n      this.template;\n\n      if (template) {\n        if (typeof template === 'string') {\n          console.error('template getter must return HTMLTemplateElement');\n          template = null;\n        } else {\n          template = template.cloneNode(true);\n        }\n      }\n\n      this.prototype._template = template;\n    }\n    /**\n     * Override of PropertiesChanged createProperties to create accessors\n     * and property effects for all of the properties.\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    static createProperties(props) {\n      for (let p in props) {\n        createPropertyFromConfig(this.prototype, p, props[p], props);\n      }\n    }\n    /**\n     * Creates observers for the given `observers` array.\n     * Leverages `PropertyEffects` to create observers.\n     * @param {Object} observers Array of observer descriptors for\n     *   this class\n     * @param {Object} dynamicFns Object containing keys for any properties\n     *   that are functions and should trigger the effect when the function\n     *   reference is changed\n     * @return {void}\n     * @protected\n     */\n\n\n    static createObservers(observers, dynamicFns) {\n      const proto = this.prototype;\n\n      for (let i = 0; i < observers.length; i++) {\n        proto._createMethodObserver(observers[i], dynamicFns);\n      }\n    }\n    /**\n     * Returns the template that will be stamped into this element's shadow root.\n     *\n     * If a `static get is()` getter is defined, the default implementation\n     * will return the first `<template>` in a `dom-module` whose `id`\n     * matches this element's `is`.\n     *\n     * Users may override this getter to return an arbitrary template\n     * (in which case the `is` getter is unnecessary). The template returned\n     * must be an `HTMLTemplateElement`.\n     *\n     * Note that when subclassing, if the super class overrode the default\n     * implementation and the subclass would like to provide an alternate\n     * template via a `dom-module`, it should override this getter and\n     * return `DomModule.import(this.is, 'template')`.\n     *\n     * If a subclass would like to modify the super class template, it should\n     * clone it rather than modify it in place.  If the getter does expensive\n     * work such as cloning/modifying a template, it should memoize the\n     * template for maximum performance:\n     *\n     *   let memoizedTemplate;\n     *   class MySubClass extends MySuperClass {\n     *     static get template() {\n     *       if (!memoizedTemplate) {\n     *         memoizedTemplate = super.template.cloneNode(true);\n     *         let subContent = document.createElement('div');\n     *         subContent.textContent = 'This came from MySubClass';\n     *         memoizedTemplate.content.appendChild(subContent);\n     *       }\n     *       return memoizedTemplate;\n     *     }\n     *   }\n     *\n     * @return {!HTMLTemplateElement|string} Template to be stamped\n     */\n\n\n    static get template() {\n      // Explanation of template-related properties:\n      // - constructor.template (this getter): the template for the class.\n      //     This can come from the prototype (for legacy elements), from a\n      //     dom-module, or from the super class's template (or can be overridden\n      //     altogether by the user)\n      // - constructor._template: memoized version of constructor.template\n      // - prototype._template: working template for the element, which will be\n      //     parsed and modified in place. It is a cloned version of\n      //     constructor.template, saved in _finalizeClass(). Note that before\n      //     this getter is called, for legacy elements this could be from a\n      //     _template field on the info object passed to Polymer(), a behavior,\n      //     or set in registered(); once the static getter runs, a clone of it\n      //     will overwrite it on the prototype as the working template.\n      if (!this.hasOwnProperty(JSCompiler_renameProperty('_template', this))) {\n        this._template = // If user has put template on prototype (e.g. in legacy via registered\n        // callback or info object), prefer that first\n        this.prototype.hasOwnProperty(JSCompiler_renameProperty('_template', this.prototype)) ? this.prototype._template : // Look in dom-module associated with this element's is\n        getTemplateFromDomModule(\n        /** @type {PolymerElementConstructor}*/\n        this.is) || // Next look for superclass template (call the super impl this\n        // way so that `this` points to the superclass)\n        Object.getPrototypeOf(\n        /** @type {PolymerElementConstructor}*/\n        this.prototype).constructor.template;\n      }\n\n      return this._template;\n    }\n    /**\n     * Set the template.\n     *\n     * @param {!HTMLTemplateElement|string} value Template to set.\n     */\n\n\n    static set template(value) {\n      this._template = value;\n    }\n    /**\n     * Path matching the url from which the element was imported.\n     *\n     * This path is used to resolve url's in template style cssText.\n     * The `importPath` property is also set on element instances and can be\n     * used to create bindings relative to the import path.\n     *\n     * For elements defined in ES modules, users should implement\n     * `static get importMeta() { return import.meta; }`, and the default\n     * implementation of `importPath` will  return `import.meta.url`'s path.\n     * For elements defined in HTML imports, this getter will return the path\n     * to the document containing a `dom-module` element matching this\n     * element's static `is` property.\n     *\n     * Note, this path should contain a trailing `/`.\n     *\n     * @return {string} The import path for this element class\n     * @suppress {missingProperties}\n     */\n\n\n    static get importPath() {\n      if (!this.hasOwnProperty(JSCompiler_renameProperty('_importPath', this))) {\n        const meta = this.importMeta;\n\n        if (meta) {\n          this._importPath = (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__.pathFromUrl)(meta.url);\n        } else {\n          const module = _elements_dom_module_js__WEBPACK_IMPORTED_MODULE_5__.DomModule.import(\n          /** @type {PolymerElementConstructor} */\n          this.is);\n          this._importPath = module && module.assetpath || Object.getPrototypeOf(\n          /** @type {PolymerElementConstructor}*/\n          this.prototype).constructor.importPath;\n        }\n      }\n\n      return this._importPath;\n    }\n\n    constructor() {\n      super();\n      /** @type {HTMLTemplateElement} */\n\n      this._template;\n      /** @type {string} */\n\n      this._importPath;\n      /** @type {string} */\n\n      this.rootPath;\n      /** @type {string} */\n\n      this.importPath;\n      /** @type {StampedTemplate | HTMLElement | ShadowRoot} */\n\n      this.root;\n      /** @type {!Object<string, !Element>} */\n\n      this.$;\n    }\n    /**\n     * Overrides the default `PropertyAccessors` to ensure class\n     * metaprogramming related to property accessors and effects has\n     * completed (calls `finalize`).\n     *\n     * It also initializes any property defaults provided via `value` in\n     * `properties` metadata.\n     *\n     * @return {void}\n     * @override\n     * @suppress {invalidCasts}\n     */\n\n\n    _initializeProperties() {\n      instanceCount++;\n      this.constructor.finalize(); // note: finalize template when we have access to `localName` to\n      // avoid dependence on `is` for polyfilling styling.\n\n      this.constructor._finalizeTemplate(\n      /** @type {!HTMLElement} */\n      this.localName);\n\n      super._initializeProperties(); // set path defaults\n\n\n      this.rootPath = _utils_settings_js__WEBPACK_IMPORTED_MODULE_1__.rootPath;\n      this.importPath = this.constructor.importPath; // apply property defaults...\n\n      let p$ = propertyDefaults(this.constructor);\n\n      if (!p$) {\n        return;\n      }\n\n      for (let p in p$) {\n        let info = p$[p]; // Don't set default value if there is already an own property, which\n        // happens when a `properties` property with default but no effects had\n        // a property set (e.g. bound) by its host before upgrade\n\n        if (!this.hasOwnProperty(p)) {\n          let value = typeof info.value == 'function' ? info.value.call(this) : info.value; // Set via `_setProperty` if there is an accessor, to enable\n          // initializing readOnly property defaults\n\n          if (this._hasAccessor(p)) {\n            this._setPendingProperty(p, value, true);\n          } else {\n            this[p] = value;\n          }\n        }\n      }\n    }\n    /**\n     * Gather style text for a style element in the template.\n     *\n     * @param {string} cssText Text containing styling to process\n     * @param {string} baseURI Base URI to rebase CSS paths against\n     * @return {string} The processed CSS text\n     * @protected\n     */\n\n\n    static _processStyleText(cssText, baseURI) {\n      return (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__.resolveCss)(cssText, baseURI);\n    }\n    /**\n    * Configures an element `proto` to function with a given `template`.\n    * The element name `is` and extends `ext` must be specified for ShadyCSS\n    * style scoping.\n    *\n    * @param {string} is Tag name (or type extension name) for this element\n    * @return {void}\n    * @protected\n    */\n\n\n    static _finalizeTemplate(is) {\n      /** @const {HTMLTemplateElement} */\n      const template = this.prototype._template;\n\n      if (template && !template.__polymerFinalized) {\n        template.__polymerFinalized = true;\n        const importPath = this.importPath;\n        const baseURI = importPath ? (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__.resolveUrl)(importPath) : ''; // e.g. support `include=\"module-name\"`, and ShadyCSS\n\n        processElementStyles(this, template, is, baseURI);\n\n        this.prototype._bindTemplate(template);\n      }\n    }\n    /**\n     * Provides a default implementation of the standard Custom Elements\n     * `connectedCallback`.\n     *\n     * The default implementation enables the property effects system and\n     * flushes any pending properties, and updates shimmed CSS properties\n     * when using the ShadyCSS scoping/custom properties polyfill.\n     *\n     * @suppress {missingProperties, invalidCasts} Super may or may not implement the callback\n     * @return {void}\n     */\n\n\n    connectedCallback() {\n      if (window.ShadyCSS && this._template) {\n        window.ShadyCSS.styleElement(\n        /** @type {!HTMLElement} */\n        this);\n      }\n\n      super.connectedCallback();\n    }\n    /**\n     * Stamps the element template.\n     *\n     * @return {void}\n     * @override\n     */\n\n\n    ready() {\n      if (this._template) {\n        this.root = this._stampTemplate(this._template);\n        this.$ = this.root.$;\n      }\n\n      super.ready();\n    }\n    /**\n     * Implements `PropertyEffects`'s `_readyClients` call. Attaches\n     * element dom by calling `_attachDom` with the dom stamped from the\n     * element's template via `_stampTemplate`. Note that this allows\n     * client dom to be attached to the element prior to any observers\n     * running.\n     *\n     * @return {void}\n     * @override\n     */\n\n\n    _readyClients() {\n      if (this._template) {\n        this.root = this._attachDom(\n        /** @type {StampedTemplate} */\n        this.root);\n      } // The super._readyClients here sets the clients initialized flag.\n      // We must wait to do this until after client dom is created/attached\n      // so that this flag can be checked to prevent notifications fired\n      // during this process from being handled before clients are ready.\n\n\n      super._readyClients();\n    }\n    /**\n     * Attaches an element's stamped dom to itself. By default,\n     * this method creates a `shadowRoot` and adds the dom to it.\n     * However, this method may be overridden to allow an element\n     * to put its dom in another location.\n     *\n     * @throws {Error}\n     * @suppress {missingReturn}\n     * @param {StampedTemplate} dom to attach to the element.\n     * @return {ShadowRoot} node to which the dom has been attached.\n     */\n\n\n    _attachDom(dom) {\n      if (this.attachShadow) {\n        if (dom) {\n          if (!this.shadowRoot) {\n            this.attachShadow({\n              mode: 'open'\n            });\n          }\n\n          this.shadowRoot.appendChild(dom);\n          return this.shadowRoot;\n        }\n\n        return null;\n      } else {\n        throw new Error('ShadowDOM not available. ' + // TODO(sorvell): move to compile-time conditional when supported\n        'PolymerElement can create dom as children instead of in ' + 'ShadowDOM by setting `this.root = this;\\` before \\`ready\\`.');\n      }\n    }\n    /**\n     * When using the ShadyCSS scoping and custom property shim, causes all\n     * shimmed styles in this element (and its subtree) to be updated\n     * based on current custom property values.\n     *\n     * The optional parameter overrides inline custom property styles with an\n     * object of properties where the keys are CSS properties, and the values\n     * are strings.\n     *\n     * Example: `this.updateStyles({'--color': 'blue'})`\n     *\n     * These properties are retained unless a value of `null` is set.\n     *\n     * Note: This function does not support updating CSS mixins.\n     * You can not dynamically change the value of an `@apply`.\n     *\n     * @param {Object=} properties Bag of custom property key/values to\n     *   apply to this element.\n     * @return {void}\n     * @suppress {invalidCasts}\n     */\n\n\n    updateStyles(properties) {\n      if (window.ShadyCSS) {\n        window.ShadyCSS.styleSubtree(\n        /** @type {!HTMLElement} */\n        this, properties);\n      }\n    }\n    /**\n     * Rewrites a given URL relative to a base URL. The base URL defaults to\n     * the original location of the document containing the `dom-module` for\n     * this element. This method will return the same URL before and after\n     * bundling.\n     *\n     * Note that this function performs no resolution for URLs that start\n     * with `/` (absolute URLs) or `#` (hash identifiers).  For general purpose\n     * URL resolution, use `window.URL`.\n     *\n     * @param {string} url URL to resolve.\n     * @param {string=} base Optional base URL to resolve against, defaults\n     * to the element's `importPath`\n     * @return {string} Rewritten URL relative to base\n     */\n\n\n    resolveUrl(url, base) {\n      if (!base && this.importPath) {\n        base = (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__.resolveUrl)(this.importPath);\n      }\n\n      return (0,_utils_resolve_url_js__WEBPACK_IMPORTED_MODULE_4__.resolveUrl)(url, base);\n    }\n    /**\n     * Overrides `PropertyAccessors` to add map of dynamic functions on\n     * template info, for consumption by `PropertyEffects` template binding\n     * code. This map determines which method templates should have accessors\n     * created for them.\n     *\n     * @override\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n\n\n    static _parseTemplateContent(template, templateInfo, nodeInfo) {\n      templateInfo.dynamicFns = templateInfo.dynamicFns || this._properties;\n      return super._parseTemplateContent(template, templateInfo, nodeInfo);\n    }\n\n  }\n\n  return PolymerElement;\n});\n/**\n * Total number of Polymer element instances created.\n * @type {number}\n */\n\nlet instanceCount = 0;\n/**\n * Array of Polymer element classes that have been finalized.\n * @type {Array<PolymerElement>}\n */\n\nconst registrations = [];\n/**\n * @param {!PolymerElementConstructor} prototype Element prototype to log\n * @this {this}\n * @private\n */\n\nfunction _regLog(prototype) {\n  console.log('[' + prototype.is + ']: registered');\n}\n/**\n * Registers a class prototype for telemetry purposes.\n * @param {HTMLElement} prototype Element prototype to register\n * @this {this}\n * @protected\n */\n\n\nfunction register(prototype) {\n  registrations.push(prototype);\n}\n/**\n * Logs all elements registered with an `is` to the console.\n * @public\n * @this {this}\n */\n\nfunction dumpRegistrations() {\n  registrations.forEach(_regLog);\n}\n/**\n * When using the ShadyCSS scoping and custom property shim, causes all\n * shimmed `styles` (via `custom-style`) in the document (and its subtree)\n * to be updated based on current custom property values.\n *\n * The optional parameter overrides inline custom property styles with an\n * object of properties where the keys are CSS properties, and the values\n * are strings.\n *\n * Example: `updateStyles({'--color': 'blue'})`\n *\n * These properties are retained unless a value of `null` is set.\n *\n * @param {Object=} props Bag of custom property key/values to\n *   apply to the document.\n * @return {void}\n */\n\nconst updateStyles = function (props) {\n  if (window.ShadyCSS) {\n    window.ShadyCSS.styleDocument(props);\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/element-mixin.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/gesture-event-listeners.js":
/*!*****************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/gesture-event-listeners.js ***!
  \*****************************************************************************/
/*! namespace exports */
/*! export GestureEventListeners [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"GestureEventListeners\": () => /* binding */ GestureEventListeners\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_gestures_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/gestures.js */ \"./node_modules/@polymer/polymer/lib/utils/gestures.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * Element class mixin that provides API for adding Polymer's cross-platform\n * gesture events to nodes.\n *\n * The API is designed to be compatible with override points implemented\n * in `TemplateStamp` such that declarative event listeners in\n * templates will support gesture events when this mixin is applied along with\n * `TemplateStamp`.\n *\n * @mixinFunction\n * @polymer\n * @summary Element class mixin that provides API for adding Polymer's\n *   cross-platform\n * gesture events to nodes\n */\n\nconst GestureEventListeners = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(\n/**\n * @template T\n * @param {function(new:T)} superClass Class to apply mixin to.\n * @return {function(new:T)} superClass with mixin applied.\n */\nsuperClass => {\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_GestureEventListeners}\n   */\n  class GestureEventListeners extends superClass {\n    /**\n     * Add the event listener to the node if it is a gestures event.\n     *\n     * @param {!EventTarget} node Node to add event listener to\n     * @param {string} eventName Name of event\n     * @param {function(!Event):void} handler Listener function to add\n     * @return {void}\n     * @override\n     */\n    _addEventListenerToNode(node, eventName, handler) {\n      if (!(0,_utils_gestures_js__WEBPACK_IMPORTED_MODULE_2__.addListener)(node, eventName, handler)) {\n        super._addEventListenerToNode(node, eventName, handler);\n      }\n    }\n    /**\n     * Remove the event listener to the node if it is a gestures event.\n     *\n     * @param {!EventTarget} node Node to remove event listener from\n     * @param {string} eventName Name of event\n     * @param {function(!Event):void} handler Listener function to remove\n     * @return {void}\n     * @override\n     */\n\n\n    _removeEventListenerFromNode(node, eventName, handler) {\n      if (!(0,_utils_gestures_js__WEBPACK_IMPORTED_MODULE_2__.removeListener)(node, eventName, handler)) {\n        super._removeEventListenerFromNode(node, eventName, handler);\n      }\n    }\n\n  }\n\n  return GestureEventListeners;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/gesture-event-listeners.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/mutable-data.js":
/*!******************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/mutable-data.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export MutableData [provided] [no usage info] [missing usage info prevents renaming] */
/*! export OptionalMutableData [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"MutableData\": () => /* binding */ MutableData,\n/* harmony export */   \"OptionalMutableData\": () => /* binding */ OptionalMutableData\n/* harmony export */ });\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n // Common implementation for mixin & behavior\n\nfunction mutablePropertyChange(inst, property, value, old, mutableData) {\n  let isObject;\n\n  if (mutableData) {\n    isObject = typeof value === 'object' && value !== null; // Pull `old` for Objects from temp cache, but treat `null` as a primitive\n\n    if (isObject) {\n      old = inst.__dataTemp[property];\n    }\n  } // Strict equality check, but return false for NaN===NaN\n\n\n  let shouldChange = old !== value && (old === old || value === value); // Objects are stored in temporary cache (cleared at end of\n  // turn), which is used for dirty-checking\n\n  if (isObject && shouldChange) {\n    inst.__dataTemp[property] = value;\n  }\n\n  return shouldChange;\n}\n/**\n * Element class mixin to skip strict dirty-checking for objects and arrays\n * (always consider them to be \"dirty\"), for use on elements utilizing\n * `PropertyEffects`\n *\n * By default, `PropertyEffects` performs strict dirty checking on\n * objects, which means that any deep modifications to an object or array will\n * not be propagated unless \"immutable\" data patterns are used (i.e. all object\n * references from the root to the mutation were changed).\n *\n * Polymer also provides a proprietary data mutation and path notification API\n * (e.g. `notifyPath`, `set`, and array mutation API's) that allow efficient\n * mutation and notification of deep changes in an object graph to all elements\n * bound to the same object graph.\n *\n * In cases where neither immutable patterns nor the data mutation API can be\n * used, applying this mixin will cause Polymer to skip dirty checking for\n * objects and arrays (always consider them to be \"dirty\").  This allows a\n * user to make a deep modification to a bound object graph, and then either\n * simply re-set the object (e.g. `this.items = this.items`) or call `notifyPath`\n * (e.g. `this.notifyPath('items')`) to update the tree.  Note that all\n * elements that wish to be updated based on deep mutations must apply this\n * mixin or otherwise skip strict dirty checking for objects/arrays.\n * Specifically, any elements in the binding tree between the source of a\n * mutation and the consumption of it must apply this mixin or enable the\n * `OptionalMutableData` mixin.\n *\n * In order to make the dirty check strategy configurable, see\n * `OptionalMutableData`.\n *\n * Note, the performance characteristics of propagating large object graphs\n * will be worse as opposed to using strict dirty checking with immutable\n * patterns or Polymer's path notification API.\n *\n * @mixinFunction\n * @polymer\n * @summary Element class mixin to skip strict dirty-checking for objects\n *   and arrays\n */\n\n\nconst MutableData = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_0__.dedupingMixin)(superClass => {\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_MutableData}\n   */\n  class MutableData extends superClass {\n    /**\n     * Overrides `PropertyEffects` to provide option for skipping\n     * strict equality checking for Objects and Arrays.\n     *\n     * This method pulls the value to dirty check against from the `__dataTemp`\n     * cache (rather than the normal `__data` cache) for Objects.  Since the temp\n     * cache is cleared at the end of a turn, this implementation allows\n     * side-effects of deep object changes to be processed by re-setting the\n     * same object (using the temp cache as an in-turn backstop to prevent\n     * cycles due to 2-way notification).\n     *\n     * @param {string} property Property name\n     * @param {*} value New property value\n     * @param {*} old Previous property value\n     * @return {boolean} Whether the property should be considered a change\n     * @protected\n     */\n    _shouldPropertyChange(property, value, old) {\n      return mutablePropertyChange(this, property, value, old, true);\n    }\n\n  }\n\n  return MutableData;\n});\n/**\n * Element class mixin to add the optional ability to skip strict\n * dirty-checking for objects and arrays (always consider them to be\n * \"dirty\") by setting a `mutable-data` attribute on an element instance.\n *\n * By default, `PropertyEffects` performs strict dirty checking on\n * objects, which means that any deep modifications to an object or array will\n * not be propagated unless \"immutable\" data patterns are used (i.e. all object\n * references from the root to the mutation were changed).\n *\n * Polymer also provides a proprietary data mutation and path notification API\n * (e.g. `notifyPath`, `set`, and array mutation API's) that allow efficient\n * mutation and notification of deep changes in an object graph to all elements\n * bound to the same object graph.\n *\n * In cases where neither immutable patterns nor the data mutation API can be\n * used, applying this mixin will allow Polymer to skip dirty checking for\n * objects and arrays (always consider them to be \"dirty\").  This allows a\n * user to make a deep modification to a bound object graph, and then either\n * simply re-set the object (e.g. `this.items = this.items`) or call `notifyPath`\n * (e.g. `this.notifyPath('items')`) to update the tree.  Note that all\n * elements that wish to be updated based on deep mutations must apply this\n * mixin or otherwise skip strict dirty checking for objects/arrays.\n * Specifically, any elements in the binding tree between the source of a\n * mutation and the consumption of it must enable this mixin or apply the\n * `MutableData` mixin.\n *\n * While this mixin adds the ability to forgo Object/Array dirty checking,\n * the `mutableData` flag defaults to false and must be set on the instance.\n *\n * Note, the performance characteristics of propagating large object graphs\n * will be worse by relying on `mutableData: true` as opposed to using\n * strict dirty checking with immutable patterns or Polymer's path notification\n * API.\n *\n * @mixinFunction\n * @polymer\n * @summary Element class mixin to optionally skip strict dirty-checking\n *   for objects and arrays\n */\n\nconst OptionalMutableData = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_0__.dedupingMixin)(superClass => {\n  /**\n   * @mixinClass\n   * @polymer\n   * @implements {Polymer_OptionalMutableData}\n   */\n  class OptionalMutableData extends superClass {\n    static get properties() {\n      return {\n        /**\n         * Instance-level flag for configuring the dirty-checking strategy\n         * for this element.  When true, Objects and Arrays will skip dirty\n         * checking, otherwise strict equality checking will be used.\n         */\n        mutableData: Boolean\n      };\n    }\n    /**\n     * Overrides `PropertyEffects` to provide option for skipping\n     * strict equality checking for Objects and Arrays.\n     *\n     * When `this.mutableData` is true on this instance, this method\n     * pulls the value to dirty check against from the `__dataTemp` cache\n     * (rather than the normal `__data` cache) for Objects.  Since the temp\n     * cache is cleared at the end of a turn, this implementation allows\n     * side-effects of deep object changes to be processed by re-setting the\n     * same object (using the temp cache as an in-turn backstop to prevent\n     * cycles due to 2-way notification).\n     *\n     * @param {string} property Property name\n     * @param {*} value New property value\n     * @param {*} old Previous property value\n     * @return {boolean} Whether the property should be considered a change\n     * @protected\n     */\n\n\n    _shouldPropertyChange(property, value, old) {\n      return mutablePropertyChange(this, property, value, old, this.mutableData);\n    }\n\n  }\n\n  return OptionalMutableData;\n}); // Export for use by legacy behavior\n\nMutableData._mutablePropertyChange = mutablePropertyChange;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/mutable-data.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/properties-changed.js":
/*!************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/properties-changed.js ***!
  \************************************************************************/
/*! namespace exports */
/*! export PropertiesChanged [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PropertiesChanged\": () => /* binding */ PropertiesChanged\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_async_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/** @const {!AsyncInterface} */\n\nconst microtask = _utils_async_js__WEBPACK_IMPORTED_MODULE_2__.microTask;\n/**\n * Element class mixin that provides basic meta-programming for creating one\n * or more property accessors (getter/setter pair) that enqueue an async\n * (batched) `_propertiesChanged` callback.\n *\n * For basic usage of this mixin, call `MyClass.createProperties(props)`\n * once at class definition time to create property accessors for properties\n * named in props, implement `_propertiesChanged` to react as desired to\n * property changes, and implement `static get observedAttributes()` and\n * include lowercase versions of any property names that should be set from\n * attributes. Last, call `this._enableProperties()` in the element's\n * `connectedCallback` to enable the accessors.\n *\n * @mixinFunction\n * @polymer\n * @summary Element class mixin for reacting to property changes from\n *   generated property accessors.\n */\n\nconst PropertiesChanged = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(\n/**\n * @template T\n * @param {function(new:T)} superClass Class to apply mixin to.\n * @return {function(new:T)} superClass with mixin applied.\n */\nsuperClass => {\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_PropertiesChanged}\n   * @unrestricted\n   */\n  class PropertiesChanged extends superClass {\n    /**\n     * Creates property accessors for the given property names.\n     * @param {!Object} props Object whose keys are names of accessors.\n     * @return {void}\n     * @protected\n     */\n    static createProperties(props) {\n      const proto = this.prototype;\n\n      for (let prop in props) {\n        // don't stomp an existing accessor\n        if (!(prop in proto)) {\n          proto._createPropertyAccessor(prop);\n        }\n      }\n    }\n    /**\n     * Returns an attribute name that corresponds to the given property.\n     * The attribute name is the lowercased property name. Override to\n     * customize this mapping.\n     * @param {string} property Property to convert\n     * @return {string} Attribute name corresponding to the given property.\n     *\n     * @protected\n     */\n\n\n    static attributeNameForProperty(property) {\n      return property.toLowerCase();\n    }\n    /**\n     * Override point to provide a type to which to deserialize a value to\n     * a given property.\n     * @param {string} name Name of property\n     *\n     * @protected\n     */\n\n\n    static typeForProperty(name) {} //eslint-disable-line no-unused-vars\n\n    /**\n     * Creates a setter/getter pair for the named property with its own\n     * local storage.  The getter returns the value in the local storage,\n     * and the setter calls `_setProperty`, which updates the local storage\n     * for the property and enqueues a `_propertiesChanged` callback.\n     *\n     * This method may be called on a prototype or an instance.  Calling\n     * this method may overwrite a property value that already exists on\n     * the prototype/instance by creating the accessor.\n     *\n     * @param {string} property Name of the property\n     * @param {boolean=} readOnly When true, no setter is created; the\n     *   protected `_setProperty` function must be used to set the property\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _createPropertyAccessor(property, readOnly) {\n      this._addPropertyToAttributeMap(property);\n\n      if (!this.hasOwnProperty('__dataHasAccessor')) {\n        this.__dataHasAccessor = Object.assign({}, this.__dataHasAccessor);\n      }\n\n      if (!this.__dataHasAccessor[property]) {\n        this.__dataHasAccessor[property] = true;\n\n        this._definePropertyAccessor(property, readOnly);\n      }\n    }\n    /**\n     * Adds the given `property` to a map matching attribute names\n     * to property names, using `attributeNameForProperty`. This map is\n     * used when deserializing attribute values to properties.\n     *\n     * @param {string} property Name of the property\n     * @override\n     */\n\n\n    _addPropertyToAttributeMap(property) {\n      if (!this.hasOwnProperty('__dataAttributes')) {\n        this.__dataAttributes = Object.assign({}, this.__dataAttributes);\n      }\n\n      if (!this.__dataAttributes[property]) {\n        const attr = this.constructor.attributeNameForProperty(property);\n        this.__dataAttributes[attr] = property;\n      }\n    }\n    /**\n     * Defines a property accessor for the given property.\n     * @param {string} property Name of the property\n     * @param {boolean=} readOnly When true, no setter is created\n     * @return {void}\n     * @override\n     */\n\n\n    _definePropertyAccessor(property, readOnly) {\n      Object.defineProperty(this, property, {\n        /* eslint-disable valid-jsdoc */\n\n        /** @this {PropertiesChanged} */\n        get() {\n          return this._getProperty(property);\n        },\n\n        /** @this {PropertiesChanged} */\n        set: readOnly ? function () {} : function (value) {\n          this._setProperty(property, value);\n        }\n        /* eslint-enable */\n\n      });\n    }\n\n    constructor() {\n      super();\n      this.__dataEnabled = false;\n      this.__dataReady = false;\n      this.__dataInvalid = false;\n      this.__data = {};\n      this.__dataPending = null;\n      this.__dataOld = null;\n      this.__dataInstanceProps = null;\n      this.__serializing = false;\n\n      this._initializeProperties();\n    }\n    /**\n     * Lifecycle callback called when properties are enabled via\n     * `_enableProperties`.\n     *\n     * Users may override this function to implement behavior that is\n     * dependent on the element having its property data initialized, e.g.\n     * from defaults (initialized from `constructor`, `_initializeProperties`),\n     * `attributeChangedCallback`, or values propagated from host e.g. via\n     * bindings.  `super.ready()` must be called to ensure the data system\n     * becomes enabled.\n     *\n     * @return {void}\n     * @public\n     * @override\n     */\n\n\n    ready() {\n      this.__dataReady = true;\n\n      this._flushProperties();\n    }\n    /**\n     * Initializes the local storage for property accessors.\n     *\n     * Provided as an override point for performing any setup work prior\n     * to initializing the property accessor system.\n     *\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _initializeProperties() {\n      // Capture instance properties; these will be set into accessors\n      // during first flush. Don't set them here, since we want\n      // these to overwrite defaults/constructor assignments\n      for (let p in this.__dataHasAccessor) {\n        if (this.hasOwnProperty(p)) {\n          this.__dataInstanceProps = this.__dataInstanceProps || {};\n          this.__dataInstanceProps[p] = this[p];\n          delete this[p];\n        }\n      }\n    }\n    /**\n     * Called at ready time with bag of instance properties that overwrote\n     * accessors when the element upgraded.\n     *\n     * The default implementation sets these properties back into the\n     * setter at ready time.  This method is provided as an override\n     * point for customizing or providing more efficient initialization.\n     *\n     * @param {Object} props Bag of property values that were overwritten\n     *   when creating property accessors.\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _initializeInstanceProperties(props) {\n      Object.assign(this, props);\n    }\n    /**\n     * Updates the local storage for a property (via `_setPendingProperty`)\n     * and enqueues a `_proeprtiesChanged` callback.\n     *\n     * @param {string} property Name of the property\n     * @param {*} value Value to set\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _setProperty(property, value) {\n      if (this._setPendingProperty(property, value)) {\n        this._invalidateProperties();\n      }\n    }\n    /**\n     * Returns the value for the given property.\n     * @param {string} property Name of property\n     * @return {*} Value for the given property\n     * @protected\n     * @override\n     */\n\n\n    _getProperty(property) {\n      return this.__data[property];\n    }\n    /* eslint-disable no-unused-vars */\n\n    /**\n     * Updates the local storage for a property, records the previous value,\n     * and adds it to the set of \"pending changes\" that will be passed to the\n     * `_propertiesChanged` callback.  This method does not enqueue the\n     * `_propertiesChanged` callback.\n     *\n     * @param {string} property Name of the property\n     * @param {*} value Value to set\n     * @param {boolean=} ext Not used here; affordance for closure\n     * @return {boolean} Returns true if the property changed\n     * @protected\n     * @override\n     */\n\n\n    _setPendingProperty(property, value, ext) {\n      let old = this.__data[property];\n\n      let changed = this._shouldPropertyChange(property, value, old);\n\n      if (changed) {\n        if (!this.__dataPending) {\n          this.__dataPending = {};\n          this.__dataOld = {};\n        } // Ensure old is captured from the last turn\n\n\n        if (this.__dataOld && !(property in this.__dataOld)) {\n          this.__dataOld[property] = old;\n        }\n\n        this.__data[property] = value;\n        this.__dataPending[property] = value;\n      }\n\n      return changed;\n    }\n    /* eslint-enable */\n\n    /**\n     * Marks the properties as invalid, and enqueues an async\n     * `_propertiesChanged` callback.\n     *\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _invalidateProperties() {\n      if (!this.__dataInvalid && this.__dataReady) {\n        this.__dataInvalid = true;\n        microtask.run(() => {\n          if (this.__dataInvalid) {\n            this.__dataInvalid = false;\n\n            this._flushProperties();\n          }\n        });\n      }\n    }\n    /**\n     * Call to enable property accessor processing. Before this method is\n     * called accessor values will be set but side effects are\n     * queued. When called, any pending side effects occur immediately.\n     * For elements, generally `connectedCallback` is a normal spot to do so.\n     * It is safe to call this method multiple times as it only turns on\n     * property accessors once.\n     *\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _enableProperties() {\n      if (!this.__dataEnabled) {\n        this.__dataEnabled = true;\n\n        if (this.__dataInstanceProps) {\n          this._initializeInstanceProperties(this.__dataInstanceProps);\n\n          this.__dataInstanceProps = null;\n        }\n\n        this.ready();\n      }\n    }\n    /**\n     * Calls the `_propertiesChanged` callback with the current set of\n     * pending changes (and old values recorded when pending changes were\n     * set), and resets the pending set of changes. Generally, this method\n     * should not be called in user code.\n     *\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _flushProperties() {\n      const props = this.__data;\n      const changedProps = this.__dataPending;\n      const old = this.__dataOld;\n\n      if (this._shouldPropertiesChange(props, changedProps, old)) {\n        this.__dataPending = null;\n        this.__dataOld = null;\n\n        this._propertiesChanged(props, changedProps, old);\n      }\n    }\n    /**\n     * Called in `_flushProperties` to determine if `_propertiesChanged`\n     * should be called. The default implementation returns true if\n     * properties are pending. Override to customize when\n     * `_propertiesChanged` is called.\n     * @param {!Object} currentProps Bag of all current accessor values\n     * @param {?Object} changedProps Bag of properties changed since the last\n     *   call to `_propertiesChanged`\n     * @param {?Object} oldProps Bag of previous values for each property\n     *   in `changedProps`\n     * @return {boolean} true if changedProps is truthy\n     * @override\n     */\n\n\n    _shouldPropertiesChange(currentProps, changedProps, oldProps) {\n      // eslint-disable-line no-unused-vars\n      return Boolean(changedProps);\n    }\n    /**\n     * Callback called when any properties with accessors created via\n     * `_createPropertyAccessor` have been set.\n     *\n     * @param {!Object} currentProps Bag of all current accessor values\n     * @param {?Object} changedProps Bag of properties changed since the last\n     *   call to `_propertiesChanged`\n     * @param {?Object} oldProps Bag of previous values for each property\n     *   in `changedProps`\n     * @return {void}\n     * @protected\n     * @override\n     */\n\n\n    _propertiesChanged(currentProps, changedProps, oldProps) {// eslint-disable-line no-unused-vars\n    }\n    /**\n     * Method called to determine whether a property value should be\n     * considered as a change and cause the `_propertiesChanged` callback\n     * to be enqueued.\n     *\n     * The default implementation returns `true` if a strict equality\n     * check fails. The method always returns false for `NaN`.\n     *\n     * Override this method to e.g. provide stricter checking for\n     * Objects/Arrays when using immutable patterns.\n     *\n     * @param {string} property Property name\n     * @param {*} value New property value\n     * @param {*} old Previous property value\n     * @return {boolean} Whether the property should be considered a change\n     *   and enqueue a `_proeprtiesChanged` callback\n     * @protected\n     * @override\n     */\n\n\n    _shouldPropertyChange(property, value, old) {\n      return (// Strict equality check\n        old !== value && ( // This ensures (old==NaN, value==NaN) always returns false\n        old === old || value === value)\n      );\n    }\n    /**\n     * Implements native Custom Elements `attributeChangedCallback` to\n     * set an attribute value to a property via `_attributeToProperty`.\n     *\n     * @param {string} name Name of attribute that changed\n     * @param {?string} old Old attribute value\n     * @param {?string} value New attribute value\n     * @param {?string} namespace Attribute namespace.\n     * @return {void}\n     * @suppress {missingProperties} Super may or may not implement the callback\n     * @override\n     */\n\n\n    attributeChangedCallback(name, old, value, namespace) {\n      if (old !== value) {\n        this._attributeToProperty(name, value);\n      }\n\n      if (super.attributeChangedCallback) {\n        super.attributeChangedCallback(name, old, value, namespace);\n      }\n    }\n    /**\n     * Deserializes an attribute to its associated property.\n     *\n     * This method calls the `_deserializeValue` method to convert the string to\n     * a typed value.\n     *\n     * @param {string} attribute Name of attribute to deserialize.\n     * @param {?string} value of the attribute.\n     * @param {*=} type type to deserialize to, defaults to the value\n     * returned from `typeForProperty`\n     * @return {void}\n     * @override\n     */\n\n\n    _attributeToProperty(attribute, value, type) {\n      if (!this.__serializing) {\n        const map = this.__dataAttributes;\n        const property = map && map[attribute] || attribute;\n        this[property] = this._deserializeValue(value, type || this.constructor.typeForProperty(property));\n      }\n    }\n    /**\n     * Serializes a property to its associated attribute.\n     *\n     * @suppress {invalidCasts} Closure can't figure out `this` is an element.\n     *\n     * @param {string} property Property name to reflect.\n     * @param {string=} attribute Attribute name to reflect to.\n     * @param {*=} value Property value to refect.\n     * @return {void}\n     * @override\n     */\n\n\n    _propertyToAttribute(property, attribute, value) {\n      this.__serializing = true;\n      value = arguments.length < 3 ? this[property] : value;\n\n      this._valueToNodeAttribute(\n      /** @type {!HTMLElement} */\n      this, value, attribute || this.constructor.attributeNameForProperty(property));\n\n      this.__serializing = false;\n    }\n    /**\n     * Sets a typed value to an HTML attribute on a node.\n     *\n     * This method calls the `_serializeValue` method to convert the typed\n     * value to a string.  If the `_serializeValue` method returns `undefined`,\n     * the attribute will be removed (this is the default for boolean\n     * type `false`).\n     *\n     * @param {Element} node Element to set attribute to.\n     * @param {*} value Value to serialize.\n     * @param {string} attribute Attribute name to serialize to.\n     * @return {void}\n     * @override\n     */\n\n\n    _valueToNodeAttribute(node, value, attribute) {\n      const str = this._serializeValue(value);\n\n      if (str === undefined) {\n        node.removeAttribute(attribute);\n      } else {\n        node.setAttribute(attribute, str);\n      }\n    }\n    /**\n     * Converts a typed JavaScript value to a string.\n     *\n     * This method is called when setting JS property values to\n     * HTML attributes.  Users may override this method to provide\n     * serialization for custom types.\n     *\n     * @param {*} value Property value to serialize.\n     * @return {string | undefined} String serialized from the provided\n     * property  value.\n     * @override\n     */\n\n\n    _serializeValue(value) {\n      switch (typeof value) {\n        case 'boolean':\n          return value ? '' : undefined;\n\n        default:\n          return value != null ? value.toString() : undefined;\n      }\n    }\n    /**\n     * Converts a string to a typed JavaScript value.\n     *\n     * This method is called when reading HTML attribute values to\n     * JS properties.  Users may override this method to provide\n     * deserialization for custom `type`s. Types for `Boolean`, `String`,\n     * and `Number` convert attributes to the expected types.\n     *\n     * @param {?string} value Value to deserialize.\n     * @param {*=} type Type to deserialize the string to.\n     * @return {*} Typed value deserialized from the provided string.\n     * @override\n     */\n\n\n    _deserializeValue(value, type) {\n      switch (type) {\n        case Boolean:\n          return value !== null;\n\n        case Number:\n          return Number(value);\n\n        default:\n          return value;\n      }\n    }\n\n  }\n\n  return PropertiesChanged;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/properties-changed.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/properties-mixin.js":
/*!**********************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/properties-mixin.js ***!
  \**********************************************************************/
/*! namespace exports */
/*! export PropertiesMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PropertiesMixin\": () => /* binding */ PropertiesMixin\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _properties_changed_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./properties-changed.js */ \"./node_modules/@polymer/polymer/lib/mixins/properties-changed.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * Creates a copy of `props` with each property normalized such that\n * upgraded it is an object with at least a type property { type: Type}.\n *\n * @param {Object} props Properties to normalize\n * @return {Object} Copy of input `props` with normalized properties that\n * are in the form {type: Type}\n * @private\n */\n\nfunction normalizeProperties(props) {\n  const output = {};\n\n  for (let p in props) {\n    const o = props[p];\n    output[p] = typeof o === 'function' ? {\n      type: o\n    } : o;\n  }\n\n  return output;\n}\n/**\n * Mixin that provides a minimal starting point to using the PropertiesChanged\n * mixin by providing a mechanism to declare properties in a static\n * getter (e.g. static get properties() { return { foo: String } }). Changes\n * are reported via the `_propertiesChanged` method.\n *\n * This mixin provides no specific support for rendering. Users are expected\n * to create a ShadowRoot and put content into it and update it in whatever\n * way makes sense. This can be done in reaction to properties changing by\n * implementing `_propertiesChanged`.\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin PropertiesChanged\n * @summary Mixin that provides a minimal starting point for using\n * the PropertiesChanged mixin by providing a declarative `properties` object.\n */\n\n\nconst PropertiesMixin = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(superClass => {\n  /**\n   * @constructor\n   * @implements {Polymer_PropertiesChanged}\n   * @private\n   */\n  const base = (0,_properties_changed_js__WEBPACK_IMPORTED_MODULE_2__.PropertiesChanged)(superClass);\n  /**\n   * Returns the super class constructor for the given class, if it is an\n   * instance of the PropertiesMixin.\n   *\n   * @param {!PropertiesMixinConstructor} constructor PropertiesMixin constructor\n   * @return {?PropertiesMixinConstructor} Super class constructor\n   */\n\n  function superPropertiesClass(constructor) {\n    const superCtor = Object.getPrototypeOf(constructor); // Note, the `PropertiesMixin` class below only refers to the class\n    // generated by this call to the mixin; the instanceof test only works\n    // because the mixin is deduped and guaranteed only to apply once, hence\n    // all constructors in a proto chain will see the same `PropertiesMixin`\n\n    return superCtor.prototype instanceof PropertiesMixin ?\n    /** @type {!PropertiesMixinConstructor} */\n    superCtor : null;\n  }\n  /**\n   * Returns a memoized version of the `properties` object for the\n   * given class. Properties not in object format are converted to at\n   * least {type}.\n   *\n   * @param {PropertiesMixinConstructor} constructor PropertiesMixin constructor\n   * @return {Object} Memoized properties object\n   */\n\n\n  function ownProperties(constructor) {\n    if (!constructor.hasOwnProperty(JSCompiler_renameProperty('__ownProperties', constructor))) {\n      let props = null;\n\n      if (constructor.hasOwnProperty(JSCompiler_renameProperty('properties', constructor))) {\n        const properties = constructor.properties;\n\n        if (properties) {\n          props = normalizeProperties(properties);\n        }\n      }\n\n      constructor.__ownProperties = props;\n    }\n\n    return constructor.__ownProperties;\n  }\n  /**\n   * @polymer\n   * @mixinClass\n   * @extends {base}\n   * @implements {Polymer_PropertiesMixin}\n   * @unrestricted\n   */\n\n\n  class PropertiesMixin extends base {\n    /**\n     * Implements standard custom elements getter to observes the attributes\n     * listed in `properties`.\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n    static get observedAttributes() {\n      const props = this._properties;\n      return props ? Object.keys(props).map(p => this.attributeNameForProperty(p)) : [];\n    }\n    /**\n     * Finalizes an element definition, including ensuring any super classes\n     * are also finalized. This includes ensuring property\n     * accessors exist on the element prototype. This method calls\n     * `_finalizeClass` to finalize each constructor in the prototype chain.\n     * @return {void}\n     */\n\n\n    static finalize() {\n      if (!this.hasOwnProperty(JSCompiler_renameProperty('__finalized', this))) {\n        const superCtor = superPropertiesClass(\n        /** @type {!PropertiesMixinConstructor} */\n        this);\n\n        if (superCtor) {\n          superCtor.finalize();\n        }\n\n        this.__finalized = true;\n\n        this._finalizeClass();\n      }\n    }\n    /**\n     * Finalize an element class. This includes ensuring property\n     * accessors exist on the element prototype. This method is called by\n     * `finalize` and finalizes the class constructor.\n     *\n     * @protected\n     */\n\n\n    static _finalizeClass() {\n      const props = ownProperties(\n      /** @type {!PropertiesMixinConstructor} */\n      this);\n\n      if (props) {\n        this.createProperties(props);\n      }\n    }\n    /**\n     * Returns a memoized version of all properties, including those inherited\n     * from super classes. Properties not in object format are converted to\n     * at least {type}.\n     *\n     * @return {Object} Object containing properties for this class\n     * @protected\n     */\n\n\n    static get _properties() {\n      if (!this.hasOwnProperty(JSCompiler_renameProperty('__properties', this))) {\n        const superCtor = superPropertiesClass(\n        /** @type {!PropertiesMixinConstructor} */\n        this);\n        this.__properties = Object.assign({}, superCtor && superCtor._properties, ownProperties(\n        /** @type {PropertiesMixinConstructor} */\n        this));\n      }\n\n      return this.__properties;\n    }\n    /**\n     * Overrides `PropertiesChanged` method to return type specified in the\n     * static `properties` object for the given property.\n     * @param {string} name Name of property\n     * @return {*} Type to which to deserialize attribute\n     *\n     * @protected\n     */\n\n\n    static typeForProperty(name) {\n      const info = this._properties[name];\n      return info && info.type;\n    }\n    /**\n     * Overrides `PropertiesChanged` method and adds a call to\n     * `finalize` which lazily configures the element's property accessors.\n     * @override\n     * @return {void}\n     */\n\n\n    _initializeProperties() {\n      this.constructor.finalize();\n\n      super._initializeProperties();\n    }\n    /**\n     * Called when the element is added to a document.\n     * Calls `_enableProperties` to turn on property system from\n     * `PropertiesChanged`.\n     * @suppress {missingProperties} Super may or may not implement the callback\n     * @return {void}\n     * @override\n     */\n\n\n    connectedCallback() {\n      if (super.connectedCallback) {\n        super.connectedCallback();\n      }\n\n      this._enableProperties();\n    }\n    /**\n     * Called when the element is removed from a document\n     * @suppress {missingProperties} Super may or may not implement the callback\n     * @return {void}\n     * @override\n     */\n\n\n    disconnectedCallback() {\n      if (super.disconnectedCallback) {\n        super.disconnectedCallback();\n      }\n    }\n\n  }\n\n  return PropertiesMixin;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/properties-mixin.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/property-accessors.js":
/*!************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/property-accessors.js ***!
  \************************************************************************/
/*! namespace exports */
/*! export PropertyAccessors [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PropertyAccessors\": () => /* binding */ PropertyAccessors\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_case_map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/case-map.js */ \"./node_modules/@polymer/polymer/lib/utils/case-map.js\");\n/* harmony import */ var _properties_changed_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./properties-changed.js */ \"./node_modules/@polymer/polymer/lib/mixins/properties-changed.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n // Save map of native properties; this forms a blacklist or properties\n// that won't have their values \"saved\" by `saveAccessorValue`, since\n// reading from an HTMLElement accessor from the context of a prototype throws\n\nconst nativeProperties = {};\nlet proto = HTMLElement.prototype;\n\nwhile (proto) {\n  let props = Object.getOwnPropertyNames(proto);\n\n  for (let i = 0; i < props.length; i++) {\n    nativeProperties[props[i]] = true;\n  }\n\n  proto = Object.getPrototypeOf(proto);\n}\n/**\n * Used to save the value of a property that will be overridden with\n * an accessor. If the `model` is a prototype, the values will be saved\n * in `__dataProto`, and it's up to the user (or downstream mixin) to\n * decide how/when to set these values back into the accessors.\n * If `model` is already an instance (it has a `__data` property), then\n * the value will be set as a pending property, meaning the user should\n * call `_invalidateProperties` or `_flushProperties` to take effect\n *\n * @param {Object} model Prototype or instance\n * @param {string} property Name of property\n * @return {void}\n * @private\n */\n\n\nfunction saveAccessorValue(model, property) {\n  // Don't read/store value for any native properties since they could throw\n  if (!nativeProperties[property]) {\n    let value = model[property];\n\n    if (value !== undefined) {\n      if (model.__data) {\n        // Adding accessor to instance; update the property\n        // It is the user's responsibility to call _flushProperties\n        model._setPendingProperty(property, value);\n      } else {\n        // Adding accessor to proto; save proto's value for instance-time use\n        if (!model.__dataProto) {\n          model.__dataProto = {};\n        } else if (!model.hasOwnProperty(JSCompiler_renameProperty('__dataProto', model))) {\n          model.__dataProto = Object.create(model.__dataProto);\n        }\n\n        model.__dataProto[property] = value;\n      }\n    }\n  }\n}\n/**\n * Element class mixin that provides basic meta-programming for creating one\n * or more property accessors (getter/setter pair) that enqueue an async\n * (batched) `_propertiesChanged` callback.\n *\n * For basic usage of this mixin:\n *\n * -   Declare attributes to observe via the standard `static get observedAttributes()`. Use\n *     `dash-case` attribute names to represent `camelCase` property names.\n * -   Implement the `_propertiesChanged` callback on the class.\n * -   Call `MyClass.createPropertiesForAttributes()` **once** on the class to generate\n *     property accessors for each observed attribute. This must be called before the first\n *     instance is created, for example, by calling it before calling `customElements.define`.\n *     It can also be called lazily from the element's `constructor`, as long as it's guarded so\n *     that the call is only made once, when the first instance is created.\n * -   Call `this._enableProperties()` in the element's `connectedCallback` to enable\n *     the accessors.\n *\n * Any `observedAttributes` will automatically be\n * deserialized via `attributeChangedCallback` and set to the associated\n * property using `dash-case`-to-`camelCase` convention.\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin PropertiesChanged\n * @summary Element class mixin for reacting to property changes from\n *   generated property accessors.\n */\n\n\nconst PropertyAccessors = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(superClass => {\n  /**\n   * @constructor\n   * @extends {superClass}\n   * @implements {Polymer_PropertiesChanged}\n   * @unrestricted\n   * @private\n   */\n  const base = (0,_properties_changed_js__WEBPACK_IMPORTED_MODULE_3__.PropertiesChanged)(superClass);\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_PropertyAccessors}\n   * @extends {base}\n   * @unrestricted\n   */\n\n  class PropertyAccessors extends base {\n    /**\n     * Generates property accessors for all attributes in the standard\n     * static `observedAttributes` array.\n     *\n     * Attribute names are mapped to property names using the `dash-case` to\n     * `camelCase` convention\n     *\n     * @return {void}\n     */\n    static createPropertiesForAttributes() {\n      let a$ = this.observedAttributes;\n\n      for (let i = 0; i < a$.length; i++) {\n        this.prototype._createPropertyAccessor((0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_2__.dashToCamelCase)(a$[i]));\n      }\n    }\n    /**\n     * Returns an attribute name that corresponds to the given property.\n     * By default, converts camel to dash case, e.g. `fooBar` to `foo-bar`.\n     * @param {string} property Property to convert\n     * @return {string} Attribute name corresponding to the given property.\n     *\n     * @protected\n     */\n\n\n    static attributeNameForProperty(property) {\n      return (0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_2__.camelToDashCase)(property);\n    }\n    /**\n     * Overrides PropertiesChanged implementation to initialize values for\n     * accessors created for values that already existed on the element\n     * prototype.\n     *\n     * @return {void}\n     * @protected\n     */\n\n\n    _initializeProperties() {\n      if (this.__dataProto) {\n        this._initializeProtoProperties(this.__dataProto);\n\n        this.__dataProto = null;\n      }\n\n      super._initializeProperties();\n    }\n    /**\n     * Called at instance time with bag of properties that were overwritten\n     * by accessors on the prototype when accessors were created.\n     *\n     * The default implementation sets these properties back into the\n     * setter at instance time.  This method is provided as an override\n     * point for customizing or providing more efficient initialization.\n     *\n     * @param {Object} props Bag of property values that were overwritten\n     *   when creating property accessors.\n     * @return {void}\n     * @protected\n     */\n\n\n    _initializeProtoProperties(props) {\n      for (let p in props) {\n        this._setProperty(p, props[p]);\n      }\n    }\n    /**\n     * Ensures the element has the given attribute. If it does not,\n     * assigns the given value to the attribute.\n     *\n     * @suppress {invalidCasts} Closure can't figure out `this` is infact an element\n     *\n     * @param {string} attribute Name of attribute to ensure is set.\n     * @param {string} value of the attribute.\n     * @return {void}\n     */\n\n\n    _ensureAttribute(attribute, value) {\n      const el =\n      /** @type {!HTMLElement} */\n      this;\n\n      if (!el.hasAttribute(attribute)) {\n        this._valueToNodeAttribute(el, value, attribute);\n      }\n    }\n    /**\n     * Overrides PropertiesChanged implemention to serialize objects as JSON.\n     *\n     * @param {*} value Property value to serialize.\n     * @return {string | undefined} String serialized from the provided property value.\n     */\n\n\n    _serializeValue(value) {\n      /* eslint-disable no-fallthrough */\n      switch (typeof value) {\n        case 'object':\n          if (value instanceof Date) {\n            return value.toString();\n          } else if (value) {\n            try {\n              return JSON.stringify(value);\n            } catch (x) {\n              return '';\n            }\n          }\n\n        default:\n          return super._serializeValue(value);\n      }\n    }\n    /**\n     * Converts a string to a typed JavaScript value.\n     *\n     * This method is called by Polymer when reading HTML attribute values to\n     * JS properties.  Users may override this method on Polymer element\n     * prototypes to provide deserialization for custom `type`s.  Note,\n     * the `type` argument is the value of the `type` field provided in the\n     * `properties` configuration object for a given property, and is\n     * by convention the constructor for the type to deserialize.\n     *\n     *\n     * @param {?string} value Attribute value to deserialize.\n     * @param {*=} type Type to deserialize the string to.\n     * @return {*} Typed value deserialized from the provided string.\n     */\n\n\n    _deserializeValue(value, type) {\n      /**\n       * @type {*}\n       */\n      let outValue;\n\n      switch (type) {\n        case Object:\n          try {\n            outValue = JSON.parse(\n            /** @type {string} */\n            value);\n          } catch (x) {\n            // allow non-JSON literals like Strings and Numbers\n            outValue = value;\n          }\n\n          break;\n\n        case Array:\n          try {\n            outValue = JSON.parse(\n            /** @type {string} */\n            value);\n          } catch (x) {\n            outValue = null;\n            console.warn(`Polymer::Attributes: couldn't decode Array as JSON: ${value}`);\n          }\n\n          break;\n\n        case Date:\n          outValue = isNaN(value) ? String(value) : Number(value);\n          outValue = new Date(outValue);\n          break;\n\n        default:\n          outValue = super._deserializeValue(value, type);\n          break;\n      }\n\n      return outValue;\n    }\n    /* eslint-enable no-fallthrough */\n\n    /**\n     * Overrides PropertiesChanged implementation to save existing prototype\n     * property value so that it can be reset.\n     * @param {string} property Name of the property\n     * @param {boolean=} readOnly When true, no setter is created\n     *\n     * When calling on a prototype, any overwritten values are saved in\n     * `__dataProto`, and it is up to the subclasser to decide how/when\n     * to set those properties back into the accessor.  When calling on an\n     * instance, the overwritten value is set via `_setPendingProperty`,\n     * and the user should call `_invalidateProperties` or `_flushProperties`\n     * for the values to take effect.\n     * @protected\n     * @return {void}\n     */\n\n\n    _definePropertyAccessor(property, readOnly) {\n      saveAccessorValue(this, property);\n\n      super._definePropertyAccessor(property, readOnly);\n    }\n    /**\n     * Returns true if this library created an accessor for the given property.\n     *\n     * @param {string} property Property name\n     * @return {boolean} True if an accessor was created\n     */\n\n\n    _hasAccessor(property) {\n      return this.__dataHasAccessor && this.__dataHasAccessor[property];\n    }\n    /**\n     * Returns true if the specified property has a pending change.\n     *\n     * @param {string} prop Property name\n     * @return {boolean} True if property has a pending change\n     * @protected\n     */\n\n\n    _isPropertyPending(prop) {\n      return Boolean(this.__dataPending && prop in this.__dataPending);\n    }\n\n  }\n\n  return PropertyAccessors;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/property-accessors.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/property-effects.js":
/*!**********************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/property-effects.js ***!
  \**********************************************************************/
/*! namespace exports */
/*! export PropertyEffects [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PropertyEffects\": () => /* binding */ PropertyEffects\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _utils_path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../utils/path.js */ \"./node_modules/@polymer/polymer/lib/utils/path.js\");\n/* harmony import */ var _utils_case_map_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/case-map.js */ \"./node_modules/@polymer/polymer/lib/utils/case-map.js\");\n/* harmony import */ var _property_accessors_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./property-accessors.js */ \"./node_modules/@polymer/polymer/lib/mixins/property-accessors.js\");\n/* harmony import */ var _template_stamp_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./template-stamp.js */ \"./node_modules/@polymer/polymer/lib/mixins/template-stamp.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/* for notify, reflect */\n\n\n\n/* for annotated effects */\n\n\n // Monotonically increasing unique ID used for de-duping effects triggered\n// from multiple properties in the same turn\n\nlet dedupeId = 0;\n/**\n * Property effect types; effects are stored on the prototype using these keys\n * @enum {string}\n */\n\nconst TYPES = {\n  COMPUTE: '__computeEffects',\n  REFLECT: '__reflectEffects',\n  NOTIFY: '__notifyEffects',\n  PROPAGATE: '__propagateEffects',\n  OBSERVE: '__observeEffects',\n  READ_ONLY: '__readOnly'\n};\n/** @const {RegExp} */\n\nconst capitalAttributeRegex = /[A-Z]/;\n/**\n * @typedef {{\n * name: (string | undefined),\n * structured: (boolean | undefined),\n * wildcard: (boolean | undefined)\n * }}\n */\n\nlet DataTrigger; //eslint-disable-line no-unused-vars\n\n/**\n * @typedef {{\n * info: ?,\n * trigger: (!DataTrigger | undefined),\n * fn: (!Function | undefined)\n * }}\n */\n\nlet DataEffect; //eslint-disable-line no-unused-vars\n\nlet PropertyEffectsType; //eslint-disable-line no-unused-vars\n\n/**\n * Ensures that the model has an own-property map of effects for the given type.\n * The model may be a prototype or an instance.\n *\n * Property effects are stored as arrays of effects by property in a map,\n * by named type on the model. e.g.\n *\n *   __computeEffects: {\n *     foo: [ ... ],\n *     bar: [ ... ]\n *   }\n *\n * If the model does not yet have an effect map for the type, one is created\n * and returned.  If it does, but it is not an own property (i.e. the\n * prototype had effects), the the map is deeply cloned and the copy is\n * set on the model and returned, ready for new effects to be added.\n *\n * @param {Object} model Prototype or instance\n * @param {string} type Property effect type\n * @return {Object} The own-property map of effects for the given type\n * @private\n */\n\nfunction ensureOwnEffectMap(model, type) {\n  let effects = model[type];\n\n  if (!effects) {\n    effects = model[type] = {};\n  } else if (!model.hasOwnProperty(type)) {\n    effects = model[type] = Object.create(model[type]);\n\n    for (let p in effects) {\n      let protoFx = effects[p];\n      let instFx = effects[p] = Array(protoFx.length);\n\n      for (let i = 0; i < protoFx.length; i++) {\n        instFx[i] = protoFx[i];\n      }\n    }\n  }\n\n  return effects;\n} // -- effects ----------------------------------------------\n\n/**\n * Runs all effects of a given type for the given set of property changes\n * on an instance.\n *\n * @param {!PropertyEffectsType} inst The instance with effects to run\n * @param {Object} effects Object map of property-to-Array of effects\n * @param {Object} props Bag of current property changes\n * @param {Object=} oldProps Bag of previous values for changed properties\n * @param {boolean=} hasPaths True with `props` contains one or more paths\n * @param {*=} extraArgs Additional metadata to pass to effect function\n * @return {boolean} True if an effect ran for this property\n * @private\n */\n\n\nfunction runEffects(inst, effects, props, oldProps, hasPaths, extraArgs) {\n  if (effects) {\n    let ran = false;\n    let id = dedupeId++;\n\n    for (let prop in props) {\n      if (runEffectsForProperty(inst, effects, id, prop, props, oldProps, hasPaths, extraArgs)) {\n        ran = true;\n      }\n    }\n\n    return ran;\n  }\n\n  return false;\n}\n/**\n * Runs a list of effects for a given property.\n *\n * @param {!PropertyEffectsType} inst The instance with effects to run\n * @param {Object} effects Object map of property-to-Array of effects\n * @param {number} dedupeId Counter used for de-duping effects\n * @param {string} prop Name of changed property\n * @param {*} props Changed properties\n * @param {*} oldProps Old properties\n * @param {boolean=} hasPaths True with `props` contains one or more paths\n * @param {*=} extraArgs Additional metadata to pass to effect function\n * @return {boolean} True if an effect ran for this property\n * @private\n */\n\n\nfunction runEffectsForProperty(inst, effects, dedupeId, prop, props, oldProps, hasPaths, extraArgs) {\n  let ran = false;\n  let rootProperty = hasPaths ? (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.root)(prop) : prop;\n  let fxs = effects[rootProperty];\n\n  if (fxs) {\n    for (let i = 0, l = fxs.length, fx; i < l && (fx = fxs[i]); i++) {\n      if ((!fx.info || fx.info.lastRun !== dedupeId) && (!hasPaths || pathMatchesTrigger(prop, fx.trigger))) {\n        if (fx.info) {\n          fx.info.lastRun = dedupeId;\n        }\n\n        fx.fn(inst, prop, props, oldProps, fx.info, hasPaths, extraArgs);\n        ran = true;\n      }\n    }\n  }\n\n  return ran;\n}\n/**\n * Determines whether a property/path that has changed matches the trigger\n * criteria for an effect.  A trigger is a descriptor with the following\n * structure, which matches the descriptors returned from `parseArg`.\n * e.g. for `foo.bar.*`:\n * ```\n * trigger: {\n *   name: 'a.b',\n *   structured: true,\n *   wildcard: true\n * }\n * ```\n * If no trigger is given, the path is deemed to match.\n *\n * @param {string} path Path or property that changed\n * @param {DataTrigger} trigger Descriptor\n * @return {boolean} Whether the path matched the trigger\n */\n\n\nfunction pathMatchesTrigger(path, trigger) {\n  if (trigger) {\n    let triggerPath = trigger.name;\n    return triggerPath == path || trigger.structured && (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isAncestor)(triggerPath, path) || trigger.wildcard && (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isDescendant)(triggerPath, path);\n  } else {\n    return true;\n  }\n}\n/**\n * Implements the \"observer\" effect.\n *\n * Calls the method with `info.methodName` on the instance, passing the\n * new and old values.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} property Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @return {void}\n * @private\n */\n\n\nfunction runObserverEffect(inst, property, props, oldProps, info) {\n  let fn = typeof info.method === \"string\" ? inst[info.method] : info.method;\n  let changedProp = info.property;\n\n  if (fn) {\n    fn.call(inst, inst.__data[changedProp], oldProps[changedProp]);\n  } else if (!info.dynamicFn) {\n    console.warn('observer method `' + info.method + '` not defined');\n  }\n}\n/**\n * Runs \"notify\" effects for a set of changed properties.\n *\n * This method differs from the generic `runEffects` method in that it\n * will dispatch path notification events in the case that the property\n * changed was a path and the root property for that path didn't have a\n * \"notify\" effect.  This is to maintain 1.0 behavior that did not require\n * `notify: true` to ensure object sub-property notifications were\n * sent.\n *\n * @param {!PropertyEffectsType} inst The instance with effects to run\n * @param {Object} notifyProps Bag of properties to notify\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {boolean} hasPaths True with `props` contains one or more paths\n * @return {void}\n * @private\n */\n\n\nfunction runNotifyEffects(inst, notifyProps, props, oldProps, hasPaths) {\n  // Notify\n  let fxs = inst[TYPES.NOTIFY];\n  let notified;\n  let id = dedupeId++; // Try normal notify effects; if none, fall back to try path notification\n\n  for (let prop in notifyProps) {\n    if (notifyProps[prop]) {\n      if (fxs && runEffectsForProperty(inst, fxs, id, prop, props, oldProps, hasPaths)) {\n        notified = true;\n      } else if (hasPaths && notifyPath(inst, prop, props)) {\n        notified = true;\n      }\n    }\n  } // Flush host if we actually notified and host was batching\n  // And the host has already initialized clients; this prevents\n  // an issue with a host observing data changes before clients are ready.\n\n\n  let host;\n\n  if (notified && (host = inst.__dataHost) && host._invalidateProperties) {\n    host._invalidateProperties();\n  }\n}\n/**\n * Dispatches {property}-changed events with path information in the detail\n * object to indicate a sub-path of the property was changed.\n *\n * @param {!PropertyEffectsType} inst The element from which to fire the event\n * @param {string} path The path that was changed\n * @param {Object} props Bag of current property changes\n * @return {boolean} Returns true if the path was notified\n * @private\n */\n\n\nfunction notifyPath(inst, path, props) {\n  let rootProperty = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.root)(path);\n\n  if (rootProperty !== path) {\n    let eventName = (0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_3__.camelToDashCase)(rootProperty) + '-changed';\n    dispatchNotifyEvent(inst, eventName, props[path], path);\n    return true;\n  }\n\n  return false;\n}\n/**\n * Dispatches {property}-changed events to indicate a property (or path)\n * changed.\n *\n * @param {!PropertyEffectsType} inst The element from which to fire the event\n * @param {string} eventName The name of the event to send ('{property}-changed')\n * @param {*} value The value of the changed property\n * @param {string | null | undefined} path If a sub-path of this property changed, the path\n *   that changed (optional).\n * @return {void}\n * @private\n * @suppress {invalidCasts}\n */\n\n\nfunction dispatchNotifyEvent(inst, eventName, value, path) {\n  let detail = {\n    value: value,\n    queueProperty: true\n  };\n\n  if (path) {\n    detail.path = path;\n  }\n  /** @type {!HTMLElement} */\n\n\n  inst.dispatchEvent(new CustomEvent(eventName, {\n    detail\n  }));\n}\n/**\n * Implements the \"notify\" effect.\n *\n * Dispatches a non-bubbling event named `info.eventName` on the instance\n * with a detail object containing the new `value`.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} property Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @param {boolean} hasPaths True with `props` contains one or more paths\n * @return {void}\n * @private\n */\n\n\nfunction runNotifyEffect(inst, property, props, oldProps, info, hasPaths) {\n  let rootProperty = hasPaths ? (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.root)(property) : property;\n  let path = rootProperty != property ? property : null;\n  let value = path ? (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(inst, path) : inst.__data[property];\n\n  if (path && value === undefined) {\n    value = props[property]; // specifically for .splices\n  }\n\n  dispatchNotifyEvent(inst, info.eventName, value, path);\n}\n/**\n * Handler function for 2-way notification events. Receives context\n * information captured in the `addNotifyListener` closure from the\n * `__notifyListeners` metadata.\n *\n * Sets the value of the notified property to the host property or path.  If\n * the event contained path information, translate that path to the host\n * scope's name for that path first.\n *\n * @param {CustomEvent} event Notification event (e.g. '<property>-changed')\n * @param {!PropertyEffectsType} inst Host element instance handling the notification event\n * @param {string} fromProp Child element property that was bound\n * @param {string} toPath Host property/path that was bound\n * @param {boolean} negate Whether the binding was negated\n * @return {void}\n * @private\n */\n\n\nfunction handleNotification(event, inst, fromProp, toPath, negate) {\n  let value;\n  let detail =\n  /** @type {Object} */\n  event.detail;\n  let fromPath = detail && detail.path;\n\n  if (fromPath) {\n    toPath = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.translate)(fromProp, toPath, fromPath);\n    value = detail && detail.value;\n  } else {\n    value = event.currentTarget[fromProp];\n  }\n\n  value = negate ? !value : value;\n\n  if (!inst[TYPES.READ_ONLY] || !inst[TYPES.READ_ONLY][toPath]) {\n    if (inst._setPendingPropertyOrPath(toPath, value, true, Boolean(fromPath)) && (!detail || !detail.queueProperty)) {\n      inst._invalidateProperties();\n    }\n  }\n}\n/**\n * Implements the \"reflect\" effect.\n *\n * Sets the attribute named `info.attrName` to the given property value.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} property Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @return {void}\n * @private\n */\n\n\nfunction runReflectEffect(inst, property, props, oldProps, info) {\n  let value = inst.__data[property];\n\n  if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_6__.sanitizeDOMValue) {\n    value = (0,_utils_settings_js__WEBPACK_IMPORTED_MODULE_6__.sanitizeDOMValue)(value, info.attrName, 'attribute',\n    /** @type {Node} */\n    inst);\n  }\n\n  inst._propertyToAttribute(property, info.attrName, value);\n}\n/**\n * Runs \"computed\" effects for a set of changed properties.\n *\n * This method differs from the generic `runEffects` method in that it\n * continues to run computed effects based on the output of each pass until\n * there are no more newly computed properties.  This ensures that all\n * properties that will be computed by the initial set of changes are\n * computed before other effects (binding propagation, observers, and notify)\n * run.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {!Object} changedProps Bag of changed properties\n * @param {!Object} oldProps Bag of previous values for changed properties\n * @param {boolean} hasPaths True with `props` contains one or more paths\n * @return {void}\n * @private\n */\n\n\nfunction runComputedEffects(inst, changedProps, oldProps, hasPaths) {\n  let computeEffects = inst[TYPES.COMPUTE];\n\n  if (computeEffects) {\n    let inputProps = changedProps;\n\n    while (runEffects(inst, computeEffects, inputProps, oldProps, hasPaths)) {\n      Object.assign(oldProps, inst.__dataOld);\n      Object.assign(changedProps, inst.__dataPending);\n      inputProps = inst.__dataPending;\n      inst.__dataPending = null;\n    }\n  }\n}\n/**\n * Implements the \"computed property\" effect by running the method with the\n * values of the arguments specified in the `info` object and setting the\n * return value to the computed property specified.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} property Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @return {void}\n * @private\n */\n\n\nfunction runComputedEffect(inst, property, props, oldProps, info) {\n  let result = runMethodEffect(inst, property, props, oldProps, info);\n  let computedProp = info.methodInfo;\n\n  if (inst.__dataHasAccessor && inst.__dataHasAccessor[computedProp]) {\n    inst._setPendingProperty(computedProp, result, true);\n  } else {\n    inst[computedProp] = result;\n  }\n}\n/**\n * Computes path changes based on path links set up using the `linkPaths`\n * API.\n *\n * @param {!PropertyEffectsType} inst The instance whose props are changing\n * @param {string | !Array<(string|number)>} path Path that has changed\n * @param {*} value Value of changed path\n * @return {void}\n * @private\n */\n\n\nfunction computeLinkedPaths(inst, path, value) {\n  let links = inst.__dataLinkedPaths;\n\n  if (links) {\n    let link;\n\n    for (let a in links) {\n      let b = links[a];\n\n      if ((0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isDescendant)(a, path)) {\n        link = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.translate)(a, b, path);\n\n        inst._setPendingPropertyOrPath(link, value, true, true);\n      } else if ((0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isDescendant)(b, path)) {\n        link = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.translate)(b, a, path);\n\n        inst._setPendingPropertyOrPath(link, value, true, true);\n      }\n    }\n  }\n} // -- bindings ----------------------------------------------\n\n/**\n * Adds binding metadata to the current `nodeInfo`, and binding effects\n * for all part dependencies to `templateInfo`.\n *\n * @param {Function} constructor Class that `_parseTemplate` is currently\n *   running on\n * @param {TemplateInfo} templateInfo Template metadata for current template\n * @param {NodeInfo} nodeInfo Node metadata for current template node\n * @param {string} kind Binding kind, either 'property', 'attribute', or 'text'\n * @param {string} target Target property name\n * @param {!Array<!BindingPart>} parts Array of binding part metadata\n * @param {string=} literal Literal text surrounding binding parts (specified\n *   only for 'property' bindings, since these must be initialized as part\n *   of boot-up)\n * @return {void}\n * @private\n */\n\n\nfunction addBinding(constructor, templateInfo, nodeInfo, kind, target, parts, literal) {\n  // Create binding metadata and add to nodeInfo\n  nodeInfo.bindings = nodeInfo.bindings || [];\n  let\n  /** Binding */\n  binding = {\n    kind,\n    target,\n    parts,\n    literal,\n    isCompound: parts.length !== 1\n  };\n  nodeInfo.bindings.push(binding); // Add listener info to binding metadata\n\n  if (shouldAddListener(binding)) {\n    let {\n      event,\n      negate\n    } = binding.parts[0];\n    binding.listenerEvent = event || (0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_3__.camelToDashCase)(target) + '-changed';\n    binding.listenerNegate = negate;\n  } // Add \"propagate\" property effects to templateInfo\n\n\n  let index = templateInfo.nodeInfoList.length;\n\n  for (let i = 0; i < binding.parts.length; i++) {\n    let part = binding.parts[i];\n    part.compoundIndex = i;\n    addEffectForBindingPart(constructor, templateInfo, binding, part, index);\n  }\n}\n/**\n * Adds property effects to the given `templateInfo` for the given binding\n * part.\n *\n * @param {Function} constructor Class that `_parseTemplate` is currently\n *   running on\n * @param {TemplateInfo} templateInfo Template metadata for current template\n * @param {!Binding} binding Binding metadata\n * @param {!BindingPart} part Binding part metadata\n * @param {number} index Index into `nodeInfoList` for this node\n * @return {void}\n */\n\n\nfunction addEffectForBindingPart(constructor, templateInfo, binding, part, index) {\n  if (!part.literal) {\n    if (binding.kind === 'attribute' && binding.target[0] === '-') {\n      console.warn('Cannot set attribute ' + binding.target + ' because \"-\" is not a valid attribute starting character');\n    } else {\n      let dependencies = part.dependencies;\n      let info = {\n        index,\n        binding,\n        part,\n        evaluator: constructor\n      };\n\n      for (let j = 0; j < dependencies.length; j++) {\n        let trigger = dependencies[j];\n\n        if (typeof trigger == 'string') {\n          trigger = parseArg(trigger);\n          trigger.wildcard = true;\n        }\n\n        constructor._addTemplatePropertyEffect(templateInfo, trigger.rootProperty, {\n          fn: runBindingEffect,\n          info,\n          trigger\n        });\n      }\n    }\n  }\n}\n/**\n * Implements the \"binding\" (property/path binding) effect.\n *\n * Note that binding syntax is overridable via `_parseBindings` and\n * `_evaluateBinding`.  This method will call `_evaluateBinding` for any\n * non-literal parts returned from `_parseBindings`.  However,\n * there is no support for _path_ bindings via custom binding parts,\n * as this is specific to Polymer's path binding syntax.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} path Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @param {boolean} hasPaths True with `props` contains one or more paths\n * @param {Array} nodeList List of nodes associated with `nodeInfoList` template\n *   metadata\n * @return {void}\n * @private\n */\n\n\nfunction runBindingEffect(inst, path, props, oldProps, info, hasPaths, nodeList) {\n  let node = nodeList[info.index];\n  let binding = info.binding;\n  let part = info.part; // Subpath notification: transform path and set to client\n  // e.g.: foo=\"{{obj.sub}}\", path: 'obj.sub.prop', set 'foo.prop'=obj.sub.prop\n\n  if (hasPaths && part.source && path.length > part.source.length && binding.kind == 'property' && !binding.isCompound && node.__isPropertyEffectsClient && node.__dataHasAccessor && node.__dataHasAccessor[binding.target]) {\n    let value = props[path];\n    path = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.translate)(part.source, binding.target, path);\n\n    if (node._setPendingPropertyOrPath(path, value, false, true)) {\n      inst._enqueueClient(node);\n    }\n  } else {\n    let value = info.evaluator._evaluateBinding(inst, part, path, props, oldProps, hasPaths); // Propagate value to child\n\n\n    applyBindingValue(inst, node, binding, part, value);\n  }\n}\n/**\n * Sets the value for an \"binding\" (binding) effect to a node,\n * either as a property or attribute.\n *\n * @param {!PropertyEffectsType} inst The instance owning the binding effect\n * @param {Node} node Target node for binding\n * @param {!Binding} binding Binding metadata\n * @param {!BindingPart} part Binding part metadata\n * @param {*} value Value to set\n * @return {void}\n * @private\n */\n\n\nfunction applyBindingValue(inst, node, binding, part, value) {\n  value = computeBindingValue(node, value, binding, part);\n\n  if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_6__.sanitizeDOMValue) {\n    value = (0,_utils_settings_js__WEBPACK_IMPORTED_MODULE_6__.sanitizeDOMValue)(value, binding.target, binding.kind, node);\n  }\n\n  if (binding.kind == 'attribute') {\n    // Attribute binding\n    inst._valueToNodeAttribute(\n    /** @type {Element} */\n    node, value, binding.target);\n  } else {\n    // Property binding\n    let prop = binding.target;\n\n    if (node.__isPropertyEffectsClient && node.__dataHasAccessor && node.__dataHasAccessor[prop]) {\n      if (!node[TYPES.READ_ONLY] || !node[TYPES.READ_ONLY][prop]) {\n        if (node._setPendingProperty(prop, value)) {\n          inst._enqueueClient(node);\n        }\n      }\n    } else {\n      inst._setUnmanagedPropertyToNode(node, prop, value);\n    }\n  }\n}\n/**\n * Transforms an \"binding\" effect value based on compound & negation\n * effect metadata, as well as handling for special-case properties\n *\n * @param {Node} node Node the value will be set to\n * @param {*} value Value to set\n * @param {!Binding} binding Binding metadata\n * @param {!BindingPart} part Binding part metadata\n * @return {*} Transformed value to set\n * @private\n */\n\n\nfunction computeBindingValue(node, value, binding, part) {\n  if (binding.isCompound) {\n    let storage = node.__dataCompoundStorage[binding.target];\n    storage[part.compoundIndex] = value;\n    value = storage.join('');\n  }\n\n  if (binding.kind !== 'attribute') {\n    // Some browsers serialize `undefined` to `\"undefined\"`\n    if (binding.target === 'textContent' || binding.target === 'value' && (node.localName === 'input' || node.localName === 'textarea')) {\n      value = value == undefined ? '' : value;\n    }\n  }\n\n  return value;\n}\n/**\n * Returns true if a binding's metadata meets all the requirements to allow\n * 2-way binding, and therefore a `<property>-changed` event listener should be\n * added:\n * - used curly braces\n * - is a property (not attribute) binding\n * - is not a textContent binding\n * - is not compound\n *\n * @param {!Binding} binding Binding metadata\n * @return {boolean} True if 2-way listener should be added\n * @private\n */\n\n\nfunction shouldAddListener(binding) {\n  return Boolean(binding.target) && binding.kind != 'attribute' && binding.kind != 'text' && !binding.isCompound && binding.parts[0].mode === '{';\n}\n/**\n * Setup compound binding storage structures, notify listeners, and dataHost\n * references onto the bound nodeList.\n *\n * @param {!PropertyEffectsType} inst Instance that bas been previously bound\n * @param {TemplateInfo} templateInfo Template metadata\n * @return {void}\n * @private\n */\n\n\nfunction setupBindings(inst, templateInfo) {\n  // Setup compound storage, dataHost, and notify listeners\n  let {\n    nodeList,\n    nodeInfoList\n  } = templateInfo;\n\n  if (nodeInfoList.length) {\n    for (let i = 0; i < nodeInfoList.length; i++) {\n      let info = nodeInfoList[i];\n      let node = nodeList[i];\n      let bindings = info.bindings;\n\n      if (bindings) {\n        for (let i = 0; i < bindings.length; i++) {\n          let binding = bindings[i];\n          setupCompoundStorage(node, binding);\n          addNotifyListener(node, inst, binding);\n        }\n      }\n\n      node.__dataHost = inst;\n    }\n  }\n}\n/**\n * Initializes `__dataCompoundStorage` local storage on a bound node with\n * initial literal data for compound bindings, and sets the joined\n * literal parts to the bound property.\n *\n * When changes to compound parts occur, they are first set into the compound\n * storage array for that property, and then the array is joined to result in\n * the final value set to the property/attribute.\n *\n * @param {Node} node Bound node to initialize\n * @param {Binding} binding Binding metadata\n * @return {void}\n * @private\n */\n\n\nfunction setupCompoundStorage(node, binding) {\n  if (binding.isCompound) {\n    // Create compound storage map\n    let storage = node.__dataCompoundStorage || (node.__dataCompoundStorage = {});\n    let parts = binding.parts; // Copy literals from parts into storage for this binding\n\n    let literals = new Array(parts.length);\n\n    for (let j = 0; j < parts.length; j++) {\n      literals[j] = parts[j].literal;\n    }\n\n    let target = binding.target;\n    storage[target] = literals; // Configure properties with their literal parts\n\n    if (binding.literal && binding.kind == 'property') {\n      node[target] = binding.literal;\n    }\n  }\n}\n/**\n * Adds a 2-way binding notification event listener to the node specified\n *\n * @param {Object} node Child element to add listener to\n * @param {!PropertyEffectsType} inst Host element instance to handle notification event\n * @param {Binding} binding Binding metadata\n * @return {void}\n * @private\n */\n\n\nfunction addNotifyListener(node, inst, binding) {\n  if (binding.listenerEvent) {\n    let part = binding.parts[0];\n    node.addEventListener(binding.listenerEvent, function (e) {\n      handleNotification(e, inst, binding.target, part.source, part.negate);\n    });\n  }\n} // -- for method-based effects (complexObserver & computed) --------------\n\n/**\n * Adds property effects for each argument in the method signature (and\n * optionally, for the method name if `dynamic` is true) that calls the\n * provided effect function.\n *\n * @param {Element | Object} model Prototype or instance\n * @param {!MethodSignature} sig Method signature metadata\n * @param {string} type Type of property effect to add\n * @param {Function} effectFn Function to run when arguments change\n * @param {*=} methodInfo Effect-specific information to be included in\n *   method effect metadata\n * @param {boolean|Object=} dynamicFn Boolean or object map indicating whether\n *   method names should be included as a dependency to the effect. Note,\n *   defaults to true if the signature is static (sig.static is true).\n * @return {void}\n * @private\n */\n\n\nfunction createMethodEffect(model, sig, type, effectFn, methodInfo, dynamicFn) {\n  dynamicFn = sig.static || dynamicFn && (typeof dynamicFn !== 'object' || dynamicFn[sig.methodName]);\n  let info = {\n    methodName: sig.methodName,\n    args: sig.args,\n    methodInfo,\n    dynamicFn\n  };\n\n  for (let i = 0, arg; i < sig.args.length && (arg = sig.args[i]); i++) {\n    if (!arg.literal) {\n      model._addPropertyEffect(arg.rootProperty, type, {\n        fn: effectFn,\n        info: info,\n        trigger: arg\n      });\n    }\n  }\n\n  if (dynamicFn) {\n    model._addPropertyEffect(sig.methodName, type, {\n      fn: effectFn,\n      info: info\n    });\n  }\n}\n/**\n * Calls a method with arguments marshaled from properties on the instance\n * based on the method signature contained in the effect metadata.\n *\n * Multi-property observers, computed properties, and inline computing\n * functions call this function to invoke the method, then use the return\n * value accordingly.\n *\n * @param {!PropertyEffectsType} inst The instance the effect will be run on\n * @param {string} property Name of property\n * @param {Object} props Bag of current property changes\n * @param {Object} oldProps Bag of previous values for changed properties\n * @param {?} info Effect metadata\n * @return {*} Returns the return value from the method invocation\n * @private\n */\n\n\nfunction runMethodEffect(inst, property, props, oldProps, info) {\n  // Instances can optionally have a _methodHost which allows redirecting where\n  // to find methods. Currently used by `templatize`.\n  let context = inst._methodHost || inst;\n  let fn = context[info.methodName];\n\n  if (fn) {\n    let args = inst._marshalArgs(info.args, property, props);\n\n    return fn.apply(context, args);\n  } else if (!info.dynamicFn) {\n    console.warn('method `' + info.methodName + '` not defined');\n  }\n}\n\nconst emptyArray = []; // Regular expressions used for binding\n\nconst IDENT = '(?:' + '[a-zA-Z_$][\\\\w.:$\\\\-*]*' + ')';\nconst NUMBER = '(?:' + '[-+]?[0-9]*\\\\.?[0-9]+(?:[eE][-+]?[0-9]+)?' + ')';\nconst SQUOTE_STRING = '(?:' + '\\'(?:[^\\'\\\\\\\\]|\\\\\\\\.)*\\'' + ')';\nconst DQUOTE_STRING = '(?:' + '\"(?:[^\"\\\\\\\\]|\\\\\\\\.)*\"' + ')';\nconst STRING = '(?:' + SQUOTE_STRING + '|' + DQUOTE_STRING + ')';\nconst ARGUMENT = '(?:(' + IDENT + '|' + NUMBER + '|' + STRING + ')\\\\s*' + ')';\nconst ARGUMENTS = '(?:' + ARGUMENT + '(?:,\\\\s*' + ARGUMENT + ')*' + ')';\nconst ARGUMENT_LIST = '(?:' + '\\\\(\\\\s*' + '(?:' + ARGUMENTS + '?' + ')' + '\\\\)\\\\s*' + ')';\nconst BINDING = '(' + IDENT + '\\\\s*' + ARGUMENT_LIST + '?' + ')'; // Group 3\n\nconst OPEN_BRACKET = '(\\\\[\\\\[|{{)' + '\\\\s*';\nconst CLOSE_BRACKET = '(?:]]|}})';\nconst NEGATE = '(?:(!)\\\\s*)?'; // Group 2\n\nconst EXPRESSION = OPEN_BRACKET + NEGATE + BINDING + CLOSE_BRACKET;\nconst bindingRegex = new RegExp(EXPRESSION, \"g\");\n/**\n * Create a string from binding parts of all the literal parts\n *\n * @param {!Array<BindingPart>} parts All parts to stringify\n * @return {string} String made from the literal parts\n */\n\nfunction literalFromParts(parts) {\n  let s = '';\n\n  for (let i = 0; i < parts.length; i++) {\n    let literal = parts[i].literal;\n    s += literal || '';\n  }\n\n  return s;\n}\n/**\n * Parses an expression string for a method signature, and returns a metadata\n * describing the method in terms of `methodName`, `static` (whether all the\n * arguments are literals), and an array of `args`\n *\n * @param {string} expression The expression to parse\n * @return {?MethodSignature} The method metadata object if a method expression was\n *   found, otherwise `undefined`\n * @private\n */\n\n\nfunction parseMethod(expression) {\n  // tries to match valid javascript property names\n  let m = expression.match(/([^\\s]+?)\\(([\\s\\S]*)\\)/);\n\n  if (m) {\n    let methodName = m[1];\n    let sig = {\n      methodName,\n      static: true,\n      args: emptyArray\n    };\n\n    if (m[2].trim()) {\n      // replace escaped commas with comma entity, split on un-escaped commas\n      let args = m[2].replace(/\\\\,/g, '&comma;').split(',');\n      return parseArgs(args, sig);\n    } else {\n      return sig;\n    }\n  }\n\n  return null;\n}\n/**\n * Parses an array of arguments and sets the `args` property of the supplied\n * signature metadata object. Sets the `static` property to false if any\n * argument is a non-literal.\n *\n * @param {!Array<string>} argList Array of argument names\n * @param {!MethodSignature} sig Method signature metadata object\n * @return {!MethodSignature} The updated signature metadata object\n * @private\n */\n\n\nfunction parseArgs(argList, sig) {\n  sig.args = argList.map(function (rawArg) {\n    let arg = parseArg(rawArg);\n\n    if (!arg.literal) {\n      sig.static = false;\n    }\n\n    return arg;\n  }, this);\n  return sig;\n}\n/**\n * Parses an individual argument, and returns an argument metadata object\n * with the following fields:\n *\n *   {\n *     value: 'prop',        // property/path or literal value\n *     literal: false,       // whether argument is a literal\n *     structured: false,    // whether the property is a path\n *     rootProperty: 'prop', // the root property of the path\n *     wildcard: false       // whether the argument was a wildcard '.*' path\n *   }\n *\n * @param {string} rawArg The string value of the argument\n * @return {!MethodArg} Argument metadata object\n * @private\n */\n\n\nfunction parseArg(rawArg) {\n  // clean up whitespace\n  let arg = rawArg.trim() // replace comma entity with comma\n  .replace(/&comma;/g, ',') // repair extra escape sequences; note only commas strictly need\n  // escaping, but we allow any other char to be escaped since its\n  // likely users will do this\n  .replace(/\\\\(.)/g, '\\$1'); // basic argument descriptor\n\n  let a = {\n    name: arg,\n    value: '',\n    literal: false\n  }; // detect literal value (must be String or Number)\n\n  let fc = arg[0];\n\n  if (fc === '-') {\n    fc = arg[1];\n  }\n\n  if (fc >= '0' && fc <= '9') {\n    fc = '#';\n  }\n\n  switch (fc) {\n    case \"'\":\n    case '\"':\n      a.value = arg.slice(1, -1);\n      a.literal = true;\n      break;\n\n    case '#':\n      a.value = Number(arg);\n      a.literal = true;\n      break;\n  } // if not literal, look for structured path\n\n\n  if (!a.literal) {\n    a.rootProperty = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.root)(arg); // detect structured path (has dots)\n\n    a.structured = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isPath)(arg);\n\n    if (a.structured) {\n      a.wildcard = arg.slice(-2) == '.*';\n\n      if (a.wildcard) {\n        a.name = arg.slice(0, -2);\n      }\n    }\n  }\n\n  return a;\n} // data api\n\n/**\n * Sends array splice notifications (`.splices` and `.length`)\n *\n * Note: this implementation only accepts normalized paths\n *\n * @param {!PropertyEffectsType} inst Instance to send notifications to\n * @param {Array} array The array the mutations occurred on\n * @param {string} path The path to the array that was mutated\n * @param {Array} splices Array of splice records\n * @return {void}\n * @private\n */\n\n\nfunction notifySplices(inst, array, path, splices) {\n  let splicesPath = path + '.splices';\n  inst.notifyPath(splicesPath, {\n    indexSplices: splices\n  });\n  inst.notifyPath(path + '.length', array.length); // Null here to allow potentially large splice records to be GC'ed.\n\n  inst.__data[splicesPath] = {\n    indexSplices: null\n  };\n}\n/**\n * Creates a splice record and sends an array splice notification for\n * the described mutation\n *\n * Note: this implementation only accepts normalized paths\n *\n * @param {!PropertyEffectsType} inst Instance to send notifications to\n * @param {Array} array The array the mutations occurred on\n * @param {string} path The path to the array that was mutated\n * @param {number} index Index at which the array mutation occurred\n * @param {number} addedCount Number of added items\n * @param {Array} removed Array of removed items\n * @return {void}\n * @private\n */\n\n\nfunction notifySplice(inst, array, path, index, addedCount, removed) {\n  notifySplices(inst, array, path, [{\n    index: index,\n    addedCount: addedCount,\n    removed: removed,\n    object: array,\n    type: 'splice'\n  }]);\n}\n/**\n * Returns an upper-cased version of the string.\n *\n * @param {string} name String to uppercase\n * @return {string} Uppercased string\n * @private\n */\n\n\nfunction upper(name) {\n  return name[0].toUpperCase() + name.substring(1);\n}\n/**\n * Element class mixin that provides meta-programming for Polymer's template\n * binding and data observation (collectively, \"property effects\") system.\n *\n * This mixin uses provides the following key static methods for adding\n * property effects to an element class:\n * - `addPropertyEffect`\n * - `createPropertyObserver`\n * - `createMethodObserver`\n * - `createNotifyingProperty`\n * - `createReadOnlyProperty`\n * - `createReflectedProperty`\n * - `createComputedProperty`\n * - `bindTemplate`\n *\n * Each method creates one or more property accessors, along with metadata\n * used by this mixin's implementation of `_propertiesChanged` to perform\n * the property effects.\n *\n * Underscored versions of the above methods also exist on the element\n * prototype for adding property effects on instances at runtime.\n *\n * Note that this mixin overrides several `PropertyAccessors` methods, in\n * many cases to maintain guarantees provided by the Polymer 1.x features;\n * notably it changes property accessors to be synchronous by default\n * whereas the default when using `PropertyAccessors` standalone is to be\n * async by default.\n *\n * @mixinFunction\n * @polymer\n * @appliesMixin TemplateStamp\n * @appliesMixin PropertyAccessors\n * @summary Element class mixin that provides meta-programming for Polymer's\n * template binding and data observation system.\n */\n\n\nconst PropertyEffects = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(superClass => {\n  /**\n   * @constructor\n   * @extends {superClass}\n   * @implements {Polymer_PropertyAccessors}\n   * @implements {Polymer_TemplateStamp}\n   * @unrestricted\n   * @private\n   */\n  const propertyEffectsBase = (0,_template_stamp_js__WEBPACK_IMPORTED_MODULE_5__.TemplateStamp)((0,_property_accessors_js__WEBPACK_IMPORTED_MODULE_4__.PropertyAccessors)(superClass));\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_PropertyEffects}\n   * @extends {propertyEffectsBase}\n   * @unrestricted\n   */\n\n  class PropertyEffects extends propertyEffectsBase {\n    constructor() {\n      super();\n      /** @type {boolean} */\n      // Used to identify users of this mixin, ala instanceof\n\n      this.__isPropertyEffectsClient = true;\n      /** @type {number} */\n      // NOTE: used to track re-entrant calls to `_flushProperties`\n      // path changes dirty check against `__dataTemp` only during one \"turn\"\n      // and are cleared when `__dataCounter` returns to 0.\n\n      this.__dataCounter = 0;\n      /** @type {boolean} */\n\n      this.__dataClientsReady;\n      /** @type {Array} */\n\n      this.__dataPendingClients;\n      /** @type {Object} */\n\n      this.__dataToNotify;\n      /** @type {Object} */\n\n      this.__dataLinkedPaths;\n      /** @type {boolean} */\n\n      this.__dataHasPaths;\n      /** @type {Object} */\n\n      this.__dataCompoundStorage;\n      /** @type {Polymer_PropertyEffects} */\n\n      this.__dataHost;\n      /** @type {!Object} */\n\n      this.__dataTemp;\n      /** @type {boolean} */\n\n      this.__dataClientsInitialized;\n      /** @type {!Object} */\n\n      this.__data;\n      /** @type {!Object} */\n\n      this.__dataPending;\n      /** @type {!Object} */\n\n      this.__dataOld;\n      /** @type {Object} */\n\n      this.__computeEffects;\n      /** @type {Object} */\n\n      this.__reflectEffects;\n      /** @type {Object} */\n\n      this.__notifyEffects;\n      /** @type {Object} */\n\n      this.__propagateEffects;\n      /** @type {Object} */\n\n      this.__observeEffects;\n      /** @type {Object} */\n\n      this.__readOnly;\n      /** @type {!TemplateInfo} */\n\n      this.__templateInfo;\n    }\n\n    get PROPERTY_EFFECT_TYPES() {\n      return TYPES;\n    }\n    /**\n     * @return {void}\n     */\n\n\n    _initializeProperties() {\n      super._initializeProperties();\n\n      hostStack.registerHost(this);\n      this.__dataClientsReady = false;\n      this.__dataPendingClients = null;\n      this.__dataToNotify = null;\n      this.__dataLinkedPaths = null;\n      this.__dataHasPaths = false; // May be set on instance prior to upgrade\n\n      this.__dataCompoundStorage = this.__dataCompoundStorage || null;\n      this.__dataHost = this.__dataHost || null;\n      this.__dataTemp = {};\n      this.__dataClientsInitialized = false;\n    }\n    /**\n     * Overrides `PropertyAccessors` implementation to provide a\n     * more efficient implementation of initializing properties from\n     * the prototype on the instance.\n     *\n     * @override\n     * @param {Object} props Properties to initialize on the prototype\n     * @return {void}\n     */\n\n\n    _initializeProtoProperties(props) {\n      this.__data = Object.create(props);\n      this.__dataPending = Object.create(props);\n      this.__dataOld = {};\n    }\n    /**\n     * Overrides `PropertyAccessors` implementation to avoid setting\n     * `_setProperty`'s `shouldNotify: true`.\n     *\n     * @override\n     * @param {Object} props Properties to initialize on the instance\n     * @return {void}\n     */\n\n\n    _initializeInstanceProperties(props) {\n      let readOnly = this[TYPES.READ_ONLY];\n\n      for (let prop in props) {\n        if (!readOnly || !readOnly[prop]) {\n          this.__dataPending = this.__dataPending || {};\n          this.__dataOld = this.__dataOld || {};\n          this.__data[prop] = this.__dataPending[prop] = props[prop];\n        }\n      }\n    } // Prototype setup ----------------------------------------\n\n    /**\n     * Equivalent to static `addPropertyEffect` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Property that should trigger the effect\n     * @param {string} type Effect type, from this.PROPERTY_EFFECT_TYPES\n     * @param {Object=} effect Effect metadata object\n     * @return {void}\n     * @protected\n     */\n\n\n    _addPropertyEffect(property, type, effect) {\n      this._createPropertyAccessor(property, type == TYPES.READ_ONLY); // effects are accumulated into arrays per property based on type\n\n\n      let effects = ensureOwnEffectMap(this, type)[property];\n\n      if (!effects) {\n        effects = this[type][property] = [];\n      }\n\n      effects.push(effect);\n    }\n    /**\n     * Removes the given property effect.\n     *\n     * @param {string} property Property the effect was associated with\n     * @param {string} type Effect type, from this.PROPERTY_EFFECT_TYPES\n     * @param {Object=} effect Effect metadata object to remove\n     * @return {void}\n     */\n\n\n    _removePropertyEffect(property, type, effect) {\n      let effects = ensureOwnEffectMap(this, type)[property];\n      let idx = effects.indexOf(effect);\n\n      if (idx >= 0) {\n        effects.splice(idx, 1);\n      }\n    }\n    /**\n     * Returns whether the current prototype/instance has a property effect\n     * of a certain type.\n     *\n     * @param {string} property Property name\n     * @param {string=} type Effect type, from this.PROPERTY_EFFECT_TYPES\n     * @return {boolean} True if the prototype/instance has an effect of this type\n     * @protected\n     */\n\n\n    _hasPropertyEffect(property, type) {\n      let effects = this[type];\n      return Boolean(effects && effects[property]);\n    }\n    /**\n     * Returns whether the current prototype/instance has a \"read only\"\n     * accessor for the given property.\n     *\n     * @param {string} property Property name\n     * @return {boolean} True if the prototype/instance has an effect of this type\n     * @protected\n     */\n\n\n    _hasReadOnlyEffect(property) {\n      return this._hasPropertyEffect(property, TYPES.READ_ONLY);\n    }\n    /**\n     * Returns whether the current prototype/instance has a \"notify\"\n     * property effect for the given property.\n     *\n     * @param {string} property Property name\n     * @return {boolean} True if the prototype/instance has an effect of this type\n     * @protected\n     */\n\n\n    _hasNotifyEffect(property) {\n      return this._hasPropertyEffect(property, TYPES.NOTIFY);\n    }\n    /**\n     * Returns whether the current prototype/instance has a \"reflect to attribute\"\n     * property effect for the given property.\n     *\n     * @param {string} property Property name\n     * @return {boolean} True if the prototype/instance has an effect of this type\n     * @protected\n     */\n\n\n    _hasReflectEffect(property) {\n      return this._hasPropertyEffect(property, TYPES.REFLECT);\n    }\n    /**\n     * Returns whether the current prototype/instance has a \"computed\"\n     * property effect for the given property.\n     *\n     * @param {string} property Property name\n     * @return {boolean} True if the prototype/instance has an effect of this type\n     * @protected\n     */\n\n\n    _hasComputedEffect(property) {\n      return this._hasPropertyEffect(property, TYPES.COMPUTE);\n    } // Runtime ----------------------------------------\n\n    /**\n     * Sets a pending property or path.  If the root property of the path in\n     * question had no accessor, the path is set, otherwise it is enqueued\n     * via `_setPendingProperty`.\n     *\n     * This function isolates relatively expensive functionality necessary\n     * for the public API (`set`, `setProperties`, `notifyPath`, and property\n     * change listeners via {{...}} bindings), such that it is only done\n     * when paths enter the system, and not at every propagation step.  It\n     * also sets a `__dataHasPaths` flag on the instance which is used to\n     * fast-path slower path-matching code in the property effects host paths.\n     *\n     * `path` can be a path string or array of path parts as accepted by the\n     * public API.\n     *\n     * @param {string | !Array<number|string>} path Path to set\n     * @param {*} value Value to set\n     * @param {boolean=} shouldNotify Set to true if this change should\n     *  cause a property notification event dispatch\n     * @param {boolean=} isPathNotification If the path being set is a path\n     *   notification of an already changed value, as opposed to a request\n     *   to set and notify the change.  In the latter `false` case, a dirty\n     *   check is performed and then the value is set to the path before\n     *   enqueuing the pending property change.\n     * @return {boolean} Returns true if the property/path was enqueued in\n     *   the pending changes bag.\n     * @protected\n     */\n\n\n    _setPendingPropertyOrPath(path, value, shouldNotify, isPathNotification) {\n      if (isPathNotification || (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.root)(Array.isArray(path) ? path[0] : path) !== path) {\n        // Dirty check changes being set to a path against the actual object,\n        // since this is the entry point for paths into the system; from here\n        // the only dirty checks are against the `__dataTemp` cache to prevent\n        // duplicate work in the same turn only. Note, if this was a notification\n        // of a change already set to a path (isPathNotification: true),\n        // we always let the change through and skip the `set` since it was\n        // already dirty checked at the point of entry and the underlying\n        // object has already been updated\n        if (!isPathNotification) {\n          let old = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path);\n          path =\n          /** @type {string} */\n          (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.set)(this, path, value); // Use property-accessor's simpler dirty check\n\n          if (!path || !super._shouldPropertyChange(path, value, old)) {\n            return false;\n          }\n        }\n\n        this.__dataHasPaths = true;\n\n        if (this._setPendingProperty(\n        /**@type{string}*/\n        path, value, shouldNotify)) {\n          computeLinkedPaths(this, path, value);\n          return true;\n        }\n      } else {\n        if (this.__dataHasAccessor && this.__dataHasAccessor[path]) {\n          return this._setPendingProperty(\n          /**@type{string}*/\n          path, value, shouldNotify);\n        } else {\n          this[path] = value;\n        }\n      }\n\n      return false;\n    }\n    /**\n     * Applies a value to a non-Polymer element/node's property.\n     *\n     * The implementation makes a best-effort at binding interop:\n     * Some native element properties have side-effects when\n     * re-setting the same value (e.g. setting `<input>.value` resets the\n     * cursor position), so we do a dirty-check before setting the value.\n     * However, for better interop with non-Polymer custom elements that\n     * accept objects, we explicitly re-set object changes coming from the\n     * Polymer world (which may include deep object changes without the\n     * top reference changing), erring on the side of providing more\n     * information.\n     *\n     * Users may override this method to provide alternate approaches.\n     *\n     * @param {!Node} node The node to set a property on\n     * @param {string} prop The property to set\n     * @param {*} value The value to set\n     * @return {void}\n     * @protected\n     */\n\n\n    _setUnmanagedPropertyToNode(node, prop, value) {\n      // It is a judgment call that resetting primitives is\n      // \"bad\" and resettings objects is also \"good\"; alternatively we could\n      // implement a whitelist of tag & property values that should never\n      // be reset (e.g. <input>.value && <select>.value)\n      if (value !== node[prop] || typeof value == 'object') {\n        node[prop] = value;\n      }\n    }\n    /**\n     * Overrides the `PropertiesChanged` implementation to introduce special\n     * dirty check logic depending on the property & value being set:\n     *\n     * 1. Any value set to a path (e.g. 'obj.prop': 42 or 'obj.prop': {...})\n     *    Stored in `__dataTemp`, dirty checked against `__dataTemp`\n     * 2. Object set to simple property (e.g. 'prop': {...})\n     *    Stored in `__dataTemp` and `__data`, dirty checked against\n     *    `__dataTemp` by default implementation of `_shouldPropertyChange`\n     * 3. Primitive value set to simple property (e.g. 'prop': 42)\n     *    Stored in `__data`, dirty checked against `__data`\n     *\n     * The dirty-check is important to prevent cycles due to two-way\n     * notification, but paths and objects are only dirty checked against any\n     * previous value set during this turn via a \"temporary cache\" that is\n     * cleared when the last `_propertiesChanged` exits. This is so:\n     * a. any cached array paths (e.g. 'array.3.prop') may be invalidated\n     *    due to array mutations like shift/unshift/splice; this is fine\n     *    since path changes are dirty-checked at user entry points like `set`\n     * b. dirty-checking for objects only lasts one turn to allow the user\n     *    to mutate the object in-place and re-set it with the same identity\n     *    and have all sub-properties re-propagated in a subsequent turn.\n     *\n     * The temp cache is not necessarily sufficient to prevent invalid array\n     * paths, since a splice can happen during the same turn (with pathological\n     * user code); we could introduce a \"fixup\" for temporarily cached array\n     * paths if needed: https://github.com/Polymer/polymer/issues/4227\n     *\n     * @override\n     * @param {string} property Name of the property\n     * @param {*} value Value to set\n     * @param {boolean=} shouldNotify True if property should fire notification\n     *   event (applies only for `notify: true` properties)\n     * @return {boolean} Returns true if the property changed\n     */\n\n\n    _setPendingProperty(property, value, shouldNotify) {\n      let propIsPath = this.__dataHasPaths && (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isPath)(property);\n      let prevProps = propIsPath ? this.__dataTemp : this.__data;\n\n      if (this._shouldPropertyChange(property, value, prevProps[property])) {\n        if (!this.__dataPending) {\n          this.__dataPending = {};\n          this.__dataOld = {};\n        } // Ensure old is captured from the last turn\n\n\n        if (!(property in this.__dataOld)) {\n          this.__dataOld[property] = this.__data[property];\n        } // Paths are stored in temporary cache (cleared at end of turn),\n        // which is used for dirty-checking, all others stored in __data\n\n\n        if (propIsPath) {\n          this.__dataTemp[property] = value;\n        } else {\n          this.__data[property] = value;\n        } // All changes go into pending property bag, passed to _propertiesChanged\n\n\n        this.__dataPending[property] = value; // Track properties that should notify separately\n\n        if (propIsPath || this[TYPES.NOTIFY] && this[TYPES.NOTIFY][property]) {\n          this.__dataToNotify = this.__dataToNotify || {};\n          this.__dataToNotify[property] = shouldNotify;\n        }\n\n        return true;\n      }\n\n      return false;\n    }\n    /**\n     * Overrides base implementation to ensure all accessors set `shouldNotify`\n     * to true, for per-property notification tracking.\n     *\n     * @override\n     * @param {string} property Name of the property\n     * @param {*} value Value to set\n     * @return {void}\n     */\n\n\n    _setProperty(property, value) {\n      if (this._setPendingProperty(property, value, true)) {\n        this._invalidateProperties();\n      }\n    }\n    /**\n     * Overrides `PropertyAccessor`'s default async queuing of\n     * `_propertiesChanged`: if `__dataReady` is false (has not yet been\n     * manually flushed), the function no-ops; otherwise flushes\n     * `_propertiesChanged` synchronously.\n     *\n     * @override\n     * @return {void}\n     */\n\n\n    _invalidateProperties() {\n      if (this.__dataReady) {\n        this._flushProperties();\n      }\n    }\n    /**\n     * Enqueues the given client on a list of pending clients, whose\n     * pending property changes can later be flushed via a call to\n     * `_flushClients`.\n     *\n     * @param {Object} client PropertyEffects client to enqueue\n     * @return {void}\n     * @protected\n     */\n\n\n    _enqueueClient(client) {\n      this.__dataPendingClients = this.__dataPendingClients || [];\n\n      if (client !== this) {\n        this.__dataPendingClients.push(client);\n      }\n    }\n    /**\n     * Overrides superclass implementation.\n     *\n     * @return {void}\n     * @protected\n     */\n\n\n    _flushProperties() {\n      this.__dataCounter++;\n\n      super._flushProperties();\n\n      this.__dataCounter--;\n    }\n    /**\n     * Flushes any clients previously enqueued via `_enqueueClient`, causing\n     * their `_flushProperties` method to run.\n     *\n     * @return {void}\n     * @protected\n     */\n\n\n    _flushClients() {\n      if (!this.__dataClientsReady) {\n        this.__dataClientsReady = true;\n\n        this._readyClients(); // Override point where accessors are turned on; importantly,\n        // this is after clients have fully readied, providing a guarantee\n        // that any property effects occur only after all clients are ready.\n\n\n        this.__dataReady = true;\n      } else {\n        this.__enableOrFlushClients();\n      }\n    } // NOTE: We ensure clients either enable or flush as appropriate. This\n    // handles two corner cases:\n    // (1) clients flush properly when connected/enabled before the host\n    // enables; e.g.\n    //   (a) Templatize stamps with no properties and does not flush and\n    //   (b) the instance is inserted into dom and\n    //   (c) then the instance flushes.\n    // (2) clients enable properly when not connected/enabled when the host\n    // flushes; e.g.\n    //   (a) a template is runtime stamped and not yet connected/enabled\n    //   (b) a host sets a property, causing stamped dom to flush\n    //   (c) the stamped dom enables.\n\n\n    __enableOrFlushClients() {\n      let clients = this.__dataPendingClients;\n\n      if (clients) {\n        this.__dataPendingClients = null;\n\n        for (let i = 0; i < clients.length; i++) {\n          let client = clients[i];\n\n          if (!client.__dataEnabled) {\n            client._enableProperties();\n          } else if (client.__dataPending) {\n            client._flushProperties();\n          }\n        }\n      }\n    }\n    /**\n     * Perform any initial setup on client dom. Called before the first\n     * `_flushProperties` call on client dom and before any element\n     * observers are called.\n     *\n     * @return {void}\n     * @protected\n     */\n\n\n    _readyClients() {\n      this.__enableOrFlushClients();\n    }\n    /**\n     * Sets a bag of property changes to this instance, and\n     * synchronously processes all effects of the properties as a batch.\n     *\n     * Property names must be simple properties, not paths.  Batched\n     * path propagation is not supported.\n     *\n     * @param {Object} props Bag of one or more key-value pairs whose key is\n     *   a property and value is the new value to set for that property.\n     * @param {boolean=} setReadOnly When true, any private values set in\n     *   `props` will be set. By default, `setProperties` will not set\n     *   `readOnly: true` root properties.\n     * @return {void}\n     * @public\n     */\n\n\n    setProperties(props, setReadOnly) {\n      for (let path in props) {\n        if (setReadOnly || !this[TYPES.READ_ONLY] || !this[TYPES.READ_ONLY][path]) {\n          //TODO(kschaaf): explicitly disallow paths in setProperty?\n          // wildcard observers currently only pass the first changed path\n          // in the `info` object, and you could do some odd things batching\n          // paths, e.g. {'foo.bar': {...}, 'foo': null}\n          this._setPendingPropertyOrPath(path, props[path], true);\n        }\n      }\n\n      this._invalidateProperties();\n    }\n    /**\n     * Overrides `PropertyAccessors` so that property accessor\n     * side effects are not enabled until after client dom is fully ready.\n     * Also calls `_flushClients` callback to ensure client dom is enabled\n     * that was not enabled as a result of flushing properties.\n     *\n     * @override\n     * @return {void}\n     */\n\n\n    ready() {\n      // It is important that `super.ready()` is not called here as it\n      // immediately turns on accessors. Instead, we wait until `readyClients`\n      // to enable accessors to provide a guarantee that clients are ready\n      // before processing any accessors side effects.\n      this._flushProperties(); // If no data was pending, `_flushProperties` will not `flushClients`\n      // so ensure this is done.\n\n\n      if (!this.__dataClientsReady) {\n        this._flushClients();\n      } // Before ready, client notifications do not trigger _flushProperties.\n      // Therefore a flush is necessary here if data has been set.\n\n\n      if (this.__dataPending) {\n        this._flushProperties();\n      }\n    }\n    /**\n     * Implements `PropertyAccessors`'s properties changed callback.\n     *\n     * Runs each class of effects for the batch of changed properties in\n     * a specific order (compute, propagate, reflect, observe, notify).\n     *\n     * @param {!Object} currentProps Bag of all current accessor values\n     * @param {?Object} changedProps Bag of properties changed since the last\n     *   call to `_propertiesChanged`\n     * @param {?Object} oldProps Bag of previous values for each property\n     *   in `changedProps`\n     * @return {void}\n     */\n\n\n    _propertiesChanged(currentProps, changedProps, oldProps) {\n      // ----------------------------\n      // let c = Object.getOwnPropertyNames(changedProps || {});\n      // window.debug && console.group(this.localName + '#' + this.id + ': ' + c);\n      // if (window.debug) { debugger; }\n      // ----------------------------\n      let hasPaths = this.__dataHasPaths;\n      this.__dataHasPaths = false; // Compute properties\n\n      runComputedEffects(this, changedProps, oldProps, hasPaths); // Clear notify properties prior to possible reentry (propagate, observe),\n      // but after computing effects have a chance to add to them\n\n      let notifyProps = this.__dataToNotify;\n      this.__dataToNotify = null; // Propagate properties to clients\n\n      this._propagatePropertyChanges(changedProps, oldProps, hasPaths); // Flush clients\n\n\n      this._flushClients(); // Reflect properties\n\n\n      runEffects(this, this[TYPES.REFLECT], changedProps, oldProps, hasPaths); // Observe properties\n\n      runEffects(this, this[TYPES.OBSERVE], changedProps, oldProps, hasPaths); // Notify properties to host\n\n      if (notifyProps) {\n        runNotifyEffects(this, notifyProps, changedProps, oldProps, hasPaths);\n      } // Clear temporary cache at end of turn\n\n\n      if (this.__dataCounter == 1) {\n        this.__dataTemp = {};\n      } // ----------------------------\n      // window.debug && console.groupEnd(this.localName + '#' + this.id + ': ' + c);\n      // ----------------------------\n\n    }\n    /**\n     * Called to propagate any property changes to stamped template nodes\n     * managed by this element.\n     *\n     * @param {Object} changedProps Bag of changed properties\n     * @param {Object} oldProps Bag of previous values for changed properties\n     * @param {boolean} hasPaths True with `props` contains one or more paths\n     * @return {void}\n     * @protected\n     */\n\n\n    _propagatePropertyChanges(changedProps, oldProps, hasPaths) {\n      if (this[TYPES.PROPAGATE]) {\n        runEffects(this, this[TYPES.PROPAGATE], changedProps, oldProps, hasPaths);\n      }\n\n      let templateInfo = this.__templateInfo;\n\n      while (templateInfo) {\n        runEffects(this, templateInfo.propertyEffects, changedProps, oldProps, hasPaths, templateInfo.nodeList);\n        templateInfo = templateInfo.nextTemplateInfo;\n      }\n    }\n    /**\n     * Aliases one data path as another, such that path notifications from one\n     * are routed to the other.\n     *\n     * @param {string | !Array<string|number>} to Target path to link.\n     * @param {string | !Array<string|number>} from Source path to link.\n     * @return {void}\n     * @public\n     */\n\n\n    linkPaths(to, from) {\n      to = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.normalize)(to);\n      from = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.normalize)(from);\n      this.__dataLinkedPaths = this.__dataLinkedPaths || {};\n      this.__dataLinkedPaths[to] = from;\n    }\n    /**\n     * Removes a data path alias previously established with `_linkPaths`.\n     *\n     * Note, the path to unlink should be the target (`to`) used when\n     * linking the paths.\n     *\n     * @param {string | !Array<string|number>} path Target path to unlink.\n     * @return {void}\n     * @public\n     */\n\n\n    unlinkPaths(path) {\n      path = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.normalize)(path);\n\n      if (this.__dataLinkedPaths) {\n        delete this.__dataLinkedPaths[path];\n      }\n    }\n    /**\n     * Notify that an array has changed.\n     *\n     * Example:\n     *\n     *     this.items = [ {name: 'Jim'}, {name: 'Todd'}, {name: 'Bill'} ];\n     *     ...\n     *     this.items.splice(1, 1, {name: 'Sam'});\n     *     this.items.push({name: 'Bob'});\n     *     this.notifySplices('items', [\n     *       { index: 1, removed: [{name: 'Todd'}], addedCount: 1, object: this.items, type: 'splice' },\n     *       { index: 3, removed: [], addedCount: 1, object: this.items, type: 'splice'}\n     *     ]);\n     *\n     * @param {string} path Path that should be notified.\n     * @param {Array} splices Array of splice records indicating ordered\n     *   changes that occurred to the array. Each record should have the\n     *   following fields:\n     *    * index: index at which the change occurred\n     *    * removed: array of items that were removed from this index\n     *    * addedCount: number of new items added at this index\n     *    * object: a reference to the array in question\n     *    * type: the string literal 'splice'\n     *\n     *   Note that splice records _must_ be normalized such that they are\n     *   reported in index order (raw results from `Object.observe` are not\n     *   ordered and must be normalized/merged before notifying).\n     * @return {void}\n     * @public\n    */\n\n\n    notifySplices(path, splices) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array} */\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n      notifySplices(this, array, info.path, splices);\n    }\n    /**\n     * Convenience method for reading a value from a path.\n     *\n     * Note, if any part in the path is undefined, this method returns\n     * `undefined` (this method does not throw when dereferencing undefined\n     * paths).\n     *\n     * @param {(string|!Array<(string|number)>)} path Path to the value\n     *   to read.  The path may be specified as a string (e.g. `foo.bar.baz`)\n     *   or an array of path parts (e.g. `['foo.bar', 'baz']`).  Note that\n     *   bracketed expressions are not supported; string-based path parts\n     *   *must* be separated by dots.  Note that when dereferencing array\n     *   indices, the index may be used as a dotted part directly\n     *   (e.g. `users.12.name` or `['users', 12, 'name']`).\n     * @param {Object=} root Root object from which the path is evaluated.\n     * @return {*} Value at the path, or `undefined` if any part of the path\n     *   is undefined.\n     * @public\n     */\n\n\n    get(path, root) {\n      return (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(root || this, path);\n    }\n    /**\n     * Convenience method for setting a value to a path and notifying any\n     * elements bound to the same path.\n     *\n     * Note, if any part in the path except for the last is undefined,\n     * this method does nothing (this method does not throw when\n     * dereferencing undefined paths).\n     *\n     * @param {(string|!Array<(string|number)>)} path Path to the value\n     *   to write.  The path may be specified as a string (e.g. `'foo.bar.baz'`)\n     *   or an array of path parts (e.g. `['foo.bar', 'baz']`).  Note that\n     *   bracketed expressions are not supported; string-based path parts\n     *   *must* be separated by dots.  Note that when dereferencing array\n     *   indices, the index may be used as a dotted part directly\n     *   (e.g. `'users.12.name'` or `['users', 12, 'name']`).\n     * @param {*} value Value to set at the specified path.\n     * @param {Object=} root Root object from which the path is evaluated.\n     *   When specified, no notification will occur.\n     * @return {void}\n     * @public\n    */\n\n\n    set(path, value, root) {\n      if (root) {\n        (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.set)(root, path, value);\n      } else {\n        if (!this[TYPES.READ_ONLY] || !this[TYPES.READ_ONLY][\n        /** @type {string} */\n        path]) {\n          if (this._setPendingPropertyOrPath(path, value, true)) {\n            this._invalidateProperties();\n          }\n        }\n      }\n    }\n    /**\n     * Adds items onto the end of the array at the path specified.\n     *\n     * The arguments after `path` and return value match that of\n     * `Array.prototype.push`.\n     *\n     * This method notifies other paths to the same array that a\n     * splice occurred to the array.\n     *\n     * @param {string | !Array<string|number>} path Path to array.\n     * @param {...*} items Items to push onto array\n     * @return {number} New length of the array.\n     * @public\n     */\n\n\n    push(path, ...items) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array}*/\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n      let len = array.length;\n      let ret = array.push(...items);\n\n      if (items.length) {\n        notifySplice(this, array, info.path, len, items.length, []);\n      }\n\n      return ret;\n    }\n    /**\n     * Removes an item from the end of array at the path specified.\n     *\n     * The arguments after `path` and return value match that of\n     * `Array.prototype.pop`.\n     *\n     * This method notifies other paths to the same array that a\n     * splice occurred to the array.\n     *\n     * @param {string | !Array<string|number>} path Path to array.\n     * @return {*} Item that was removed.\n     * @public\n     */\n\n\n    pop(path) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array} */\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n      let hadLength = Boolean(array.length);\n      let ret = array.pop();\n\n      if (hadLength) {\n        notifySplice(this, array, info.path, array.length, 0, [ret]);\n      }\n\n      return ret;\n    }\n    /**\n     * Starting from the start index specified, removes 0 or more items\n     * from the array and inserts 0 or more new items in their place.\n     *\n     * The arguments after `path` and return value match that of\n     * `Array.prototype.splice`.\n     *\n     * This method notifies other paths to the same array that a\n     * splice occurred to the array.\n     *\n     * @param {string | !Array<string|number>} path Path to array.\n     * @param {number} start Index from which to start removing/inserting.\n     * @param {number=} deleteCount Number of items to remove.\n     * @param {...*} items Items to insert into array.\n     * @return {Array} Array of removed items.\n     * @public\n     */\n\n\n    splice(path, start, deleteCount, ...items) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array} */\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info); // Normalize fancy native splice handling of crazy start values\n\n      if (start < 0) {\n        start = array.length - Math.floor(-start);\n      } else if (start) {\n        start = Math.floor(start);\n      } // array.splice does different things based on the number of arguments\n      // you pass in. Therefore, array.splice(0) and array.splice(0, undefined)\n      // do different things. In the former, the whole array is cleared. In the\n      // latter, no items are removed.\n      // This means that we need to detect whether 1. one of the arguments\n      // is actually passed in and then 2. determine how many arguments\n      // we should pass on to the native array.splice\n      //\n\n\n      let ret; // Omit any additional arguments if they were not passed in\n\n      if (arguments.length === 2) {\n        ret = array.splice(start); // Either start was undefined and the others were defined, but in this\n        // case we can safely pass on all arguments\n        //\n        // Note: this includes the case where none of the arguments were passed in,\n        // e.g. this.splice('array'). However, if both start and deleteCount\n        // are undefined, array.splice will not modify the array (as expected)\n      } else {\n        ret = array.splice(start, deleteCount, ...items);\n      } // At the end, check whether any items were passed in (e.g. insertions)\n      // or if the return array contains items (e.g. deletions).\n      // Only notify if items were added or deleted.\n\n\n      if (items.length || ret.length) {\n        notifySplice(this, array, info.path, start, items.length, ret);\n      }\n\n      return ret;\n    }\n    /**\n     * Removes an item from the beginning of array at the path specified.\n     *\n     * The arguments after `path` and return value match that of\n     * `Array.prototype.pop`.\n     *\n     * This method notifies other paths to the same array that a\n     * splice occurred to the array.\n     *\n     * @param {string | !Array<string|number>} path Path to array.\n     * @return {*} Item that was removed.\n     * @public\n     */\n\n\n    shift(path) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array} */\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n      let hadLength = Boolean(array.length);\n      let ret = array.shift();\n\n      if (hadLength) {\n        notifySplice(this, array, info.path, 0, 0, [ret]);\n      }\n\n      return ret;\n    }\n    /**\n     * Adds items onto the beginning of the array at the path specified.\n     *\n     * The arguments after `path` and return value match that of\n     * `Array.prototype.push`.\n     *\n     * This method notifies other paths to the same array that a\n     * splice occurred to the array.\n     *\n     * @param {string | !Array<string|number>} path Path to array.\n     * @param {...*} items Items to insert info array\n     * @return {number} New length of the array.\n     * @public\n     */\n\n\n    unshift(path, ...items) {\n      let info = {\n        path: ''\n      };\n      let array =\n      /** @type {Array} */\n      (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n      let ret = array.unshift(...items);\n\n      if (items.length) {\n        notifySplice(this, array, info.path, 0, items.length, []);\n      }\n\n      return ret;\n    }\n    /**\n     * Notify that a path has changed.\n     *\n     * Example:\n     *\n     *     this.item.user.name = 'Bob';\n     *     this.notifyPath('item.user.name');\n     *\n     * @param {string} path Path that should be notified.\n     * @param {*=} value Value at the path (optional).\n     * @return {void}\n     * @public\n    */\n\n\n    notifyPath(path, value) {\n      /** @type {string} */\n      let propPath;\n\n      if (arguments.length == 1) {\n        // Get value if not supplied\n        let info = {\n          path: ''\n        };\n        value = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(this, path, info);\n        propPath = info.path;\n      } else if (Array.isArray(path)) {\n        // Normalize path if needed\n        propPath = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.normalize)(path);\n      } else {\n        propPath =\n        /** @type{string} */\n        path;\n      }\n\n      if (this._setPendingPropertyOrPath(propPath, value, true, true)) {\n        this._invalidateProperties();\n      }\n    }\n    /**\n     * Equivalent to static `createReadOnlyProperty` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Property name\n     * @param {boolean=} protectedSetter Creates a custom protected setter\n     *   when `true`.\n     * @return {void}\n     * @protected\n     */\n\n\n    _createReadOnlyProperty(property, protectedSetter) {\n      this._addPropertyEffect(property, TYPES.READ_ONLY);\n\n      if (protectedSetter) {\n        this['_set' + upper(property)] =\n        /** @this {PropertyEffects} */\n        function (value) {\n          this._setProperty(property, value);\n        };\n      }\n    }\n    /**\n     * Equivalent to static `createPropertyObserver` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Property name\n     * @param {string|function(*,*)} method Function or name of observer method to call\n     * @param {boolean=} dynamicFn Whether the method name should be included as\n     *   a dependency to the effect.\n     * @return {void}\n     * @protected\n     */\n\n\n    _createPropertyObserver(property, method, dynamicFn) {\n      let info = {\n        property,\n        method,\n        dynamicFn: Boolean(dynamicFn)\n      };\n\n      this._addPropertyEffect(property, TYPES.OBSERVE, {\n        fn: runObserverEffect,\n        info,\n        trigger: {\n          name: property\n        }\n      });\n\n      if (dynamicFn) {\n        this._addPropertyEffect(\n        /** @type {string} */\n        method, TYPES.OBSERVE, {\n          fn: runObserverEffect,\n          info,\n          trigger: {\n            name: method\n          }\n        });\n      }\n    }\n    /**\n     * Equivalent to static `createMethodObserver` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} expression Method expression\n     * @param {boolean|Object=} dynamicFn Boolean or object map indicating\n     *   whether method names should be included as a dependency to the effect.\n     * @return {void}\n     * @protected\n     */\n\n\n    _createMethodObserver(expression, dynamicFn) {\n      let sig = parseMethod(expression);\n\n      if (!sig) {\n        throw new Error(\"Malformed observer expression '\" + expression + \"'\");\n      }\n\n      createMethodEffect(this, sig, TYPES.OBSERVE, runMethodEffect, null, dynamicFn);\n    }\n    /**\n     * Equivalent to static `createNotifyingProperty` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Property name\n     * @return {void}\n     * @protected\n     */\n\n\n    _createNotifyingProperty(property) {\n      this._addPropertyEffect(property, TYPES.NOTIFY, {\n        fn: runNotifyEffect,\n        info: {\n          eventName: (0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_3__.camelToDashCase)(property) + '-changed',\n          property: property\n        }\n      });\n    }\n    /**\n     * Equivalent to static `createReflectedProperty` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Property name\n     * @return {void}\n     * @protected\n     */\n\n\n    _createReflectedProperty(property) {\n      let attr = this.constructor.attributeNameForProperty(property);\n\n      if (attr[0] === '-') {\n        console.warn('Property ' + property + ' cannot be reflected to attribute ' + attr + ' because \"-\" is not a valid starting attribute name. Use a lowercase first letter for the property instead.');\n      } else {\n        this._addPropertyEffect(property, TYPES.REFLECT, {\n          fn: runReflectEffect,\n          info: {\n            attrName: attr\n          }\n        });\n      }\n    }\n    /**\n     * Equivalent to static `createComputedProperty` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * @param {string} property Name of computed property to set\n     * @param {string} expression Method expression\n     * @param {boolean|Object=} dynamicFn Boolean or object map indicating\n     *   whether method names should be included as a dependency to the effect.\n     * @return {void}\n     * @protected\n     */\n\n\n    _createComputedProperty(property, expression, dynamicFn) {\n      let sig = parseMethod(expression);\n\n      if (!sig) {\n        throw new Error(\"Malformed computed expression '\" + expression + \"'\");\n      }\n\n      createMethodEffect(this, sig, TYPES.COMPUTE, runComputedEffect, property, dynamicFn);\n    }\n    /**\n     * Gather the argument values for a method specified in the provided array\n     * of argument metadata.\n     *\n     * The `path` and `value` arguments are used to fill in wildcard descriptor\n     * when the method is being called as a result of a path notification.\n     *\n     * @param {!Array<!MethodArg>} args Array of argument metadata\n     * @param {string} path Property/path name that triggered the method effect\n     * @param {Object} props Bag of current property changes\n     * @return {Array<*>} Array of argument values\n     * @private\n     */\n\n\n    _marshalArgs(args, path, props) {\n      const data = this.__data;\n      let values = [];\n\n      for (let i = 0, l = args.length; i < l; i++) {\n        let arg = args[i];\n        let name = arg.name;\n        let v;\n\n        if (arg.literal) {\n          v = arg.value;\n        } else {\n          if (arg.structured) {\n            v = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(data, name); // when data is not stored e.g. `splices`\n\n            if (v === undefined) {\n              v = props[name];\n            }\n          } else {\n            v = data[name];\n          }\n        }\n\n        if (arg.wildcard) {\n          // Only send the actual path changed info if the change that\n          // caused the observer to run matched the wildcard\n          let baseChanged = name.indexOf(path + '.') === 0;\n          let matches = path.indexOf(name) === 0 && !baseChanged;\n          values[i] = {\n            path: matches ? path : name,\n            value: matches ? props[path] : v,\n            base: v\n          };\n        } else {\n          values[i] = v;\n        }\n      }\n\n      return values;\n    } // -- static class methods ------------\n\n    /**\n     * Ensures an accessor exists for the specified property, and adds\n     * to a list of \"property effects\" that will run when the accessor for\n     * the specified property is set.  Effects are grouped by \"type\", which\n     * roughly corresponds to a phase in effect processing.  The effect\n     * metadata should be in the following form:\n     *\n     *     {\n     *       fn: effectFunction, // Reference to function to call to perform effect\n     *       info: { ... }       // Effect metadata passed to function\n     *       trigger: {          // Optional triggering metadata; if not provided\n     *         name: string      // the property is treated as a wildcard\n     *         structured: boolean\n     *         wildcard: boolean\n     *       }\n     *     }\n     *\n     * Effects are called from `_propertiesChanged` in the following order by\n     * type:\n     *\n     * 1. COMPUTE\n     * 2. PROPAGATE\n     * 3. REFLECT\n     * 4. OBSERVE\n     * 5. NOTIFY\n     *\n     * Effect functions are called with the following signature:\n     *\n     *     effectFunction(inst, path, props, oldProps, info, hasPaths)\n     *\n     * @param {string} property Property that should trigger the effect\n     * @param {string} type Effect type, from this.PROPERTY_EFFECT_TYPES\n     * @param {Object=} effect Effect metadata object\n     * @return {void}\n     * @protected\n     */\n\n\n    static addPropertyEffect(property, type, effect) {\n      this.prototype._addPropertyEffect(property, type, effect);\n    }\n    /**\n     * Creates a single-property observer for the given property.\n     *\n     * @param {string} property Property name\n     * @param {string|function(*,*)} method Function or name of observer method to call\n     * @param {boolean=} dynamicFn Whether the method name should be included as\n     *   a dependency to the effect.\n     * @return {void}\n     * @protected\n     */\n\n\n    static createPropertyObserver(property, method, dynamicFn) {\n      this.prototype._createPropertyObserver(property, method, dynamicFn);\n    }\n    /**\n     * Creates a multi-property \"method observer\" based on the provided\n     * expression, which should be a string in the form of a normal JavaScript\n     * function signature: `'methodName(arg1, [..., argn])'`.  Each argument\n     * should correspond to a property or path in the context of this\n     * prototype (or instance), or may be a literal string or number.\n     *\n     * @param {string} expression Method expression\n     * @param {boolean|Object=} dynamicFn Boolean or object map indicating\n     * @return {void}\n     *   whether method names should be included as a dependency to the effect.\n     * @protected\n     */\n\n\n    static createMethodObserver(expression, dynamicFn) {\n      this.prototype._createMethodObserver(expression, dynamicFn);\n    }\n    /**\n     * Causes the setter for the given property to dispatch `<property>-changed`\n     * events to notify of changes to the property.\n     *\n     * @param {string} property Property name\n     * @return {void}\n     * @protected\n     */\n\n\n    static createNotifyingProperty(property) {\n      this.prototype._createNotifyingProperty(property);\n    }\n    /**\n     * Creates a read-only accessor for the given property.\n     *\n     * To set the property, use the protected `_setProperty` API.\n     * To create a custom protected setter (e.g. `_setMyProp()` for\n     * property `myProp`), pass `true` for `protectedSetter`.\n     *\n     * Note, if the property will have other property effects, this method\n     * should be called first, before adding other effects.\n     *\n     * @param {string} property Property name\n     * @param {boolean=} protectedSetter Creates a custom protected setter\n     *   when `true`.\n     * @return {void}\n     * @protected\n     */\n\n\n    static createReadOnlyProperty(property, protectedSetter) {\n      this.prototype._createReadOnlyProperty(property, protectedSetter);\n    }\n    /**\n     * Causes the setter for the given property to reflect the property value\n     * to a (dash-cased) attribute of the same name.\n     *\n     * @param {string} property Property name\n     * @return {void}\n     * @protected\n     */\n\n\n    static createReflectedProperty(property) {\n      this.prototype._createReflectedProperty(property);\n    }\n    /**\n     * Creates a computed property whose value is set to the result of the\n     * method described by the given `expression` each time one or more\n     * arguments to the method changes.  The expression should be a string\n     * in the form of a normal JavaScript function signature:\n     * `'methodName(arg1, [..., argn])'`\n     *\n     * @param {string} property Name of computed property to set\n     * @param {string} expression Method expression\n     * @param {boolean|Object=} dynamicFn Boolean or object map indicating whether\n     *   method names should be included as a dependency to the effect.\n     * @return {void}\n     * @protected\n     */\n\n\n    static createComputedProperty(property, expression, dynamicFn) {\n      this.prototype._createComputedProperty(property, expression, dynamicFn);\n    }\n    /**\n     * Parses the provided template to ensure binding effects are created\n     * for them, and then ensures property accessors are created for any\n     * dependent properties in the template.  Binding effects for bound\n     * templates are stored in a linked list on the instance so that\n     * templates can be efficiently stamped and unstamped.\n     *\n     * @param {!HTMLTemplateElement} template Template containing binding\n     *   bindings\n     * @return {!TemplateInfo} Template metadata object\n     * @protected\n     */\n\n\n    static bindTemplate(template) {\n      return this.prototype._bindTemplate(template);\n    } // -- binding ----------------------------------------------\n\n    /**\n     * Equivalent to static `bindTemplate` API but can be called on\n     * an instance to add effects at runtime.  See that method for\n     * full API docs.\n     *\n     * This method may be called on the prototype (for prototypical template\n     * binding, to avoid creating accessors every instance) once per prototype,\n     * and will be called with `runtimeBinding: true` by `_stampTemplate` to\n     * create and link an instance of the template metadata associated with a\n     * particular stamping.\n     *\n     * @param {!HTMLTemplateElement} template Template containing binding\n     *   bindings\n     * @param {boolean=} instanceBinding When false (default), performs\n     *   \"prototypical\" binding of the template and overwrites any previously\n     *   bound template for the class. When true (as passed from\n     *   `_stampTemplate`), the template info is instanced and linked into\n     *   the list of bound templates.\n     * @return {!TemplateInfo} Template metadata object; for `runtimeBinding`,\n     *   this is an instance of the prototypical template info\n     * @protected\n     */\n\n\n    _bindTemplate(template, instanceBinding) {\n      let templateInfo = this.constructor._parseTemplate(template);\n\n      let wasPreBound = this.__templateInfo == templateInfo; // Optimization: since this is called twice for proto-bound templates,\n      // don't attempt to recreate accessors if this template was pre-bound\n\n      if (!wasPreBound) {\n        for (let prop in templateInfo.propertyEffects) {\n          this._createPropertyAccessor(prop);\n        }\n      }\n\n      if (instanceBinding) {\n        // For instance-time binding, create instance of template metadata\n        // and link into list of templates if necessary\n        templateInfo =\n        /** @type {!TemplateInfo} */\n        Object.create(templateInfo);\n        templateInfo.wasPreBound = wasPreBound;\n\n        if (!wasPreBound && this.__templateInfo) {\n          let last = this.__templateInfoLast || this.__templateInfo;\n          this.__templateInfoLast = last.nextTemplateInfo = templateInfo;\n          templateInfo.previousTemplateInfo = last;\n          return templateInfo;\n        }\n      }\n\n      return this.__templateInfo = templateInfo;\n    }\n    /**\n     * Adds a property effect to the given template metadata, which is run\n     * at the \"propagate\" stage of `_propertiesChanged` when the template\n     * has been bound to the element via `_bindTemplate`.\n     *\n     * The `effect` object should match the format in `_addPropertyEffect`.\n     *\n     * @param {Object} templateInfo Template metadata to add effect to\n     * @param {string} prop Property that should trigger the effect\n     * @param {Object=} effect Effect metadata object\n     * @return {void}\n     * @protected\n     */\n\n\n    static _addTemplatePropertyEffect(templateInfo, prop, effect) {\n      let hostProps = templateInfo.hostProps = templateInfo.hostProps || {};\n      hostProps[prop] = true;\n      let effects = templateInfo.propertyEffects = templateInfo.propertyEffects || {};\n      let propEffects = effects[prop] = effects[prop] || [];\n      propEffects.push(effect);\n    }\n    /**\n     * Stamps the provided template and performs instance-time setup for\n     * Polymer template features, including data bindings, declarative event\n     * listeners, and the `this.$` map of `id`'s to nodes.  A document fragment\n     * is returned containing the stamped DOM, ready for insertion into the\n     * DOM.\n     *\n     * This method may be called more than once; however note that due to\n     * `shadycss` polyfill limitations, only styles from templates prepared\n     * using `ShadyCSS.prepareTemplate` will be correctly polyfilled (scoped\n     * to the shadow root and support CSS custom properties), and note that\n     * `ShadyCSS.prepareTemplate` may only be called once per element. As such,\n     * any styles required by in runtime-stamped templates must be included\n     * in the main element template.\n     *\n     * @param {!HTMLTemplateElement} template Template to stamp\n     * @return {!StampedTemplate} Cloned template content\n     * @override\n     * @protected\n     */\n\n\n    _stampTemplate(template) {\n      // Ensures that created dom is `_enqueueClient`'d to this element so\n      // that it can be flushed on next call to `_flushProperties`\n      hostStack.beginHosting(this);\n\n      let dom = super._stampTemplate(template);\n\n      hostStack.endHosting(this);\n\n      let templateInfo =\n      /** @type {!TemplateInfo} */\n      this._bindTemplate(template, true); // Add template-instance-specific data to instanced templateInfo\n\n\n      templateInfo.nodeList = dom.nodeList; // Capture child nodes to allow unstamping of non-prototypical templates\n\n      if (!templateInfo.wasPreBound) {\n        let nodes = templateInfo.childNodes = [];\n\n        for (let n = dom.firstChild; n; n = n.nextSibling) {\n          nodes.push(n);\n        }\n      }\n\n      dom.templateInfo = templateInfo; // Setup compound storage, 2-way listeners, and dataHost for bindings\n\n      setupBindings(this, templateInfo); // Flush properties into template nodes if already booted\n\n      if (this.__dataReady) {\n        runEffects(this, templateInfo.propertyEffects, this.__data, null, false, templateInfo.nodeList);\n      }\n\n      return dom;\n    }\n    /**\n     * Removes and unbinds the nodes previously contained in the provided\n     * DocumentFragment returned from `_stampTemplate`.\n     *\n     * @param {!StampedTemplate} dom DocumentFragment previously returned\n     *   from `_stampTemplate` associated with the nodes to be removed\n     * @return {void}\n     * @protected\n     */\n\n\n    _removeBoundDom(dom) {\n      // Unlink template info\n      let templateInfo = dom.templateInfo;\n\n      if (templateInfo.previousTemplateInfo) {\n        templateInfo.previousTemplateInfo.nextTemplateInfo = templateInfo.nextTemplateInfo;\n      }\n\n      if (templateInfo.nextTemplateInfo) {\n        templateInfo.nextTemplateInfo.previousTemplateInfo = templateInfo.previousTemplateInfo;\n      }\n\n      if (this.__templateInfoLast == templateInfo) {\n        this.__templateInfoLast = templateInfo.previousTemplateInfo;\n      }\n\n      templateInfo.previousTemplateInfo = templateInfo.nextTemplateInfo = null; // Remove stamped nodes\n\n      let nodes = templateInfo.childNodes;\n\n      for (let i = 0; i < nodes.length; i++) {\n        let node = nodes[i];\n        node.parentNode.removeChild(node);\n      }\n    }\n    /**\n     * Overrides default `TemplateStamp` implementation to add support for\n     * parsing bindings from `TextNode`'s' `textContent`.  A `bindings`\n     * array is added to `nodeInfo` and populated with binding metadata\n     * with information capturing the binding target, and a `parts` array\n     * with one or more metadata objects capturing the source(s) of the\n     * binding.\n     *\n     * @override\n     * @param {Node} node Node to parse\n     * @param {TemplateInfo} templateInfo Template metadata for current template\n     * @param {NodeInfo} nodeInfo Node metadata for current template node\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     * @protected\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n\n\n    static _parseTemplateNode(node, templateInfo, nodeInfo) {\n      let noted = super._parseTemplateNode(node, templateInfo, nodeInfo);\n\n      if (node.nodeType === Node.TEXT_NODE) {\n        let parts = this._parseBindings(node.textContent, templateInfo);\n\n        if (parts) {\n          // Initialize the textContent with any literal parts\n          // NOTE: default to a space here so the textNode remains; some browsers\n          // (IE) omit an empty textNode following cloneNode/importNode.\n          node.textContent = literalFromParts(parts) || ' ';\n          addBinding(this, templateInfo, nodeInfo, 'text', 'textContent', parts);\n          noted = true;\n        }\n      }\n\n      return noted;\n    }\n    /**\n     * Overrides default `TemplateStamp` implementation to add support for\n     * parsing bindings from attributes.  A `bindings`\n     * array is added to `nodeInfo` and populated with binding metadata\n     * with information capturing the binding target, and a `parts` array\n     * with one or more metadata objects capturing the source(s) of the\n     * binding.\n     *\n     * @override\n     * @param {Element} node Node to parse\n     * @param {TemplateInfo} templateInfo Template metadata for current template\n     * @param {NodeInfo} nodeInfo Node metadata for current template node\n     * @param {string} name Attribute name\n     * @param {string} value Attribute value\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     * @protected\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n\n\n    static _parseTemplateNodeAttribute(node, templateInfo, nodeInfo, name, value) {\n      let parts = this._parseBindings(value, templateInfo);\n\n      if (parts) {\n        // Attribute or property\n        let origName = name;\n        let kind = 'property'; // The only way we see a capital letter here is if the attr has\n        // a capital letter in it per spec. In this case, to make sure\n        // this binding works, we go ahead and make the binding to the attribute.\n\n        if (capitalAttributeRegex.test(name)) {\n          kind = 'attribute';\n        } else if (name[name.length - 1] == '$') {\n          name = name.slice(0, -1);\n          kind = 'attribute';\n        } // Initialize attribute bindings with any literal parts\n\n\n        let literal = literalFromParts(parts);\n\n        if (literal && kind == 'attribute') {\n          node.setAttribute(name, literal);\n        } // Clear attribute before removing, since IE won't allow removing\n        // `value` attribute if it previously had a value (can't\n        // unconditionally set '' before removing since attributes with `$`\n        // can't be set using setAttribute)\n\n\n        if (node.localName === 'input' && origName === 'value') {\n          node.setAttribute(origName, '');\n        } // Remove annotation\n\n\n        node.removeAttribute(origName); // Case hackery: attributes are lower-case, but bind targets\n        // (properties) are case sensitive. Gambit is to map dash-case to\n        // camel-case: `foo-bar` becomes `fooBar`.\n        // Attribute bindings are excepted.\n\n        if (kind === 'property') {\n          name = (0,_utils_case_map_js__WEBPACK_IMPORTED_MODULE_3__.dashToCamelCase)(name);\n        }\n\n        addBinding(this, templateInfo, nodeInfo, kind, name, parts, literal);\n        return true;\n      } else {\n        return super._parseTemplateNodeAttribute(node, templateInfo, nodeInfo, name, value);\n      }\n    }\n    /**\n     * Overrides default `TemplateStamp` implementation to add support for\n     * binding the properties that a nested template depends on to the template\n     * as `_host_<property>`.\n     *\n     * @override\n     * @param {Node} node Node to parse\n     * @param {TemplateInfo} templateInfo Template metadata for current template\n     * @param {NodeInfo} nodeInfo Node metadata for current template node\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     * @protected\n     * @suppress {missingProperties} Interfaces in closure do not inherit statics, but classes do\n     */\n\n\n    static _parseTemplateNestedTemplate(node, templateInfo, nodeInfo) {\n      let noted = super._parseTemplateNestedTemplate(node, templateInfo, nodeInfo); // Merge host props into outer template and add bindings\n\n\n      let hostProps = nodeInfo.templateInfo.hostProps;\n      let mode = '{';\n\n      for (let source in hostProps) {\n        let parts = [{\n          mode,\n          source,\n          dependencies: [source]\n        }];\n        addBinding(this, templateInfo, nodeInfo, 'property', '_host_' + source, parts);\n      }\n\n      return noted;\n    }\n    /**\n     * Called to parse text in a template (either attribute values or\n     * textContent) into binding metadata.\n     *\n     * Any overrides of this method should return an array of binding part\n     * metadata  representing one or more bindings found in the provided text\n     * and any \"literal\" text in between.  Any non-literal parts will be passed\n     * to `_evaluateBinding` when any dependencies change.  The only required\n     * fields of each \"part\" in the returned array are as follows:\n     *\n     * - `dependencies` - Array containing trigger metadata for each property\n     *   that should trigger the binding to update\n     * - `literal` - String containing text if the part represents a literal;\n     *   in this case no `dependencies` are needed\n     *\n     * Additional metadata for use by `_evaluateBinding` may be provided in\n     * each part object as needed.\n     *\n     * The default implementation handles the following types of bindings\n     * (one or more may be intermixed with literal strings):\n     * - Property binding: `[[prop]]`\n     * - Path binding: `[[object.prop]]`\n     * - Negated property or path bindings: `[[!prop]]` or `[[!object.prop]]`\n     * - Two-way property or path bindings (supports negation):\n     *   `{{prop}}`, `{{object.prop}}`, `{{!prop}}` or `{{!object.prop}}`\n     * - Inline computed method (supports negation):\n     *   `[[compute(a, 'literal', b)]]`, `[[!compute(a, 'literal', b)]]`\n     *\n     * The default implementation uses a regular expression for best\n     * performance. However, the regular expression uses a white-list of\n     * allowed characters in a data-binding, which causes problems for\n     * data-bindings that do use characters not in this white-list.\n     *\n     * Instead of updating the white-list with all allowed characters,\n     * there is a StrictBindingParser (see lib/mixins/strict-binding-parser)\n     * that uses a state machine instead. This state machine is able to handle\n     * all characters. However, it is slightly less performant, therefore we\n     * extracted it into a separate optional mixin.\n     *\n     * @param {string} text Text to parse from attribute or textContent\n     * @param {Object} templateInfo Current template metadata\n     * @return {Array<!BindingPart>} Array of binding part metadata\n     * @protected\n     */\n\n\n    static _parseBindings(text, templateInfo) {\n      let parts = [];\n      let lastIndex = 0;\n      let m; // Example: \"literal1{{prop}}literal2[[!compute(foo,bar)]]final\"\n      // Regex matches:\n      //        Iteration 1:  Iteration 2:\n      // m[1]: '{{'          '[['\n      // m[2]: ''            '!'\n      // m[3]: 'prop'        'compute(foo,bar)'\n\n      while ((m = bindingRegex.exec(text)) !== null) {\n        // Add literal part\n        if (m.index > lastIndex) {\n          parts.push({\n            literal: text.slice(lastIndex, m.index)\n          });\n        } // Add binding part\n\n\n        let mode = m[1][0];\n        let negate = Boolean(m[2]);\n        let source = m[3].trim();\n        let customEvent = false,\n            notifyEvent = '',\n            colon = -1;\n\n        if (mode == '{' && (colon = source.indexOf('::')) > 0) {\n          notifyEvent = source.substring(colon + 2);\n          source = source.substring(0, colon);\n          customEvent = true;\n        }\n\n        let signature = parseMethod(source);\n        let dependencies = [];\n\n        if (signature) {\n          // Inline computed function\n          let {\n            args,\n            methodName\n          } = signature;\n\n          for (let i = 0; i < args.length; i++) {\n            let arg = args[i];\n\n            if (!arg.literal) {\n              dependencies.push(arg);\n            }\n          }\n\n          let dynamicFns = templateInfo.dynamicFns;\n\n          if (dynamicFns && dynamicFns[methodName] || signature.static) {\n            dependencies.push(methodName);\n            signature.dynamicFn = true;\n          }\n        } else {\n          // Property or path\n          dependencies.push(source);\n        }\n\n        parts.push({\n          source,\n          mode,\n          negate,\n          customEvent,\n          signature,\n          dependencies,\n          event: notifyEvent\n        });\n        lastIndex = bindingRegex.lastIndex;\n      } // Add a final literal part\n\n\n      if (lastIndex && lastIndex < text.length) {\n        let literal = text.substring(lastIndex);\n\n        if (literal) {\n          parts.push({\n            literal: literal\n          });\n        }\n      }\n\n      if (parts.length) {\n        return parts;\n      } else {\n        return null;\n      }\n    }\n    /**\n     * Called to evaluate a previously parsed binding part based on a set of\n     * one or more changed dependencies.\n     *\n     * @param {this} inst Element that should be used as scope for\n     *   binding dependencies\n     * @param {BindingPart} part Binding part metadata\n     * @param {string} path Property/path that triggered this effect\n     * @param {Object} props Bag of current property changes\n     * @param {Object} oldProps Bag of previous values for changed properties\n     * @param {boolean} hasPaths True with `props` contains one or more paths\n     * @return {*} Value the binding part evaluated to\n     * @protected\n     */\n\n\n    static _evaluateBinding(inst, part, path, props, oldProps, hasPaths) {\n      let value;\n\n      if (part.signature) {\n        value = runMethodEffect(inst, path, props, oldProps, part.signature);\n      } else if (path != part.source) {\n        value = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(inst, part.source);\n      } else {\n        if (hasPaths && (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.isPath)(path)) {\n          value = (0,_utils_path_js__WEBPACK_IMPORTED_MODULE_2__.get)(inst, path);\n        } else {\n          value = inst.__data[path];\n        }\n      }\n\n      if (part.negate) {\n        value = !value;\n      }\n\n      return value;\n    }\n\n  } // make a typing for closure :P\n\n\n  PropertyEffectsType = PropertyEffects;\n  return PropertyEffects;\n});\n/**\n * Helper api for enqueuing client dom created by a host element.\n *\n * By default elements are flushed via `_flushProperties` when\n * `connectedCallback` is called. Elements attach their client dom to\n * themselves at `ready` time which results from this first flush.\n * This provides an ordering guarantee that the client dom an element\n * creates is flushed before the element itself (i.e. client `ready`\n * fires before host `ready`).\n *\n * However, if `_flushProperties` is called *before* an element is connected,\n * as for example `Templatize` does, this ordering guarantee cannot be\n * satisfied because no elements are connected. (Note: Bound elements that\n * receive data do become enqueued clients and are properly ordered but\n * unbound elements are not.)\n *\n * To maintain the desired \"client before host\" ordering guarantee for this\n * case we rely on the \"host stack. Client nodes registers themselves with\n * the creating host element when created. This ensures that all client dom\n * is readied in the proper order, maintaining the desired guarantee.\n *\n * @private\n */\n\nclass HostStack {\n  constructor() {\n    this.stack = [];\n  }\n  /**\n   * @param {*} inst Instance to add to hostStack\n   * @return {void}\n   */\n\n\n  registerHost(inst) {\n    if (this.stack.length) {\n      let host = this.stack[this.stack.length - 1];\n\n      host._enqueueClient(inst);\n    }\n  }\n  /**\n   * @param {*} inst Instance to begin hosting\n   * @return {void}\n   */\n\n\n  beginHosting(inst) {\n    this.stack.push(inst);\n  }\n  /**\n   * @param {*} inst Instance to end hosting\n   * @return {void}\n   */\n\n\n  endHosting(inst) {\n    let stackLen = this.stack.length;\n\n    if (stackLen && this.stack[stackLen - 1] == inst) {\n      this.stack.pop();\n    }\n  }\n\n}\n\nconst hostStack = new HostStack();//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/property-effects.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/mixins/template-stamp.js":
/*!********************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/mixins/template-stamp.js ***!
  \********************************************************************/
/*! namespace exports */
/*! export TemplateStamp [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"TemplateStamp\": () => /* binding */ TemplateStamp\n/* harmony export */ });\n/* harmony import */ var _utils_boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../utils/boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n // 1.x backwards-compatible auto-wrapper for template type extensions\n// This is a clear layering violation and gives favored-nation status to\n// dom-if and dom-repeat templates.  This is a conceit we're choosing to keep\n// a.) to ease 1.x backwards-compatibility due to loss of `is`, and\n// b.) to maintain if/repeat capability in parser-constrained elements\n//     (e.g. table, select) in lieu of native CE type extensions without\n//     massive new invention in this space (e.g. directive system)\n\nconst templateExtensions = {\n  'dom-if': true,\n  'dom-repeat': true\n};\n\nfunction wrapTemplateExtension(node) {\n  let is = node.getAttribute('is');\n\n  if (is && templateExtensions[is]) {\n    let t = node;\n    t.removeAttribute('is');\n    node = t.ownerDocument.createElement(is);\n    t.parentNode.replaceChild(node, t);\n    node.appendChild(t);\n\n    while (t.attributes.length) {\n      node.setAttribute(t.attributes[0].name, t.attributes[0].value);\n      t.removeAttribute(t.attributes[0].name);\n    }\n  }\n\n  return node;\n}\n\nfunction findTemplateNode(root, nodeInfo) {\n  // recursively ascend tree until we hit root\n  let parent = nodeInfo.parentInfo && findTemplateNode(root, nodeInfo.parentInfo); // unwind the stack, returning the indexed node at each level\n\n  if (parent) {\n    // note: marginally faster than indexing via childNodes\n    // (http://jsperf.com/childnodes-lookup)\n    for (let n = parent.firstChild, i = 0; n; n = n.nextSibling) {\n      if (nodeInfo.parentIndex === i++) {\n        return n;\n      }\n    }\n  } else {\n    return root;\n  }\n} // construct `$` map (from id annotations)\n\n\nfunction applyIdToMap(inst, map, node, nodeInfo) {\n  if (nodeInfo.id) {\n    map[nodeInfo.id] = node;\n  }\n} // install event listeners (from event annotations)\n\n\nfunction applyEventListener(inst, node, nodeInfo) {\n  if (nodeInfo.events && nodeInfo.events.length) {\n    for (let j = 0, e$ = nodeInfo.events, e; j < e$.length && (e = e$[j]); j++) {\n      inst._addMethodEventListenerToNode(node, e.name, e.value, inst);\n    }\n  }\n} // push configuration references at configure time\n\n\nfunction applyTemplateContent(inst, node, nodeInfo) {\n  if (nodeInfo.templateInfo) {\n    node._templateInfo = nodeInfo.templateInfo;\n  }\n}\n\nfunction createNodeEventHandler(context, eventName, methodName) {\n  // Instances can optionally have a _methodHost which allows redirecting where\n  // to find methods. Currently used by `templatize`.\n  context = context._methodHost || context;\n\n  let handler = function (e) {\n    if (context[methodName]) {\n      context[methodName](e, e.detail);\n    } else {\n      console.warn('listener method `' + methodName + '` not defined');\n    }\n  };\n\n  return handler;\n}\n/**\n * Element mixin that provides basic template parsing and stamping, including\n * the following template-related features for stamped templates:\n *\n * - Declarative event listeners (`on-eventname=\"listener\"`)\n * - Map of node id's to stamped node instances (`this.$.id`)\n * - Nested template content caching/removal and re-installation (performance\n *   optimization)\n *\n * @mixinFunction\n * @polymer\n * @summary Element class mixin that provides basic template parsing and stamping\n */\n\n\nconst TemplateStamp = (0,_utils_mixin_js__WEBPACK_IMPORTED_MODULE_1__.dedupingMixin)(\n/**\n * @template T\n * @param {function(new:T)} superClass Class to apply mixin to.\n * @return {function(new:T)} superClass with mixin applied.\n */\nsuperClass => {\n  /**\n   * @polymer\n   * @mixinClass\n   * @implements {Polymer_TemplateStamp}\n   */\n  class TemplateStamp extends superClass {\n    /**\n     * Scans a template to produce template metadata.\n     *\n     * Template-specific metadata are stored in the object returned, and node-\n     * specific metadata are stored in objects in its flattened `nodeInfoList`\n     * array.  Only nodes in the template that were parsed as nodes of\n     * interest contain an object in `nodeInfoList`.  Each `nodeInfo` object\n     * contains an `index` (`childNodes` index in parent) and optionally\n     * `parent`, which points to node info of its parent (including its index).\n     *\n     * The template metadata object returned from this method has the following\n     * structure (many fields optional):\n     *\n     * ```js\n     *   {\n     *     // Flattened list of node metadata (for nodes that generated metadata)\n     *     nodeInfoList: [\n     *       {\n     *         // `id` attribute for any nodes with id's for generating `$` map\n     *         id: {string},\n     *         // `on-event=\"handler\"` metadata\n     *         events: [\n     *           {\n     *             name: {string},   // event name\n     *             value: {string},  // handler method name\n     *           }, ...\n     *         ],\n     *         // Notes when the template contained a `<slot>` for shady DOM\n     *         // optimization purposes\n     *         hasInsertionPoint: {boolean},\n     *         // For nested `<template>`` nodes, nested template metadata\n     *         templateInfo: {object}, // nested template metadata\n     *         // Metadata to allow efficient retrieval of instanced node\n     *         // corresponding to this metadata\n     *         parentInfo: {number},   // reference to parent nodeInfo>\n     *         parentIndex: {number},  // index in parent's `childNodes` collection\n     *         infoIndex: {number},    // index of this `nodeInfo` in `templateInfo.nodeInfoList`\n     *       },\n     *       ...\n     *     ],\n     *     // When true, the template had the `strip-whitespace` attribute\n     *     // or was nested in a template with that setting\n     *     stripWhitespace: {boolean},\n     *     // For nested templates, nested template content is moved into\n     *     // a document fragment stored here; this is an optimization to\n     *     // avoid the cost of nested template cloning\n     *     content: {DocumentFragment}\n     *   }\n     * ```\n     *\n     * This method kicks off a recursive treewalk as follows:\n     *\n     * ```\n     *    _parseTemplate <---------------------+\n     *      _parseTemplateContent              |\n     *        _parseTemplateNode  <------------|--+\n     *          _parseTemplateNestedTemplate --+  |\n     *          _parseTemplateChildNodes ---------+\n     *          _parseTemplateNodeAttributes\n     *            _parseTemplateNodeAttribute\n     *\n     * ```\n     *\n     * These methods may be overridden to add custom metadata about templates\n     * to either `templateInfo` or `nodeInfo`.\n     *\n     * Note that this method may be destructive to the template, in that\n     * e.g. event annotations may be removed after being noted in the\n     * template metadata.\n     *\n     * @param {!HTMLTemplateElement} template Template to parse\n     * @param {TemplateInfo=} outerTemplateInfo Template metadata from the outer\n     *   template, for parsing nested templates\n     * @return {!TemplateInfo} Parsed template metadata\n     */\n    static _parseTemplate(template, outerTemplateInfo) {\n      // since a template may be re-used, memo-ize metadata\n      if (!template._templateInfo) {\n        let templateInfo = template._templateInfo = {};\n        templateInfo.nodeInfoList = [];\n        templateInfo.stripWhiteSpace = outerTemplateInfo && outerTemplateInfo.stripWhiteSpace || template.hasAttribute('strip-whitespace');\n\n        this._parseTemplateContent(template, templateInfo, {\n          parent: null\n        });\n      }\n\n      return template._templateInfo;\n    }\n\n    static _parseTemplateContent(template, templateInfo, nodeInfo) {\n      return this._parseTemplateNode(template.content, templateInfo, nodeInfo);\n    }\n    /**\n     * Parses template node and adds template and node metadata based on\n     * the current node, and its `childNodes` and `attributes`.\n     *\n     * This method may be overridden to add custom node or template specific\n     * metadata based on this node.\n     *\n     * @param {Node} node Node to parse\n     * @param {!TemplateInfo} templateInfo Template metadata for current template\n     * @param {!NodeInfo} nodeInfo Node metadata for current template.\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     */\n\n\n    static _parseTemplateNode(node, templateInfo, nodeInfo) {\n      let noted;\n      let element =\n      /** @type {Element} */\n      node;\n\n      if (element.localName == 'template' && !element.hasAttribute('preserve-content')) {\n        noted = this._parseTemplateNestedTemplate(element, templateInfo, nodeInfo) || noted;\n      } else if (element.localName === 'slot') {\n        // For ShadyDom optimization, indicating there is an insertion point\n        templateInfo.hasInsertionPoint = true;\n      }\n\n      if (element.firstChild) {\n        noted = this._parseTemplateChildNodes(element, templateInfo, nodeInfo) || noted;\n      }\n\n      if (element.hasAttributes && element.hasAttributes()) {\n        noted = this._parseTemplateNodeAttributes(element, templateInfo, nodeInfo) || noted;\n      }\n\n      return noted;\n    }\n    /**\n     * Parses template child nodes for the given root node.\n     *\n     * This method also wraps whitelisted legacy template extensions\n     * (`is=\"dom-if\"` and `is=\"dom-repeat\"`) with their equivalent element\n     * wrappers, collapses text nodes, and strips whitespace from the template\n     * if the `templateInfo.stripWhitespace` setting was provided.\n     *\n     * @param {Node} root Root node whose `childNodes` will be parsed\n     * @param {!TemplateInfo} templateInfo Template metadata for current template\n     * @param {!NodeInfo} nodeInfo Node metadata for current template.\n     * @return {void}\n     */\n\n\n    static _parseTemplateChildNodes(root, templateInfo, nodeInfo) {\n      if (root.localName === 'script' || root.localName === 'style') {\n        return;\n      }\n\n      for (let node = root.firstChild, parentIndex = 0, next; node; node = next) {\n        // Wrap templates\n        if (node.localName == 'template') {\n          node = wrapTemplateExtension(node);\n        } // collapse adjacent textNodes: fixes an IE issue that can cause\n        // text nodes to be inexplicably split =(\n        // note that root.normalize() should work but does not so we do this\n        // manually.\n\n\n        next = node.nextSibling;\n\n        if (node.nodeType === Node.TEXT_NODE) {\n          let\n          /** Node */\n          n = next;\n\n          while (n && n.nodeType === Node.TEXT_NODE) {\n            node.textContent += n.textContent;\n            next = n.nextSibling;\n            root.removeChild(n);\n            n = next;\n          } // optionally strip whitespace\n\n\n          if (templateInfo.stripWhiteSpace && !node.textContent.trim()) {\n            root.removeChild(node);\n            continue;\n          }\n        }\n\n        let childInfo = {\n          parentIndex,\n          parentInfo: nodeInfo\n        };\n\n        if (this._parseTemplateNode(node, templateInfo, childInfo)) {\n          childInfo.infoIndex = templateInfo.nodeInfoList.push(\n          /** @type {!NodeInfo} */\n          childInfo) - 1;\n        } // Increment if not removed\n\n\n        if (node.parentNode) {\n          parentIndex++;\n        }\n      }\n    }\n    /**\n     * Parses template content for the given nested `<template>`.\n     *\n     * Nested template info is stored as `templateInfo` in the current node's\n     * `nodeInfo`. `template.content` is removed and stored in `templateInfo`.\n     * It will then be the responsibility of the host to set it back to the\n     * template and for users stamping nested templates to use the\n     * `_contentForTemplate` method to retrieve the content for this template\n     * (an optimization to avoid the cost of cloning nested template content).\n     *\n     * @param {HTMLTemplateElement} node Node to parse (a <template>)\n     * @param {TemplateInfo} outerTemplateInfo Template metadata for current template\n     *   that includes the template `node`\n     * @param {!NodeInfo} nodeInfo Node metadata for current template.\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     */\n\n\n    static _parseTemplateNestedTemplate(node, outerTemplateInfo, nodeInfo) {\n      let templateInfo = this._parseTemplate(node, outerTemplateInfo);\n\n      let content = templateInfo.content = node.content.ownerDocument.createDocumentFragment();\n      content.appendChild(node.content);\n      nodeInfo.templateInfo = templateInfo;\n      return true;\n    }\n    /**\n     * Parses template node attributes and adds node metadata to `nodeInfo`\n     * for nodes of interest.\n     *\n     * @param {Element} node Node to parse\n     * @param {TemplateInfo} templateInfo Template metadata for current template\n     * @param {NodeInfo} nodeInfo Node metadata for current template.\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     */\n\n\n    static _parseTemplateNodeAttributes(node, templateInfo, nodeInfo) {\n      // Make copy of original attribute list, since the order may change\n      // as attributes are added and removed\n      let noted = false;\n      let attrs = Array.from(node.attributes);\n\n      for (let i = attrs.length - 1, a; a = attrs[i]; i--) {\n        noted = this._parseTemplateNodeAttribute(node, templateInfo, nodeInfo, a.name, a.value) || noted;\n      }\n\n      return noted;\n    }\n    /**\n     * Parses a single template node attribute and adds node metadata to\n     * `nodeInfo` for attributes of interest.\n     *\n     * This implementation adds metadata for `on-event=\"handler\"` attributes\n     * and `id` attributes.\n     *\n     * @param {Element} node Node to parse\n     * @param {!TemplateInfo} templateInfo Template metadata for current template\n     * @param {!NodeInfo} nodeInfo Node metadata for current template.\n     * @param {string} name Attribute name\n     * @param {string} value Attribute value\n     * @return {boolean} `true` if the visited node added node-specific\n     *   metadata to `nodeInfo`\n     */\n\n\n    static _parseTemplateNodeAttribute(node, templateInfo, nodeInfo, name, value) {\n      // events (on-*)\n      if (name.slice(0, 3) === 'on-') {\n        node.removeAttribute(name);\n        nodeInfo.events = nodeInfo.events || [];\n        nodeInfo.events.push({\n          name: name.slice(3),\n          value\n        });\n        return true;\n      } // static id\n      else if (name === 'id') {\n          nodeInfo.id = value;\n          return true;\n        }\n\n      return false;\n    }\n    /**\n     * Returns the `content` document fragment for a given template.\n     *\n     * For nested templates, Polymer performs an optimization to cache nested\n     * template content to avoid the cost of cloning deeply nested templates.\n     * This method retrieves the cached content for a given template.\n     *\n     * @param {HTMLTemplateElement} template Template to retrieve `content` for\n     * @return {DocumentFragment} Content fragment\n     */\n\n\n    static _contentForTemplate(template) {\n      let templateInfo =\n      /** @type {HTMLTemplateElementWithInfo} */\n      template._templateInfo;\n      return templateInfo && templateInfo.content || template.content;\n    }\n    /**\n     * Clones the provided template content and returns a document fragment\n     * containing the cloned dom.\n     *\n     * The template is parsed (once and memoized) using this library's\n     * template parsing features, and provides the following value-added\n     * features:\n     * * Adds declarative event listeners for `on-event=\"handler\"` attributes\n     * * Generates an \"id map\" for all nodes with id's under `$` on returned\n     *   document fragment\n     * * Passes template info including `content` back to templates as\n     *   `_templateInfo` (a performance optimization to avoid deep template\n     *   cloning)\n     *\n     * Note that the memoized template parsing process is destructive to the\n     * template: attributes for bindings and declarative event listeners are\n     * removed after being noted in notes, and any nested `<template>.content`\n     * is removed and stored in notes as well.\n     *\n     * @param {!HTMLTemplateElement} template Template to stamp\n     * @return {!StampedTemplate} Cloned template content\n     * @override\n     */\n\n\n    _stampTemplate(template) {\n      // Polyfill support: bootstrap the template if it has not already been\n      if (template && !template.content && window.HTMLTemplateElement && HTMLTemplateElement.decorate) {\n        HTMLTemplateElement.decorate(template);\n      }\n\n      let templateInfo = this.constructor._parseTemplate(template);\n\n      let nodeInfo = templateInfo.nodeInfoList;\n      let content = templateInfo.content || template.content;\n      let dom =\n      /** @type {DocumentFragment} */\n      document.importNode(content, true); // NOTE: ShadyDom optimization indicating there is an insertion point\n\n      dom.__noInsertionPoint = !templateInfo.hasInsertionPoint;\n      let nodes = dom.nodeList = new Array(nodeInfo.length);\n      dom.$ = {};\n\n      for (let i = 0, l = nodeInfo.length, info; i < l && (info = nodeInfo[i]); i++) {\n        let node = nodes[i] = findTemplateNode(dom, info);\n        applyIdToMap(this, dom.$, node, info);\n        applyTemplateContent(this, node, info);\n        applyEventListener(this, node, info);\n      }\n\n      dom =\n      /** @type {!StampedTemplate} */\n      dom; // eslint-disable-line no-self-assign\n\n      return dom;\n    }\n    /**\n     * Adds an event listener by method name for the event provided.\n     *\n     * This method generates a handler function that looks up the method\n     * name at handling time.\n     *\n     * @param {!EventTarget} node Node to add listener on\n     * @param {string} eventName Name of event\n     * @param {string} methodName Name of method\n     * @param {*=} context Context the method will be called on (defaults\n     *   to `node`)\n     * @return {Function} Generated handler function\n     * @override\n     */\n\n\n    _addMethodEventListenerToNode(node, eventName, methodName, context) {\n      context = context || node;\n      let handler = createNodeEventHandler(context, eventName, methodName);\n\n      this._addEventListenerToNode(node, eventName, handler);\n\n      return handler;\n    }\n    /**\n     * Override point for adding custom or simulated event handling.\n     *\n     * @param {!EventTarget} node Node to add event listener to\n     * @param {string} eventName Name of event\n     * @param {function(!Event):void} handler Listener function to add\n     * @return {void}\n     * @override\n     */\n\n\n    _addEventListenerToNode(node, eventName, handler) {\n      node.addEventListener(eventName, handler);\n    }\n    /**\n     * Override point for adding custom or simulated event handling.\n     *\n     * @param {!EventTarget} node Node to remove event listener from\n     * @param {string} eventName Name of event\n     * @param {function(!Event):void} handler Listener function to remove\n     * @return {void}\n     * @override\n     */\n\n\n    _removeEventListenerFromNode(node, eventName, handler) {\n      node.removeEventListener(eventName, handler);\n    }\n\n  }\n\n  return TemplateStamp;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/mixins/template-stamp.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/array-splice.js":
/*!*****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/array-splice.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export calculateSplices [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"calculateSplices\": () => /* binding */ calculateSplices\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\nfunction newSplice(index, removed, addedCount) {\n  return {\n    index: index,\n    removed: removed,\n    addedCount: addedCount\n  };\n}\n\nconst EDIT_LEAVE = 0;\nconst EDIT_UPDATE = 1;\nconst EDIT_ADD = 2;\nconst EDIT_DELETE = 3; // Note: This function is *based* on the computation of the Levenshtein\n// \"edit\" distance. The one change is that \"updates\" are treated as two\n// edits - not one. With Array splices, an update is really a delete\n// followed by an add. By retaining this, we optimize for \"keeping\" the\n// maximum array items in the original array. For example:\n//\n//   'xxxx123' -> '123yyyy'\n//\n// With 1-edit updates, the shortest path would be just to update all seven\n// characters. With 2-edit updates, we delete 4, leave 3, and add 4. This\n// leaves the substring '123' intact.\n\nfunction calcEditDistances(current, currentStart, currentEnd, old, oldStart, oldEnd) {\n  // \"Deletion\" columns\n  let rowCount = oldEnd - oldStart + 1;\n  let columnCount = currentEnd - currentStart + 1;\n  let distances = new Array(rowCount); // \"Addition\" rows. Initialize null column.\n\n  for (let i = 0; i < rowCount; i++) {\n    distances[i] = new Array(columnCount);\n    distances[i][0] = i;\n  } // Initialize null row\n\n\n  for (let j = 0; j < columnCount; j++) distances[0][j] = j;\n\n  for (let i = 1; i < rowCount; i++) {\n    for (let j = 1; j < columnCount; j++) {\n      if (equals(current[currentStart + j - 1], old[oldStart + i - 1])) distances[i][j] = distances[i - 1][j - 1];else {\n        let north = distances[i - 1][j] + 1;\n        let west = distances[i][j - 1] + 1;\n        distances[i][j] = north < west ? north : west;\n      }\n    }\n  }\n\n  return distances;\n} // This starts at the final weight, and walks \"backward\" by finding\n// the minimum previous weight recursively until the origin of the weight\n// matrix.\n\n\nfunction spliceOperationsFromEditDistances(distances) {\n  let i = distances.length - 1;\n  let j = distances[0].length - 1;\n  let current = distances[i][j];\n  let edits = [];\n\n  while (i > 0 || j > 0) {\n    if (i == 0) {\n      edits.push(EDIT_ADD);\n      j--;\n      continue;\n    }\n\n    if (j == 0) {\n      edits.push(EDIT_DELETE);\n      i--;\n      continue;\n    }\n\n    let northWest = distances[i - 1][j - 1];\n    let west = distances[i - 1][j];\n    let north = distances[i][j - 1];\n    let min;\n    if (west < north) min = west < northWest ? west : northWest;else min = north < northWest ? north : northWest;\n\n    if (min == northWest) {\n      if (northWest == current) {\n        edits.push(EDIT_LEAVE);\n      } else {\n        edits.push(EDIT_UPDATE);\n        current = northWest;\n      }\n\n      i--;\n      j--;\n    } else if (min == west) {\n      edits.push(EDIT_DELETE);\n      i--;\n      current = west;\n    } else {\n      edits.push(EDIT_ADD);\n      j--;\n      current = north;\n    }\n  }\n\n  edits.reverse();\n  return edits;\n}\n/**\n * Splice Projection functions:\n *\n * A splice map is a representation of how a previous array of items\n * was transformed into a new array of items. Conceptually it is a list of\n * tuples of\n *\n *   <index, removed, addedCount>\n *\n * which are kept in ascending index order of. The tuple represents that at\n * the |index|, |removed| sequence of items were removed, and counting forward\n * from |index|, |addedCount| items were added.\n */\n\n/**\n * Lacking individual splice mutation information, the minimal set of\n * splices can be synthesized given the previous state and final state of an\n * array. The basic approach is to calculate the edit distance matrix and\n * choose the shortest path through it.\n *\n * Complexity: O(l * p)\n *   l: The length of the current array\n *   p: The length of the old array\n *\n * @param {!Array} current The current \"changed\" array for which to\n * calculate splices.\n * @param {number} currentStart Starting index in the `current` array for\n * which splices are calculated.\n * @param {number} currentEnd Ending index in the `current` array for\n * which splices are calculated.\n * @param {!Array} old The original \"unchanged\" array to compare `current`\n * against to determine splices.\n * @param {number} oldStart Starting index in the `old` array for\n * which splices are calculated.\n * @param {number} oldEnd Ending index in the `old` array for\n * which splices are calculated.\n * @return {!Array} Returns an array of splice record objects. Each of these\n * contains: `index` the location where the splice occurred; `removed`\n * the array of removed items from this location; `addedCount` the number\n * of items added at this location.\n */\n\n\nfunction calcSplices(current, currentStart, currentEnd, old, oldStart, oldEnd) {\n  let prefixCount = 0;\n  let suffixCount = 0;\n  let splice;\n  let minLength = Math.min(currentEnd - currentStart, oldEnd - oldStart);\n  if (currentStart == 0 && oldStart == 0) prefixCount = sharedPrefix(current, old, minLength);\n  if (currentEnd == current.length && oldEnd == old.length) suffixCount = sharedSuffix(current, old, minLength - prefixCount);\n  currentStart += prefixCount;\n  oldStart += prefixCount;\n  currentEnd -= suffixCount;\n  oldEnd -= suffixCount;\n  if (currentEnd - currentStart == 0 && oldEnd - oldStart == 0) return [];\n\n  if (currentStart == currentEnd) {\n    splice = newSplice(currentStart, [], 0);\n\n    while (oldStart < oldEnd) splice.removed.push(old[oldStart++]);\n\n    return [splice];\n  } else if (oldStart == oldEnd) return [newSplice(currentStart, [], currentEnd - currentStart)];\n\n  let ops = spliceOperationsFromEditDistances(calcEditDistances(current, currentStart, currentEnd, old, oldStart, oldEnd));\n  splice = undefined;\n  let splices = [];\n  let index = currentStart;\n  let oldIndex = oldStart;\n\n  for (let i = 0; i < ops.length; i++) {\n    switch (ops[i]) {\n      case EDIT_LEAVE:\n        if (splice) {\n          splices.push(splice);\n          splice = undefined;\n        }\n\n        index++;\n        oldIndex++;\n        break;\n\n      case EDIT_UPDATE:\n        if (!splice) splice = newSplice(index, [], 0);\n        splice.addedCount++;\n        index++;\n        splice.removed.push(old[oldIndex]);\n        oldIndex++;\n        break;\n\n      case EDIT_ADD:\n        if (!splice) splice = newSplice(index, [], 0);\n        splice.addedCount++;\n        index++;\n        break;\n\n      case EDIT_DELETE:\n        if (!splice) splice = newSplice(index, [], 0);\n        splice.removed.push(old[oldIndex]);\n        oldIndex++;\n        break;\n    }\n  }\n\n  if (splice) {\n    splices.push(splice);\n  }\n\n  return splices;\n}\n\nfunction sharedPrefix(current, old, searchLength) {\n  for (let i = 0; i < searchLength; i++) if (!equals(current[i], old[i])) return i;\n\n  return searchLength;\n}\n\nfunction sharedSuffix(current, old, searchLength) {\n  let index1 = current.length;\n  let index2 = old.length;\n  let count = 0;\n\n  while (count < searchLength && equals(current[--index1], old[--index2])) count++;\n\n  return count;\n}\n/**\n * Returns an array of splice records indicating the minimum edits required\n * to transform the `previous` array into the `current` array.\n *\n * Splice records are ordered by index and contain the following fields:\n * - `index`: index where edit started\n * - `removed`: array of removed items from this index\n * - `addedCount`: number of items added at this index\n *\n * This function is based on the Levenshtein \"minimum edit distance\"\n * algorithm. Note that updates are treated as removal followed by addition.\n *\n * The worst-case time complexity of this algorithm is `O(l * p)`\n *   l: The length of the current array\n *   p: The length of the previous array\n *\n * However, the worst-case complexity is reduced by an `O(n)` optimization\n * to detect any shared prefix & suffix between the two arrays and only\n * perform the more expensive minimum edit distance calculation over the\n * non-shared portions of the arrays.\n *\n * @function\n * @param {!Array} current The \"changed\" array for which splices will be\n * calculated.\n * @param {!Array} previous The \"unchanged\" original array to compare\n * `current` against to determine the splices.\n * @return {!Array} Returns an array of splice record objects. Each of these\n * contains: `index` the location where the splice occurred; `removed`\n * the array of removed items from this location; `addedCount` the number\n * of items added at this location.\n */\n\n\nfunction calculateSplices(current, previous) {\n  return calcSplices(current, 0, current.length, previous, 0, previous.length);\n}\n\nfunction equals(currentValue, previousValue) {\n  return currentValue === previousValue;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/array-splice.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/async.js":
/*!**********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/async.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export animationFrame [provided] [no usage info] [missing usage info prevents renaming] */
/*! export idlePeriod [provided] [no usage info] [missing usage info prevents renaming] */
/*! export microTask [provided] [no usage info] [missing usage info prevents renaming] */
/*! export timeOut [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"timeOut\": () => /* binding */ timeOut,\n/* harmony export */   \"animationFrame\": () => /* binding */ animationFrame,\n/* harmony export */   \"idlePeriod\": () => /* binding */ idlePeriod,\n/* harmony export */   \"microTask\": () => /* binding */ microTask\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * @fileoverview\n *\n * This module provides a number of strategies for enqueuing asynchronous\n * tasks. Each sub-module provides a standard `run(fn)` interface that returns a\n * handle, and a `cancel(handle)` interface for canceling async tasks before\n * they run.\n *\n * @summary Module that provides a number of strategies for enqueuing\n * asynchronous tasks.\n */\n // Microtask implemented using Mutation Observer\n\nlet microtaskCurrHandle = 0;\nlet microtaskLastHandle = 0;\nlet microtaskCallbacks = [];\nlet microtaskNodeContent = 0;\nlet microtaskNode = document.createTextNode('');\nnew window.MutationObserver(microtaskFlush).observe(microtaskNode, {\n  characterData: true\n});\n\nfunction microtaskFlush() {\n  const len = microtaskCallbacks.length;\n\n  for (let i = 0; i < len; i++) {\n    let cb = microtaskCallbacks[i];\n\n    if (cb) {\n      try {\n        cb();\n      } catch (e) {\n        setTimeout(() => {\n          throw e;\n        });\n      }\n    }\n  }\n\n  microtaskCallbacks.splice(0, len);\n  microtaskLastHandle += len;\n}\n/**\n * Async interface wrapper around `setTimeout`.\n *\n * @namespace\n * @summary Async interface wrapper around `setTimeout`.\n */\n\n\nconst timeOut = {\n  /**\n   * Returns a sub-module with the async interface providing the provided\n   * delay.\n   *\n   * @memberof timeOut\n   * @param {number=} delay Time to wait before calling callbacks in ms\n   * @return {!AsyncInterface} An async timeout interface\n   */\n  after(delay) {\n    return {\n      run(fn) {\n        return window.setTimeout(fn, delay);\n      },\n\n      cancel(handle) {\n        window.clearTimeout(handle);\n      }\n\n    };\n  },\n\n  /**\n   * Enqueues a function called in the next task.\n   *\n   * @memberof timeOut\n   * @param {!Function} fn Callback to run\n   * @param {number=} delay Delay in milliseconds\n   * @return {number} Handle used for canceling task\n   */\n  run(fn, delay) {\n    return window.setTimeout(fn, delay);\n  },\n\n  /**\n   * Cancels a previously enqueued `timeOut` callback.\n   *\n   * @memberof timeOut\n   * @param {number} handle Handle returned from `run` of callback to cancel\n   * @return {void}\n   */\n  cancel(handle) {\n    window.clearTimeout(handle);\n  }\n\n};\n\n/**\n * Async interface wrapper around `requestAnimationFrame`.\n *\n * @namespace\n * @summary Async interface wrapper around `requestAnimationFrame`.\n */\n\nconst animationFrame = {\n  /**\n   * Enqueues a function called at `requestAnimationFrame` timing.\n   *\n   * @memberof animationFrame\n   * @param {function(number):void} fn Callback to run\n   * @return {number} Handle used for canceling task\n   */\n  run(fn) {\n    return window.requestAnimationFrame(fn);\n  },\n\n  /**\n   * Cancels a previously enqueued `animationFrame` callback.\n   *\n   * @memberof animationFrame\n   * @param {number} handle Handle returned from `run` of callback to cancel\n   * @return {void}\n   */\n  cancel(handle) {\n    window.cancelAnimationFrame(handle);\n  }\n\n};\n\n/**\n * Async interface wrapper around `requestIdleCallback`.  Falls back to\n * `setTimeout` on browsers that do not support `requestIdleCallback`.\n *\n * @namespace\n * @summary Async interface wrapper around `requestIdleCallback`.\n */\n\nconst idlePeriod = {\n  /**\n   * Enqueues a function called at `requestIdleCallback` timing.\n   *\n   * @memberof idlePeriod\n   * @param {function(!IdleDeadline):void} fn Callback to run\n   * @return {number} Handle used for canceling task\n   */\n  run(fn) {\n    return window.requestIdleCallback ? window.requestIdleCallback(fn) : window.setTimeout(fn, 16);\n  },\n\n  /**\n   * Cancels a previously enqueued `idlePeriod` callback.\n   *\n   * @memberof idlePeriod\n   * @param {number} handle Handle returned from `run` of callback to cancel\n   * @return {void}\n   */\n  cancel(handle) {\n    window.cancelIdleCallback ? window.cancelIdleCallback(handle) : window.clearTimeout(handle);\n  }\n\n};\n\n/**\n * Async interface for enqueuing callbacks that run at microtask timing.\n *\n * Note that microtask timing is achieved via a single `MutationObserver`,\n * and thus callbacks enqueued with this API will all run in a single\n * batch, and not interleaved with other microtasks such as promises.\n * Promises are avoided as an implementation choice for the time being\n * due to Safari bugs that cause Promises to lack microtask guarantees.\n *\n * @namespace\n * @summary Async interface for enqueuing callbacks that run at microtask\n *   timing.\n */\n\nconst microTask = {\n  /**\n   * Enqueues a function called at microtask timing.\n   *\n   * @memberof microTask\n   * @param {!Function=} callback Callback to run\n   * @return {number} Handle used for canceling task\n   */\n  run(callback) {\n    microtaskNode.textContent = microtaskNodeContent++;\n    microtaskCallbacks.push(callback);\n    return microtaskCurrHandle++;\n  },\n\n  /**\n   * Cancels a previously enqueued `microTask` callback.\n   *\n   * @memberof microTask\n   * @param {number} handle Handle returned from `run` of callback to cancel\n   * @return {void}\n   */\n  cancel(handle) {\n    const idx = handle - microtaskLastHandle;\n\n    if (idx >= 0) {\n      if (!microtaskCallbacks[idx]) {\n        throw new Error('invalid async handle: ' + handle);\n      }\n\n      microtaskCallbacks[idx] = null;\n    }\n  }\n\n};\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/async.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/boot.js":
/*!*********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/boot.js ***!
  \*********************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/* eslint-disable no-unused-vars */\n\n/**\n * When using Closure Compiler, JSCompiler_renameProperty(property, object) is replaced by the munged name for object[property]\n * We cannot alias this function, so we have to use a small shim that has the same behavior when not compiling.\n *\n * @param {string} prop Property name\n * @param {?Object} obj Reference object\n * @return {string} Potentially renamed property name\n */\nwindow.JSCompiler_renameProperty = function (prop, obj) {\n  return prop;\n};\n/* eslint-enable */\n\n\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQHBvbHltZXIvcG9seW1lci9saWIvdXRpbHMvYm9vdC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vbm9kZV9tb2R1bGVzL0Bwb2x5bWVyL3BvbHltZXIvbGliL3V0aWxzL2Jvb3QuanM/ZmQ0OCJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgKGMpIDIwMTcgVGhlIFBvbHltZXIgUHJvamVjdCBBdXRob3JzLiBBbGwgcmlnaHRzIHJlc2VydmVkLlxuVGhpcyBjb2RlIG1heSBvbmx5IGJlIHVzZWQgdW5kZXIgdGhlIEJTRCBzdHlsZSBsaWNlbnNlIGZvdW5kIGF0IGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9MSUNFTlNFLnR4dFxuVGhlIGNvbXBsZXRlIHNldCBvZiBhdXRob3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQVVUSE9SUy50eHRcblRoZSBjb21wbGV0ZSBzZXQgb2YgY29udHJpYnV0b3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQ09OVFJJQlVUT1JTLnR4dFxuQ29kZSBkaXN0cmlidXRlZCBieSBHb29nbGUgYXMgcGFydCBvZiB0aGUgcG9seW1lciBwcm9qZWN0IGlzIGFsc29cbnN1YmplY3QgdG8gYW4gYWRkaXRpb25hbCBJUCByaWdodHMgZ3JhbnQgZm91bmQgYXQgaHR0cDovL3BvbHltZXIuZ2l0aHViLmlvL1BBVEVOVFMudHh0XG4qL1xuXG4vKiBlc2xpbnQtZGlzYWJsZSBuby11bnVzZWQtdmFycyAqL1xuLyoqXG4gKiBXaGVuIHVzaW5nIENsb3N1cmUgQ29tcGlsZXIsIEpTQ29tcGlsZXJfcmVuYW1lUHJvcGVydHkocHJvcGVydHksIG9iamVjdCkgaXMgcmVwbGFjZWQgYnkgdGhlIG11bmdlZCBuYW1lIGZvciBvYmplY3RbcHJvcGVydHldXG4gKiBXZSBjYW5ub3QgYWxpYXMgdGhpcyBmdW5jdGlvbiwgc28gd2UgaGF2ZSB0byB1c2UgYSBzbWFsbCBzaGltIHRoYXQgaGFzIHRoZSBzYW1lIGJlaGF2aW9yIHdoZW4gbm90IGNvbXBpbGluZy5cbiAqXG4gKiBAcGFyYW0ge3N0cmluZ30gcHJvcCBQcm9wZXJ0eSBuYW1lXG4gKiBAcGFyYW0gez9PYmplY3R9IG9iaiBSZWZlcmVuY2Ugb2JqZWN0XG4gKiBAcmV0dXJuIHtzdHJpbmd9IFBvdGVudGlhbGx5IHJlbmFtZWQgcHJvcGVydHkgbmFtZVxuICovXG53aW5kb3cuSlNDb21waWxlcl9yZW5hbWVQcm9wZXJ0eSA9IGZ1bmN0aW9uKHByb3AsIG9iaikge1xuICByZXR1cm4gcHJvcDtcbn07XG4vKiBlc2xpbnQtZW5hYmxlICovXG5cbmV4cG9ydCB7fTtcbiJdLCJtYXBwaW5ncyI6IjtBQUFBOzs7Ozs7Ozs7O0FBVUE7QUFDQTtBQUFBOzs7Ozs7OztBQVFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTsiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/boot.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/case-map.js":
/*!*************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/case-map.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export camelToDashCase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export dashToCamelCase [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"dashToCamelCase\": () => /* binding */ dashToCamelCase,\n/* harmony export */   \"camelToDashCase\": () => /* binding */ camelToDashCase\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\nconst caseMap = {};\nconst DASH_TO_CAMEL = /-[a-z]/g;\nconst CAMEL_TO_DASH = /([A-Z])/g;\n/**\n * @fileoverview Module with utilities for converting between \"dash-case\" and\n * \"camelCase\" identifiers.\n */\n\n/**\n * Converts \"dash-case\" identifier (e.g. `foo-bar-baz`) to \"camelCase\"\n * (e.g. `fooBarBaz`).\n *\n * @param {string} dash Dash-case identifier\n * @return {string} Camel-case representation of the identifier\n */\n\nfunction dashToCamelCase(dash) {\n  return caseMap[dash] || (caseMap[dash] = dash.indexOf('-') < 0 ? dash : dash.replace(DASH_TO_CAMEL, m => m[1].toUpperCase()));\n}\n/**\n * Converts \"camelCase\" identifier (e.g. `fooBarBaz`) to \"dash-case\"\n * (e.g. `foo-bar-baz`).\n *\n * @param {string} camel Camel-case identifier\n * @return {string} Dash-case representation of the identifier\n */\n\nfunction camelToDashCase(camel) {\n  return caseMap[camel] || (caseMap[camel] = camel.replace(CAMEL_TO_DASH, '-$1').toLowerCase());\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/case-map.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/debounce.js":
/*!*************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/debounce.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export Debouncer [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Debouncer\": () => /* binding */ Debouncer\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _mixin_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mixin.js */ \"./node_modules/@polymer/polymer/lib/utils/mixin.js\");\n/* harmony import */ var _async_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * @summary Collapse multiple callbacks into one invocation after a timer.\n */\n\nclass Debouncer {\n  constructor() {\n    this._asyncModule = null;\n    this._callback = null;\n    this._timer = null;\n  }\n  /**\n   * Sets the scheduler; that is, a module with the Async interface,\n   * a callback and optional arguments to be passed to the run function\n   * from the async module.\n   *\n   * @param {!AsyncInterface} asyncModule Object with Async interface.\n   * @param {function()} callback Callback to run.\n   * @return {void}\n   */\n\n\n  setConfig(asyncModule, callback) {\n    this._asyncModule = asyncModule;\n    this._callback = callback;\n    this._timer = this._asyncModule.run(() => {\n      this._timer = null;\n\n      this._callback();\n    });\n  }\n  /**\n   * Cancels an active debouncer and returns a reference to itself.\n   *\n   * @return {void}\n   */\n\n\n  cancel() {\n    if (this.isActive()) {\n      this._asyncModule.cancel(\n      /** @type {number} */\n      this._timer);\n\n      this._timer = null;\n    }\n  }\n  /**\n   * Flushes an active debouncer and returns a reference to itself.\n   *\n   * @return {void}\n   */\n\n\n  flush() {\n    if (this.isActive()) {\n      this.cancel();\n\n      this._callback();\n    }\n  }\n  /**\n   * Returns true if the debouncer is active.\n   *\n   * @return {boolean} True if active.\n   */\n\n\n  isActive() {\n    return this._timer != null;\n  }\n  /**\n   * Creates a debouncer if no debouncer is passed as a parameter\n   * or it cancels an active debouncer otherwise. The following\n   * example shows how a debouncer can be called multiple times within a\n   * microtask and \"debounced\" such that the provided callback function is\n   * called once. Add this method to a custom element:\n   *\n   * ```js\n   * import {microTask} from '@polymer/polymer/lib/utils/async.js';\n   * import {Debouncer} from '@polymer/polymer/lib/utils/debounce.js';\n   * // ...\n   *\n   * _debounceWork() {\n   *   this._debounceJob = Debouncer.debounce(this._debounceJob,\n   *       microTask, () => this._doWork());\n   * }\n   * ```\n   *\n   * If the `_debounceWork` method is called multiple times within the same\n   * microtask, the `_doWork` function will be called only once at the next\n   * microtask checkpoint.\n   *\n   * Note: In testing it is often convenient to avoid asynchrony. To accomplish\n   * this with a debouncer, you can use `enqueueDebouncer` and\n   * `flush`. For example, extend the above example by adding\n   * `enqueueDebouncer(this._debounceJob)` at the end of the\n   * `_debounceWork` method. Then in a test, call `flush` to ensure\n   * the debouncer has completed.\n   *\n   * @param {Debouncer?} debouncer Debouncer object.\n   * @param {!AsyncInterface} asyncModule Object with Async interface\n   * @param {function()} callback Callback to run.\n   * @return {!Debouncer} Returns a debouncer object.\n   */\n\n\n  static debounce(debouncer, asyncModule, callback) {\n    if (debouncer instanceof Debouncer) {\n      debouncer.cancel();\n    } else {\n      debouncer = new Debouncer();\n    }\n\n    debouncer.setConfig(asyncModule, callback);\n    return debouncer;\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/debounce.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/flattened-nodes-observer.js":
/*!*****************************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/flattened-nodes-observer.js ***!
  \*****************************************************************************/
/*! namespace exports */
/*! export FlattenedNodesObserver [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"FlattenedNodesObserver\": () => /* binding */ FlattenedNodesObserver\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _array_splice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./array-splice.js */ \"./node_modules/@polymer/polymer/lib/utils/array-splice.js\");\n/* harmony import */ var _async_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * Returns true if `node` is a slot element\n * @param {!Node} node Node to test.\n * @return {boolean} Returns true if the given `node` is a slot\n * @private\n */\n\nfunction isSlot(node) {\n  return node.localName === 'slot';\n}\n/**\n * Class that listens for changes (additions or removals) to\n * \"flattened nodes\" on a given `node`. The list of flattened nodes consists\n * of a node's children and, for any children that are `<slot>` elements,\n * the expanded flattened list of `assignedNodes`.\n * For example, if the observed node has children `<a></a><slot></slot><b></b>`\n * and the `<slot>` has one `<div>` assigned to it, then the flattened\n * nodes list is `<a></a><div></div><b></b>`. If the `<slot>` has other\n * `<slot>` elements assigned to it, these are flattened as well.\n *\n * The provided `callback` is called whenever any change to this list\n * of flattened nodes occurs, where an addition or removal of a node is\n * considered a change. The `callback` is called with one argument, an object\n * containing an array of any `addedNodes` and `removedNodes`.\n *\n * Note: the callback is called asynchronous to any changes\n * at a microtask checkpoint. This is because observation is performed using\n * `MutationObserver` and the `<slot>` element's `slotchange` event which\n * are asynchronous.\n *\n * An example:\n * ```js\n * class TestSelfObserve extends PolymerElement {\n *   static get is() { return 'test-self-observe';}\n *   connectedCallback() {\n *     super.connectedCallback();\n *     this._observer = new FlattenedNodesObserver(this, (info) => {\n *       this.info = info;\n *     });\n *   }\n *   disconnectedCallback() {\n *     super.disconnectedCallback();\n *     this._observer.disconnect();\n *   }\n * }\n * customElements.define(TestSelfObserve.is, TestSelfObserve);\n * ```\n *\n * @summary Class that listens for changes (additions or removals) to\n * \"flattened nodes\" on a given `node`.\n */\n\n\nclass FlattenedNodesObserver {\n  /**\n   * Returns the list of flattened nodes for the given `node`.\n   * This list consists of a node's children and, for any children\n   * that are `<slot>` elements, the expanded flattened list of `assignedNodes`.\n   * For example, if the observed node has children `<a></a><slot></slot><b></b>`\n   * and the `<slot>` has one `<div>` assigned to it, then the flattened\n   * nodes list is `<a></a><div></div><b></b>`. If the `<slot>` has other\n   * `<slot>` elements assigned to it, these are flattened as well.\n   *\n   * @param {!HTMLElement|!HTMLSlotElement} node The node for which to\n   *      return the list of flattened nodes.\n   * @return {!Array<!Node>} The list of flattened nodes for the given `node`.\n   * @nocollapse See https://github.com/google/closure-compiler/issues/2763\n   */\n  static getFlattenedNodes(node) {\n    if (isSlot(node)) {\n      node =\n      /** @type {!HTMLSlotElement} */\n      node; // eslint-disable-line no-self-assign\n\n      return node.assignedNodes({\n        flatten: true\n      });\n    } else {\n      return Array.from(node.childNodes).map(node => {\n        if (isSlot(node)) {\n          node =\n          /** @type {!HTMLSlotElement} */\n          node; // eslint-disable-line no-self-assign\n\n          return node.assignedNodes({\n            flatten: true\n          });\n        } else {\n          return [node];\n        }\n      }).reduce((a, b) => a.concat(b), []);\n    }\n  }\n  /**\n   * @param {!HTMLElement} target Node on which to listen for changes.\n   * @param {?function(this: Element, { target: !HTMLElement, addedNodes: !Array<!Element>, removedNodes: !Array<!Element> }):void} callback Function called when there are additions\n   * or removals from the target's list of flattened nodes.\n   */\n\n\n  constructor(target, callback) {\n    /**\n     * @type {MutationObserver}\n     * @private\n     */\n    this._shadyChildrenObserver = null;\n    /**\n     * @type {MutationObserver}\n     * @private\n     */\n\n    this._nativeChildrenObserver = null;\n    this._connected = false;\n    /**\n     * @type {!HTMLElement}\n     * @private\n     */\n\n    this._target = target;\n    this.callback = callback;\n    this._effectiveNodes = [];\n    this._observer = null;\n    this._scheduled = false;\n    /**\n     * @type {function()}\n     * @private\n     */\n\n    this._boundSchedule = () => {\n      this._schedule();\n    };\n\n    this.connect();\n\n    this._schedule();\n  }\n  /**\n   * Activates an observer. This method is automatically called when\n   * a `FlattenedNodesObserver` is created. It should only be called to\n   * re-activate an observer that has been deactivated via the `disconnect` method.\n   *\n   * @return {void}\n   */\n\n\n  connect() {\n    if (isSlot(this._target)) {\n      this._listenSlots([this._target]);\n    } else if (this._target.children) {\n      this._listenSlots(\n      /** @type {!NodeList<!Node>} */\n      this._target.children);\n\n      if (window.ShadyDOM) {\n        this._shadyChildrenObserver = ShadyDOM.observeChildren(this._target, mutations => {\n          this._processMutations(mutations);\n        });\n      } else {\n        this._nativeChildrenObserver = new MutationObserver(mutations => {\n          this._processMutations(mutations);\n        });\n\n        this._nativeChildrenObserver.observe(this._target, {\n          childList: true\n        });\n      }\n    }\n\n    this._connected = true;\n  }\n  /**\n   * Deactivates the flattened nodes observer. After calling this method\n   * the observer callback will not be called when changes to flattened nodes\n   * occur. The `connect` method may be subsequently called to reactivate\n   * the observer.\n   *\n   * @return {void}\n   */\n\n\n  disconnect() {\n    if (isSlot(this._target)) {\n      this._unlistenSlots([this._target]);\n    } else if (this._target.children) {\n      this._unlistenSlots(\n      /** @type {!NodeList<!Node>} */\n      this._target.children);\n\n      if (window.ShadyDOM && this._shadyChildrenObserver) {\n        ShadyDOM.unobserveChildren(this._shadyChildrenObserver);\n        this._shadyChildrenObserver = null;\n      } else if (this._nativeChildrenObserver) {\n        this._nativeChildrenObserver.disconnect();\n\n        this._nativeChildrenObserver = null;\n      }\n    }\n\n    this._connected = false;\n  }\n  /**\n   * @return {void}\n   * @private\n   */\n\n\n  _schedule() {\n    if (!this._scheduled) {\n      this._scheduled = true;\n      _async_js__WEBPACK_IMPORTED_MODULE_2__.microTask.run(() => this.flush());\n    }\n  }\n  /**\n   * @param {Array<MutationRecord>} mutations Mutations signaled by the mutation observer\n   * @return {void}\n   * @private\n   */\n\n\n  _processMutations(mutations) {\n    this._processSlotMutations(mutations);\n\n    this.flush();\n  }\n  /**\n   * @param {Array<MutationRecord>} mutations Mutations signaled by the mutation observer\n   * @return {void}\n   * @private\n   */\n\n\n  _processSlotMutations(mutations) {\n    if (mutations) {\n      for (let i = 0; i < mutations.length; i++) {\n        let mutation = mutations[i];\n\n        if (mutation.addedNodes) {\n          this._listenSlots(mutation.addedNodes);\n        }\n\n        if (mutation.removedNodes) {\n          this._unlistenSlots(mutation.removedNodes);\n        }\n      }\n    }\n  }\n  /**\n   * Flushes the observer causing any pending changes to be immediately\n   * delivered the observer callback. By default these changes are delivered\n   * asynchronously at the next microtask checkpoint.\n   *\n   * @return {boolean} Returns true if any pending changes caused the observer\n   * callback to run.\n   */\n\n\n  flush() {\n    if (!this._connected) {\n      return false;\n    }\n\n    if (window.ShadyDOM) {\n      ShadyDOM.flush();\n    }\n\n    if (this._nativeChildrenObserver) {\n      this._processSlotMutations(this._nativeChildrenObserver.takeRecords());\n    } else if (this._shadyChildrenObserver) {\n      this._processSlotMutations(this._shadyChildrenObserver.takeRecords());\n    }\n\n    this._scheduled = false;\n    let info = {\n      target: this._target,\n      addedNodes: [],\n      removedNodes: []\n    };\n    let newNodes = this.constructor.getFlattenedNodes(this._target);\n    let splices = (0,_array_splice_js__WEBPACK_IMPORTED_MODULE_1__.calculateSplices)(newNodes, this._effectiveNodes); // process removals\n\n    for (let i = 0, s; i < splices.length && (s = splices[i]); i++) {\n      for (let j = 0, n; j < s.removed.length && (n = s.removed[j]); j++) {\n        info.removedNodes.push(n);\n      }\n    } // process adds\n\n\n    for (let i = 0, s; i < splices.length && (s = splices[i]); i++) {\n      for (let j = s.index; j < s.index + s.addedCount; j++) {\n        info.addedNodes.push(newNodes[j]);\n      }\n    } // update cache\n\n\n    this._effectiveNodes = newNodes;\n    let didFlush = false;\n\n    if (info.addedNodes.length || info.removedNodes.length) {\n      didFlush = true;\n      this.callback.call(this._target, info);\n    }\n\n    return didFlush;\n  }\n  /**\n   * @param {!Array<!Node>|!NodeList<!Node>} nodeList Nodes that could change\n   * @return {void}\n   * @private\n   */\n\n\n  _listenSlots(nodeList) {\n    for (let i = 0; i < nodeList.length; i++) {\n      let n = nodeList[i];\n\n      if (isSlot(n)) {\n        n.addEventListener('slotchange', this._boundSchedule);\n      }\n    }\n  }\n  /**\n   * @param {!Array<!Node>|!NodeList<!Node>} nodeList Nodes that could change\n   * @return {void}\n   * @private\n   */\n\n\n  _unlistenSlots(nodeList) {\n    for (let i = 0; i < nodeList.length; i++) {\n      let n = nodeList[i];\n\n      if (isSlot(n)) {\n        n.removeEventListener('slotchange', this._boundSchedule);\n      }\n    }\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/flattened-nodes-observer.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/flush.js":
/*!**********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/flush.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export enqueueDebouncer [provided] [no usage info] [missing usage info prevents renaming] */
/*! export flush [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"enqueueDebouncer\": () => /* binding */ enqueueDebouncer,\n/* harmony export */   \"flush\": () => /* binding */ flush\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _utils_debounce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../utils/debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/* eslint-disable no-unused-vars */\n\n // used in type annotations\n\n/* eslint-enable no-unused-vars */\n\nlet debouncerQueue = [];\n/**\n * Adds a `Debouncer` to a list of globally flushable tasks.\n *\n * @param {!Debouncer} debouncer Debouncer to enqueue\n * @return {void}\n */\n\nconst enqueueDebouncer = function (debouncer) {\n  debouncerQueue.push(debouncer);\n};\n\nfunction flushDebouncers() {\n  const didFlush = Boolean(debouncerQueue.length);\n\n  while (debouncerQueue.length) {\n    try {\n      debouncerQueue.shift().flush();\n    } catch (e) {\n      setTimeout(() => {\n        throw e;\n      });\n    }\n  }\n\n  return didFlush;\n}\n/**\n * Forces several classes of asynchronously queued tasks to flush:\n * - Debouncers added via `enqueueDebouncer`\n * - ShadyDOM distribution\n *\n * @return {void}\n */\n\n\nconst flush = function () {\n  let shadyDOM, debouncers;\n\n  do {\n    shadyDOM = window.ShadyDOM && ShadyDOM.flush();\n\n    if (window.ShadyCSS && window.ShadyCSS.ScopingShim) {\n      window.ShadyCSS.ScopingShim.flush();\n    }\n\n    debouncers = flushDebouncers();\n  } while (shadyDOM || debouncers);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/flush.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/gestures.js":
/*!*************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/gestures.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export add [provided] [no usage info] [missing usage info prevents renaming] */
/*! export addListener [provided] [no usage info] [missing usage info prevents renaming] */
/*! export deepTargetFind [provided] [no usage info] [missing usage info prevents renaming] */
/*! export findOriginalTarget [provided] [no usage info] [missing usage info prevents renaming] */
/*! export gestures [provided] [no usage info] [missing usage info prevents renaming] */
/*! export prevent [provided] [no usage info] [missing usage info prevents renaming] */
/*! export recognizers [provided] [no usage info] [missing usage info prevents renaming] */
/*! export register [provided] [no usage info] [missing usage info prevents renaming] */
/*! export remove [provided] [no usage info] [missing usage info prevents renaming] */
/*! export removeListener [provided] [no usage info] [missing usage info prevents renaming] */
/*! export resetMouseCanceller [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setTouchAction [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"gestures\": () => /* binding */ gestures,\n/* harmony export */   \"recognizers\": () => /* binding */ recognizers,\n/* harmony export */   \"deepTargetFind\": () => /* binding */ deepTargetFind,\n/* harmony export */   \"addListener\": () => /* binding */ addListener,\n/* harmony export */   \"removeListener\": () => /* binding */ removeListener,\n/* harmony export */   \"register\": () => /* binding */ register,\n/* harmony export */   \"setTouchAction\": () => /* binding */ setTouchAction,\n/* harmony export */   \"prevent\": () => /* binding */ prevent,\n/* harmony export */   \"resetMouseCanceller\": () => /* binding */ resetMouseCanceller,\n/* harmony export */   \"findOriginalTarget\": () => /* binding */ findOriginalTarget,\n/* harmony export */   \"add\": () => /* binding */ add,\n/* harmony export */   \"remove\": () => /* binding */ remove\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _async_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./async.js */ \"./node_modules/@polymer/polymer/lib/utils/async.js\");\n/* harmony import */ var _debounce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./debounce.js */ \"./node_modules/@polymer/polymer/lib/utils/debounce.js\");\n/* harmony import */ var _settings_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * @fileoverview\n *\n * Module for adding listeners to a node for the following normalized\n * cross-platform \"gesture\" events:\n * - `down` - mouse or touch went down\n * - `up` - mouse or touch went up\n * - `tap` - mouse click or finger tap\n * - `track` - mouse drag or touch move\n *\n * @summary Module for adding cross-platform gesture event listeners.\n */\n\n\n\n // detect native touch action support\n\nlet HAS_NATIVE_TA = typeof document.head.style.touchAction === 'string';\nlet GESTURE_KEY = '__polymerGestures';\nlet HANDLED_OBJ = '__polymerGesturesHandled';\nlet TOUCH_ACTION = '__polymerGesturesTouchAction'; // radius for tap and track\n\nlet TAP_DISTANCE = 25;\nlet TRACK_DISTANCE = 5; // number of last N track positions to keep\n\nlet TRACK_LENGTH = 2; // Disabling \"mouse\" handlers for 2500ms is enough\n\nlet MOUSE_TIMEOUT = 2500;\nlet MOUSE_EVENTS = ['mousedown', 'mousemove', 'mouseup', 'click']; // an array of bitmask values for mapping MouseEvent.which to MouseEvent.buttons\n\nlet MOUSE_WHICH_TO_BUTTONS = [0, 1, 4, 2];\n\nlet MOUSE_HAS_BUTTONS = function () {\n  try {\n    return new MouseEvent('test', {\n      buttons: 1\n    }).buttons === 1;\n  } catch (e) {\n    return false;\n  }\n}();\n/**\n * @param {string} name Possible mouse event name\n * @return {boolean} true if mouse event, false if not\n */\n\n\nfunction isMouseEvent(name) {\n  return MOUSE_EVENTS.indexOf(name) > -1;\n}\n/* eslint no-empty: [\"error\", { \"allowEmptyCatch\": true }] */\n// check for passive event listeners\n\n\nlet SUPPORTS_PASSIVE = false;\n\n(function () {\n  try {\n    let opts = Object.defineProperty({}, 'passive', {\n      get() {\n        SUPPORTS_PASSIVE = true;\n      }\n\n    });\n    window.addEventListener('test', null, opts);\n    window.removeEventListener('test', null, opts);\n  } catch (e) {}\n})();\n/**\n * Generate settings for event listeners, dependant on `passiveTouchGestures`\n *\n * @param {string} eventName Event name to determine if `{passive}` option is\n *   needed\n * @return {{passive: boolean} | undefined} Options to use for addEventListener\n *   and removeEventListener\n */\n\n\nfunction PASSIVE_TOUCH(eventName) {\n  if (isMouseEvent(eventName) || eventName === 'touchend') {\n    return;\n  }\n\n  if (HAS_NATIVE_TA && SUPPORTS_PASSIVE && _settings_js__WEBPACK_IMPORTED_MODULE_3__.passiveTouchGestures) {\n    return {\n      passive: true\n    };\n  } else {\n    return;\n  }\n} // Check for touch-only devices\n\n\nlet IS_TOUCH_ONLY = navigator.userAgent.match(/iP(?:[oa]d|hone)|Android/); // keep track of any labels hit by the mouseCanceller\n\n/** @type {!Array<!HTMLLabelElement>} */\n\nconst clickedLabels = [];\n/** @type {!Object<boolean>} */\n\nconst labellable = {\n  'button': true,\n  'input': true,\n  'keygen': true,\n  'meter': true,\n  'output': true,\n  'textarea': true,\n  'progress': true,\n  'select': true\n}; // Defined at https://html.spec.whatwg.org/multipage/form-control-infrastructure.html#enabling-and-disabling-form-controls:-the-disabled-attribute\n\n/** @type {!Object<boolean>} */\n\nconst canBeDisabled = {\n  'button': true,\n  'command': true,\n  'fieldset': true,\n  'input': true,\n  'keygen': true,\n  'optgroup': true,\n  'option': true,\n  'select': true,\n  'textarea': true\n};\n/**\n * @param {HTMLElement} el Element to check labelling status\n * @return {boolean} element can have labels\n */\n\nfunction canBeLabelled(el) {\n  return labellable[el.localName] || false;\n}\n/**\n * @param {HTMLElement} el Element that may be labelled.\n * @return {!Array<!HTMLLabelElement>} Relevant label for `el`\n */\n\n\nfunction matchingLabels(el) {\n  let labels = Array.prototype.slice.call(\n  /** @type {HTMLInputElement} */\n  el.labels || []); // IE doesn't have `labels` and Safari doesn't populate `labels`\n  // if element is in a shadowroot.\n  // In this instance, finding the non-ancestor labels is enough,\n  // as the mouseCancellor code will handle ancstor labels\n\n  if (!labels.length) {\n    labels = [];\n    let root = el.getRootNode(); // if there is an id on `el`, check for all labels with a matching `for` attribute\n\n    if (el.id) {\n      let matching = root.querySelectorAll(`label[for = ${el.id}]`);\n\n      for (let i = 0; i < matching.length; i++) {\n        labels.push(\n        /** @type {!HTMLLabelElement} */\n        matching[i]);\n      }\n    }\n  }\n\n  return labels;\n} // touch will make synthetic mouse events\n// `preventDefault` on touchend will cancel them,\n// but this breaks `<input>` focus and link clicks\n// disable mouse handlers for MOUSE_TIMEOUT ms after\n// a touchend to ignore synthetic mouse events\n\n\nlet mouseCanceller = function (mouseEvent) {\n  // Check for sourceCapabilities, used to distinguish synthetic events\n  // if mouseEvent did not come from a device that fires touch events,\n  // it was made by a real mouse and should be counted\n  // http://wicg.github.io/InputDeviceCapabilities/#dom-inputdevicecapabilities-firestouchevents\n  let sc = mouseEvent.sourceCapabilities;\n\n  if (sc && !sc.firesTouchEvents) {\n    return;\n  } // skip synthetic mouse events\n\n\n  mouseEvent[HANDLED_OBJ] = {\n    skip: true\n  }; // disable \"ghost clicks\"\n\n  if (mouseEvent.type === 'click') {\n    let clickFromLabel = false;\n    let path = mouseEvent.composedPath && mouseEvent.composedPath();\n\n    if (path) {\n      for (let i = 0; i < path.length; i++) {\n        if (path[i].nodeType === Node.ELEMENT_NODE) {\n          if (path[i].localName === 'label') {\n            clickedLabels.push(path[i]);\n          } else if (canBeLabelled(path[i])) {\n            let ownerLabels = matchingLabels(path[i]); // check if one of the clicked labels is labelling this element\n\n            for (let j = 0; j < ownerLabels.length; j++) {\n              clickFromLabel = clickFromLabel || clickedLabels.indexOf(ownerLabels[j]) > -1;\n            }\n          }\n        }\n\n        if (path[i] === POINTERSTATE.mouse.target) {\n          return;\n        }\n      }\n    } // if one of the clicked labels was labelling the target element,\n    // this is not a ghost click\n\n\n    if (clickFromLabel) {\n      return;\n    }\n\n    mouseEvent.preventDefault();\n    mouseEvent.stopPropagation();\n  }\n};\n/**\n * @param {boolean=} setup True to add, false to remove.\n * @return {void}\n */\n\n\nfunction setupTeardownMouseCanceller(setup) {\n  let events = IS_TOUCH_ONLY ? ['click'] : MOUSE_EVENTS;\n\n  for (let i = 0, en; i < events.length; i++) {\n    en = events[i];\n\n    if (setup) {\n      // reset clickLabels array\n      clickedLabels.length = 0;\n      document.addEventListener(en, mouseCanceller, true);\n    } else {\n      document.removeEventListener(en, mouseCanceller, true);\n    }\n  }\n}\n\nfunction ignoreMouse(e) {\n  if (!POINTERSTATE.mouse.mouseIgnoreJob) {\n    setupTeardownMouseCanceller(true);\n  }\n\n  let unset = function () {\n    setupTeardownMouseCanceller();\n    POINTERSTATE.mouse.target = null;\n    POINTERSTATE.mouse.mouseIgnoreJob = null;\n  };\n\n  POINTERSTATE.mouse.target = e.composedPath()[0];\n  POINTERSTATE.mouse.mouseIgnoreJob = _debounce_js__WEBPACK_IMPORTED_MODULE_2__.Debouncer.debounce(POINTERSTATE.mouse.mouseIgnoreJob, _async_js__WEBPACK_IMPORTED_MODULE_1__.timeOut.after(MOUSE_TIMEOUT), unset);\n}\n/**\n * @param {MouseEvent} ev event to test for left mouse button down\n * @return {boolean} has left mouse button down\n */\n\n\nfunction hasLeftMouseButton(ev) {\n  let type = ev.type; // exit early if the event is not a mouse event\n\n  if (!isMouseEvent(type)) {\n    return false;\n  } // ev.button is not reliable for mousemove (0 is overloaded as both left button and no buttons)\n  // instead we use ev.buttons (bitmask of buttons) or fall back to ev.which (deprecated, 0 for no buttons, 1 for left button)\n\n\n  if (type === 'mousemove') {\n    // allow undefined for testing events\n    let buttons = ev.buttons === undefined ? 1 : ev.buttons;\n\n    if (ev instanceof window.MouseEvent && !MOUSE_HAS_BUTTONS) {\n      buttons = MOUSE_WHICH_TO_BUTTONS[ev.which] || 0;\n    } // buttons is a bitmask, check that the left button bit is set (1)\n\n\n    return Boolean(buttons & 1);\n  } else {\n    // allow undefined for testing events\n    let button = ev.button === undefined ? 0 : ev.button; // ev.button is 0 in mousedown/mouseup/click for left button activation\n\n    return button === 0;\n  }\n}\n\nfunction isSyntheticClick(ev) {\n  if (ev.type === 'click') {\n    // ev.detail is 0 for HTMLElement.click in most browsers\n    if (ev.detail === 0) {\n      return true;\n    } // in the worst case, check that the x/y position of the click is within\n    // the bounding box of the target of the event\n    // Thanks IE 10 >:(\n\n\n    let t = _findOriginalTarget(ev); // make sure the target of the event is an element so we can use getBoundingClientRect,\n    // if not, just assume it is a synthetic click\n\n\n    if (!t.nodeType ||\n    /** @type {Element} */\n    t.nodeType !== Node.ELEMENT_NODE) {\n      return true;\n    }\n\n    let bcr =\n    /** @type {Element} */\n    t.getBoundingClientRect(); // use page x/y to account for scrolling\n\n    let x = ev.pageX,\n        y = ev.pageY; // ev is a synthetic click if the position is outside the bounding box of the target\n\n    return !(x >= bcr.left && x <= bcr.right && y >= bcr.top && y <= bcr.bottom);\n  }\n\n  return false;\n}\n\nlet POINTERSTATE = {\n  mouse: {\n    target: null,\n    mouseIgnoreJob: null\n  },\n  touch: {\n    x: 0,\n    y: 0,\n    id: -1,\n    scrollDecided: false\n  }\n};\n\nfunction firstTouchAction(ev) {\n  let ta = 'auto';\n  let path = ev.composedPath && ev.composedPath();\n\n  if (path) {\n    for (let i = 0, n; i < path.length; i++) {\n      n = path[i];\n\n      if (n[TOUCH_ACTION]) {\n        ta = n[TOUCH_ACTION];\n        break;\n      }\n    }\n  }\n\n  return ta;\n}\n\nfunction trackDocument(stateObj, movefn, upfn) {\n  stateObj.movefn = movefn;\n  stateObj.upfn = upfn;\n  document.addEventListener('mousemove', movefn);\n  document.addEventListener('mouseup', upfn);\n}\n\nfunction untrackDocument(stateObj) {\n  document.removeEventListener('mousemove', stateObj.movefn);\n  document.removeEventListener('mouseup', stateObj.upfn);\n  stateObj.movefn = null;\n  stateObj.upfn = null;\n} // use a document-wide touchend listener to start the ghost-click prevention mechanism\n// Use passive event listeners, if supported, to not affect scrolling performance\n\n\ndocument.addEventListener('touchend', ignoreMouse, SUPPORTS_PASSIVE ? {\n  passive: true\n} : false);\n/** @type {!Object<string, !GestureRecognizer>} */\n\nconst gestures = {};\n/** @type {!Array<!GestureRecognizer>} */\n\nconst recognizers = [];\n/**\n * Finds the element rendered on the screen at the provided coordinates.\n *\n * Similar to `document.elementFromPoint`, but pierces through\n * shadow roots.\n *\n * @param {number} x Horizontal pixel coordinate\n * @param {number} y Vertical pixel coordinate\n * @return {Element} Returns the deepest shadowRoot inclusive element\n * found at the screen position given.\n */\n\nfunction deepTargetFind(x, y) {\n  let node = document.elementFromPoint(x, y);\n  let next = node; // this code path is only taken when native ShadowDOM is used\n  // if there is a shadowroot, it may have a node at x/y\n  // if there is not a shadowroot, exit the loop\n\n  while (next && next.shadowRoot && !window.ShadyDOM) {\n    // if there is a node at x/y in the shadowroot, look deeper\n    let oldNext = next;\n    next = next.shadowRoot.elementFromPoint(x, y); // on Safari, elementFromPoint may return the shadowRoot host\n\n    if (oldNext === next) {\n      break;\n    }\n\n    if (next) {\n      node = next;\n    }\n  }\n\n  return node;\n}\n/**\n * a cheaper check than ev.composedPath()[0];\n *\n * @private\n * @param {Event|Touch} ev Event.\n * @return {EventTarget} Returns the event target.\n */\n\nfunction _findOriginalTarget(ev) {\n  // shadowdom\n  if (ev.composedPath) {\n    const targets =\n    /** @type {!Array<!EventTarget>} */\n    ev.composedPath(); // It shouldn't be, but sometimes targets is empty (window on Safari).\n\n    return targets.length > 0 ? targets[0] : ev.target;\n  } // shadydom\n\n\n  return ev.target;\n}\n/**\n * @private\n * @param {Event} ev Event.\n * @return {void}\n */\n\n\nfunction _handleNative(ev) {\n  let handled;\n  let type = ev.type;\n  let node = ev.currentTarget;\n  let gobj = node[GESTURE_KEY];\n\n  if (!gobj) {\n    return;\n  }\n\n  let gs = gobj[type];\n\n  if (!gs) {\n    return;\n  }\n\n  if (!ev[HANDLED_OBJ]) {\n    ev[HANDLED_OBJ] = {};\n\n    if (type.slice(0, 5) === 'touch') {\n      ev =\n      /** @type {TouchEvent} */\n      ev; // eslint-disable-line no-self-assign\n\n      let t = ev.changedTouches[0];\n\n      if (type === 'touchstart') {\n        // only handle the first finger\n        if (ev.touches.length === 1) {\n          POINTERSTATE.touch.id = t.identifier;\n        }\n      }\n\n      if (POINTERSTATE.touch.id !== t.identifier) {\n        return;\n      }\n\n      if (!HAS_NATIVE_TA) {\n        if (type === 'touchstart' || type === 'touchmove') {\n          _handleTouchAction(ev);\n        }\n      }\n    }\n  }\n\n  handled = ev[HANDLED_OBJ]; // used to ignore synthetic mouse events\n\n  if (handled.skip) {\n    return;\n  } // reset recognizer state\n\n\n  for (let i = 0, r; i < recognizers.length; i++) {\n    r = recognizers[i];\n\n    if (gs[r.name] && !handled[r.name]) {\n      if (r.flow && r.flow.start.indexOf(ev.type) > -1 && r.reset) {\n        r.reset();\n      }\n    }\n  } // enforce gesture recognizer order\n\n\n  for (let i = 0, r; i < recognizers.length; i++) {\n    r = recognizers[i];\n\n    if (gs[r.name] && !handled[r.name]) {\n      handled[r.name] = true;\n      r[type](ev);\n    }\n  }\n}\n/**\n * @private\n * @param {TouchEvent} ev Event.\n * @return {void}\n */\n\n\nfunction _handleTouchAction(ev) {\n  let t = ev.changedTouches[0];\n  let type = ev.type;\n\n  if (type === 'touchstart') {\n    POINTERSTATE.touch.x = t.clientX;\n    POINTERSTATE.touch.y = t.clientY;\n    POINTERSTATE.touch.scrollDecided = false;\n  } else if (type === 'touchmove') {\n    if (POINTERSTATE.touch.scrollDecided) {\n      return;\n    }\n\n    POINTERSTATE.touch.scrollDecided = true;\n    let ta = firstTouchAction(ev);\n    let shouldPrevent = false;\n    let dx = Math.abs(POINTERSTATE.touch.x - t.clientX);\n    let dy = Math.abs(POINTERSTATE.touch.y - t.clientY);\n\n    if (!ev.cancelable) {// scrolling is happening\n    } else if (ta === 'none') {\n      shouldPrevent = true;\n    } else if (ta === 'pan-x') {\n      shouldPrevent = dy > dx;\n    } else if (ta === 'pan-y') {\n      shouldPrevent = dx > dy;\n    }\n\n    if (shouldPrevent) {\n      ev.preventDefault();\n    } else {\n      prevent('track');\n    }\n  }\n}\n/**\n * Adds an event listener to a node for the given gesture type.\n *\n * @param {!EventTarget} node Node to add listener on\n * @param {string} evType Gesture type: `down`, `up`, `track`, or `tap`\n * @param {!function(!Event):void} handler Event listener function to call\n * @return {boolean} Returns true if a gesture event listener was added.\n */\n\n\nfunction addListener(node, evType, handler) {\n  if (gestures[evType]) {\n    _add(node, evType, handler);\n\n    return true;\n  }\n\n  return false;\n}\n/**\n * Removes an event listener from a node for the given gesture type.\n *\n * @param {!EventTarget} node Node to remove listener from\n * @param {string} evType Gesture type: `down`, `up`, `track`, or `tap`\n * @param {!function(!Event):void} handler Event listener function previously passed to\n *  `addListener`.\n * @return {boolean} Returns true if a gesture event listener was removed.\n */\n\nfunction removeListener(node, evType, handler) {\n  if (gestures[evType]) {\n    _remove(node, evType, handler);\n\n    return true;\n  }\n\n  return false;\n}\n/**\n * automate the event listeners for the native events\n *\n * @private\n * @param {!EventTarget} node Node on which to add the event.\n * @param {string} evType Event type to add.\n * @param {function(!Event)} handler Event handler function.\n * @return {void}\n */\n\nfunction _add(node, evType, handler) {\n  let recognizer = gestures[evType];\n  let deps = recognizer.deps;\n  let name = recognizer.name;\n  let gobj = node[GESTURE_KEY];\n\n  if (!gobj) {\n    node[GESTURE_KEY] = gobj = {};\n  }\n\n  for (let i = 0, dep, gd; i < deps.length; i++) {\n    dep = deps[i]; // don't add mouse handlers on iOS because they cause gray selection overlays\n\n    if (IS_TOUCH_ONLY && isMouseEvent(dep) && dep !== 'click') {\n      continue;\n    }\n\n    gd = gobj[dep];\n\n    if (!gd) {\n      gobj[dep] = gd = {\n        _count: 0\n      };\n    }\n\n    if (gd._count === 0) {\n      node.addEventListener(dep, _handleNative, PASSIVE_TOUCH(dep));\n    }\n\n    gd[name] = (gd[name] || 0) + 1;\n    gd._count = (gd._count || 0) + 1;\n  }\n\n  node.addEventListener(evType, handler);\n\n  if (recognizer.touchAction) {\n    setTouchAction(node, recognizer.touchAction);\n  }\n}\n/**\n * automate event listener removal for native events\n *\n * @private\n * @param {!EventTarget} node Node on which to remove the event.\n * @param {string} evType Event type to remove.\n * @param {function(!Event): void} handler Event handler function.\n * @return {void}\n */\n\n\nfunction _remove(node, evType, handler) {\n  let recognizer = gestures[evType];\n  let deps = recognizer.deps;\n  let name = recognizer.name;\n  let gobj = node[GESTURE_KEY];\n\n  if (gobj) {\n    for (let i = 0, dep, gd; i < deps.length; i++) {\n      dep = deps[i];\n      gd = gobj[dep];\n\n      if (gd && gd[name]) {\n        gd[name] = (gd[name] || 1) - 1;\n        gd._count = (gd._count || 1) - 1;\n\n        if (gd._count === 0) {\n          node.removeEventListener(dep, _handleNative, PASSIVE_TOUCH(dep));\n        }\n      }\n    }\n  }\n\n  node.removeEventListener(evType, handler);\n}\n/**\n * Registers a new gesture event recognizer for adding new custom\n * gesture event types.\n *\n * @param {!GestureRecognizer} recog Gesture recognizer descriptor\n * @return {void}\n */\n\n\nfunction register(recog) {\n  recognizers.push(recog);\n\n  for (let i = 0; i < recog.emits.length; i++) {\n    gestures[recog.emits[i]] = recog;\n  }\n}\n/**\n * @private\n * @param {string} evName Event name.\n * @return {Object} Returns the gesture for the given event name.\n */\n\nfunction _findRecognizerByEvent(evName) {\n  for (let i = 0, r; i < recognizers.length; i++) {\n    r = recognizers[i];\n\n    for (let j = 0, n; j < r.emits.length; j++) {\n      n = r.emits[j];\n\n      if (n === evName) {\n        return r;\n      }\n    }\n  }\n\n  return null;\n}\n/**\n * Sets scrolling direction on node.\n *\n * This value is checked on first move, thus it should be called prior to\n * adding event listeners.\n *\n * @param {!EventTarget} node Node to set touch action setting on\n * @param {string} value Touch action value\n * @return {void}\n */\n\n\nfunction setTouchAction(node, value) {\n  if (HAS_NATIVE_TA && node instanceof HTMLElement) {\n    // NOTE: add touchAction async so that events can be added in\n    // custom element constructors. Otherwise we run afoul of custom\n    // elements restriction against settings attributes (style) in the\n    // constructor.\n    _async_js__WEBPACK_IMPORTED_MODULE_1__.microTask.run(() => {\n      node.style.touchAction = value;\n    });\n  }\n\n  node[TOUCH_ACTION] = value;\n}\n/**\n * Dispatches an event on the `target` element of `type` with the given\n * `detail`.\n * @private\n * @param {!EventTarget} target The element on which to fire an event.\n * @param {string} type The type of event to fire.\n * @param {!Object=} detail The detail object to populate on the event.\n * @return {void}\n */\n\nfunction _fire(target, type, detail) {\n  let ev = new Event(type, {\n    bubbles: true,\n    cancelable: true,\n    composed: true\n  });\n  ev.detail = detail;\n  target.dispatchEvent(ev); // forward `preventDefault` in a clean way\n\n  if (ev.defaultPrevented) {\n    let preventer = detail.preventer || detail.sourceEvent;\n\n    if (preventer && preventer.preventDefault) {\n      preventer.preventDefault();\n    }\n  }\n}\n/**\n * Prevents the dispatch and default action of the given event name.\n *\n * @param {string} evName Event name.\n * @return {void}\n */\n\n\nfunction prevent(evName) {\n  let recognizer = _findRecognizerByEvent(evName);\n\n  if (recognizer.info) {\n    recognizer.info.prevent = true;\n  }\n}\n/**\n * Reset the 2500ms timeout on processing mouse input after detecting touch input.\n *\n * Touch inputs create synthesized mouse inputs anywhere from 0 to 2000ms after the touch.\n * This method should only be called during testing with simulated touch inputs.\n * Calling this method in production may cause duplicate taps or other Gestures.\n *\n * @return {void}\n */\n\nfunction resetMouseCanceller() {\n  if (POINTERSTATE.mouse.mouseIgnoreJob) {\n    POINTERSTATE.mouse.mouseIgnoreJob.flush();\n  }\n}\n/* eslint-disable valid-jsdoc */\n\nregister({\n  name: 'downup',\n  deps: ['mousedown', 'touchstart', 'touchend'],\n  flow: {\n    start: ['mousedown', 'touchstart'],\n    end: ['mouseup', 'touchend']\n  },\n  emits: ['down', 'up'],\n  info: {\n    movefn: null,\n    upfn: null\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @return {void}\n   */\n  reset: function () {\n    untrackDocument(this.info);\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {MouseEvent} e\n   * @return {void}\n   */\n  mousedown: function (e) {\n    if (!hasLeftMouseButton(e)) {\n      return;\n    }\n\n    let t = _findOriginalTarget(e);\n\n    let self = this;\n\n    let movefn = function movefn(e) {\n      if (!hasLeftMouseButton(e)) {\n        downupFire('up', t, e);\n        untrackDocument(self.info);\n      }\n    };\n\n    let upfn = function upfn(e) {\n      if (hasLeftMouseButton(e)) {\n        downupFire('up', t, e);\n      }\n\n      untrackDocument(self.info);\n    };\n\n    trackDocument(this.info, movefn, upfn);\n    downupFire('down', t, e);\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchstart: function (e) {\n    downupFire('down', _findOriginalTarget(e), e.changedTouches[0], e);\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchend: function (e) {\n    downupFire('up', _findOriginalTarget(e), e.changedTouches[0], e);\n  }\n});\n/**\n * @param {string} type\n * @param {EventTarget} target\n * @param {Event|Touch} event\n * @param {Event=} preventer\n * @return {void}\n */\n\nfunction downupFire(type, target, event, preventer) {\n  if (!target) {\n    return;\n  }\n\n  _fire(target, type, {\n    x: event.clientX,\n    y: event.clientY,\n    sourceEvent: event,\n    preventer: preventer,\n    prevent: function (e) {\n      return prevent(e);\n    }\n  });\n}\n\nregister({\n  name: 'track',\n  touchAction: 'none',\n  deps: ['mousedown', 'touchstart', 'touchmove', 'touchend'],\n  flow: {\n    start: ['mousedown', 'touchstart'],\n    end: ['mouseup', 'touchend']\n  },\n  emits: ['track'],\n  info: {\n    x: 0,\n    y: 0,\n    state: 'start',\n    started: false,\n    moves: [],\n\n    /** @this {GestureInfo} */\n    addMove: function (move) {\n      if (this.moves.length > TRACK_LENGTH) {\n        this.moves.shift();\n      }\n\n      this.moves.push(move);\n    },\n    movefn: null,\n    upfn: null,\n    prevent: false\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @return {void}\n   */\n  reset: function () {\n    this.info.state = 'start';\n    this.info.started = false;\n    this.info.moves = [];\n    this.info.x = 0;\n    this.info.y = 0;\n    this.info.prevent = false;\n    untrackDocument(this.info);\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {MouseEvent} e\n   * @return {void}\n   */\n  mousedown: function (e) {\n    if (!hasLeftMouseButton(e)) {\n      return;\n    }\n\n    let t = _findOriginalTarget(e);\n\n    let self = this;\n\n    let movefn = function movefn(e) {\n      let x = e.clientX,\n          y = e.clientY;\n\n      if (trackHasMovedEnough(self.info, x, y)) {\n        // first move is 'start', subsequent moves are 'move', mouseup is 'end'\n        self.info.state = self.info.started ? e.type === 'mouseup' ? 'end' : 'track' : 'start';\n\n        if (self.info.state === 'start') {\n          // if and only if tracking, always prevent tap\n          prevent('tap');\n        }\n\n        self.info.addMove({\n          x: x,\n          y: y\n        });\n\n        if (!hasLeftMouseButton(e)) {\n          // always fire \"end\"\n          self.info.state = 'end';\n          untrackDocument(self.info);\n        }\n\n        if (t) {\n          trackFire(self.info, t, e);\n        }\n\n        self.info.started = true;\n      }\n    };\n\n    let upfn = function upfn(e) {\n      if (self.info.started) {\n        movefn(e);\n      } // remove the temporary listeners\n\n\n      untrackDocument(self.info);\n    }; // add temporary document listeners as mouse retargets\n\n\n    trackDocument(this.info, movefn, upfn);\n    this.info.x = e.clientX;\n    this.info.y = e.clientY;\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchstart: function (e) {\n    let ct = e.changedTouches[0];\n    this.info.x = ct.clientX;\n    this.info.y = ct.clientY;\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchmove: function (e) {\n    let t = _findOriginalTarget(e);\n\n    let ct = e.changedTouches[0];\n    let x = ct.clientX,\n        y = ct.clientY;\n\n    if (trackHasMovedEnough(this.info, x, y)) {\n      if (this.info.state === 'start') {\n        // if and only if tracking, always prevent tap\n        prevent('tap');\n      }\n\n      this.info.addMove({\n        x: x,\n        y: y\n      });\n      trackFire(this.info, t, ct);\n      this.info.state = 'track';\n      this.info.started = true;\n    }\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchend: function (e) {\n    let t = _findOriginalTarget(e);\n\n    let ct = e.changedTouches[0]; // only trackend if track was started and not aborted\n\n    if (this.info.started) {\n      // reset started state on up\n      this.info.state = 'end';\n      this.info.addMove({\n        x: ct.clientX,\n        y: ct.clientY\n      });\n      trackFire(this.info, t, ct);\n    }\n  }\n});\n/**\n * @param {!GestureInfo} info\n * @param {number} x\n * @param {number} y\n * @return {boolean}\n */\n\nfunction trackHasMovedEnough(info, x, y) {\n  if (info.prevent) {\n    return false;\n  }\n\n  if (info.started) {\n    return true;\n  }\n\n  let dx = Math.abs(info.x - x);\n  let dy = Math.abs(info.y - y);\n  return dx >= TRACK_DISTANCE || dy >= TRACK_DISTANCE;\n}\n/**\n * @param {!GestureInfo} info\n * @param {?EventTarget} target\n * @param {Touch} touch\n * @return {void}\n */\n\n\nfunction trackFire(info, target, touch) {\n  if (!target) {\n    return;\n  }\n\n  let secondlast = info.moves[info.moves.length - 2];\n  let lastmove = info.moves[info.moves.length - 1];\n  let dx = lastmove.x - info.x;\n  let dy = lastmove.y - info.y;\n  let ddx,\n      ddy = 0;\n\n  if (secondlast) {\n    ddx = lastmove.x - secondlast.x;\n    ddy = lastmove.y - secondlast.y;\n  }\n\n  _fire(target, 'track', {\n    state: info.state,\n    x: touch.clientX,\n    y: touch.clientY,\n    dx: dx,\n    dy: dy,\n    ddx: ddx,\n    ddy: ddy,\n    sourceEvent: touch,\n    hover: function () {\n      return deepTargetFind(touch.clientX, touch.clientY);\n    }\n  });\n}\n\nregister({\n  name: 'tap',\n  deps: ['mousedown', 'click', 'touchstart', 'touchend'],\n  flow: {\n    start: ['mousedown', 'touchstart'],\n    end: ['click', 'touchend']\n  },\n  emits: ['tap'],\n  info: {\n    x: NaN,\n    y: NaN,\n    prevent: false\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @return {void}\n   */\n  reset: function () {\n    this.info.x = NaN;\n    this.info.y = NaN;\n    this.info.prevent = false;\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {MouseEvent} e\n   * @return {void}\n   */\n  mousedown: function (e) {\n    if (hasLeftMouseButton(e)) {\n      this.info.x = e.clientX;\n      this.info.y = e.clientY;\n    }\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {MouseEvent} e\n   * @return {void}\n   */\n  click: function (e) {\n    if (hasLeftMouseButton(e)) {\n      trackForward(this.info, e);\n    }\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchstart: function (e) {\n    const touch = e.changedTouches[0];\n    this.info.x = touch.clientX;\n    this.info.y = touch.clientY;\n  },\n\n  /**\n   * @this {GestureRecognizer}\n   * @param {TouchEvent} e\n   * @return {void}\n   */\n  touchend: function (e) {\n    trackForward(this.info, e.changedTouches[0], e);\n  }\n});\n/**\n * @param {!GestureInfo} info\n * @param {Event | Touch} e\n * @param {Event=} preventer\n * @return {void}\n */\n\nfunction trackForward(info, e, preventer) {\n  let dx = Math.abs(e.clientX - info.x);\n  let dy = Math.abs(e.clientY - info.y); // find original target from `preventer` for TouchEvents, or `e` for MouseEvents\n\n  let t = _findOriginalTarget(preventer || e);\n\n  if (!t || canBeDisabled[\n  /** @type {!HTMLElement} */\n  t.localName] && t.hasAttribute('disabled')) {\n    return;\n  } // dx,dy can be NaN if `click` has been simulated and there was no `down` for `start`\n\n\n  if (isNaN(dx) || isNaN(dy) || dx <= TAP_DISTANCE && dy <= TAP_DISTANCE || isSyntheticClick(e)) {\n    // prevent taps from being generated if an event has canceled them\n    if (!info.prevent) {\n      _fire(t, 'tap', {\n        x: e.clientX,\n        y: e.clientY,\n        sourceEvent: e,\n        preventer: preventer\n      });\n    }\n  }\n}\n/* eslint-enable valid-jsdoc */\n\n/** @deprecated */\n\n\nconst findOriginalTarget = _findOriginalTarget;\n/** @deprecated */\n\nconst add = addListener;\n/** @deprecated */\n\nconst remove = removeListener;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/gestures.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/html-tag.js":
/*!*************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/html-tag.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] */
/*! export htmlLiteral [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"html\": () => /* binding */ html,\n/* harmony export */   \"htmlLiteral\": () => /* binding */ htmlLiteral\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Class representing a static string value which can be used to filter\n * strings by asseting that they have been created via this class. The\n * `value` property returns the string passed to the constructor.\n */\n\nclass LiteralString {\n  constructor(string) {\n    /** @type {string} */\n    this.value = string.toString();\n  }\n  /**\n   * @return {string} LiteralString string value\n   * @override\n   */\n\n\n  toString() {\n    return this.value;\n  }\n\n}\n/**\n * @param {*} value Object to stringify into HTML\n * @return {string} HTML stringified form of `obj`\n */\n\n\nfunction literalValue(value) {\n  if (value instanceof LiteralString) {\n    return (\n      /** @type {!LiteralString} */\n      value.value\n    );\n  } else {\n    throw new Error(`non-literal value passed to Polymer's htmlLiteral function: ${value}`);\n  }\n}\n/**\n * @param {*} value Object to stringify into HTML\n * @return {string} HTML stringified form of `obj`\n */\n\n\nfunction htmlValue(value) {\n  if (value instanceof HTMLTemplateElement) {\n    return (\n      /** @type {!HTMLTemplateElement } */\n      value.innerHTML\n    );\n  } else if (value instanceof LiteralString) {\n    return literalValue(value);\n  } else {\n    throw new Error(`non-template value passed to Polymer's html function: ${value}`);\n  }\n}\n/**\n * A template literal tag that creates an HTML <template> element from the\n * contents of the string.\n *\n * This allows you to write a Polymer Template in JavaScript.\n *\n * Templates can be composed by interpolating `HTMLTemplateElement`s in\n * expressions in the JavaScript template literal. The nested template's\n * `innerHTML` is included in the containing template.  The only other\n * values allowed in expressions are those returned from `htmlLiteral`\n * which ensures only literal values from JS source ever reach the HTML, to\n * guard against XSS risks.\n *\n * All other values are disallowed in expressions to help prevent XSS\n * attacks; however, `htmlLiteral` can be used to compose static\n * string values into templates. This is useful to compose strings into\n * places that do not accept html, like the css text of a `style`\n * element.\n *\n * Example:\n *\n *     static get template() {\n *       return html`\n *         <style>:host{ content:\"...\" }</style>\n *         <div class=\"shadowed\">${this.partialTemplate}</div>\n *         ${super.template}\n *       `;\n *     }\n *     static get partialTemplate() { return html`<span>Partial!</span>`; }\n *\n * @param {!ITemplateArray} strings Constant parts of tagged template literal\n * @param {...*} values Variable parts of tagged template literal\n * @return {!HTMLTemplateElement} Constructed HTMLTemplateElement\n */\n\n\nconst html = function html(strings, ...values) {\n  const template =\n  /** @type {!HTMLTemplateElement} */\n  document.createElement('template');\n  template.innerHTML = values.reduce((acc, v, idx) => acc + htmlValue(v) + strings[idx + 1], strings[0]);\n  return template;\n};\n/**\n * An html literal tag that can be used with `html` to compose.\n * a literal string.\n *\n * Example:\n *\n *     static get template() {\n *       return html`\n *         <style>\n *           :host { display: block; }\n *           ${this.styleTemplate()}\n *         </style>\n *         <div class=\"shadowed\">${staticValue}</div>\n *         ${super.template}\n *       `;\n *     }\n *     static get styleTemplate() {\n *        return htmlLiteral`.shadowed { background: gray; }`;\n *     }\n *\n * @param {!ITemplateArray} strings Constant parts of tagged template literal\n * @param {...*} values Variable parts of tagged template literal\n * @return {!LiteralString} Constructed literal string\n */\n\nconst htmlLiteral = function (strings, ...values) {\n  return new LiteralString(values.reduce((acc, v, idx) => acc + literalValue(v) + strings[idx + 1], strings[0]));\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/html-tag.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/mixin.js":
/*!**********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/mixin.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export dedupingMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"dedupingMixin\": () => /* binding */ dedupingMixin\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n // unique global id for deduping mixins.\n\nlet dedupeId = 0;\n/**\n * @constructor\n * @extends {Function}\n * @private\n */\n\nfunction MixinFunction() {}\n/** @type {(WeakMap | undefined)} */\n\n\nMixinFunction.prototype.__mixinApplications;\n/** @type {(Object | undefined)} */\n\nMixinFunction.prototype.__mixinSet;\n/* eslint-disable valid-jsdoc */\n\n/**\n * Wraps an ES6 class expression mixin such that the mixin is only applied\n * if it has not already been applied its base argument. Also memoizes mixin\n * applications.\n *\n * @template T\n * @param {T} mixin ES6 class expression mixin to wrap\n * @return {T}\n * @suppress {invalidCasts}\n */\n\nconst dedupingMixin = function (mixin) {\n  let mixinApplications =\n  /** @type {!MixinFunction} */\n  mixin.__mixinApplications;\n\n  if (!mixinApplications) {\n    mixinApplications = new WeakMap();\n    /** @type {!MixinFunction} */\n\n    mixin.__mixinApplications = mixinApplications;\n  } // maintain a unique id for each mixin\n\n\n  let mixinDedupeId = dedupeId++;\n\n  function dedupingMixin(base) {\n    let baseSet =\n    /** @type {!MixinFunction} */\n    base.__mixinSet;\n\n    if (baseSet && baseSet[mixinDedupeId]) {\n      return base;\n    }\n\n    let map = mixinApplications;\n    let extended = map.get(base);\n\n    if (!extended) {\n      extended =\n      /** @type {!Function} */\n      mixin(base);\n      map.set(base, extended);\n    } // copy inherited mixin set from the extended class, or the base class\n    // NOTE: we avoid use of Set here because some browser (IE11)\n    // cannot extend a base Set via the constructor.\n\n\n    let mixinSet = Object.create(\n    /** @type {!MixinFunction} */\n    extended.__mixinSet || baseSet || null);\n    mixinSet[mixinDedupeId] = true;\n    /** @type {!MixinFunction} */\n\n    extended.__mixinSet = mixinSet;\n    return extended;\n  }\n\n  return dedupingMixin;\n};\n/* eslint-enable valid-jsdoc *///# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/mixin.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/path.js":
/*!*********************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/path.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export get [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isAncestor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDeep [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDescendant [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export matches [provided] [no usage info] [missing usage info prevents renaming] */
/*! export normalize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export root [provided] [no usage info] [missing usage info prevents renaming] */
/*! export set [provided] [no usage info] [missing usage info prevents renaming] */
/*! export split [provided] [no usage info] [missing usage info prevents renaming] */
/*! export translate [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"isPath\": () => /* binding */ isPath,\n/* harmony export */   \"root\": () => /* binding */ root,\n/* harmony export */   \"isAncestor\": () => /* binding */ isAncestor,\n/* harmony export */   \"isDescendant\": () => /* binding */ isDescendant,\n/* harmony export */   \"translate\": () => /* binding */ translate,\n/* harmony export */   \"matches\": () => /* binding */ matches,\n/* harmony export */   \"normalize\": () => /* binding */ normalize,\n/* harmony export */   \"split\": () => /* binding */ split,\n/* harmony export */   \"get\": () => /* binding */ get,\n/* harmony export */   \"set\": () => /* binding */ set,\n/* harmony export */   \"isDeep\": () => /* binding */ isDeep\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Module with utilities for manipulating structured data path strings.\n *\n * @summary Module with utilities for manipulating structured data path strings.\n */\n\n/**\n * Returns true if the given string is a structured data path (has dots).\n *\n * Example:\n *\n * ```\n * isPath('foo.bar.baz') // true\n * isPath('foo')         // false\n * ```\n *\n * @param {string} path Path string\n * @return {boolean} True if the string contained one or more dots\n */\n\nfunction isPath(path) {\n  return path.indexOf('.') >= 0;\n}\n/**\n * Returns the root property name for the given path.\n *\n * Example:\n *\n * ```\n * root('foo.bar.baz') // 'foo'\n * root('foo')         // 'foo'\n * ```\n *\n * @param {string} path Path string\n * @return {string} Root property name\n */\n\nfunction root(path) {\n  let dotIndex = path.indexOf('.');\n\n  if (dotIndex === -1) {\n    return path;\n  }\n\n  return path.slice(0, dotIndex);\n}\n/**\n * Given `base` is `foo.bar`, `foo` is an ancestor, `foo.bar` is not\n * Returns true if the given path is an ancestor of the base path.\n *\n * Example:\n *\n * ```\n * isAncestor('foo.bar', 'foo')         // true\n * isAncestor('foo.bar', 'foo.bar')     // false\n * isAncestor('foo.bar', 'foo.bar.baz') // false\n * ```\n *\n * @param {string} base Path string to test against.\n * @param {string} path Path string to test.\n * @return {boolean} True if `path` is an ancestor of `base`.\n */\n\nfunction isAncestor(base, path) {\n  //     base.startsWith(path + '.');\n  return base.indexOf(path + '.') === 0;\n}\n/**\n * Given `base` is `foo.bar`, `foo.bar.baz` is an descendant\n *\n * Example:\n *\n * ```\n * isDescendant('foo.bar', 'foo.bar.baz') // true\n * isDescendant('foo.bar', 'foo.bar')     // false\n * isDescendant('foo.bar', 'foo')         // false\n * ```\n *\n * @param {string} base Path string to test against.\n * @param {string} path Path string to test.\n * @return {boolean} True if `path` is a descendant of `base`.\n */\n\nfunction isDescendant(base, path) {\n  //     path.startsWith(base + '.');\n  return path.indexOf(base + '.') === 0;\n}\n/**\n * Replaces a previous base path with a new base path, preserving the\n * remainder of the path.\n *\n * User must ensure `path` has a prefix of `base`.\n *\n * Example:\n *\n * ```\n * translate('foo.bar', 'zot', 'foo.bar.baz') // 'zot.baz'\n * ```\n *\n * @param {string} base Current base string to remove\n * @param {string} newBase New base string to replace with\n * @param {string} path Path to translate\n * @return {string} Translated string\n */\n\nfunction translate(base, newBase, path) {\n  return newBase + path.slice(base.length);\n}\n/**\n * @param {string} base Path string to test against\n * @param {string} path Path string to test\n * @return {boolean} True if `path` is equal to `base`\n */\n\nfunction matches(base, path) {\n  return base === path || isAncestor(base, path) || isDescendant(base, path);\n}\n/**\n * Converts array-based paths to flattened path.  String-based paths\n * are returned as-is.\n *\n * Example:\n *\n * ```\n * normalize(['foo.bar', 0, 'baz'])  // 'foo.bar.0.baz'\n * normalize('foo.bar.0.baz')        // 'foo.bar.0.baz'\n * ```\n *\n * @param {string | !Array<string|number>} path Input path\n * @return {string} Flattened path\n */\n\nfunction normalize(path) {\n  if (Array.isArray(path)) {\n    let parts = [];\n\n    for (let i = 0; i < path.length; i++) {\n      let args = path[i].toString().split('.');\n\n      for (let j = 0; j < args.length; j++) {\n        parts.push(args[j]);\n      }\n    }\n\n    return parts.join('.');\n  } else {\n    return path;\n  }\n}\n/**\n * Splits a path into an array of property names. Accepts either arrays\n * of path parts or strings.\n *\n * Example:\n *\n * ```\n * split(['foo.bar', 0, 'baz'])  // ['foo', 'bar', '0', 'baz']\n * split('foo.bar.0.baz')        // ['foo', 'bar', '0', 'baz']\n * ```\n *\n * @param {string | !Array<string|number>} path Input path\n * @return {!Array<string>} Array of path parts\n * @suppress {checkTypes}\n */\n\nfunction split(path) {\n  if (Array.isArray(path)) {\n    return normalize(path).split('.');\n  }\n\n  return path.toString().split('.');\n}\n/**\n * Reads a value from a path.  If any sub-property in the path is `undefined`,\n * this method returns `undefined` (will never throw.\n *\n * @param {Object} root Object from which to dereference path from\n * @param {string | !Array<string|number>} path Path to read\n * @param {Object=} info If an object is provided to `info`, the normalized\n *  (flattened) path will be set to `info.path`.\n * @return {*} Value at path, or `undefined` if the path could not be\n *  fully dereferenced.\n */\n\nfunction get(root, path, info) {\n  let prop = root;\n  let parts = split(path); // Loop over path parts[0..n-1] and dereference\n\n  for (let i = 0; i < parts.length; i++) {\n    if (!prop) {\n      return;\n    }\n\n    let part = parts[i];\n    prop = prop[part];\n  }\n\n  if (info) {\n    info.path = parts.join('.');\n  }\n\n  return prop;\n}\n/**\n * Sets a value to a path.  If any sub-property in the path is `undefined`,\n * this method will no-op.\n *\n * @param {Object} root Object from which to dereference path from\n * @param {string | !Array<string|number>} path Path to set\n * @param {*} value Value to set to path\n * @return {string | undefined} The normalized version of the input path\n */\n\nfunction set(root, path, value) {\n  let prop = root;\n  let parts = split(path);\n  let last = parts[parts.length - 1];\n\n  if (parts.length > 1) {\n    // Loop over path parts[0..n-2] and dereference\n    for (let i = 0; i < parts.length - 1; i++) {\n      let part = parts[i];\n      prop = prop[part];\n\n      if (!prop) {\n        return;\n      }\n    } // Set value to object at end of path\n\n\n    prop[last] = value;\n  } else {\n    // Simple property set\n    prop[path] = value;\n  }\n\n  return parts.join('.');\n}\n/**\n * Returns true if the given string is a structured data path (has dots).\n *\n * This function is deprecated.  Use `isPath` instead.\n *\n * Example:\n *\n * ```\n * isDeep('foo.bar.baz') // true\n * isDeep('foo')         // false\n * ```\n *\n * @deprecated\n * @param {string} path Path string\n * @return {boolean} True if the string contained one or more dots\n */\n\nconst isDeep = isPath;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/path.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/render-status.js":
/*!******************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/render-status.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export afterNextRender [provided] [no usage info] [missing usage info prevents renaming] */
/*! export beforeNextRender [provided] [no usage info] [missing usage info prevents renaming] */
/*! export flush [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"flush\": () => /* binding */ flush,\n/* harmony export */   \"beforeNextRender\": () => /* binding */ beforeNextRender,\n/* harmony export */   \"afterNextRender\": () => /* binding */ afterNextRender\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Module for scheduling flushable pre-render and post-render tasks.\n *\n * @summary Module for scheduling flushable pre-render and post-render tasks.\n */\n\nlet scheduled = false;\nlet beforeRenderQueue = [];\nlet afterRenderQueue = [];\n\nfunction schedule() {\n  scheduled = true; // before next render\n\n  requestAnimationFrame(function () {\n    scheduled = false;\n    flushQueue(beforeRenderQueue); // after the render\n\n    setTimeout(function () {\n      runQueue(afterRenderQueue);\n    });\n  });\n}\n\nfunction flushQueue(queue) {\n  while (queue.length) {\n    callMethod(queue.shift());\n  }\n}\n\nfunction runQueue(queue) {\n  for (let i = 0, l = queue.length; i < l; i++) {\n    callMethod(queue.shift());\n  }\n}\n\nfunction callMethod(info) {\n  const context = info[0];\n  const callback = info[1];\n  const args = info[2];\n\n  try {\n    callback.apply(context, args);\n  } catch (e) {\n    setTimeout(() => {\n      throw e;\n    });\n  }\n}\n/**\n * Flushes all `beforeNextRender` tasks, followed by all `afterNextRender`\n * tasks.\n *\n * @return {void}\n */\n\n\nfunction flush() {\n  while (beforeRenderQueue.length || afterRenderQueue.length) {\n    flushQueue(beforeRenderQueue);\n    flushQueue(afterRenderQueue);\n  }\n\n  scheduled = false;\n}\n/**\n * Enqueues a callback which will be run before the next render, at\n * `requestAnimationFrame` timing.\n *\n * This method is useful for enqueuing work that requires DOM measurement,\n * since measurement may not be reliable in custom element callbacks before\n * the first render, as well as for batching measurement tasks in general.\n *\n * Tasks in this queue may be flushed by calling `flush()`.\n *\n * @param {*} context Context object the callback function will be bound to\n * @param {function(...*):void} callback Callback function\n * @param {!Array=} args An array of arguments to call the callback function with\n * @return {void}\n */\n\nfunction beforeNextRender(context, callback, args) {\n  if (!scheduled) {\n    schedule();\n  }\n\n  beforeRenderQueue.push([context, callback, args]);\n}\n/**\n * Enqueues a callback which will be run after the next render, equivalent\n * to one task (`setTimeout`) after the next `requestAnimationFrame`.\n *\n * This method is useful for tuning the first-render performance of an\n * element or application by deferring non-critical work until after the\n * first paint.  Typical non-render-critical work may include adding UI\n * event listeners and aria attributes.\n *\n * @param {*} context Context object the callback function will be bound to\n * @param {function(...*):void} callback Callback function\n * @param {!Array=} args An array of arguments to call the callback function with\n * @return {void}\n */\n\nfunction afterNextRender(context, callback, args) {\n  if (!scheduled) {\n    schedule();\n  }\n\n  afterRenderQueue.push([context, callback, args]);\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/render-status.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/resolve-url.js":
/*!****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/resolve-url.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export pathFromUrl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export resolveCss [provided] [no usage info] [missing usage info prevents renaming] */
/*! export resolveUrl [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"resolveUrl\": () => /* binding */ resolveUrl,\n/* harmony export */   \"resolveCss\": () => /* binding */ resolveCss,\n/* harmony export */   \"pathFromUrl\": () => /* binding */ pathFromUrl\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\nlet CSS_URL_RX = /(url\\()([^)]*)(\\))/g;\nlet ABS_URL = /(^\\/)|(^#)|(^[\\w-\\d]*:)/;\nlet workingURL;\nlet resolveDoc;\n/**\n * Resolves the given URL against the provided `baseUri'.\n *\n * Note that this function performs no resolution for URLs that start\n * with `/` (absolute URLs) or `#` (hash identifiers).  For general purpose\n * URL resolution, use `window.URL`.\n *\n * @param {string} url Input URL to resolve\n * @param {?string=} baseURI Base URI to resolve the URL against\n * @return {string} resolved URL\n */\n\nfunction resolveUrl(url, baseURI) {\n  if (url && ABS_URL.test(url)) {\n    return url;\n  } // Lazy feature detection.\n\n\n  if (workingURL === undefined) {\n    workingURL = false;\n\n    try {\n      const u = new URL('b', 'http://a');\n      u.pathname = 'c%20d';\n      workingURL = u.href === 'http://a/c%20d';\n    } catch (e) {// silently fail\n    }\n  }\n\n  if (!baseURI) {\n    baseURI = document.baseURI || window.location.href;\n  }\n\n  if (workingURL) {\n    return new URL(url, baseURI).href;\n  } // Fallback to creating an anchor into a disconnected document.\n\n\n  if (!resolveDoc) {\n    resolveDoc = document.implementation.createHTMLDocument('temp');\n    resolveDoc.base = resolveDoc.createElement('base');\n    resolveDoc.head.appendChild(resolveDoc.base);\n    resolveDoc.anchor = resolveDoc.createElement('a');\n    resolveDoc.body.appendChild(resolveDoc.anchor);\n  }\n\n  resolveDoc.base.href = baseURI;\n  resolveDoc.anchor.href = url;\n  return resolveDoc.anchor.href || url;\n}\n/**\n * Resolves any relative URL's in the given CSS text against the provided\n * `ownerDocument`'s `baseURI`.\n *\n * @param {string} cssText CSS text to process\n * @param {string} baseURI Base URI to resolve the URL against\n * @return {string} Processed CSS text with resolved URL's\n */\n\nfunction resolveCss(cssText, baseURI) {\n  return cssText.replace(CSS_URL_RX, function (m, pre, url, post) {\n    return pre + '\\'' + resolveUrl(url.replace(/[\"']/g, ''), baseURI) + '\\'' + post;\n  });\n}\n/**\n * Returns a path from a given `url`. The path includes the trailing\n * `/` from the url.\n *\n * @param {string} url Input URL to transform\n * @return {string} resolved path\n */\n\nfunction pathFromUrl(url) {\n  return url.substring(0, url.lastIndexOf('/') + 1);\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/resolve-url.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/settings.js":
/*!*************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/settings.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export allowTemplateFromDomModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export passiveTouchGestures [provided] [no usage info] [missing usage info prevents renaming] */
/*! export rootPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export sanitizeDOMValue [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setAllowTemplateFromDomModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setPassiveTouchGestures [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setRootPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setSanitizeDOMValue [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setStrictTemplatePolicy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export strictTemplatePolicy [provided] [no usage info] [missing usage info prevents renaming] */
/*! export useNativeCSSProperties [provided] [no usage info] [missing usage info prevents renaming] */
/*! export useNativeCustomElements [provided] [no usage info] [missing usage info prevents renaming] */
/*! export useShadow [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"useShadow\": () => /* binding */ useShadow,\n/* harmony export */   \"useNativeCSSProperties\": () => /* binding */ useNativeCSSProperties,\n/* harmony export */   \"useNativeCustomElements\": () => /* binding */ useNativeCustomElements,\n/* harmony export */   \"rootPath\": () => /* binding */ rootPath,\n/* harmony export */   \"setRootPath\": () => /* binding */ setRootPath,\n/* harmony export */   \"sanitizeDOMValue\": () => /* binding */ sanitizeDOMValue,\n/* harmony export */   \"setSanitizeDOMValue\": () => /* binding */ setSanitizeDOMValue,\n/* harmony export */   \"passiveTouchGestures\": () => /* binding */ passiveTouchGestures,\n/* harmony export */   \"setPassiveTouchGestures\": () => /* binding */ setPassiveTouchGestures,\n/* harmony export */   \"strictTemplatePolicy\": () => /* binding */ strictTemplatePolicy,\n/* harmony export */   \"setStrictTemplatePolicy\": () => /* binding */ setStrictTemplatePolicy,\n/* harmony export */   \"allowTemplateFromDomModule\": () => /* binding */ allowTemplateFromDomModule,\n/* harmony export */   \"setAllowTemplateFromDomModule\": () => /* binding */ setAllowTemplateFromDomModule\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _resolve_url_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./resolve-url.js */ \"./node_modules/@polymer/polymer/lib/utils/resolve-url.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\nconst useShadow = !window.ShadyDOM;\nconst useNativeCSSProperties = Boolean(!window.ShadyCSS || window.ShadyCSS.nativeCss);\nconst useNativeCustomElements = !window.customElements.polyfillWrapFlushCallback;\n/**\n * Globally settable property that is automatically assigned to\n * `ElementMixin` instances, useful for binding in templates to\n * make URL's relative to an application's root.  Defaults to the main\n * document URL, but can be overridden by users.  It may be useful to set\n * `rootPath` to provide a stable application mount path when\n * using client side routing.\n */\n\nlet rootPath = undefined || (0,_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__.pathFromUrl)(document.baseURI || window.location.href);\n/**\n * Sets the global rootPath property used by `ElementMixin` and\n * available via `rootPath`.\n *\n * @param {string} path The new root path\n * @return {void}\n */\n\nconst setRootPath = function (path) {\n  rootPath = path;\n};\n/**\n * A global callback used to sanitize any value before inserting it into the DOM.\n * The callback signature is:\n *\n *  function sanitizeDOMValue(value, name, type, node) { ... }\n *\n * Where:\n *\n * `value` is the value to sanitize.\n * `name` is the name of an attribute or property (for example, href).\n * `type` indicates where the value is being inserted: one of property, attribute, or text.\n * `node` is the node where the value is being inserted.\n *\n * @type {(function(*,string,string,Node):*)|undefined}\n */\n\nlet sanitizeDOMValue = window.Polymer && window.Polymer.sanitizeDOMValue || undefined;\n/**\n * Sets the global sanitizeDOMValue available via this module's exported\n * `sanitizeDOMValue` variable.\n *\n * @param {(function(*,string,string,Node):*)|undefined} newSanitizeDOMValue the global sanitizeDOMValue callback\n * @return {void}\n */\n\nconst setSanitizeDOMValue = function (newSanitizeDOMValue) {\n  sanitizeDOMValue = newSanitizeDOMValue;\n};\n/**\n * Globally settable property to make Polymer Gestures use passive TouchEvent listeners when recognizing gestures.\n * When set to `true`, gestures made from touch will not be able to prevent scrolling, allowing for smoother\n * scrolling performance.\n * Defaults to `false` for backwards compatibility.\n */\n\nlet passiveTouchGestures = false;\n/**\n * Sets `passiveTouchGestures` globally for all elements using Polymer Gestures.\n *\n * @param {boolean} usePassive enable or disable passive touch gestures globally\n * @return {void}\n */\n\nconst setPassiveTouchGestures = function (usePassive) {\n  passiveTouchGestures = usePassive;\n};\n/**\n * Setting to ensure Polymer template evaluation only occurs based on tempates\n * defined in trusted script.  When true, `<dom-module>` re-registration is\n * disallowed, `<dom-bind>` is disabled, and `<dom-if>`/`<dom-repeat>`\n * templates will only evaluate in the context of a trusted element template.\n */\n\nlet strictTemplatePolicy = false;\n/**\n * Sets `strictTemplatePolicy` globally for all elements\n *\n * @param {boolean} useStrictPolicy enable or disable strict template policy\n *   globally\n * @return {void}\n */\n\nconst setStrictTemplatePolicy = function (useStrictPolicy) {\n  strictTemplatePolicy = useStrictPolicy;\n};\n/**\n * Setting to enable dom-module lookup from Polymer.Element.  By default,\n * templates must be defined in script using the `static get template()`\n * getter and the `html` tag function.  To enable legacy loading of templates\n * via dom-module, set this flag to true.\n */\n\nlet allowTemplateFromDomModule = false;\n/**\n * Sets `lookupTemplateFromDomModule` globally for all elements\n *\n * @param {boolean} allowDomModule enable or disable template lookup \n *   globally\n * @return {void}\n */\n\nconst setAllowTemplateFromDomModule = function (allowDomModule) {\n  allowTemplateFromDomModule = allowDomModule;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/settings.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/style-gather.js":
/*!*****************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/style-gather.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export cssFromModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export cssFromModuleImports [provided] [no usage info] [missing usage info prevents renaming] */
/*! export cssFromModules [provided] [no usage info] [missing usage info prevents renaming] */
/*! export cssFromTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export stylesFromModule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export stylesFromModuleImports [provided] [no usage info] [missing usage info prevents renaming] */
/*! export stylesFromModules [provided] [no usage info] [missing usage info prevents renaming] */
/*! export stylesFromTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"stylesFromModules\": () => /* binding */ stylesFromModules,\n/* harmony export */   \"stylesFromModule\": () => /* binding */ stylesFromModule,\n/* harmony export */   \"stylesFromTemplate\": () => /* binding */ stylesFromTemplate,\n/* harmony export */   \"stylesFromModuleImports\": () => /* binding */ stylesFromModuleImports,\n/* harmony export */   \"cssFromModules\": () => /* binding */ cssFromModules,\n/* harmony export */   \"cssFromModule\": () => /* binding */ cssFromModule,\n/* harmony export */   \"cssFromTemplate\": () => /* binding */ cssFromTemplate,\n/* harmony export */   \"cssFromModuleImports\": () => /* binding */ cssFromModuleImports\n/* harmony export */ });\n/* harmony import */ var _elements_dom_module_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../elements/dom-module.js */ \"./node_modules/@polymer/polymer/lib/elements/dom-module.js\");\n/* harmony import */ var _resolve_url_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./resolve-url.js */ \"./node_modules/@polymer/polymer/lib/utils/resolve-url.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Module with utilities for collection CSS text from `<templates>`, external\n * stylesheets, and `dom-module`s.\n *\n * @summary Module with utilities for collection CSS text from various sources.\n */\n\n\nconst MODULE_STYLE_LINK_SELECTOR = 'link[rel=import][type~=css]';\nconst INCLUDE_ATTR = 'include';\nconst SHADY_UNSCOPED_ATTR = 'shady-unscoped';\n/**\n * @param {string} moduleId .\n * @return {?DomModule} .\n */\n\nfunction importModule(moduleId) {\n  return (\n    /** @type {?DomModule} */\n    _elements_dom_module_js__WEBPACK_IMPORTED_MODULE_0__.DomModule.import(moduleId)\n  );\n}\n\nfunction styleForImport(importDoc) {\n  // NOTE: polyfill affordance.\n  // under the HTMLImports polyfill, there will be no 'body',\n  // but the import pseudo-doc can be used directly.\n  let container = importDoc.body ? importDoc.body : importDoc;\n  const importCss = (0,_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__.resolveCss)(container.textContent, importDoc.baseURI);\n  const style = document.createElement('style');\n  style.textContent = importCss;\n  return style;\n}\n/** @typedef {{assetpath: string}} */\n\n\nlet templateWithAssetPath; // eslint-disable-line no-unused-vars\n\n/**\n * Returns a list of <style> elements in a space-separated list of `dom-module`s.\n *\n * @function\n * @param {string} moduleIds List of dom-module id's within which to\n * search for css.\n * @return {!Array<!HTMLStyleElement>} Array of contained <style> elements\n */\n\nfunction stylesFromModules(moduleIds) {\n  const modules = moduleIds.trim().split(/\\s+/);\n  const styles = [];\n\n  for (let i = 0; i < modules.length; i++) {\n    styles.push(...stylesFromModule(modules[i]));\n  }\n\n  return styles;\n}\n/**\n * Returns a list of <style> elements in a given `dom-module`.\n * Styles in a `dom-module` can come either from `<style>`s within the\n * first `<template>`, or else from one or more\n * `<link rel=\"import\" type=\"css\">` links outside the template.\n *\n * @param {string} moduleId dom-module id to gather styles from\n * @return {!Array<!HTMLStyleElement>} Array of contained styles.\n */\n\nfunction stylesFromModule(moduleId) {\n  const m = importModule(moduleId);\n\n  if (!m) {\n    console.warn('Could not find style data in module named', moduleId);\n    return [];\n  }\n\n  if (m._styles === undefined) {\n    const styles = []; // module imports: <link rel=\"import\" type=\"css\">\n\n    styles.push(..._stylesFromModuleImports(m)); // include css from the first template in the module\n\n    const template =\n    /** @type {?HTMLTemplateElement} */\n    m.querySelector('template');\n\n    if (template) {\n      styles.push(...stylesFromTemplate(template,\n      /** @type {templateWithAssetPath} */\n      m.assetpath));\n    }\n\n    m._styles = styles;\n  }\n\n  return m._styles;\n}\n/**\n * Returns the `<style>` elements within a given template.\n *\n * @param {!HTMLTemplateElement} template Template to gather styles from\n * @param {string} baseURI baseURI for style content\n * @return {!Array<!HTMLStyleElement>} Array of styles\n */\n\nfunction stylesFromTemplate(template, baseURI) {\n  if (!template._styles) {\n    const styles = []; // if element is a template, get content from its .content\n\n    const e$ = template.content.querySelectorAll('style');\n\n    for (let i = 0; i < e$.length; i++) {\n      let e = e$[i]; // support style sharing by allowing styles to \"include\"\n      // other dom-modules that contain styling\n\n      let include = e.getAttribute(INCLUDE_ATTR);\n\n      if (include) {\n        styles.push(...stylesFromModules(include).filter(function (item, index, self) {\n          return self.indexOf(item) === index;\n        }));\n      }\n\n      if (baseURI) {\n        e.textContent = (0,_resolve_url_js__WEBPACK_IMPORTED_MODULE_1__.resolveCss)(e.textContent, baseURI);\n      }\n\n      styles.push(e);\n    }\n\n    template._styles = styles;\n  }\n\n  return template._styles;\n}\n/**\n * Returns a list of <style> elements  from stylesheets loaded via `<link rel=\"import\" type=\"css\">` links within the specified `dom-module`.\n *\n * @param {string} moduleId Id of `dom-module` to gather CSS from\n * @return {!Array<!HTMLStyleElement>} Array of contained styles.\n */\n\nfunction stylesFromModuleImports(moduleId) {\n  let m = importModule(moduleId);\n  return m ? _stylesFromModuleImports(m) : [];\n}\n/**\n * @param {!HTMLElement} module dom-module element that could contain `<link rel=\"import\" type=\"css\">` styles\n * @return {!Array<!HTMLStyleElement>} Array of contained styles\n */\n\nfunction _stylesFromModuleImports(module) {\n  const styles = [];\n  const p$ = module.querySelectorAll(MODULE_STYLE_LINK_SELECTOR);\n\n  for (let i = 0; i < p$.length; i++) {\n    let p = p$[i];\n\n    if (p.import) {\n      const importDoc = p.import;\n      const unscoped = p.hasAttribute(SHADY_UNSCOPED_ATTR);\n\n      if (unscoped && !importDoc._unscopedStyle) {\n        const style = styleForImport(importDoc);\n        style.setAttribute(SHADY_UNSCOPED_ATTR, '');\n        importDoc._unscopedStyle = style;\n      } else if (!importDoc._style) {\n        importDoc._style = styleForImport(importDoc);\n      }\n\n      styles.push(unscoped ? importDoc._unscopedStyle : importDoc._style);\n    }\n  }\n\n  return styles;\n}\n/**\n *\n * Returns CSS text of styles in a space-separated list of `dom-module`s.\n * Note: This method is deprecated, use `stylesFromModules` instead.\n *\n * @deprecated\n * @param {string} moduleIds List of dom-module id's within which to\n * search for css.\n * @return {string} Concatenated CSS content from specified `dom-module`s\n */\n\n\nfunction cssFromModules(moduleIds) {\n  let modules = moduleIds.trim().split(/\\s+/);\n  let cssText = '';\n\n  for (let i = 0; i < modules.length; i++) {\n    cssText += cssFromModule(modules[i]);\n  }\n\n  return cssText;\n}\n/**\n * Returns CSS text of styles in a given `dom-module`.  CSS in a `dom-module`\n * can come either from `<style>`s within the first `<template>`, or else\n * from one or more `<link rel=\"import\" type=\"css\">` links outside the\n * template.\n *\n * Any `<styles>` processed are removed from their original location.\n * Note: This method is deprecated, use `styleFromModule` instead.\n *\n * @deprecated\n * @param {string} moduleId dom-module id to gather styles from\n * @return {string} Concatenated CSS content from specified `dom-module`\n */\n\nfunction cssFromModule(moduleId) {\n  let m = importModule(moduleId);\n\n  if (m && m._cssText === undefined) {\n    // module imports: <link rel=\"import\" type=\"css\">\n    let cssText = _cssFromModuleImports(m); // include css from the first template in the module\n\n\n    let t =\n    /** @type {?HTMLTemplateElement} */\n    m.querySelector('template');\n\n    if (t) {\n      cssText += cssFromTemplate(t,\n      /** @type {templateWithAssetPath} */\n      m.assetpath);\n    }\n\n    m._cssText = cssText || null;\n  }\n\n  if (!m) {\n    console.warn('Could not find style data in module named', moduleId);\n  }\n\n  return m && m._cssText || '';\n}\n/**\n * Returns CSS text of `<styles>` within a given template.\n *\n * Any `<styles>` processed are removed from their original location.\n * Note: This method is deprecated, use `styleFromTemplate` instead.\n *\n * @deprecated\n * @param {!HTMLTemplateElement} template Template to gather styles from\n * @param {string} baseURI Base URI to resolve the URL against\n * @return {string} Concatenated CSS content from specified template\n */\n\nfunction cssFromTemplate(template, baseURI) {\n  let cssText = '';\n  const e$ = stylesFromTemplate(template, baseURI); // if element is a template, get content from its .content\n\n  for (let i = 0; i < e$.length; i++) {\n    let e = e$[i];\n\n    if (e.parentNode) {\n      e.parentNode.removeChild(e);\n    }\n\n    cssText += e.textContent;\n  }\n\n  return cssText;\n}\n/**\n * Returns CSS text from stylesheets loaded via `<link rel=\"import\" type=\"css\">`\n * links within the specified `dom-module`.\n *\n * Note: This method is deprecated, use `stylesFromModuleImports` instead.\n *\n * @deprecated\n *\n * @param {string} moduleId Id of `dom-module` to gather CSS from\n * @return {string} Concatenated CSS content from links in specified `dom-module`\n */\n\nfunction cssFromModuleImports(moduleId) {\n  let m = importModule(moduleId);\n  return m ? _cssFromModuleImports(m) : '';\n}\n/**\n * @deprecated\n * @param {!HTMLElement} module dom-module element that could contain `<link rel=\"import\" type=\"css\">` styles\n * @return {string} Concatenated CSS content from links in the dom-module\n */\n\nfunction _cssFromModuleImports(module) {\n  let cssText = '';\n\n  let styles = _stylesFromModuleImports(module);\n\n  for (let i = 0; i < styles.length; i++) {\n    cssText += styles[i].textContent;\n  }\n\n  return cssText;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/style-gather.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/templatize.js":
/*!***************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/templatize.js ***!
  \***************************************************************/
/*! namespace exports */
/*! export TemplateInstanceBase [provided] [no usage info] [missing usage info prevents renaming] */
/*! export modelForElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export templatize [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"templatize\": () => /* binding */ templatize,\n/* harmony export */   \"modelForElement\": () => /* binding */ modelForElement,\n/* harmony export */   \"TemplateInstanceBase\": () => /* binding */ TemplateInstanceBase\n/* harmony export */ });\n/* harmony import */ var _boot_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./boot.js */ \"./node_modules/@polymer/polymer/lib/utils/boot.js\");\n/* harmony import */ var _mixins_property_effects_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../mixins/property-effects.js */ \"./node_modules/@polymer/polymer/lib/mixins/property-effects.js\");\n/* harmony import */ var _mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../mixins/mutable-data.js */ \"./node_modules/@polymer/polymer/lib/mixins/mutable-data.js\");\n/* harmony import */ var _utils_settings_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../utils/settings.js */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Module for preparing and stamping instances of templates that utilize\n * Polymer's data-binding and declarative event listener features.\n *\n * Example:\n *\n *     // Get a template from somewhere, e.g. light DOM\n *     let template = this.querySelector('template');\n *     // Prepare the template\n *     let TemplateClass = Templatize.templatize(template);\n *     // Instance the template with an initial data model\n *     let instance = new TemplateClass({myProp: 'initial'});\n *     // Insert the instance's DOM somewhere, e.g. element's shadow DOM\n *     this.shadowRoot.appendChild(instance.root);\n *     // Changing a property on the instance will propagate to bindings\n *     // in the template\n *     instance.myProp = 'new value';\n *\n * The `options` dictionary passed to `templatize` allows for customizing\n * features of the generated template class, including how outer-scope host\n * properties should be forwarded into template instances, how any instance\n * properties added into the template's scope should be notified out to\n * the host, and whether the instance should be decorated as a \"parent model\"\n * of any event handlers.\n *\n *     // Customize property forwarding and event model decoration\n *     let TemplateClass = Templatize.templatize(template, this, {\n *       parentModel: true,\n *       forwardHostProp(property, value) {...},\n *       instanceProps: {...},\n *       notifyInstanceProp(instance, property, value) {...},\n *     });\n *\n * @summary Module for preparing and stamping instances of templates\n *   utilizing Polymer templating features.\n */\n\n\n\n // Base class for HTMLTemplateElement extension that has property effects\n// machinery for propagating host properties to children. This is an ES5\n// class only because Babel (incorrectly) requires super() in the class\n// constructor even though no `this` is used and it returns an instance.\n\nlet newInstance = null;\n/**\n * @constructor\n * @extends {HTMLTemplateElement}\n * @private\n */\n\nfunction HTMLTemplateElementExtension() {\n  return newInstance;\n}\n\nHTMLTemplateElementExtension.prototype = Object.create(HTMLTemplateElement.prototype, {\n  constructor: {\n    value: HTMLTemplateElementExtension,\n    writable: true\n  }\n});\n/**\n * @constructor\n * @implements {Polymer_PropertyEffects}\n * @extends {HTMLTemplateElementExtension}\n * @private\n */\n\nconst DataTemplate = (0,_mixins_property_effects_js__WEBPACK_IMPORTED_MODULE_1__.PropertyEffects)(HTMLTemplateElementExtension);\n/**\n * @constructor\n * @implements {Polymer_MutableData}\n * @extends {DataTemplate}\n * @private\n */\n\nconst MutableDataTemplate = (0,_mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_2__.MutableData)(DataTemplate); // Applies a DataTemplate subclass to a <template> instance\n\nfunction upgradeTemplate(template, constructor) {\n  newInstance = template;\n  Object.setPrototypeOf(template, constructor.prototype);\n  new constructor();\n  newInstance = null;\n}\n/**\n * Base class for TemplateInstance.\n * @constructor\n * @implements {Polymer_PropertyEffects}\n * @private\n */\n\n\nconst base = (0,_mixins_property_effects_js__WEBPACK_IMPORTED_MODULE_1__.PropertyEffects)(class {});\n/**\n * @polymer\n * @customElement\n * @appliesMixin PropertyEffects\n * @unrestricted\n */\n\nclass TemplateInstanceBase extends base {\n  constructor(props) {\n    super();\n\n    this._configureProperties(props);\n\n    this.root = this._stampTemplate(this.__dataHost); // Save list of stamped children\n\n    let children = this.children = [];\n\n    for (let n = this.root.firstChild; n; n = n.nextSibling) {\n      children.push(n);\n      n.__templatizeInstance = this;\n    }\n\n    if (this.__templatizeOwner && this.__templatizeOwner.__hideTemplateChildren__) {\n      this._showHideChildren(true);\n    } // Flush props only when props are passed if instance props exist\n    // or when there isn't instance props.\n\n\n    let options = this.__templatizeOptions;\n\n    if (props && options.instanceProps || !options.instanceProps) {\n      this._enableProperties();\n    }\n  }\n  /**\n   * Configure the given `props` by calling `_setPendingProperty`. Also\n   * sets any properties stored in `__hostProps`.\n   * @private\n   * @param {Object} props Object of property name-value pairs to set.\n   * @return {void}\n   */\n\n\n  _configureProperties(props) {\n    let options = this.__templatizeOptions;\n\n    if (options.forwardHostProp) {\n      for (let hprop in this.__hostProps) {\n        this._setPendingProperty(hprop, this.__dataHost['_host_' + hprop]);\n      }\n    } // Any instance props passed in the constructor will overwrite host props;\n    // normally this would be a user error but we don't specifically filter them\n\n\n    for (let iprop in props) {\n      this._setPendingProperty(iprop, props[iprop]);\n    }\n  }\n  /**\n   * Forwards a host property to this instance.  This method should be\n   * called on instances from the `options.forwardHostProp` callback\n   * to propagate changes of host properties to each instance.\n   *\n   * Note this method enqueues the change, which are flushed as a batch.\n   *\n   * @param {string} prop Property or path name\n   * @param {*} value Value of the property to forward\n   * @return {void}\n   */\n\n\n  forwardHostProp(prop, value) {\n    if (this._setPendingPropertyOrPath(prop, value, false, true)) {\n      this.__dataHost._enqueueClient(this);\n    }\n  }\n  /**\n   * Override point for adding custom or simulated event handling.\n   *\n   * @override\n   * @param {!Node} node Node to add event listener to\n   * @param {string} eventName Name of event\n   * @param {function(!Event):void} handler Listener function to add\n   * @return {void}\n   */\n\n\n  _addEventListenerToNode(node, eventName, handler) {\n    if (this._methodHost && this.__templatizeOptions.parentModel) {\n      // If this instance should be considered a parent model, decorate\n      // events this template instance as `model`\n      this._methodHost._addEventListenerToNode(node, eventName, e => {\n        e.model = this;\n        handler(e);\n      });\n    } else {\n      // Otherwise delegate to the template's host (which could be)\n      // another template instance\n      let templateHost = this.__dataHost.__dataHost;\n\n      if (templateHost) {\n        templateHost._addEventListenerToNode(node, eventName, handler);\n      }\n    }\n  }\n  /**\n   * Shows or hides the template instance top level child elements. For\n   * text nodes, `textContent` is removed while \"hidden\" and replaced when\n   * \"shown.\"\n   * @param {boolean} hide Set to true to hide the children;\n   * set to false to show them.\n   * @return {void}\n   * @protected\n   */\n\n\n  _showHideChildren(hide) {\n    let c = this.children;\n\n    for (let i = 0; i < c.length; i++) {\n      let n = c[i]; // Ignore non-changes\n\n      if (Boolean(hide) != Boolean(n.__hideTemplateChildren__)) {\n        if (n.nodeType === Node.TEXT_NODE) {\n          if (hide) {\n            n.__polymerTextContent__ = n.textContent;\n            n.textContent = '';\n          } else {\n            n.textContent = n.__polymerTextContent__;\n          } // remove and replace slot\n\n        } else if (n.localName === 'slot') {\n          if (hide) {\n            n.__polymerReplaced__ = document.createComment('hidden-slot');\n            n.parentNode.replaceChild(n.__polymerReplaced__, n);\n          } else {\n            const replace = n.__polymerReplaced__;\n\n            if (replace) {\n              replace.parentNode.replaceChild(n, replace);\n            }\n          }\n        } else if (n.style) {\n          if (hide) {\n            n.__polymerDisplay__ = n.style.display;\n            n.style.display = 'none';\n          } else {\n            n.style.display = n.__polymerDisplay__;\n          }\n        }\n      }\n\n      n.__hideTemplateChildren__ = hide;\n\n      if (n._showHideChildren) {\n        n._showHideChildren(hide);\n      }\n    }\n  }\n  /**\n   * Overrides default property-effects implementation to intercept\n   * textContent bindings while children are \"hidden\" and cache in\n   * private storage for later retrieval.\n   *\n   * @override\n   * @param {!Node} node The node to set a property on\n   * @param {string} prop The property to set\n   * @param {*} value The value to set\n   * @return {void}\n   * @protected\n   */\n\n\n  _setUnmanagedPropertyToNode(node, prop, value) {\n    if (node.__hideTemplateChildren__ && node.nodeType == Node.TEXT_NODE && prop == 'textContent') {\n      node.__polymerTextContent__ = value;\n    } else {\n      super._setUnmanagedPropertyToNode(node, prop, value);\n    }\n  }\n  /**\n   * Find the parent model of this template instance.  The parent model\n   * is either another templatize instance that had option `parentModel: true`,\n   * or else the host element.\n   *\n   * @return {!Polymer_PropertyEffects} The parent model of this instance\n   */\n\n\n  get parentModel() {\n    let model = this.__parentModel;\n\n    if (!model) {\n      let options;\n      model = this;\n\n      do {\n        // A template instance's `__dataHost` is a <template>\n        // `model.__dataHost.__dataHost` is the template's host\n        model = model.__dataHost.__dataHost;\n      } while ((options = model.__templatizeOptions) && !options.parentModel);\n\n      this.__parentModel = model;\n    }\n\n    return model;\n  }\n  /**\n   * Stub of HTMLElement's `dispatchEvent`, so that effects that may\n   * dispatch events safely no-op.\n   *\n   * @param {Event} event Event to dispatch\n   * @return {boolean} Always true.\n   */\n\n\n  dispatchEvent(event) {\n    // eslint-disable-line no-unused-vars\n    return true;\n  }\n\n}\n/** @type {!DataTemplate} */\n\n\nTemplateInstanceBase.prototype.__dataHost;\n/** @type {!TemplatizeOptions} */\n\nTemplateInstanceBase.prototype.__templatizeOptions;\n/** @type {!Polymer_PropertyEffects} */\n\nTemplateInstanceBase.prototype._methodHost;\n/** @type {!Object} */\n\nTemplateInstanceBase.prototype.__templatizeOwner;\n/** @type {!Object} */\n\nTemplateInstanceBase.prototype.__hostProps;\n/**\n * @constructor\n * @extends {TemplateInstanceBase}\n * @implements {Polymer_MutableData}\n * @private\n */\n\nconst MutableTemplateInstanceBase = (0,_mixins_mutable_data_js__WEBPACK_IMPORTED_MODULE_2__.MutableData)(TemplateInstanceBase);\n\nfunction findMethodHost(template) {\n  // Technically this should be the owner of the outermost template.\n  // In shadow dom, this is always getRootNode().host, but we can\n  // approximate this via cooperation with our dataHost always setting\n  // `_methodHost` as long as there were bindings (or id's) on this\n  // instance causing it to get a dataHost.\n  let templateHost = template.__dataHost;\n  return templateHost && templateHost._methodHost || templateHost;\n}\n/* eslint-disable valid-jsdoc */\n\n/**\n * @suppress {missingProperties} class.prototype is not defined for some reason\n */\n\n\nfunction createTemplatizerClass(template, templateInfo, options) {\n  // Anonymous class created by the templatize\n  let base = options.mutableData ? MutableTemplateInstanceBase : TemplateInstanceBase;\n  /**\n   * @constructor\n   * @extends {base}\n   * @private\n   */\n\n  let klass = class extends base {};\n  klass.prototype.__templatizeOptions = options;\n\n  klass.prototype._bindTemplate(template);\n\n  addNotifyEffects(klass, template, templateInfo, options);\n  return klass;\n}\n/**\n * @suppress {missingProperties} class.prototype is not defined for some reason\n */\n\n\nfunction addPropagateEffects(template, templateInfo, options) {\n  let userForwardHostProp = options.forwardHostProp;\n\n  if (userForwardHostProp) {\n    // Provide data API and property effects on memoized template class\n    let klass = templateInfo.templatizeTemplateClass;\n\n    if (!klass) {\n      let base = options.mutableData ? MutableDataTemplate : DataTemplate;\n      /** @private */\n\n      klass = templateInfo.templatizeTemplateClass = class TemplatizedTemplate extends base {}; // Add template - >instances effects\n      // and host <- template effects\n\n      let hostProps = templateInfo.hostProps;\n\n      for (let prop in hostProps) {\n        klass.prototype._addPropertyEffect('_host_' + prop, klass.prototype.PROPERTY_EFFECT_TYPES.PROPAGATE, {\n          fn: createForwardHostPropEffect(prop, userForwardHostProp)\n        });\n\n        klass.prototype._createNotifyingProperty('_host_' + prop);\n      }\n    }\n\n    upgradeTemplate(template, klass); // Mix any pre-bound data into __data; no need to flush this to\n    // instances since they pull from the template at instance-time\n\n    if (template.__dataProto) {\n      // Note, generally `__dataProto` could be chained, but it's guaranteed\n      // to not be since this is a vanilla template we just added effects to\n      Object.assign(template.__data, template.__dataProto);\n    } // Clear any pending data for performance\n\n\n    template.__dataTemp = {};\n    template.__dataPending = null;\n    template.__dataOld = null;\n\n    template._enableProperties();\n  }\n}\n/* eslint-enable valid-jsdoc */\n\n\nfunction createForwardHostPropEffect(hostProp, userForwardHostProp) {\n  return function forwardHostProp(template, prop, props) {\n    userForwardHostProp.call(template.__templatizeOwner, prop.substring('_host_'.length), props[prop]);\n  };\n}\n\nfunction addNotifyEffects(klass, template, templateInfo, options) {\n  let hostProps = templateInfo.hostProps || {};\n\n  for (let iprop in options.instanceProps) {\n    delete hostProps[iprop];\n    let userNotifyInstanceProp = options.notifyInstanceProp;\n\n    if (userNotifyInstanceProp) {\n      klass.prototype._addPropertyEffect(iprop, klass.prototype.PROPERTY_EFFECT_TYPES.NOTIFY, {\n        fn: createNotifyInstancePropEffect(iprop, userNotifyInstanceProp)\n      });\n    }\n  }\n\n  if (options.forwardHostProp && template.__dataHost) {\n    for (let hprop in hostProps) {\n      klass.prototype._addPropertyEffect(hprop, klass.prototype.PROPERTY_EFFECT_TYPES.NOTIFY, {\n        fn: createNotifyHostPropEffect()\n      });\n    }\n  }\n}\n\nfunction createNotifyInstancePropEffect(instProp, userNotifyInstanceProp) {\n  return function notifyInstanceProp(inst, prop, props) {\n    userNotifyInstanceProp.call(inst.__templatizeOwner, inst, prop, props[prop]);\n  };\n}\n\nfunction createNotifyHostPropEffect() {\n  return function notifyHostProp(inst, prop, props) {\n    inst.__dataHost._setPendingPropertyOrPath('_host_' + prop, props[prop], true, true);\n  };\n}\n/**\n * Returns an anonymous `PropertyEffects` class bound to the\n * `<template>` provided.  Instancing the class will result in the\n * template being stamped into a document fragment stored as the instance's\n * `root` property, after which it can be appended to the DOM.\n *\n * Templates may utilize all Polymer data-binding features as well as\n * declarative event listeners.  Event listeners and inline computing\n * functions in the template will be called on the host of the template.\n *\n * The constructor returned takes a single argument dictionary of initial\n * property values to propagate into template bindings.  Additionally\n * host properties can be forwarded in, and instance properties can be\n * notified out by providing optional callbacks in the `options` dictionary.\n *\n * Valid configuration in `options` are as follows:\n *\n * - `forwardHostProp(property, value)`: Called when a property referenced\n *   in the template changed on the template's host. As this library does\n *   not retain references to templates instanced by the user, it is the\n *   templatize owner's responsibility to forward host property changes into\n *   user-stamped instances.  The `instance.forwardHostProp(property, value)`\n *    method on the generated class should be called to forward host\n *   properties into the template to prevent unnecessary property-changed\n *   notifications. Any properties referenced in the template that are not\n *   defined in `instanceProps` will be notified up to the template's host\n *   automatically.\n * - `instanceProps`: Dictionary of property names that will be added\n *   to the instance by the templatize owner.  These properties shadow any\n *   host properties, and changes within the template to these properties\n *   will result in `notifyInstanceProp` being called.\n * - `mutableData`: When `true`, the generated class will skip strict\n *   dirty-checking for objects and arrays (always consider them to be\n *   \"dirty\").\n * - `notifyInstanceProp(instance, property, value)`: Called when\n *   an instance property changes.  Users may choose to call `notifyPath`\n *   on e.g. the owner to notify the change.\n * - `parentModel`: When `true`, events handled by declarative event listeners\n *   (`on-event=\"handler\"`) will be decorated with a `model` property pointing\n *   to the template instance that stamped it.  It will also be returned\n *   from `instance.parentModel` in cases where template instance nesting\n *   causes an inner model to shadow an outer model.\n *\n * All callbacks are called bound to the `owner`. Any context\n * needed for the callbacks (such as references to `instances` stamped)\n * should be stored on the `owner` such that they can be retrieved via\n * `this`.\n *\n * When `options.forwardHostProp` is declared as an option, any properties\n * referenced in the template will be automatically forwarded from the host of\n * the `<template>` to instances, with the exception of any properties listed in\n * the `options.instanceProps` object.  `instanceProps` are assumed to be\n * managed by the owner of the instances, either passed into the constructor\n * or set after the fact.  Note, any properties passed into the constructor will\n * always be set to the instance (regardless of whether they would normally\n * be forwarded from the host).\n *\n * Note that `templatize()` can be run only once for a given `<template>`.\n * Further calls will result in an error. Also, there is a special\n * behavior if the template was duplicated through a mechanism such as\n * `<dom-repeat>` or `<test-fixture>`. In this case, all calls to\n * `templatize()` return the same class for all duplicates of a template.\n * The class returned from `templatize()` is generated only once using\n * the `options` from the first call. This means that any `options`\n * provided to subsequent calls will be ignored. Therefore, it is very\n * important not to close over any variables inside the callbacks. Also,\n * arrow functions must be avoided because they bind the outer `this`.\n * Inside the callbacks, any contextual information can be accessed\n * through `this`, which points to the `owner`.\n *\n * @param {!HTMLTemplateElement} template Template to templatize\n * @param {Polymer_PropertyEffects=} owner Owner of the template instances;\n *   any optional callbacks will be bound to this owner.\n * @param {Object=} options Options dictionary (see summary for details)\n * @return {function(new:TemplateInstanceBase)} Generated class bound to the template\n *   provided\n * @suppress {invalidCasts}\n */\n\n\nfunction templatize(template, owner, options) {\n  // Under strictTemplatePolicy, the templatized element must be owned\n  // by a (trusted) Polymer element, indicated by existence of _methodHost;\n  // e.g. for dom-if & dom-repeat in main document, _methodHost is null\n  if (_utils_settings_js__WEBPACK_IMPORTED_MODULE_3__.strictTemplatePolicy && !findMethodHost(template)) {\n    throw new Error('strictTemplatePolicy: template owner not trusted');\n  }\n\n  options =\n  /** @type {!TemplatizeOptions} */\n  options || {};\n\n  if (template.__templatizeOwner) {\n    throw new Error('A <template> can only be templatized once');\n  }\n\n  template.__templatizeOwner = owner;\n  const ctor = owner ? owner.constructor : TemplateInstanceBase;\n\n  let templateInfo = ctor._parseTemplate(template); // Get memoized base class for the prototypical template, which\n  // includes property effects for binding template & forwarding\n\n\n  let baseClass = templateInfo.templatizeInstanceClass;\n\n  if (!baseClass) {\n    baseClass = createTemplatizerClass(template, templateInfo, options);\n    templateInfo.templatizeInstanceClass = baseClass;\n  } // Host property forwarding must be installed onto template instance\n\n\n  addPropagateEffects(template, templateInfo, options); // Subclass base class and add reference for this specific template\n\n  /** @private */\n\n  let klass = class TemplateInstance extends baseClass {};\n  klass.prototype._methodHost = findMethodHost(template);\n  klass.prototype.__dataHost = template;\n  klass.prototype.__templatizeOwner = owner;\n  klass.prototype.__hostProps = templateInfo.hostProps;\n  klass =\n  /** @type {function(new:TemplateInstanceBase)} */\n  klass; //eslint-disable-line no-self-assign\n\n  return klass;\n}\n/**\n * Returns the template \"model\" associated with a given element, which\n * serves as the binding scope for the template instance the element is\n * contained in. A template model is an instance of\n * `TemplateInstanceBase`, and should be used to manipulate data\n * associated with this template instance.\n *\n * Example:\n *\n *   let model = modelForElement(el);\n *   if (model.index < 10) {\n *     model.set('item.checked', true);\n *   }\n *\n * @param {HTMLTemplateElement} template The model will be returned for\n *   elements stamped from this template\n * @param {Node=} node Node for which to return a template model.\n * @return {TemplateInstanceBase} Template instance representing the\n *   binding scope for the element\n */\n\nfunction modelForElement(template, node) {\n  let model;\n\n  while (node) {\n    // An element with a __templatizeInstance marks the top boundary\n    // of a scope; walk up until we find one, and then ensure that\n    // its __dataHost matches `this`, meaning this dom-repeat stamped it\n    if (model = node.__templatizeInstance) {\n      // Found an element stamped by another template; keep walking up\n      // from its __dataHost\n      if (model.__dataHost != template) {\n        node = model.__dataHost;\n      } else {\n        return model;\n      }\n    } else {\n      // Still in a template scope, keep going up until\n      // a __templatizeInstance is found\n      node = node.parentNode;\n    }\n  }\n\n  return null;\n}\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/templatize.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/lib/utils/unresolved.js":
/*!***************************************************************!*\
  !*** ./node_modules/@polymer/polymer/lib/utils/unresolved.js ***!
  \***************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\nfunction resolve() {\n  document.body.removeAttribute('unresolved');\n}\n\nif (document.readyState === 'interactive' || document.readyState === 'complete') {\n  resolve();\n} else {\n  window.addEventListener('DOMContentLoaded', resolve);\n}\n\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQHBvbHltZXIvcG9seW1lci9saWIvdXRpbHMvdW5yZXNvbHZlZC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vbm9kZV9tb2R1bGVzL0Bwb2x5bWVyL3BvbHltZXIvbGliL3V0aWxzL3VucmVzb2x2ZWQuanM/ZDExYSJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgKGMpIDIwMTcgVGhlIFBvbHltZXIgUHJvamVjdCBBdXRob3JzLiBBbGwgcmlnaHRzIHJlc2VydmVkLlxuVGhpcyBjb2RlIG1heSBvbmx5IGJlIHVzZWQgdW5kZXIgdGhlIEJTRCBzdHlsZSBsaWNlbnNlIGZvdW5kIGF0IGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9MSUNFTlNFLnR4dFxuVGhlIGNvbXBsZXRlIHNldCBvZiBhdXRob3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQVVUSE9SUy50eHRcblRoZSBjb21wbGV0ZSBzZXQgb2YgY29udHJpYnV0b3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQ09OVFJJQlVUT1JTLnR4dFxuQ29kZSBkaXN0cmlidXRlZCBieSBHb29nbGUgYXMgcGFydCBvZiB0aGUgcG9seW1lciBwcm9qZWN0IGlzIGFsc29cbnN1YmplY3QgdG8gYW4gYWRkaXRpb25hbCBJUCByaWdodHMgZ3JhbnQgZm91bmQgYXQgaHR0cDovL3BvbHltZXIuZ2l0aHViLmlvL1BBVEVOVFMudHh0XG4qL1xuXG5mdW5jdGlvbiByZXNvbHZlKCkge1xuICBkb2N1bWVudC5ib2R5LnJlbW92ZUF0dHJpYnV0ZSgndW5yZXNvbHZlZCcpO1xufVxuXG5pZiAoZG9jdW1lbnQucmVhZHlTdGF0ZSA9PT0gJ2ludGVyYWN0aXZlJyB8fCBkb2N1bWVudC5yZWFkeVN0YXRlID09PSAnY29tcGxldGUnKSB7XG4gIHJlc29sdmUoKTtcbn0gZWxzZSB7XG4gIHdpbmRvdy5hZGRFdmVudExpc3RlbmVyKCdET01Db250ZW50TG9hZGVkJywgcmVzb2x2ZSk7XG59XG5cbmV4cG9ydCB7fTtcbiJdLCJtYXBwaW5ncyI6IjtBQUFBOzs7Ozs7Ozs7QUFVQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTsiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/lib/utils/unresolved.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/polymer-element.js":
/*!**********************************************************!*\
  !*** ./node_modules/@polymer/polymer/polymer-element.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export PolymerElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/utils/html-tag.js .html */
/*! export version [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/mixins/element-mixin.js .version */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"html\": () => /* reexport safe */ _lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__.html,\n/* harmony export */   \"version\": () => /* reexport safe */ _lib_mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__.version,\n/* harmony export */   \"PolymerElement\": () => /* binding */ PolymerElement\n/* harmony export */ });\n/* harmony import */ var _lib_mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./lib/mixins/element-mixin.js */ \"./node_modules/@polymer/polymer/lib/mixins/element-mixin.js\");\n/* harmony import */ var _lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * Base class that provides the core API for Polymer's meta-programming\n * features including template stamping, data-binding, attribute deserialization,\n * and property change observation.\n *\n * @customElement\n * @polymer\n * @constructor\n * @implements {Polymer_ElementMixin}\n * @extends HTMLElement\n * @appliesMixin ElementMixin\n * @summary Custom element base class that provides the core API for Polymer's\n *   key meta-programming features including template stamping, data-binding,\n *   attribute deserialization, and property change observation\n */\n\nconst PolymerElement = (0,_lib_mixins_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__.ElementMixin)(HTMLElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/polymer-element.js\n");

/***/ }),

/***/ "./node_modules/@polymer/polymer/polymer-legacy.js":
/*!*********************************************************!*\
  !*** ./node_modules/@polymer/polymer/polymer-legacy.js ***!
  \*********************************************************/
/*! namespace exports */
/*! export Base [provided] [no usage info] [missing usage info prevents renaming] */
/*! export Polymer [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js .Polymer */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/@polymer/polymer/lib/utils/html-tag.js .html */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"Polymer\": () => /* reexport safe */ _lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__.Polymer,\n/* harmony export */   \"html\": () => /* reexport safe */ _lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_9__.html,\n/* harmony export */   \"Base\": () => /* binding */ Base\n/* harmony export */ });\n/* harmony import */ var _lib_legacy_legacy_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./lib/legacy/legacy-element-mixin.js */ \"./node_modules/@polymer/polymer/lib/legacy/legacy-element-mixin.js\");\n/* harmony import */ var _lib_legacy_polymer_fn_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./lib/legacy/polymer-fn.js */ \"./node_modules/@polymer/polymer/lib/legacy/polymer-fn.js\");\n/* harmony import */ var _lib_legacy_templatizer_behavior_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lib/legacy/templatizer-behavior.js */ \"./node_modules/@polymer/polymer/lib/legacy/templatizer-behavior.js\");\n/* harmony import */ var _lib_elements_dom_bind_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./lib/elements/dom-bind.js */ \"./node_modules/@polymer/polymer/lib/elements/dom-bind.js\");\n/* harmony import */ var _lib_elements_dom_repeat_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./lib/elements/dom-repeat.js */ \"./node_modules/@polymer/polymer/lib/elements/dom-repeat.js\");\n/* harmony import */ var _lib_elements_dom_if_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./lib/elements/dom-if.js */ \"./node_modules/@polymer/polymer/lib/elements/dom-if.js\");\n/* harmony import */ var _lib_elements_array_selector_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./lib/elements/array-selector.js */ \"./node_modules/@polymer/polymer/lib/elements/array-selector.js\");\n/* harmony import */ var _lib_elements_custom_style_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./lib/elements/custom-style.js */ \"./node_modules/@polymer/polymer/lib/elements/custom-style.js\");\n/* harmony import */ var _lib_legacy_mutable_data_behavior_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./lib/legacy/mutable-data-behavior.js */ \"./node_modules/@polymer/polymer/lib/legacy/mutable-data-behavior.js\");\n/* harmony import */ var _lib_utils_html_tag_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./lib/utils/html-tag.js */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n/* template elements */\n\n\n\n\n\n\n/* custom-style */\n\n\n/* bc behaviors */\n\n\n/* import html-tag to export html */\n\n // bc\n\nconst Base = (0,_lib_legacy_legacy_element_mixin_js__WEBPACK_IMPORTED_MODULE_0__.LegacyElementMixin)(HTMLElement).prototype;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@polymer/polymer/polymer-legacy.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/entrypoints/apply-shim.js":
/*!************************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/entrypoints/apply-shim.js ***!
  \************************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _src_apply_shim_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../src/apply-shim.js */ \"./node_modules/@webcomponents/shadycss/src/apply-shim.js\");\n/* harmony import */ var _src_template_map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../src/template-map.js */ \"./node_modules/@webcomponents/shadycss/src/template-map.js\");\n/* harmony import */ var _src_style_util_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../src/style-util.js */ \"./node_modules/@webcomponents/shadycss/src/style-util.js\");\n/* harmony import */ var _src_apply_shim_utils_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../src/apply-shim-utils.js */ \"./node_modules/@webcomponents/shadycss/src/apply-shim-utils.js\");\n/* harmony import */ var _src_common_utils_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../src/common-utils.js */ \"./node_modules/@webcomponents/shadycss/src/common-utils.js\");\n/* harmony import */ var _src_custom_style_interface_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../src/custom-style-interface.js */ \"./node_modules/@webcomponents/shadycss/src/custom-style-interface.js\");\n/* harmony import */ var _src_style_settings_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../src/style-settings.js */ \"./node_modules/@webcomponents/shadycss/src/style-settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\n\n\n // eslint-disable-line no-unused-vars\n\n\n/** @const {ApplyShim} */\n\nconst applyShim = new _src_apply_shim_js__WEBPACK_IMPORTED_MODULE_0__.default();\n\nclass ApplyShimInterface {\n  constructor() {\n    /** @type {?CustomStyleInterfaceInterface} */\n    this.customStyleInterface = null;\n    applyShim['invalidCallback'] = _src_apply_shim_utils_js__WEBPACK_IMPORTED_MODULE_3__.invalidate;\n  }\n\n  ensure() {\n    if (this.customStyleInterface) {\n      return;\n    }\n\n    if (window.ShadyCSS.CustomStyleInterface) {\n      this.customStyleInterface =\n      /** @type {!CustomStyleInterfaceInterface} */\n      window.ShadyCSS.CustomStyleInterface;\n\n      this.customStyleInterface['transformCallback'] = style => {\n        applyShim.transformCustomStyle(style);\n      };\n\n      this.customStyleInterface['validateCallback'] = () => {\n        requestAnimationFrame(() => {\n          if (this.customStyleInterface['enqueued']) {\n            this.flushCustomStyles();\n          }\n        });\n      };\n    }\n  }\n  /**\n   * @param {!HTMLTemplateElement} template\n   * @param {string} elementName\n   */\n\n\n  prepareTemplate(template, elementName) {\n    this.ensure();\n\n    if ((0,_src_style_util_js__WEBPACK_IMPORTED_MODULE_2__.elementHasBuiltCss)(template)) {\n      return;\n    }\n\n    _src_template_map_js__WEBPACK_IMPORTED_MODULE_1__.default[elementName] = template;\n    let ast = applyShim.transformTemplate(template, elementName); // save original style ast to use for revalidating instances\n\n    template['_styleAst'] = ast;\n  }\n\n  flushCustomStyles() {\n    this.ensure();\n\n    if (!this.customStyleInterface) {\n      return;\n    }\n\n    let styles = this.customStyleInterface['processStyles']();\n\n    if (!this.customStyleInterface['enqueued']) {\n      return;\n    }\n\n    for (let i = 0; i < styles.length; i++) {\n      let cs = styles[i];\n      let style = this.customStyleInterface['getStyleForCustomStyle'](cs);\n\n      if (style) {\n        applyShim.transformCustomStyle(style);\n      }\n    }\n\n    this.customStyleInterface['enqueued'] = false;\n  }\n  /**\n   * @param {HTMLElement} element\n   * @param {Object=} properties\n   */\n\n\n  styleSubtree(element, properties) {\n    this.ensure();\n\n    if (properties) {\n      (0,_src_common_utils_js__WEBPACK_IMPORTED_MODULE_4__.updateNativeProperties)(element, properties);\n    }\n\n    if (element.shadowRoot) {\n      this.styleElement(element);\n      let shadowChildren =\n      /** @type {!ParentNode} */\n      element.shadowRoot.children || element.shadowRoot.childNodes;\n\n      for (let i = 0; i < shadowChildren.length; i++) {\n        this.styleSubtree(\n        /** @type {HTMLElement} */\n        shadowChildren[i]);\n      }\n    } else {\n      let children = element.children || element.childNodes;\n\n      for (let i = 0; i < children.length; i++) {\n        this.styleSubtree(\n        /** @type {HTMLElement} */\n        children[i]);\n      }\n    }\n  }\n  /**\n   * @param {HTMLElement} element\n   */\n\n\n  styleElement(element) {\n    this.ensure();\n    let {\n      is\n    } = (0,_src_style_util_js__WEBPACK_IMPORTED_MODULE_2__.getIsExtends)(element);\n    let template = _src_template_map_js__WEBPACK_IMPORTED_MODULE_1__.default[is];\n\n    if (template && (0,_src_style_util_js__WEBPACK_IMPORTED_MODULE_2__.elementHasBuiltCss)(template)) {\n      return;\n    }\n\n    if (template && !_src_apply_shim_utils_js__WEBPACK_IMPORTED_MODULE_3__.templateIsValid(template)) {\n      // only revalidate template once\n      if (!_src_apply_shim_utils_js__WEBPACK_IMPORTED_MODULE_3__.templateIsValidating(template)) {\n        this.prepareTemplate(template, is);\n        _src_apply_shim_utils_js__WEBPACK_IMPORTED_MODULE_3__.startValidatingTemplate(template);\n      } // update this element instance\n\n\n      let root = element.shadowRoot;\n\n      if (root) {\n        let style =\n        /** @type {HTMLStyleElement} */\n        root.querySelector('style');\n\n        if (style) {\n          // reuse the template's style ast, it has all the original css text\n          style['__cssRules'] = template['_styleAst'];\n          style.textContent = (0,_src_style_util_js__WEBPACK_IMPORTED_MODULE_2__.toCssText)(template['_styleAst']);\n        }\n      }\n    }\n  }\n  /**\n   * @param {Object=} properties\n   */\n\n\n  styleDocument(properties) {\n    this.ensure();\n    this.styleSubtree(document.body, properties);\n  }\n\n}\n\nif (!window.ShadyCSS || !window.ShadyCSS.ScopingShim) {\n  const applyShimInterface = new ApplyShimInterface();\n  let CustomStyleInterface = window.ShadyCSS && window.ShadyCSS.CustomStyleInterface;\n  /** @suppress {duplicate} */\n\n  window.ShadyCSS = {\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     * @param {string=} elementExtends\n     */\n    prepareTemplate(template, elementName, elementExtends) {\n      // eslint-disable-line no-unused-vars\n      applyShimInterface.flushCustomStyles();\n      applyShimInterface.prepareTemplate(template, elementName);\n    },\n\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     * @param {string=} elementExtends\n     */\n    prepareTemplateStyles(template, elementName, elementExtends) {\n      window.ShadyCSS.prepareTemplate(template, elementName, elementExtends);\n    },\n\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     */\n    prepareTemplateDom(template, elementName) {},\n\n    // eslint-disable-line no-unused-vars\n\n    /**\n     * @param {!HTMLElement} element\n     * @param {Object=} properties\n     */\n    styleSubtree(element, properties) {\n      applyShimInterface.flushCustomStyles();\n      applyShimInterface.styleSubtree(element, properties);\n    },\n\n    /**\n     * @param {!HTMLElement} element\n     */\n    styleElement(element) {\n      applyShimInterface.flushCustomStyles();\n      applyShimInterface.styleElement(element);\n    },\n\n    /**\n     * @param {Object=} properties\n     */\n    styleDocument(properties) {\n      applyShimInterface.flushCustomStyles();\n      applyShimInterface.styleDocument(properties);\n    },\n\n    /**\n     * @param {Element} element\n     * @param {string} property\n     * @return {string}\n     */\n    getComputedStyleValue(element, property) {\n      return (0,_src_common_utils_js__WEBPACK_IMPORTED_MODULE_4__.getComputedStyleValue)(element, property);\n    },\n\n    flushCustomStyles() {\n      applyShimInterface.flushCustomStyles();\n    },\n\n    nativeCss: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_6__.nativeCssVariables,\n    nativeShadow: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_6__.nativeShadow,\n    cssBuild: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_6__.cssBuild,\n    disableRuntime: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_6__.disableRuntime\n  };\n\n  if (CustomStyleInterface) {\n    window.ShadyCSS.CustomStyleInterface = CustomStyleInterface;\n  }\n}\n\nwindow.ShadyCSS.ApplyShim = applyShim;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/entrypoints/apply-shim.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/entrypoints/custom-style-interface.js":
/*!************************************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/entrypoints/custom-style-interface.js ***!
  \************************************************************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _src_custom_style_interface_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../src/custom-style-interface.js */ \"./node_modules/@webcomponents/shadycss/src/custom-style-interface.js\");\n/* harmony import */ var _src_common_utils_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../src/common-utils.js */ \"./node_modules/@webcomponents/shadycss/src/common-utils.js\");\n/* harmony import */ var _src_style_settings_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../src/style-settings.js */ \"./node_modules/@webcomponents/shadycss/src/style-settings.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n\n\nconst customStyleInterface = new _src_custom_style_interface_js__WEBPACK_IMPORTED_MODULE_0__.default();\n\nif (!window.ShadyCSS) {\n  window.ShadyCSS = {\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     * @param {string=} elementExtends\n     */\n    prepareTemplate(template, elementName, elementExtends) {},\n\n    // eslint-disable-line no-unused-vars\n\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     */\n    prepareTemplateDom(template, elementName) {},\n\n    // eslint-disable-line no-unused-vars\n\n    /**\n     * @param {!HTMLTemplateElement} template\n     * @param {string} elementName\n     * @param {string=} elementExtends\n     */\n    prepareTemplateStyles(template, elementName, elementExtends) {},\n\n    // eslint-disable-line no-unused-vars\n\n    /**\n     * @param {Element} element\n     * @param {Object=} properties\n     */\n    styleSubtree(element, properties) {\n      customStyleInterface.processStyles();\n      (0,_src_common_utils_js__WEBPACK_IMPORTED_MODULE_1__.updateNativeProperties)(element, properties);\n    },\n\n    /**\n     * @param {Element} element\n     */\n    styleElement(element) {\n      // eslint-disable-line no-unused-vars\n      customStyleInterface.processStyles();\n    },\n\n    /**\n     * @param {Object=} properties\n     */\n    styleDocument(properties) {\n      customStyleInterface.processStyles();\n      (0,_src_common_utils_js__WEBPACK_IMPORTED_MODULE_1__.updateNativeProperties)(document.body, properties);\n    },\n\n    /**\n     * @param {Element} element\n     * @param {string} property\n     * @return {string}\n     */\n    getComputedStyleValue(element, property) {\n      return (0,_src_common_utils_js__WEBPACK_IMPORTED_MODULE_1__.getComputedStyleValue)(element, property);\n    },\n\n    flushCustomStyles() {},\n\n    nativeCss: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_2__.nativeCssVariables,\n    nativeShadow: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_2__.nativeShadow,\n    cssBuild: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_2__.cssBuild,\n    disableRuntime: _src_style_settings_js__WEBPACK_IMPORTED_MODULE_2__.disableRuntime\n  };\n}\n\nwindow.ShadyCSS.CustomStyleInterface = customStyleInterface;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/entrypoints/custom-style-interface.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/apply-shim-utils.js":
/*!**********************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/apply-shim-utils.js ***!
  \**********************************************************************/
/*! namespace exports */
/*! export elementsAreInvalid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export invalidate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export invalidateTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isValid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isValidating [provided] [no usage info] [missing usage info prevents renaming] */
/*! export startValidating [provided] [no usage info] [missing usage info prevents renaming] */
/*! export startValidatingTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export templateIsValid [provided] [no usage info] [missing usage info prevents renaming] */
/*! export templateIsValidating [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"invalidate\": () => /* binding */ invalidate,\n/* harmony export */   \"invalidateTemplate\": () => /* binding */ invalidateTemplate,\n/* harmony export */   \"isValid\": () => /* binding */ isValid,\n/* harmony export */   \"templateIsValid\": () => /* binding */ templateIsValid,\n/* harmony export */   \"isValidating\": () => /* binding */ isValidating,\n/* harmony export */   \"templateIsValidating\": () => /* binding */ templateIsValidating,\n/* harmony export */   \"startValidating\": () => /* binding */ startValidating,\n/* harmony export */   \"startValidatingTemplate\": () => /* binding */ startValidatingTemplate,\n/* harmony export */   \"elementsAreInvalid\": () => /* binding */ elementsAreInvalid\n/* harmony export */ });\n/* harmony import */ var _template_map_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./template-map.js */ \"./node_modules/@webcomponents/shadycss/src/template-map.js\");\n/* harmony import */ var _css_parse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./css-parse.js */ \"./node_modules/@webcomponents/shadycss/src/css-parse.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n // eslint-disable-line no-unused-vars\n\n/*\n * Utilities for handling invalidating apply-shim mixins for a given template.\n *\n * The invalidation strategy involves keeping track of the \"current\" version of a template's mixins, and updating that count when a mixin is invalidated.\n * The template\n */\n\n/** @const {string} */\n\nconst CURRENT_VERSION = '_applyShimCurrentVersion';\n/** @const {string} */\n\nconst NEXT_VERSION = '_applyShimNextVersion';\n/** @const {string} */\n\nconst VALIDATING_VERSION = '_applyShimValidatingVersion';\n/**\n * @const {Promise<void>}\n */\n\nconst promise = Promise.resolve();\n/**\n * @param {string} elementName\n */\n\nfunction invalidate(elementName) {\n  let template = _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default[elementName];\n\n  if (template) {\n    invalidateTemplate(template);\n  }\n}\n/**\n * This function can be called multiple times to mark a template invalid\n * and signal that the style inside must be regenerated.\n *\n * Use `startValidatingTemplate` to begin an asynchronous validation cycle.\n * During that cycle, call `templateIsValidating` to see if the template must\n * be revalidated\n * @param {HTMLTemplateElement} template\n */\n\nfunction invalidateTemplate(template) {\n  // default the current version to 0\n  template[CURRENT_VERSION] = template[CURRENT_VERSION] || 0; // ensure the \"validating for\" flag exists\n\n  template[VALIDATING_VERSION] = template[VALIDATING_VERSION] || 0; // increment the next version\n\n  template[NEXT_VERSION] = (template[NEXT_VERSION] || 0) + 1;\n}\n/**\n * @param {string} elementName\n * @return {boolean}\n */\n\nfunction isValid(elementName) {\n  let template = _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default[elementName];\n\n  if (template) {\n    return templateIsValid(template);\n  }\n\n  return true;\n}\n/**\n * @param {HTMLTemplateElement} template\n * @return {boolean}\n */\n\nfunction templateIsValid(template) {\n  return template[CURRENT_VERSION] === template[NEXT_VERSION];\n}\n/**\n * @param {string} elementName\n * @return {boolean}\n */\n\nfunction isValidating(elementName) {\n  let template = _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default[elementName];\n\n  if (template) {\n    return templateIsValidating(template);\n  }\n\n  return false;\n}\n/**\n * Returns true if the template is currently invalid and `startValidating` has been called since the last invalidation.\n * If false, the template must be validated.\n * @param {HTMLTemplateElement} template\n * @return {boolean}\n */\n\nfunction templateIsValidating(template) {\n  return !templateIsValid(template) && template[VALIDATING_VERSION] === template[NEXT_VERSION];\n}\n/**\n * the template is marked as `validating` for one microtask so that all instances\n * found in the tree crawl of `applyStyle` will update themselves,\n * but the template will only be updated once.\n * @param {string} elementName\n*/\n\nfunction startValidating(elementName) {\n  let template = _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default[elementName];\n  startValidatingTemplate(template);\n}\n/**\n * Begin an asynchronous invalidation cycle.\n * This should be called after every validation of a template\n *\n * After one microtask, the template will be marked as valid until the next call to `invalidateTemplate`\n * @param {HTMLTemplateElement} template\n */\n\nfunction startValidatingTemplate(template) {\n  // remember that the current \"next version\" is the reason for this validation cycle\n  template[VALIDATING_VERSION] = template[NEXT_VERSION]; // however, there only needs to be one async task to clear the counters\n\n  if (!template._validating) {\n    template._validating = true;\n    promise.then(function () {\n      // sync the current version to let future invalidations cause a refresh cycle\n      template[CURRENT_VERSION] = template[NEXT_VERSION];\n      template._validating = false;\n    });\n  }\n}\n/**\n * @return {boolean}\n */\n\nfunction elementsAreInvalid() {\n  for (let elementName in _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default) {\n    let template = _template_map_js__WEBPACK_IMPORTED_MODULE_0__.default[elementName];\n\n    if (!templateIsValid(template)) {\n      return true;\n    }\n  }\n\n  return false;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/apply-shim-utils.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/apply-shim.js":
/*!****************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/apply-shim.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _style_util_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./style-util.js */ \"./node_modules/@webcomponents/shadycss/src/style-util.js\");\n/* harmony import */ var _common_regex_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./common-regex.js */ \"./node_modules/@webcomponents/shadycss/src/common-regex.js\");\n/* harmony import */ var _common_utils_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./common-utils.js */ \"./node_modules/@webcomponents/shadycss/src/common-utils.js\");\n/* harmony import */ var _css_parse_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./css-parse.js */ \"./node_modules/@webcomponents/shadycss/src/css-parse.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/*\n * The apply shim simulates the behavior of `@apply` proposed at\n * https://tabatkins.github.io/specs/css-apply-rule/.\n * The approach is to convert a property like this:\n *\n *    --foo: {color: red; background: blue;}\n *\n * to this:\n *\n *    --foo_-_color: red;\n *    --foo_-_background: blue;\n *\n * Then where `@apply --foo` is used, that is converted to:\n *\n *    color: var(--foo_-_color);\n *    background: var(--foo_-_background);\n *\n * This approach generally works but there are some issues and limitations.\n * Consider, for example, that somewhere *between* where `--foo` is set and used,\n * another element sets it to:\n *\n *    --foo: { border: 2px solid red; }\n *\n * We must now ensure that the color and background from the previous setting\n * do not apply. This is accomplished by changing the property set to this:\n *\n *    --foo_-_border: 2px solid red;\n *    --foo_-_color: initial;\n *    --foo_-_background: initial;\n *\n * This works but introduces one new issue.\n * Consider this setup at the point where the `@apply` is used:\n *\n *    background: orange;\n *    `@apply` --foo;\n *\n * In this case the background will be unset (initial) rather than the desired\n * `orange`. We address this by altering the property set to use a fallback\n * value like this:\n *\n *    color: var(--foo_-_color);\n *    background: var(--foo_-_background, orange);\n *    border: var(--foo_-_border);\n *\n * Note that the default is retained in the property set and the `background` is\n * the desired `orange`. This leads us to a limitation.\n *\n * Limitation 1:\n\n * Only properties in the rule where the `@apply`\n * is used are considered as default values.\n * If another rule matches the element and sets `background` with\n * less specificity than the rule in which `@apply` appears,\n * the `background` will not be set.\n *\n * Limitation 2:\n *\n * When using Polymer's `updateStyles` api, new properties may not be set for\n * `@apply` properties.\n\n*/\n\n\n\n\n\n // eslint-disable-line no-unused-vars\n\nconst APPLY_NAME_CLEAN = /;\\s*/m;\nconst INITIAL_INHERIT = /^\\s*(initial)|(inherit)\\s*$/;\nconst IMPORTANT = /\\s*!important/; // separator used between mixin-name and mixin-property-name when producing properties\n// NOTE: plain '-' may cause collisions in user styles\n\nconst MIXIN_VAR_SEP = '_-_';\n/**\n * @typedef {!Object<string, string>}\n */\n\nlet PropertyEntry; // eslint-disable-line no-unused-vars\n\n/**\n * @typedef {!Object<string, boolean>}\n */\n\nlet DependantsEntry; // eslint-disable-line no-unused-vars\n\n/** @typedef {{\n *    properties: PropertyEntry,\n *    dependants: DependantsEntry\n * }}\n */\n\nlet MixinMapEntry; // eslint-disable-line no-unused-vars\n// map of mixin to property names\n// --foo: {border: 2px} -> {properties: {(--foo, ['border'])}, dependants: {'element-name': proto}}\n\nclass MixinMap {\n  constructor() {\n    /** @type {!Object<string, !MixinMapEntry>} */\n    this._map = {};\n  }\n  /**\n   * @param {string} name\n   * @param {!PropertyEntry} props\n   */\n\n\n  set(name, props) {\n    name = name.trim();\n    this._map[name] = {\n      properties: props,\n      dependants: {}\n    };\n  }\n  /**\n   * @param {string} name\n   * @return {MixinMapEntry}\n   */\n\n\n  get(name) {\n    name = name.trim();\n    return this._map[name] || null;\n  }\n\n}\n/**\n * Callback for when an element is marked invalid\n * @type {?function(string)}\n */\n\n\nlet invalidCallback = null;\n/** @unrestricted */\n\nclass ApplyShim {\n  constructor() {\n    /** @type {?string} */\n    this._currentElement = null;\n    /** @type {HTMLMetaElement} */\n\n    this._measureElement = null;\n    this._map = new MixinMap();\n  }\n  /**\n   * return true if `cssText` contains a mixin definition or consumption\n   * @param {string} cssText\n   * @return {boolean}\n   */\n\n\n  detectMixin(cssText) {\n    return (0,_common_utils_js__WEBPACK_IMPORTED_MODULE_1__.detectMixin)(cssText);\n  }\n  /**\n   * Gather styles into one style for easier processing\n   * @param {!HTMLTemplateElement} template\n   * @return {HTMLStyleElement}\n   */\n\n\n  gatherStyles(template) {\n    const styleText = (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.gatherStyleText)(template.content);\n\n    if (styleText) {\n      const style =\n      /** @type {!HTMLStyleElement} */\n      document.createElement('style');\n      style.textContent = styleText;\n      template.content.insertBefore(style, template.content.firstChild);\n      return style;\n    }\n\n    return null;\n  }\n  /**\n   * @param {!HTMLTemplateElement} template\n   * @param {string} elementName\n   * @return {StyleNode}\n   */\n\n\n  transformTemplate(template, elementName) {\n    if (template._gatheredStyle === undefined) {\n      template._gatheredStyle = this.gatherStyles(template);\n    }\n    /** @type {HTMLStyleElement} */\n\n\n    const style = template._gatheredStyle;\n    return style ? this.transformStyle(style, elementName) : null;\n  }\n  /**\n   * @param {!HTMLStyleElement} style\n   * @param {string} elementName\n   * @return {StyleNode}\n   */\n\n\n  transformStyle(style, elementName = '') {\n    let ast = (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.rulesForStyle)(style);\n    this.transformRules(ast, elementName);\n    style.textContent = (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.toCssText)(ast);\n    return ast;\n  }\n  /**\n   * @param {!HTMLStyleElement} style\n   * @return {StyleNode}\n   */\n\n\n  transformCustomStyle(style) {\n    let ast = (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.rulesForStyle)(style);\n    (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.forEachRule)(ast, rule => {\n      if (rule['selector'] === ':root') {\n        rule['selector'] = 'html';\n      }\n\n      this.transformRule(rule);\n    });\n    style.textContent = (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.toCssText)(ast);\n    return ast;\n  }\n  /**\n   * @param {StyleNode} rules\n   * @param {string} elementName\n   */\n\n\n  transformRules(rules, elementName) {\n    this._currentElement = elementName;\n    (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.forEachRule)(rules, r => {\n      this.transformRule(r);\n    });\n    this._currentElement = null;\n  }\n  /**\n   * @param {!StyleNode} rule\n   */\n\n\n  transformRule(rule) {\n    rule['cssText'] = this.transformCssText(rule['parsedCssText'], rule); // :root was only used for variable assignment in property shim,\n    // but generates invalid selectors with real properties.\n    // replace with `:host > *`, which serves the same effect\n\n    if (rule['selector'] === ':root') {\n      rule['selector'] = ':host > *';\n    }\n  }\n  /**\n   * @param {string} cssText\n   * @param {!StyleNode} rule\n   * @return {string}\n   */\n\n\n  transformCssText(cssText, rule) {\n    // produce variables\n    cssText = cssText.replace(_common_regex_js__WEBPACK_IMPORTED_MODULE_3__.VAR_ASSIGN, (matchText, propertyName, valueProperty, valueMixin) => this._produceCssProperties(matchText, propertyName, valueProperty, valueMixin, rule)); // consume mixins\n\n    return this._consumeCssProperties(cssText, rule);\n  }\n  /**\n   * @param {string} property\n   * @return {string}\n   */\n\n\n  _getInitialValueForProperty(property) {\n    if (!this._measureElement) {\n      this._measureElement =\n      /** @type {HTMLMetaElement} */\n      document.createElement('meta');\n\n      this._measureElement.setAttribute('apply-shim-measure', '');\n\n      this._measureElement.style.all = 'initial';\n      document.head.appendChild(this._measureElement);\n    }\n\n    return window.getComputedStyle(this._measureElement).getPropertyValue(property);\n  }\n  /**\n   * Walk over all rules before this rule to find fallbacks for mixins\n   *\n   * @param {!StyleNode} startRule\n   * @return {!Object}\n   */\n\n\n  _fallbacksFromPreviousRules(startRule) {\n    // find the \"top\" rule\n    let topRule = startRule;\n\n    while (topRule['parent']) {\n      topRule = topRule['parent'];\n    }\n\n    const fallbacks = {};\n    let seenStartRule = false;\n    (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.forEachRule)(topRule, r => {\n      // stop when we hit the input rule\n      seenStartRule = seenStartRule || r === startRule;\n\n      if (seenStartRule) {\n        return;\n      } // NOTE: Only matching selectors are \"safe\" for this fallback processing\n      // It would be prohibitive to run `matchesSelector()` on each selector,\n      // so we cheat and only check if the same selector string is used, which\n      // guarantees things like specificity matching\n\n\n      if (r['selector'] === startRule['selector']) {\n        Object.assign(fallbacks, this._cssTextToMap(r['parsedCssText']));\n      }\n    });\n    return fallbacks;\n  }\n  /**\n   * replace mixin consumption with variable consumption\n   * @param {string} text\n   * @param {!StyleNode=} rule\n   * @return {string}\n   */\n\n\n  _consumeCssProperties(text, rule) {\n    /** @type {Array} */\n    let m = null; // loop over text until all mixins with defintions have been applied\n\n    while (m = _common_regex_js__WEBPACK_IMPORTED_MODULE_3__.MIXIN_MATCH.exec(text)) {\n      let matchText = m[0];\n      let mixinName = m[1];\n      let idx = m.index; // collect properties before apply to be \"defaults\" if mixin might override them\n      // match includes a \"prefix\", so find the start and end positions of @apply\n\n      let applyPos = idx + matchText.indexOf('@apply');\n      let afterApplyPos = idx + matchText.length; // find props defined before this @apply\n\n      let textBeforeApply = text.slice(0, applyPos);\n      let textAfterApply = text.slice(afterApplyPos);\n      let defaults = rule ? this._fallbacksFromPreviousRules(rule) : {};\n      Object.assign(defaults, this._cssTextToMap(textBeforeApply));\n\n      let replacement = this._atApplyToCssProperties(mixinName, defaults); // use regex match position to replace mixin, keep linear processing time\n\n\n      text = `${textBeforeApply}${replacement}${textAfterApply}`; // move regex search to _after_ replacement\n\n      _common_regex_js__WEBPACK_IMPORTED_MODULE_3__.MIXIN_MATCH.lastIndex = idx + replacement.length;\n    }\n\n    return text;\n  }\n  /**\n   * produce variable consumption at the site of mixin consumption\n   * `@apply` --foo; -> for all props (${propname}: var(--foo_-_${propname}, ${fallback[propname]}}))\n   * Example:\n   *  border: var(--foo_-_border); padding: var(--foo_-_padding, 2px)\n   *\n   * @param {string} mixinName\n   * @param {Object} fallbacks\n   * @return {string}\n   */\n\n\n  _atApplyToCssProperties(mixinName, fallbacks) {\n    mixinName = mixinName.replace(APPLY_NAME_CLEAN, '');\n    let vars = [];\n\n    let mixinEntry = this._map.get(mixinName); // if we depend on a mixin before it is created\n    // make a sentinel entry in the map to add this element as a dependency for when it is defined.\n\n\n    if (!mixinEntry) {\n      this._map.set(mixinName, {});\n\n      mixinEntry = this._map.get(mixinName);\n    }\n\n    if (mixinEntry) {\n      if (this._currentElement) {\n        mixinEntry.dependants[this._currentElement] = true;\n      }\n\n      let p, parts, f;\n      const properties = mixinEntry.properties;\n\n      for (p in properties) {\n        f = fallbacks && fallbacks[p];\n        parts = [p, ': var(', mixinName, MIXIN_VAR_SEP, p];\n\n        if (f) {\n          parts.push(',', f.replace(IMPORTANT, ''));\n        }\n\n        parts.push(')');\n\n        if (IMPORTANT.test(properties[p])) {\n          parts.push(' !important');\n        }\n\n        vars.push(parts.join(''));\n      }\n    }\n\n    return vars.join('; ');\n  }\n  /**\n   * @param {string} property\n   * @param {string} value\n   * @return {string}\n   */\n\n\n  _replaceInitialOrInherit(property, value) {\n    let match = INITIAL_INHERIT.exec(value);\n\n    if (match) {\n      if (match[1]) {\n        // initial\n        // replace `initial` with the concrete initial value for this property\n        value = this._getInitialValueForProperty(property);\n      } else {\n        // inherit\n        // with this purposfully illegal value, the variable will be invalid at\n        // compute time (https://www.w3.org/TR/css-variables/#invalid-at-computed-value-time)\n        // and for inheriting values, will behave similarly\n        // we cannot support the same behavior for non inheriting values like 'border'\n        value = 'apply-shim-inherit';\n      }\n    }\n\n    return value;\n  }\n  /**\n   * \"parse\" a mixin definition into a map of properties and values\n   * cssTextToMap('border: 2px solid black') -> ('border', '2px solid black')\n   * @param {string} text\n   * @param {boolean=} replaceInitialOrInherit\n   * @return {!Object<string, string>}\n   */\n\n\n  _cssTextToMap(text, replaceInitialOrInherit = false) {\n    let props = text.split(';');\n    let property, value;\n    let out = {};\n\n    for (let i = 0, p, sp; i < props.length; i++) {\n      p = props[i];\n\n      if (p) {\n        sp = p.split(':'); // ignore lines that aren't definitions like @media\n\n        if (sp.length > 1) {\n          property = sp[0].trim(); // some properties may have ':' in the value, like data urls\n\n          value = sp.slice(1).join(':');\n\n          if (replaceInitialOrInherit) {\n            value = this._replaceInitialOrInherit(property, value);\n          }\n\n          out[property] = value;\n        }\n      }\n    }\n\n    return out;\n  }\n  /**\n   * @param {MixinMapEntry} mixinEntry\n   */\n\n\n  _invalidateMixinEntry(mixinEntry) {\n    if (!invalidCallback) {\n      return;\n    }\n\n    for (let elementName in mixinEntry.dependants) {\n      if (elementName !== this._currentElement) {\n        invalidCallback(elementName);\n      }\n    }\n  }\n  /**\n   * @param {string} matchText\n   * @param {string} propertyName\n   * @param {?string} valueProperty\n   * @param {?string} valueMixin\n   * @param {!StyleNode} rule\n   * @return {string}\n   */\n\n\n  _produceCssProperties(matchText, propertyName, valueProperty, valueMixin, rule) {\n    // handle case where property value is a mixin\n    if (valueProperty) {\n      // form: --mixin2: var(--mixin1), where --mixin1 is in the map\n      (0,_style_util_js__WEBPACK_IMPORTED_MODULE_0__.processVariableAndFallback)(valueProperty, (prefix, value) => {\n        if (value && this._map.get(value)) {\n          valueMixin = `@apply ${value};`;\n        }\n      });\n    }\n\n    if (!valueMixin) {\n      return matchText;\n    }\n\n    let mixinAsProperties = this._consumeCssProperties('' + valueMixin, rule);\n\n    let prefix = matchText.slice(0, matchText.indexOf('--')); // `initial` and `inherit` as properties in a map should be replaced because\n    // these keywords are eagerly evaluated when the mixin becomes CSS Custom Properties,\n    // and would set the variable value, rather than carry the keyword to the `var()` usage.\n\n    let mixinValues = this._cssTextToMap(mixinAsProperties, true);\n\n    let combinedProps = mixinValues;\n\n    let mixinEntry = this._map.get(propertyName);\n\n    let oldProps = mixinEntry && mixinEntry.properties;\n\n    if (oldProps) {\n      // NOTE: since we use mixin, the map of properties is updated here\n      // and this is what we want.\n      combinedProps = Object.assign(Object.create(oldProps), mixinValues);\n    } else {\n      this._map.set(propertyName, combinedProps);\n    }\n\n    let out = [];\n    let p, v; // set variables defined by current mixin\n\n    let needToInvalidate = false;\n\n    for (p in combinedProps) {\n      v = mixinValues[p]; // if property not defined by current mixin, set initial\n\n      if (v === undefined) {\n        v = 'initial';\n      }\n\n      if (oldProps && !(p in oldProps)) {\n        needToInvalidate = true;\n      }\n\n      out.push(`${propertyName}${MIXIN_VAR_SEP}${p}: ${v}`);\n    }\n\n    if (needToInvalidate) {\n      this._invalidateMixinEntry(mixinEntry);\n    }\n\n    if (mixinEntry) {\n      mixinEntry.properties = combinedProps;\n    } // because the mixinMap is global, the mixin might conflict with\n    // a different scope's simple variable definition:\n    // Example:\n    // some style somewhere:\n    // --mixin1:{ ... }\n    // --mixin2: var(--mixin1);\n    // some other element:\n    // --mixin1: 10px solid red;\n    // --foo: var(--mixin1);\n    // In this case, we leave the original variable definition in place.\n\n\n    if (valueProperty) {\n      prefix = `${matchText};${prefix}`;\n    }\n\n    return `${prefix}${out.join('; ')};`;\n  }\n\n}\n/* exports */\n\n/* eslint-disable no-self-assign */\n\n\nApplyShim.prototype['detectMixin'] = ApplyShim.prototype.detectMixin;\nApplyShim.prototype['transformStyle'] = ApplyShim.prototype.transformStyle;\nApplyShim.prototype['transformCustomStyle'] = ApplyShim.prototype.transformCustomStyle;\nApplyShim.prototype['transformRules'] = ApplyShim.prototype.transformRules;\nApplyShim.prototype['transformRule'] = ApplyShim.prototype.transformRule;\nApplyShim.prototype['transformTemplate'] = ApplyShim.prototype.transformTemplate;\nApplyShim.prototype['_separator'] = MIXIN_VAR_SEP;\n/* eslint-enable no-self-assign */\n\nObject.defineProperty(ApplyShim.prototype, 'invalidCallback', {\n  /** @return {?function(string)} */\n  get() {\n    return invalidCallback;\n  },\n\n  /** @param {?function(string)} cb */\n  set(cb) {\n    invalidCallback = cb;\n  }\n\n});\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (ApplyShim);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/apply-shim.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/common-regex.js":
/*!******************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/common-regex.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export ANIMATION_MATCH [provided] [no usage info] [missing usage info prevents renaming] */
/*! export BRACKETED [provided] [no usage info] [missing usage info prevents renaming] */
/*! export HOST_PREFIX [provided] [no usage info] [missing usage info prevents renaming] */
/*! export HOST_SUFFIX [provided] [no usage info] [missing usage info prevents renaming] */
/*! export IS_VAR [provided] [no usage info] [missing usage info prevents renaming] */
/*! export MEDIA_MATCH [provided] [no usage info] [missing usage info prevents renaming] */
/*! export MIXIN_MATCH [provided] [no usage info] [missing usage info prevents renaming] */
/*! export VAR_ASSIGN [provided] [no usage info] [missing usage info prevents renaming] */
/*! export VAR_CONSUMED [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"VAR_ASSIGN\": () => /* binding */ VAR_ASSIGN,\n/* harmony export */   \"MIXIN_MATCH\": () => /* binding */ MIXIN_MATCH,\n/* harmony export */   \"VAR_CONSUMED\": () => /* binding */ VAR_CONSUMED,\n/* harmony export */   \"ANIMATION_MATCH\": () => /* binding */ ANIMATION_MATCH,\n/* harmony export */   \"MEDIA_MATCH\": () => /* binding */ MEDIA_MATCH,\n/* harmony export */   \"IS_VAR\": () => /* binding */ IS_VAR,\n/* harmony export */   \"BRACKETED\": () => /* binding */ BRACKETED,\n/* harmony export */   \"HOST_PREFIX\": () => /* binding */ HOST_PREFIX,\n/* harmony export */   \"HOST_SUFFIX\": () => /* binding */ HOST_SUFFIX\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\nconst VAR_ASSIGN = /(?:^|[;\\s{]\\s*)(--[\\w-]*?)\\s*:\\s*(?:((?:'(?:\\\\'|.)*?'|\"(?:\\\\\"|.)*?\"|\\([^)]*?\\)|[^};{])+)|\\{([^}]*)\\}(?:(?=[;\\s}])|$))/gi;\nconst MIXIN_MATCH = /(?:^|\\W+)@apply\\s*\\(?([^);\\n]*)\\)?/gi;\nconst VAR_CONSUMED = /(--[\\w-]+)\\s*([:,;)]|$)/gi;\nconst ANIMATION_MATCH = /(animation\\s*:)|(animation-name\\s*:)/;\nconst MEDIA_MATCH = /@media\\s(.*)/;\nconst IS_VAR = /^--/;\nconst BRACKETED = /\\{[^}]*\\}/g;\nconst HOST_PREFIX = '(?:^|[^.#[:])';\nconst HOST_SUFFIX = '($|[.:[\\\\s>+~])';//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQHdlYmNvbXBvbmVudHMvc2hhZHljc3Mvc3JjL2NvbW1vbi1yZWdleC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vbm9kZV9tb2R1bGVzL0B3ZWJjb21wb25lbnRzL3NoYWR5Y3NzL3NyYy9jb21tb24tcmVnZXguanM/MzRmYiJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgKGMpIDIwMTcgVGhlIFBvbHltZXIgUHJvamVjdCBBdXRob3JzLiBBbGwgcmlnaHRzIHJlc2VydmVkLlxuVGhpcyBjb2RlIG1heSBvbmx5IGJlIHVzZWQgdW5kZXIgdGhlIEJTRCBzdHlsZSBsaWNlbnNlIGZvdW5kIGF0IGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9MSUNFTlNFLnR4dFxuVGhlIGNvbXBsZXRlIHNldCBvZiBhdXRob3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQVVUSE9SUy50eHRcblRoZSBjb21wbGV0ZSBzZXQgb2YgY29udHJpYnV0b3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQ09OVFJJQlVUT1JTLnR4dFxuQ29kZSBkaXN0cmlidXRlZCBieSBHb29nbGUgYXMgcGFydCBvZiB0aGUgcG9seW1lciBwcm9qZWN0IGlzIGFsc29cbnN1YmplY3QgdG8gYW4gYWRkaXRpb25hbCBJUCByaWdodHMgZ3JhbnQgZm91bmQgYXQgaHR0cDovL3BvbHltZXIuZ2l0aHViLmlvL1BBVEVOVFMudHh0XG4qL1xuXG5leHBvcnQgY29uc3QgVkFSX0FTU0lHTiA9IC8oPzpefFs7XFxze11cXHMqKSgtLVtcXHctXSo/KVxccyo6XFxzKig/OigoPzonKD86XFxcXCd8LikqPyd8XCIoPzpcXFxcXCJ8LikqP1wifFxcKFteKV0qP1xcKXxbXn07e10pKyl8XFx7KFtefV0qKVxcfSg/Oig/PVs7XFxzfV0pfCQpKS9naTtcbmV4cG9ydCBjb25zdCBNSVhJTl9NQVRDSCA9IC8oPzpefFxcVyspQGFwcGx5XFxzKlxcKD8oW14pO1xcbl0qKVxcKT8vZ2k7XG5leHBvcnQgY29uc3QgVkFSX0NPTlNVTUVEID0gLygtLVtcXHctXSspXFxzKihbOiw7KV18JCkvZ2k7XG5leHBvcnQgY29uc3QgQU5JTUFUSU9OX01BVENIID0gLyhhbmltYXRpb25cXHMqOil8KGFuaW1hdGlvbi1uYW1lXFxzKjopLztcbmV4cG9ydCBjb25zdCBNRURJQV9NQVRDSCA9IC9AbWVkaWFcXHMoLiopLztcbmV4cG9ydCBjb25zdCBJU19WQVIgPSAvXi0tLztcbmV4cG9ydCBjb25zdCBCUkFDS0VURUQgPSAvXFx7W159XSpcXH0vZztcbmV4cG9ydCBjb25zdCBIT1NUX1BSRUZJWCA9ICcoPzpefFteLiNbOl0pJztcbmV4cG9ydCBjb25zdCBIT1NUX1NVRkZJWCA9ICcoJHxbLjpbXFxcXHM+K35dKSc7XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7Ozs7OztBQUFBOzs7Ozs7Ozs7QUFVQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/common-regex.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/common-utils.js":
/*!******************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/common-utils.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export detectMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getComputedStyleValue [provided] [no usage info] [missing usage info prevents renaming] */
/*! export updateNativeProperties [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"updateNativeProperties\": () => /* binding */ updateNativeProperties,\n/* harmony export */   \"getComputedStyleValue\": () => /* binding */ getComputedStyleValue,\n/* harmony export */   \"detectMixin\": () => /* binding */ detectMixin\n/* harmony export */ });\n/* harmony import */ var _common_regex_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./common-regex.js */ \"./node_modules/@webcomponents/shadycss/src/common-regex.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * @param {Element} element\n * @param {Object=} properties\n */\n\nfunction updateNativeProperties(element, properties) {\n  // remove previous properties\n  for (let p in properties) {\n    // NOTE: for bc with shim, don't apply null values.\n    if (p === null) {\n      element.style.removeProperty(p);\n    } else {\n      element.style.setProperty(p, properties[p]);\n    }\n  }\n}\n/**\n * @param {Element} element\n * @param {string} property\n * @return {string}\n */\n\nfunction getComputedStyleValue(element, property) {\n  /**\n   * @const {string}\n   */\n  const value = window.getComputedStyle(element).getPropertyValue(property);\n\n  if (!value) {\n    return '';\n  } else {\n    return value.trim();\n  }\n}\n/**\n * return true if `cssText` contains a mixin definition or consumption\n * @param {string} cssText\n * @return {boolean}\n */\n\nfunction detectMixin(cssText) {\n  const has = _common_regex_js__WEBPACK_IMPORTED_MODULE_0__.MIXIN_MATCH.test(cssText) || _common_regex_js__WEBPACK_IMPORTED_MODULE_0__.VAR_ASSIGN.test(cssText); // reset state of the regexes\n\n  _common_regex_js__WEBPACK_IMPORTED_MODULE_0__.MIXIN_MATCH.lastIndex = 0;\n  _common_regex_js__WEBPACK_IMPORTED_MODULE_0__.VAR_ASSIGN.lastIndex = 0;\n  return has;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/common-utils.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/css-parse.js":
/*!***************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/css-parse.js ***!
  \***************************************************************/
/*! namespace exports */
/*! export StyleNode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export parse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export removeCustomPropAssignment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export stringify [provided] [no usage info] [missing usage info prevents renaming] */
/*! export types [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"StyleNode\": () => /* binding */ StyleNode,\n/* harmony export */   \"parse\": () => /* binding */ parse,\n/* harmony export */   \"stringify\": () => /* binding */ stringify,\n/* harmony export */   \"removeCustomPropAssignment\": () => /* binding */ removeCustomPropAssignment,\n/* harmony export */   \"types\": () => /* binding */ types\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/*\nExtremely simple css parser. Intended to be not more than what we need\nand definitely not necessarily correct =).\n*/\n\n/** @unrestricted */\n\nclass StyleNode {\n  constructor() {\n    /** @type {number} */\n    this['start'] = 0;\n    /** @type {number} */\n\n    this['end'] = 0;\n    /** @type {StyleNode} */\n\n    this['previous'] = null;\n    /** @type {StyleNode} */\n\n    this['parent'] = null;\n    /** @type {Array<StyleNode>} */\n\n    this['rules'] = null;\n    /** @type {string} */\n\n    this['parsedCssText'] = '';\n    /** @type {string} */\n\n    this['cssText'] = '';\n    /** @type {boolean} */\n\n    this['atRule'] = false;\n    /** @type {number} */\n\n    this['type'] = 0;\n    /** @type {string} */\n\n    this['keyframesName'] = '';\n    /** @type {string} */\n\n    this['selector'] = '';\n    /** @type {string} */\n\n    this['parsedSelector'] = '';\n  }\n\n}\n\n // given a string of css, return a simple rule tree\n\n/**\n * @param {string} text\n * @return {StyleNode}\n */\n\nfunction parse(text) {\n  text = clean(text);\n  return parseCss(lex(text), text);\n} // remove stuff we don't care about that may hinder parsing\n\n/**\n * @param {string} cssText\n * @return {string}\n */\n\nfunction clean(cssText) {\n  return cssText.replace(RX.comments, '').replace(RX.port, '');\n} // super simple {...} lexer that returns a node tree\n\n/**\n * @param {string} text\n * @return {StyleNode}\n */\n\n\nfunction lex(text) {\n  let root = new StyleNode();\n  root['start'] = 0;\n  root['end'] = text.length;\n  let n = root;\n\n  for (let i = 0, l = text.length; i < l; i++) {\n    if (text[i] === OPEN_BRACE) {\n      if (!n['rules']) {\n        n['rules'] = [];\n      }\n\n      let p = n;\n      let previous = p['rules'][p['rules'].length - 1] || null;\n      n = new StyleNode();\n      n['start'] = i + 1;\n      n['parent'] = p;\n      n['previous'] = previous;\n      p['rules'].push(n);\n    } else if (text[i] === CLOSE_BRACE) {\n      n['end'] = i + 1;\n      n = n['parent'] || root;\n    }\n  }\n\n  return root;\n} // add selectors/cssText to node tree\n\n/**\n * @param {StyleNode} node\n * @param {string} text\n * @return {StyleNode}\n */\n\n\nfunction parseCss(node, text) {\n  let t = text.substring(node['start'], node['end'] - 1);\n  node['parsedCssText'] = node['cssText'] = t.trim();\n\n  if (node['parent']) {\n    let ss = node['previous'] ? node['previous']['end'] : node['parent']['start'];\n    t = text.substring(ss, node['start'] - 1);\n    t = _expandUnicodeEscapes(t);\n    t = t.replace(RX.multipleSpaces, ' '); // TODO(sorvell): ad hoc; make selector include only after last ;\n    // helps with mixin syntax\n\n    t = t.substring(t.lastIndexOf(';') + 1);\n    let s = node['parsedSelector'] = node['selector'] = t.trim();\n    node['atRule'] = s.indexOf(AT_START) === 0; // note, support a subset of rule types...\n\n    if (node['atRule']) {\n      if (s.indexOf(MEDIA_START) === 0) {\n        node['type'] = types.MEDIA_RULE;\n      } else if (s.match(RX.keyframesRule)) {\n        node['type'] = types.KEYFRAMES_RULE;\n        node['keyframesName'] = node['selector'].split(RX.multipleSpaces).pop();\n      }\n    } else {\n      if (s.indexOf(VAR_START) === 0) {\n        node['type'] = types.MIXIN_RULE;\n      } else {\n        node['type'] = types.STYLE_RULE;\n      }\n    }\n  }\n\n  let r$ = node['rules'];\n\n  if (r$) {\n    for (let i = 0, l = r$.length, r; i < l && (r = r$[i]); i++) {\n      parseCss(r, text);\n    }\n  }\n\n  return node;\n}\n/**\n * conversion of sort unicode escapes with spaces like `\\33 ` (and longer) into\n * expanded form that doesn't require trailing space `\\000033`\n * @param {string} s\n * @return {string}\n */\n\n\nfunction _expandUnicodeEscapes(s) {\n  return s.replace(/\\\\([0-9a-f]{1,6})\\s/gi, function () {\n    let code = arguments[1],\n        repeat = 6 - code.length;\n\n    while (repeat--) {\n      code = '0' + code;\n    }\n\n    return '\\\\' + code;\n  });\n}\n/**\n * stringify parsed css.\n * @param {StyleNode} node\n * @param {boolean=} preserveProperties\n * @param {string=} text\n * @return {string}\n */\n\n\nfunction stringify(node, preserveProperties, text = '') {\n  // calc rule cssText\n  let cssText = '';\n\n  if (node['cssText'] || node['rules']) {\n    let r$ = node['rules'];\n\n    if (r$ && !_hasMixinRules(r$)) {\n      for (let i = 0, l = r$.length, r; i < l && (r = r$[i]); i++) {\n        cssText = stringify(r, preserveProperties, cssText);\n      }\n    } else {\n      cssText = preserveProperties ? node['cssText'] : removeCustomProps(node['cssText']);\n      cssText = cssText.trim();\n\n      if (cssText) {\n        cssText = '  ' + cssText + '\\n';\n      }\n    }\n  } // emit rule if there is cssText\n\n\n  if (cssText) {\n    if (node['selector']) {\n      text += node['selector'] + ' ' + OPEN_BRACE + '\\n';\n    }\n\n    text += cssText;\n\n    if (node['selector']) {\n      text += CLOSE_BRACE + '\\n\\n';\n    }\n  }\n\n  return text;\n}\n/**\n * @param {Array<StyleNode>} rules\n * @return {boolean}\n */\n\nfunction _hasMixinRules(rules) {\n  let r = rules[0];\n  return Boolean(r) && Boolean(r['selector']) && r['selector'].indexOf(VAR_START) === 0;\n}\n/**\n * @param {string} cssText\n * @return {string}\n */\n\n\nfunction removeCustomProps(cssText) {\n  cssText = removeCustomPropAssignment(cssText);\n  return removeCustomPropApply(cssText);\n}\n/**\n * @param {string} cssText\n * @return {string}\n */\n\n\nfunction removeCustomPropAssignment(cssText) {\n  return cssText.replace(RX.customProp, '').replace(RX.mixinProp, '');\n}\n/**\n * @param {string} cssText\n * @return {string}\n */\n\nfunction removeCustomPropApply(cssText) {\n  return cssText.replace(RX.mixinApply, '').replace(RX.varApply, '');\n}\n/** @enum {number} */\n\n\nconst types = {\n  STYLE_RULE: 1,\n  KEYFRAMES_RULE: 7,\n  MEDIA_RULE: 4,\n  MIXIN_RULE: 1000\n};\nconst OPEN_BRACE = '{';\nconst CLOSE_BRACE = '}'; // helper regexp's\n\nconst RX = {\n  comments: /\\/\\*[^*]*\\*+([^/*][^*]*\\*+)*\\//gim,\n  port: /@import[^;]*;/gim,\n  customProp: /(?:^[^;\\-\\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\\n]|$)/gim,\n  mixinProp: /(?:^[^;\\-\\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\\n]|$)?/gim,\n  mixinApply: /@apply\\s*\\(?[^);]*\\)?\\s*(?:[;\\n]|$)?/gim,\n  varApply: /[^;:]*?:[^;]*?var\\([^;]*\\)(?:[;\\n]|$)?/gim,\n  keyframesRule: /^@[^\\s]*keyframes/,\n  multipleSpaces: /\\s+/g\n};\nconst VAR_START = '--';\nconst MEDIA_START = '@media';\nconst AT_START = '@';//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/css-parse.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/custom-style-interface.js":
/*!****************************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/custom-style-interface.js ***!
  \****************************************************************************/
/*! namespace exports */
/*! export CustomStyleInterfaceInterface [provided] [no usage info] [missing usage info prevents renaming] */
/*! export CustomStyleProvider [provided] [no usage info] [missing usage info prevents renaming] */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"CustomStyleProvider\": () => /* binding */ CustomStyleProvider,\n/* harmony export */   \"default\": () => /* binding */ CustomStyleInterface,\n/* harmony export */   \"CustomStyleInterfaceInterface\": () => /* binding */ CustomStyleInterfaceInterface\n/* harmony export */ });\n/* harmony import */ var _document_wait_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./document-wait.js */ \"./node_modules/@webcomponents/shadycss/src/document-wait.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n/**\n * @typedef {HTMLStyleElement | {getStyle: function():HTMLStyleElement}}\n */\n\nlet CustomStyleProvider;\nconst SEEN_MARKER = '__seenByShadyCSS';\nconst CACHED_STYLE = '__shadyCSSCachedStyle';\n/** @type {?function(!HTMLStyleElement)} */\n\nlet transformFn = null;\n/** @type {?function()} */\n\nlet validateFn = null;\n/**\nThis interface is provided to add document-level <style> elements to ShadyCSS for processing.\nThese styles must be processed by ShadyCSS to simulate ShadowRoot upper-bound encapsulation from outside styles\nIn addition, these styles may also need to be processed for @apply rules and CSS Custom Properties\n\nTo add document-level styles to ShadyCSS, one can call `ShadyCSS.addDocumentStyle(styleElement)` or `ShadyCSS.addDocumentStyle({getStyle: () => styleElement})`\n\nIn addition, if the process used to discover document-level styles can be synchronously flushed, one should set `ShadyCSS.documentStyleFlush`.\nThis function will be called when calculating styles.\n\nAn example usage of the document-level styling api can be found in `examples/document-style-lib.js`\n\n@unrestricted\n*/\n\nclass CustomStyleInterface {\n  constructor() {\n    /** @type {!Array<!CustomStyleProvider>} */\n    this['customStyles'] = [];\n    this['enqueued'] = false; // NOTE(dfreedm): use quotes here to prevent closure inlining to `function(){}`;\n\n    (0,_document_wait_js__WEBPACK_IMPORTED_MODULE_0__.default)(() => {\n      if (window['ShadyCSS']['flushCustomStyles']) {\n        window['ShadyCSS']['flushCustomStyles']();\n      }\n    });\n  }\n  /**\n   * Queue a validation for new custom styles to batch style recalculations\n   */\n\n\n  enqueueDocumentValidation() {\n    if (this['enqueued'] || !validateFn) {\n      return;\n    }\n\n    this['enqueued'] = true;\n    (0,_document_wait_js__WEBPACK_IMPORTED_MODULE_0__.default)(validateFn);\n  }\n  /**\n   * @param {!HTMLStyleElement} style\n   */\n\n\n  addCustomStyle(style) {\n    if (!style[SEEN_MARKER]) {\n      style[SEEN_MARKER] = true;\n      this['customStyles'].push(style);\n      this.enqueueDocumentValidation();\n    }\n  }\n  /**\n   * @param {!CustomStyleProvider} customStyle\n   * @return {HTMLStyleElement}\n   */\n\n\n  getStyleForCustomStyle(customStyle) {\n    if (customStyle[CACHED_STYLE]) {\n      return customStyle[CACHED_STYLE];\n    }\n\n    let style;\n\n    if (customStyle['getStyle']) {\n      style = customStyle['getStyle']();\n    } else {\n      style = customStyle;\n    }\n\n    return style;\n  }\n  /**\n   * @return {!Array<!CustomStyleProvider>}\n   */\n\n\n  processStyles() {\n    const cs = this['customStyles'];\n\n    for (let i = 0; i < cs.length; i++) {\n      const customStyle = cs[i];\n\n      if (customStyle[CACHED_STYLE]) {\n        continue;\n      }\n\n      const style = this.getStyleForCustomStyle(customStyle);\n\n      if (style) {\n        // HTMLImports polyfill may have cloned the style into the main document,\n        // which is referenced with __appliedElement.\n        const styleToTransform =\n        /** @type {!HTMLStyleElement} */\n        style['__appliedElement'] || style;\n\n        if (transformFn) {\n          transformFn(styleToTransform);\n        }\n\n        customStyle[CACHED_STYLE] = styleToTransform;\n      }\n    }\n\n    return cs;\n  }\n\n}\n/* eslint-disable no-self-assign */\n\nCustomStyleInterface.prototype['addCustomStyle'] = CustomStyleInterface.prototype.addCustomStyle;\nCustomStyleInterface.prototype['getStyleForCustomStyle'] = CustomStyleInterface.prototype.getStyleForCustomStyle;\nCustomStyleInterface.prototype['processStyles'] = CustomStyleInterface.prototype.processStyles;\n/* eslint-enable no-self-assign */\n\nObject.defineProperties(CustomStyleInterface.prototype, {\n  'transformCallback': {\n    /** @return {?function(!HTMLStyleElement)} */\n    get() {\n      return transformFn;\n    },\n\n    /** @param {?function(!HTMLStyleElement)} fn */\n    set(fn) {\n      transformFn = fn;\n    }\n\n  },\n  'validateCallback': {\n    /** @return {?function()} */\n    get() {\n      return validateFn;\n    },\n\n    /**\n     * @param {?function()} fn\n     * @this {CustomStyleInterface}\n     */\n    set(fn) {\n      let needsEnqueue = false;\n\n      if (!validateFn) {\n        needsEnqueue = true;\n      }\n\n      validateFn = fn;\n\n      if (needsEnqueue) {\n        this.enqueueDocumentValidation();\n      }\n    }\n\n  }\n});\n/** @typedef {{\n * customStyles: !Array<!CustomStyleProvider>,\n * addCustomStyle: function(!CustomStyleProvider),\n * getStyleForCustomStyle: function(!CustomStyleProvider): HTMLStyleElement,\n * findStyles: function(),\n * transformCallback: ?function(!HTMLStyleElement),\n * validateCallback: ?function()\n * }}\n */\n\nconst CustomStyleInterfaceInterface = {};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/custom-style-interface.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/document-wait.js":
/*!*******************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/document-wait.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => /* binding */ documentWait\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/** @type {Promise<void>} */\n\nlet readyPromise = null;\n/** @type {?function(?function())} */\n\nlet whenReady = window['HTMLImports'] && window['HTMLImports']['whenReady'] || null;\n/** @type {function()} */\n\nlet resolveFn;\n/**\n * @param {?function()} callback\n */\n\nfunction documentWait(callback) {\n  requestAnimationFrame(function () {\n    if (whenReady) {\n      whenReady(callback);\n    } else {\n      if (!readyPromise) {\n        readyPromise = new Promise(resolve => {\n          resolveFn = resolve;\n        });\n\n        if (document.readyState === 'complete') {\n          resolveFn();\n        } else {\n          document.addEventListener('readystatechange', () => {\n            if (document.readyState === 'complete') {\n              resolveFn();\n            }\n          });\n        }\n      }\n\n      readyPromise.then(function () {\n        callback && callback();\n      });\n    }\n  });\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/document-wait.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/style-settings.js":
/*!********************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/style-settings.js ***!
  \********************************************************************/
/*! namespace exports */
/*! export cssBuild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export disableRuntime [provided] [no usage info] [missing usage info prevents renaming] */
/*! export nativeCssVariables [provided] [no usage info] [missing usage info prevents renaming] */
/*! export nativeShadow [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"nativeShadow\": () => /* binding */ nativeShadow,\n/* harmony export */   \"cssBuild\": () => /* binding */ cssBuild,\n/* harmony export */   \"disableRuntime\": () => /* binding */ disableRuntime,\n/* harmony export */   \"nativeCssVariables\": () => /* binding */ nativeCssVariables\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\nconst nativeShadow = !(window['ShadyDOM'] && window['ShadyDOM']['inUse']);\nlet nativeCssVariables_;\n/**\n * @param {(ShadyCSSOptions | ShadyCSSInterface)=} settings\n */\n\nfunction calcCssVariables(settings) {\n  if (settings && settings['shimcssproperties']) {\n    nativeCssVariables_ = false;\n  } else {\n    // chrome 49 has semi-working css vars, check if box-shadow works\n    // safari 9.1 has a recalc bug: https://bugs.webkit.org/show_bug.cgi?id=155782\n    // However, shim css custom properties are only supported with ShadyDOM enabled,\n    // so fall back on native if we do not detect ShadyDOM\n    // Edge 15: custom properties used in ::before and ::after will also be used in the parent element\n    // https://developer.microsoft.com/en-us/microsoft-edge/platform/issues/12414257/\n    nativeCssVariables_ = nativeShadow || Boolean(!navigator.userAgent.match(/AppleWebKit\\/601|Edge\\/15/) && window.CSS && CSS.supports && CSS.supports('box-shadow', '0 0 0 var(--foo)'));\n  }\n}\n/** @type {string | undefined} */\n\n\nlet cssBuild;\n\nif (window.ShadyCSS && window.ShadyCSS.cssBuild !== undefined) {\n  cssBuild = window.ShadyCSS.cssBuild;\n}\n/** @type {boolean} */\n\n\nconst disableRuntime = Boolean(window.ShadyCSS && window.ShadyCSS.disableRuntime);\n\nif (window.ShadyCSS && window.ShadyCSS.nativeCss !== undefined) {\n  nativeCssVariables_ = window.ShadyCSS.nativeCss;\n} else if (window.ShadyCSS) {\n  calcCssVariables(window.ShadyCSS); // reset window variable to let ShadyCSS API take its place\n\n  window.ShadyCSS = undefined;\n} else {\n  calcCssVariables(window['WebComponents'] && window['WebComponents']['flags']);\n} // Hack for type error under new type inference which doesn't like that\n// nativeCssVariables is updated in a function and assigns the type\n// `function(): ?` instead of `boolean`.\n\n\nconst nativeCssVariables =\n/** @type {boolean} */\nnativeCssVariables_;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/style-settings.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/style-util.js":
/*!****************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/style-util.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export applyCss [provided] [no usage info] [missing usage info prevents renaming] */
/*! export applyStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export applyStylePlaceHolder [provided] [no usage info] [missing usage info prevents renaming] */
/*! export createScopeStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export elementHasBuiltCss [provided] [no usage info] [missing usage info prevents renaming] */
/*! export findMatchingParen [provided] [no usage info] [missing usage info prevents renaming] */
/*! export forEachRule [provided] [no usage info] [missing usage info prevents renaming] */
/*! export gatherStyleText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getBuildComment [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getCssBuild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getIsExtends [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isKeyframesSelector [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isOptimalCssBuild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isTargetedBuild [provided] [no usage info] [missing usage info prevents renaming] */
/*! export processVariableAndFallback [provided] [no usage info] [missing usage info prevents renaming] */
/*! export rulesForStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setElementClassRaw [provided] [no usage info] [missing usage info prevents renaming] */
/*! export splitSelectorList [provided] [no usage info] [missing usage info prevents renaming] */
/*! export toCssText [provided] [no usage info] [missing usage info prevents renaming] */
/*! export wrap [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"toCssText\": () => /* binding */ toCssText,\n/* harmony export */   \"rulesForStyle\": () => /* binding */ rulesForStyle,\n/* harmony export */   \"isKeyframesSelector\": () => /* binding */ isKeyframesSelector,\n/* harmony export */   \"forEachRule\": () => /* binding */ forEachRule,\n/* harmony export */   \"applyCss\": () => /* binding */ applyCss,\n/* harmony export */   \"createScopeStyle\": () => /* binding */ createScopeStyle,\n/* harmony export */   \"applyStylePlaceHolder\": () => /* binding */ applyStylePlaceHolder,\n/* harmony export */   \"applyStyle\": () => /* binding */ applyStyle,\n/* harmony export */   \"isTargetedBuild\": () => /* binding */ isTargetedBuild,\n/* harmony export */   \"findMatchingParen\": () => /* binding */ findMatchingParen,\n/* harmony export */   \"processVariableAndFallback\": () => /* binding */ processVariableAndFallback,\n/* harmony export */   \"setElementClassRaw\": () => /* binding */ setElementClassRaw,\n/* harmony export */   \"wrap\": () => /* binding */ wrap,\n/* harmony export */   \"getIsExtends\": () => /* binding */ getIsExtends,\n/* harmony export */   \"gatherStyleText\": () => /* binding */ gatherStyleText,\n/* harmony export */   \"splitSelectorList\": () => /* binding */ splitSelectorList,\n/* harmony export */   \"getCssBuild\": () => /* binding */ getCssBuild,\n/* harmony export */   \"elementHasBuiltCss\": () => /* binding */ elementHasBuiltCss,\n/* harmony export */   \"getBuildComment\": () => /* binding */ getBuildComment,\n/* harmony export */   \"isOptimalCssBuild\": () => /* binding */ isOptimalCssBuild\n/* harmony export */ });\n/* harmony import */ var _style_settings_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./style-settings.js */ \"./node_modules/@webcomponents/shadycss/src/style-settings.js\");\n/* harmony import */ var _css_parse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./css-parse.js */ \"./node_modules/@webcomponents/shadycss/src/css-parse.js\");\n/* harmony import */ var _common_regex_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./common-regex.js */ \"./node_modules/@webcomponents/shadycss/src/common-regex.js\");\n/* harmony import */ var _unscoped_style_handler_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./unscoped-style-handler.js */ \"./node_modules/@webcomponents/shadycss/src/unscoped-style-handler.js\");\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n\n\n // eslint-disable-line no-unused-vars\n\n\n\n/**\n * @param {string|StyleNode} rules\n * @param {function(StyleNode)=} callback\n * @return {string}\n */\n\nfunction toCssText(rules, callback) {\n  if (!rules) {\n    return '';\n  }\n\n  if (typeof rules === 'string') {\n    rules = (0,_css_parse_js__WEBPACK_IMPORTED_MODULE_1__.parse)(rules);\n  }\n\n  if (callback) {\n    forEachRule(rules, callback);\n  }\n\n  return (0,_css_parse_js__WEBPACK_IMPORTED_MODULE_1__.stringify)(rules, _style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeCssVariables);\n}\n/**\n * @param {HTMLStyleElement} style\n * @return {StyleNode}\n */\n\nfunction rulesForStyle(style) {\n  if (!style['__cssRules'] && style.textContent) {\n    style['__cssRules'] = (0,_css_parse_js__WEBPACK_IMPORTED_MODULE_1__.parse)(style.textContent);\n  }\n\n  return style['__cssRules'] || null;\n} // Tests if a rule is a keyframes selector, which looks almost exactly\n// like a normal selector but is not (it has nothing to do with scoping\n// for example).\n\n/**\n * @param {StyleNode} rule\n * @return {boolean}\n */\n\nfunction isKeyframesSelector(rule) {\n  return Boolean(rule['parent']) && rule['parent']['type'] === _css_parse_js__WEBPACK_IMPORTED_MODULE_1__.types.KEYFRAMES_RULE;\n}\n/**\n * @param {StyleNode} node\n * @param {Function=} styleRuleCallback\n * @param {Function=} keyframesRuleCallback\n * @param {boolean=} onlyActiveRules\n */\n\nfunction forEachRule(node, styleRuleCallback, keyframesRuleCallback, onlyActiveRules) {\n  if (!node) {\n    return;\n  }\n\n  let skipRules = false;\n  let type = node['type'];\n\n  if (onlyActiveRules) {\n    if (type === _css_parse_js__WEBPACK_IMPORTED_MODULE_1__.types.MEDIA_RULE) {\n      let matchMedia = node['selector'].match(_common_regex_js__WEBPACK_IMPORTED_MODULE_3__.MEDIA_MATCH);\n\n      if (matchMedia) {\n        // if rule is a non matching @media rule, skip subrules\n        if (!window.matchMedia(matchMedia[1]).matches) {\n          skipRules = true;\n        }\n      }\n    }\n  }\n\n  if (type === _css_parse_js__WEBPACK_IMPORTED_MODULE_1__.types.STYLE_RULE) {\n    styleRuleCallback(node);\n  } else if (keyframesRuleCallback && type === _css_parse_js__WEBPACK_IMPORTED_MODULE_1__.types.KEYFRAMES_RULE) {\n    keyframesRuleCallback(node);\n  } else if (type === _css_parse_js__WEBPACK_IMPORTED_MODULE_1__.types.MIXIN_RULE) {\n    skipRules = true;\n  }\n\n  let r$ = node['rules'];\n\n  if (r$ && !skipRules) {\n    for (let i = 0, l = r$.length, r; i < l && (r = r$[i]); i++) {\n      forEachRule(r, styleRuleCallback, keyframesRuleCallback, onlyActiveRules);\n    }\n  }\n} // add a string of cssText to the document.\n\n/**\n * @param {string} cssText\n * @param {string} moniker\n * @param {Node} target\n * @param {Node} contextNode\n * @return {HTMLStyleElement}\n */\n\nfunction applyCss(cssText, moniker, target, contextNode) {\n  let style = createScopeStyle(cssText, moniker);\n  applyStyle(style, target, contextNode);\n  return style;\n}\n/**\n * @param {string} cssText\n * @param {string} moniker\n * @return {HTMLStyleElement}\n */\n\nfunction createScopeStyle(cssText, moniker) {\n  let style =\n  /** @type {HTMLStyleElement} */\n  document.createElement('style');\n\n  if (moniker) {\n    style.setAttribute('scope', moniker);\n  }\n\n  style.textContent = cssText;\n  return style;\n}\n/**\n * Track the position of the last added style for placing placeholders\n * @type {Node}\n */\n\nlet lastHeadApplyNode = null; // insert a comment node as a styling position placeholder.\n\n/**\n * @param {string} moniker\n * @return {!Comment}\n */\n\nfunction applyStylePlaceHolder(moniker) {\n  let placeHolder = document.createComment(' Shady DOM styles for ' + moniker + ' ');\n  let after = lastHeadApplyNode ? lastHeadApplyNode['nextSibling'] : null;\n  let scope = document.head;\n  scope.insertBefore(placeHolder, after || scope.firstChild);\n  lastHeadApplyNode = placeHolder;\n  return placeHolder;\n}\n/**\n * @param {HTMLStyleElement} style\n * @param {?Node} target\n * @param {?Node} contextNode\n */\n\nfunction applyStyle(style, target, contextNode) {\n  target = target || document.head;\n  let after = contextNode && contextNode.nextSibling || target.firstChild;\n  target.insertBefore(style, after);\n\n  if (!lastHeadApplyNode) {\n    lastHeadApplyNode = style;\n  } else {\n    // only update lastHeadApplyNode if the new style is inserted after the old lastHeadApplyNode\n    let position = style.compareDocumentPosition(lastHeadApplyNode);\n\n    if (position === Node.DOCUMENT_POSITION_PRECEDING) {\n      lastHeadApplyNode = style;\n    }\n  }\n}\n/**\n * @param {string} buildType\n * @return {boolean}\n */\n\nfunction isTargetedBuild(buildType) {\n  return _style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeShadow ? buildType === 'shadow' : buildType === 'shady';\n}\n/**\n * Walk from text[start] matching parens and\n * returns position of the outer end paren\n * @param {string} text\n * @param {number} start\n * @return {number}\n */\n\nfunction findMatchingParen(text, start) {\n  let level = 0;\n\n  for (let i = start, l = text.length; i < l; i++) {\n    if (text[i] === '(') {\n      level++;\n    } else if (text[i] === ')') {\n      if (--level === 0) {\n        return i;\n      }\n    }\n  }\n\n  return -1;\n}\n/**\n * @param {string} str\n * @param {function(string, string, string, string)} callback\n */\n\nfunction processVariableAndFallback(str, callback) {\n  // find 'var('\n  let start = str.indexOf('var(');\n\n  if (start === -1) {\n    // no var?, everything is prefix\n    return callback(str, '', '', '');\n  } //${prefix}var(${inner})${suffix}\n\n\n  let end = findMatchingParen(str, start + 3);\n  let inner = str.substring(start + 4, end);\n  let prefix = str.substring(0, start); // suffix may have other variables\n\n  let suffix = processVariableAndFallback(str.substring(end + 1), callback);\n  let comma = inner.indexOf(','); // value and fallback args should be trimmed to match in property lookup\n\n  if (comma === -1) {\n    // variable, no fallback\n    return callback(prefix, inner.trim(), '', suffix);\n  } // var(${value},${fallback})\n\n\n  let value = inner.substring(0, comma).trim();\n  let fallback = inner.substring(comma + 1).trim();\n  return callback(prefix, value, fallback, suffix);\n}\n/**\n * @param {Element} element\n * @param {string} value\n */\n\nfunction setElementClassRaw(element, value) {\n  // use native setAttribute provided by ShadyDOM when setAttribute is patched\n  if (_style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeShadow) {\n    element.setAttribute('class', value);\n  } else {\n    window['ShadyDOM']['nativeMethods']['setAttribute'].call(element, 'class', value);\n  }\n}\n/**\n * @type {function(*):*}\n */\n\nconst wrap = window['ShadyDOM'] && window['ShadyDOM']['wrap'] || (node => node);\n/**\n * @param {Element | {is: string, extends: string}} element\n * @return {{is: string, typeExtension: string}}\n */\n\nfunction getIsExtends(element) {\n  let localName = element['localName'];\n  let is = '',\n      typeExtension = '';\n  /*\n  NOTE: technically, this can be wrong for certain svg elements\n  with `-` in the name like `<font-face>`\n  */\n\n  if (localName) {\n    if (localName.indexOf('-') > -1) {\n      is = localName;\n    } else {\n      typeExtension = localName;\n      is = element.getAttribute && element.getAttribute('is') || '';\n    }\n  } else {\n    is =\n    /** @type {?} */\n    element.is;\n    typeExtension =\n    /** @type {?} */\n    element.extends;\n  }\n\n  return {\n    is,\n    typeExtension\n  };\n}\n/**\n * @param {Element|DocumentFragment} element\n * @return {string}\n */\n\nfunction gatherStyleText(element) {\n  /** @type {!Array<string>} */\n  const styleTextParts = [];\n  const styles =\n  /** @type {!NodeList<!HTMLStyleElement>} */\n  element.querySelectorAll('style');\n\n  for (let i = 0; i < styles.length; i++) {\n    const style = styles[i];\n\n    if ((0,_unscoped_style_handler_js__WEBPACK_IMPORTED_MODULE_2__.isUnscopedStyle)(style)) {\n      if (!_style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeShadow) {\n        (0,_unscoped_style_handler_js__WEBPACK_IMPORTED_MODULE_2__.processUnscopedStyle)(style);\n        style.parentNode.removeChild(style);\n      }\n    } else {\n      styleTextParts.push(style.textContent);\n      style.parentNode.removeChild(style);\n    }\n  }\n\n  return styleTextParts.join('').trim();\n}\n/**\n * Split a selector separated by commas into an array in a smart way\n * @param {string} selector\n * @return {!Array<string>}\n */\n\nfunction splitSelectorList(selector) {\n  const parts = [];\n  let part = '';\n\n  for (let i = 0; i >= 0 && i < selector.length; i++) {\n    // A selector with parentheses will be one complete part\n    if (selector[i] === '(') {\n      // find the matching paren\n      const end = findMatchingParen(selector, i); // push the paren block into the part\n\n      part += selector.slice(i, end + 1); // move the index to after the paren block\n\n      i = end;\n    } else if (selector[i] === ',') {\n      parts.push(part);\n      part = '';\n    } else {\n      part += selector[i];\n    }\n  } // catch any pieces after the last comma\n\n\n  if (part) {\n    parts.push(part);\n  }\n\n  return parts;\n}\nconst CSS_BUILD_ATTR = 'css-build';\n/**\n * Return the polymer-css-build \"build type\" applied to this element\n *\n * @param {!HTMLElement} element\n * @return {string} Can be \"\", \"shady\", or \"shadow\"\n */\n\nfunction getCssBuild(element) {\n  if (_style_settings_js__WEBPACK_IMPORTED_MODULE_0__.cssBuild !== undefined) {\n    return (\n      /** @type {string} */\n      _style_settings_js__WEBPACK_IMPORTED_MODULE_0__.cssBuild\n    );\n  }\n\n  if (element.__cssBuild === undefined) {\n    // try attribute first, as it is the common case\n    const attrValue = element.getAttribute(CSS_BUILD_ATTR);\n\n    if (attrValue) {\n      element.__cssBuild = attrValue;\n    } else {\n      const buildComment = getBuildComment(element);\n\n      if (buildComment !== '') {\n        // remove build comment so it is not needlessly copied into every element instance\n        removeBuildComment(element);\n      }\n\n      element.__cssBuild = buildComment;\n    }\n  }\n\n  return element.__cssBuild || '';\n}\n/**\n * Check if the given element, either a <template> or <style>, has been processed\n * by polymer-css-build.\n *\n * If so, then we can make a number of optimizations:\n * - polymer-css-build will decompose mixins into individual CSS Custom Properties,\n * so the ApplyShim can be skipped entirely.\n * - Under native ShadowDOM, the style text can just be copied into each instance\n * without modification\n * - If the build is \"shady\" and ShadyDOM is in use, the styling does not need\n * scoping beyond the shimming of CSS Custom Properties\n *\n * @param {!HTMLElement} element\n * @return {boolean}\n */\n\nfunction elementHasBuiltCss(element) {\n  return getCssBuild(element) !== '';\n}\n/**\n * For templates made with tagged template literals, polymer-css-build will\n * insert a comment of the form `<!--css-build:shadow-->`\n *\n * @param {!HTMLElement} element\n * @return {string}\n */\n\nfunction getBuildComment(element) {\n  const buildComment = element.localName === 'template' ?\n  /** @type {!HTMLTemplateElement} */\n  element.content.firstChild : element.firstChild;\n\n  if (buildComment instanceof Comment) {\n    const commentParts = buildComment.textContent.trim().split(':');\n\n    if (commentParts[0] === CSS_BUILD_ATTR) {\n      return commentParts[1];\n    }\n  }\n\n  return '';\n}\n/**\n * Check if the css build status is optimal, and do no unneeded work.\n *\n * @param {string=} cssBuild CSS build status\n * @return {boolean} css build is optimal or not\n */\n\nfunction isOptimalCssBuild(cssBuild = '') {\n  // CSS custom property shim always requires work\n  if (cssBuild === '' || !_style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeCssVariables) {\n    return false;\n  }\n\n  return _style_settings_js__WEBPACK_IMPORTED_MODULE_0__.nativeShadow ? cssBuild === 'shadow' : cssBuild === 'shady';\n}\n/**\n * @param {!HTMLElement} element\n */\n\nfunction removeBuildComment(element) {\n  const buildComment = element.localName === 'template' ?\n  /** @type {!HTMLTemplateElement} */\n  element.content.firstChild : element.firstChild;\n  buildComment.parentNode.removeChild(buildComment);\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/style-util.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/template-map.js":
/*!******************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/template-map.js ***!
  \******************************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * @const {!Object<string, !HTMLTemplateElement>}\n */\n\nconst templateMap = {};\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (templateMap);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvQHdlYmNvbXBvbmVudHMvc2hhZHljc3Mvc3JjL3RlbXBsYXRlLW1hcC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vbm9kZV9tb2R1bGVzL0B3ZWJjb21wb25lbnRzL3NoYWR5Y3NzL3NyYy90ZW1wbGF0ZS1tYXAuanM/OTc0NCJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbkBsaWNlbnNlXG5Db3B5cmlnaHQgKGMpIDIwMTcgVGhlIFBvbHltZXIgUHJvamVjdCBBdXRob3JzLiBBbGwgcmlnaHRzIHJlc2VydmVkLlxuVGhpcyBjb2RlIG1heSBvbmx5IGJlIHVzZWQgdW5kZXIgdGhlIEJTRCBzdHlsZSBsaWNlbnNlIGZvdW5kIGF0IGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9MSUNFTlNFLnR4dFxuVGhlIGNvbXBsZXRlIHNldCBvZiBhdXRob3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQVVUSE9SUy50eHRcblRoZSBjb21wbGV0ZSBzZXQgb2YgY29udHJpYnV0b3JzIG1heSBiZSBmb3VuZCBhdCBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQ09OVFJJQlVUT1JTLnR4dFxuQ29kZSBkaXN0cmlidXRlZCBieSBHb29nbGUgYXMgcGFydCBvZiB0aGUgcG9seW1lciBwcm9qZWN0IGlzIGFsc29cbnN1YmplY3QgdG8gYW4gYWRkaXRpb25hbCBJUCByaWdodHMgZ3JhbnQgZm91bmQgYXQgaHR0cDovL3BvbHltZXIuZ2l0aHViLmlvL1BBVEVOVFMudHh0XG4qL1xuXG4ndXNlIHN0cmljdCc7XG5cbi8qKlxuICogQGNvbnN0IHshT2JqZWN0PHN0cmluZywgIUhUTUxUZW1wbGF0ZUVsZW1lbnQ+fVxuICovXG5jb25zdCB0ZW1wbGF0ZU1hcCA9IHt9O1xuZXhwb3J0IGRlZmF1bHQgdGVtcGxhdGVNYXA7XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTs7Ozs7Ozs7O0FBVUE7QUFFQTs7OztBQUdBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/template-map.js\n");

/***/ }),

/***/ "./node_modules/@webcomponents/shadycss/src/unscoped-style-handler.js":
/*!****************************************************************************!*\
  !*** ./node_modules/@webcomponents/shadycss/src/unscoped-style-handler.js ***!
  \****************************************************************************/
/*! namespace exports */
/*! export isUnscopedStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export processUnscopedStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export scopingAttribute [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"scopingAttribute\": () => /* binding */ scopingAttribute,\n/* harmony export */   \"processUnscopedStyle\": () => /* binding */ processUnscopedStyle,\n/* harmony export */   \"isUnscopedStyle\": () => /* binding */ isUnscopedStyle\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2017 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/** @type {!Set<string>} */\n\nconst styleTextSet = new Set();\nconst scopingAttribute = 'shady-unscoped';\n/**\n * Add a specifically-marked style to the document directly, and only one copy of that style.\n *\n * @param {!HTMLStyleElement} style\n * @return {undefined}\n */\n\nfunction processUnscopedStyle(style) {\n  const text = style.textContent;\n\n  if (!styleTextSet.has(text)) {\n    styleTextSet.add(text);\n    const newStyle = style.cloneNode(true);\n    document.head.appendChild(newStyle);\n  }\n}\n/**\n * Check if a style is supposed to be unscoped\n * @param {!HTMLStyleElement} style\n * @return {boolean} true if the style has the unscoping attribute\n */\n\nfunction isUnscopedStyle(style) {\n  return style.hasAttribute(scopingAttribute);\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/@webcomponents/shadycss/src/unscoped-style-handler.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/collection.js":
/*!*********************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/collection.js ***!
  \*********************************************************************/
/*! namespace exports */
/*! export createCollection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getCollection [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"getCollection\": () => /* binding */ getCollection,\n/* harmony export */   \"createCollection\": () => /* binding */ createCollection\n/* harmony export */ });\n/* harmony import */ var _store_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./store.js */ \"./node_modules/home-assistant-js-websocket/dist/store.js\");\n\nconst getCollection = (conn, key, fetchCollection, subscribeUpdates) => {\n  if (conn[key]) {\n    return conn[key];\n  }\n\n  let active = 0;\n  let unsubProm;\n  let store = (0,_store_js__WEBPACK_IMPORTED_MODULE_0__.createStore)();\n\n  const refresh = () => fetchCollection(conn).then(state => store.setState(state, true));\n\n  const refreshSwallow = () => refresh().catch(err => {\n    // Swallow errors if socket is connecting, closing or closed.\n    // We will automatically call refresh again when we re-establish the connection.\n    if (conn.connected) {\n      throw err;\n    }\n  });\n\n  conn[key] = {\n    get state() {\n      return store.state;\n    },\n\n    refresh,\n\n    subscribe(subscriber) {\n      active++; // If this was the first subscriber, attach collection\n\n      if (active === 1) {\n        if (subscribeUpdates) {\n          unsubProm = subscribeUpdates(conn, store);\n        } // Fetch when connection re-established.\n\n\n        conn.addEventListener(\"ready\", refreshSwallow);\n        refreshSwallow();\n      }\n\n      const unsub = store.subscribe(subscriber);\n\n      if (store.state !== undefined) {\n        // Don't call it right away so that caller has time\n        // to initialize all the things.\n        setTimeout(() => subscriber(store.state), 0);\n      }\n\n      return () => {\n        unsub();\n        active--;\n\n        if (!active) {\n          // Unsubscribe from changes\n          if (unsubProm) unsubProm.then(unsub => {\n            unsub();\n          });\n          conn.removeEventListener(\"ready\", refresh);\n        }\n      };\n    }\n\n  };\n  return conn[key];\n}; // Legacy name. It gets a collection and subscribes.\n\nconst createCollection = (key, fetchCollection, subscribeUpdates, conn, onChange) => getCollection(conn, key, fetchCollection, subscribeUpdates).subscribe(onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/collection.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/commands.js":
/*!*******************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/commands.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export callService [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getConfig [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getServices [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getStates [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getUser [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"getStates\": () => /* binding */ getStates,\n/* harmony export */   \"getServices\": () => /* binding */ getServices,\n/* harmony export */   \"getConfig\": () => /* binding */ getConfig,\n/* harmony export */   \"getUser\": () => /* binding */ getUser,\n/* harmony export */   \"callService\": () => /* binding */ callService\n/* harmony export */ });\n/* harmony import */ var _messages_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./messages.js */ \"./node_modules/home-assistant-js-websocket/dist/messages.js\");\n\nconst getStates = connection => connection.sendMessagePromise(_messages_js__WEBPACK_IMPORTED_MODULE_0__.states());\nconst getServices = connection => connection.sendMessagePromise(_messages_js__WEBPACK_IMPORTED_MODULE_0__.services());\nconst getConfig = connection => connection.sendMessagePromise(_messages_js__WEBPACK_IMPORTED_MODULE_0__.config());\nconst getUser = connection => connection.sendMessagePromise(_messages_js__WEBPACK_IMPORTED_MODULE_0__.user());\nconst callService = (connection, domain, service, serviceData) => connection.sendMessagePromise(_messages_js__WEBPACK_IMPORTED_MODULE_0__.callService(domain, service, serviceData));//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0L2Rpc3QvY29tbWFuZHMuanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL25vZGVfbW9kdWxlcy9ob21lLWFzc2lzdGFudC1qcy13ZWJzb2NrZXQvZGlzdC9jb21tYW5kcy5qcz8yYzg0Il0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCAqIGFzIG1lc3NhZ2VzIGZyb20gXCIuL21lc3NhZ2VzLmpzXCI7XG5leHBvcnQgY29uc3QgZ2V0U3RhdGVzID0gKGNvbm5lY3Rpb24pID0+IGNvbm5lY3Rpb24uc2VuZE1lc3NhZ2VQcm9taXNlKG1lc3NhZ2VzLnN0YXRlcygpKTtcbmV4cG9ydCBjb25zdCBnZXRTZXJ2aWNlcyA9IChjb25uZWN0aW9uKSA9PiBjb25uZWN0aW9uLnNlbmRNZXNzYWdlUHJvbWlzZShtZXNzYWdlcy5zZXJ2aWNlcygpKTtcbmV4cG9ydCBjb25zdCBnZXRDb25maWcgPSAoY29ubmVjdGlvbikgPT4gY29ubmVjdGlvbi5zZW5kTWVzc2FnZVByb21pc2UobWVzc2FnZXMuY29uZmlnKCkpO1xuZXhwb3J0IGNvbnN0IGdldFVzZXIgPSAoY29ubmVjdGlvbikgPT4gY29ubmVjdGlvbi5zZW5kTWVzc2FnZVByb21pc2UobWVzc2FnZXMudXNlcigpKTtcbmV4cG9ydCBjb25zdCBjYWxsU2VydmljZSA9IChjb25uZWN0aW9uLCBkb21haW4sIHNlcnZpY2UsIHNlcnZpY2VEYXRhKSA9PiBjb25uZWN0aW9uLnNlbmRNZXNzYWdlUHJvbWlzZShtZXNzYWdlcy5jYWxsU2VydmljZShkb21haW4sIHNlcnZpY2UsIHNlcnZpY2VEYXRhKSk7XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7OztBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/commands.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/config.js":
/*!*****************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/config.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export STATE_FINAL_WRITE [provided] [no usage info] [missing usage info prevents renaming] */
/*! export STATE_NOT_RUNNING [provided] [no usage info] [missing usage info prevents renaming] */
/*! export STATE_RUNNING [provided] [no usage info] [missing usage info prevents renaming] */
/*! export STATE_STARTING [provided] [no usage info] [missing usage info prevents renaming] */
/*! export STATE_STOPPING [provided] [no usage info] [missing usage info prevents renaming] */
/*! export configColl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export subscribeConfig [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"configColl\": () => /* binding */ configColl,\n/* harmony export */   \"subscribeConfig\": () => /* binding */ subscribeConfig,\n/* harmony export */   \"STATE_NOT_RUNNING\": () => /* binding */ STATE_NOT_RUNNING,\n/* harmony export */   \"STATE_STARTING\": () => /* binding */ STATE_STARTING,\n/* harmony export */   \"STATE_RUNNING\": () => /* binding */ STATE_RUNNING,\n/* harmony export */   \"STATE_STOPPING\": () => /* binding */ STATE_STOPPING,\n/* harmony export */   \"STATE_FINAL_WRITE\": () => /* binding */ STATE_FINAL_WRITE\n/* harmony export */ });\n/* harmony import */ var _collection_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./collection.js */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n/* harmony import */ var _commands_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./commands.js */ \"./node_modules/home-assistant-js-websocket/dist/commands.js\");\n\n\n\nfunction processComponentLoaded(state, event) {\n  if (state === undefined) return null;\n  return {\n    components: state.components.concat(event.data.component)\n  };\n}\n\nconst fetchConfig = conn => (0,_commands_js__WEBPACK_IMPORTED_MODULE_0__.getConfig)(conn);\n\nconst subscribeUpdates = (conn, store) => Promise.all([conn.subscribeEvents(store.action(processComponentLoaded), \"component_loaded\"), conn.subscribeEvents(() => fetchConfig(conn).then(config => store.setState(config, true)), \"core_config_updated\")]).then(unsubs => () => unsubs.forEach(unsub => unsub()));\n\nconst configColl = conn => (0,_collection_js__WEBPACK_IMPORTED_MODULE_1__.getCollection)(conn, \"_cnf\", fetchConfig, subscribeUpdates);\nconst subscribeConfig = (conn, onChange) => configColl(conn).subscribe(onChange);\nconst STATE_NOT_RUNNING = \"NOT_RUNNING\";\nconst STATE_STARTING = \"STARTING\";\nconst STATE_RUNNING = \"RUNNING\";\nconst STATE_STOPPING = \"STOPPING\";\nconst STATE_FINAL_WRITE = \"FINAL_WRITE\";//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0L2Rpc3QvY29uZmlnLmpzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9ub2RlX21vZHVsZXMvaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0L2Rpc3QvY29uZmlnLmpzPzAzM2YiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgZ2V0Q29sbGVjdGlvbiB9IGZyb20gXCIuL2NvbGxlY3Rpb24uanNcIjtcbmltcG9ydCB7IGdldENvbmZpZyB9IGZyb20gXCIuL2NvbW1hbmRzLmpzXCI7XG5mdW5jdGlvbiBwcm9jZXNzQ29tcG9uZW50TG9hZGVkKHN0YXRlLCBldmVudCkge1xuICAgIGlmIChzdGF0ZSA9PT0gdW5kZWZpbmVkKVxuICAgICAgICByZXR1cm4gbnVsbDtcbiAgICByZXR1cm4ge1xuICAgICAgICBjb21wb25lbnRzOiBzdGF0ZS5jb21wb25lbnRzLmNvbmNhdChldmVudC5kYXRhLmNvbXBvbmVudCksXG4gICAgfTtcbn1cbmNvbnN0IGZldGNoQ29uZmlnID0gKGNvbm4pID0+IGdldENvbmZpZyhjb25uKTtcbmNvbnN0IHN1YnNjcmliZVVwZGF0ZXMgPSAoY29ubiwgc3RvcmUpID0+IFByb21pc2UuYWxsKFtcbiAgICBjb25uLnN1YnNjcmliZUV2ZW50cyhzdG9yZS5hY3Rpb24ocHJvY2Vzc0NvbXBvbmVudExvYWRlZCksIFwiY29tcG9uZW50X2xvYWRlZFwiKSxcbiAgICBjb25uLnN1YnNjcmliZUV2ZW50cygoKSA9PiBmZXRjaENvbmZpZyhjb25uKS50aGVuKChjb25maWcpID0+IHN0b3JlLnNldFN0YXRlKGNvbmZpZywgdHJ1ZSkpLCBcImNvcmVfY29uZmlnX3VwZGF0ZWRcIiksXG5dKS50aGVuKCh1bnN1YnMpID0+ICgpID0+IHVuc3Vicy5mb3JFYWNoKCh1bnN1YikgPT4gdW5zdWIoKSkpO1xuZXhwb3J0IGNvbnN0IGNvbmZpZ0NvbGwgPSAoY29ubikgPT4gZ2V0Q29sbGVjdGlvbihjb25uLCBcIl9jbmZcIiwgZmV0Y2hDb25maWcsIHN1YnNjcmliZVVwZGF0ZXMpO1xuZXhwb3J0IGNvbnN0IHN1YnNjcmliZUNvbmZpZyA9IChjb25uLCBvbkNoYW5nZSkgPT4gY29uZmlnQ29sbChjb25uKS5zdWJzY3JpYmUob25DaGFuZ2UpO1xuZXhwb3J0IGNvbnN0IFNUQVRFX05PVF9SVU5OSU5HID0gXCJOT1RfUlVOTklOR1wiO1xuZXhwb3J0IGNvbnN0IFNUQVRFX1NUQVJUSU5HID0gXCJTVEFSVElOR1wiO1xuZXhwb3J0IGNvbnN0IFNUQVRFX1JVTk5JTkcgPSBcIlJVTk5JTkdcIjtcbmV4cG9ydCBjb25zdCBTVEFURV9TVE9QUElORyA9IFwiU1RPUFBJTkdcIjtcbmV4cG9ydCBjb25zdCBTVEFURV9GSU5BTF9XUklURSA9IFwiRklOQUxfV1JJVEVcIjtcbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7Ozs7Ozs7O0FBQUE7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUVBO0FBQ0E7QUFEQTtBQUdBO0FBQ0E7QUFBQTtBQUNBO0FBQUE7QUFDQTtBQUdBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/config.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/entities.js":
/*!*******************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/entities.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export entitiesColl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export subscribeEntities [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"entitiesColl\": () => /* binding */ entitiesColl,\n/* harmony export */   \"subscribeEntities\": () => /* binding */ subscribeEntities\n/* harmony export */ });\n/* harmony import */ var _collection_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./collection.js */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n/* harmony import */ var _commands_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./commands.js */ \"./node_modules/home-assistant-js-websocket/dist/commands.js\");\n\n\n\nfunction processEvent(store, event) {\n  const state = store.state;\n  if (state === undefined) return;\n  const {\n    entity_id,\n    new_state\n  } = event.data;\n\n  if (new_state) {\n    store.setState({\n      [new_state.entity_id]: new_state\n    });\n  } else {\n    const newEntities = Object.assign({}, state);\n    delete newEntities[entity_id];\n    store.setState(newEntities, true);\n  }\n}\n\nasync function fetchEntities(conn) {\n  const states = await (0,_commands_js__WEBPACK_IMPORTED_MODULE_0__.getStates)(conn);\n  const entities = {};\n\n  for (let i = 0; i < states.length; i++) {\n    const state = states[i];\n    entities[state.entity_id] = state;\n  }\n\n  return entities;\n}\n\nconst subscribeUpdates = (conn, store) => conn.subscribeEvents(ev => processEvent(store, ev), \"state_changed\");\n\nconst entitiesColl = conn => (0,_collection_js__WEBPACK_IMPORTED_MODULE_1__.getCollection)(conn, \"_ent\", fetchEntities, subscribeUpdates);\nconst subscribeEntities = (conn, onChange) => entitiesColl(conn).subscribe(onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/entities.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/errors.js":
/*!*****************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/errors.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export ERR_CANNOT_CONNECT [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ERR_CONNECTION_LOST [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ERR_HASS_HOST_REQUIRED [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ERR_INVALID_AUTH [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ERR_INVALID_HTTPS_TO_HTTP [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"ERR_CANNOT_CONNECT\": () => /* binding */ ERR_CANNOT_CONNECT,\n/* harmony export */   \"ERR_INVALID_AUTH\": () => /* binding */ ERR_INVALID_AUTH,\n/* harmony export */   \"ERR_CONNECTION_LOST\": () => /* binding */ ERR_CONNECTION_LOST,\n/* harmony export */   \"ERR_HASS_HOST_REQUIRED\": () => /* binding */ ERR_HASS_HOST_REQUIRED,\n/* harmony export */   \"ERR_INVALID_HTTPS_TO_HTTP\": () => /* binding */ ERR_INVALID_HTTPS_TO_HTTP\n/* harmony export */ });\nconst ERR_CANNOT_CONNECT = 1;\nconst ERR_INVALID_AUTH = 2;\nconst ERR_CONNECTION_LOST = 3;\nconst ERR_HASS_HOST_REQUIRED = 4;\nconst ERR_INVALID_HTTPS_TO_HTTP = 5;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0L2Rpc3QvZXJyb3JzLmpzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9ub2RlX21vZHVsZXMvaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0L2Rpc3QvZXJyb3JzLmpzPzZjN2MiXSwic291cmNlc0NvbnRlbnQiOlsiZXhwb3J0IGNvbnN0IEVSUl9DQU5OT1RfQ09OTkVDVCA9IDE7XG5leHBvcnQgY29uc3QgRVJSX0lOVkFMSURfQVVUSCA9IDI7XG5leHBvcnQgY29uc3QgRVJSX0NPTk5FQ1RJT05fTE9TVCA9IDM7XG5leHBvcnQgY29uc3QgRVJSX0hBU1NfSE9TVF9SRVFVSVJFRCA9IDQ7XG5leHBvcnQgY29uc3QgRVJSX0lOVkFMSURfSFRUUFNfVE9fSFRUUCA9IDU7XG4iXSwibWFwcGluZ3MiOiI7Ozs7Ozs7O0FBQUE7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/errors.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/messages.js":
/*!*******************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/messages.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export auth [provided] [no usage info] [missing usage info prevents renaming] */
/*! export callService [provided] [no usage info] [missing usage info prevents renaming] */
/*! export config [provided] [no usage info] [missing usage info prevents renaming] */
/*! export error [provided] [no usage info] [missing usage info prevents renaming] */
/*! export ping [provided] [no usage info] [missing usage info prevents renaming] */
/*! export services [provided] [no usage info] [missing usage info prevents renaming] */
/*! export states [provided] [no usage info] [missing usage info prevents renaming] */
/*! export subscribeEvents [provided] [no usage info] [missing usage info prevents renaming] */
/*! export unsubscribeEvents [provided] [no usage info] [missing usage info prevents renaming] */
/*! export user [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"auth\": () => /* binding */ auth,\n/* harmony export */   \"states\": () => /* binding */ states,\n/* harmony export */   \"config\": () => /* binding */ config,\n/* harmony export */   \"services\": () => /* binding */ services,\n/* harmony export */   \"user\": () => /* binding */ user,\n/* harmony export */   \"callService\": () => /* binding */ callService,\n/* harmony export */   \"subscribeEvents\": () => /* binding */ subscribeEvents,\n/* harmony export */   \"unsubscribeEvents\": () => /* binding */ unsubscribeEvents,\n/* harmony export */   \"ping\": () => /* binding */ ping,\n/* harmony export */   \"error\": () => /* binding */ error\n/* harmony export */ });\nfunction auth(accessToken) {\n  return {\n    type: \"auth\",\n    access_token: accessToken\n  };\n}\nfunction states() {\n  return {\n    type: \"get_states\"\n  };\n}\nfunction config() {\n  return {\n    type: \"get_config\"\n  };\n}\nfunction services() {\n  return {\n    type: \"get_services\"\n  };\n}\nfunction user() {\n  return {\n    type: \"auth/current_user\"\n  };\n}\nfunction callService(domain, service, serviceData) {\n  const message = {\n    type: \"call_service\",\n    domain,\n    service\n  };\n\n  if (serviceData) {\n    message.service_data = serviceData;\n  }\n\n  return message;\n}\nfunction subscribeEvents(eventType) {\n  const message = {\n    type: \"subscribe_events\"\n  };\n\n  if (eventType) {\n    message.event_type = eventType;\n  }\n\n  return message;\n}\nfunction unsubscribeEvents(subscription) {\n  return {\n    type: \"unsubscribe_events\",\n    subscription\n  };\n}\nfunction ping() {\n  return {\n    type: \"ping\"\n  };\n}\nfunction error(code, message) {\n  return {\n    type: \"result\",\n    success: false,\n    error: {\n      code,\n      message\n    }\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/messages.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/services.js":
/*!*******************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/services.js ***!
  \*******************************************************************/
/*! namespace exports */
/*! export servicesColl [provided] [no usage info] [missing usage info prevents renaming] */
/*! export subscribeServices [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"servicesColl\": () => /* binding */ servicesColl,\n/* harmony export */   \"subscribeServices\": () => /* binding */ subscribeServices\n/* harmony export */ });\n/* harmony import */ var _collection_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./collection.js */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n/* harmony import */ var _commands_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./commands.js */ \"./node_modules/home-assistant-js-websocket/dist/commands.js\");\n\n\n\nfunction processServiceRegistered(state, event) {\n  if (state === undefined) return null;\n  const {\n    domain,\n    service\n  } = event.data;\n  const domainInfo = Object.assign({}, state[domain], {\n    [service]: {\n      description: \"\",\n      fields: {}\n    }\n  });\n  return {\n    [domain]: domainInfo\n  };\n}\n\nfunction processServiceRemoved(state, event) {\n  if (state === undefined) return null;\n  const {\n    domain,\n    service\n  } = event.data;\n  const curDomainInfo = state[domain];\n  if (!curDomainInfo || !(service in curDomainInfo)) return null;\n  const domainInfo = {};\n  Object.keys(curDomainInfo).forEach(sKey => {\n    if (sKey !== service) domainInfo[sKey] = curDomainInfo[sKey];\n  });\n  return {\n    [domain]: domainInfo\n  };\n}\n\nconst fetchServices = conn => (0,_commands_js__WEBPACK_IMPORTED_MODULE_0__.getServices)(conn);\n\nconst subscribeUpdates = (conn, store) => Promise.all([conn.subscribeEvents(store.action(processServiceRegistered), \"service_registered\"), conn.subscribeEvents(store.action(processServiceRemoved), \"service_removed\")]).then(unsubs => () => unsubs.forEach(fn => fn()));\n\nconst servicesColl = conn => (0,_collection_js__WEBPACK_IMPORTED_MODULE_1__.getCollection)(conn, \"_srv\", fetchServices, subscribeUpdates);\nconst subscribeServices = (conn, onChange) => servicesColl(conn).subscribe(onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/services.js\n");

/***/ }),

/***/ "./node_modules/home-assistant-js-websocket/dist/store.js":
/*!****************************************************************!*\
  !*** ./node_modules/home-assistant-js-websocket/dist/store.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export createStore [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"createStore\": () => /* binding */ createStore\n/* harmony export */ });\nconst createStore = state => {\n  let listeners = [];\n\n  function unsubscribe(listener) {\n    let out = [];\n\n    for (let i = 0; i < listeners.length; i++) {\n      if (listeners[i] === listener) {\n        listener = null;\n      } else {\n        out.push(listeners[i]);\n      }\n    }\n\n    listeners = out;\n  }\n\n  function setState(update, overwrite) {\n    state = overwrite ? update : Object.assign(Object.assign({}, state), update);\n    let currentListeners = listeners;\n\n    for (let i = 0; i < currentListeners.length; i++) {\n      currentListeners[i](state);\n    }\n  }\n  /**\n   * An observable state container, returned from {@link createStore}\n   * @name store\n   */\n\n\n  return {\n    get state() {\n      return state;\n    },\n\n    /**\n     * Create a bound copy of the given action function.\n     * The bound returned function invokes action() and persists the result back to the store.\n     * If the return value of `action` is a Promise, the resolved value will be used as state.\n     * @param {Function} action\tAn action of the form `action(state, ...args) -> stateUpdate`\n     * @returns {Function} boundAction()\n     */\n    action(action) {\n      function apply(result) {\n        setState(result, false);\n      } // Note: perf tests verifying this implementation: https://esbench.com/bench/5a295e6299634800a0349500\n\n\n      return function () {\n        let args = [state];\n\n        for (let i = 0; i < arguments.length; i++) args.push(arguments[i]); // @ts-ignore\n\n\n        let ret = action.apply(this, args);\n\n        if (ret != null) {\n          return ret instanceof Promise ? ret.then(apply) : apply(ret);\n        }\n      };\n    },\n\n    /**\n     * Apply a partial state object to the current state, invoking registered listeners.\n     * @param {Object} update\t\t\t\tAn object with properties to be merged into state\n     * @param {Boolean} [overwrite=false]\tIf `true`, update will replace state instead of being merged into it\n     */\n    setState,\n\n    /**\n     * Register a listener function to be called whenever state is changed. Returns an `unsubscribe()` function.\n     * @param {Function} listener\tA function to call when state changes. Gets passed the new state.\n     * @returns {Function} unsubscribe()\n     */\n    subscribe(listener) {\n      listeners.push(listener);\n      return () => {\n        unsubscribe(listener);\n      };\n    } // /**\n    //  * Remove a previously-registered listener function.\n    //  * @param {Function} listener\tThe callback previously passed to `subscribe()` that should be removed.\n    //  * @function\n    //  */\n    // unsubscribe,\n\n\n  };\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/home-assistant-js-websocket/dist/store.js\n");

/***/ }),

/***/ "./node_modules/intl-format-cache/lib/index.js":
/*!*****************************************************!*\
  !*** ./node_modules/intl-format-cache/lib/index.js ***!
  \*****************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/*\nCopyright (c) 2014, Yahoo! Inc. All rights reserved.\nCopyrights licensed under the New BSD License.\nSee the accompanying LICENSE file for terms.\n*/\nvar __spreadArrays = undefined && undefined.__spreadArrays || function () {\n  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;\n\n  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];\n\n  return r;\n}; // -- Utilities ----------------------------------------------------------------\n\n\nfunction getCacheId(inputs) {\n  return JSON.stringify(inputs.map(function (input) {\n    return input && typeof input === 'object' ? orderedProps(input) : input;\n  }));\n}\n\nfunction orderedProps(obj) {\n  return Object.keys(obj).sort().map(function (k) {\n    var _a;\n\n    return _a = {}, _a[k] = obj[k], _a;\n  });\n}\n\nvar memoizeFormatConstructor = function (FormatConstructor, cache) {\n  if (cache === void 0) {\n    cache = {};\n  }\n\n  return function () {\n    var _a;\n\n    var args = [];\n\n    for (var _i = 0; _i < arguments.length; _i++) {\n      args[_i] = arguments[_i];\n    }\n\n    var cacheId = getCacheId(args);\n    var format = cacheId && cache[cacheId];\n\n    if (!format) {\n      format = new ((_a = FormatConstructor).bind.apply(_a, __spreadArrays([void 0], args)))();\n\n      if (cacheId) {\n        cache[cacheId] = format;\n      }\n    }\n\n    return format;\n  };\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (memoizeFormatConstructor);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/intl-format-cache/lib/index.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat-parser/lib/index.js":
/*!*************************************************************!*\
  !*** ./node_modules/intl-messageformat-parser/lib/index.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export SKELETON_TYPE [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .SKELETON_TYPE */
/*! export SyntaxError [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/parser.js .SyntaxError */
/*! export TYPE [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .TYPE */
/*! export convertNumberSkeletonToNumberFormatOptions [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/skeleton.js .convertNumberSkeletonToNumberFormatOptions */
/*! export createLiteralElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .createLiteralElement */
/*! export createNumberElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .createNumberElement */
/*! export isArgumentElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isArgumentElement */
/*! export isDateElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isDateElement */
/*! export isDateTimeSkeleton [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isDateTimeSkeleton */
/*! export isLiteralElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isLiteralElement */
/*! export isNumberElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isNumberElement */
/*! export isNumberSkeleton [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isNumberSkeleton */
/*! export isPluralElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isPluralElement */
/*! export isPoundElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isPoundElement */
/*! export isSelectElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isSelectElement */
/*! export isTagElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isTagElement */
/*! export isTimeElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/types.js .isTimeElement */
/*! export parse [provided] [no usage info] [missing usage info prevents renaming] */
/*! export parseDateTimeSkeleton [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/skeleton.js .parseDateTimeSkeleton */
/*! export pegParse [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat-parser/lib/parser.js .pegParse */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"SKELETON_TYPE\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.SKELETON_TYPE,\n/* harmony export */   \"TYPE\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.TYPE,\n/* harmony export */   \"createLiteralElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.createLiteralElement,\n/* harmony export */   \"createNumberElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.createNumberElement,\n/* harmony export */   \"isArgumentElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isArgumentElement,\n/* harmony export */   \"isDateElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isDateElement,\n/* harmony export */   \"isDateTimeSkeleton\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isDateTimeSkeleton,\n/* harmony export */   \"isLiteralElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isLiteralElement,\n/* harmony export */   \"isNumberElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isNumberElement,\n/* harmony export */   \"isNumberSkeleton\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isNumberSkeleton,\n/* harmony export */   \"isPluralElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isPluralElement,\n/* harmony export */   \"isPoundElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isPoundElement,\n/* harmony export */   \"isSelectElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isSelectElement,\n/* harmony export */   \"isTagElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isTagElement,\n/* harmony export */   \"isTimeElement\": () => /* reexport safe */ _types__WEBPACK_IMPORTED_MODULE_0__.isTimeElement,\n/* harmony export */   \"SyntaxError\": () => /* reexport safe */ _parser__WEBPACK_IMPORTED_MODULE_1__.SyntaxError,\n/* harmony export */   \"pegParse\": () => /* reexport safe */ _parser__WEBPACK_IMPORTED_MODULE_1__.pegParse,\n/* harmony export */   \"convertNumberSkeletonToNumberFormatOptions\": () => /* reexport safe */ _skeleton__WEBPACK_IMPORTED_MODULE_2__.convertNumberSkeletonToNumberFormatOptions,\n/* harmony export */   \"parseDateTimeSkeleton\": () => /* reexport safe */ _skeleton__WEBPACK_IMPORTED_MODULE_2__.parseDateTimeSkeleton,\n/* harmony export */   \"parse\": () => /* binding */ parse\n/* harmony export */ });\n/* harmony import */ var _parser__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./parser */ \"./node_modules/intl-messageformat-parser/lib/parser.js\");\n/* harmony import */ var _normalize__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./normalize */ \"./node_modules/intl-messageformat-parser/lib/normalize.js\");\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ \"./node_modules/intl-messageformat-parser/lib/types.js\");\n/* harmony import */ var _skeleton__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./skeleton */ \"./node_modules/intl-messageformat-parser/lib/skeleton.js\");\n\n\n\n\n\nfunction parse(input, opts) {\n  var els = (0,_parser__WEBPACK_IMPORTED_MODULE_1__.pegParse)(input, opts);\n\n  if (!opts || opts.normalizeHashtagInPlural !== false) {\n    (0,_normalize__WEBPACK_IMPORTED_MODULE_3__.normalizeHashtagInPlural)(els);\n  }\n\n  return els;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvaW50bC1tZXNzYWdlZm9ybWF0LXBhcnNlci9saWIvaW5kZXguanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uLi9zcmMvaW5kZXgudHM/NmYzNyJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBwZWdQYXJzZSB9IGZyb20gJy4vcGFyc2VyJztcbmltcG9ydCB7IG5vcm1hbGl6ZUhhc2h0YWdJblBsdXJhbCB9IGZyb20gJy4vbm9ybWFsaXplJztcbmV4cG9ydCAqIGZyb20gJy4vdHlwZXMnO1xuZXhwb3J0ICogZnJvbSAnLi9wYXJzZXInO1xuZXhwb3J0ICogZnJvbSAnLi9za2VsZXRvbic7XG5leHBvcnQgZnVuY3Rpb24gcGFyc2UoaW5wdXQsIG9wdHMpIHtcbiAgICB2YXIgZWxzID0gcGVnUGFyc2UoaW5wdXQsIG9wdHMpO1xuICAgIGlmICghb3B0cyB8fCBvcHRzLm5vcm1hbGl6ZUhhc2h0YWdJblBsdXJhbCAhPT0gZmFsc2UpIHtcbiAgICAgICAgbm9ybWFsaXplSGFzaHRhZ0luUGx1cmFsKGVscyk7XG4gICAgfVxuICAgIHJldHVybiBlbHM7XG59XG4vLyMgc291cmNlTWFwcGluZ1VSTD1pbmRleC5qcy5tYXAiXSwibWFwcGluZ3MiOiI7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7OztBQUFBO0FBRUE7QUFDQTtBQUNBO0FBQ0E7QUFJQTtBQUlBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat-parser/lib/index.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat-parser/lib/normalize.js":
/*!*****************************************************************!*\
  !*** ./node_modules/intl-messageformat-parser/lib/normalize.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export normalizeHashtagInPlural [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"normalizeHashtagInPlural\": () => /* binding */ normalizeHashtagInPlural\n/* harmony export */ });\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ \"./node_modules/intl-messageformat-parser/lib/types.js\");\n/* harmony import */ var _parser__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./parser */ \"./node_modules/intl-messageformat-parser/lib/parser.js\");\nvar __spreadArrays = undefined && undefined.__spreadArrays || function () {\n  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;\n\n  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];\n\n  return r;\n};\n\n\n\nvar PLURAL_HASHTAG_REGEX = /(^|[^\\\\])#/g;\n/**\n * Whether to convert `#` in plural rule options\n * to `{var, number}`\n * @param el AST Element\n * @param pluralStack current plural stack\n */\n\nfunction normalizeHashtagInPlural(els) {\n  els.forEach(function (el) {\n    // If we're encountering a plural el\n    if (!(0,_types__WEBPACK_IMPORTED_MODULE_0__.isPluralElement)(el) && !(0,_types__WEBPACK_IMPORTED_MODULE_0__.isSelectElement)(el)) {\n      return;\n    } // Go down the options and search for # in any literal element\n\n\n    Object.keys(el.options).forEach(function (id) {\n      var _a;\n\n      var opt = el.options[id]; // If we got a match, we have to split this\n      // and inject a NumberElement in the middle\n\n      var matchingLiteralElIndex = -1;\n      var literalEl = undefined;\n\n      for (var i = 0; i < opt.value.length; i++) {\n        var el_1 = opt.value[i];\n\n        if ((0,_types__WEBPACK_IMPORTED_MODULE_0__.isLiteralElement)(el_1) && PLURAL_HASHTAG_REGEX.test(el_1.value)) {\n          matchingLiteralElIndex = i;\n          literalEl = el_1;\n          break;\n        }\n      }\n\n      if (literalEl) {\n        var newValue = literalEl.value.replace(PLURAL_HASHTAG_REGEX, \"$1{\" + el.value + \", number}\");\n        var newEls = (0,_parser__WEBPACK_IMPORTED_MODULE_1__.pegParse)(newValue);\n\n        (_a = opt.value).splice.apply(_a, __spreadArrays([matchingLiteralElIndex, 1], newEls));\n      }\n\n      normalizeHashtagInPlural(opt.value);\n    });\n  });\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat-parser/lib/normalize.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat-parser/lib/parser.js":
/*!**************************************************************!*\
  !*** ./node_modules/intl-messageformat-parser/lib/parser.js ***!
  \**************************************************************/
/*! namespace exports */
/*! export SyntaxError [provided] [no usage info] [missing usage info prevents renaming] */
/*! export pegParse [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"SyntaxError\": () => /* binding */ SyntaxError,\n/* harmony export */   \"pegParse\": () => /* binding */ pegParse\n/* harmony export */ });\n/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./types */ \"./node_modules/intl-messageformat-parser/lib/types.js\");\n// tslint:disable:only-arrow-functions\n// tslint:disable:object-literal-shorthand\n// tslint:disable:trailing-comma\n// tslint:disable:object-literal-sort-keys\n// tslint:disable:one-variable-per-declaration\n// tslint:disable:max-line-length\n// tslint:disable:no-consecutive-blank-lines\n// tslint:disable:align\nvar __extends = undefined && undefined.__extends || function () {\n  var extendStatics = function (d, b) {\n    extendStatics = Object.setPrototypeOf || {\n      __proto__: []\n    } instanceof Array && function (d, b) {\n      d.__proto__ = b;\n    } || function (d, b) {\n      for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];\n    };\n\n    return extendStatics(d, b);\n  };\n\n  return function (d, b) {\n    extendStatics(d, b);\n\n    function __() {\n      this.constructor = d;\n    }\n\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n  };\n}();\n\nvar __assign = undefined && undefined.__assign || function () {\n  __assign = Object.assign || function (t) {\n    for (var s, i = 1, n = arguments.length; i < n; i++) {\n      s = arguments[i];\n\n      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\n    }\n\n    return t;\n  };\n\n  return __assign.apply(this, arguments);\n}; // Generated by PEG.js v. 0.10.0 (ts-pegjs plugin v. 0.2.6 )\n//\n// https://pegjs.org/   https://github.com/metadevpro/ts-pegjs\n\n\n\n\nvar SyntaxError =\n/** @class */\nfunction (_super) {\n  __extends(SyntaxError, _super);\n\n  function SyntaxError(message, expected, found, location) {\n    var _this = _super.call(this) || this;\n\n    _this.message = message;\n    _this.expected = expected;\n    _this.found = found;\n    _this.location = location;\n    _this.name = \"SyntaxError\";\n\n    if (typeof Error.captureStackTrace === \"function\") {\n      Error.captureStackTrace(_this, SyntaxError);\n    }\n\n    return _this;\n  }\n\n  SyntaxError.buildMessage = function (expected, found) {\n    function hex(ch) {\n      return ch.charCodeAt(0).toString(16).toUpperCase();\n    }\n\n    function literalEscape(s) {\n      return s.replace(/\\\\/g, \"\\\\\\\\\").replace(/\"/g, \"\\\\\\\"\").replace(/\\0/g, \"\\\\0\").replace(/\\t/g, \"\\\\t\").replace(/\\n/g, \"\\\\n\").replace(/\\r/g, \"\\\\r\").replace(/[\\x00-\\x0F]/g, function (ch) {\n        return \"\\\\x0\" + hex(ch);\n      }).replace(/[\\x10-\\x1F\\x7F-\\x9F]/g, function (ch) {\n        return \"\\\\x\" + hex(ch);\n      });\n    }\n\n    function classEscape(s) {\n      return s.replace(/\\\\/g, \"\\\\\\\\\").replace(/\\]/g, \"\\\\]\").replace(/\\^/g, \"\\\\^\").replace(/-/g, \"\\\\-\").replace(/\\0/g, \"\\\\0\").replace(/\\t/g, \"\\\\t\").replace(/\\n/g, \"\\\\n\").replace(/\\r/g, \"\\\\r\").replace(/[\\x00-\\x0F]/g, function (ch) {\n        return \"\\\\x0\" + hex(ch);\n      }).replace(/[\\x10-\\x1F\\x7F-\\x9F]/g, function (ch) {\n        return \"\\\\x\" + hex(ch);\n      });\n    }\n\n    function describeExpectation(expectation) {\n      switch (expectation.type) {\n        case \"literal\":\n          return \"\\\"\" + literalEscape(expectation.text) + \"\\\"\";\n\n        case \"class\":\n          var escapedParts = expectation.parts.map(function (part) {\n            return Array.isArray(part) ? classEscape(part[0]) + \"-\" + classEscape(part[1]) : classEscape(part);\n          });\n          return \"[\" + (expectation.inverted ? \"^\" : \"\") + escapedParts + \"]\";\n\n        case \"any\":\n          return \"any character\";\n\n        case \"end\":\n          return \"end of input\";\n\n        case \"other\":\n          return expectation.description;\n      }\n    }\n\n    function describeExpected(expected1) {\n      var descriptions = expected1.map(describeExpectation);\n      var i;\n      var j;\n      descriptions.sort();\n\n      if (descriptions.length > 0) {\n        for (i = 1, j = 1; i < descriptions.length; i++) {\n          if (descriptions[i - 1] !== descriptions[i]) {\n            descriptions[j] = descriptions[i];\n            j++;\n          }\n        }\n\n        descriptions.length = j;\n      }\n\n      switch (descriptions.length) {\n        case 1:\n          return descriptions[0];\n\n        case 2:\n          return descriptions[0] + \" or \" + descriptions[1];\n\n        default:\n          return descriptions.slice(0, -1).join(\", \") + \", or \" + descriptions[descriptions.length - 1];\n      }\n    }\n\n    function describeFound(found1) {\n      return found1 ? \"\\\"\" + literalEscape(found1) + \"\\\"\" : \"end of input\";\n    }\n\n    return \"Expected \" + describeExpected(expected) + \" but \" + describeFound(found) + \" found.\";\n  };\n\n  return SyntaxError;\n}(Error);\n\n\n\nfunction peg$parse(input, options) {\n  options = options !== undefined ? options : {};\n  var peg$FAILED = {};\n  var peg$startRuleFunctions = {\n    start: peg$parsestart\n  };\n  var peg$startRuleFunction = peg$parsestart;\n\n  var peg$c0 = function (parts) {\n    return parts.join('');\n  };\n\n  var peg$c1 = function (messageText) {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.literal,\n      value: messageText\n    }, insertLocation());\n  };\n\n  var peg$c2 = \"#\";\n  var peg$c3 = peg$literalExpectation(\"#\", false);\n\n  var peg$c4 = function () {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.pound\n    }, insertLocation());\n  };\n\n  var peg$c5 = peg$otherExpectation(\"tagElement\");\n  var peg$c6 = \"<\";\n  var peg$c7 = peg$literalExpectation(\"<\", false);\n  var peg$c8 = \"/>\";\n  var peg$c9 = peg$literalExpectation(\"/>\", false);\n\n  var peg$c10 = function (value) {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.literal,\n      value: value.join('')\n    }, insertLocation());\n  };\n\n  var peg$c11 = function (open, children, close) {\n    if (open !== close) {\n      error(\"Mismatch tag \\\"\" + open + \"\\\" !== \\\"\" + close + \"\\\"\", location());\n    }\n\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.tag,\n      value: open,\n      children: children\n    }, insertLocation());\n  };\n\n  var peg$c12 = function () {\n    messageCtx.push('openingTag');\n    return true;\n  };\n\n  var peg$c13 = \">\";\n  var peg$c14 = peg$literalExpectation(\">\", false);\n\n  var peg$c15 = function (tag) {\n    messageCtx.pop();\n    return true;\n  };\n\n  var peg$c16 = function (tag) {\n    return tag;\n  };\n\n  var peg$c17 = \"</\";\n  var peg$c18 = peg$literalExpectation(\"</\", false);\n\n  var peg$c19 = function () {\n    messageCtx.push('closingTag');\n    return true;\n  };\n\n  var peg$c20 = peg$otherExpectation(\"argumentElement\");\n  var peg$c21 = \"{\";\n  var peg$c22 = peg$literalExpectation(\"{\", false);\n  var peg$c23 = \"}\";\n  var peg$c24 = peg$literalExpectation(\"}\", false);\n\n  var peg$c25 = function (value) {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.argument,\n      value: value\n    }, insertLocation());\n  };\n\n  var peg$c26 = peg$otherExpectation(\"numberSkeletonId\");\n  var peg$c27 = /^['\\/{}]/;\n  var peg$c28 = peg$classExpectation([\"'\", \"/\", \"{\", \"}\"], false, false);\n  var peg$c29 = peg$anyExpectation();\n  var peg$c30 = peg$otherExpectation(\"numberSkeletonTokenOption\");\n  var peg$c31 = \"/\";\n  var peg$c32 = peg$literalExpectation(\"/\", false);\n\n  var peg$c33 = function (option) {\n    return option;\n  };\n\n  var peg$c34 = peg$otherExpectation(\"numberSkeletonToken\");\n\n  var peg$c35 = function (stem, options) {\n    return {\n      stem: stem,\n      options: options\n    };\n  };\n\n  var peg$c36 = function (tokens) {\n    return __assign({\n      type: 0\n      /* number */\n      ,\n      tokens: tokens\n    }, insertLocation());\n  };\n\n  var peg$c37 = \"::\";\n  var peg$c38 = peg$literalExpectation(\"::\", false);\n\n  var peg$c39 = function (skeleton) {\n    return skeleton;\n  };\n\n  var peg$c40 = function () {\n    messageCtx.push('numberArgStyle');\n    return true;\n  };\n\n  var peg$c41 = function (style) {\n    messageCtx.pop();\n    return style.replace(/\\s*$/, '');\n  };\n\n  var peg$c42 = \",\";\n  var peg$c43 = peg$literalExpectation(\",\", false);\n  var peg$c44 = \"number\";\n  var peg$c45 = peg$literalExpectation(\"number\", false);\n\n  var peg$c46 = function (value, type, style) {\n    return __assign({\n      type: type === 'number' ? _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.number : type === 'date' ? _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.date : _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.time,\n      style: style && style[2],\n      value: value\n    }, insertLocation());\n  };\n\n  var peg$c47 = \"'\";\n  var peg$c48 = peg$literalExpectation(\"'\", false);\n  var peg$c49 = /^[^']/;\n  var peg$c50 = peg$classExpectation([\"'\"], true, false);\n  var peg$c51 = /^[^a-zA-Z'{}]/;\n  var peg$c52 = peg$classExpectation([[\"a\", \"z\"], [\"A\", \"Z\"], \"'\", \"{\", \"}\"], true, false);\n  var peg$c53 = /^[a-zA-Z]/;\n  var peg$c54 = peg$classExpectation([[\"a\", \"z\"], [\"A\", \"Z\"]], false, false);\n\n  var peg$c55 = function (pattern) {\n    return __assign({\n      type: 1\n      /* dateTime */\n      ,\n      pattern: pattern\n    }, insertLocation());\n  };\n\n  var peg$c56 = function () {\n    messageCtx.push('dateOrTimeArgStyle');\n    return true;\n  };\n\n  var peg$c57 = \"date\";\n  var peg$c58 = peg$literalExpectation(\"date\", false);\n  var peg$c59 = \"time\";\n  var peg$c60 = peg$literalExpectation(\"time\", false);\n  var peg$c61 = \"plural\";\n  var peg$c62 = peg$literalExpectation(\"plural\", false);\n  var peg$c63 = \"selectordinal\";\n  var peg$c64 = peg$literalExpectation(\"selectordinal\", false);\n  var peg$c65 = \"offset:\";\n  var peg$c66 = peg$literalExpectation(\"offset:\", false);\n\n  var peg$c67 = function (value, pluralType, offset, options) {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.plural,\n      pluralType: pluralType === 'plural' ? 'cardinal' : 'ordinal',\n      value: value,\n      offset: offset ? offset[2] : 0,\n      options: options.reduce(function (all, _a) {\n        var id = _a.id,\n            value = _a.value,\n            optionLocation = _a.location;\n\n        if (id in all) {\n          error(\"Duplicate option \\\"\" + id + \"\\\" in plural element: \\\"\" + text() + \"\\\"\", location());\n        }\n\n        all[id] = {\n          value: value,\n          location: optionLocation\n        };\n        return all;\n      }, {})\n    }, insertLocation());\n  };\n\n  var peg$c68 = \"select\";\n  var peg$c69 = peg$literalExpectation(\"select\", false);\n\n  var peg$c70 = function (value, options) {\n    return __assign({\n      type: _types__WEBPACK_IMPORTED_MODULE_0__.TYPE.select,\n      value: value,\n      options: options.reduce(function (all, _a) {\n        var id = _a.id,\n            value = _a.value,\n            optionLocation = _a.location;\n\n        if (id in all) {\n          error(\"Duplicate option \\\"\" + id + \"\\\" in select element: \\\"\" + text() + \"\\\"\", location());\n        }\n\n        all[id] = {\n          value: value,\n          location: optionLocation\n        };\n        return all;\n      }, {})\n    }, insertLocation());\n  };\n\n  var peg$c71 = \"=\";\n  var peg$c72 = peg$literalExpectation(\"=\", false);\n\n  var peg$c73 = function (id) {\n    messageCtx.push('select');\n    return true;\n  };\n\n  var peg$c74 = function (id, value) {\n    messageCtx.pop();\n    return __assign({\n      id: id,\n      value: value\n    }, insertLocation());\n  };\n\n  var peg$c75 = function (id) {\n    messageCtx.push('plural');\n    return true;\n  };\n\n  var peg$c76 = function (id, value) {\n    messageCtx.pop();\n    return __assign({\n      id: id,\n      value: value\n    }, insertLocation());\n  };\n\n  var peg$c77 = peg$otherExpectation(\"whitespace\");\n  var peg$c78 = /^[\\t-\\r \\x85\\xA0\\u1680\\u2000-\\u200A\\u2028\\u2029\\u202F\\u205F\\u3000]/;\n  var peg$c79 = peg$classExpectation([[\"\\t\", \"\\r\"], \" \", \"\\x85\", \"\\xA0\", \"\\u1680\", [\"\\u2000\", \"\\u200A\"], \"\\u2028\", \"\\u2029\", \"\\u202F\", \"\\u205F\", \"\\u3000\"], false, false);\n  var peg$c80 = peg$otherExpectation(\"syntax pattern\");\n  var peg$c81 = /^[!-\\/:-@[-\\^`{-~\\xA1-\\xA7\\xA9\\xAB\\xAC\\xAE\\xB0\\xB1\\xB6\\xBB\\xBF\\xD7\\xF7\\u2010-\\u2027\\u2030-\\u203E\\u2041-\\u2053\\u2055-\\u205E\\u2190-\\u245F\\u2500-\\u2775\\u2794-\\u2BFF\\u2E00-\\u2E7F\\u3001-\\u3003\\u3008-\\u3020\\u3030\\uFD3E\\uFD3F\\uFE45\\uFE46]/;\n  var peg$c82 = peg$classExpectation([[\"!\", \"/\"], [\":\", \"@\"], [\"[\", \"^\"], \"`\", [\"{\", \"~\"], [\"\\xA1\", \"\\xA7\"], \"\\xA9\", \"\\xAB\", \"\\xAC\", \"\\xAE\", \"\\xB0\", \"\\xB1\", \"\\xB6\", \"\\xBB\", \"\\xBF\", \"\\xD7\", \"\\xF7\", [\"\\u2010\", \"\\u2027\"], [\"\\u2030\", \"\\u203E\"], [\"\\u2041\", \"\\u2053\"], [\"\\u2055\", \"\\u205E\"], [\"\\u2190\", \"\\u245F\"], [\"\\u2500\", \"\\u2775\"], [\"\\u2794\", \"\\u2BFF\"], [\"\\u2E00\", \"\\u2E7F\"], [\"\\u3001\", \"\\u3003\"], [\"\\u3008\", \"\\u3020\"], \"\\u3030\", \"\\uFD3E\", \"\\uFD3F\", \"\\uFE45\", \"\\uFE46\"], false, false);\n  var peg$c83 = peg$otherExpectation(\"optional whitespace\");\n  var peg$c84 = peg$otherExpectation(\"number\");\n  var peg$c85 = \"-\";\n  var peg$c86 = peg$literalExpectation(\"-\", false);\n\n  var peg$c87 = function (negative, num) {\n    return num ? negative ? -num : num : 0;\n  };\n\n  var peg$c88 = peg$otherExpectation(\"apostrophe\");\n  var peg$c89 = peg$otherExpectation(\"double apostrophes\");\n  var peg$c90 = \"''\";\n  var peg$c91 = peg$literalExpectation(\"''\", false);\n\n  var peg$c92 = function () {\n    return \"'\";\n  };\n\n  var peg$c93 = function (escapedChar, quotedChars) {\n    return escapedChar + quotedChars.replace(\"''\", \"'\");\n  };\n\n  var peg$c94 = function (x) {\n    return x !== '<' && x !== '{' && !(isInPluralOption() && x === '#') && !(isNestedMessageText() && x === '}') && !(isNestedMessageText() && x === '>');\n  };\n\n  var peg$c95 = \"\\n\";\n  var peg$c96 = peg$literalExpectation(\"\\n\", false);\n\n  var peg$c97 = function (x) {\n    return x === '<' || x === '>' || x === '{' || x === '}' || isInPluralOption() && x === '#';\n  };\n\n  var peg$c98 = peg$otherExpectation(\"argNameOrNumber\");\n  var peg$c99 = peg$otherExpectation(\"validTag\");\n  var peg$c100 = peg$otherExpectation(\"argNumber\");\n  var peg$c101 = \"0\";\n  var peg$c102 = peg$literalExpectation(\"0\", false);\n\n  var peg$c103 = function () {\n    return 0;\n  };\n\n  var peg$c104 = /^[1-9]/;\n  var peg$c105 = peg$classExpectation([[\"1\", \"9\"]], false, false);\n  var peg$c106 = /^[0-9]/;\n  var peg$c107 = peg$classExpectation([[\"0\", \"9\"]], false, false);\n\n  var peg$c108 = function (digits) {\n    return parseInt(digits.join(''), 10);\n  };\n\n  var peg$c109 = peg$otherExpectation(\"argName\");\n  var peg$c110 = peg$otherExpectation(\"tagName\");\n  var peg$currPos = 0;\n  var peg$savedPos = 0;\n  var peg$posDetailsCache = [{\n    line: 1,\n    column: 1\n  }];\n  var peg$maxFailPos = 0;\n  var peg$maxFailExpected = [];\n  var peg$silentFails = 0;\n  var peg$result;\n\n  if (options.startRule !== undefined) {\n    if (!(options.startRule in peg$startRuleFunctions)) {\n      throw new Error(\"Can't start parsing from rule \\\"\" + options.startRule + \"\\\".\");\n    }\n\n    peg$startRuleFunction = peg$startRuleFunctions[options.startRule];\n  }\n\n  function text() {\n    return input.substring(peg$savedPos, peg$currPos);\n  }\n\n  function location() {\n    return peg$computeLocation(peg$savedPos, peg$currPos);\n  }\n\n  function expected(description, location1) {\n    location1 = location1 !== undefined ? location1 : peg$computeLocation(peg$savedPos, peg$currPos);\n    throw peg$buildStructuredError([peg$otherExpectation(description)], input.substring(peg$savedPos, peg$currPos), location1);\n  }\n\n  function error(message, location1) {\n    location1 = location1 !== undefined ? location1 : peg$computeLocation(peg$savedPos, peg$currPos);\n    throw peg$buildSimpleError(message, location1);\n  }\n\n  function peg$literalExpectation(text1, ignoreCase) {\n    return {\n      type: \"literal\",\n      text: text1,\n      ignoreCase: ignoreCase\n    };\n  }\n\n  function peg$classExpectation(parts, inverted, ignoreCase) {\n    return {\n      type: \"class\",\n      parts: parts,\n      inverted: inverted,\n      ignoreCase: ignoreCase\n    };\n  }\n\n  function peg$anyExpectation() {\n    return {\n      type: \"any\"\n    };\n  }\n\n  function peg$endExpectation() {\n    return {\n      type: \"end\"\n    };\n  }\n\n  function peg$otherExpectation(description) {\n    return {\n      type: \"other\",\n      description: description\n    };\n  }\n\n  function peg$computePosDetails(pos) {\n    var details = peg$posDetailsCache[pos];\n    var p;\n\n    if (details) {\n      return details;\n    } else {\n      p = pos - 1;\n\n      while (!peg$posDetailsCache[p]) {\n        p--;\n      }\n\n      details = peg$posDetailsCache[p];\n      details = {\n        line: details.line,\n        column: details.column\n      };\n\n      while (p < pos) {\n        if (input.charCodeAt(p) === 10) {\n          details.line++;\n          details.column = 1;\n        } else {\n          details.column++;\n        }\n\n        p++;\n      }\n\n      peg$posDetailsCache[pos] = details;\n      return details;\n    }\n  }\n\n  function peg$computeLocation(startPos, endPos) {\n    var startPosDetails = peg$computePosDetails(startPos);\n    var endPosDetails = peg$computePosDetails(endPos);\n    return {\n      start: {\n        offset: startPos,\n        line: startPosDetails.line,\n        column: startPosDetails.column\n      },\n      end: {\n        offset: endPos,\n        line: endPosDetails.line,\n        column: endPosDetails.column\n      }\n    };\n  }\n\n  function peg$fail(expected1) {\n    if (peg$currPos < peg$maxFailPos) {\n      return;\n    }\n\n    if (peg$currPos > peg$maxFailPos) {\n      peg$maxFailPos = peg$currPos;\n      peg$maxFailExpected = [];\n    }\n\n    peg$maxFailExpected.push(expected1);\n  }\n\n  function peg$buildSimpleError(message, location1) {\n    return new SyntaxError(message, [], \"\", location1);\n  }\n\n  function peg$buildStructuredError(expected1, found, location1) {\n    return new SyntaxError(SyntaxError.buildMessage(expected1, found), expected1, found, location1);\n  }\n\n  function peg$parsestart() {\n    var s0;\n    s0 = peg$parsemessage();\n    return s0;\n  }\n\n  function peg$parsemessage() {\n    var s0, s1;\n    s0 = [];\n    s1 = peg$parsemessageElement();\n\n    while (s1 !== peg$FAILED) {\n      s0.push(s1);\n      s1 = peg$parsemessageElement();\n    }\n\n    return s0;\n  }\n\n  function peg$parsemessageElement() {\n    var s0;\n    s0 = peg$parseliteralElement();\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$parseargumentElement();\n\n      if (s0 === peg$FAILED) {\n        s0 = peg$parsesimpleFormatElement();\n\n        if (s0 === peg$FAILED) {\n          s0 = peg$parsepluralElement();\n\n          if (s0 === peg$FAILED) {\n            s0 = peg$parseselectElement();\n\n            if (s0 === peg$FAILED) {\n              s0 = peg$parsetagElement();\n\n              if (s0 === peg$FAILED) {\n                s0 = peg$parsepoundElement();\n              }\n            }\n          }\n        }\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsemessageText() {\n    var s0, s1, s2;\n    s0 = peg$currPos;\n    s1 = [];\n    s2 = peg$parsedoubleApostrophes();\n\n    if (s2 === peg$FAILED) {\n      s2 = peg$parsequotedString();\n\n      if (s2 === peg$FAILED) {\n        s2 = peg$parseunquotedString();\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      while (s2 !== peg$FAILED) {\n        s1.push(s2);\n        s2 = peg$parsedoubleApostrophes();\n\n        if (s2 === peg$FAILED) {\n          s2 = peg$parsequotedString();\n\n          if (s2 === peg$FAILED) {\n            s2 = peg$parseunquotedString();\n          }\n        }\n      }\n    } else {\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c0(s1);\n    }\n\n    s0 = s1;\n    return s0;\n  }\n\n  function peg$parseliteralElement() {\n    var s0, s1;\n    s0 = peg$currPos;\n    s1 = peg$parsemessageText();\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c1(s1);\n    }\n\n    s0 = s1;\n    return s0;\n  }\n\n  function peg$parsepoundElement() {\n    var s0, s1;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 35) {\n      s1 = peg$c2;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c3);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c4();\n    }\n\n    s0 = s1;\n    return s0;\n  }\n\n  function peg$parsetagElement() {\n    var s0, s1, s2, s3, s4, s5;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 60) {\n      s2 = peg$c6;\n      peg$currPos++;\n    } else {\n      s2 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c7);\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      s3 = peg$parsevalidTag();\n\n      if (s3 !== peg$FAILED) {\n        s4 = peg$parse_();\n\n        if (s4 !== peg$FAILED) {\n          if (input.substr(peg$currPos, 2) === peg$c8) {\n            s5 = peg$c8;\n            peg$currPos += 2;\n          } else {\n            s5 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c9);\n            }\n          }\n\n          if (s5 !== peg$FAILED) {\n            s2 = [s2, s3, s4, s5];\n            s1 = s2;\n          } else {\n            peg$currPos = s1;\n            s1 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s1;\n          s1 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s1;\n        s1 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s1;\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c10(s1);\n    }\n\n    s0 = s1;\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$currPos;\n      s1 = peg$parseopeningTag();\n\n      if (s1 !== peg$FAILED) {\n        s2 = peg$parsemessage();\n\n        if (s2 !== peg$FAILED) {\n          s3 = peg$parseclosingTag();\n\n          if (s3 !== peg$FAILED) {\n            peg$savedPos = s0;\n            s1 = peg$c11(s1, s2, s3);\n            s0 = s1;\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c5);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parseopeningTag() {\n    var s0, s1, s2, s3, s4, s5;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 60) {\n      s1 = peg$c6;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c7);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = peg$currPos;\n      s2 = peg$c12();\n\n      if (s2) {\n        s2 = undefined;\n      } else {\n        s2 = peg$FAILED;\n      }\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parsevalidTag();\n\n        if (s3 !== peg$FAILED) {\n          if (input.charCodeAt(peg$currPos) === 62) {\n            s4 = peg$c13;\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c14);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            peg$savedPos = peg$currPos;\n            s5 = peg$c15(s3);\n\n            if (s5) {\n              s5 = undefined;\n            } else {\n              s5 = peg$FAILED;\n            }\n\n            if (s5 !== peg$FAILED) {\n              peg$savedPos = s0;\n              s1 = peg$c16(s3);\n              s0 = s1;\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parseclosingTag() {\n    var s0, s1, s2, s3, s4, s5;\n    s0 = peg$currPos;\n\n    if (input.substr(peg$currPos, 2) === peg$c17) {\n      s1 = peg$c17;\n      peg$currPos += 2;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c18);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = peg$currPos;\n      s2 = peg$c19();\n\n      if (s2) {\n        s2 = undefined;\n      } else {\n        s2 = peg$FAILED;\n      }\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parsevalidTag();\n\n        if (s3 !== peg$FAILED) {\n          if (input.charCodeAt(peg$currPos) === 62) {\n            s4 = peg$c13;\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c14);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            peg$savedPos = peg$currPos;\n            s5 = peg$c15(s3);\n\n            if (s5) {\n              s5 = undefined;\n            } else {\n              s5 = peg$FAILED;\n            }\n\n            if (s5 !== peg$FAILED) {\n              peg$savedPos = s0;\n              s1 = peg$c16(s3);\n              s0 = s1;\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parseargumentElement() {\n    var s0, s1, s2, s3, s4, s5;\n    peg$silentFails++;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 123) {\n      s1 = peg$c21;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c22);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parse_();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parseargNameOrNumber();\n\n        if (s3 !== peg$FAILED) {\n          s4 = peg$parse_();\n\n          if (s4 !== peg$FAILED) {\n            if (input.charCodeAt(peg$currPos) === 125) {\n              s5 = peg$c23;\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c24);\n              }\n            }\n\n            if (s5 !== peg$FAILED) {\n              peg$savedPos = s0;\n              s1 = peg$c25(s3);\n              s0 = s1;\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c20);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumberSkeletonId() {\n    var s0, s1, s2, s3, s4;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = [];\n    s2 = peg$currPos;\n    s3 = peg$currPos;\n    peg$silentFails++;\n    s4 = peg$parsewhiteSpace();\n\n    if (s4 === peg$FAILED) {\n      if (peg$c27.test(input.charAt(peg$currPos))) {\n        s4 = input.charAt(peg$currPos);\n        peg$currPos++;\n      } else {\n        s4 = peg$FAILED;\n\n        if (peg$silentFails === 0) {\n          peg$fail(peg$c28);\n        }\n      }\n    }\n\n    peg$silentFails--;\n\n    if (s4 === peg$FAILED) {\n      s3 = undefined;\n    } else {\n      peg$currPos = s3;\n      s3 = peg$FAILED;\n    }\n\n    if (s3 !== peg$FAILED) {\n      if (input.length > peg$currPos) {\n        s4 = input.charAt(peg$currPos);\n        peg$currPos++;\n      } else {\n        s4 = peg$FAILED;\n\n        if (peg$silentFails === 0) {\n          peg$fail(peg$c29);\n        }\n      }\n\n      if (s4 !== peg$FAILED) {\n        s3 = [s3, s4];\n        s2 = s3;\n      } else {\n        peg$currPos = s2;\n        s2 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s2;\n      s2 = peg$FAILED;\n    }\n\n    if (s2 !== peg$FAILED) {\n      while (s2 !== peg$FAILED) {\n        s1.push(s2);\n        s2 = peg$currPos;\n        s3 = peg$currPos;\n        peg$silentFails++;\n        s4 = peg$parsewhiteSpace();\n\n        if (s4 === peg$FAILED) {\n          if (peg$c27.test(input.charAt(peg$currPos))) {\n            s4 = input.charAt(peg$currPos);\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c28);\n            }\n          }\n        }\n\n        peg$silentFails--;\n\n        if (s4 === peg$FAILED) {\n          s3 = undefined;\n        } else {\n          peg$currPos = s3;\n          s3 = peg$FAILED;\n        }\n\n        if (s3 !== peg$FAILED) {\n          if (input.length > peg$currPos) {\n            s4 = input.charAt(peg$currPos);\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c29);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            s3 = [s3, s4];\n            s2 = s3;\n          } else {\n            peg$currPos = s2;\n            s2 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s2;\n          s2 = peg$FAILED;\n        }\n      }\n    } else {\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c26);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumberSkeletonTokenOption() {\n    var s0, s1, s2;\n    peg$silentFails++;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 47) {\n      s1 = peg$c31;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c32);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parsenumberSkeletonId();\n\n      if (s2 !== peg$FAILED) {\n        peg$savedPos = s0;\n        s1 = peg$c33(s2);\n        s0 = s1;\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c30);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumberSkeletonToken() {\n    var s0, s1, s2, s3, s4;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = peg$parse_();\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parsenumberSkeletonId();\n\n      if (s2 !== peg$FAILED) {\n        s3 = [];\n        s4 = peg$parsenumberSkeletonTokenOption();\n\n        while (s4 !== peg$FAILED) {\n          s3.push(s4);\n          s4 = peg$parsenumberSkeletonTokenOption();\n        }\n\n        if (s3 !== peg$FAILED) {\n          peg$savedPos = s0;\n          s1 = peg$c35(s2, s3);\n          s0 = s1;\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c34);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumberSkeleton() {\n    var s0, s1, s2;\n    s0 = peg$currPos;\n    s1 = [];\n    s2 = peg$parsenumberSkeletonToken();\n\n    if (s2 !== peg$FAILED) {\n      while (s2 !== peg$FAILED) {\n        s1.push(s2);\n        s2 = peg$parsenumberSkeletonToken();\n      }\n    } else {\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c36(s1);\n    }\n\n    s0 = s1;\n    return s0;\n  }\n\n  function peg$parsenumberArgStyle() {\n    var s0, s1, s2;\n    s0 = peg$currPos;\n\n    if (input.substr(peg$currPos, 2) === peg$c37) {\n      s1 = peg$c37;\n      peg$currPos += 2;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c38);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parsenumberSkeleton();\n\n      if (s2 !== peg$FAILED) {\n        peg$savedPos = s0;\n        s1 = peg$c39(s2);\n        s0 = s1;\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$currPos;\n      peg$savedPos = peg$currPos;\n      s1 = peg$c40();\n\n      if (s1) {\n        s1 = undefined;\n      } else {\n        s1 = peg$FAILED;\n      }\n\n      if (s1 !== peg$FAILED) {\n        s2 = peg$parsemessageText();\n\n        if (s2 !== peg$FAILED) {\n          peg$savedPos = s0;\n          s1 = peg$c41(s2);\n          s0 = s1;\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumberFormatElement() {\n    var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9, s10, s11, s12;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 123) {\n      s1 = peg$c21;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c22);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parse_();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parseargNameOrNumber();\n\n        if (s3 !== peg$FAILED) {\n          s4 = peg$parse_();\n\n          if (s4 !== peg$FAILED) {\n            if (input.charCodeAt(peg$currPos) === 44) {\n              s5 = peg$c42;\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c43);\n              }\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parse_();\n\n              if (s6 !== peg$FAILED) {\n                if (input.substr(peg$currPos, 6) === peg$c44) {\n                  s7 = peg$c44;\n                  peg$currPos += 6;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c45);\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  s8 = peg$parse_();\n\n                  if (s8 !== peg$FAILED) {\n                    s9 = peg$currPos;\n\n                    if (input.charCodeAt(peg$currPos) === 44) {\n                      s10 = peg$c42;\n                      peg$currPos++;\n                    } else {\n                      s10 = peg$FAILED;\n\n                      if (peg$silentFails === 0) {\n                        peg$fail(peg$c43);\n                      }\n                    }\n\n                    if (s10 !== peg$FAILED) {\n                      s11 = peg$parse_();\n\n                      if (s11 !== peg$FAILED) {\n                        s12 = peg$parsenumberArgStyle();\n\n                        if (s12 !== peg$FAILED) {\n                          s10 = [s10, s11, s12];\n                          s9 = s10;\n                        } else {\n                          peg$currPos = s9;\n                          s9 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s9;\n                        s9 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s9;\n                      s9 = peg$FAILED;\n                    }\n\n                    if (s9 === peg$FAILED) {\n                      s9 = null;\n                    }\n\n                    if (s9 !== peg$FAILED) {\n                      s10 = peg$parse_();\n\n                      if (s10 !== peg$FAILED) {\n                        if (input.charCodeAt(peg$currPos) === 125) {\n                          s11 = peg$c23;\n                          peg$currPos++;\n                        } else {\n                          s11 = peg$FAILED;\n\n                          if (peg$silentFails === 0) {\n                            peg$fail(peg$c24);\n                          }\n                        }\n\n                        if (s11 !== peg$FAILED) {\n                          peg$savedPos = s0;\n                          s1 = peg$c46(s3, s7, s9);\n                          s0 = s1;\n                        } else {\n                          peg$currPos = s0;\n                          s0 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s0;\n                        s0 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s0;\n                      s0 = peg$FAILED;\n                    }\n                  } else {\n                    peg$currPos = s0;\n                    s0 = peg$FAILED;\n                  }\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsedateTimeSkeletonLiteral() {\n    var s0, s1, s2, s3;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 39) {\n      s1 = peg$c47;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c48);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = [];\n      s3 = peg$parsedoubleApostrophes();\n\n      if (s3 === peg$FAILED) {\n        if (peg$c49.test(input.charAt(peg$currPos))) {\n          s3 = input.charAt(peg$currPos);\n          peg$currPos++;\n        } else {\n          s3 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c50);\n          }\n        }\n      }\n\n      if (s3 !== peg$FAILED) {\n        while (s3 !== peg$FAILED) {\n          s2.push(s3);\n          s3 = peg$parsedoubleApostrophes();\n\n          if (s3 === peg$FAILED) {\n            if (peg$c49.test(input.charAt(peg$currPos))) {\n              s3 = input.charAt(peg$currPos);\n              peg$currPos++;\n            } else {\n              s3 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c50);\n              }\n            }\n          }\n        }\n      } else {\n        s2 = peg$FAILED;\n      }\n\n      if (s2 !== peg$FAILED) {\n        if (input.charCodeAt(peg$currPos) === 39) {\n          s3 = peg$c47;\n          peg$currPos++;\n        } else {\n          s3 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c48);\n          }\n        }\n\n        if (s3 !== peg$FAILED) {\n          s1 = [s1, s2, s3];\n          s0 = s1;\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    if (s0 === peg$FAILED) {\n      s0 = [];\n      s1 = peg$parsedoubleApostrophes();\n\n      if (s1 === peg$FAILED) {\n        if (peg$c51.test(input.charAt(peg$currPos))) {\n          s1 = input.charAt(peg$currPos);\n          peg$currPos++;\n        } else {\n          s1 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c52);\n          }\n        }\n      }\n\n      if (s1 !== peg$FAILED) {\n        while (s1 !== peg$FAILED) {\n          s0.push(s1);\n          s1 = peg$parsedoubleApostrophes();\n\n          if (s1 === peg$FAILED) {\n            if (peg$c51.test(input.charAt(peg$currPos))) {\n              s1 = input.charAt(peg$currPos);\n              peg$currPos++;\n            } else {\n              s1 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c52);\n              }\n            }\n          }\n        }\n      } else {\n        s0 = peg$FAILED;\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsedateTimeSkeletonPattern() {\n    var s0, s1;\n    s0 = [];\n\n    if (peg$c53.test(input.charAt(peg$currPos))) {\n      s1 = input.charAt(peg$currPos);\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c54);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      while (s1 !== peg$FAILED) {\n        s0.push(s1);\n\n        if (peg$c53.test(input.charAt(peg$currPos))) {\n          s1 = input.charAt(peg$currPos);\n          peg$currPos++;\n        } else {\n          s1 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c54);\n          }\n        }\n      }\n    } else {\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsedateTimeSkeleton() {\n    var s0, s1, s2, s3;\n    s0 = peg$currPos;\n    s1 = peg$currPos;\n    s2 = [];\n    s3 = peg$parsedateTimeSkeletonLiteral();\n\n    if (s3 === peg$FAILED) {\n      s3 = peg$parsedateTimeSkeletonPattern();\n    }\n\n    if (s3 !== peg$FAILED) {\n      while (s3 !== peg$FAILED) {\n        s2.push(s3);\n        s3 = peg$parsedateTimeSkeletonLiteral();\n\n        if (s3 === peg$FAILED) {\n          s3 = peg$parsedateTimeSkeletonPattern();\n        }\n      }\n    } else {\n      s2 = peg$FAILED;\n    }\n\n    if (s2 !== peg$FAILED) {\n      s1 = input.substring(s1, peg$currPos);\n    } else {\n      s1 = s2;\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c55(s1);\n    }\n\n    s0 = s1;\n    return s0;\n  }\n\n  function peg$parsedateOrTimeArgStyle() {\n    var s0, s1, s2;\n    s0 = peg$currPos;\n\n    if (input.substr(peg$currPos, 2) === peg$c37) {\n      s1 = peg$c37;\n      peg$currPos += 2;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c38);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parsedateTimeSkeleton();\n\n      if (s2 !== peg$FAILED) {\n        peg$savedPos = s0;\n        s1 = peg$c39(s2);\n        s0 = s1;\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$currPos;\n      peg$savedPos = peg$currPos;\n      s1 = peg$c56();\n\n      if (s1) {\n        s1 = undefined;\n      } else {\n        s1 = peg$FAILED;\n      }\n\n      if (s1 !== peg$FAILED) {\n        s2 = peg$parsemessageText();\n\n        if (s2 !== peg$FAILED) {\n          peg$savedPos = s0;\n          s1 = peg$c41(s2);\n          s0 = s1;\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsedateOrTimeFormatElement() {\n    var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9, s10, s11, s12;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 123) {\n      s1 = peg$c21;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c22);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parse_();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parseargNameOrNumber();\n\n        if (s3 !== peg$FAILED) {\n          s4 = peg$parse_();\n\n          if (s4 !== peg$FAILED) {\n            if (input.charCodeAt(peg$currPos) === 44) {\n              s5 = peg$c42;\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c43);\n              }\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parse_();\n\n              if (s6 !== peg$FAILED) {\n                if (input.substr(peg$currPos, 4) === peg$c57) {\n                  s7 = peg$c57;\n                  peg$currPos += 4;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c58);\n                  }\n                }\n\n                if (s7 === peg$FAILED) {\n                  if (input.substr(peg$currPos, 4) === peg$c59) {\n                    s7 = peg$c59;\n                    peg$currPos += 4;\n                  } else {\n                    s7 = peg$FAILED;\n\n                    if (peg$silentFails === 0) {\n                      peg$fail(peg$c60);\n                    }\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  s8 = peg$parse_();\n\n                  if (s8 !== peg$FAILED) {\n                    s9 = peg$currPos;\n\n                    if (input.charCodeAt(peg$currPos) === 44) {\n                      s10 = peg$c42;\n                      peg$currPos++;\n                    } else {\n                      s10 = peg$FAILED;\n\n                      if (peg$silentFails === 0) {\n                        peg$fail(peg$c43);\n                      }\n                    }\n\n                    if (s10 !== peg$FAILED) {\n                      s11 = peg$parse_();\n\n                      if (s11 !== peg$FAILED) {\n                        s12 = peg$parsedateOrTimeArgStyle();\n\n                        if (s12 !== peg$FAILED) {\n                          s10 = [s10, s11, s12];\n                          s9 = s10;\n                        } else {\n                          peg$currPos = s9;\n                          s9 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s9;\n                        s9 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s9;\n                      s9 = peg$FAILED;\n                    }\n\n                    if (s9 === peg$FAILED) {\n                      s9 = null;\n                    }\n\n                    if (s9 !== peg$FAILED) {\n                      s10 = peg$parse_();\n\n                      if (s10 !== peg$FAILED) {\n                        if (input.charCodeAt(peg$currPos) === 125) {\n                          s11 = peg$c23;\n                          peg$currPos++;\n                        } else {\n                          s11 = peg$FAILED;\n\n                          if (peg$silentFails === 0) {\n                            peg$fail(peg$c24);\n                          }\n                        }\n\n                        if (s11 !== peg$FAILED) {\n                          peg$savedPos = s0;\n                          s1 = peg$c46(s3, s7, s9);\n                          s0 = s1;\n                        } else {\n                          peg$currPos = s0;\n                          s0 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s0;\n                        s0 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s0;\n                      s0 = peg$FAILED;\n                    }\n                  } else {\n                    peg$currPos = s0;\n                    s0 = peg$FAILED;\n                  }\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsesimpleFormatElement() {\n    var s0;\n    s0 = peg$parsenumberFormatElement();\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$parsedateOrTimeFormatElement();\n    }\n\n    return s0;\n  }\n\n  function peg$parsepluralElement() {\n    var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9, s10, s11, s12, s13, s14, s15;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 123) {\n      s1 = peg$c21;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c22);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parse_();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parseargNameOrNumber();\n\n        if (s3 !== peg$FAILED) {\n          s4 = peg$parse_();\n\n          if (s4 !== peg$FAILED) {\n            if (input.charCodeAt(peg$currPos) === 44) {\n              s5 = peg$c42;\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c43);\n              }\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parse_();\n\n              if (s6 !== peg$FAILED) {\n                if (input.substr(peg$currPos, 6) === peg$c61) {\n                  s7 = peg$c61;\n                  peg$currPos += 6;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c62);\n                  }\n                }\n\n                if (s7 === peg$FAILED) {\n                  if (input.substr(peg$currPos, 13) === peg$c63) {\n                    s7 = peg$c63;\n                    peg$currPos += 13;\n                  } else {\n                    s7 = peg$FAILED;\n\n                    if (peg$silentFails === 0) {\n                      peg$fail(peg$c64);\n                    }\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  s8 = peg$parse_();\n\n                  if (s8 !== peg$FAILED) {\n                    if (input.charCodeAt(peg$currPos) === 44) {\n                      s9 = peg$c42;\n                      peg$currPos++;\n                    } else {\n                      s9 = peg$FAILED;\n\n                      if (peg$silentFails === 0) {\n                        peg$fail(peg$c43);\n                      }\n                    }\n\n                    if (s9 !== peg$FAILED) {\n                      s10 = peg$parse_();\n\n                      if (s10 !== peg$FAILED) {\n                        s11 = peg$currPos;\n\n                        if (input.substr(peg$currPos, 7) === peg$c65) {\n                          s12 = peg$c65;\n                          peg$currPos += 7;\n                        } else {\n                          s12 = peg$FAILED;\n\n                          if (peg$silentFails === 0) {\n                            peg$fail(peg$c66);\n                          }\n                        }\n\n                        if (s12 !== peg$FAILED) {\n                          s13 = peg$parse_();\n\n                          if (s13 !== peg$FAILED) {\n                            s14 = peg$parsenumber();\n\n                            if (s14 !== peg$FAILED) {\n                              s12 = [s12, s13, s14];\n                              s11 = s12;\n                            } else {\n                              peg$currPos = s11;\n                              s11 = peg$FAILED;\n                            }\n                          } else {\n                            peg$currPos = s11;\n                            s11 = peg$FAILED;\n                          }\n                        } else {\n                          peg$currPos = s11;\n                          s11 = peg$FAILED;\n                        }\n\n                        if (s11 === peg$FAILED) {\n                          s11 = null;\n                        }\n\n                        if (s11 !== peg$FAILED) {\n                          s12 = peg$parse_();\n\n                          if (s12 !== peg$FAILED) {\n                            s13 = [];\n                            s14 = peg$parsepluralOption();\n\n                            if (s14 !== peg$FAILED) {\n                              while (s14 !== peg$FAILED) {\n                                s13.push(s14);\n                                s14 = peg$parsepluralOption();\n                              }\n                            } else {\n                              s13 = peg$FAILED;\n                            }\n\n                            if (s13 !== peg$FAILED) {\n                              s14 = peg$parse_();\n\n                              if (s14 !== peg$FAILED) {\n                                if (input.charCodeAt(peg$currPos) === 125) {\n                                  s15 = peg$c23;\n                                  peg$currPos++;\n                                } else {\n                                  s15 = peg$FAILED;\n\n                                  if (peg$silentFails === 0) {\n                                    peg$fail(peg$c24);\n                                  }\n                                }\n\n                                if (s15 !== peg$FAILED) {\n                                  peg$savedPos = s0;\n                                  s1 = peg$c67(s3, s7, s11, s13);\n                                  s0 = s1;\n                                } else {\n                                  peg$currPos = s0;\n                                  s0 = peg$FAILED;\n                                }\n                              } else {\n                                peg$currPos = s0;\n                                s0 = peg$FAILED;\n                              }\n                            } else {\n                              peg$currPos = s0;\n                              s0 = peg$FAILED;\n                            }\n                          } else {\n                            peg$currPos = s0;\n                            s0 = peg$FAILED;\n                          }\n                        } else {\n                          peg$currPos = s0;\n                          s0 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s0;\n                        s0 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s0;\n                      s0 = peg$FAILED;\n                    }\n                  } else {\n                    peg$currPos = s0;\n                    s0 = peg$FAILED;\n                  }\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parseselectElement() {\n    var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9, s10, s11, s12, s13;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 123) {\n      s1 = peg$c21;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c22);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parse_();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parseargNameOrNumber();\n\n        if (s3 !== peg$FAILED) {\n          s4 = peg$parse_();\n\n          if (s4 !== peg$FAILED) {\n            if (input.charCodeAt(peg$currPos) === 44) {\n              s5 = peg$c42;\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c43);\n              }\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parse_();\n\n              if (s6 !== peg$FAILED) {\n                if (input.substr(peg$currPos, 6) === peg$c68) {\n                  s7 = peg$c68;\n                  peg$currPos += 6;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c69);\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  s8 = peg$parse_();\n\n                  if (s8 !== peg$FAILED) {\n                    if (input.charCodeAt(peg$currPos) === 44) {\n                      s9 = peg$c42;\n                      peg$currPos++;\n                    } else {\n                      s9 = peg$FAILED;\n\n                      if (peg$silentFails === 0) {\n                        peg$fail(peg$c43);\n                      }\n                    }\n\n                    if (s9 !== peg$FAILED) {\n                      s10 = peg$parse_();\n\n                      if (s10 !== peg$FAILED) {\n                        s11 = [];\n                        s12 = peg$parseselectOption();\n\n                        if (s12 !== peg$FAILED) {\n                          while (s12 !== peg$FAILED) {\n                            s11.push(s12);\n                            s12 = peg$parseselectOption();\n                          }\n                        } else {\n                          s11 = peg$FAILED;\n                        }\n\n                        if (s11 !== peg$FAILED) {\n                          s12 = peg$parse_();\n\n                          if (s12 !== peg$FAILED) {\n                            if (input.charCodeAt(peg$currPos) === 125) {\n                              s13 = peg$c23;\n                              peg$currPos++;\n                            } else {\n                              s13 = peg$FAILED;\n\n                              if (peg$silentFails === 0) {\n                                peg$fail(peg$c24);\n                              }\n                            }\n\n                            if (s13 !== peg$FAILED) {\n                              peg$savedPos = s0;\n                              s1 = peg$c70(s3, s11);\n                              s0 = s1;\n                            } else {\n                              peg$currPos = s0;\n                              s0 = peg$FAILED;\n                            }\n                          } else {\n                            peg$currPos = s0;\n                            s0 = peg$FAILED;\n                          }\n                        } else {\n                          peg$currPos = s0;\n                          s0 = peg$FAILED;\n                        }\n                      } else {\n                        peg$currPos = s0;\n                        s0 = peg$FAILED;\n                      }\n                    } else {\n                      peg$currPos = s0;\n                      s0 = peg$FAILED;\n                    }\n                  } else {\n                    peg$currPos = s0;\n                    s0 = peg$FAILED;\n                  }\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsepluralRuleSelectValue() {\n    var s0, s1, s2, s3;\n    s0 = peg$currPos;\n    s1 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 61) {\n      s2 = peg$c71;\n      peg$currPos++;\n    } else {\n      s2 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c72);\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      s3 = peg$parsenumber();\n\n      if (s3 !== peg$FAILED) {\n        s2 = [s2, s3];\n        s1 = s2;\n      } else {\n        peg$currPos = s1;\n        s1 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s1;\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$parseargName();\n    }\n\n    return s0;\n  }\n\n  function peg$parseselectOption() {\n    var s0, s1, s2, s3, s4, s5, s6, s7;\n    s0 = peg$currPos;\n    s1 = peg$parse_();\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parseargName();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parse_();\n\n        if (s3 !== peg$FAILED) {\n          if (input.charCodeAt(peg$currPos) === 123) {\n            s4 = peg$c21;\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c22);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            peg$savedPos = peg$currPos;\n            s5 = peg$c73(s2);\n\n            if (s5) {\n              s5 = undefined;\n            } else {\n              s5 = peg$FAILED;\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parsemessage();\n\n              if (s6 !== peg$FAILED) {\n                if (input.charCodeAt(peg$currPos) === 125) {\n                  s7 = peg$c23;\n                  peg$currPos++;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c24);\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  peg$savedPos = s0;\n                  s1 = peg$c74(s2, s6);\n                  s0 = s1;\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsepluralOption() {\n    var s0, s1, s2, s3, s4, s5, s6, s7;\n    s0 = peg$currPos;\n    s1 = peg$parse_();\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parsepluralRuleSelectValue();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$parse_();\n\n        if (s3 !== peg$FAILED) {\n          if (input.charCodeAt(peg$currPos) === 123) {\n            s4 = peg$c21;\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c22);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            peg$savedPos = peg$currPos;\n            s5 = peg$c75(s2);\n\n            if (s5) {\n              s5 = undefined;\n            } else {\n              s5 = peg$FAILED;\n            }\n\n            if (s5 !== peg$FAILED) {\n              s6 = peg$parsemessage();\n\n              if (s6 !== peg$FAILED) {\n                if (input.charCodeAt(peg$currPos) === 125) {\n                  s7 = peg$c23;\n                  peg$currPos++;\n                } else {\n                  s7 = peg$FAILED;\n\n                  if (peg$silentFails === 0) {\n                    peg$fail(peg$c24);\n                  }\n                }\n\n                if (s7 !== peg$FAILED) {\n                  peg$savedPos = s0;\n                  s1 = peg$c76(s2, s6);\n                  s0 = s1;\n                } else {\n                  peg$currPos = s0;\n                  s0 = peg$FAILED;\n                }\n              } else {\n                peg$currPos = s0;\n                s0 = peg$FAILED;\n              }\n            } else {\n              peg$currPos = s0;\n              s0 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parsewhiteSpace() {\n    var s0, s1;\n    peg$silentFails++;\n\n    if (peg$c78.test(input.charAt(peg$currPos))) {\n      s0 = input.charAt(peg$currPos);\n      peg$currPos++;\n    } else {\n      s0 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c79);\n      }\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c77);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsepatternSyntax() {\n    var s0, s1;\n    peg$silentFails++;\n\n    if (peg$c81.test(input.charAt(peg$currPos))) {\n      s0 = input.charAt(peg$currPos);\n      peg$currPos++;\n    } else {\n      s0 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c82);\n      }\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c80);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parse_() {\n    var s0, s1, s2;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = [];\n    s2 = peg$parsewhiteSpace();\n\n    while (s2 !== peg$FAILED) {\n      s1.push(s2);\n      s2 = peg$parsewhiteSpace();\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c83);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsenumber() {\n    var s0, s1, s2;\n    peg$silentFails++;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 45) {\n      s1 = peg$c85;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c86);\n      }\n    }\n\n    if (s1 === peg$FAILED) {\n      s1 = null;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parseargNumber();\n\n      if (s2 !== peg$FAILED) {\n        peg$savedPos = s0;\n        s1 = peg$c87(s1, s2);\n        s0 = s1;\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c84);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parseapostrophe() {\n    var s0, s1;\n    peg$silentFails++;\n\n    if (input.charCodeAt(peg$currPos) === 39) {\n      s0 = peg$c47;\n      peg$currPos++;\n    } else {\n      s0 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c48);\n      }\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c88);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsedoubleApostrophes() {\n    var s0, s1;\n    peg$silentFails++;\n    s0 = peg$currPos;\n\n    if (input.substr(peg$currPos, 2) === peg$c90) {\n      s1 = peg$c90;\n      peg$currPos += 2;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c91);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c92();\n    }\n\n    s0 = s1;\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c89);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsequotedString() {\n    var s0, s1, s2, s3, s4, s5;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 39) {\n      s1 = peg$c47;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c48);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s2 = peg$parseescapedChar();\n\n      if (s2 !== peg$FAILED) {\n        s3 = peg$currPos;\n        s4 = [];\n\n        if (input.substr(peg$currPos, 2) === peg$c90) {\n          s5 = peg$c90;\n          peg$currPos += 2;\n        } else {\n          s5 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c91);\n          }\n        }\n\n        if (s5 === peg$FAILED) {\n          if (peg$c49.test(input.charAt(peg$currPos))) {\n            s5 = input.charAt(peg$currPos);\n            peg$currPos++;\n          } else {\n            s5 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c50);\n            }\n          }\n        }\n\n        while (s5 !== peg$FAILED) {\n          s4.push(s5);\n\n          if (input.substr(peg$currPos, 2) === peg$c90) {\n            s5 = peg$c90;\n            peg$currPos += 2;\n          } else {\n            s5 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c91);\n            }\n          }\n\n          if (s5 === peg$FAILED) {\n            if (peg$c49.test(input.charAt(peg$currPos))) {\n              s5 = input.charAt(peg$currPos);\n              peg$currPos++;\n            } else {\n              s5 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c50);\n              }\n            }\n          }\n        }\n\n        if (s4 !== peg$FAILED) {\n          s3 = input.substring(s3, peg$currPos);\n        } else {\n          s3 = s4;\n        }\n\n        if (s3 !== peg$FAILED) {\n          if (input.charCodeAt(peg$currPos) === 39) {\n            s4 = peg$c47;\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c48);\n            }\n          }\n\n          if (s4 === peg$FAILED) {\n            s4 = null;\n          }\n\n          if (s4 !== peg$FAILED) {\n            peg$savedPos = s0;\n            s1 = peg$c93(s2, s3);\n            s0 = s1;\n          } else {\n            peg$currPos = s0;\n            s0 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s0;\n          s0 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s0;\n        s0 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s0;\n      s0 = peg$FAILED;\n    }\n\n    return s0;\n  }\n\n  function peg$parseunquotedString() {\n    var s0, s1, s2, s3;\n    s0 = peg$currPos;\n    s1 = peg$currPos;\n\n    if (input.length > peg$currPos) {\n      s2 = input.charAt(peg$currPos);\n      peg$currPos++;\n    } else {\n      s2 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c29);\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      peg$savedPos = peg$currPos;\n      s3 = peg$c94(s2);\n\n      if (s3) {\n        s3 = undefined;\n      } else {\n        s3 = peg$FAILED;\n      }\n\n      if (s3 !== peg$FAILED) {\n        s2 = [s2, s3];\n        s1 = s2;\n      } else {\n        peg$currPos = s1;\n        s1 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s1;\n      s1 = peg$FAILED;\n    }\n\n    if (s1 === peg$FAILED) {\n      if (input.charCodeAt(peg$currPos) === 10) {\n        s1 = peg$c95;\n        peg$currPos++;\n      } else {\n        s1 = peg$FAILED;\n\n        if (peg$silentFails === 0) {\n          peg$fail(peg$c96);\n        }\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    return s0;\n  }\n\n  function peg$parseescapedChar() {\n    var s0, s1, s2, s3;\n    s0 = peg$currPos;\n    s1 = peg$currPos;\n\n    if (input.length > peg$currPos) {\n      s2 = input.charAt(peg$currPos);\n      peg$currPos++;\n    } else {\n      s2 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c29);\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      peg$savedPos = peg$currPos;\n      s3 = peg$c97(s2);\n\n      if (s3) {\n        s3 = undefined;\n      } else {\n        s3 = peg$FAILED;\n      }\n\n      if (s3 !== peg$FAILED) {\n        s2 = [s2, s3];\n        s1 = s2;\n      } else {\n        peg$currPos = s1;\n        s1 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s1;\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    return s0;\n  }\n\n  function peg$parseargNameOrNumber() {\n    var s0, s1;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = peg$parseargNumber();\n\n    if (s1 === peg$FAILED) {\n      s1 = peg$parseargName();\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c98);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsevalidTag() {\n    var s0, s1;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = peg$parseargNumber();\n\n    if (s1 === peg$FAILED) {\n      s1 = peg$parsetagName();\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c99);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parseargNumber() {\n    var s0, s1, s2, s3, s4;\n    peg$silentFails++;\n    s0 = peg$currPos;\n\n    if (input.charCodeAt(peg$currPos) === 48) {\n      s1 = peg$c101;\n      peg$currPos++;\n    } else {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c102);\n      }\n    }\n\n    if (s1 !== peg$FAILED) {\n      peg$savedPos = s0;\n      s1 = peg$c103();\n    }\n\n    s0 = s1;\n\n    if (s0 === peg$FAILED) {\n      s0 = peg$currPos;\n      s1 = peg$currPos;\n\n      if (peg$c104.test(input.charAt(peg$currPos))) {\n        s2 = input.charAt(peg$currPos);\n        peg$currPos++;\n      } else {\n        s2 = peg$FAILED;\n\n        if (peg$silentFails === 0) {\n          peg$fail(peg$c105);\n        }\n      }\n\n      if (s2 !== peg$FAILED) {\n        s3 = [];\n\n        if (peg$c106.test(input.charAt(peg$currPos))) {\n          s4 = input.charAt(peg$currPos);\n          peg$currPos++;\n        } else {\n          s4 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c107);\n          }\n        }\n\n        while (s4 !== peg$FAILED) {\n          s3.push(s4);\n\n          if (peg$c106.test(input.charAt(peg$currPos))) {\n            s4 = input.charAt(peg$currPos);\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c107);\n            }\n          }\n        }\n\n        if (s3 !== peg$FAILED) {\n          s2 = [s2, s3];\n          s1 = s2;\n        } else {\n          peg$currPos = s1;\n          s1 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s1;\n        s1 = peg$FAILED;\n      }\n\n      if (s1 !== peg$FAILED) {\n        peg$savedPos = s0;\n        s1 = peg$c108(s1);\n      }\n\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c100);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parseargName() {\n    var s0, s1, s2, s3, s4;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = [];\n    s2 = peg$currPos;\n    s3 = peg$currPos;\n    peg$silentFails++;\n    s4 = peg$parsewhiteSpace();\n\n    if (s4 === peg$FAILED) {\n      s4 = peg$parsepatternSyntax();\n    }\n\n    peg$silentFails--;\n\n    if (s4 === peg$FAILED) {\n      s3 = undefined;\n    } else {\n      peg$currPos = s3;\n      s3 = peg$FAILED;\n    }\n\n    if (s3 !== peg$FAILED) {\n      if (input.length > peg$currPos) {\n        s4 = input.charAt(peg$currPos);\n        peg$currPos++;\n      } else {\n        s4 = peg$FAILED;\n\n        if (peg$silentFails === 0) {\n          peg$fail(peg$c29);\n        }\n      }\n\n      if (s4 !== peg$FAILED) {\n        s3 = [s3, s4];\n        s2 = s3;\n      } else {\n        peg$currPos = s2;\n        s2 = peg$FAILED;\n      }\n    } else {\n      peg$currPos = s2;\n      s2 = peg$FAILED;\n    }\n\n    if (s2 !== peg$FAILED) {\n      while (s2 !== peg$FAILED) {\n        s1.push(s2);\n        s2 = peg$currPos;\n        s3 = peg$currPos;\n        peg$silentFails++;\n        s4 = peg$parsewhiteSpace();\n\n        if (s4 === peg$FAILED) {\n          s4 = peg$parsepatternSyntax();\n        }\n\n        peg$silentFails--;\n\n        if (s4 === peg$FAILED) {\n          s3 = undefined;\n        } else {\n          peg$currPos = s3;\n          s3 = peg$FAILED;\n        }\n\n        if (s3 !== peg$FAILED) {\n          if (input.length > peg$currPos) {\n            s4 = input.charAt(peg$currPos);\n            peg$currPos++;\n          } else {\n            s4 = peg$FAILED;\n\n            if (peg$silentFails === 0) {\n              peg$fail(peg$c29);\n            }\n          }\n\n          if (s4 !== peg$FAILED) {\n            s3 = [s3, s4];\n            s2 = s3;\n          } else {\n            peg$currPos = s2;\n            s2 = peg$FAILED;\n          }\n        } else {\n          peg$currPos = s2;\n          s2 = peg$FAILED;\n        }\n      }\n    } else {\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c109);\n      }\n    }\n\n    return s0;\n  }\n\n  function peg$parsetagName() {\n    var s0, s1, s2, s3, s4;\n    peg$silentFails++;\n    s0 = peg$currPos;\n    s1 = [];\n\n    if (input.charCodeAt(peg$currPos) === 45) {\n      s2 = peg$c85;\n      peg$currPos++;\n    } else {\n      s2 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c86);\n      }\n    }\n\n    if (s2 === peg$FAILED) {\n      s2 = peg$currPos;\n      s3 = peg$currPos;\n      peg$silentFails++;\n      s4 = peg$parsewhiteSpace();\n\n      if (s4 === peg$FAILED) {\n        s4 = peg$parsepatternSyntax();\n      }\n\n      peg$silentFails--;\n\n      if (s4 === peg$FAILED) {\n        s3 = undefined;\n      } else {\n        peg$currPos = s3;\n        s3 = peg$FAILED;\n      }\n\n      if (s3 !== peg$FAILED) {\n        if (input.length > peg$currPos) {\n          s4 = input.charAt(peg$currPos);\n          peg$currPos++;\n        } else {\n          s4 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c29);\n          }\n        }\n\n        if (s4 !== peg$FAILED) {\n          s3 = [s3, s4];\n          s2 = s3;\n        } else {\n          peg$currPos = s2;\n          s2 = peg$FAILED;\n        }\n      } else {\n        peg$currPos = s2;\n        s2 = peg$FAILED;\n      }\n    }\n\n    if (s2 !== peg$FAILED) {\n      while (s2 !== peg$FAILED) {\n        s1.push(s2);\n\n        if (input.charCodeAt(peg$currPos) === 45) {\n          s2 = peg$c85;\n          peg$currPos++;\n        } else {\n          s2 = peg$FAILED;\n\n          if (peg$silentFails === 0) {\n            peg$fail(peg$c86);\n          }\n        }\n\n        if (s2 === peg$FAILED) {\n          s2 = peg$currPos;\n          s3 = peg$currPos;\n          peg$silentFails++;\n          s4 = peg$parsewhiteSpace();\n\n          if (s4 === peg$FAILED) {\n            s4 = peg$parsepatternSyntax();\n          }\n\n          peg$silentFails--;\n\n          if (s4 === peg$FAILED) {\n            s3 = undefined;\n          } else {\n            peg$currPos = s3;\n            s3 = peg$FAILED;\n          }\n\n          if (s3 !== peg$FAILED) {\n            if (input.length > peg$currPos) {\n              s4 = input.charAt(peg$currPos);\n              peg$currPos++;\n            } else {\n              s4 = peg$FAILED;\n\n              if (peg$silentFails === 0) {\n                peg$fail(peg$c29);\n              }\n            }\n\n            if (s4 !== peg$FAILED) {\n              s3 = [s3, s4];\n              s2 = s3;\n            } else {\n              peg$currPos = s2;\n              s2 = peg$FAILED;\n            }\n          } else {\n            peg$currPos = s2;\n            s2 = peg$FAILED;\n          }\n        }\n      }\n    } else {\n      s1 = peg$FAILED;\n    }\n\n    if (s1 !== peg$FAILED) {\n      s0 = input.substring(s0, peg$currPos);\n    } else {\n      s0 = s1;\n    }\n\n    peg$silentFails--;\n\n    if (s0 === peg$FAILED) {\n      s1 = peg$FAILED;\n\n      if (peg$silentFails === 0) {\n        peg$fail(peg$c110);\n      }\n    }\n\n    return s0;\n  }\n\n  var messageCtx = ['root'];\n\n  function isNestedMessageText() {\n    return messageCtx.length > 1;\n  }\n\n  function isInPluralOption() {\n    return messageCtx[messageCtx.length - 1] === 'plural';\n  }\n\n  function insertLocation() {\n    return options && options.captureLocation ? {\n      location: location()\n    } : {};\n  }\n\n  peg$result = peg$startRuleFunction();\n\n  if (peg$result !== peg$FAILED && peg$currPos === input.length) {\n    return peg$result;\n  } else {\n    if (peg$result !== peg$FAILED && peg$currPos < input.length) {\n      peg$fail(peg$endExpectation());\n    }\n\n    throw peg$buildStructuredError(peg$maxFailExpected, peg$maxFailPos < input.length ? input.charAt(peg$maxFailPos) : null, peg$maxFailPos < input.length ? peg$computeLocation(peg$maxFailPos, peg$maxFailPos + 1) : peg$computeLocation(peg$maxFailPos, peg$maxFailPos));\n  }\n}\n\nvar pegParse = peg$parse;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat-parser/lib/parser.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat-parser/lib/skeleton.js":
/*!****************************************************************!*\
  !*** ./node_modules/intl-messageformat-parser/lib/skeleton.js ***!
  \****************************************************************/
/*! namespace exports */
/*! export convertNumberSkeletonToNumberFormatOptions [provided] [no usage info] [missing usage info prevents renaming] */
/*! export parseDateTimeSkeleton [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"parseDateTimeSkeleton\": () => /* binding */ parseDateTimeSkeleton,\n/* harmony export */   \"convertNumberSkeletonToNumberFormatOptions\": () => /* binding */ convertNumberSkeletonToNumberFormatOptions\n/* harmony export */ });\nvar __assign = undefined && undefined.__assign || function () {\n  __assign = Object.assign || function (t) {\n    for (var s, i = 1, n = arguments.length; i < n; i++) {\n      s = arguments[i];\n\n      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\n    }\n\n    return t;\n  };\n\n  return __assign.apply(this, arguments);\n};\n/**\n * https://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table\n * Credit: https://github.com/caridy/intl-datetimeformat-pattern/blob/master/index.js\n * with some tweaks\n */\n\n\nvar DATE_TIME_REGEX = /(?:[Eec]{1,6}|G{1,5}|[Qq]{1,5}|(?:[yYur]+|U{1,5})|[ML]{1,5}|d{1,2}|D{1,3}|F{1}|[abB]{1,5}|[hkHK]{1,2}|w{1,2}|W{1}|m{1,2}|s{1,2}|[zZOvVxX]{1,4})(?=([^']*'[^']*')*[^']*$)/g;\n/**\n * Parse Date time skeleton into Intl.DateTimeFormatOptions\n * Ref: https://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table\n * @public\n * @param skeleton skeleton string\n */\n\nfunction parseDateTimeSkeleton(skeleton) {\n  var result = {};\n  skeleton.replace(DATE_TIME_REGEX, function (match) {\n    var len = match.length;\n\n    switch (match[0]) {\n      // Era\n      case 'G':\n        result.era = len === 4 ? 'long' : len === 5 ? 'narrow' : 'short';\n        break;\n      // Year\n\n      case 'y':\n        result.year = len === 2 ? '2-digit' : 'numeric';\n        break;\n\n      case 'Y':\n      case 'u':\n      case 'U':\n      case 'r':\n        throw new RangeError('`Y/u/U/r` (year) patterns are not supported, use `y` instead');\n      // Quarter\n\n      case 'q':\n      case 'Q':\n        throw new RangeError('`q/Q` (quarter) patterns are not supported');\n      // Month\n\n      case 'M':\n      case 'L':\n        result.month = ['numeric', '2-digit', 'short', 'long', 'narrow'][len - 1];\n        break;\n      // Week\n\n      case 'w':\n      case 'W':\n        throw new RangeError('`w/W` (week) patterns are not supported');\n\n      case 'd':\n        result.day = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'D':\n      case 'F':\n      case 'g':\n        throw new RangeError('`D/F/g` (day) patterns are not supported, use `d` instead');\n      // Weekday\n\n      case 'E':\n        result.weekday = len === 4 ? 'short' : len === 5 ? 'narrow' : 'short';\n        break;\n\n      case 'e':\n        if (len < 4) {\n          throw new RangeError('`e..eee` (weekday) patterns are not supported');\n        }\n\n        result.weekday = ['short', 'long', 'narrow', 'short'][len - 4];\n        break;\n\n      case 'c':\n        if (len < 4) {\n          throw new RangeError('`c..ccc` (weekday) patterns are not supported');\n        }\n\n        result.weekday = ['short', 'long', 'narrow', 'short'][len - 4];\n        break;\n      // Period\n\n      case 'a':\n        // AM, PM\n        result.hour12 = true;\n        break;\n\n      case 'b': // am, pm, noon, midnight\n\n      case 'B':\n        // flexible day periods\n        throw new RangeError('`b/B` (period) patterns are not supported, use `a` instead');\n      // Hour\n\n      case 'h':\n        result.hourCycle = 'h12';\n        result.hour = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'H':\n        result.hourCycle = 'h23';\n        result.hour = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'K':\n        result.hourCycle = 'h11';\n        result.hour = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'k':\n        result.hourCycle = 'h24';\n        result.hour = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'j':\n      case 'J':\n      case 'C':\n        throw new RangeError('`j/J/C` (hour) patterns are not supported, use `h/H/K/k` instead');\n      // Minute\n\n      case 'm':\n        result.minute = ['numeric', '2-digit'][len - 1];\n        break;\n      // Second\n\n      case 's':\n        result.second = ['numeric', '2-digit'][len - 1];\n        break;\n\n      case 'S':\n      case 'A':\n        throw new RangeError('`S/A` (second) pattenrs are not supported, use `s` instead');\n      // Zone\n\n      case 'z':\n        // 1..3, 4: specific non-location format\n        result.timeZoneName = len < 4 ? 'short' : 'long';\n        break;\n\n      case 'Z': // 1..3, 4, 5: The ISO8601 varios formats\n\n      case 'O': // 1, 4: miliseconds in day short, long\n\n      case 'v': // 1, 4: generic non-location format\n\n      case 'V': // 1, 2, 3, 4: time zone ID or city\n\n      case 'X': // 1, 2, 3, 4: The ISO8601 varios formats\n\n      case 'x':\n        // 1, 2, 3, 4: The ISO8601 varios formats\n        throw new RangeError('`Z/O/v/V/X/x` (timeZone) pattenrs are not supported, use `z` instead');\n    }\n\n    return '';\n  });\n  return result;\n}\n\nfunction icuUnitToEcma(unit) {\n  return unit.replace(/^(.*?)-/, '');\n}\n\nvar FRACTION_PRECISION_REGEX = /^\\.(?:(0+)(\\*)?|(#+)|(0+)(#+))$/g;\nvar SIGNIFICANT_PRECISION_REGEX = /^(@+)?(\\+|#+)?$/g;\n\nfunction parseSignificantPrecision(str) {\n  var result = {};\n  str.replace(SIGNIFICANT_PRECISION_REGEX, function (_, g1, g2) {\n    // @@@ case\n    if (typeof g2 !== 'string') {\n      result.minimumSignificantDigits = g1.length;\n      result.maximumSignificantDigits = g1.length;\n    } // @@@+ case\n    else if (g2 === '+') {\n        result.minimumSignificantDigits = g1.length;\n      } // .### case\n      else if (g1[0] === '#') {\n          result.maximumSignificantDigits = g1.length;\n        } // .@@## or .@@@ case\n        else {\n            result.minimumSignificantDigits = g1.length;\n            result.maximumSignificantDigits = g1.length + (typeof g2 === 'string' ? g2.length : 0);\n          }\n\n    return '';\n  });\n  return result;\n}\n\nfunction parseSign(str) {\n  switch (str) {\n    case 'sign-auto':\n      return {\n        signDisplay: 'auto'\n      };\n\n    case 'sign-accounting':\n      return {\n        currencySign: 'accounting'\n      };\n\n    case 'sign-always':\n      return {\n        signDisplay: 'always'\n      };\n\n    case 'sign-accounting-always':\n      return {\n        signDisplay: 'always',\n        currencySign: 'accounting'\n      };\n\n    case 'sign-except-zero':\n      return {\n        signDisplay: 'exceptZero'\n      };\n\n    case 'sign-accounting-except-zero':\n      return {\n        signDisplay: 'exceptZero',\n        currencySign: 'accounting'\n      };\n\n    case 'sign-never':\n      return {\n        signDisplay: 'never'\n      };\n  }\n}\n\nfunction parseNotationOptions(opt) {\n  var result = {};\n  var signOpts = parseSign(opt);\n\n  if (signOpts) {\n    return signOpts;\n  }\n\n  return result;\n}\n/**\n * https://github.com/unicode-org/icu/blob/master/docs/userguide/format_parse/numbers/skeletons.md#skeleton-stems-and-options\n */\n\n\nfunction convertNumberSkeletonToNumberFormatOptions(tokens) {\n  var result = {};\n\n  for (var _i = 0, tokens_1 = tokens; _i < tokens_1.length; _i++) {\n    var token = tokens_1[_i];\n\n    switch (token.stem) {\n      case 'percent':\n        result.style = 'percent';\n        continue;\n\n      case 'currency':\n        result.style = 'currency';\n        result.currency = token.options[0];\n        continue;\n\n      case 'group-off':\n        result.useGrouping = false;\n        continue;\n\n      case 'precision-integer':\n      case '.':\n        result.maximumFractionDigits = 0;\n        continue;\n\n      case 'measure-unit':\n        result.style = 'unit';\n        result.unit = icuUnitToEcma(token.options[0]);\n        continue;\n\n      case 'compact-short':\n        result.notation = 'compact';\n        result.compactDisplay = 'short';\n        continue;\n\n      case 'compact-long':\n        result.notation = 'compact';\n        result.compactDisplay = 'long';\n        continue;\n\n      case 'scientific':\n        result = __assign(__assign(__assign({}, result), {\n          notation: 'scientific'\n        }), token.options.reduce(function (all, opt) {\n          return __assign(__assign({}, all), parseNotationOptions(opt));\n        }, {}));\n        continue;\n\n      case 'engineering':\n        result = __assign(__assign(__assign({}, result), {\n          notation: 'engineering'\n        }), token.options.reduce(function (all, opt) {\n          return __assign(__assign({}, all), parseNotationOptions(opt));\n        }, {}));\n        continue;\n\n      case 'notation-simple':\n        result.notation = 'standard';\n        continue;\n      // https://github.com/unicode-org/icu/blob/master/icu4c/source/i18n/unicode/unumberformatter.h\n\n      case 'unit-width-narrow':\n        result.currencyDisplay = 'narrowSymbol';\n        result.unitDisplay = 'narrow';\n        continue;\n\n      case 'unit-width-short':\n        result.currencyDisplay = 'code';\n        result.unitDisplay = 'short';\n        continue;\n\n      case 'unit-width-full-name':\n        result.currencyDisplay = 'name';\n        result.unitDisplay = 'long';\n        continue;\n\n      case 'unit-width-iso-code':\n        result.currencyDisplay = 'symbol';\n        continue;\n    } // Precision\n    // https://github.com/unicode-org/icu/blob/master/docs/userguide/format_parse/numbers/skeletons.md#fraction-precision\n    // precision-integer case\n\n\n    if (FRACTION_PRECISION_REGEX.test(token.stem)) {\n      if (token.options.length > 1) {\n        throw new RangeError('Fraction-precision stems only accept a single optional option');\n      }\n\n      token.stem.replace(FRACTION_PRECISION_REGEX, function (match, g1, g2, g3, g4, g5) {\n        // .000* case (before ICU67 it was .000+)\n        if (g2 === '*') {\n          result.minimumFractionDigits = g1.length;\n        } // .### case\n        else if (g3 && g3[0] === '#') {\n            result.maximumFractionDigits = g3.length;\n          } // .00## case\n          else if (g4 && g5) {\n              result.minimumFractionDigits = g4.length;\n              result.maximumFractionDigits = g4.length + g5.length;\n            } else {\n              result.minimumFractionDigits = g1.length;\n              result.maximumFractionDigits = g1.length;\n            }\n\n        return '';\n      });\n\n      if (token.options.length) {\n        result = __assign(__assign({}, result), parseSignificantPrecision(token.options[0]));\n      }\n\n      continue;\n    }\n\n    if (SIGNIFICANT_PRECISION_REGEX.test(token.stem)) {\n      result = __assign(__assign({}, result), parseSignificantPrecision(token.stem));\n      continue;\n    }\n\n    var signOpts = parseSign(token.stem);\n\n    if (signOpts) {\n      result = __assign(__assign({}, result), signOpts);\n    }\n  }\n\n  return result;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat-parser/lib/skeleton.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat-parser/lib/types.js":
/*!*************************************************************!*\
  !*** ./node_modules/intl-messageformat-parser/lib/types.js ***!
  \*************************************************************/
/*! namespace exports */
/*! export SKELETON_TYPE [provided] [no usage info] [missing usage info prevents renaming] */
/*! export TYPE [provided] [no usage info] [missing usage info prevents renaming] */
/*! export createLiteralElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export createNumberElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isArgumentElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDateElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDateTimeSkeleton [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isLiteralElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isNumberElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isNumberSkeleton [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isPluralElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isPoundElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isSelectElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isTagElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isTimeElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"TYPE\": () => /* binding */ TYPE,\n/* harmony export */   \"SKELETON_TYPE\": () => /* binding */ SKELETON_TYPE,\n/* harmony export */   \"isLiteralElement\": () => /* binding */ isLiteralElement,\n/* harmony export */   \"isArgumentElement\": () => /* binding */ isArgumentElement,\n/* harmony export */   \"isNumberElement\": () => /* binding */ isNumberElement,\n/* harmony export */   \"isDateElement\": () => /* binding */ isDateElement,\n/* harmony export */   \"isTimeElement\": () => /* binding */ isTimeElement,\n/* harmony export */   \"isSelectElement\": () => /* binding */ isSelectElement,\n/* harmony export */   \"isPluralElement\": () => /* binding */ isPluralElement,\n/* harmony export */   \"isPoundElement\": () => /* binding */ isPoundElement,\n/* harmony export */   \"isTagElement\": () => /* binding */ isTagElement,\n/* harmony export */   \"isNumberSkeleton\": () => /* binding */ isNumberSkeleton,\n/* harmony export */   \"isDateTimeSkeleton\": () => /* binding */ isDateTimeSkeleton,\n/* harmony export */   \"createLiteralElement\": () => /* binding */ createLiteralElement,\n/* harmony export */   \"createNumberElement\": () => /* binding */ createNumberElement\n/* harmony export */ });\nvar TYPE;\n\n(function (TYPE) {\n  /**\n   * Raw text\n   */\n  TYPE[TYPE[\"literal\"] = 0] = \"literal\";\n  /**\n   * Variable w/o any format, e.g `var` in `this is a {var}`\n   */\n\n  TYPE[TYPE[\"argument\"] = 1] = \"argument\";\n  /**\n   * Variable w/ number format\n   */\n\n  TYPE[TYPE[\"number\"] = 2] = \"number\";\n  /**\n   * Variable w/ date format\n   */\n\n  TYPE[TYPE[\"date\"] = 3] = \"date\";\n  /**\n   * Variable w/ time format\n   */\n\n  TYPE[TYPE[\"time\"] = 4] = \"time\";\n  /**\n   * Variable w/ select format\n   */\n\n  TYPE[TYPE[\"select\"] = 5] = \"select\";\n  /**\n   * Variable w/ plural format\n   */\n\n  TYPE[TYPE[\"plural\"] = 6] = \"plural\";\n  /**\n   * Only possible within plural argument.\n   * This is the `#` symbol that will be substituted with the count.\n   */\n\n  TYPE[TYPE[\"pound\"] = 7] = \"pound\";\n  /**\n   * XML-like tag\n   */\n\n  TYPE[TYPE[\"tag\"] = 8] = \"tag\";\n})(TYPE || (TYPE = {}));\n\nvar SKELETON_TYPE;\n\n(function (SKELETON_TYPE) {\n  SKELETON_TYPE[SKELETON_TYPE[\"number\"] = 0] = \"number\";\n  SKELETON_TYPE[SKELETON_TYPE[\"dateTime\"] = 1] = \"dateTime\";\n})(SKELETON_TYPE || (SKELETON_TYPE = {}));\n/**\n * Type Guards\n */\n\n\nfunction isLiteralElement(el) {\n  return el.type === TYPE.literal;\n}\nfunction isArgumentElement(el) {\n  return el.type === TYPE.argument;\n}\nfunction isNumberElement(el) {\n  return el.type === TYPE.number;\n}\nfunction isDateElement(el) {\n  return el.type === TYPE.date;\n}\nfunction isTimeElement(el) {\n  return el.type === TYPE.time;\n}\nfunction isSelectElement(el) {\n  return el.type === TYPE.select;\n}\nfunction isPluralElement(el) {\n  return el.type === TYPE.plural;\n}\nfunction isPoundElement(el) {\n  return el.type === TYPE.pound;\n}\nfunction isTagElement(el) {\n  return el.type === TYPE.tag;\n}\nfunction isNumberSkeleton(el) {\n  return !!(el && typeof el === 'object' && el.type === 0\n  /* number */\n  );\n}\nfunction isDateTimeSkeleton(el) {\n  return !!(el && typeof el === 'object' && el.type === 1\n  /* dateTime */\n  );\n}\nfunction createLiteralElement(value) {\n  return {\n    type: TYPE.literal,\n    value: value\n  };\n}\nfunction createNumberElement(value, style) {\n  return {\n    type: TYPE.number,\n    value: value,\n    style: style\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat-parser/lib/types.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat/lib/core.js":
/*!*****************************************************!*\
  !*** ./node_modules/intl-messageformat/lib/core.js ***!
  \*****************************************************/
/*! namespace exports */
/*! export IntlMessageFormat [provided] [no usage info] [missing usage info prevents renaming] */
/*! export createDefaultFormatters [provided] [no usage info] [missing usage info prevents renaming] */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"createDefaultFormatters\": () => /* binding */ createDefaultFormatters,\n/* harmony export */   \"IntlMessageFormat\": () => /* binding */ IntlMessageFormat,\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! intl-messageformat-parser */ \"./node_modules/intl-messageformat-parser/lib/index.js\");\n/* harmony import */ var intl_format_cache__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! intl-format-cache */ \"./node_modules/intl-format-cache/lib/index.js\");\n/* harmony import */ var _formatters__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./formatters */ \"./node_modules/intl-messageformat/lib/formatters.js\");\n/*\nCopyright (c) 2014, Yahoo! Inc. All rights reserved.\nCopyrights licensed under the New BSD License.\nSee the accompanying LICENSE file for terms.\n*/\nvar __assign = undefined && undefined.__assign || function () {\n  __assign = Object.assign || function (t) {\n    for (var s, i = 1, n = arguments.length; i < n; i++) {\n      s = arguments[i];\n\n      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\n    }\n\n    return t;\n  };\n\n  return __assign.apply(this, arguments);\n};\n\n\n\n // -- MessageFormat --------------------------------------------------------\n\nfunction mergeConfig(c1, c2) {\n  if (!c2) {\n    return c1;\n  }\n\n  return __assign(__assign(__assign({}, c1 || {}), c2 || {}), Object.keys(c1).reduce(function (all, k) {\n    all[k] = __assign(__assign({}, c1[k]), c2[k] || {});\n    return all;\n  }, {}));\n}\n\nfunction mergeConfigs(defaultConfig, configs) {\n  if (!configs) {\n    return defaultConfig;\n  }\n\n  return Object.keys(defaultConfig).reduce(function (all, k) {\n    all[k] = mergeConfig(defaultConfig[k], configs[k]);\n    return all;\n  }, __assign({}, defaultConfig));\n}\n\nfunction createDefaultFormatters(cache) {\n  if (cache === void 0) {\n    cache = {\n      number: {},\n      dateTime: {},\n      pluralRules: {}\n    };\n  }\n\n  return {\n    getNumberFormat: (0,intl_format_cache__WEBPACK_IMPORTED_MODULE_0__.default)(Intl.NumberFormat, cache.number),\n    getDateTimeFormat: (0,intl_format_cache__WEBPACK_IMPORTED_MODULE_0__.default)(Intl.DateTimeFormat, cache.dateTime),\n    getPluralRules: (0,intl_format_cache__WEBPACK_IMPORTED_MODULE_0__.default)(Intl.PluralRules, cache.pluralRules)\n  };\n}\n\nvar IntlMessageFormat =\n/** @class */\nfunction () {\n  function IntlMessageFormat(message, locales, overrideFormats, opts) {\n    var _this = this;\n\n    if (locales === void 0) {\n      locales = IntlMessageFormat.defaultLocale;\n    }\n\n    this.formatterCache = {\n      number: {},\n      dateTime: {},\n      pluralRules: {}\n    };\n\n    this.format = function (values) {\n      var parts = _this.formatToParts(values); // Hot path for straight simple msg translations\n\n\n      if (parts.length === 1) {\n        return parts[0].value;\n      }\n\n      var result = parts.reduce(function (all, part) {\n        if (!all.length || part.type !== 0\n        /* literal */\n        || typeof all[all.length - 1] !== 'string') {\n          all.push(part.value);\n        } else {\n          all[all.length - 1] += part.value;\n        }\n\n        return all;\n      }, []);\n\n      if (result.length <= 1) {\n        return result[0] || '';\n      }\n\n      return result;\n    };\n\n    this.formatToParts = function (values) {\n      return (0,_formatters__WEBPACK_IMPORTED_MODULE_1__.formatToParts)(_this.ast, _this.locales, _this.formatters, _this.formats, values, undefined, _this.message);\n    };\n\n    this.resolvedOptions = function () {\n      return {\n        locale: Intl.NumberFormat.supportedLocalesOf(_this.locales)[0]\n      };\n    };\n\n    this.getAst = function () {\n      return _this.ast;\n    };\n\n    if (typeof message === 'string') {\n      this.message = message;\n\n      if (!IntlMessageFormat.__parse) {\n        throw new TypeError('IntlMessageFormat.__parse must be set to process `message` of type `string`');\n      } // Parse string messages into an AST.\n\n\n      this.ast = IntlMessageFormat.__parse(message, {\n        normalizeHashtagInPlural: false\n      });\n    } else {\n      this.ast = message;\n    }\n\n    if (!Array.isArray(this.ast)) {\n      throw new TypeError('A message must be provided as a String or AST.');\n    } // Creates a new object with the specified `formats` merged with the default\n    // formats.\n\n\n    this.formats = mergeConfigs(IntlMessageFormat.formats, overrideFormats); // Defined first because it's used to build the format pattern.\n\n    this.locales = locales;\n    this.formatters = opts && opts.formatters || createDefaultFormatters(this.formatterCache);\n  }\n\n  Object.defineProperty(IntlMessageFormat, \"defaultLocale\", {\n    get: function () {\n      if (!IntlMessageFormat.memoizedDefaultLocale) {\n        IntlMessageFormat.memoizedDefaultLocale = new Intl.NumberFormat().resolvedOptions().locale;\n      }\n\n      return IntlMessageFormat.memoizedDefaultLocale;\n    },\n    enumerable: true,\n    configurable: true\n  });\n  IntlMessageFormat.memoizedDefaultLocale = null;\n  IntlMessageFormat.__parse = intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__.parse; // Default format options used as the prototype of the `formats` provided to the\n  // constructor. These are used when constructing the internal Intl.NumberFormat\n  // and Intl.DateTimeFormat instances.\n\n  IntlMessageFormat.formats = {\n    number: {\n      currency: {\n        style: 'currency'\n      },\n      percent: {\n        style: 'percent'\n      }\n    },\n    date: {\n      short: {\n        month: 'numeric',\n        day: 'numeric',\n        year: '2-digit'\n      },\n      medium: {\n        month: 'short',\n        day: 'numeric',\n        year: 'numeric'\n      },\n      long: {\n        month: 'long',\n        day: 'numeric',\n        year: 'numeric'\n      },\n      full: {\n        weekday: 'long',\n        month: 'long',\n        day: 'numeric',\n        year: 'numeric'\n      }\n    },\n    time: {\n      short: {\n        hour: 'numeric',\n        minute: 'numeric'\n      },\n      medium: {\n        hour: 'numeric',\n        minute: 'numeric',\n        second: 'numeric'\n      },\n      long: {\n        hour: 'numeric',\n        minute: 'numeric',\n        second: 'numeric',\n        timeZoneName: 'short'\n      },\n      full: {\n        hour: 'numeric',\n        minute: 'numeric',\n        second: 'numeric',\n        timeZoneName: 'short'\n      }\n    }\n  };\n  return IntlMessageFormat;\n}();\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (IntlMessageFormat);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat/lib/core.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat/lib/error.js":
/*!******************************************************!*\
  !*** ./node_modules/intl-messageformat/lib/error.js ***!
  \******************************************************/
/*! namespace exports */
/*! export ErrorCode [provided] [no usage info] [missing usage info prevents renaming] */
/*! export FormatError [provided] [no usage info] [missing usage info prevents renaming] */
/*! export InvalidValueError [provided] [no usage info] [missing usage info prevents renaming] */
/*! export InvalidValueTypeError [provided] [no usage info] [missing usage info prevents renaming] */
/*! export MissingValueError [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"ErrorCode\": () => /* binding */ ErrorCode,\n/* harmony export */   \"FormatError\": () => /* binding */ FormatError,\n/* harmony export */   \"InvalidValueError\": () => /* binding */ InvalidValueError,\n/* harmony export */   \"InvalidValueTypeError\": () => /* binding */ InvalidValueTypeError,\n/* harmony export */   \"MissingValueError\": () => /* binding */ MissingValueError\n/* harmony export */ });\nvar __extends = undefined && undefined.__extends || function () {\n  var extendStatics = function (d, b) {\n    extendStatics = Object.setPrototypeOf || {\n      __proto__: []\n    } instanceof Array && function (d, b) {\n      d.__proto__ = b;\n    } || function (d, b) {\n      for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];\n    };\n\n    return extendStatics(d, b);\n  };\n\n  return function (d, b) {\n    extendStatics(d, b);\n\n    function __() {\n      this.constructor = d;\n    }\n\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n  };\n}();\n\nvar ErrorCode;\n\n(function (ErrorCode) {\n  // When we have a placeholder but no value to format\n  ErrorCode[\"MISSING_VALUE\"] = \"MISSING_VALUE\"; // When value supplied is invalid\n\n  ErrorCode[\"INVALID_VALUE\"] = \"INVALID_VALUE\"; // When we need specific Intl API but it's not available\n\n  ErrorCode[\"MISSING_INTL_API\"] = \"MISSING_INTL_API\";\n})(ErrorCode || (ErrorCode = {}));\n\nvar FormatError =\n/** @class */\nfunction (_super) {\n  __extends(FormatError, _super);\n\n  function FormatError(msg, code, originalMessage) {\n    var _this = _super.call(this, msg) || this;\n\n    _this.code = code;\n    _this.originalMessage = originalMessage;\n    return _this;\n  }\n\n  FormatError.prototype.toString = function () {\n    return \"[formatjs Error: \" + this.code + \"] \" + this.message;\n  };\n\n  return FormatError;\n}(Error);\n\n\n\nvar InvalidValueError =\n/** @class */\nfunction (_super) {\n  __extends(InvalidValueError, _super);\n\n  function InvalidValueError(variableId, value, options, originalMessage) {\n    return _super.call(this, \"Invalid values for \\\"\" + variableId + \"\\\": \\\"\" + value + \"\\\". Options are \\\"\" + Object.keys(options).join('\", \"') + \"\\\"\", \"INVALID_VALUE\"\n    /* INVALID_VALUE */\n    , originalMessage) || this;\n  }\n\n  return InvalidValueError;\n}(FormatError);\n\n\n\nvar InvalidValueTypeError =\n/** @class */\nfunction (_super) {\n  __extends(InvalidValueTypeError, _super);\n\n  function InvalidValueTypeError(value, type, originalMessage) {\n    return _super.call(this, \"Value for \\\"\" + value + \"\\\" must be of type \" + type, \"INVALID_VALUE\"\n    /* INVALID_VALUE */\n    , originalMessage) || this;\n  }\n\n  return InvalidValueTypeError;\n}(FormatError);\n\n\n\nvar MissingValueError =\n/** @class */\nfunction (_super) {\n  __extends(MissingValueError, _super);\n\n  function MissingValueError(variableId, originalMessage) {\n    return _super.call(this, \"The intl string context variable \\\"\" + variableId + \"\\\" was not provided to the string \\\"\" + originalMessage + \"\\\"\", \"MISSING_VALUE\"\n    /* MISSING_VALUE */\n    , originalMessage) || this;\n  }\n\n  return MissingValueError;\n}(FormatError);\n\n//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat/lib/error.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat/lib/formatters.js":
/*!***********************************************************!*\
  !*** ./node_modules/intl-messageformat/lib/formatters.js ***!
  \***********************************************************/
/*! namespace exports */
/*! export PART_TYPE [provided] [no usage info] [missing usage info prevents renaming] */
/*! export formatToParts [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PART_TYPE\": () => /* binding */ PART_TYPE,\n/* harmony export */   \"formatToParts\": () => /* binding */ formatToParts\n/* harmony export */ });\n/* harmony import */ var intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! intl-messageformat-parser */ \"./node_modules/intl-messageformat-parser/lib/types.js\");\n/* harmony import */ var intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! intl-messageformat-parser */ \"./node_modules/intl-messageformat-parser/lib/skeleton.js\");\n/* harmony import */ var _error__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./error */ \"./node_modules/intl-messageformat/lib/error.js\");\n\n\nvar PART_TYPE;\n\n(function (PART_TYPE) {\n  PART_TYPE[PART_TYPE[\"literal\"] = 0] = \"literal\";\n  PART_TYPE[PART_TYPE[\"object\"] = 1] = \"object\";\n})(PART_TYPE || (PART_TYPE = {}));\n\nfunction mergeLiteral(parts) {\n  if (parts.length < 2) {\n    return parts;\n  }\n\n  return parts.reduce(function (all, part) {\n    var lastPart = all[all.length - 1];\n\n    if (!lastPart || lastPart.type !== 0\n    /* literal */\n    || part.type !== 0\n    /* literal */\n    ) {\n        all.push(part);\n      } else {\n      lastPart.value += part.value;\n    }\n\n    return all;\n  }, []);\n}\n\nfunction isFormatXMLElementFn(el) {\n  return typeof el === 'function';\n} // TODO(skeleton): add skeleton support\n\n\nfunction formatToParts(els, locales, formatters, formats, values, currentPluralValue, // For debugging\noriginalMessage) {\n  // Hot path for straight simple msg translations\n  if (els.length === 1 && (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isLiteralElement)(els[0])) {\n    return [{\n      type: 0\n      /* literal */\n      ,\n      value: els[0].value\n    }];\n  }\n\n  var result = [];\n\n  for (var _i = 0, els_1 = els; _i < els_1.length; _i++) {\n    var el = els_1[_i]; // Exit early for string parts.\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isLiteralElement)(el)) {\n      result.push({\n        type: 0\n        /* literal */\n        ,\n        value: el.value\n      });\n      continue;\n    } // TODO: should this part be literal type?\n    // Replace `#` in plural rules with the actual numeric value.\n\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isPoundElement)(el)) {\n      if (typeof currentPluralValue === 'number') {\n        result.push({\n          type: 0\n          /* literal */\n          ,\n          value: formatters.getNumberFormat(locales).format(currentPluralValue)\n        });\n      }\n\n      continue;\n    }\n\n    var varName = el.value; // Enforce that all required values are provided by the caller.\n\n    if (!(values && varName in values)) {\n      throw new _error__WEBPACK_IMPORTED_MODULE_1__.MissingValueError(varName, originalMessage);\n    }\n\n    var value = values[varName];\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isArgumentElement)(el)) {\n      if (!value || typeof value === 'string' || typeof value === 'number') {\n        value = typeof value === 'string' || typeof value === 'number' ? String(value) : '';\n      }\n\n      result.push({\n        type: typeof value === 'string' ? 0\n        /* literal */\n        : 1\n        /* object */\n        ,\n        value: value\n      });\n      continue;\n    } // Recursively format plural and select parts' option — which can be a\n    // nested pattern structure. The choosing of the option to use is\n    // abstracted-by and delegated-to the part helper object.\n\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isDateElement)(el)) {\n      var style = typeof el.style === 'string' ? formats.date[el.style] : (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isDateTimeSkeleton)(el.style) ? (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__.parseDateTimeSkeleton)(el.style.pattern) : undefined;\n      result.push({\n        type: 0\n        /* literal */\n        ,\n        value: formatters.getDateTimeFormat(locales, style).format(value)\n      });\n      continue;\n    }\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isTimeElement)(el)) {\n      var style = typeof el.style === 'string' ? formats.time[el.style] : (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isDateTimeSkeleton)(el.style) ? (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__.parseDateTimeSkeleton)(el.style.pattern) : undefined;\n      result.push({\n        type: 0\n        /* literal */\n        ,\n        value: formatters.getDateTimeFormat(locales, style).format(value)\n      });\n      continue;\n    }\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isNumberElement)(el)) {\n      var style = typeof el.style === 'string' ? formats.number[el.style] : (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isNumberSkeleton)(el.style) ? (0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_2__.convertNumberSkeletonToNumberFormatOptions)(el.style.tokens) : undefined;\n      result.push({\n        type: 0\n        /* literal */\n        ,\n        value: formatters.getNumberFormat(locales, style).format(value)\n      });\n      continue;\n    }\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isTagElement)(el)) {\n      var children = el.children,\n          value_1 = el.value;\n      var formatFn = values[value_1];\n\n      if (!isFormatXMLElementFn(formatFn)) {\n        throw new _error__WEBPACK_IMPORTED_MODULE_1__.InvalidValueTypeError(value_1, 'function', originalMessage);\n      }\n\n      var parts = formatToParts(children, locales, formatters, formats, values);\n      var chunks = formatFn.apply(void 0, parts.map(function (p) {\n        return p.value;\n      }));\n\n      if (!Array.isArray(chunks)) {\n        chunks = [chunks];\n      }\n\n      result.push.apply(result, chunks.map(function (c) {\n        return {\n          type: typeof c === 'string' ? 0\n          /* literal */\n          : 1\n          /* object */\n          ,\n          value: c\n        };\n      }));\n    }\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isSelectElement)(el)) {\n      var opt = el.options[value] || el.options.other;\n\n      if (!opt) {\n        throw new _error__WEBPACK_IMPORTED_MODULE_1__.InvalidValueError(el.value, value, Object.keys(el.options), originalMessage);\n      }\n\n      result.push.apply(result, formatToParts(opt.value, locales, formatters, formats, values));\n      continue;\n    }\n\n    if ((0,intl_messageformat_parser__WEBPACK_IMPORTED_MODULE_0__.isPluralElement)(el)) {\n      var opt = el.options[\"=\" + value];\n\n      if (!opt) {\n        if (!Intl.PluralRules) {\n          throw new _error__WEBPACK_IMPORTED_MODULE_1__.FormatError(\"Intl.PluralRules is not available in this environment.\\nTry polyfilling it using \\\"@formatjs/intl-pluralrules\\\"\\n\", \"MISSING_INTL_API\"\n          /* MISSING_INTL_API */\n          , originalMessage);\n        }\n\n        var rule = formatters.getPluralRules(locales, {\n          type: el.pluralType\n        }).select(value - (el.offset || 0));\n        opt = el.options[rule] || el.options.other;\n      }\n\n      if (!opt) {\n        throw new _error__WEBPACK_IMPORTED_MODULE_1__.InvalidValueError(el.value, value, Object.keys(el.options), originalMessage);\n      }\n\n      result.push.apply(result, formatToParts(opt.value, locales, formatters, formats, values, value - (el.offset || 0)));\n      continue;\n    }\n  }\n\n  return mergeLiteral(result);\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat/lib/formatters.js\n");

/***/ }),

/***/ "./node_modules/intl-messageformat/lib/index.js":
/*!******************************************************!*\
  !*** ./node_modules/intl-messageformat/lib/index.js ***!
  \******************************************************/
/*! namespace exports */
/*! export ErrorCode [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/error.js .ErrorCode */
/*! export FormatError [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/error.js .FormatError */
/*! export IntlMessageFormat [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/core.js .IntlMessageFormat */
/*! export InvalidValueError [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/error.js .InvalidValueError */
/*! export InvalidValueTypeError [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/error.js .InvalidValueTypeError */
/*! export MissingValueError [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/error.js .MissingValueError */
/*! export PART_TYPE [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/formatters.js .PART_TYPE */
/*! export createDefaultFormatters [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/core.js .createDefaultFormatters */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! export formatToParts [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/intl-messageformat/lib/formatters.js .formatToParts */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"PART_TYPE\": () => /* reexport safe */ _formatters__WEBPACK_IMPORTED_MODULE_0__.PART_TYPE,\n/* harmony export */   \"formatToParts\": () => /* reexport safe */ _formatters__WEBPACK_IMPORTED_MODULE_0__.formatToParts,\n/* harmony export */   \"IntlMessageFormat\": () => /* reexport safe */ _core__WEBPACK_IMPORTED_MODULE_1__.IntlMessageFormat,\n/* harmony export */   \"createDefaultFormatters\": () => /* reexport safe */ _core__WEBPACK_IMPORTED_MODULE_1__.createDefaultFormatters,\n/* harmony export */   \"ErrorCode\": () => /* reexport safe */ _error__WEBPACK_IMPORTED_MODULE_2__.ErrorCode,\n/* harmony export */   \"FormatError\": () => /* reexport safe */ _error__WEBPACK_IMPORTED_MODULE_2__.FormatError,\n/* harmony export */   \"InvalidValueError\": () => /* reexport safe */ _error__WEBPACK_IMPORTED_MODULE_2__.InvalidValueError,\n/* harmony export */   \"InvalidValueTypeError\": () => /* reexport safe */ _error__WEBPACK_IMPORTED_MODULE_2__.InvalidValueTypeError,\n/* harmony export */   \"MissingValueError\": () => /* reexport safe */ _error__WEBPACK_IMPORTED_MODULE_2__.MissingValueError,\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./core */ \"./node_modules/intl-messageformat/lib/core.js\");\n/* harmony import */ var _formatters__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./formatters */ \"./node_modules/intl-messageformat/lib/formatters.js\");\n/* harmony import */ var _error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./error */ \"./node_modules/intl-messageformat/lib/error.js\");\n/*\nCopyright (c) 2014, Yahoo! Inc. All rights reserved.\nCopyrights licensed under the New BSD License.\nSee the accompanying LICENSE file for terms.\n*/\n\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_core__WEBPACK_IMPORTED_MODULE_1__.default);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvaW50bC1tZXNzYWdlZm9ybWF0L2xpYi9pbmRleC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4uL3NyYy9pbmRleC50cz82ZjM3Il0sInNvdXJjZXNDb250ZW50IjpbIi8qXG5Db3B5cmlnaHQgKGMpIDIwMTQsIFlhaG9vISBJbmMuIEFsbCByaWdodHMgcmVzZXJ2ZWQuXG5Db3B5cmlnaHRzIGxpY2Vuc2VkIHVuZGVyIHRoZSBOZXcgQlNEIExpY2Vuc2UuXG5TZWUgdGhlIGFjY29tcGFueWluZyBMSUNFTlNFIGZpbGUgZm9yIHRlcm1zLlxuKi9cbmltcG9ydCBJbnRsTWVzc2FnZUZvcm1hdCBmcm9tICcuL2NvcmUnO1xuZXhwb3J0ICogZnJvbSAnLi9mb3JtYXR0ZXJzJztcbmV4cG9ydCAqIGZyb20gJy4vY29yZSc7XG5leHBvcnQgKiBmcm9tICcuL2Vycm9yJztcbmV4cG9ydCBkZWZhdWx0IEludGxNZXNzYWdlRm9ybWF0O1xuLy8jIHNvdXJjZU1hcHBpbmdVUkw9aW5kZXguanMubWFwIl0sIm1hcHBpbmdzIjoiOzs7Ozs7Ozs7Ozs7Ozs7O0FBQUE7Ozs7O0FBTUE7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/intl-messageformat/lib/index.js\n");

/***/ }),

/***/ "./node_modules/lit-element/lib/css-tag.js":
/*!*************************************************!*\
  !*** ./node_modules/lit-element/lib/css-tag.js ***!
  \*************************************************/
/*! namespace exports */
/*! export CSSResult [provided] [no usage info] [missing usage info prevents renaming] */
/*! export css [provided] [no usage info] [missing usage info prevents renaming] */
/*! export supportsAdoptingStyleSheets [provided] [no usage info] [missing usage info prevents renaming] */
/*! export unsafeCSS [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"supportsAdoptingStyleSheets\": () => /* binding */ supportsAdoptingStyleSheets,\n/* harmony export */   \"CSSResult\": () => /* binding */ CSSResult,\n/* harmony export */   \"unsafeCSS\": () => /* binding */ unsafeCSS,\n/* harmony export */   \"css\": () => /* binding */ css\n/* harmony export */ });\n/**\n@license\nCopyright (c) 2019 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at\nhttp://polymer.github.io/LICENSE.txt The complete set of authors may be found at\nhttp://polymer.github.io/AUTHORS.txt The complete set of contributors may be\nfound at http://polymer.github.io/CONTRIBUTORS.txt Code distributed by Google as\npart of the polymer project is also subject to an additional IP rights grant\nfound at http://polymer.github.io/PATENTS.txt\n*/\n\n/**\n * Whether the current browser supports `adoptedStyleSheets`.\n */\nconst supportsAdoptingStyleSheets = window.ShadowRoot && (window.ShadyCSS === undefined || window.ShadyCSS.nativeShadow) && 'adoptedStyleSheets' in Document.prototype && 'replace' in CSSStyleSheet.prototype;\nconst constructionToken = Symbol();\nclass CSSResult {\n  constructor(cssText, safeToken) {\n    if (safeToken !== constructionToken) {\n      throw new Error('CSSResult is not constructable. Use `unsafeCSS` or `css` instead.');\n    }\n\n    this.cssText = cssText;\n  } // Note, this is a getter so that it's lazy. In practice, this means\n  // stylesheets are not created until the first element instance is made.\n\n\n  get styleSheet() {\n    if (this._styleSheet === undefined) {\n      // Note, if `supportsAdoptingStyleSheets` is true then we assume\n      // CSSStyleSheet is constructable.\n      if (supportsAdoptingStyleSheets) {\n        this._styleSheet = new CSSStyleSheet();\n\n        this._styleSheet.replaceSync(this.cssText);\n      } else {\n        this._styleSheet = null;\n      }\n    }\n\n    return this._styleSheet;\n  }\n\n  toString() {\n    return this.cssText;\n  }\n\n}\n/**\n * Wrap a value for interpolation in a [[`css`]] tagged template literal.\n *\n * This is unsafe because untrusted CSS text can be used to phone home\n * or exfiltrate data to an attacker controlled site. Take care to only use\n * this with trusted input.\n */\n\nconst unsafeCSS = value => {\n  return new CSSResult(String(value), constructionToken);\n};\n\nconst textFromCSSResult = value => {\n  if (value instanceof CSSResult) {\n    return value.cssText;\n  } else if (typeof value === 'number') {\n    return value;\n  } else {\n    throw new Error(`Value passed to 'css' function must be a 'css' function result: ${value}. Use 'unsafeCSS' to pass non-literal values, but\n            take care to ensure page security.`);\n  }\n};\n/**\n * Template tag which which can be used with LitElement's [[LitElement.styles |\n * `styles`]] property to set element styles. For security reasons, only literal\n * string values may be used. To incorporate non-literal values [[`unsafeCSS`]]\n * may be used inside a template string part.\n */\n\n\nconst css = (strings, ...values) => {\n  const cssText = values.reduce((acc, v, idx) => acc + textFromCSSResult(v) + strings[idx + 1], strings[0]);\n  return new CSSResult(cssText, constructionToken);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-element/lib/css-tag.js\n");

/***/ }),

/***/ "./node_modules/lit-element/lib/decorators.js":
/*!****************************************************!*\
  !*** ./node_modules/lit-element/lib/decorators.js ***!
  \****************************************************/
/*! namespace exports */
/*! export customElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export eventOptions [provided] [no usage info] [missing usage info prevents renaming] */
/*! export internalProperty [provided] [no usage info] [missing usage info prevents renaming] */
/*! export property [provided] [no usage info] [missing usage info prevents renaming] */
/*! export query [provided] [no usage info] [missing usage info prevents renaming] */
/*! export queryAll [provided] [no usage info] [missing usage info prevents renaming] */
/*! export queryAssignedNodes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export queryAsync [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"customElement\": () => /* binding */ customElement,\n/* harmony export */   \"property\": () => /* binding */ property,\n/* harmony export */   \"internalProperty\": () => /* binding */ internalProperty,\n/* harmony export */   \"query\": () => /* binding */ query,\n/* harmony export */   \"queryAsync\": () => /* binding */ queryAsync,\n/* harmony export */   \"queryAll\": () => /* binding */ queryAll,\n/* harmony export */   \"eventOptions\": () => /* binding */ eventOptions,\n/* harmony export */   \"queryAssignedNodes\": () => /* binding */ queryAssignedNodes\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\nconst legacyCustomElement = (tagName, clazz) => {\n  window.customElements.define(tagName, clazz); // Cast as any because TS doesn't recognize the return type as being a\n  // subtype of the decorated class when clazz is typed as\n  // `Constructor<HTMLElement>` for some reason.\n  // `Constructor<HTMLElement>` is helpful to make sure the decorator is\n  // applied to elements however.\n  // tslint:disable-next-line:no-any\n\n  return clazz;\n};\n\nconst standardCustomElement = (tagName, descriptor) => {\n  const {\n    kind,\n    elements\n  } = descriptor;\n  return {\n    kind,\n    elements,\n\n    // This callback is called once the class is otherwise fully defined\n    finisher(clazz) {\n      window.customElements.define(tagName, clazz);\n    }\n\n  };\n};\n/**\n * Class decorator factory that defines the decorated class as a custom element.\n *\n * ```\n * @customElement('my-element')\n * class MyElement {\n *   render() {\n *     return html``;\n *   }\n * }\n * ```\n * @category Decorator\n * @param tagName The name of the custom element to define.\n */\n\n\nconst customElement = tagName => classOrDescriptor => typeof classOrDescriptor === 'function' ? legacyCustomElement(tagName, classOrDescriptor) : standardCustomElement(tagName, classOrDescriptor);\n\nconst standardProperty = (options, element) => {\n  // When decorating an accessor, pass it through and add property metadata.\n  // Note, the `hasOwnProperty` check in `createProperty` ensures we don't\n  // stomp over the user's accessor.\n  if (element.kind === 'method' && element.descriptor && !('value' in element.descriptor)) {\n    return Object.assign(Object.assign({}, element), {\n      finisher(clazz) {\n        clazz.createProperty(element.key, options);\n      }\n\n    });\n  } else {\n    // createProperty() takes care of defining the property, but we still\n    // must return some kind of descriptor, so return a descriptor for an\n    // unused prototype field. The finisher calls createProperty().\n    return {\n      kind: 'field',\n      key: Symbol(),\n      placement: 'own',\n      descriptor: {},\n\n      // When @babel/plugin-proposal-decorators implements initializers,\n      // do this instead of the initializer below. See:\n      // https://github.com/babel/babel/issues/9260 extras: [\n      //   {\n      //     kind: 'initializer',\n      //     placement: 'own',\n      //     initializer: descriptor.initializer,\n      //   }\n      // ],\n      initializer() {\n        if (typeof element.initializer === 'function') {\n          this[element.key] = element.initializer.call(this);\n        }\n      },\n\n      finisher(clazz) {\n        clazz.createProperty(element.key, options);\n      }\n\n    };\n  }\n};\n\nconst legacyProperty = (options, proto, name) => {\n  proto.constructor.createProperty(name, options);\n};\n/**\n * A property decorator which creates a LitElement property which reflects a\n * corresponding attribute value. A [[`PropertyDeclaration`]] may optionally be\n * supplied to configure property features.\n *\n * This decorator should only be used for public fields. Private or protected\n * fields should use the [[`internalProperty`]] decorator.\n *\n * @example\n * ```ts\n * class MyElement {\n *   @property({ type: Boolean })\n *   clicked = false;\n * }\n * ```\n * @category Decorator\n * @ExportDecoratedItems\n */\n\n\nfunction property(options) {\n  // tslint:disable-next-line:no-any decorator\n  return (protoOrDescriptor, name) => name !== undefined ? legacyProperty(options, protoOrDescriptor, name) : standardProperty(options, protoOrDescriptor);\n}\n/**\n * Declares a private or protected property that still triggers updates to the\n * element when it changes.\n *\n * Properties declared this way must not be used from HTML or HTML templating\n * systems, they're solely for properties internal to the element. These\n * properties may be renamed by optimization tools like closure compiler.\n * @category Decorator\n */\n\nfunction internalProperty(options) {\n  return property({\n    attribute: false,\n    hasChanged: options === null || options === void 0 ? void 0 : options.hasChanged\n  });\n}\n/**\n * A property decorator that converts a class property into a getter that\n * executes a querySelector on the element's renderRoot.\n *\n * @param selector A DOMString containing one or more selectors to match.\n * @param cache An optional boolean which when true performs the DOM query only\n * once and caches the result.\n *\n * See: https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector\n *\n * @example\n *\n * ```ts\n * class MyElement {\n *   @query('#first')\n *   first;\n *\n *   render() {\n *     return html`\n *       <div id=\"first\"></div>\n *       <div id=\"second\"></div>\n *     `;\n *   }\n * }\n * ```\n * @category Decorator\n */\n\nfunction query(selector, cache) {\n  return (protoOrDescriptor, // tslint:disable-next-line:no-any decorator\n  name) => {\n    const descriptor = {\n      get() {\n        return this.renderRoot.querySelector(selector);\n      },\n\n      enumerable: true,\n      configurable: true\n    };\n\n    if (cache) {\n      const key = typeof name === 'symbol' ? Symbol() : `__${name}`;\n\n      descriptor.get = function () {\n        if (this[key] === undefined) {\n          this[key] = this.renderRoot.querySelector(selector);\n        }\n\n        return this[key];\n      };\n    }\n\n    return name !== undefined ? legacyQuery(descriptor, protoOrDescriptor, name) : standardQuery(descriptor, protoOrDescriptor);\n  };\n} // Note, in the future, we may extend this decorator to support the use case\n// where the queried element may need to do work to become ready to interact\n// with (e.g. load some implementation code). If so, we might elect to\n// add a second argument defining a function that can be run to make the\n// queried element loaded/updated/ready.\n\n/**\n * A property decorator that converts a class property into a getter that\n * returns a promise that resolves to the result of a querySelector on the\n * element's renderRoot done after the element's `updateComplete` promise\n * resolves. When the queried property may change with element state, this\n * decorator can be used instead of requiring users to await the\n * `updateComplete` before accessing the property.\n *\n * @param selector A DOMString containing one or more selectors to match.\n *\n * See: https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector\n *\n * @example\n * ```ts\n * class MyElement {\n *   @queryAsync('#first')\n *   first;\n *\n *   render() {\n *     return html`\n *       <div id=\"first\"></div>\n *       <div id=\"second\"></div>\n *     `;\n *   }\n * }\n *\n * // external usage\n * async doSomethingWithFirst() {\n *  (await aMyElement.first).doSomething();\n * }\n * ```\n * @category Decorator\n */\n\nfunction queryAsync(selector) {\n  return (protoOrDescriptor, // tslint:disable-next-line:no-any decorator\n  name) => {\n    const descriptor = {\n      async get() {\n        await this.updateComplete;\n        return this.renderRoot.querySelector(selector);\n      },\n\n      enumerable: true,\n      configurable: true\n    };\n    return name !== undefined ? legacyQuery(descriptor, protoOrDescriptor, name) : standardQuery(descriptor, protoOrDescriptor);\n  };\n}\n/**\n * A property decorator that converts a class property into a getter\n * that executes a querySelectorAll on the element's renderRoot.\n *\n * @param selector A DOMString containing one or more selectors to match.\n *\n * See:\n * https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelectorAll\n *\n * @example\n * ```ts\n * class MyElement {\n *   @queryAll('div')\n *   divs;\n *\n *   render() {\n *     return html`\n *       <div id=\"first\"></div>\n *       <div id=\"second\"></div>\n *     `;\n *   }\n * }\n * ```\n * @category Decorator\n */\n\nfunction queryAll(selector) {\n  return (protoOrDescriptor, // tslint:disable-next-line:no-any decorator\n  name) => {\n    const descriptor = {\n      get() {\n        return this.renderRoot.querySelectorAll(selector);\n      },\n\n      enumerable: true,\n      configurable: true\n    };\n    return name !== undefined ? legacyQuery(descriptor, protoOrDescriptor, name) : standardQuery(descriptor, protoOrDescriptor);\n  };\n}\n\nconst legacyQuery = (descriptor, proto, name) => {\n  Object.defineProperty(proto, name, descriptor);\n};\n\nconst standardQuery = (descriptor, element) => ({\n  kind: 'method',\n  placement: 'prototype',\n  key: element.key,\n  descriptor\n});\n\nconst standardEventOptions = (options, element) => {\n  return Object.assign(Object.assign({}, element), {\n    finisher(clazz) {\n      Object.assign(clazz.prototype[element.key], options);\n    }\n\n  });\n};\n\nconst legacyEventOptions = // tslint:disable-next-line:no-any legacy decorator\n(options, proto, name) => {\n  Object.assign(proto[name], options);\n};\n/**\n * Adds event listener options to a method used as an event listener in a\n * lit-html template.\n *\n * @param options An object that specifies event listener options as accepted by\n * `EventTarget#addEventListener` and `EventTarget#removeEventListener`.\n *\n * Current browsers support the `capture`, `passive`, and `once` options. See:\n * https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener#Parameters\n *\n * @example\n * ```ts\n * class MyElement {\n *   clicked = false;\n *\n *   render() {\n *     return html`\n *       <div @click=${this._onClick}`>\n *         <button></button>\n *       </div>\n *     `;\n *   }\n *\n *   @eventOptions({capture: true})\n *   _onClick(e) {\n *     this.clicked = true;\n *   }\n * }\n * ```\n * @category Decorator\n */\n\n\nfunction eventOptions(options) {\n  // Return value typed as any to prevent TypeScript from complaining that\n  // standard decorator function signature does not match TypeScript decorator\n  // signature\n  // TODO(kschaaf): unclear why it was only failing on this decorator and not\n  // the others\n  return (protoOrDescriptor, name) => name !== undefined ? legacyEventOptions(options, protoOrDescriptor, name) : standardEventOptions(options, protoOrDescriptor);\n} // x-browser support for matches\n// tslint:disable-next-line:no-any\n\nconst ElementProto = Element.prototype;\nconst legacyMatches = ElementProto.msMatchesSelector || ElementProto.webkitMatchesSelector;\n/**\n * A property decorator that converts a class property into a getter that\n * returns the `assignedNodes` of the given named `slot`. Note, the type of\n * this property should be annotated as `NodeListOf<HTMLElement>`.\n *\n * @param slotName A string name of the slot.\n * @param flatten A boolean which when true flattens the assigned nodes,\n * meaning any assigned nodes that are slot elements are replaced with their\n * assigned nodes.\n * @param selector A string which filters the results to elements that match\n * the given css selector.\n *\n * * @example\n * ```ts\n * class MyElement {\n *   @queryAssignedNodes('list', true, '.item')\n *   listItems;\n *\n *   render() {\n *     return html`\n *       <slot name=\"list\"></slot>\n *     `;\n *   }\n * }\n * ```\n * @category Decorator\n */\n\nfunction queryAssignedNodes(slotName = '', flatten = false, selector = '') {\n  return (protoOrDescriptor, // tslint:disable-next-line:no-any decorator\n  name) => {\n    const descriptor = {\n      get() {\n        const slotSelector = `slot${slotName ? `[name=${slotName}]` : ':not([name])'}`;\n        const slot = this.renderRoot.querySelector(slotSelector);\n        let nodes = slot && slot.assignedNodes({\n          flatten\n        });\n\n        if (nodes && selector) {\n          nodes = nodes.filter(node => node.nodeType === Node.ELEMENT_NODE && node.matches ? node.matches(selector) : legacyMatches.call(node, selector));\n        }\n\n        return nodes;\n      },\n\n      enumerable: true,\n      configurable: true\n    };\n    return name !== undefined ? legacyQuery(descriptor, protoOrDescriptor, name) : standardQuery(descriptor, protoOrDescriptor);\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-element/lib/decorators.js\n");

/***/ }),

/***/ "./node_modules/lit-element/lib/updating-element.js":
/*!**********************************************************!*\
  !*** ./node_modules/lit-element/lib/updating-element.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export UpdatingElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export defaultConverter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export notEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"defaultConverter\": () => /* binding */ defaultConverter,\n/* harmony export */   \"notEqual\": () => /* binding */ notEqual,\n/* harmony export */   \"UpdatingElement\": () => /* binding */ UpdatingElement\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\nvar _a;\n/**\n * Use this module if you want to create your own base class extending\n * [[UpdatingElement]].\n * @packageDocumentation\n */\n\n/*\n * When using Closure Compiler, JSCompiler_renameProperty(property, object) is\n * replaced at compile time by the munged name for object[property]. We cannot\n * alias this function, so we have to use a small shim that has the same\n * behavior when not compiling.\n */\n\n\nwindow.JSCompiler_renameProperty = (prop, _obj) => prop;\n\nconst defaultConverter = {\n  toAttribute(value, type) {\n    switch (type) {\n      case Boolean:\n        return value ? '' : null;\n\n      case Object:\n      case Array:\n        // if the value is `null` or `undefined` pass this through\n        // to allow removing/no change behavior.\n        return value == null ? value : JSON.stringify(value);\n    }\n\n    return value;\n  },\n\n  fromAttribute(value, type) {\n    switch (type) {\n      case Boolean:\n        return value !== null;\n\n      case Number:\n        return value === null ? null : Number(value);\n\n      case Object:\n      case Array:\n        return JSON.parse(value);\n    }\n\n    return value;\n  }\n\n};\n/**\n * Change function that returns true if `value` is different from `oldValue`.\n * This method is used as the default for a property's `hasChanged` function.\n */\n\nconst notEqual = (value, old) => {\n  // This ensures (old==NaN, value==NaN) always returns false\n  return old !== value && (old === old || value === value);\n};\nconst defaultPropertyDeclaration = {\n  attribute: true,\n  type: String,\n  converter: defaultConverter,\n  reflect: false,\n  hasChanged: notEqual\n};\nconst STATE_HAS_UPDATED = 1;\nconst STATE_UPDATE_REQUESTED = 1 << 2;\nconst STATE_IS_REFLECTING_TO_ATTRIBUTE = 1 << 3;\nconst STATE_IS_REFLECTING_TO_PROPERTY = 1 << 4;\n/**\n * The Closure JS Compiler doesn't currently have good support for static\n * property semantics where \"this\" is dynamic (e.g.\n * https://github.com/google/closure-compiler/issues/3177 and others) so we use\n * this hack to bypass any rewriting by the compiler.\n */\n\nconst finalized = 'finalized';\n/**\n * Base element class which manages element properties and attributes. When\n * properties change, the `update` method is asynchronously called. This method\n * should be supplied by subclassers to render updates as desired.\n * @noInheritDoc\n */\n\nclass UpdatingElement extends HTMLElement {\n  constructor() {\n    super();\n    this.initialize();\n  }\n  /**\n   * Returns a list of attributes corresponding to the registered properties.\n   * @nocollapse\n   */\n\n\n  static get observedAttributes() {\n    // note: piggy backing on this to ensure we're finalized.\n    this.finalize();\n    const attributes = []; // Use forEach so this works even if for/of loops are compiled to for loops\n    // expecting arrays\n\n    this._classProperties.forEach((v, p) => {\n      const attr = this._attributeNameForProperty(p, v);\n\n      if (attr !== undefined) {\n        this._attributeToPropertyMap.set(attr, p);\n\n        attributes.push(attr);\n      }\n    });\n\n    return attributes;\n  }\n  /**\n   * Ensures the private `_classProperties` property metadata is created.\n   * In addition to `finalize` this is also called in `createProperty` to\n   * ensure the `@property` decorator can add property metadata.\n   */\n\n  /** @nocollapse */\n\n\n  static _ensureClassProperties() {\n    // ensure private storage for property declarations.\n    if (!this.hasOwnProperty(JSCompiler_renameProperty('_classProperties', this))) {\n      this._classProperties = new Map(); // NOTE: Workaround IE11 not supporting Map constructor argument.\n\n      const superProperties = Object.getPrototypeOf(this)._classProperties;\n\n      if (superProperties !== undefined) {\n        superProperties.forEach((v, k) => this._classProperties.set(k, v));\n      }\n    }\n  }\n  /**\n   * Creates a property accessor on the element prototype if one does not exist\n   * and stores a PropertyDeclaration for the property with the given options.\n   * The property setter calls the property's `hasChanged` property option\n   * or uses a strict identity check to determine whether or not to request\n   * an update.\n   *\n   * This method may be overridden to customize properties; however,\n   * when doing so, it's important to call `super.createProperty` to ensure\n   * the property is setup correctly. This method calls\n   * `getPropertyDescriptor` internally to get a descriptor to install.\n   * To customize what properties do when they are get or set, override\n   * `getPropertyDescriptor`. To customize the options for a property,\n   * implement `createProperty` like this:\n   *\n   * static createProperty(name, options) {\n   *   options = Object.assign(options, {myOption: true});\n   *   super.createProperty(name, options);\n   * }\n   *\n   * @nocollapse\n   */\n\n\n  static createProperty(name, options = defaultPropertyDeclaration) {\n    // Note, since this can be called by the `@property` decorator which\n    // is called before `finalize`, we ensure storage exists for property\n    // metadata.\n    this._ensureClassProperties();\n\n    this._classProperties.set(name, options); // Do not generate an accessor if the prototype already has one, since\n    // it would be lost otherwise and that would never be the user's intention;\n    // Instead, we expect users to call `requestUpdate` themselves from\n    // user-defined accessors. Note that if the super has an accessor we will\n    // still overwrite it\n\n\n    if (options.noAccessor || this.prototype.hasOwnProperty(name)) {\n      return;\n    }\n\n    const key = typeof name === 'symbol' ? Symbol() : `__${name}`;\n    const descriptor = this.getPropertyDescriptor(name, key, options);\n\n    if (descriptor !== undefined) {\n      Object.defineProperty(this.prototype, name, descriptor);\n    }\n  }\n  /**\n   * Returns a property descriptor to be defined on the given named property.\n   * If no descriptor is returned, the property will not become an accessor.\n   * For example,\n   *\n   *   class MyElement extends LitElement {\n   *     static getPropertyDescriptor(name, key, options) {\n   *       const defaultDescriptor =\n   *           super.getPropertyDescriptor(name, key, options);\n   *       const setter = defaultDescriptor.set;\n   *       return {\n   *         get: defaultDescriptor.get,\n   *         set(value) {\n   *           setter.call(this, value);\n   *           // custom action.\n   *         },\n   *         configurable: true,\n   *         enumerable: true\n   *       }\n   *     }\n   *   }\n   *\n   * @nocollapse\n   */\n\n\n  static getPropertyDescriptor(name, key, options) {\n    return {\n      // tslint:disable-next-line:no-any no symbol in index\n      get() {\n        return this[key];\n      },\n\n      set(value) {\n        const oldValue = this[name];\n        this[key] = value;\n        this.requestUpdateInternal(name, oldValue, options);\n      },\n\n      configurable: true,\n      enumerable: true\n    };\n  }\n  /**\n   * Returns the property options associated with the given property.\n   * These options are defined with a PropertyDeclaration via the `properties`\n   * object or the `@property` decorator and are registered in\n   * `createProperty(...)`.\n   *\n   * Note, this method should be considered \"final\" and not overridden. To\n   * customize the options for a given property, override `createProperty`.\n   *\n   * @nocollapse\n   * @final\n   */\n\n\n  static getPropertyOptions(name) {\n    return this._classProperties && this._classProperties.get(name) || defaultPropertyDeclaration;\n  }\n  /**\n   * Creates property accessors for registered properties and ensures\n   * any superclasses are also finalized.\n   * @nocollapse\n   */\n\n\n  static finalize() {\n    // finalize any superclasses\n    const superCtor = Object.getPrototypeOf(this);\n\n    if (!superCtor.hasOwnProperty(finalized)) {\n      superCtor.finalize();\n    }\n\n    this[finalized] = true;\n\n    this._ensureClassProperties(); // initialize Map populated in observedAttributes\n\n\n    this._attributeToPropertyMap = new Map(); // make any properties\n    // Note, only process \"own\" properties since this element will inherit\n    // any properties defined on the superClass, and finalization ensures\n    // the entire prototype chain is finalized.\n\n    if (this.hasOwnProperty(JSCompiler_renameProperty('properties', this))) {\n      const props = this.properties; // support symbols in properties (IE11 does not support this)\n\n      const propKeys = [...Object.getOwnPropertyNames(props), ...(typeof Object.getOwnPropertySymbols === 'function' ? Object.getOwnPropertySymbols(props) : [])]; // This for/of is ok because propKeys is an array\n\n      for (const p of propKeys) {\n        // note, use of `any` is due to TypeSript lack of support for symbol in\n        // index types\n        // tslint:disable-next-line:no-any no symbol in index\n        this.createProperty(p, props[p]);\n      }\n    }\n  }\n  /**\n   * Returns the property name for the given attribute `name`.\n   * @nocollapse\n   */\n\n\n  static _attributeNameForProperty(name, options) {\n    const attribute = options.attribute;\n    return attribute === false ? undefined : typeof attribute === 'string' ? attribute : typeof name === 'string' ? name.toLowerCase() : undefined;\n  }\n  /**\n   * Returns true if a property should request an update.\n   * Called when a property value is set and uses the `hasChanged`\n   * option for the property if present or a strict identity check.\n   * @nocollapse\n   */\n\n\n  static _valueHasChanged(value, old, hasChanged = notEqual) {\n    return hasChanged(value, old);\n  }\n  /**\n   * Returns the property value for the given attribute value.\n   * Called via the `attributeChangedCallback` and uses the property's\n   * `converter` or `converter.fromAttribute` property option.\n   * @nocollapse\n   */\n\n\n  static _propertyValueFromAttribute(value, options) {\n    const type = options.type;\n    const converter = options.converter || defaultConverter;\n    const fromAttribute = typeof converter === 'function' ? converter : converter.fromAttribute;\n    return fromAttribute ? fromAttribute(value, type) : value;\n  }\n  /**\n   * Returns the attribute value for the given property value. If this\n   * returns undefined, the property will *not* be reflected to an attribute.\n   * If this returns null, the attribute will be removed, otherwise the\n   * attribute will be set to the value.\n   * This uses the property's `reflect` and `type.toAttribute` property options.\n   * @nocollapse\n   */\n\n\n  static _propertyValueToAttribute(value, options) {\n    if (options.reflect === undefined) {\n      return;\n    }\n\n    const type = options.type;\n    const converter = options.converter;\n    const toAttribute = converter && converter.toAttribute || defaultConverter.toAttribute;\n    return toAttribute(value, type);\n  }\n  /**\n   * Performs element initialization. By default captures any pre-set values for\n   * registered properties.\n   */\n\n\n  initialize() {\n    this._updateState = 0;\n    this._updatePromise = new Promise(res => this._enableUpdatingResolver = res);\n    this._changedProperties = new Map();\n\n    this._saveInstanceProperties(); // ensures first update will be caught by an early access of\n    // `updateComplete`\n\n\n    this.requestUpdateInternal();\n  }\n  /**\n   * Fixes any properties set on the instance before upgrade time.\n   * Otherwise these would shadow the accessor and break these properties.\n   * The properties are stored in a Map which is played back after the\n   * constructor runs. Note, on very old versions of Safari (<=9) or Chrome\n   * (<=41), properties created for native platform properties like (`id` or\n   * `name`) may not have default values set in the element constructor. On\n   * these browsers native properties appear on instances and therefore their\n   * default value will overwrite any element default (e.g. if the element sets\n   * this.id = 'id' in the constructor, the 'id' will become '' since this is\n   * the native platform default).\n   */\n\n\n  _saveInstanceProperties() {\n    // Use forEach so this works even if for/of loops are compiled to for loops\n    // expecting arrays\n    this.constructor._classProperties.forEach((_v, p) => {\n      if (this.hasOwnProperty(p)) {\n        const value = this[p];\n        delete this[p];\n\n        if (!this._instanceProperties) {\n          this._instanceProperties = new Map();\n        }\n\n        this._instanceProperties.set(p, value);\n      }\n    });\n  }\n  /**\n   * Applies previously saved instance properties.\n   */\n\n\n  _applyInstanceProperties() {\n    // Use forEach so this works even if for/of loops are compiled to for loops\n    // expecting arrays\n    // tslint:disable-next-line:no-any\n    this._instanceProperties.forEach((v, p) => this[p] = v);\n\n    this._instanceProperties = undefined;\n  }\n\n  connectedCallback() {\n    // Ensure first connection completes an update. Updates cannot complete\n    // before connection.\n    this.enableUpdating();\n  }\n\n  enableUpdating() {\n    if (this._enableUpdatingResolver !== undefined) {\n      this._enableUpdatingResolver();\n\n      this._enableUpdatingResolver = undefined;\n    }\n  }\n  /**\n   * Allows for `super.disconnectedCallback()` in extensions while\n   * reserving the possibility of making non-breaking feature additions\n   * when disconnecting at some point in the future.\n   */\n\n\n  disconnectedCallback() {}\n  /**\n   * Synchronizes property values when attributes change.\n   */\n\n\n  attributeChangedCallback(name, old, value) {\n    if (old !== value) {\n      this._attributeToProperty(name, value);\n    }\n  }\n\n  _propertyToAttribute(name, value, options = defaultPropertyDeclaration) {\n    const ctor = this.constructor;\n\n    const attr = ctor._attributeNameForProperty(name, options);\n\n    if (attr !== undefined) {\n      const attrValue = ctor._propertyValueToAttribute(value, options); // an undefined value does not change the attribute.\n\n\n      if (attrValue === undefined) {\n        return;\n      } // Track if the property is being reflected to avoid\n      // setting the property again via `attributeChangedCallback`. Note:\n      // 1. this takes advantage of the fact that the callback is synchronous.\n      // 2. will behave incorrectly if multiple attributes are in the reaction\n      // stack at time of calling. However, since we process attributes\n      // in `update` this should not be possible (or an extreme corner case\n      // that we'd like to discover).\n      // mark state reflecting\n\n\n      this._updateState = this._updateState | STATE_IS_REFLECTING_TO_ATTRIBUTE;\n\n      if (attrValue == null) {\n        this.removeAttribute(attr);\n      } else {\n        this.setAttribute(attr, attrValue);\n      } // mark state not reflecting\n\n\n      this._updateState = this._updateState & ~STATE_IS_REFLECTING_TO_ATTRIBUTE;\n    }\n  }\n\n  _attributeToProperty(name, value) {\n    // Use tracking info to avoid deserializing attribute value if it was\n    // just set from a property setter.\n    if (this._updateState & STATE_IS_REFLECTING_TO_ATTRIBUTE) {\n      return;\n    }\n\n    const ctor = this.constructor; // Note, hint this as an `AttributeMap` so closure clearly understands\n    // the type; it has issues with tracking types through statics\n    // tslint:disable-next-line:no-unnecessary-type-assertion\n\n    const propName = ctor._attributeToPropertyMap.get(name);\n\n    if (propName !== undefined) {\n      const options = ctor.getPropertyOptions(propName); // mark state reflecting\n\n      this._updateState = this._updateState | STATE_IS_REFLECTING_TO_PROPERTY;\n      this[propName] = // tslint:disable-next-line:no-any\n      ctor._propertyValueFromAttribute(value, options); // mark state not reflecting\n\n      this._updateState = this._updateState & ~STATE_IS_REFLECTING_TO_PROPERTY;\n    }\n  }\n  /**\n   * This protected version of `requestUpdate` does not access or return the\n   * `updateComplete` promise. This promise can be overridden and is therefore\n   * not free to access.\n   */\n\n\n  requestUpdateInternal(name, oldValue, options) {\n    let shouldRequestUpdate = true; // If we have a property key, perform property update steps.\n\n    if (name !== undefined) {\n      const ctor = this.constructor;\n      options = options || ctor.getPropertyOptions(name);\n\n      if (ctor._valueHasChanged(this[name], oldValue, options.hasChanged)) {\n        if (!this._changedProperties.has(name)) {\n          this._changedProperties.set(name, oldValue);\n        } // Add to reflecting properties set.\n        // Note, it's important that every change has a chance to add the\n        // property to `_reflectingProperties`. This ensures setting\n        // attribute + property reflects correctly.\n\n\n        if (options.reflect === true && !(this._updateState & STATE_IS_REFLECTING_TO_PROPERTY)) {\n          if (this._reflectingProperties === undefined) {\n            this._reflectingProperties = new Map();\n          }\n\n          this._reflectingProperties.set(name, options);\n        }\n      } else {\n        // Abort the request if the property should not be considered changed.\n        shouldRequestUpdate = false;\n      }\n    }\n\n    if (!this._hasRequestedUpdate && shouldRequestUpdate) {\n      this._updatePromise = this._enqueueUpdate();\n    }\n  }\n  /**\n   * Requests an update which is processed asynchronously. This should\n   * be called when an element should update based on some state not triggered\n   * by setting a property. In this case, pass no arguments. It should also be\n   * called when manually implementing a property setter. In this case, pass the\n   * property `name` and `oldValue` to ensure that any configured property\n   * options are honored. Returns the `updateComplete` Promise which is resolved\n   * when the update completes.\n   *\n   * @param name {PropertyKey} (optional) name of requesting property\n   * @param oldValue {any} (optional) old value of requesting property\n   * @returns {Promise} A Promise that is resolved when the update completes.\n   */\n\n\n  requestUpdate(name, oldValue) {\n    this.requestUpdateInternal(name, oldValue);\n    return this.updateComplete;\n  }\n  /**\n   * Sets up the element to asynchronously update.\n   */\n\n\n  async _enqueueUpdate() {\n    this._updateState = this._updateState | STATE_UPDATE_REQUESTED;\n\n    try {\n      // Ensure any previous update has resolved before updating.\n      // This `await` also ensures that property changes are batched.\n      await this._updatePromise;\n    } catch (e) {// Ignore any previous errors. We only care that the previous cycle is\n      // done. Any error should have been handled in the previous update.\n    }\n\n    const result = this.performUpdate(); // If `performUpdate` returns a Promise, we await it. This is done to\n    // enable coordinating updates with a scheduler. Note, the result is\n    // checked to avoid delaying an additional microtask unless we need to.\n\n    if (result != null) {\n      await result;\n    }\n\n    return !this._hasRequestedUpdate;\n  }\n\n  get _hasRequestedUpdate() {\n    return this._updateState & STATE_UPDATE_REQUESTED;\n  }\n\n  get hasUpdated() {\n    return this._updateState & STATE_HAS_UPDATED;\n  }\n  /**\n   * Performs an element update. Note, if an exception is thrown during the\n   * update, `firstUpdated` and `updated` will not be called.\n   *\n   * You can override this method to change the timing of updates. If this\n   * method is overridden, `super.performUpdate()` must be called.\n   *\n   * For instance, to schedule updates to occur just before the next frame:\n   *\n   * ```\n   * protected async performUpdate(): Promise<unknown> {\n   *   await new Promise((resolve) => requestAnimationFrame(() => resolve()));\n   *   super.performUpdate();\n   * }\n   * ```\n   */\n\n\n  performUpdate() {\n    // Abort any update if one is not pending when this is called.\n    // This can happen if `performUpdate` is called early to \"flush\"\n    // the update.\n    if (!this._hasRequestedUpdate) {\n      return;\n    } // Mixin instance properties once, if they exist.\n\n\n    if (this._instanceProperties) {\n      this._applyInstanceProperties();\n    }\n\n    let shouldUpdate = false;\n    const changedProperties = this._changedProperties;\n\n    try {\n      shouldUpdate = this.shouldUpdate(changedProperties);\n\n      if (shouldUpdate) {\n        this.update(changedProperties);\n      } else {\n        this._markUpdated();\n      }\n    } catch (e) {\n      // Prevent `firstUpdated` and `updated` from running when there's an\n      // update exception.\n      shouldUpdate = false; // Ensure element can accept additional updates after an exception.\n\n      this._markUpdated();\n\n      throw e;\n    }\n\n    if (shouldUpdate) {\n      if (!(this._updateState & STATE_HAS_UPDATED)) {\n        this._updateState = this._updateState | STATE_HAS_UPDATED;\n        this.firstUpdated(changedProperties);\n      }\n\n      this.updated(changedProperties);\n    }\n  }\n\n  _markUpdated() {\n    this._changedProperties = new Map();\n    this._updateState = this._updateState & ~STATE_UPDATE_REQUESTED;\n  }\n  /**\n   * Returns a Promise that resolves when the element has completed updating.\n   * The Promise value is a boolean that is `true` if the element completed the\n   * update without triggering another update. The Promise result is `false` if\n   * a property was set inside `updated()`. If the Promise is rejected, an\n   * exception was thrown during the update.\n   *\n   * To await additional asynchronous work, override the `_getUpdateComplete`\n   * method. For example, it is sometimes useful to await a rendered element\n   * before fulfilling this Promise. To do this, first await\n   * `super._getUpdateComplete()`, then any subsequent state.\n   *\n   * @returns {Promise} The Promise returns a boolean that indicates if the\n   * update resolved without triggering another update.\n   */\n\n\n  get updateComplete() {\n    return this._getUpdateComplete();\n  }\n  /**\n   * Override point for the `updateComplete` promise.\n   *\n   * It is not safe to override the `updateComplete` getter directly due to a\n   * limitation in TypeScript which means it is not possible to call a\n   * superclass getter (e.g. `super.updateComplete.then(...)`) when the target\n   * language is ES5 (https://github.com/microsoft/TypeScript/issues/338).\n   * This method should be overridden instead. For example:\n   *\n   *   class MyElement extends LitElement {\n   *     async _getUpdateComplete() {\n   *       await super._getUpdateComplete();\n   *       await this._myChild.updateComplete;\n   *     }\n   *   }\n   */\n\n\n  _getUpdateComplete() {\n    return this._updatePromise;\n  }\n  /**\n   * Controls whether or not `update` should be called when the element requests\n   * an update. By default, this method always returns `true`, but this can be\n   * customized to control when to update.\n   *\n   * @param _changedProperties Map of changed properties with old values\n   */\n\n\n  shouldUpdate(_changedProperties) {\n    return true;\n  }\n  /**\n   * Updates the element. This method reflects property values to attributes.\n   * It can be overridden to render and keep updated element DOM.\n   * Setting properties inside this method will *not* trigger\n   * another update.\n   *\n   * @param _changedProperties Map of changed properties with old values\n   */\n\n\n  update(_changedProperties) {\n    if (this._reflectingProperties !== undefined && this._reflectingProperties.size > 0) {\n      // Use forEach so this works even if for/of loops are compiled to for\n      // loops expecting arrays\n      this._reflectingProperties.forEach((v, k) => this._propertyToAttribute(k, this[k], v));\n\n      this._reflectingProperties = undefined;\n    }\n\n    this._markUpdated();\n  }\n  /**\n   * Invoked whenever the element is updated. Implement to perform\n   * post-updating tasks via DOM APIs, for example, focusing an element.\n   *\n   * Setting properties inside this method will trigger the element to update\n   * again after this update cycle completes.\n   *\n   * @param _changedProperties Map of changed properties with old values\n   */\n\n\n  updated(_changedProperties) {}\n  /**\n   * Invoked when the element is first updated. Implement to perform one time\n   * work on the element after update.\n   *\n   * Setting properties inside this method will trigger the element to update\n   * again after this update cycle completes.\n   *\n   * @param _changedProperties Map of changed properties with old values\n   */\n\n\n  firstUpdated(_changedProperties) {}\n\n}\n_a = finalized;\n/**\n * Marks class as having finished creating properties.\n */\n\nUpdatingElement[_a] = true;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-element/lib/updating-element.js\n");

/***/ }),

/***/ "./node_modules/lit-element/lit-element.js":
/*!*************************************************!*\
  !*** ./node_modules/lit-element/lit-element.js ***!
  \*************************************************/
/*! namespace exports */
/*! export CSSResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/css-tag.js .CSSResult */
/*! export LitElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export SVGTemplateResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-result.js .SVGTemplateResult */
/*! export TemplateResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-result.js .TemplateResult */
/*! export UpdatingElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/updating-element.js .UpdatingElement */
/*! export css [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/css-tag.js .css */
/*! export customElement [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .customElement */
/*! export defaultConverter [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/updating-element.js .defaultConverter */
/*! export eventOptions [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .eventOptions */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lit-html.js .html */
/*! export internalProperty [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .internalProperty */
/*! export notEqual [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/updating-element.js .notEqual */
/*! export property [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .property */
/*! export query [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .query */
/*! export queryAll [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .queryAll */
/*! export queryAssignedNodes [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .queryAssignedNodes */
/*! export queryAsync [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/decorators.js .queryAsync */
/*! export supportsAdoptingStyleSheets [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/css-tag.js .supportsAdoptingStyleSheets */
/*! export svg [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lit-html.js .svg */
/*! export unsafeCSS [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-element/lib/css-tag.js .unsafeCSS */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"UpdatingElement\": () => /* reexport safe */ _lib_updating_element_js__WEBPACK_IMPORTED_MODULE_1__.UpdatingElement,\n/* harmony export */   \"defaultConverter\": () => /* reexport safe */ _lib_updating_element_js__WEBPACK_IMPORTED_MODULE_1__.defaultConverter,\n/* harmony export */   \"notEqual\": () => /* reexport safe */ _lib_updating_element_js__WEBPACK_IMPORTED_MODULE_1__.notEqual,\n/* harmony export */   \"customElement\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.customElement,\n/* harmony export */   \"eventOptions\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.eventOptions,\n/* harmony export */   \"internalProperty\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.internalProperty,\n/* harmony export */   \"property\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.property,\n/* harmony export */   \"query\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.query,\n/* harmony export */   \"queryAll\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.queryAll,\n/* harmony export */   \"queryAssignedNodes\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.queryAssignedNodes,\n/* harmony export */   \"queryAsync\": () => /* reexport safe */ _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__.queryAsync,\n/* harmony export */   \"html\": () => /* reexport safe */ lit_html_lit_html_js__WEBPACK_IMPORTED_MODULE_3__.html,\n/* harmony export */   \"svg\": () => /* reexport safe */ lit_html_lit_html_js__WEBPACK_IMPORTED_MODULE_3__.svg,\n/* harmony export */   \"TemplateResult\": () => /* reexport safe */ lit_html_lit_html_js__WEBPACK_IMPORTED_MODULE_3__.TemplateResult,\n/* harmony export */   \"SVGTemplateResult\": () => /* reexport safe */ lit_html_lit_html_js__WEBPACK_IMPORTED_MODULE_3__.SVGTemplateResult,\n/* harmony export */   \"CSSResult\": () => /* reexport safe */ _lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.CSSResult,\n/* harmony export */   \"css\": () => /* reexport safe */ _lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.css,\n/* harmony export */   \"supportsAdoptingStyleSheets\": () => /* reexport safe */ _lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.supportsAdoptingStyleSheets,\n/* harmony export */   \"unsafeCSS\": () => /* reexport safe */ _lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.unsafeCSS,\n/* harmony export */   \"LitElement\": () => /* binding */ LitElement\n/* harmony export */ });\n/* harmony import */ var lit_html_lib_shady_render_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-html/lib/shady-render.js */ \"./node_modules/lit-html/lib/shady-render.js\");\n/* harmony import */ var _lib_updating_element_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./lib/updating-element.js */ \"./node_modules/lit-element/lib/updating-element.js\");\n/* harmony import */ var _lib_decorators_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lib/decorators.js */ \"./node_modules/lit-element/lib/decorators.js\");\n/* harmony import */ var lit_html_lit_html_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! lit-html/lit-html.js */ \"./node_modules/lit-html/lit-html.js\");\n/* harmony import */ var _lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./lib/css-tag.js */ \"./node_modules/lit-element/lib/css-tag.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * The main LitElement module, which defines the [[`LitElement`]] base class and\n * related APIs.\n *\n *  LitElement components can define a template and a set of observed\n * properties. Changing an observed property triggers a re-render of the\n * element.\n *\n *  Import [[`LitElement`]] and [[`html`]] from this module to create a\n * component:\n *\n *  ```js\n * import {LitElement, html} from 'lit-element';\n *\n * class MyElement extends LitElement {\n *\n *   // Declare observed properties\n *   static get properties() {\n *     return {\n *       adjective: {}\n *     }\n *   }\n *\n *   constructor() {\n *     this.adjective = 'awesome';\n *   }\n *\n *   // Define the element's template\n *   render() {\n *     return html`<p>your ${adjective} template here</p>`;\n *   }\n * }\n *\n * customElements.define('my-element', MyElement);\n * ```\n *\n * `LitElement` extends [[`UpdatingElement`]] and adds lit-html templating.\n * The `UpdatingElement` class is provided for users that want to build\n * their own custom element base classes that don't use lit-html.\n *\n * @packageDocumentation\n */\n\n\n\n\n\n\n // IMPORTANT: do not change the property name or the assignment expression.\n// This line will be used in regexes to search for LitElement usage.\n// TODO(justinfagnani): inject version number at build time\n\n(window['litElementVersions'] || (window['litElementVersions'] = [])).push('2.4.0');\n/**\n * Sentinal value used to avoid calling lit-html's render function when\n * subclasses do not implement `render`\n */\n\nconst renderNotImplemented = {};\n/**\n * Base element class that manages element properties and attributes, and\n * renders a lit-html template.\n *\n * To define a component, subclass `LitElement` and implement a\n * `render` method to provide the component's template. Define properties\n * using the [[`properties`]] property or the [[`property`]] decorator.\n */\n\nclass LitElement extends _lib_updating_element_js__WEBPACK_IMPORTED_MODULE_1__.UpdatingElement {\n  /**\n   * Return the array of styles to apply to the element.\n   * Override this method to integrate into a style management system.\n   *\n   * @nocollapse\n   */\n  static getStyles() {\n    return this.styles;\n  }\n  /** @nocollapse */\n\n\n  static _getUniqueStyles() {\n    // Only gather styles once per class\n    if (this.hasOwnProperty(JSCompiler_renameProperty('_styles', this))) {\n      return;\n    } // Take care not to call `this.getStyles()` multiple times since this\n    // generates new CSSResults each time.\n    // TODO(sorvell): Since we do not cache CSSResults by input, any\n    // shared styles will generate new stylesheet objects, which is wasteful.\n    // This should be addressed when a browser ships constructable\n    // stylesheets.\n\n\n    const userStyles = this.getStyles();\n\n    if (Array.isArray(userStyles)) {\n      // De-duplicate styles preserving the _last_ instance in the set.\n      // This is a performance optimization to avoid duplicated styles that can\n      // occur especially when composing via subclassing.\n      // The last item is kept to try to preserve the cascade order with the\n      // assumption that it's most important that last added styles override\n      // previous styles.\n      const addStyles = (styles, set) => styles.reduceRight((set, s) => // Note: On IE set.add() does not return the set\n      Array.isArray(s) ? addStyles(s, set) : (set.add(s), set), set); // Array.from does not work on Set in IE, otherwise return\n      // Array.from(addStyles(userStyles, new Set<CSSResult>())).reverse()\n\n\n      const set = addStyles(userStyles, new Set());\n      const styles = [];\n      set.forEach(v => styles.unshift(v));\n      this._styles = styles;\n    } else {\n      this._styles = userStyles === undefined ? [] : [userStyles];\n    } // Ensure that there are no invalid CSSStyleSheet instances here. They are\n    // invalid in two conditions.\n    // (1) the sheet is non-constructible (`sheet` of a HTMLStyleElement), but\n    //     this is impossible to check except via .replaceSync or use\n    // (2) the ShadyCSS polyfill is enabled (:. supportsAdoptingStyleSheets is\n    //     false)\n\n\n    this._styles = this._styles.map(s => {\n      if (s instanceof CSSStyleSheet && !_lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.supportsAdoptingStyleSheets) {\n        // Flatten the cssText from the passed constructible stylesheet (or\n        // undetectable non-constructible stylesheet). The user might have\n        // expected to update their stylesheets over time, but the alternative\n        // is a crash.\n        const cssText = Array.prototype.slice.call(s.cssRules).reduce((css, rule) => css + rule.cssText, '');\n        return (0,_lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.unsafeCSS)(cssText);\n      }\n\n      return s;\n    });\n  }\n  /**\n   * Performs element initialization. By default this calls\n   * [[`createRenderRoot`]] to create the element [[`renderRoot`]] node and\n   * captures any pre-set values for registered properties.\n   */\n\n\n  initialize() {\n    super.initialize();\n\n    this.constructor._getUniqueStyles();\n\n    this.renderRoot = this.createRenderRoot(); // Note, if renderRoot is not a shadowRoot, styles would/could apply to the\n    // element's getRootNode(). While this could be done, we're choosing not to\n    // support this now since it would require different logic around de-duping.\n\n    if (window.ShadowRoot && this.renderRoot instanceof window.ShadowRoot) {\n      this.adoptStyles();\n    }\n  }\n  /**\n   * Returns the node into which the element should render and by default\n   * creates and returns an open shadowRoot. Implement to customize where the\n   * element's DOM is rendered. For example, to render into the element's\n   * childNodes, return `this`.\n   * @returns {Element|DocumentFragment} Returns a node into which to render.\n   */\n\n\n  createRenderRoot() {\n    return this.attachShadow({\n      mode: 'open'\n    });\n  }\n  /**\n   * Applies styling to the element shadowRoot using the [[`styles`]]\n   * property. Styling will apply using `shadowRoot.adoptedStyleSheets` where\n   * available and will fallback otherwise. When Shadow DOM is polyfilled,\n   * ShadyCSS scopes styles and adds them to the document. When Shadow DOM\n   * is available but `adoptedStyleSheets` is not, styles are appended to the\n   * end of the `shadowRoot` to [mimic spec\n   * behavior](https://wicg.github.io/construct-stylesheets/#using-constructed-stylesheets).\n   */\n\n\n  adoptStyles() {\n    const styles = this.constructor._styles;\n\n    if (styles.length === 0) {\n      return;\n    } // There are three separate cases here based on Shadow DOM support.\n    // (1) shadowRoot polyfilled: use ShadyCSS\n    // (2) shadowRoot.adoptedStyleSheets available: use it\n    // (3) shadowRoot.adoptedStyleSheets polyfilled: append styles after\n    // rendering\n\n\n    if (window.ShadyCSS !== undefined && !window.ShadyCSS.nativeShadow) {\n      window.ShadyCSS.ScopingShim.prepareAdoptedCssText(styles.map(s => s.cssText), this.localName);\n    } else if (_lib_css_tag_js__WEBPACK_IMPORTED_MODULE_4__.supportsAdoptingStyleSheets) {\n      this.renderRoot.adoptedStyleSheets = styles.map(s => s instanceof CSSStyleSheet ? s : s.styleSheet);\n    } else {\n      // This must be done after rendering so the actual style insertion is done\n      // in `update`.\n      this._needsShimAdoptedStyleSheets = true;\n    }\n  }\n\n  connectedCallback() {\n    super.connectedCallback(); // Note, first update/render handles styleElement so we only call this if\n    // connected after first update.\n\n    if (this.hasUpdated && window.ShadyCSS !== undefined) {\n      window.ShadyCSS.styleElement(this);\n    }\n  }\n  /**\n   * Updates the element. This method reflects property values to attributes\n   * and calls `render` to render DOM via lit-html. Setting properties inside\n   * this method will *not* trigger another update.\n   * @param _changedProperties Map of changed properties with old values\n   */\n\n\n  update(changedProperties) {\n    // Setting properties in `render` should not trigger an update. Since\n    // updates are allowed after super.update, it's important to call `render`\n    // before that.\n    const templateResult = this.render();\n    super.update(changedProperties); // If render is not implemented by the component, don't call lit-html render\n\n    if (templateResult !== renderNotImplemented) {\n      this.constructor.render(templateResult, this.renderRoot, {\n        scopeName: this.localName,\n        eventContext: this\n      });\n    } // When native Shadow DOM is used but adoptedStyles are not supported,\n    // insert styling after rendering to ensure adoptedStyles have highest\n    // priority.\n\n\n    if (this._needsShimAdoptedStyleSheets) {\n      this._needsShimAdoptedStyleSheets = false;\n\n      this.constructor._styles.forEach(s => {\n        const style = document.createElement('style');\n        style.textContent = s.cssText;\n        this.renderRoot.appendChild(style);\n      });\n    }\n  }\n  /**\n   * Invoked on each update to perform rendering tasks. This method may return\n   * any value renderable by lit-html's `NodePart` - typically a\n   * `TemplateResult`. Setting properties inside this method will *not* trigger\n   * the element to update.\n   */\n\n\n  render() {\n    return renderNotImplemented;\n  }\n\n}\n/**\n * Ensure this class is marked as `finalized` as an optimization ensuring\n * it will not needlessly try to `finalize`.\n *\n * Note this property name is a string to prevent breaking Closure JS Compiler\n * optimizations. See updating-element.ts for more information.\n */\n\nLitElement['finalized'] = true;\n/**\n * Reference to the underlying library method used to render the element's\n * DOM. By default, points to the `render` method from lit-html's shady-render\n * module.\n *\n * **Most users will never need to touch this property.**\n *\n * This  property should not be confused with the `render` instance method,\n * which should be overridden to define a template for the element.\n *\n * Advanced users creating a new base class based on LitElement can override\n * this property to point to a custom render method with a signature that\n * matches [shady-render's `render`\n * method](https://lit-html.polymer-project.org/api/modules/shady_render.html#render).\n *\n * @nocollapse\n */\n\nLitElement.render = lit_html_lib_shady_render_js__WEBPACK_IMPORTED_MODULE_0__.render;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-element/lit-element.js\n");

/***/ }),

/***/ "./node_modules/lit-html/directives/class-map.js":
/*!*******************************************************!*\
  !*** ./node_modules/lit-html/directives/class-map.js ***!
  \*******************************************************/
/*! namespace exports */
/*! export classMap [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"classMap\": () => /* binding */ classMap\n/* harmony export */ });\n/* harmony import */ var _lit_html_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../lit-html.js */ \"./node_modules/lit-html/lit-html.js\");\n/**\n * @license\n * Copyright (c) 2018 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n // IE11 doesn't support classList on SVG elements, so we emulate it with a Set\n\nclass ClassList {\n  constructor(element) {\n    this.classes = new Set();\n    this.changed = false;\n    this.element = element;\n    const classList = (element.getAttribute('class') || '').split(/\\s+/);\n\n    for (const cls of classList) {\n      this.classes.add(cls);\n    }\n  }\n\n  add(cls) {\n    this.classes.add(cls);\n    this.changed = true;\n  }\n\n  remove(cls) {\n    this.classes.delete(cls);\n    this.changed = true;\n  }\n\n  commit() {\n    if (this.changed) {\n      let classString = '';\n      this.classes.forEach(cls => classString += cls + ' ');\n      this.element.setAttribute('class', classString);\n    }\n  }\n\n}\n/**\n * Stores the ClassInfo object applied to a given AttributePart.\n * Used to unset existing values when a new ClassInfo object is applied.\n */\n\n\nconst previousClassesCache = new WeakMap();\n/**\n * A directive that applies CSS classes. This must be used in the `class`\n * attribute and must be the only part used in the attribute. It takes each\n * property in the `classInfo` argument and adds the property name to the\n * element's `class` if the property value is truthy; if the property value is\n * falsey, the property name is removed from the element's `class`. For example\n * `{foo: bar}` applies the class `foo` if the value of `bar` is truthy.\n * @param classInfo {ClassInfo}\n */\n\nconst classMap = (0,_lit_html_js__WEBPACK_IMPORTED_MODULE_0__.directive)(classInfo => part => {\n  if (!(part instanceof _lit_html_js__WEBPACK_IMPORTED_MODULE_0__.AttributePart) || part instanceof _lit_html_js__WEBPACK_IMPORTED_MODULE_0__.PropertyPart || part.committer.name !== 'class' || part.committer.parts.length > 1) {\n    throw new Error('The `classMap` directive must be used in the `class` attribute ' + 'and must be the only part in the attribute.');\n  }\n\n  const {\n    committer\n  } = part;\n  const {\n    element\n  } = committer;\n  let previousClasses = previousClassesCache.get(part);\n\n  if (previousClasses === undefined) {\n    // Write static classes once\n    // Use setAttribute() because className isn't a string on SVG elements\n    element.setAttribute('class', committer.strings.join(' '));\n    previousClassesCache.set(part, previousClasses = new Set());\n  }\n\n  const classList = element.classList || new ClassList(element); // Remove old classes that no longer apply\n  // We use forEach() instead of for-of so that re don't require down-level\n  // iteration.\n\n  previousClasses.forEach(name => {\n    if (!(name in classInfo)) {\n      classList.remove(name);\n      previousClasses.delete(name);\n    }\n  }); // Add or remove classes based on their classMap value\n\n  for (const name in classInfo) {\n    const value = classInfo[name];\n\n    if (value != previousClasses.has(name)) {\n      // We explicitly want a loose truthy check of `value` because it seems\n      // more convenient that '' and 0 are skipped.\n      if (value) {\n        classList.add(name);\n        previousClasses.add(name);\n      } else {\n        classList.remove(name);\n        previousClasses.delete(name);\n      }\n    }\n  }\n\n  if (typeof classList.commit === 'function') {\n    classList.commit();\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/directives/class-map.js\n");

/***/ }),

/***/ "./node_modules/lit-html/directives/if-defined.js":
/*!********************************************************!*\
  !*** ./node_modules/lit-html/directives/if-defined.js ***!
  \********************************************************/
/*! namespace exports */
/*! export ifDefined [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"ifDefined\": () => /* binding */ ifDefined\n/* harmony export */ });\n/* harmony import */ var _lit_html_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../lit-html.js */ \"./node_modules/lit-html/lit-html.js\");\n/**\n * @license\n * Copyright (c) 2018 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\nconst previousValues = new WeakMap();\n/**\n * For AttributeParts, sets the attribute if the value is defined and removes\n * the attribute if the value is undefined.\n *\n * For other part types, this directive is a no-op.\n */\n\nconst ifDefined = (0,_lit_html_js__WEBPACK_IMPORTED_MODULE_0__.directive)(value => part => {\n  const previousValue = previousValues.get(part);\n\n  if (value === undefined && part instanceof _lit_html_js__WEBPACK_IMPORTED_MODULE_0__.AttributePart) {\n    // If the value is undefined, remove the attribute, but only if the value\n    // was previously defined.\n    if (previousValue !== undefined || !previousValues.has(part)) {\n      const name = part.committer.name;\n      part.committer.element.removeAttribute(name);\n    }\n  } else if (value !== previousValue) {\n    part.setValue(value);\n  }\n\n  previousValues.set(part, value);\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/lit-html/directives/if-defined.js\n");

/***/ }),

/***/ "./node_modules/lit-html/directives/style-map.js":
/*!*******************************************************!*\
  !*** ./node_modules/lit-html/directives/style-map.js ***!
  \*******************************************************/
/*! namespace exports */
/*! export styleMap [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"styleMap\": () => /* binding */ styleMap\n/* harmony export */ });\n/* harmony import */ var _lit_html_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../lit-html.js */ \"./node_modules/lit-html/lit-html.js\");\n/**\n * @license\n * Copyright (c) 2018 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * Stores the StyleInfo object applied to a given AttributePart.\n * Used to unset existing values when a new StyleInfo object is applied.\n */\n\nconst previousStylePropertyCache = new WeakMap();\n/**\n * A directive that applies CSS properties to an element.\n *\n * `styleMap` can only be used in the `style` attribute and must be the only\n * expression in the attribute. It takes the property names in the `styleInfo`\n * object and adds the property values as CSS properties. Property names with\n * dashes (`-`) are assumed to be valid CSS property names and set on the\n * element's style object using `setProperty()`. Names without dashes are\n * assumed to be camelCased JavaScript property names and set on the element's\n * style object using property assignment, allowing the style object to\n * translate JavaScript-style names to CSS property names.\n *\n * For example `styleMap({backgroundColor: 'red', 'border-top': '5px', '--size':\n * '0'})` sets the `background-color`, `border-top` and `--size` properties.\n *\n * @param styleInfo {StyleInfo}\n */\n\nconst styleMap = (0,_lit_html_js__WEBPACK_IMPORTED_MODULE_0__.directive)(styleInfo => part => {\n  if (!(part instanceof _lit_html_js__WEBPACK_IMPORTED_MODULE_0__.AttributePart) || part instanceof _lit_html_js__WEBPACK_IMPORTED_MODULE_0__.PropertyPart || part.committer.name !== 'style' || part.committer.parts.length > 1) {\n    throw new Error('The `styleMap` directive must be used in the style attribute ' + 'and must be the only part in the attribute.');\n  }\n\n  const {\n    committer\n  } = part;\n  const {\n    style\n  } = committer.element;\n  let previousStyleProperties = previousStylePropertyCache.get(part);\n\n  if (previousStyleProperties === undefined) {\n    // Write static styles once\n    style.cssText = committer.strings.join(' ');\n    previousStylePropertyCache.set(part, previousStyleProperties = new Set());\n  } // Remove old properties that no longer exist in styleInfo\n  // We use forEach() instead of for-of so that re don't require down-level\n  // iteration.\n\n\n  previousStyleProperties.forEach(name => {\n    if (!(name in styleInfo)) {\n      previousStyleProperties.delete(name);\n\n      if (name.indexOf('-') === -1) {\n        // eslint-disable-next-line @typescript-eslint/no-explicit-any\n        style[name] = null;\n      } else {\n        style.removeProperty(name);\n      }\n    }\n  }); // Add or update properties\n\n  for (const name in styleInfo) {\n    previousStyleProperties.add(name);\n\n    if (name.indexOf('-') === -1) {\n      // eslint-disable-next-line @typescript-eslint/no-explicit-any\n      style[name] = styleInfo[name];\n    } else {\n      style.setProperty(name, styleInfo[name]);\n    }\n  }\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/directives/style-map.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/default-template-processor.js":
/*!*****************************************************************!*\
  !*** ./node_modules/lit-html/lib/default-template-processor.js ***!
  \*****************************************************************/
/*! namespace exports */
/*! export DefaultTemplateProcessor [provided] [no usage info] [missing usage info prevents renaming] */
/*! export defaultTemplateProcessor [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DefaultTemplateProcessor\": () => /* binding */ DefaultTemplateProcessor,\n/* harmony export */   \"defaultTemplateProcessor\": () => /* binding */ defaultTemplateProcessor\n/* harmony export */ });\n/* harmony import */ var _parts_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./parts.js */ \"./node_modules/lit-html/lib/parts.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * Creates Parts when a template is instantiated.\n */\n\nclass DefaultTemplateProcessor {\n  /**\n   * Create parts for an attribute-position binding, given the event, attribute\n   * name, and string literals.\n   *\n   * @param element The element containing the binding\n   * @param name  The attribute name\n   * @param strings The string literals. There are always at least two strings,\n   *   event for fully-controlled bindings with a single expression.\n   */\n  handleAttributeExpressions(element, name, strings, options) {\n    const prefix = name[0];\n\n    if (prefix === '.') {\n      const committer = new _parts_js__WEBPACK_IMPORTED_MODULE_0__.PropertyCommitter(element, name.slice(1), strings);\n      return committer.parts;\n    }\n\n    if (prefix === '@') {\n      return [new _parts_js__WEBPACK_IMPORTED_MODULE_0__.EventPart(element, name.slice(1), options.eventContext)];\n    }\n\n    if (prefix === '?') {\n      return [new _parts_js__WEBPACK_IMPORTED_MODULE_0__.BooleanAttributePart(element, name.slice(1), strings)];\n    }\n\n    const committer = new _parts_js__WEBPACK_IMPORTED_MODULE_0__.AttributeCommitter(element, name, strings);\n    return committer.parts;\n  }\n  /**\n   * Create parts for a text-position binding.\n   * @param templateFactory\n   */\n\n\n  handleTextExpression(options) {\n    return new _parts_js__WEBPACK_IMPORTED_MODULE_0__.NodePart(options);\n  }\n\n}\nconst defaultTemplateProcessor = new DefaultTemplateProcessor();//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/default-template-processor.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/directive.js":
/*!************************************************!*\
  !*** ./node_modules/lit-html/lib/directive.js ***!
  \************************************************/
/*! namespace exports */
/*! export directive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDirective [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"directive\": () => /* binding */ directive,\n/* harmony export */   \"isDirective\": () => /* binding */ isDirective\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\nconst directives = new WeakMap();\n/**\n * Brands a function as a directive factory function so that lit-html will call\n * the function during template rendering, rather than passing as a value.\n *\n * A _directive_ is a function that takes a Part as an argument. It has the\n * signature: `(part: Part) => void`.\n *\n * A directive _factory_ is a function that takes arguments for data and\n * configuration and returns a directive. Users of directive usually refer to\n * the directive factory as the directive. For example, \"The repeat directive\".\n *\n * Usually a template author will invoke a directive factory in their template\n * with relevant arguments, which will then return a directive function.\n *\n * Here's an example of using the `repeat()` directive factory that takes an\n * array and a function to render an item:\n *\n * ```js\n * html`<ul><${repeat(items, (item) => html`<li>${item}</li>`)}</ul>`\n * ```\n *\n * When `repeat` is invoked, it returns a directive function that closes over\n * `items` and the template function. When the outer template is rendered, the\n * return directive function is called with the Part for the expression.\n * `repeat` then performs it's custom logic to render multiple items.\n *\n * @param f The directive factory function. Must be a function that returns a\n * function of the signature `(part: Part) => void`. The returned function will\n * be called with the part object.\n *\n * @example\n *\n * import {directive, html} from 'lit-html';\n *\n * const immutable = directive((v) => (part) => {\n *   if (part.value !== v) {\n *     part.setValue(v)\n *   }\n * });\n */\n\nconst directive = f => (...args) => {\n  const d = f(...args);\n  directives.set(d, true);\n  return d;\n};\nconst isDirective = o => {\n  return typeof o === 'function' && directives.has(o);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/directive.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/dom.js":
/*!******************************************!*\
  !*** ./node_modules/lit-html/lib/dom.js ***!
  \******************************************/
/*! namespace exports */
/*! export isCEPolyfill [provided] [no usage info] [missing usage info prevents renaming] */
/*! export removeNodes [provided] [no usage info] [missing usage info prevents renaming] */
/*! export reparentNodes [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"isCEPolyfill\": () => /* binding */ isCEPolyfill,\n/* harmony export */   \"reparentNodes\": () => /* binding */ reparentNodes,\n/* harmony export */   \"removeNodes\": () => /* binding */ removeNodes\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * True if the custom elements polyfill is in use.\n */\nconst isCEPolyfill = typeof window !== 'undefined' && window.customElements != null && window.customElements.polyfillWrapFlushCallback !== undefined;\n/**\n * Reparents nodes, starting from `start` (inclusive) to `end` (exclusive),\n * into another container (could be the same container), before `before`. If\n * `before` is null, it appends the nodes to the container.\n */\n\nconst reparentNodes = (container, start, end = null, before = null) => {\n  while (start !== end) {\n    const n = start.nextSibling;\n    container.insertBefore(start, before);\n    start = n;\n  }\n};\n/**\n * Removes nodes, starting from `start` (inclusive) to `end` (exclusive), from\n * `container`.\n */\n\nconst removeNodes = (container, start, end = null) => {\n  while (start !== end) {\n    const n = start.nextSibling;\n    container.removeChild(start);\n    start = n;\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/dom.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/modify-template.js":
/*!******************************************************!*\
  !*** ./node_modules/lit-html/lib/modify-template.js ***!
  \******************************************************/
/*! namespace exports */
/*! export insertNodeIntoTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export removeNodesFromTemplate [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"removeNodesFromTemplate\": () => /* binding */ removeNodesFromTemplate,\n/* harmony export */   \"insertNodeIntoTemplate\": () => /* binding */ insertNodeIntoTemplate\n/* harmony export */ });\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\nconst walkerNodeFilter = 133\n/* NodeFilter.SHOW_{ELEMENT|COMMENT|TEXT} */\n;\n/**\n * Removes the list of nodes from a Template safely. In addition to removing\n * nodes from the Template, the Template part indices are updated to match\n * the mutated Template DOM.\n *\n * As the template is walked the removal state is tracked and\n * part indices are adjusted as needed.\n *\n * div\n *   div#1 (remove) <-- start removing (removing node is div#1)\n *     div\n *       div#2 (remove)  <-- continue removing (removing node is still div#1)\n *         div\n * div <-- stop removing since previous sibling is the removing node (div#1,\n * removed 4 nodes)\n */\n\nfunction removeNodesFromTemplate(template, nodesToRemove) {\n  const {\n    element: {\n      content\n    },\n    parts\n  } = template;\n  const walker = document.createTreeWalker(content, walkerNodeFilter, null, false);\n  let partIndex = nextActiveIndexInTemplateParts(parts);\n  let part = parts[partIndex];\n  let nodeIndex = -1;\n  let removeCount = 0;\n  const nodesToRemoveInTemplate = [];\n  let currentRemovingNode = null;\n\n  while (walker.nextNode()) {\n    nodeIndex++;\n    const node = walker.currentNode; // End removal if stepped past the removing node\n\n    if (node.previousSibling === currentRemovingNode) {\n      currentRemovingNode = null;\n    } // A node to remove was found in the template\n\n\n    if (nodesToRemove.has(node)) {\n      nodesToRemoveInTemplate.push(node); // Track node we're removing\n\n      if (currentRemovingNode === null) {\n        currentRemovingNode = node;\n      }\n    } // When removing, increment count by which to adjust subsequent part indices\n\n\n    if (currentRemovingNode !== null) {\n      removeCount++;\n    }\n\n    while (part !== undefined && part.index === nodeIndex) {\n      // If part is in a removed node deactivate it by setting index to -1 or\n      // adjust the index as needed.\n      part.index = currentRemovingNode !== null ? -1 : part.index - removeCount; // go to the next active part.\n\n      partIndex = nextActiveIndexInTemplateParts(parts, partIndex);\n      part = parts[partIndex];\n    }\n  }\n\n  nodesToRemoveInTemplate.forEach(n => n.parentNode.removeChild(n));\n}\n\nconst countNodes = node => {\n  let count = node.nodeType === 11\n  /* Node.DOCUMENT_FRAGMENT_NODE */\n  ? 0 : 1;\n  const walker = document.createTreeWalker(node, walkerNodeFilter, null, false);\n\n  while (walker.nextNode()) {\n    count++;\n  }\n\n  return count;\n};\n\nconst nextActiveIndexInTemplateParts = (parts, startIndex = -1) => {\n  for (let i = startIndex + 1; i < parts.length; i++) {\n    const part = parts[i];\n\n    if ((0,_template_js__WEBPACK_IMPORTED_MODULE_0__.isTemplatePartActive)(part)) {\n      return i;\n    }\n  }\n\n  return -1;\n};\n/**\n * Inserts the given node into the Template, optionally before the given\n * refNode. In addition to inserting the node into the Template, the Template\n * part indices are updated to match the mutated Template DOM.\n */\n\n\nfunction insertNodeIntoTemplate(template, node, refNode = null) {\n  const {\n    element: {\n      content\n    },\n    parts\n  } = template; // If there's no refNode, then put node at end of template.\n  // No part indices need to be shifted in this case.\n\n  if (refNode === null || refNode === undefined) {\n    content.appendChild(node);\n    return;\n  }\n\n  const walker = document.createTreeWalker(content, walkerNodeFilter, null, false);\n  let partIndex = nextActiveIndexInTemplateParts(parts);\n  let insertCount = 0;\n  let walkerIndex = -1;\n\n  while (walker.nextNode()) {\n    walkerIndex++;\n    const walkerNode = walker.currentNode;\n\n    if (walkerNode === refNode) {\n      insertCount = countNodes(node);\n      refNode.parentNode.insertBefore(node, refNode);\n    }\n\n    while (partIndex !== -1 && parts[partIndex].index === walkerIndex) {\n      // If we've inserted the node, simply adjust all subsequent parts\n      if (insertCount > 0) {\n        while (partIndex !== -1) {\n          parts[partIndex].index += insertCount;\n          partIndex = nextActiveIndexInTemplateParts(parts, partIndex);\n        }\n\n        return;\n      }\n\n      partIndex = nextActiveIndexInTemplateParts(parts, partIndex);\n    }\n  }\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/modify-template.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/part.js":
/*!*******************************************!*\
  !*** ./node_modules/lit-html/lib/part.js ***!
  \*******************************************/
/*! namespace exports */
/*! export noChange [provided] [no usage info] [missing usage info prevents renaming] */
/*! export nothing [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"noChange\": () => /* binding */ noChange,\n/* harmony export */   \"nothing\": () => /* binding */ nothing\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2018 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * A sentinel value that signals that a value was handled by a directive and\n * should not be written to the DOM.\n */\nconst noChange = {};\n/**\n * A sentinel value that signals a NodePart to fully clear its content.\n */\n\nconst nothing = {};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvbGl0LWh0bWwvbGliL3BhcnQuanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uLi9zcmMvbGliL3BhcnQudHM/MmQ1NyJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbiAqIEBsaWNlbnNlXG4gKiBDb3B5cmlnaHQgKGMpIDIwMTggVGhlIFBvbHltZXIgUHJvamVjdCBBdXRob3JzLiBBbGwgcmlnaHRzIHJlc2VydmVkLlxuICogVGhpcyBjb2RlIG1heSBvbmx5IGJlIHVzZWQgdW5kZXIgdGhlIEJTRCBzdHlsZSBsaWNlbnNlIGZvdW5kIGF0XG4gKiBodHRwOi8vcG9seW1lci5naXRodWIuaW8vTElDRU5TRS50eHRcbiAqIFRoZSBjb21wbGV0ZSBzZXQgb2YgYXV0aG9ycyBtYXkgYmUgZm91bmQgYXRcbiAqIGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9BVVRIT1JTLnR4dFxuICogVGhlIGNvbXBsZXRlIHNldCBvZiBjb250cmlidXRvcnMgbWF5IGJlIGZvdW5kIGF0XG4gKiBodHRwOi8vcG9seW1lci5naXRodWIuaW8vQ09OVFJJQlVUT1JTLnR4dFxuICogQ29kZSBkaXN0cmlidXRlZCBieSBHb29nbGUgYXMgcGFydCBvZiB0aGUgcG9seW1lciBwcm9qZWN0IGlzIGFsc29cbiAqIHN1YmplY3QgdG8gYW4gYWRkaXRpb25hbCBJUCByaWdodHMgZ3JhbnQgZm91bmQgYXRcbiAqIGh0dHA6Ly9wb2x5bWVyLmdpdGh1Yi5pby9QQVRFTlRTLnR4dFxuICovXG5cbi8qKlxuICogVGhlIFBhcnQgaW50ZXJmYWNlIHJlcHJlc2VudHMgYSBkeW5hbWljIHBhcnQgb2YgYSB0ZW1wbGF0ZSBpbnN0YW5jZSByZW5kZXJlZFxuICogYnkgbGl0LWh0bWwuXG4gKi9cbmV4cG9ydCBpbnRlcmZhY2UgUGFydCB7XG4gIHJlYWRvbmx5IHZhbHVlOiB1bmtub3duO1xuXG4gIC8qKlxuICAgKiBTZXRzIHRoZSBjdXJyZW50IHBhcnQgdmFsdWUsIGJ1dCBkb2VzIG5vdCB3cml0ZSBpdCB0byB0aGUgRE9NLlxuICAgKiBAcGFyYW0gdmFsdWUgVGhlIHZhbHVlIHRoYXQgd2lsbCBiZSBjb21taXR0ZWQuXG4gICAqL1xuICBzZXRWYWx1ZSh2YWx1ZTogdW5rbm93bik6IHZvaWQ7XG5cbiAgLyoqXG4gICAqIENvbW1pdHMgdGhlIGN1cnJlbnQgcGFydCB2YWx1ZSwgY2F1c2luZyBpdCB0byBhY3R1YWxseSBiZSB3cml0dGVuIHRvIHRoZVxuICAgKiBET00uXG4gICAqXG4gICAqIERpcmVjdGl2ZXMgYXJlIHJ1biBhdCB0aGUgc3RhcnQgb2YgYGNvbW1pdGAsIHNvIHRoYXQgaWYgdGhleSBjYWxsXG4gICAqIGBwYXJ0LnNldFZhbHVlKC4uLilgIHN5bmNocm9ub3VzbHkgdGhhdCB2YWx1ZSB3aWxsIGJlIHVzZWQgaW4gdGhlIGN1cnJlbnRcbiAgICogY29tbWl0LCBhbmQgdGhlcmUncyBubyBuZWVkIHRvIGNhbGwgYHBhcnQuY29tbWl0KClgIHdpdGhpbiB0aGUgZGlyZWN0aXZlLlxuICAgKiBJZiBkaXJlY3RpdmVzIHNldCBhIHBhcnQgdmFsdWUgYXN5bmNocm9ub3VzbHksIHRoZW4gdGhleSBtdXN0IGNhbGxcbiAgICogYHBhcnQuY29tbWl0KClgIG1hbnVhbGx5LlxuICAgKi9cbiAgY29tbWl0KCk6IHZvaWQ7XG59XG5cbi8qKlxuICogQSBzZW50aW5lbCB2YWx1ZSB0aGF0IHNpZ25hbHMgdGhhdCBhIHZhbHVlIHdhcyBoYW5kbGVkIGJ5IGEgZGlyZWN0aXZlIGFuZFxuICogc2hvdWxkIG5vdCBiZSB3cml0dGVuIHRvIHRoZSBET00uXG4gKi9cbmV4cG9ydCBjb25zdCBub0NoYW5nZSA9IHt9O1xuXG4vKipcbiAqIEEgc2VudGluZWwgdmFsdWUgdGhhdCBzaWduYWxzIGEgTm9kZVBhcnQgdG8gZnVsbHkgY2xlYXIgaXRzIGNvbnRlbnQuXG4gKi9cbmV4cG9ydCBjb25zdCBub3RoaW5nID0ge307XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7Ozs7Ozs7Ozs7Ozs7O0FBd0NBOzs7O0FBSUE7QUFFQTs7OztBQUdBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/part.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/parts.js":
/*!********************************************!*\
  !*** ./node_modules/lit-html/lib/parts.js ***!
  \********************************************/
/*! namespace exports */
/*! export AttributeCommitter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export AttributePart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export BooleanAttributePart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export EventPart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export NodePart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export PropertyCommitter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export PropertyPart [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isIterable [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isPrimitive [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"isPrimitive\": () => /* binding */ isPrimitive,\n/* harmony export */   \"isIterable\": () => /* binding */ isIterable,\n/* harmony export */   \"AttributeCommitter\": () => /* binding */ AttributeCommitter,\n/* harmony export */   \"AttributePart\": () => /* binding */ AttributePart,\n/* harmony export */   \"NodePart\": () => /* binding */ NodePart,\n/* harmony export */   \"BooleanAttributePart\": () => /* binding */ BooleanAttributePart,\n/* harmony export */   \"PropertyCommitter\": () => /* binding */ PropertyCommitter,\n/* harmony export */   \"PropertyPart\": () => /* binding */ PropertyPart,\n/* harmony export */   \"EventPart\": () => /* binding */ EventPart\n/* harmony export */ });\n/* harmony import */ var _directive_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./directive.js */ \"./node_modules/lit-html/lib/directive.js\");\n/* harmony import */ var _dom_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _part_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./part.js */ \"./node_modules/lit-html/lib/part.js\");\n/* harmony import */ var _template_instance_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./template-instance.js */ \"./node_modules/lit-html/lib/template-instance.js\");\n/* harmony import */ var _template_result_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./template-result.js */ \"./node_modules/lit-html/lib/template-result.js\");\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n\n\n\n\n\nconst isPrimitive = value => {\n  return value === null || !(typeof value === 'object' || typeof value === 'function');\n};\nconst isIterable = value => {\n  return Array.isArray(value) || // eslint-disable-next-line @typescript-eslint/no-explicit-any\n  !!(value && value[Symbol.iterator]);\n};\n/**\n * Writes attribute values to the DOM for a group of AttributeParts bound to a\n * single attribute. The value is only set once even if there are multiple parts\n * for an attribute.\n */\n\nclass AttributeCommitter {\n  constructor(element, name, strings) {\n    this.dirty = true;\n    this.element = element;\n    this.name = name;\n    this.strings = strings;\n    this.parts = [];\n\n    for (let i = 0; i < strings.length - 1; i++) {\n      this.parts[i] = this._createPart();\n    }\n  }\n  /**\n   * Creates a single part. Override this to create a differnt type of part.\n   */\n\n\n  _createPart() {\n    return new AttributePart(this);\n  }\n\n  _getValue() {\n    const strings = this.strings;\n    const l = strings.length - 1;\n    const parts = this.parts; // If we're assigning an attribute via syntax like:\n    //    attr=\"${foo}\"  or  attr=${foo}\n    // but not\n    //    attr=\"${foo} ${bar}\" or attr=\"${foo} baz\"\n    // then we don't want to coerce the attribute value into one long\n    // string. Instead we want to just return the value itself directly,\n    // so that sanitizeDOMValue can get the actual value rather than\n    // String(value)\n    // The exception is if v is an array, in which case we do want to smash\n    // it together into a string without calling String() on the array.\n    //\n    // This also allows trusted values (when using TrustedTypes) being\n    // assigned to DOM sinks without being stringified in the process.\n\n    if (l === 1 && strings[0] === '' && strings[1] === '') {\n      const v = parts[0].value;\n\n      if (typeof v === 'symbol') {\n        return String(v);\n      }\n\n      if (typeof v === 'string' || !isIterable(v)) {\n        return v;\n      }\n    }\n\n    let text = '';\n\n    for (let i = 0; i < l; i++) {\n      text += strings[i];\n      const part = parts[i];\n\n      if (part !== undefined) {\n        const v = part.value;\n\n        if (isPrimitive(v) || !isIterable(v)) {\n          text += typeof v === 'string' ? v : String(v);\n        } else {\n          for (const t of v) {\n            text += typeof t === 'string' ? t : String(t);\n          }\n        }\n      }\n    }\n\n    text += strings[l];\n    return text;\n  }\n\n  commit() {\n    if (this.dirty) {\n      this.dirty = false;\n      this.element.setAttribute(this.name, this._getValue());\n    }\n  }\n\n}\n/**\n * A Part that controls all or part of an attribute value.\n */\n\nclass AttributePart {\n  constructor(committer) {\n    this.value = undefined;\n    this.committer = committer;\n  }\n\n  setValue(value) {\n    if (value !== _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange && (!isPrimitive(value) || value !== this.value)) {\n      this.value = value; // If the value is a not a directive, dirty the committer so that it'll\n      // call setAttribute. If the value is a directive, it'll dirty the\n      // committer if it calls setValue().\n\n      if (!(0,_directive_js__WEBPACK_IMPORTED_MODULE_0__.isDirective)(value)) {\n        this.committer.dirty = true;\n      }\n    }\n  }\n\n  commit() {\n    while ((0,_directive_js__WEBPACK_IMPORTED_MODULE_0__.isDirective)(this.value)) {\n      const directive = this.value;\n      this.value = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n      directive(this);\n    }\n\n    if (this.value === _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange) {\n      return;\n    }\n\n    this.committer.commit();\n  }\n\n}\n/**\n * A Part that controls a location within a Node tree. Like a Range, NodePart\n * has start and end locations and can set and update the Nodes between those\n * locations.\n *\n * NodeParts support several value types: primitives, Nodes, TemplateResults,\n * as well as arrays and iterables of those types.\n */\n\nclass NodePart {\n  constructor(options) {\n    this.value = undefined;\n    this.__pendingValue = undefined;\n    this.options = options;\n  }\n  /**\n   * Appends this part into a container.\n   *\n   * This part must be empty, as its contents are not automatically moved.\n   */\n\n\n  appendInto(container) {\n    this.startNode = container.appendChild((0,_template_js__WEBPACK_IMPORTED_MODULE_5__.createMarker)());\n    this.endNode = container.appendChild((0,_template_js__WEBPACK_IMPORTED_MODULE_5__.createMarker)());\n  }\n  /**\n   * Inserts this part after the `ref` node (between `ref` and `ref`'s next\n   * sibling). Both `ref` and its next sibling must be static, unchanging nodes\n   * such as those that appear in a literal section of a template.\n   *\n   * This part must be empty, as its contents are not automatically moved.\n   */\n\n\n  insertAfterNode(ref) {\n    this.startNode = ref;\n    this.endNode = ref.nextSibling;\n  }\n  /**\n   * Appends this part into a parent part.\n   *\n   * This part must be empty, as its contents are not automatically moved.\n   */\n\n\n  appendIntoPart(part) {\n    part.__insert(this.startNode = (0,_template_js__WEBPACK_IMPORTED_MODULE_5__.createMarker)());\n\n    part.__insert(this.endNode = (0,_template_js__WEBPACK_IMPORTED_MODULE_5__.createMarker)());\n  }\n  /**\n   * Inserts this part after the `ref` part.\n   *\n   * This part must be empty, as its contents are not automatically moved.\n   */\n\n\n  insertAfterPart(ref) {\n    ref.__insert(this.startNode = (0,_template_js__WEBPACK_IMPORTED_MODULE_5__.createMarker)());\n\n    this.endNode = ref.endNode;\n    ref.endNode = this.startNode;\n  }\n\n  setValue(value) {\n    this.__pendingValue = value;\n  }\n\n  commit() {\n    if (this.startNode.parentNode === null) {\n      return;\n    }\n\n    while ((0,_directive_js__WEBPACK_IMPORTED_MODULE_0__.isDirective)(this.__pendingValue)) {\n      const directive = this.__pendingValue;\n      this.__pendingValue = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n      directive(this);\n    }\n\n    const value = this.__pendingValue;\n\n    if (value === _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange) {\n      return;\n    }\n\n    if (isPrimitive(value)) {\n      if (value !== this.value) {\n        this.__commitText(value);\n      }\n    } else if (value instanceof _template_result_js__WEBPACK_IMPORTED_MODULE_4__.TemplateResult) {\n      this.__commitTemplateResult(value);\n    } else if (value instanceof Node) {\n      this.__commitNode(value);\n    } else if (isIterable(value)) {\n      this.__commitIterable(value);\n    } else if (value === _part_js__WEBPACK_IMPORTED_MODULE_2__.nothing) {\n      this.value = _part_js__WEBPACK_IMPORTED_MODULE_2__.nothing;\n      this.clear();\n    } else {\n      // Fallback, will render the string representation\n      this.__commitText(value);\n    }\n  }\n\n  __insert(node) {\n    this.endNode.parentNode.insertBefore(node, this.endNode);\n  }\n\n  __commitNode(value) {\n    if (this.value === value) {\n      return;\n    }\n\n    this.clear();\n\n    this.__insert(value);\n\n    this.value = value;\n  }\n\n  __commitText(value) {\n    const node = this.startNode.nextSibling;\n    value = value == null ? '' : value; // If `value` isn't already a string, we explicitly convert it here in case\n    // it can't be implicitly converted - i.e. it's a symbol.\n\n    const valueAsString = typeof value === 'string' ? value : String(value);\n\n    if (node === this.endNode.previousSibling && node.nodeType === 3\n    /* Node.TEXT_NODE */\n    ) {\n        // If we only have a single text node between the markers, we can just\n        // set its value, rather than replacing it.\n        // TODO(justinfagnani): Can we just check if this.value is primitive?\n        node.data = valueAsString;\n      } else {\n      this.__commitNode(document.createTextNode(valueAsString));\n    }\n\n    this.value = value;\n  }\n\n  __commitTemplateResult(value) {\n    const template = this.options.templateFactory(value);\n\n    if (this.value instanceof _template_instance_js__WEBPACK_IMPORTED_MODULE_3__.TemplateInstance && this.value.template === template) {\n      this.value.update(value.values);\n    } else {\n      // Make sure we propagate the template processor from the TemplateResult\n      // so that we use its syntax extension, etc. The template factory comes\n      // from the render function options so that it can control template\n      // caching and preprocessing.\n      const instance = new _template_instance_js__WEBPACK_IMPORTED_MODULE_3__.TemplateInstance(template, value.processor, this.options);\n\n      const fragment = instance._clone();\n\n      instance.update(value.values);\n\n      this.__commitNode(fragment);\n\n      this.value = instance;\n    }\n  }\n\n  __commitIterable(value) {\n    // For an Iterable, we create a new InstancePart per item, then set its\n    // value to the item. This is a little bit of overhead for every item in\n    // an Iterable, but it lets us recurse easily and efficiently update Arrays\n    // of TemplateResults that will be commonly returned from expressions like:\n    // array.map((i) => html`${i}`), by reusing existing TemplateInstances.\n    // If _value is an array, then the previous render was of an\n    // iterable and _value will contain the NodeParts from the previous\n    // render. If _value is not an array, clear this part and make a new\n    // array for NodeParts.\n    if (!Array.isArray(this.value)) {\n      this.value = [];\n      this.clear();\n    } // Lets us keep track of how many items we stamped so we can clear leftover\n    // items from a previous render\n\n\n    const itemParts = this.value;\n    let partIndex = 0;\n    let itemPart;\n\n    for (const item of value) {\n      // Try to reuse an existing part\n      itemPart = itemParts[partIndex]; // If no existing part, create a new one\n\n      if (itemPart === undefined) {\n        itemPart = new NodePart(this.options);\n        itemParts.push(itemPart);\n\n        if (partIndex === 0) {\n          itemPart.appendIntoPart(this);\n        } else {\n          itemPart.insertAfterPart(itemParts[partIndex - 1]);\n        }\n      }\n\n      itemPart.setValue(item);\n      itemPart.commit();\n      partIndex++;\n    }\n\n    if (partIndex < itemParts.length) {\n      // Truncate the parts array so _value reflects the current state\n      itemParts.length = partIndex;\n      this.clear(itemPart && itemPart.endNode);\n    }\n  }\n\n  clear(startNode = this.startNode) {\n    (0,_dom_js__WEBPACK_IMPORTED_MODULE_1__.removeNodes)(this.startNode.parentNode, startNode.nextSibling, this.endNode);\n  }\n\n}\n/**\n * Implements a boolean attribute, roughly as defined in the HTML\n * specification.\n *\n * If the value is truthy, then the attribute is present with a value of\n * ''. If the value is falsey, the attribute is removed.\n */\n\nclass BooleanAttributePart {\n  constructor(element, name, strings) {\n    this.value = undefined;\n    this.__pendingValue = undefined;\n\n    if (strings.length !== 2 || strings[0] !== '' || strings[1] !== '') {\n      throw new Error('Boolean attributes can only contain a single expression');\n    }\n\n    this.element = element;\n    this.name = name;\n    this.strings = strings;\n  }\n\n  setValue(value) {\n    this.__pendingValue = value;\n  }\n\n  commit() {\n    while ((0,_directive_js__WEBPACK_IMPORTED_MODULE_0__.isDirective)(this.__pendingValue)) {\n      const directive = this.__pendingValue;\n      this.__pendingValue = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n      directive(this);\n    }\n\n    if (this.__pendingValue === _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange) {\n      return;\n    }\n\n    const value = !!this.__pendingValue;\n\n    if (this.value !== value) {\n      if (value) {\n        this.element.setAttribute(this.name, '');\n      } else {\n        this.element.removeAttribute(this.name);\n      }\n\n      this.value = value;\n    }\n\n    this.__pendingValue = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n  }\n\n}\n/**\n * Sets attribute values for PropertyParts, so that the value is only set once\n * even if there are multiple parts for a property.\n *\n * If an expression controls the whole property value, then the value is simply\n * assigned to the property under control. If there are string literals or\n * multiple expressions, then the strings are expressions are interpolated into\n * a string first.\n */\n\nclass PropertyCommitter extends AttributeCommitter {\n  constructor(element, name, strings) {\n    super(element, name, strings);\n    this.single = strings.length === 2 && strings[0] === '' && strings[1] === '';\n  }\n\n  _createPart() {\n    return new PropertyPart(this);\n  }\n\n  _getValue() {\n    if (this.single) {\n      return this.parts[0].value;\n    }\n\n    return super._getValue();\n  }\n\n  commit() {\n    if (this.dirty) {\n      this.dirty = false; // eslint-disable-next-line @typescript-eslint/no-explicit-any\n\n      this.element[this.name] = this._getValue();\n    }\n  }\n\n}\nclass PropertyPart extends AttributePart {} // Detect event listener options support. If the `capture` property is read\n// from the options object, then options are supported. If not, then the third\n// argument to add/removeEventListener is interpreted as the boolean capture\n// value so we should only pass the `capture` property.\n\nlet eventOptionsSupported = false; // Wrap into an IIFE because MS Edge <= v41 does not support having try/catch\n// blocks right into the body of a module\n\n(() => {\n  try {\n    const options = {\n      get capture() {\n        eventOptionsSupported = true;\n        return false;\n      }\n\n    }; // eslint-disable-next-line @typescript-eslint/no-explicit-any\n\n    window.addEventListener('test', options, options); // eslint-disable-next-line @typescript-eslint/no-explicit-any\n\n    window.removeEventListener('test', options, options);\n  } catch (_e) {// event options not supported\n  }\n})();\n\nclass EventPart {\n  constructor(element, eventName, eventContext) {\n    this.value = undefined;\n    this.__pendingValue = undefined;\n    this.element = element;\n    this.eventName = eventName;\n    this.eventContext = eventContext;\n\n    this.__boundHandleEvent = e => this.handleEvent(e);\n  }\n\n  setValue(value) {\n    this.__pendingValue = value;\n  }\n\n  commit() {\n    while ((0,_directive_js__WEBPACK_IMPORTED_MODULE_0__.isDirective)(this.__pendingValue)) {\n      const directive = this.__pendingValue;\n      this.__pendingValue = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n      directive(this);\n    }\n\n    if (this.__pendingValue === _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange) {\n      return;\n    }\n\n    const newListener = this.__pendingValue;\n    const oldListener = this.value;\n    const shouldRemoveListener = newListener == null || oldListener != null && (newListener.capture !== oldListener.capture || newListener.once !== oldListener.once || newListener.passive !== oldListener.passive);\n    const shouldAddListener = newListener != null && (oldListener == null || shouldRemoveListener);\n\n    if (shouldRemoveListener) {\n      this.element.removeEventListener(this.eventName, this.__boundHandleEvent, this.__options);\n    }\n\n    if (shouldAddListener) {\n      this.__options = getOptions(newListener);\n      this.element.addEventListener(this.eventName, this.__boundHandleEvent, this.__options);\n    }\n\n    this.value = newListener;\n    this.__pendingValue = _part_js__WEBPACK_IMPORTED_MODULE_2__.noChange;\n  }\n\n  handleEvent(event) {\n    if (typeof this.value === 'function') {\n      this.value.call(this.eventContext || this.element, event);\n    } else {\n      this.value.handleEvent(event);\n    }\n  }\n\n} // We copy options because of the inconsistent behavior of browsers when reading\n// the third argument of add/removeEventListener. IE11 doesn't support options\n// at all. Chrome 41 only reads `capture` if the argument is an object.\n\nconst getOptions = o => o && (eventOptionsSupported ? {\n  capture: o.capture,\n  passive: o.passive,\n  once: o.once\n} : o.capture);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/parts.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/render.js":
/*!*********************************************!*\
  !*** ./node_modules/lit-html/lib/render.js ***!
  \*********************************************/
/*! namespace exports */
/*! export parts [provided] [no usage info] [missing usage info prevents renaming] */
/*! export render [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"parts\": () => /* binding */ parts,\n/* harmony export */   \"render\": () => /* binding */ render\n/* harmony export */ });\n/* harmony import */ var _dom_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _parts_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./parts.js */ \"./node_modules/lit-html/lib/parts.js\");\n/* harmony import */ var _template_factory_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./template-factory.js */ \"./node_modules/lit-html/lib/template-factory.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n\n\nconst parts = new WeakMap();\n/**\n * Renders a template result or other value to a container.\n *\n * To update a container with new values, reevaluate the template literal and\n * call `render` with the new result.\n *\n * @param result Any value renderable by NodePart - typically a TemplateResult\n *     created by evaluating a template tag like `html` or `svg`.\n * @param container A DOM parent to render to. The entire contents are either\n *     replaced, or efficiently updated if the same result type was previous\n *     rendered there.\n * @param options RenderOptions for the entire render tree rendered to this\n *     container. Render options must *not* change between renders to the same\n *     container, as those changes will not effect previously rendered DOM.\n */\n\nconst render = (result, container, options) => {\n  let part = parts.get(container);\n\n  if (part === undefined) {\n    (0,_dom_js__WEBPACK_IMPORTED_MODULE_0__.removeNodes)(container, container.firstChild);\n    parts.set(container, part = new _parts_js__WEBPACK_IMPORTED_MODULE_1__.NodePart(Object.assign({\n      templateFactory: _template_factory_js__WEBPACK_IMPORTED_MODULE_2__.templateFactory\n    }, options)));\n    part.appendInto(container);\n  }\n\n  part.setValue(result);\n  part.commit();\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/render.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/shady-render.js":
/*!***************************************************!*\
  !*** ./node_modules/lit-html/lib/shady-render.js ***!
  \***************************************************/
/*! namespace exports */
/*! export TemplateResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-result.js .TemplateResult */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lit-html.js .html */
/*! export render [provided] [no usage info] [missing usage info prevents renaming] */
/*! export shadyTemplateFactory [provided] [no usage info] [missing usage info prevents renaming] */
/*! export svg [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lit-html.js .svg */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"html\": () => /* reexport safe */ _lit_html_js__WEBPACK_IMPORTED_MODULE_6__.html,\n/* harmony export */   \"svg\": () => /* reexport safe */ _lit_html_js__WEBPACK_IMPORTED_MODULE_6__.svg,\n/* harmony export */   \"TemplateResult\": () => /* reexport safe */ _lit_html_js__WEBPACK_IMPORTED_MODULE_6__.TemplateResult,\n/* harmony export */   \"shadyTemplateFactory\": () => /* binding */ shadyTemplateFactory,\n/* harmony export */   \"render\": () => /* binding */ render\n/* harmony export */ });\n/* harmony import */ var _dom_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _modify_template_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./modify-template.js */ \"./node_modules/lit-html/lib/modify-template.js\");\n/* harmony import */ var _render_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./render.js */ \"./node_modules/lit-html/lib/render.js\");\n/* harmony import */ var _template_factory_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./template-factory.js */ \"./node_modules/lit-html/lib/template-factory.js\");\n/* harmony import */ var _template_instance_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./template-instance.js */ \"./node_modules/lit-html/lib/template-instance.js\");\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/* harmony import */ var _lit_html_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../lit-html.js */ \"./node_modules/lit-html/lit-html.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * Module to add shady DOM/shady CSS polyfill support to lit-html template\n * rendering. See the [[render]] method for details.\n *\n * @packageDocumentation\n */\n\n/**\n * Do not remove this comment; it keeps typedoc from misplacing the module\n * docs.\n */\n\n\n\n\n\n\n // Get a key to lookup in `templateCaches`.\n\nconst getTemplateCacheKey = (type, scopeName) => `${type}--${scopeName}`;\n\nlet compatibleShadyCSSVersion = true;\n\nif (typeof window.ShadyCSS === 'undefined') {\n  compatibleShadyCSSVersion = false;\n} else if (typeof window.ShadyCSS.prepareTemplateDom === 'undefined') {\n  console.warn(`Incompatible ShadyCSS version detected. ` + `Please update to at least @webcomponents/webcomponentsjs@2.0.2 and ` + `@webcomponents/shadycss@1.3.1.`);\n  compatibleShadyCSSVersion = false;\n}\n/**\n * Template factory which scopes template DOM using ShadyCSS.\n * @param scopeName {string}\n */\n\n\nconst shadyTemplateFactory = scopeName => result => {\n  const cacheKey = getTemplateCacheKey(result.type, scopeName);\n  let templateCache = _template_factory_js__WEBPACK_IMPORTED_MODULE_3__.templateCaches.get(cacheKey);\n\n  if (templateCache === undefined) {\n    templateCache = {\n      stringsArray: new WeakMap(),\n      keyString: new Map()\n    };\n    _template_factory_js__WEBPACK_IMPORTED_MODULE_3__.templateCaches.set(cacheKey, templateCache);\n  }\n\n  let template = templateCache.stringsArray.get(result.strings);\n\n  if (template !== undefined) {\n    return template;\n  }\n\n  const key = result.strings.join(_template_js__WEBPACK_IMPORTED_MODULE_5__.marker);\n  template = templateCache.keyString.get(key);\n\n  if (template === undefined) {\n    const element = result.getTemplateElement();\n\n    if (compatibleShadyCSSVersion) {\n      window.ShadyCSS.prepareTemplateDom(element, scopeName);\n    }\n\n    template = new _template_js__WEBPACK_IMPORTED_MODULE_5__.Template(result, element);\n    templateCache.keyString.set(key, template);\n  }\n\n  templateCache.stringsArray.set(result.strings, template);\n  return template;\n};\nconst TEMPLATE_TYPES = ['html', 'svg'];\n/**\n * Removes all style elements from Templates for the given scopeName.\n */\n\nconst removeStylesFromLitTemplates = scopeName => {\n  TEMPLATE_TYPES.forEach(type => {\n    const templates = _template_factory_js__WEBPACK_IMPORTED_MODULE_3__.templateCaches.get(getTemplateCacheKey(type, scopeName));\n\n    if (templates !== undefined) {\n      templates.keyString.forEach(template => {\n        const {\n          element: {\n            content\n          }\n        } = template; // IE 11 doesn't support the iterable param Set constructor\n\n        const styles = new Set();\n        Array.from(content.querySelectorAll('style')).forEach(s => {\n          styles.add(s);\n        });\n        (0,_modify_template_js__WEBPACK_IMPORTED_MODULE_1__.removeNodesFromTemplate)(template, styles);\n      });\n    }\n  });\n};\n\nconst shadyRenderSet = new Set();\n/**\n * For the given scope name, ensures that ShadyCSS style scoping is performed.\n * This is done just once per scope name so the fragment and template cannot\n * be modified.\n * (1) extracts styles from the rendered fragment and hands them to ShadyCSS\n * to be scoped and appended to the document\n * (2) removes style elements from all lit-html Templates for this scope name.\n *\n * Note, <style> elements can only be placed into templates for the\n * initial rendering of the scope. If <style> elements are included in templates\n * dynamically rendered to the scope (after the first scope render), they will\n * not be scoped and the <style> will be left in the template and rendered\n * output.\n */\n\nconst prepareTemplateStyles = (scopeName, renderedDOM, template) => {\n  shadyRenderSet.add(scopeName); // If `renderedDOM` is stamped from a Template, then we need to edit that\n  // Template's underlying template element. Otherwise, we create one here\n  // to give to ShadyCSS, which still requires one while scoping.\n\n  const templateElement = !!template ? template.element : document.createElement('template'); // Move styles out of rendered DOM and store.\n\n  const styles = renderedDOM.querySelectorAll('style');\n  const {\n    length\n  } = styles; // If there are no styles, skip unnecessary work\n\n  if (length === 0) {\n    // Ensure prepareTemplateStyles is called to support adding\n    // styles via `prepareAdoptedCssText` since that requires that\n    // `prepareTemplateStyles` is called.\n    //\n    // ShadyCSS will only update styles containing @apply in the template\n    // given to `prepareTemplateStyles`. If no lit Template was given,\n    // ShadyCSS will not be able to update uses of @apply in any relevant\n    // template. However, this is not a problem because we only create the\n    // template for the purpose of supporting `prepareAdoptedCssText`,\n    // which doesn't support @apply at all.\n    window.ShadyCSS.prepareTemplateStyles(templateElement, scopeName);\n    return;\n  }\n\n  const condensedStyle = document.createElement('style'); // Collect styles into a single style. This helps us make sure ShadyCSS\n  // manipulations will not prevent us from being able to fix up template\n  // part indices.\n  // NOTE: collecting styles is inefficient for browsers but ShadyCSS\n  // currently does this anyway. When it does not, this should be changed.\n\n  for (let i = 0; i < length; i++) {\n    const style = styles[i];\n    style.parentNode.removeChild(style);\n    condensedStyle.textContent += style.textContent;\n  } // Remove styles from nested templates in this scope.\n\n\n  removeStylesFromLitTemplates(scopeName); // And then put the condensed style into the \"root\" template passed in as\n  // `template`.\n\n  const content = templateElement.content;\n\n  if (!!template) {\n    (0,_modify_template_js__WEBPACK_IMPORTED_MODULE_1__.insertNodeIntoTemplate)(template, condensedStyle, content.firstChild);\n  } else {\n    content.insertBefore(condensedStyle, content.firstChild);\n  } // Note, it's important that ShadyCSS gets the template that `lit-html`\n  // will actually render so that it can update the style inside when\n  // needed (e.g. @apply native Shadow DOM case).\n\n\n  window.ShadyCSS.prepareTemplateStyles(templateElement, scopeName);\n  const style = content.querySelector('style');\n\n  if (window.ShadyCSS.nativeShadow && style !== null) {\n    // When in native Shadow DOM, ensure the style created by ShadyCSS is\n    // included in initially rendered output (`renderedDOM`).\n    renderedDOM.insertBefore(style.cloneNode(true), renderedDOM.firstChild);\n  } else if (!!template) {\n    // When no style is left in the template, parts will be broken as a\n    // result. To fix this, we put back the style node ShadyCSS removed\n    // and then tell lit to remove that node from the template.\n    // There can be no style in the template in 2 cases (1) when Shady DOM\n    // is in use, ShadyCSS removes all styles, (2) when native Shadow DOM\n    // is in use ShadyCSS removes the style if it contains no content.\n    // NOTE, ShadyCSS creates its own style so we can safely add/remove\n    // `condensedStyle` here.\n    content.insertBefore(condensedStyle, content.firstChild);\n    const removes = new Set();\n    removes.add(condensedStyle);\n    (0,_modify_template_js__WEBPACK_IMPORTED_MODULE_1__.removeNodesFromTemplate)(template, removes);\n  }\n};\n/**\n * Extension to the standard `render` method which supports rendering\n * to ShadowRoots when the ShadyDOM (https://github.com/webcomponents/shadydom)\n * and ShadyCSS (https://github.com/webcomponents/shadycss) polyfills are used\n * or when the webcomponentsjs\n * (https://github.com/webcomponents/webcomponentsjs) polyfill is used.\n *\n * Adds a `scopeName` option which is used to scope element DOM and stylesheets\n * when native ShadowDOM is unavailable. The `scopeName` will be added to\n * the class attribute of all rendered DOM. In addition, any style elements will\n * be automatically re-written with this `scopeName` selector and moved out\n * of the rendered DOM and into the document `<head>`.\n *\n * It is common to use this render method in conjunction with a custom element\n * which renders a shadowRoot. When this is done, typically the element's\n * `localName` should be used as the `scopeName`.\n *\n * In addition to DOM scoping, ShadyCSS also supports a basic shim for css\n * custom properties (needed only on older browsers like IE11) and a shim for\n * a deprecated feature called `@apply` that supports applying a set of css\n * custom properties to a given location.\n *\n * Usage considerations:\n *\n * * Part values in `<style>` elements are only applied the first time a given\n * `scopeName` renders. Subsequent changes to parts in style elements will have\n * no effect. Because of this, parts in style elements should only be used for\n * values that will never change, for example parts that set scope-wide theme\n * values or parts which render shared style elements.\n *\n * * Note, due to a limitation of the ShadyDOM polyfill, rendering in a\n * custom element's `constructor` is not supported. Instead rendering should\n * either done asynchronously, for example at microtask timing (for example\n * `Promise.resolve()`), or be deferred until the first time the element's\n * `connectedCallback` runs.\n *\n * Usage considerations when using shimmed custom properties or `@apply`:\n *\n * * Whenever any dynamic changes are made which affect\n * css custom properties, `ShadyCSS.styleElement(element)` must be called\n * to update the element. There are two cases when this is needed:\n * (1) the element is connected to a new parent, (2) a class is added to the\n * element that causes it to match different custom properties.\n * To address the first case when rendering a custom element, `styleElement`\n * should be called in the element's `connectedCallback`.\n *\n * * Shimmed custom properties may only be defined either for an entire\n * shadowRoot (for example, in a `:host` rule) or via a rule that directly\n * matches an element with a shadowRoot. In other words, instead of flowing from\n * parent to child as do native css custom properties, shimmed custom properties\n * flow only from shadowRoots to nested shadowRoots.\n *\n * * When using `@apply` mixing css shorthand property names with\n * non-shorthand names (for example `border` and `border-width`) is not\n * supported.\n */\n\n\nconst render = (result, container, options) => {\n  if (!options || typeof options !== 'object' || !options.scopeName) {\n    throw new Error('The `scopeName` option is required.');\n  }\n\n  const scopeName = options.scopeName;\n  const hasRendered = _render_js__WEBPACK_IMPORTED_MODULE_2__.parts.has(container);\n  const needsScoping = compatibleShadyCSSVersion && container.nodeType === 11\n  /* Node.DOCUMENT_FRAGMENT_NODE */\n  && !!container.host; // Handle first render to a scope specially...\n\n  const firstScopeRender = needsScoping && !shadyRenderSet.has(scopeName); // On first scope render, render into a fragment; this cannot be a single\n  // fragment that is reused since nested renders can occur synchronously.\n\n  const renderContainer = firstScopeRender ? document.createDocumentFragment() : container;\n  (0,_render_js__WEBPACK_IMPORTED_MODULE_2__.render)(result, renderContainer, Object.assign({\n    templateFactory: shadyTemplateFactory(scopeName)\n  }, options)); // When performing first scope render,\n  // (1) We've rendered into a fragment so that there's a chance to\n  // `prepareTemplateStyles` before sub-elements hit the DOM\n  // (which might cause them to render based on a common pattern of\n  // rendering in a custom element's `connectedCallback`);\n  // (2) Scope the template with ShadyCSS one time only for this scope.\n  // (3) Render the fragment into the container and make sure the\n  // container knows its `part` is the one we just rendered. This ensures\n  // DOM will be re-used on subsequent renders.\n\n  if (firstScopeRender) {\n    const part = _render_js__WEBPACK_IMPORTED_MODULE_2__.parts.get(renderContainer);\n    _render_js__WEBPACK_IMPORTED_MODULE_2__.parts.delete(renderContainer); // ShadyCSS might have style sheets (e.g. from `prepareAdoptedCssText`)\n    // that should apply to `renderContainer` even if the rendered value is\n    // not a TemplateInstance. However, it will only insert scoped styles\n    // into the document if `prepareTemplateStyles` has already been called\n    // for the given scope name.\n\n    const template = part.value instanceof _template_instance_js__WEBPACK_IMPORTED_MODULE_4__.TemplateInstance ? part.value.template : undefined;\n    prepareTemplateStyles(scopeName, renderContainer, template);\n    (0,_dom_js__WEBPACK_IMPORTED_MODULE_0__.removeNodes)(container, container.firstChild);\n    container.appendChild(renderContainer);\n    _render_js__WEBPACK_IMPORTED_MODULE_2__.parts.set(container, part);\n  } // After elements have hit the DOM, update styling if this is the\n  // initial render to this container.\n  // This is needed whenever dynamic changes are made so it would be\n  // safest to do every render; however, this would regress performance\n  // so we leave it up to the user to call `ShadyCSS.styleElement`\n  // for dynamic changes.\n\n\n  if (!hasRendered && needsScoping) {\n    window.ShadyCSS.styleElement(container.host);\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/shady-render.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/template-factory.js":
/*!*******************************************************!*\
  !*** ./node_modules/lit-html/lib/template-factory.js ***!
  \*******************************************************/
/*! namespace exports */
/*! export templateCaches [provided] [no usage info] [missing usage info prevents renaming] */
/*! export templateFactory [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"templateFactory\": () => /* binding */ templateFactory,\n/* harmony export */   \"templateCaches\": () => /* binding */ templateCaches\n/* harmony export */ });\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * The default TemplateFactory which caches Templates keyed on\n * result.type and result.strings.\n */\n\nfunction templateFactory(result) {\n  let templateCache = templateCaches.get(result.type);\n\n  if (templateCache === undefined) {\n    templateCache = {\n      stringsArray: new WeakMap(),\n      keyString: new Map()\n    };\n    templateCaches.set(result.type, templateCache);\n  }\n\n  let template = templateCache.stringsArray.get(result.strings);\n\n  if (template !== undefined) {\n    return template;\n  } // If the TemplateStringsArray is new, generate a key from the strings\n  // This key is shared between all templates with identical content\n\n\n  const key = result.strings.join(_template_js__WEBPACK_IMPORTED_MODULE_0__.marker); // Check if we already have a Template for this key\n\n  template = templateCache.keyString.get(key);\n\n  if (template === undefined) {\n    // If we have not seen this key before, create a new Template\n    template = new _template_js__WEBPACK_IMPORTED_MODULE_0__.Template(result, result.getTemplateElement()); // Cache the Template for this key\n\n    templateCache.keyString.set(key, template);\n  } // Cache all future queries for this TemplateStringsArray\n\n\n  templateCache.stringsArray.set(result.strings, template);\n  return template;\n}\nconst templateCaches = new Map();//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/template-factory.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/template-instance.js":
/*!********************************************************!*\
  !*** ./node_modules/lit-html/lib/template-instance.js ***!
  \********************************************************/
/*! namespace exports */
/*! export TemplateInstance [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"TemplateInstance\": () => /* binding */ TemplateInstance\n/* harmony export */ });\n/* harmony import */ var _dom_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n\n/**\n * An instance of a `Template` that can be attached to the DOM and updated\n * with new values.\n */\n\nclass TemplateInstance {\n  constructor(template, processor, options) {\n    this.__parts = [];\n    this.template = template;\n    this.processor = processor;\n    this.options = options;\n  }\n\n  update(values) {\n    let i = 0;\n\n    for (const part of this.__parts) {\n      if (part !== undefined) {\n        part.setValue(values[i]);\n      }\n\n      i++;\n    }\n\n    for (const part of this.__parts) {\n      if (part !== undefined) {\n        part.commit();\n      }\n    }\n  }\n\n  _clone() {\n    // There are a number of steps in the lifecycle of a template instance's\n    // DOM fragment:\n    //  1. Clone - create the instance fragment\n    //  2. Adopt - adopt into the main document\n    //  3. Process - find part markers and create parts\n    //  4. Upgrade - upgrade custom elements\n    //  5. Update - set node, attribute, property, etc., values\n    //  6. Connect - connect to the document. Optional and outside of this\n    //     method.\n    //\n    // We have a few constraints on the ordering of these steps:\n    //  * We need to upgrade before updating, so that property values will pass\n    //    through any property setters.\n    //  * We would like to process before upgrading so that we're sure that the\n    //    cloned fragment is inert and not disturbed by self-modifying DOM.\n    //  * We want custom elements to upgrade even in disconnected fragments.\n    //\n    // Given these constraints, with full custom elements support we would\n    // prefer the order: Clone, Process, Adopt, Upgrade, Update, Connect\n    //\n    // But Safari does not implement CustomElementRegistry#upgrade, so we\n    // can not implement that order and still have upgrade-before-update and\n    // upgrade disconnected fragments. So we instead sacrifice the\n    // process-before-upgrade constraint, since in Custom Elements v1 elements\n    // must not modify their light DOM in the constructor. We still have issues\n    // when co-existing with CEv0 elements like Polymer 1, and with polyfills\n    // that don't strictly adhere to the no-modification rule because shadow\n    // DOM, which may be created in the constructor, is emulated by being placed\n    // in the light DOM.\n    //\n    // The resulting order is on native is: Clone, Adopt, Upgrade, Process,\n    // Update, Connect. document.importNode() performs Clone, Adopt, and Upgrade\n    // in one step.\n    //\n    // The Custom Elements v1 polyfill supports upgrade(), so the order when\n    // polyfilled is the more ideal: Clone, Process, Adopt, Upgrade, Update,\n    // Connect.\n    const fragment = _dom_js__WEBPACK_IMPORTED_MODULE_0__.isCEPolyfill ? this.template.element.content.cloneNode(true) : document.importNode(this.template.element.content, true);\n    const stack = [];\n    const parts = this.template.parts; // Edge needs all 4 parameters present; IE11 needs 3rd parameter to be null\n\n    const walker = document.createTreeWalker(fragment, 133\n    /* NodeFilter.SHOW_{ELEMENT|COMMENT|TEXT} */\n    , null, false);\n    let partIndex = 0;\n    let nodeIndex = 0;\n    let part;\n    let node = walker.nextNode(); // Loop through all the nodes and parts of a template\n\n    while (partIndex < parts.length) {\n      part = parts[partIndex];\n\n      if (!(0,_template_js__WEBPACK_IMPORTED_MODULE_1__.isTemplatePartActive)(part)) {\n        this.__parts.push(undefined);\n\n        partIndex++;\n        continue;\n      } // Progress the tree walker until we find our next part's node.\n      // Note that multiple parts may share the same node (attribute parts\n      // on a single element), so this loop may not run at all.\n\n\n      while (nodeIndex < part.index) {\n        nodeIndex++;\n\n        if (node.nodeName === 'TEMPLATE') {\n          stack.push(node);\n          walker.currentNode = node.content;\n        }\n\n        if ((node = walker.nextNode()) === null) {\n          // We've exhausted the content inside a nested template element.\n          // Because we still have parts (the outer for-loop), we know:\n          // - There is a template in the stack\n          // - The walker will find a nextNode outside the template\n          walker.currentNode = stack.pop();\n          node = walker.nextNode();\n        }\n      } // We've arrived at our part's node.\n\n\n      if (part.type === 'node') {\n        const part = this.processor.handleTextExpression(this.options);\n        part.insertAfterNode(node.previousSibling);\n\n        this.__parts.push(part);\n      } else {\n        this.__parts.push(...this.processor.handleAttributeExpressions(node, part.name, part.strings, this.options));\n      }\n\n      partIndex++;\n    }\n\n    if (_dom_js__WEBPACK_IMPORTED_MODULE_0__.isCEPolyfill) {\n      document.adoptNode(fragment);\n      customElements.upgrade(fragment);\n    }\n\n    return fragment;\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/template-instance.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/template-result.js":
/*!******************************************************!*\
  !*** ./node_modules/lit-html/lib/template-result.js ***!
  \******************************************************/
/*! namespace exports */
/*! export SVGTemplateResult [provided] [no usage info] [missing usage info prevents renaming] */
/*! export TemplateResult [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"TemplateResult\": () => /* binding */ TemplateResult,\n/* harmony export */   \"SVGTemplateResult\": () => /* binding */ SVGTemplateResult\n/* harmony export */ });\n/* harmony import */ var _dom_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * @module lit-html\n */\n\n\n/**\n * Our TrustedTypePolicy for HTML which is declared using the html template\n * tag function.\n *\n * That HTML is a developer-authored constant, and is parsed with innerHTML\n * before any untrusted expressions have been mixed in. Therefor it is\n * considered safe by construction.\n */\n\nconst policy = window.trustedTypes && trustedTypes.createPolicy('lit-html', {\n  createHTML: s => s\n});\nconst commentMarker = ` ${_template_js__WEBPACK_IMPORTED_MODULE_1__.marker} `;\n/**\n * The return type of `html`, which holds a Template and the values from\n * interpolated expressions.\n */\n\nclass TemplateResult {\n  constructor(strings, values, type, processor) {\n    this.strings = strings;\n    this.values = values;\n    this.type = type;\n    this.processor = processor;\n  }\n  /**\n   * Returns a string of HTML used to create a `<template>` element.\n   */\n\n\n  getHTML() {\n    const l = this.strings.length - 1;\n    let html = '';\n    let isCommentBinding = false;\n\n    for (let i = 0; i < l; i++) {\n      const s = this.strings[i]; // For each binding we want to determine the kind of marker to insert\n      // into the template source before it's parsed by the browser's HTML\n      // parser. The marker type is based on whether the expression is in an\n      // attribute, text, or comment position.\n      //   * For node-position bindings we insert a comment with the marker\n      //     sentinel as its text content, like <!--{{lit-guid}}-->.\n      //   * For attribute bindings we insert just the marker sentinel for the\n      //     first binding, so that we support unquoted attribute bindings.\n      //     Subsequent bindings can use a comment marker because multi-binding\n      //     attributes must be quoted.\n      //   * For comment bindings we insert just the marker sentinel so we don't\n      //     close the comment.\n      //\n      // The following code scans the template source, but is *not* an HTML\n      // parser. We don't need to track the tree structure of the HTML, only\n      // whether a binding is inside a comment, and if not, if it appears to be\n      // the first binding in an attribute.\n\n      const commentOpen = s.lastIndexOf('<!--'); // We're in comment position if we have a comment open with no following\n      // comment close. Because <-- can appear in an attribute value there can\n      // be false positives.\n\n      isCommentBinding = (commentOpen > -1 || isCommentBinding) && s.indexOf('-->', commentOpen + 1) === -1; // Check to see if we have an attribute-like sequence preceding the\n      // expression. This can match \"name=value\" like structures in text,\n      // comments, and attribute values, so there can be false-positives.\n\n      const attributeMatch = _template_js__WEBPACK_IMPORTED_MODULE_1__.lastAttributeNameRegex.exec(s);\n\n      if (attributeMatch === null) {\n        // We're only in this branch if we don't have a attribute-like\n        // preceding sequence. For comments, this guards against unusual\n        // attribute values like <div foo=\"<!--${'bar'}\">. Cases like\n        // <!-- foo=${'bar'}--> are handled correctly in the attribute branch\n        // below.\n        html += s + (isCommentBinding ? commentMarker : _template_js__WEBPACK_IMPORTED_MODULE_1__.nodeMarker);\n      } else {\n        // For attributes we use just a marker sentinel, and also append a\n        // $lit$ suffix to the name to opt-out of attribute-specific parsing\n        // that IE and Edge do for style and certain SVG attributes.\n        html += s.substr(0, attributeMatch.index) + attributeMatch[1] + attributeMatch[2] + _template_js__WEBPACK_IMPORTED_MODULE_1__.boundAttributeSuffix + attributeMatch[3] + _template_js__WEBPACK_IMPORTED_MODULE_1__.marker;\n      }\n    }\n\n    html += this.strings[l];\n    return html;\n  }\n\n  getTemplateElement() {\n    const template = document.createElement('template');\n    let value = this.getHTML();\n\n    if (policy !== undefined) {\n      // this is secure because `this.strings` is a TemplateStringsArray.\n      // TODO: validate this when\n      // https://github.com/tc39/proposal-array-is-template-object is\n      // implemented.\n      value = policy.createHTML(value);\n    }\n\n    template.innerHTML = value;\n    return template;\n  }\n\n}\n/**\n * A TemplateResult for SVG fragments.\n *\n * This class wraps HTML in an `<svg>` tag in order to parse its contents in the\n * SVG namespace, then modifies the template to remove the `<svg>` tag so that\n * clones only container the original fragment.\n */\n\nclass SVGTemplateResult extends TemplateResult {\n  getHTML() {\n    return `<svg>${super.getHTML()}</svg>`;\n  }\n\n  getTemplateElement() {\n    const template = super.getTemplateElement();\n    const content = template.content;\n    const svgElement = content.firstChild;\n    content.removeChild(svgElement);\n    (0,_dom_js__WEBPACK_IMPORTED_MODULE_0__.reparentNodes)(content, svgElement.firstChild);\n    return template;\n  }\n\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/template-result.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lib/template.js":
/*!***********************************************!*\
  !*** ./node_modules/lit-html/lib/template.js ***!
  \***********************************************/
/*! namespace exports */
/*! export Template [provided] [no usage info] [missing usage info prevents renaming] */
/*! export boundAttributeSuffix [provided] [no usage info] [missing usage info prevents renaming] */
/*! export createMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isTemplatePartActive [provided] [no usage info] [missing usage info prevents renaming] */
/*! export lastAttributeNameRegex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export marker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export markerRegex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export nodeMarker [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"marker\": () => /* binding */ marker,\n/* harmony export */   \"nodeMarker\": () => /* binding */ nodeMarker,\n/* harmony export */   \"markerRegex\": () => /* binding */ markerRegex,\n/* harmony export */   \"boundAttributeSuffix\": () => /* binding */ boundAttributeSuffix,\n/* harmony export */   \"Template\": () => /* binding */ Template,\n/* harmony export */   \"isTemplatePartActive\": () => /* binding */ isTemplatePartActive,\n/* harmony export */   \"createMarker\": () => /* binding */ createMarker,\n/* harmony export */   \"lastAttributeNameRegex\": () => /* binding */ lastAttributeNameRegex\n/* harmony export */ });\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * An expression marker with embedded unique key to avoid collision with\n * possible text in templates.\n */\nconst marker = `{{lit-${String(Math.random()).slice(2)}}}`;\n/**\n * An expression marker used text-positions, multi-binding attributes, and\n * attributes with markup-like text values.\n */\n\nconst nodeMarker = `<!--${marker}-->`;\nconst markerRegex = new RegExp(`${marker}|${nodeMarker}`);\n/**\n * Suffix appended to all bound attribute names.\n */\n\nconst boundAttributeSuffix = '$lit$';\n/**\n * An updatable Template that tracks the location of dynamic parts.\n */\n\nclass Template {\n  constructor(result, element) {\n    this.parts = [];\n    this.element = element;\n    const nodesToRemove = [];\n    const stack = []; // Edge needs all 4 parameters present; IE11 needs 3rd parameter to be null\n\n    const walker = document.createTreeWalker(element.content, 133\n    /* NodeFilter.SHOW_{ELEMENT|COMMENT|TEXT} */\n    , null, false); // Keeps track of the last index associated with a part. We try to delete\n    // unnecessary nodes, but we never want to associate two different parts\n    // to the same index. They must have a constant node between.\n\n    let lastPartIndex = 0;\n    let index = -1;\n    let partIndex = 0;\n    const {\n      strings,\n      values: {\n        length\n      }\n    } = result;\n\n    while (partIndex < length) {\n      const node = walker.nextNode();\n\n      if (node === null) {\n        // We've exhausted the content inside a nested template element.\n        // Because we still have parts (the outer for-loop), we know:\n        // - There is a template in the stack\n        // - The walker will find a nextNode outside the template\n        walker.currentNode = stack.pop();\n        continue;\n      }\n\n      index++;\n\n      if (node.nodeType === 1\n      /* Node.ELEMENT_NODE */\n      ) {\n          if (node.hasAttributes()) {\n            const attributes = node.attributes;\n            const {\n              length\n            } = attributes; // Per\n            // https://developer.mozilla.org/en-US/docs/Web/API/NamedNodeMap,\n            // attributes are not guaranteed to be returned in document order.\n            // In particular, Edge/IE can return them out of order, so we cannot\n            // assume a correspondence between part index and attribute index.\n\n            let count = 0;\n\n            for (let i = 0; i < length; i++) {\n              if (endsWith(attributes[i].name, boundAttributeSuffix)) {\n                count++;\n              }\n            }\n\n            while (count-- > 0) {\n              // Get the template literal section leading up to the first\n              // expression in this attribute\n              const stringForPart = strings[partIndex]; // Find the attribute name\n\n              const name = lastAttributeNameRegex.exec(stringForPart)[2]; // Find the corresponding attribute\n              // All bound attributes have had a suffix added in\n              // TemplateResult#getHTML to opt out of special attribute\n              // handling. To look up the attribute value we also need to add\n              // the suffix.\n\n              const attributeLookupName = name.toLowerCase() + boundAttributeSuffix;\n              const attributeValue = node.getAttribute(attributeLookupName);\n              node.removeAttribute(attributeLookupName);\n              const statics = attributeValue.split(markerRegex);\n              this.parts.push({\n                type: 'attribute',\n                index,\n                name,\n                strings: statics\n              });\n              partIndex += statics.length - 1;\n            }\n          }\n\n          if (node.tagName === 'TEMPLATE') {\n            stack.push(node);\n            walker.currentNode = node.content;\n          }\n        } else if (node.nodeType === 3\n      /* Node.TEXT_NODE */\n      ) {\n          const data = node.data;\n\n          if (data.indexOf(marker) >= 0) {\n            const parent = node.parentNode;\n            const strings = data.split(markerRegex);\n            const lastIndex = strings.length - 1; // Generate a new text node for each literal section\n            // These nodes are also used as the markers for node parts\n\n            for (let i = 0; i < lastIndex; i++) {\n              let insert;\n              let s = strings[i];\n\n              if (s === '') {\n                insert = createMarker();\n              } else {\n                const match = lastAttributeNameRegex.exec(s);\n\n                if (match !== null && endsWith(match[2], boundAttributeSuffix)) {\n                  s = s.slice(0, match.index) + match[1] + match[2].slice(0, -boundAttributeSuffix.length) + match[3];\n                }\n\n                insert = document.createTextNode(s);\n              }\n\n              parent.insertBefore(insert, node);\n              this.parts.push({\n                type: 'node',\n                index: ++index\n              });\n            } // If there's no text, we must insert a comment to mark our place.\n            // Else, we can trust it will stick around after cloning.\n\n\n            if (strings[lastIndex] === '') {\n              parent.insertBefore(createMarker(), node);\n              nodesToRemove.push(node);\n            } else {\n              node.data = strings[lastIndex];\n            } // We have a part for each match found\n\n\n            partIndex += lastIndex;\n          }\n        } else if (node.nodeType === 8\n      /* Node.COMMENT_NODE */\n      ) {\n          if (node.data === marker) {\n            const parent = node.parentNode; // Add a new marker node to be the startNode of the Part if any of\n            // the following are true:\n            //  * We don't have a previousSibling\n            //  * The previousSibling is already the start of a previous part\n\n            if (node.previousSibling === null || index === lastPartIndex) {\n              index++;\n              parent.insertBefore(createMarker(), node);\n            }\n\n            lastPartIndex = index;\n            this.parts.push({\n              type: 'node',\n              index\n            }); // If we don't have a nextSibling, keep this node so we have an end.\n            // Else, we can remove it to save future costs.\n\n            if (node.nextSibling === null) {\n              node.data = '';\n            } else {\n              nodesToRemove.push(node);\n              index--;\n            }\n\n            partIndex++;\n          } else {\n            let i = -1;\n\n            while ((i = node.data.indexOf(marker, i + 1)) !== -1) {\n              // Comment node has a binding marker inside, make an inactive part\n              // The binding won't work, but subsequent bindings will\n              // TODO (justinfagnani): consider whether it's even worth it to\n              // make bindings in comments work\n              this.parts.push({\n                type: 'node',\n                index: -1\n              });\n              partIndex++;\n            }\n          }\n        }\n    } // Remove text binding nodes after the walk to not disturb the TreeWalker\n\n\n    for (const n of nodesToRemove) {\n      n.parentNode.removeChild(n);\n    }\n  }\n\n}\n\nconst endsWith = (str, suffix) => {\n  const index = str.length - suffix.length;\n  return index >= 0 && str.slice(index) === suffix;\n};\n\nconst isTemplatePartActive = part => part.index !== -1; // Allows `document.createComment('')` to be renamed for a\n// small manual size-savings.\n\nconst createMarker = () => document.createComment('');\n/**\n * This regex extracts the attribute name preceding an attribute-position\n * expression. It does this by matching the syntax allowed for attributes\n * against the string literal directly preceding the expression, assuming that\n * the expression is in an attribute-value position.\n *\n * See attributes in the HTML spec:\n * https://www.w3.org/TR/html5/syntax.html#elements-attributes\n *\n * \" \\x09\\x0a\\x0c\\x0d\" are HTML space characters:\n * https://www.w3.org/TR/html5/infrastructure.html#space-characters\n *\n * \"\\0-\\x1F\\x7F-\\x9F\" are Unicode control characters, which includes every\n * space character except \" \".\n *\n * So an attribute is:\n *  * The name: any character except a control character, space character, ('),\n *    (\"), \">\", \"=\", or \"/\"\n *  * Followed by zero or more space characters\n *  * Followed by \"=\"\n *  * Followed by zero or more space characters\n *  * Followed by:\n *    * Any character except space, ('), (\"), \"<\", \">\", \"=\", (`), or\n *    * (\") then any non-(\"), or\n *    * (') then any non-(')\n */\n\nconst lastAttributeNameRegex = // eslint-disable-next-line no-control-regex\n/([ \\x09\\x0a\\x0c\\x0d])([^\\0-\\x1F\\x7F-\\x9F \"'>=/]+)([ \\x09\\x0a\\x0c\\x0d]*=[ \\x09\\x0a\\x0c\\x0d]*(?:[^ \\x09\\x0a\\x0c\\x0d\"'`<>=]*|\"[^\"]*|'[^']*))$/;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lib/template.js\n");

/***/ }),

/***/ "./node_modules/lit-html/lit-html.js":
/*!*******************************************!*\
  !*** ./node_modules/lit-html/lit-html.js ***!
  \*******************************************/
/*! namespace exports */
/*! export AttributeCommitter [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .AttributeCommitter */
/*! export AttributePart [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .AttributePart */
/*! export BooleanAttributePart [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .BooleanAttributePart */
/*! export DefaultTemplateProcessor [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/default-template-processor.js .DefaultTemplateProcessor */
/*! export EventPart [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .EventPart */
/*! export NodePart [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .NodePart */
/*! export PropertyCommitter [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .PropertyCommitter */
/*! export PropertyPart [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .PropertyPart */
/*! export SVGTemplateResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-result.js .SVGTemplateResult */
/*! export Template [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template.js .Template */
/*! export TemplateInstance [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-instance.js .TemplateInstance */
/*! export TemplateResult [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-result.js .TemplateResult */
/*! export createMarker [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template.js .createMarker */
/*! export defaultTemplateProcessor [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/default-template-processor.js .defaultTemplateProcessor */
/*! export directive [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/directive.js .directive */
/*! export html [provided] [no usage info] [missing usage info prevents renaming] */
/*! export isDirective [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/directive.js .isDirective */
/*! export isIterable [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .isIterable */
/*! export isPrimitive [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/parts.js .isPrimitive */
/*! export isTemplatePartActive [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template.js .isTemplatePartActive */
/*! export noChange [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/part.js .noChange */
/*! export nothing [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/part.js .nothing */
/*! export parts [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/render.js .parts */
/*! export removeNodes [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/dom.js .removeNodes */
/*! export render [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/render.js .render */
/*! export reparentNodes [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/dom.js .reparentNodes */
/*! export svg [provided] [no usage info] [missing usage info prevents renaming] */
/*! export templateCaches [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-factory.js .templateCaches */
/*! export templateFactory [provided] [no usage info] [missing usage info prevents renaming] -> ./node_modules/lit-html/lib/template-factory.js .templateFactory */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.d, __webpack_require__.r, __webpack_require__.* */
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DefaultTemplateProcessor\": () => /* reexport safe */ _lib_default_template_processor_js__WEBPACK_IMPORTED_MODULE_0__.DefaultTemplateProcessor,\n/* harmony export */   \"defaultTemplateProcessor\": () => /* reexport safe */ _lib_default_template_processor_js__WEBPACK_IMPORTED_MODULE_0__.defaultTemplateProcessor,\n/* harmony export */   \"directive\": () => /* reexport safe */ _lib_directive_js__WEBPACK_IMPORTED_MODULE_2__.directive,\n/* harmony export */   \"isDirective\": () => /* reexport safe */ _lib_directive_js__WEBPACK_IMPORTED_MODULE_2__.isDirective,\n/* harmony export */   \"removeNodes\": () => /* reexport safe */ _lib_dom_js__WEBPACK_IMPORTED_MODULE_3__.removeNodes,\n/* harmony export */   \"reparentNodes\": () => /* reexport safe */ _lib_dom_js__WEBPACK_IMPORTED_MODULE_3__.reparentNodes,\n/* harmony export */   \"noChange\": () => /* reexport safe */ _lib_part_js__WEBPACK_IMPORTED_MODULE_4__.noChange,\n/* harmony export */   \"nothing\": () => /* reexport safe */ _lib_part_js__WEBPACK_IMPORTED_MODULE_4__.nothing,\n/* harmony export */   \"AttributeCommitter\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.AttributeCommitter,\n/* harmony export */   \"AttributePart\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.AttributePart,\n/* harmony export */   \"BooleanAttributePart\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.BooleanAttributePart,\n/* harmony export */   \"EventPart\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.EventPart,\n/* harmony export */   \"isIterable\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.isIterable,\n/* harmony export */   \"isPrimitive\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.isPrimitive,\n/* harmony export */   \"NodePart\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.NodePart,\n/* harmony export */   \"PropertyCommitter\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.PropertyCommitter,\n/* harmony export */   \"PropertyPart\": () => /* reexport safe */ _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__.PropertyPart,\n/* harmony export */   \"parts\": () => /* reexport safe */ _lib_render_js__WEBPACK_IMPORTED_MODULE_6__.parts,\n/* harmony export */   \"render\": () => /* reexport safe */ _lib_render_js__WEBPACK_IMPORTED_MODULE_6__.render,\n/* harmony export */   \"templateCaches\": () => /* reexport safe */ _lib_template_factory_js__WEBPACK_IMPORTED_MODULE_7__.templateCaches,\n/* harmony export */   \"templateFactory\": () => /* reexport safe */ _lib_template_factory_js__WEBPACK_IMPORTED_MODULE_7__.templateFactory,\n/* harmony export */   \"TemplateInstance\": () => /* reexport safe */ _lib_template_instance_js__WEBPACK_IMPORTED_MODULE_8__.TemplateInstance,\n/* harmony export */   \"SVGTemplateResult\": () => /* reexport safe */ _lib_template_result_js__WEBPACK_IMPORTED_MODULE_1__.SVGTemplateResult,\n/* harmony export */   \"TemplateResult\": () => /* reexport safe */ _lib_template_result_js__WEBPACK_IMPORTED_MODULE_1__.TemplateResult,\n/* harmony export */   \"createMarker\": () => /* reexport safe */ _lib_template_js__WEBPACK_IMPORTED_MODULE_9__.createMarker,\n/* harmony export */   \"isTemplatePartActive\": () => /* reexport safe */ _lib_template_js__WEBPACK_IMPORTED_MODULE_9__.isTemplatePartActive,\n/* harmony export */   \"Template\": () => /* reexport safe */ _lib_template_js__WEBPACK_IMPORTED_MODULE_9__.Template,\n/* harmony export */   \"html\": () => /* binding */ html,\n/* harmony export */   \"svg\": () => /* binding */ svg\n/* harmony export */ });\n/* harmony import */ var _lib_default_template_processor_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./lib/default-template-processor.js */ \"./node_modules/lit-html/lib/default-template-processor.js\");\n/* harmony import */ var _lib_template_result_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./lib/template-result.js */ \"./node_modules/lit-html/lib/template-result.js\");\n/* harmony import */ var _lib_directive_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lib/directive.js */ \"./node_modules/lit-html/lib/directive.js\");\n/* harmony import */ var _lib_dom_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./lib/dom.js */ \"./node_modules/lit-html/lib/dom.js\");\n/* harmony import */ var _lib_part_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./lib/part.js */ \"./node_modules/lit-html/lib/part.js\");\n/* harmony import */ var _lib_parts_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./lib/parts.js */ \"./node_modules/lit-html/lib/parts.js\");\n/* harmony import */ var _lib_render_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./lib/render.js */ \"./node_modules/lit-html/lib/render.js\");\n/* harmony import */ var _lib_template_factory_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./lib/template-factory.js */ \"./node_modules/lit-html/lib/template-factory.js\");\n/* harmony import */ var _lib_template_instance_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./lib/template-instance.js */ \"./node_modules/lit-html/lib/template-instance.js\");\n/* harmony import */ var _lib_template_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./lib/template.js */ \"./node_modules/lit-html/lib/template.js\");\n/**\n * @license\n * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at\n * http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at\n * http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at\n * http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at\n * http://polymer.github.io/PATENTS.txt\n */\n\n/**\n *\n * Main lit-html module.\n *\n * Main exports:\n *\n * -  [[html]]\n * -  [[svg]]\n * -  [[render]]\n *\n * @packageDocumentation\n */\n\n/**\n * Do not remove this comment; it keeps typedoc from misplacing the module\n * docs.\n */\n\n\n\n // TODO(justinfagnani): remove line when we get NodePart moving methods\n\n\n\n\n\n\n\n\n // IMPORTANT: do not change the property name or the assignment expression.\n// This line will be used in regexes to search for lit-html usage.\n// TODO(justinfagnani): inject version number at build time\n\nif (typeof window !== 'undefined') {\n  (window['litHtmlVersions'] || (window['litHtmlVersions'] = [])).push('1.3.0');\n}\n/**\n * Interprets a template literal as an HTML template that can efficiently\n * render to and update a container.\n */\n\n\nconst html = (strings, ...values) => new _lib_template_result_js__WEBPACK_IMPORTED_MODULE_1__.TemplateResult(strings, values, 'html', _lib_default_template_processor_js__WEBPACK_IMPORTED_MODULE_0__.defaultTemplateProcessor);\n/**\n * Interprets a template literal as an SVG template that can efficiently\n * render to and update a container.\n */\n\nconst svg = (strings, ...values) => new _lib_template_result_js__WEBPACK_IMPORTED_MODULE_1__.SVGTemplateResult(strings, values, 'svg', _lib_default_template_processor_js__WEBPACK_IMPORTED_MODULE_0__.defaultTemplateProcessor);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/lit-html/lit-html.js\n");

/***/ }),

/***/ "./node_modules/memoize-one/dist/memoize-one.esm.js":
/*!**********************************************************!*\
  !*** ./node_modules/memoize-one/dist/memoize-one.esm.js ***!
  \**********************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\nvar shallowEqual = function shallowEqual(newValue, oldValue) {\n  return newValue === oldValue;\n};\n\nvar simpleIsEqual = function simpleIsEqual(newArgs, lastArgs) {\n  return newArgs.length === lastArgs.length && newArgs.every(function (newArg, index) {\n    return shallowEqual(newArg, lastArgs[index]);\n  });\n};\n\nfunction index(resultFn, isEqual) {\n  if (isEqual === void 0) {\n    isEqual = simpleIsEqual;\n  }\n\n  var lastThis;\n  var lastArgs = [];\n  var lastResult;\n  var calledOnce = false;\n\n  var result = function result() {\n    for (var _len = arguments.length, newArgs = new Array(_len), _key = 0; _key < _len; _key++) {\n      newArgs[_key] = arguments[_key];\n    }\n\n    if (calledOnce && lastThis === this && isEqual(newArgs, lastArgs)) {\n      return lastResult;\n    }\n\n    lastResult = resultFn.apply(this, newArgs);\n    calledOnce = true;\n    lastThis = this;\n    lastArgs = newArgs;\n    return lastResult;\n  };\n\n  return result;\n}\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (index);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9ub2RlX21vZHVsZXMvbWVtb2l6ZS1vbmUvZGlzdC9tZW1vaXplLW9uZS5lc20uanMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL25vZGVfbW9kdWxlcy9tZW1vaXplLW9uZS9kaXN0L21lbW9pemUtb25lLmVzbS5qcz81YjBhIl0sInNvdXJjZXNDb250ZW50IjpbInZhciBzaGFsbG93RXF1YWwgPSBmdW5jdGlvbiBzaGFsbG93RXF1YWwobmV3VmFsdWUsIG9sZFZhbHVlKSB7XG4gIHJldHVybiBuZXdWYWx1ZSA9PT0gb2xkVmFsdWU7XG59O1xuXG52YXIgc2ltcGxlSXNFcXVhbCA9IGZ1bmN0aW9uIHNpbXBsZUlzRXF1YWwobmV3QXJncywgbGFzdEFyZ3MpIHtcbiAgcmV0dXJuIG5ld0FyZ3MubGVuZ3RoID09PSBsYXN0QXJncy5sZW5ndGggJiYgbmV3QXJncy5ldmVyeShmdW5jdGlvbiAobmV3QXJnLCBpbmRleCkge1xuICAgIHJldHVybiBzaGFsbG93RXF1YWwobmV3QXJnLCBsYXN0QXJnc1tpbmRleF0pO1xuICB9KTtcbn07XG5cbmZ1bmN0aW9uIGluZGV4IChyZXN1bHRGbiwgaXNFcXVhbCkge1xuICBpZiAoaXNFcXVhbCA9PT0gdm9pZCAwKSB7XG4gICAgaXNFcXVhbCA9IHNpbXBsZUlzRXF1YWw7XG4gIH1cblxuICB2YXIgbGFzdFRoaXM7XG4gIHZhciBsYXN0QXJncyA9IFtdO1xuICB2YXIgbGFzdFJlc3VsdDtcbiAgdmFyIGNhbGxlZE9uY2UgPSBmYWxzZTtcblxuICB2YXIgcmVzdWx0ID0gZnVuY3Rpb24gcmVzdWx0KCkge1xuICAgIGZvciAodmFyIF9sZW4gPSBhcmd1bWVudHMubGVuZ3RoLCBuZXdBcmdzID0gbmV3IEFycmF5KF9sZW4pLCBfa2V5ID0gMDsgX2tleSA8IF9sZW47IF9rZXkrKykge1xuICAgICAgbmV3QXJnc1tfa2V5XSA9IGFyZ3VtZW50c1tfa2V5XTtcbiAgICB9XG5cbiAgICBpZiAoY2FsbGVkT25jZSAmJiBsYXN0VGhpcyA9PT0gdGhpcyAmJiBpc0VxdWFsKG5ld0FyZ3MsIGxhc3RBcmdzKSkge1xuICAgICAgcmV0dXJuIGxhc3RSZXN1bHQ7XG4gICAgfVxuXG4gICAgbGFzdFJlc3VsdCA9IHJlc3VsdEZuLmFwcGx5KHRoaXMsIG5ld0FyZ3MpO1xuICAgIGNhbGxlZE9uY2UgPSB0cnVlO1xuICAgIGxhc3RUaGlzID0gdGhpcztcbiAgICBsYXN0QXJncyA9IG5ld0FyZ3M7XG4gICAgcmV0dXJuIGxhc3RSZXN1bHQ7XG4gIH07XG5cbiAgcmV0dXJuIHJlc3VsdDtcbn1cblxuZXhwb3J0IGRlZmF1bHQgaW5kZXg7XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./node_modules/memoize-one/dist/memoize-one.esm.js\n");

/***/ }),

/***/ "./node_modules/tinykeys/dist/tinykeys.module.js":
/*!*******************************************************!*\
  !*** ./node_modules/tinykeys/dist/tinykeys.module.js ***!
  \*******************************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => /* export default binding */ __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\nvar e = [\"Shift\", \"Meta\", \"Alt\", \"Control\"],\n    t = \"object\" == typeof navigator && /Mac|iPod|iPhone|iPad/.test(navigator.platform) ? \"Meta\" : \"Control\";\n/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(n, o) {\n  var r = Object.keys(o).map(function (e) {\n    return [(n = e, n.trim().split(\" \").map(function (e) {\n      var n = e.split(\"+\"),\n          o = n.pop();\n      return [n = n.map(function (e) {\n        return \"$mod\" === e ? t : e;\n      }), o];\n    })), o[e]];\n    var n;\n  }),\n      i = new Map(),\n      a = null,\n      u = function (t) {\n    t instanceof KeyboardEvent && (r.forEach(function (n) {\n      var o = n[0],\n          r = n[1],\n          a = i.get(o) || o;\n      !function (t, n) {\n        return !(n[1].toUpperCase() !== t.key.toUpperCase() && n[1] !== t.code || n[0].find(function (e) {\n          return !t.getModifierState(e);\n        }) || e.find(function (e) {\n          return !n[0].includes(e) && n[1] !== e && t.getModifierState(e);\n        }));\n      }(t, a[0]) ? t.getModifierState(t.key) || i.delete(o) : a.length > 1 ? i.set(o, a.slice(1)) : (i.delete(o), r(t));\n    }), a && clearTimeout(a), a = setTimeout(i.clear.bind(i), 1e3));\n  };\n\n  return n.addEventListener(\"keydown\", u), function () {\n    n.removeEventListener(\"keydown\", u);\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/tinykeys/dist/tinykeys.module.js\n");

/***/ }),

/***/ "./node_modules/tslib/tslib.es6.js":
/*!*****************************************!*\
  !*** ./node_modules/tslib/tslib.es6.js ***!
  \*****************************************/
/*! namespace exports */
/*! export __assign [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __asyncDelegator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __asyncGenerator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __asyncValues [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __await [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __awaiter [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __decorate [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __exportStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __extends [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __generator [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __importDefault [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __importStar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __makeTemplateObject [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __metadata [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __param [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __read [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __rest [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __spread [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __spreadArrays [provided] [no usage info] [missing usage info prevents renaming] */
/*! export __values [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"__extends\": () => /* binding */ __extends,\n/* harmony export */   \"__assign\": () => /* binding */ __assign,\n/* harmony export */   \"__rest\": () => /* binding */ __rest,\n/* harmony export */   \"__decorate\": () => /* binding */ __decorate,\n/* harmony export */   \"__param\": () => /* binding */ __param,\n/* harmony export */   \"__metadata\": () => /* binding */ __metadata,\n/* harmony export */   \"__awaiter\": () => /* binding */ __awaiter,\n/* harmony export */   \"__generator\": () => /* binding */ __generator,\n/* harmony export */   \"__exportStar\": () => /* binding */ __exportStar,\n/* harmony export */   \"__values\": () => /* binding */ __values,\n/* harmony export */   \"__read\": () => /* binding */ __read,\n/* harmony export */   \"__spread\": () => /* binding */ __spread,\n/* harmony export */   \"__spreadArrays\": () => /* binding */ __spreadArrays,\n/* harmony export */   \"__await\": () => /* binding */ __await,\n/* harmony export */   \"__asyncGenerator\": () => /* binding */ __asyncGenerator,\n/* harmony export */   \"__asyncDelegator\": () => /* binding */ __asyncDelegator,\n/* harmony export */   \"__asyncValues\": () => /* binding */ __asyncValues,\n/* harmony export */   \"__makeTemplateObject\": () => /* binding */ __makeTemplateObject,\n/* harmony export */   \"__importStar\": () => /* binding */ __importStar,\n/* harmony export */   \"__importDefault\": () => /* binding */ __importDefault\n/* harmony export */ });\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation. All rights reserved.\r\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use\r\nthis file except in compliance with the License. You may obtain a copy of the\r\nLicense at http://www.apache.org/licenses/LICENSE-2.0\r\n\r\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\r\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\r\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\r\nMERCHANTABLITY OR NON-INFRINGEMENT.\r\n\r\nSee the Apache Version 2.0 License for specific language governing permissions\r\nand limitations under the License.\r\n***************************************************************************** */\n\n/* global Reflect, Promise */\nvar extendStatics = function (d, b) {\n  extendStatics = Object.setPrototypeOf || {\n    __proto__: []\n  } instanceof Array && function (d, b) {\n    d.__proto__ = b;\n  } || function (d, b) {\n    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];\n  };\n\n  return extendStatics(d, b);\n};\n\nfunction __extends(d, b) {\n  extendStatics(d, b);\n\n  function __() {\n    this.constructor = d;\n  }\n\n  d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n}\nvar __assign = function () {\n  __assign = Object.assign || function __assign(t) {\n    for (var s, i = 1, n = arguments.length; i < n; i++) {\n      s = arguments[i];\n\n      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\n    }\n\n    return t;\n  };\n\n  return __assign.apply(this, arguments);\n};\nfunction __rest(s, e) {\n  var t = {};\n\n  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];\n\n  if (s != null && typeof Object.getOwnPropertySymbols === \"function\") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {\n    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];\n  }\n  return t;\n}\nfunction __decorate(decorators, target, key, desc) {\n  var c = arguments.length,\n      r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc,\n      d;\n  if (typeof Reflect === \"object\" && typeof Reflect.decorate === \"function\") r = Reflect.decorate(decorators, target, key, desc);else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;\n  return c > 3 && r && Object.defineProperty(target, key, r), r;\n}\nfunction __param(paramIndex, decorator) {\n  return function (target, key) {\n    decorator(target, key, paramIndex);\n  };\n}\nfunction __metadata(metadataKey, metadataValue) {\n  if (typeof Reflect === \"object\" && typeof Reflect.metadata === \"function\") return Reflect.metadata(metadataKey, metadataValue);\n}\nfunction __awaiter(thisArg, _arguments, P, generator) {\n  return new (P || (P = Promise))(function (resolve, reject) {\n    function fulfilled(value) {\n      try {\n        step(generator.next(value));\n      } catch (e) {\n        reject(e);\n      }\n    }\n\n    function rejected(value) {\n      try {\n        step(generator[\"throw\"](value));\n      } catch (e) {\n        reject(e);\n      }\n    }\n\n    function step(result) {\n      result.done ? resolve(result.value) : new P(function (resolve) {\n        resolve(result.value);\n      }).then(fulfilled, rejected);\n    }\n\n    step((generator = generator.apply(thisArg, _arguments || [])).next());\n  });\n}\nfunction __generator(thisArg, body) {\n  var _ = {\n    label: 0,\n    sent: function () {\n      if (t[0] & 1) throw t[1];\n      return t[1];\n    },\n    trys: [],\n    ops: []\n  },\n      f,\n      y,\n      t,\n      g;\n  return g = {\n    next: verb(0),\n    \"throw\": verb(1),\n    \"return\": verb(2)\n  }, typeof Symbol === \"function\" && (g[Symbol.iterator] = function () {\n    return this;\n  }), g;\n\n  function verb(n) {\n    return function (v) {\n      return step([n, v]);\n    };\n  }\n\n  function step(op) {\n    if (f) throw new TypeError(\"Generator is already executing.\");\n\n    while (_) try {\n      if (f = 1, y && (t = op[0] & 2 ? y[\"return\"] : op[0] ? y[\"throw\"] || ((t = y[\"return\"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;\n      if (y = 0, t) op = [op[0] & 2, t.value];\n\n      switch (op[0]) {\n        case 0:\n        case 1:\n          t = op;\n          break;\n\n        case 4:\n          _.label++;\n          return {\n            value: op[1],\n            done: false\n          };\n\n        case 5:\n          _.label++;\n          y = op[1];\n          op = [0];\n          continue;\n\n        case 7:\n          op = _.ops.pop();\n\n          _.trys.pop();\n\n          continue;\n\n        default:\n          if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {\n            _ = 0;\n            continue;\n          }\n\n          if (op[0] === 3 && (!t || op[1] > t[0] && op[1] < t[3])) {\n            _.label = op[1];\n            break;\n          }\n\n          if (op[0] === 6 && _.label < t[1]) {\n            _.label = t[1];\n            t = op;\n            break;\n          }\n\n          if (t && _.label < t[2]) {\n            _.label = t[2];\n\n            _.ops.push(op);\n\n            break;\n          }\n\n          if (t[2]) _.ops.pop();\n\n          _.trys.pop();\n\n          continue;\n      }\n\n      op = body.call(thisArg, _);\n    } catch (e) {\n      op = [6, e];\n      y = 0;\n    } finally {\n      f = t = 0;\n    }\n\n    if (op[0] & 5) throw op[1];\n    return {\n      value: op[0] ? op[1] : void 0,\n      done: true\n    };\n  }\n}\nfunction __exportStar(m, exports) {\n  for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];\n}\nfunction __values(o) {\n  var m = typeof Symbol === \"function\" && o[Symbol.iterator],\n      i = 0;\n  if (m) return m.call(o);\n  return {\n    next: function () {\n      if (o && i >= o.length) o = void 0;\n      return {\n        value: o && o[i++],\n        done: !o\n      };\n    }\n  };\n}\nfunction __read(o, n) {\n  var m = typeof Symbol === \"function\" && o[Symbol.iterator];\n  if (!m) return o;\n  var i = m.call(o),\n      r,\n      ar = [],\n      e;\n\n  try {\n    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);\n  } catch (error) {\n    e = {\n      error: error\n    };\n  } finally {\n    try {\n      if (r && !r.done && (m = i[\"return\"])) m.call(i);\n    } finally {\n      if (e) throw e.error;\n    }\n  }\n\n  return ar;\n}\nfunction __spread() {\n  for (var ar = [], i = 0; i < arguments.length; i++) ar = ar.concat(__read(arguments[i]));\n\n  return ar;\n}\nfunction __spreadArrays() {\n  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;\n\n  for (var r = Array(s), k = 0, i = 0; i < il; i++) for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++) r[k] = a[j];\n\n  return r;\n}\n;\nfunction __await(v) {\n  return this instanceof __await ? (this.v = v, this) : new __await(v);\n}\nfunction __asyncGenerator(thisArg, _arguments, generator) {\n  if (!Symbol.asyncIterator) throw new TypeError(\"Symbol.asyncIterator is not defined.\");\n  var g = generator.apply(thisArg, _arguments || []),\n      i,\n      q = [];\n  return i = {}, verb(\"next\"), verb(\"throw\"), verb(\"return\"), i[Symbol.asyncIterator] = function () {\n    return this;\n  }, i;\n\n  function verb(n) {\n    if (g[n]) i[n] = function (v) {\n      return new Promise(function (a, b) {\n        q.push([n, v, a, b]) > 1 || resume(n, v);\n      });\n    };\n  }\n\n  function resume(n, v) {\n    try {\n      step(g[n](v));\n    } catch (e) {\n      settle(q[0][3], e);\n    }\n  }\n\n  function step(r) {\n    r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);\n  }\n\n  function fulfill(value) {\n    resume(\"next\", value);\n  }\n\n  function reject(value) {\n    resume(\"throw\", value);\n  }\n\n  function settle(f, v) {\n    if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]);\n  }\n}\nfunction __asyncDelegator(o) {\n  var i, p;\n  return i = {}, verb(\"next\"), verb(\"throw\", function (e) {\n    throw e;\n  }), verb(\"return\"), i[Symbol.iterator] = function () {\n    return this;\n  }, i;\n\n  function verb(n, f) {\n    i[n] = o[n] ? function (v) {\n      return (p = !p) ? {\n        value: __await(o[n](v)),\n        done: n === \"return\"\n      } : f ? f(v) : v;\n    } : f;\n  }\n}\nfunction __asyncValues(o) {\n  if (!Symbol.asyncIterator) throw new TypeError(\"Symbol.asyncIterator is not defined.\");\n  var m = o[Symbol.asyncIterator],\n      i;\n  return m ? m.call(o) : (o = typeof __values === \"function\" ? __values(o) : o[Symbol.iterator](), i = {}, verb(\"next\"), verb(\"throw\"), verb(\"return\"), i[Symbol.asyncIterator] = function () {\n    return this;\n  }, i);\n\n  function verb(n) {\n    i[n] = o[n] && function (v) {\n      return new Promise(function (resolve, reject) {\n        v = o[n](v), settle(resolve, reject, v.done, v.value);\n      });\n    };\n  }\n\n  function settle(resolve, reject, d, v) {\n    Promise.resolve(v).then(function (v) {\n      resolve({\n        value: v,\n        done: d\n      });\n    }, reject);\n  }\n}\nfunction __makeTemplateObject(cooked, raw) {\n  if (Object.defineProperty) {\n    Object.defineProperty(cooked, \"raw\", {\n      value: raw\n    });\n  } else {\n    cooked.raw = raw;\n  }\n\n  return cooked;\n}\n;\nfunction __importStar(mod) {\n  if (mod && mod.__esModule) return mod;\n  var result = {};\n  if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];\n  result.default = mod;\n  return result;\n}\nfunction __importDefault(mod) {\n  return mod && mod.__esModule ? mod : {\n    default: mod\n  };\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./node_modules/tslib/tslib.es6.js\n");

/***/ }),

/***/ "./src/common/auth/token_storage.ts":
/*!******************************************!*\
  !*** ./src/common/auth/token_storage.ts ***!
  \******************************************/
/*! namespace exports */
/*! export askWrite [provided] [no usage info] [missing usage info prevents renaming] */
/*! export enableWrite [provided] [no usage info] [missing usage info prevents renaming] */
/*! export loadTokens [provided] [no usage info] [missing usage info prevents renaming] */
/*! export saveTokens [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"askWrite\": () => /* binding */ askWrite,\n/* harmony export */   \"saveTokens\": () => /* binding */ saveTokens,\n/* harmony export */   \"enableWrite\": () => /* binding */ enableWrite,\n/* harmony export */   \"loadTokens\": () => /* binding */ loadTokens\n/* harmony export */ });\nconst storage = window.localStorage || {};\n// So that core.js and main app hit same shared object.\nlet tokenCache = window.__tokenCache;\n\nif (!tokenCache) {\n  tokenCache = window.__tokenCache = {\n    tokens: undefined,\n    writeEnabled: undefined\n  };\n}\n\nfunction askWrite() {\n  return tokenCache.tokens !== undefined && tokenCache.writeEnabled === undefined;\n}\nfunction saveTokens(tokens) {\n  tokenCache.tokens = tokens;\n\n  if (tokenCache.writeEnabled) {\n    try {\n      storage.hassTokens = JSON.stringify(tokens);\n    } catch (err) {// write failed, ignore it. Happens if storage is full or private mode.\n    }\n  }\n}\nfunction enableWrite() {\n  tokenCache.writeEnabled = true;\n\n  if (tokenCache.tokens) {\n    saveTokens(tokenCache.tokens);\n  }\n}\nfunction loadTokens() {\n  if (tokenCache.tokens === undefined) {\n    try {\n      // Delete the old token cache.\n      delete storage.tokens;\n      const tokens = storage.hassTokens;\n\n      if (tokens) {\n        tokenCache.tokens = JSON.parse(tokens);\n        tokenCache.writeEnabled = true;\n      } else {\n        tokenCache.tokens = null;\n      }\n    } catch (err) {\n      tokenCache.tokens = null;\n    }\n  }\n\n  return tokenCache.tokens;\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/common/auth/token_storage.ts\n");

/***/ }),

/***/ "./src/common/color/convert-color.ts":
/*!*******************************************!*\
  !*** ./src/common/color/convert-color.ts ***!
  \*******************************************/
/*! namespace exports */
/*! export hex2rgb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export lab2hex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export lab2rgb [provided] [no usage info] [missing usage info prevents renaming] */
/*! export rgb2hex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export rgb2lab [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"hex2rgb\": () => /* binding */ hex2rgb,\n/* harmony export */   \"rgb2hex\": () => /* binding */ rgb2hex,\n/* harmony export */   \"rgb2lab\": () => /* binding */ rgb2lab,\n/* harmony export */   \"lab2rgb\": () => /* binding */ lab2rgb,\n/* harmony export */   \"lab2hex\": () => /* binding */ lab2hex\n/* harmony export */ });\n/* harmony import */ var _hex__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./hex */ \"./src/common/color/hex.ts\");\n\n\nconst rgb_hex = component => {\n  const hex = Math.round(Math.min(Math.max(component, 0), 255)).toString(16);\n  return hex.length === 1 ? `0${hex}` : hex;\n}; // Conversion between HEX and RGB\n\n\nconst hex2rgb = hex => {\n  hex = (0,_hex__WEBPACK_IMPORTED_MODULE_0__.expandHex)(hex);\n  return [parseInt(hex.substring(0, 2), 16), parseInt(hex.substring(2, 4), 16), parseInt(hex.substring(4, 6), 16)];\n};\nconst rgb2hex = rgb => {\n  return `#${rgb_hex(rgb[0])}${rgb_hex(rgb[1])}${rgb_hex(rgb[2])}`;\n}; // Conversion between LAB, XYZ and RGB from https://github.com/gka/chroma.js\n// Copyright (c) 2011-2019, Gregor Aisch\n// Constants for XYZ and LAB conversion\n\nconst Xn = 0.95047;\nconst Yn = 1;\nconst Zn = 1.08883;\nconst t0 = 0.137931034; // 4 / 29\n\nconst t1 = 0.206896552; // 6 / 29\n\nconst t2 = 0.12841855; // 3 * t1 * t1\n\nconst t3 = 0.008856452; // t1 * t1 * t1\n\nconst rgb_xyz = r => {\n  r /= 255;\n\n  if (r <= 0.04045) {\n    return r / 12.92;\n  }\n\n  return ((r + 0.055) / 1.055) ** 2.4;\n};\n\nconst xyz_lab = t => {\n  if (t > t3) {\n    return t ** (1 / 3);\n  }\n\n  return t / t2 + t0;\n};\n\nconst xyz_rgb = r => {\n  return 255 * (r <= 0.00304 ? 12.92 * r : 1.055 * r ** (1 / 2.4) - 0.055);\n};\n\nconst lab_xyz = t => {\n  return t > t1 ? t * t * t : t2 * (t - t0);\n}; // Conversions between RGB and LAB\n\n\nconst rgb2xyz = rgb => {\n  let [r, g, b] = rgb;\n  r = rgb_xyz(r);\n  g = rgb_xyz(g);\n  b = rgb_xyz(b);\n  const x = xyz_lab((0.4124564 * r + 0.3575761 * g + 0.1804375 * b) / Xn);\n  const y = xyz_lab((0.2126729 * r + 0.7151522 * g + 0.072175 * b) / Yn);\n  const z = xyz_lab((0.0193339 * r + 0.119192 * g + 0.9503041 * b) / Zn);\n  return [x, y, z];\n};\n\nconst rgb2lab = rgb => {\n  const [x, y, z] = rgb2xyz(rgb);\n  const l = 116 * y - 16;\n  return [l < 0 ? 0 : l, 500 * (x - y), 200 * (y - z)];\n};\nconst lab2rgb = lab => {\n  const [l, a, b] = lab;\n  let y = (l + 16) / 116;\n  let x = isNaN(a) ? y : y + a / 500;\n  let z = isNaN(b) ? y : y - b / 200;\n  y = Yn * lab_xyz(y);\n  x = Xn * lab_xyz(x);\n  z = Zn * lab_xyz(z);\n  const r = xyz_rgb(3.2404542 * x - 1.5371385 * y - 0.4985314 * z); // D65 -> sRGB\n\n  const g = xyz_rgb(-0.969266 * x + 1.8760108 * y + 0.041556 * z);\n  const b_ = xyz_rgb(0.0556434 * x - 0.2040259 * y + 1.0572252 * z);\n  return [r, g, b_];\n};\nconst lab2hex = lab => {\n  const rgb = lab2rgb(lab);\n  return rgb2hex(rgb);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/common/color/convert-color.ts\n");

/***/ }),

/***/ "./src/common/color/hex.ts":
/*!*********************************!*\
  !*** ./src/common/color/hex.ts ***!
  \*********************************/
/*! namespace exports */
/*! export expandHex [provided] [no usage info] [missing usage info prevents renaming] */
/*! export hexBlend [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"expandHex\": () => /* binding */ expandHex,\n/* harmony export */   \"hexBlend\": () => /* binding */ hexBlend\n/* harmony export */ });\nconst expandHex = hex => {\n  hex = hex.replace(\"#\", \"\");\n  if (hex.length === 6) return hex;\n  let result = \"\";\n\n  for (const val of hex) {\n    result += val + val;\n  }\n\n  return result;\n}; // Blend 2 hex colors: c1 is placed over c2, blend is c1's opacity.\n\nconst hexBlend = (c1, c2, blend = 50) => {\n  let color = \"\";\n  c1 = expandHex(c1);\n  c2 = expandHex(c2);\n\n  for (let i = 0; i <= 5; i += 2) {\n    const h1 = parseInt(c1.substr(i, 2), 16);\n    const h2 = parseInt(c2.substr(i, 2), 16);\n    let hex = Math.floor(h2 + (h1 - h2) * (blend / 100)).toString(16);\n\n    while (hex.length < 2) hex = \"0\" + hex;\n\n    color += hex;\n  }\n\n  return `#${color}`;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2NvbG9yL2hleC50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbW1vbi9jb2xvci9oZXgudHM/N2NjYyJdLCJzb3VyY2VzQ29udGVudCI6WyJleHBvcnQgY29uc3QgZXhwYW5kSGV4ID0gKGhleDogc3RyaW5nKTogc3RyaW5nID0+IHtcbiAgaGV4ID0gaGV4LnJlcGxhY2UoXCIjXCIsIFwiXCIpO1xuICBpZiAoaGV4Lmxlbmd0aCA9PT0gNikgcmV0dXJuIGhleDtcbiAgbGV0IHJlc3VsdCA9IFwiXCI7XG4gIGZvciAoY29uc3QgdmFsIG9mIGhleCkge1xuICAgIHJlc3VsdCArPSB2YWwgKyB2YWw7XG4gIH1cbiAgcmV0dXJuIHJlc3VsdDtcbn07XG5cbi8vIEJsZW5kIDIgaGV4IGNvbG9yczogYzEgaXMgcGxhY2VkIG92ZXIgYzIsIGJsZW5kIGlzIGMxJ3Mgb3BhY2l0eS5cbmV4cG9ydCBjb25zdCBoZXhCbGVuZCA9IChjMTogc3RyaW5nLCBjMjogc3RyaW5nLCBibGVuZCA9IDUwKTogc3RyaW5nID0+IHtcbiAgbGV0IGNvbG9yID0gXCJcIjtcbiAgYzEgPSBleHBhbmRIZXgoYzEpO1xuICBjMiA9IGV4cGFuZEhleChjMik7XG4gIGZvciAobGV0IGkgPSAwOyBpIDw9IDU7IGkgKz0gMikge1xuICAgIGNvbnN0IGgxID0gcGFyc2VJbnQoYzEuc3Vic3RyKGksIDIpLCAxNik7XG4gICAgY29uc3QgaDIgPSBwYXJzZUludChjMi5zdWJzdHIoaSwgMiksIDE2KTtcbiAgICBsZXQgaGV4ID0gTWF0aC5mbG9vcihoMiArIChoMSAtIGgyKSAqIChibGVuZCAvIDEwMCkpLnRvU3RyaW5nKDE2KTtcbiAgICB3aGlsZSAoaGV4Lmxlbmd0aCA8IDIpIGhleCA9IFwiMFwiICsgaGV4O1xuICAgIGNvbG9yICs9IGhleDtcbiAgfVxuICByZXR1cm4gYCMke2NvbG9yfWA7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7OztBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUVBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUFBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/common/color/hex.ts\n");

/***/ }),

/***/ "./src/common/color/lab.ts":
/*!*********************************!*\
  !*** ./src/common/color/lab.ts ***!
  \*********************************/
/*! namespace exports */
/*! export labBrighten [provided] [no usage info] [missing usage info prevents renaming] */
/*! export labDarken [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"labDarken\": () => /* binding */ labDarken,\n/* harmony export */   \"labBrighten\": () => /* binding */ labBrighten\n/* harmony export */ });\n// From https://github.com/gka/chroma.js\n// Copyright (c) 2011-2019, Gregor Aisch\nconst labDarken = (lab, amount = 1) => {\n  return [lab[0] - 18 * amount, lab[1], lab[2]];\n};\nconst labBrighten = (lab, amount = 1) => {\n  return labDarken(lab, -amount);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2NvbG9yL2xhYi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbW1vbi9jb2xvci9sYWIudHM/YWU2NiJdLCJzb3VyY2VzQ29udGVudCI6WyIvLyBGcm9tIGh0dHBzOi8vZ2l0aHViLmNvbS9na2EvY2hyb21hLmpzXG4vLyBDb3B5cmlnaHQgKGMpIDIwMTEtMjAxOSwgR3JlZ29yIEFpc2NoXG5cbmV4cG9ydCBjb25zdCBsYWJEYXJrZW4gPSAoXG4gIGxhYjogW251bWJlciwgbnVtYmVyLCBudW1iZXJdLFxuICBhbW91bnQgPSAxXG4pOiBbbnVtYmVyLCBudW1iZXIsIG51bWJlcl0gPT4ge1xuICByZXR1cm4gW2xhYlswXSAtIDE4ICogYW1vdW50LCBsYWJbMV0sIGxhYlsyXV07XG59O1xuXG5leHBvcnQgY29uc3QgbGFiQnJpZ2h0ZW4gPSAoXG4gIGxhYjogW251bWJlciwgbnVtYmVyLCBudW1iZXJdLFxuICBhbW91bnQgPSAxXG4pOiBbbnVtYmVyLCBudW1iZXIsIG51bWJlcl0gPT4ge1xuICByZXR1cm4gbGFiRGFya2VuKGxhYiwgLWFtb3VudCk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7OztBQUFBO0FBQ0E7QUFFQTtBQUlBO0FBQ0E7QUFFQTtBQUlBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/common/color/lab.ts\n");

/***/ }),

/***/ "./src/common/color/rgb.ts":
/*!*********************************!*\
  !*** ./src/common/color/rgb.ts ***!
  \*********************************/
/*! namespace exports */
/*! export rgbContrast [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"rgbContrast\": () => /* binding */ rgbContrast\n/* harmony export */ });\nconst luminosity = rgb => {\n  // http://www.w3.org/TR/WCAG20/#relativeluminancedef\n  const lum = [0, 0, 0];\n\n  for (let i = 0; i < rgb.length; i++) {\n    const chan = rgb[i] / 255;\n    lum[i] = chan <= 0.03928 ? chan / 12.92 : ((chan + 0.055) / 1.055) ** 2.4;\n  }\n\n  return 0.2126 * lum[0] + 0.7152 * lum[1] + 0.0722 * lum[2];\n};\n\nconst rgbContrast = (color1, color2) => {\n  const lum1 = luminosity(color1);\n  const lum2 = luminosity(color2);\n\n  if (lum1 > lum2) {\n    return (lum1 + 0.05) / (lum2 + 0.05);\n  }\n\n  return (lum2 + 0.05) / (lum1 + 0.05);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2NvbG9yL3JnYi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbW1vbi9jb2xvci9yZ2IudHM/MTdlZiJdLCJzb3VyY2VzQ29udGVudCI6WyJjb25zdCBsdW1pbm9zaXR5ID0gKHJnYjogW251bWJlciwgbnVtYmVyLCBudW1iZXJdKTogbnVtYmVyID0+IHtcbiAgLy8gaHR0cDovL3d3dy53My5vcmcvVFIvV0NBRzIwLyNyZWxhdGl2ZWx1bWluYW5jZWRlZlxuICBjb25zdCBsdW06IFtudW1iZXIsIG51bWJlciwgbnVtYmVyXSA9IFswLCAwLCAwXTtcbiAgZm9yIChsZXQgaSA9IDA7IGkgPCByZ2IubGVuZ3RoOyBpKyspIHtcbiAgICBjb25zdCBjaGFuID0gcmdiW2ldIC8gMjU1O1xuICAgIGx1bVtpXSA9IGNoYW4gPD0gMC4wMzkyOCA/IGNoYW4gLyAxMi45MiA6ICgoY2hhbiArIDAuMDU1KSAvIDEuMDU1KSAqKiAyLjQ7XG4gIH1cblxuICByZXR1cm4gMC4yMTI2ICogbHVtWzBdICsgMC43MTUyICogbHVtWzFdICsgMC4wNzIyICogbHVtWzJdO1xufTtcblxuZXhwb3J0IGNvbnN0IHJnYkNvbnRyYXN0ID0gKFxuICBjb2xvcjE6IFtudW1iZXIsIG51bWJlciwgbnVtYmVyXSxcbiAgY29sb3IyOiBbbnVtYmVyLCBudW1iZXIsIG51bWJlcl1cbikgPT4ge1xuICBjb25zdCBsdW0xID0gbHVtaW5vc2l0eShjb2xvcjEpO1xuICBjb25zdCBsdW0yID0gbHVtaW5vc2l0eShjb2xvcjIpO1xuXG4gIGlmIChsdW0xID4gbHVtMikge1xuICAgIHJldHVybiAobHVtMSArIDAuMDUpIC8gKGx1bTIgKyAwLjA1KTtcbiAgfVxuXG4gIHJldHVybiAobHVtMiArIDAuMDUpIC8gKGx1bTEgKyAwLjA1KTtcbn07XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUlBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/common/color/rgb.ts\n");

/***/ }),

/***/ "./src/common/decorators/restore-scroll.ts":
/*!*************************************************!*\
  !*** ./src/common/decorators/restore-scroll.ts ***!
  \*************************************************/
/*! namespace exports */
/*! export restoreScroll [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"restoreScroll\": () => /* binding */ restoreScroll\n/* harmony export */ });\nconst restoreScroll = selector => {\n  return element => ({\n    kind: \"method\",\n    placement: \"prototype\",\n    key: element.key,\n    descriptor: {\n      set(value) {\n        this[`__${String(element.key)}`] = value;\n      },\n\n      get() {\n        return this[`__${String(element.key)}`];\n      },\n\n      enumerable: true,\n      configurable: true\n    },\n\n    finisher(cls) {\n      const connectedCallback = cls.prototype.connectedCallback;\n\n      cls.prototype.connectedCallback = function () {\n        connectedCallback.call(this);\n\n        if (this[element.key]) {\n          const target = this.renderRoot.querySelector(selector);\n\n          if (!target) {\n            return;\n          }\n\n          target.scrollTop = this[element.key];\n        }\n      };\n    }\n\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2RlY29yYXRvcnMvcmVzdG9yZS1zY3JvbGwudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9jb21tb24vZGVjb3JhdG9ycy9yZXN0b3JlLXNjcm9sbC50cz80MTVjIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB0eXBlIHsgTGl0RWxlbWVudCB9IGZyb20gXCJsaXQtZWxlbWVudFwiO1xuaW1wb3J0IHR5cGUgeyBDbGFzc0VsZW1lbnQgfSBmcm9tIFwiLi4vLi4vdHlwZXNcIjtcblxuZXhwb3J0IGNvbnN0IHJlc3RvcmVTY3JvbGwgPSAoc2VsZWN0b3I6IHN0cmluZyk6IGFueSA9PiB7XG4gIHJldHVybiAoZWxlbWVudDogQ2xhc3NFbGVtZW50KSA9PiAoe1xuICAgIGtpbmQ6IFwibWV0aG9kXCIsXG4gICAgcGxhY2VtZW50OiBcInByb3RvdHlwZVwiLFxuICAgIGtleTogZWxlbWVudC5rZXksXG4gICAgZGVzY3JpcHRvcjoge1xuICAgICAgc2V0KHRoaXM6IExpdEVsZW1lbnQsIHZhbHVlOiBudW1iZXIpIHtcbiAgICAgICAgdGhpc1tgX18ke1N0cmluZyhlbGVtZW50LmtleSl9YF0gPSB2YWx1ZTtcbiAgICAgIH0sXG4gICAgICBnZXQodGhpczogTGl0RWxlbWVudCkge1xuICAgICAgICByZXR1cm4gdGhpc1tgX18ke1N0cmluZyhlbGVtZW50LmtleSl9YF07XG4gICAgICB9LFxuICAgICAgZW51bWVyYWJsZTogdHJ1ZSxcbiAgICAgIGNvbmZpZ3VyYWJsZTogdHJ1ZSxcbiAgICB9LFxuICAgIGZpbmlzaGVyKGNsczogdHlwZW9mIExpdEVsZW1lbnQpIHtcbiAgICAgIGNvbnN0IGNvbm5lY3RlZENhbGxiYWNrID0gY2xzLnByb3RvdHlwZS5jb25uZWN0ZWRDYWxsYmFjaztcbiAgICAgIGNscy5wcm90b3R5cGUuY29ubmVjdGVkQ2FsbGJhY2sgPSBmdW5jdGlvbiAoKSB7XG4gICAgICAgIGNvbm5lY3RlZENhbGxiYWNrLmNhbGwodGhpcyk7XG4gICAgICAgIGlmICh0aGlzW2VsZW1lbnQua2V5XSkge1xuICAgICAgICAgIGNvbnN0IHRhcmdldCA9IHRoaXMucmVuZGVyUm9vdC5xdWVyeVNlbGVjdG9yKHNlbGVjdG9yKTtcbiAgICAgICAgICBpZiAoIXRhcmdldCkge1xuICAgICAgICAgICAgcmV0dXJuO1xuICAgICAgICAgIH1cbiAgICAgICAgICB0YXJnZXQuc2Nyb2xsVG9wID0gdGhpc1tlbGVtZW50LmtleV07XG4gICAgICAgIH1cbiAgICAgIH07XG4gICAgfSxcbiAgfSk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBR0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFSQTtBQUNBO0FBU0E7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBM0JBO0FBNEJBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/common/decorators/restore-scroll.ts\n");

/***/ }),

/***/ "./src/common/dom/apply_themes_on_element.ts":
/*!***************************************************!*\
  !*** ./src/common/dom/apply_themes_on_element.ts ***!
  \***************************************************/
/*! namespace exports */
/*! export applyThemesOnElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! export invalidateThemeCache [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"applyThemesOnElement\": () => /* binding */ applyThemesOnElement,\n/* harmony export */   \"invalidateThemeCache\": () => /* binding */ invalidateThemeCache\n/* harmony export */ });\n/* harmony import */ var _resources_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../resources/styles */ \"./src/resources/styles.ts\");\n/* harmony import */ var _color_convert_color__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../color/convert-color */ \"./src/common/color/convert-color.ts\");\n/* harmony import */ var _color_hex__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../color/hex */ \"./src/common/color/hex.ts\");\n/* harmony import */ var _color_lab__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../color/lab */ \"./src/common/color/lab.ts\");\n/* harmony import */ var _color_rgb__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../color/rgb */ \"./src/common/color/rgb.ts\");\n\n\n\n\n\nlet PROCESSED_THEMES = {};\n/**\n * Apply a theme to an element by setting the CSS variables on it.\n *\n * element: Element to apply theme on.\n * themes: HASS Theme information\n * selectedTheme: selected theme.\n */\n\nconst applyThemesOnElement = (element, themes, selectedTheme, themeOptions) => {\n  let cacheKey = selectedTheme;\n  let themeRules = {};\n\n  if (selectedTheme === \"default\" && themeOptions) {\n    if (themeOptions.dark) {\n      cacheKey = `${cacheKey}__dark`;\n      themeRules = _resources_styles__WEBPACK_IMPORTED_MODULE_0__.darkStyles;\n\n      if (themeOptions.primaryColor) {\n        themeRules[\"app-header-background-color\"] = (0,_color_hex__WEBPACK_IMPORTED_MODULE_2__.hexBlend)(themeOptions.primaryColor, \"#121212\", 8);\n      }\n    }\n\n    if (themeOptions.primaryColor) {\n      cacheKey = `${cacheKey}__primary_${themeOptions.primaryColor}`;\n      const rgbPrimaryColor = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.hex2rgb)(themeOptions.primaryColor);\n      const labPrimaryColor = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.rgb2lab)(rgbPrimaryColor);\n      themeRules[\"primary-color\"] = themeOptions.primaryColor;\n      const rgbLigthPrimaryColor = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.lab2rgb)((0,_color_lab__WEBPACK_IMPORTED_MODULE_3__.labBrighten)(labPrimaryColor));\n      themeRules[\"light-primary-color\"] = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.rgb2hex)(rgbLigthPrimaryColor);\n      themeRules[\"dark-primary-color\"] = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.lab2hex)((0,_color_lab__WEBPACK_IMPORTED_MODULE_3__.labDarken)(labPrimaryColor));\n      themeRules[\"text-primary-color\"] = (0,_color_rgb__WEBPACK_IMPORTED_MODULE_4__.rgbContrast)(rgbPrimaryColor, [33, 33, 33]) < 6 ? \"#fff\" : \"#212121\";\n      themeRules[\"text-light-primary-color\"] = (0,_color_rgb__WEBPACK_IMPORTED_MODULE_4__.rgbContrast)(rgbLigthPrimaryColor, [33, 33, 33]) < 6 ? \"#fff\" : \"#212121\";\n      themeRules[\"state-icon-color\"] = themeRules[\"dark-primary-color\"];\n    }\n\n    if (themeOptions.accentColor) {\n      cacheKey = `${cacheKey}__accent_${themeOptions.accentColor}`;\n      themeRules[\"accent-color\"] = themeOptions.accentColor;\n      const rgbAccentColor = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.hex2rgb)(themeOptions.accentColor);\n      themeRules[\"text-accent-color\"] = (0,_color_rgb__WEBPACK_IMPORTED_MODULE_4__.rgbContrast)(rgbAccentColor, [33, 33, 33]) < 6 ? \"#fff\" : \"#212121\";\n    }\n  }\n\n  if (selectedTheme && themes.themes[selectedTheme]) {\n    themeRules = themes.themes[selectedTheme];\n  }\n\n  if (!element._themes && !Object.keys(themeRules).length) {\n    // No styles to reset, and no styles to set\n    return;\n  }\n\n  const newTheme = themeRules && cacheKey ? PROCESSED_THEMES[cacheKey] || processTheme(cacheKey, themeRules) : undefined; // Add previous set keys to reset them, and new theme\n\n  const styles = { ...element._themes,\n    ...(newTheme === null || newTheme === void 0 ? void 0 : newTheme.styles)\n  };\n  element._themes = newTheme === null || newTheme === void 0 ? void 0 : newTheme.keys; // Set and/or reset styles\n\n  if (element.updateStyles) {\n    element.updateStyles(styles);\n  } else if (window.ShadyCSS) {\n    // Implement updateStyles() method of Polymer elements\n    window.ShadyCSS.styleSubtree(\n    /** @type {!HTMLElement} */\n    element, styles);\n  }\n};\n\nconst processTheme = (cacheKey, theme) => {\n  if (!theme || !Object.keys(theme).length) {\n    return undefined;\n  }\n\n  const combinedTheme = { ..._resources_styles__WEBPACK_IMPORTED_MODULE_0__.derivedStyles,\n    ...theme\n  };\n  const styles = {};\n  const keys = {};\n\n  for (const key of Object.keys(combinedTheme)) {\n    const prefixedKey = `--${key}`;\n    const value = String(combinedTheme[key]);\n    styles[prefixedKey] = value;\n    keys[prefixedKey] = \"\"; // Try to create a rgb value for this key if it is not a var\n\n    if (!value.startsWith(\"#\")) {\n      // Can't convert non hex value\n      continue;\n    }\n\n    const rgbKey = `rgb-${key}`;\n\n    if (combinedTheme[rgbKey] !== undefined) {\n      // Theme has it's own rgb value\n      continue;\n    }\n\n    try {\n      const rgbValue = (0,_color_convert_color__WEBPACK_IMPORTED_MODULE_1__.hex2rgb)(value).join(\",\");\n      const prefixedRgbKey = `--${rgbKey}`;\n      styles[prefixedRgbKey] = rgbValue;\n      keys[prefixedRgbKey] = \"\";\n    } catch (e) {\n      continue;\n    }\n  }\n\n  PROCESSED_THEMES[cacheKey] = {\n    styles,\n    keys\n  };\n  return {\n    styles,\n    keys\n  };\n};\n\nconst invalidateThemeCache = () => {\n  PROCESSED_THEMES = {};\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/common/dom/apply_themes_on_element.ts\n");

/***/ }),

/***/ "./src/common/dom/deep-active-element.ts":
/*!***********************************************!*\
  !*** ./src/common/dom/deep-active-element.ts ***!
  \***********************************************/
/*! namespace exports */
/*! export deepActiveElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"deepActiveElement\": () => /* binding */ deepActiveElement\n/* harmony export */ });\nconst deepActiveElement = (root = document) => {\n  var _root$activeElement, _root$activeElement$s;\n\n  if ((_root$activeElement = root.activeElement) === null || _root$activeElement === void 0 ? void 0 : (_root$activeElement$s = _root$activeElement.shadowRoot) === null || _root$activeElement$s === void 0 ? void 0 : _root$activeElement$s.activeElement) {\n    return deepActiveElement(root.activeElement.shadowRoot);\n  }\n\n  return root.activeElement;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2RvbS9kZWVwLWFjdGl2ZS1lbGVtZW50LnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvY29tbW9uL2RvbS9kZWVwLWFjdGl2ZS1lbGVtZW50LnRzPzY0OTAiXSwic291cmNlc0NvbnRlbnQiOlsiZXhwb3J0IGNvbnN0IGRlZXBBY3RpdmVFbGVtZW50ID0gKFxuICByb290OiBEb2N1bWVudE9yU2hhZG93Um9vdCA9IGRvY3VtZW50XG4pOiBFbGVtZW50IHwgbnVsbCA9PiB7XG4gIGlmIChyb290LmFjdGl2ZUVsZW1lbnQ/LnNoYWRvd1Jvb3Q/LmFjdGl2ZUVsZW1lbnQpIHtcbiAgICByZXR1cm4gZGVlcEFjdGl2ZUVsZW1lbnQocm9vdC5hY3RpdmVFbGVtZW50LnNoYWRvd1Jvb3QpO1xuICB9XG4gIHJldHVybiByb290LmFjdGl2ZUVsZW1lbnQ7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBQUE7QUFFQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/common/dom/deep-active-element.ts\n");

/***/ }),

/***/ "./src/common/dom/fire_event.ts":
/*!**************************************!*\
  !*** ./src/common/dom/fire_event.ts ***!
  \**************************************/
/*! namespace exports */
/*! export fireEvent [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"fireEvent\": () => /* binding */ fireEvent\n/* harmony export */ });\n// Polymer legacy event helpers used courtesy of the Polymer project.\n//\n// Copyright (c) 2017 The Polymer Authors. All rights reserved.\n//\n// Redistribution and use in source and binary forms, with or without\n// modification, are permitted provided that the following conditions are\n// met:\n//\n//    * Redistributions of source code must retain the above copyright\n// notice, this list of conditions and the following disclaimer.\n//    * Redistributions in binary form must reproduce the above\n// copyright notice, this list of conditions and the following disclaimer\n// in the documentation and/or other materials provided with the\n// distribution.\n//    * Neither the name of Google Inc. nor the names of its\n// contributors may be used to endorse or promote products derived from\n// this software without specific prior written permission.\n//\n// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n// \"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT\n// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,\n// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT\n// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,\n// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY\n// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\n// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n/**\n * Dispatches a custom event with an optional detail value.\n *\n * @param {string} type Name of event type.\n * @param {*=} detail Detail value containing event-specific\n *   payload.\n * @param {{ bubbles: (boolean|undefined),\n *           cancelable: (boolean|undefined),\n *           composed: (boolean|undefined) }=}\n *  options Object specifying options.  These may include:\n *  `bubbles` (boolean, defaults to `true`),\n *  `cancelable` (boolean, defaults to false), and\n *  `node` on which to fire the event (HTMLElement, defaults to `this`).\n * @return {Event} The new event that was fired.\n */\nconst fireEvent = (node, type, detail, options) => {\n  options = options || {}; // @ts-ignore\n\n  detail = detail === null || detail === undefined ? {} : detail;\n  const event = new Event(type, {\n    bubbles: options.bubbles === undefined ? true : options.bubbles,\n    cancelable: Boolean(options.cancelable),\n    composed: options.composed === undefined ? true : options.composed\n  });\n  event.detail = detail;\n  node.dispatchEvent(event);\n  return event;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/common/dom/fire_event.ts\n");

/***/ }),

/***/ "./src/common/dom/media_query.ts":
/*!***************************************!*\
  !*** ./src/common/dom/media_query.ts ***!
  \***************************************/
/*! namespace exports */
/*! export listenMediaQuery [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"listenMediaQuery\": () => /* binding */ listenMediaQuery\n/* harmony export */ });\n/**\n * Attach a media query. Listener is called right away and when it matches.\n * @param mediaQuery media query to match.\n * @param listener listener to call when media query changes between match/unmatch\n * @returns function to remove the listener.\n */\nconst listenMediaQuery = (mediaQuery, matchesChanged) => {\n  const mql = matchMedia(mediaQuery);\n\n  const listener = e => matchesChanged(e.matches);\n\n  mql.addListener(listener);\n  matchesChanged(mql.matches);\n  return () => mql.removeListener(listener);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2RvbS9tZWRpYV9xdWVyeS50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbW1vbi9kb20vbWVkaWFfcXVlcnkudHM/Nzg1ZiJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbiAqIEF0dGFjaCBhIG1lZGlhIHF1ZXJ5LiBMaXN0ZW5lciBpcyBjYWxsZWQgcmlnaHQgYXdheSBhbmQgd2hlbiBpdCBtYXRjaGVzLlxuICogQHBhcmFtIG1lZGlhUXVlcnkgbWVkaWEgcXVlcnkgdG8gbWF0Y2guXG4gKiBAcGFyYW0gbGlzdGVuZXIgbGlzdGVuZXIgdG8gY2FsbCB3aGVuIG1lZGlhIHF1ZXJ5IGNoYW5nZXMgYmV0d2VlbiBtYXRjaC91bm1hdGNoXG4gKiBAcmV0dXJucyBmdW5jdGlvbiB0byByZW1vdmUgdGhlIGxpc3RlbmVyLlxuICovXG5leHBvcnQgY29uc3QgbGlzdGVuTWVkaWFRdWVyeSA9IChcbiAgbWVkaWFRdWVyeTogc3RyaW5nLFxuICBtYXRjaGVzQ2hhbmdlZDogKG1hdGNoZXM6IGJvb2xlYW4pID0+IHZvaWRcbikgPT4ge1xuICBjb25zdCBtcWwgPSBtYXRjaE1lZGlhKG1lZGlhUXVlcnkpO1xuICBjb25zdCBsaXN0ZW5lciA9IChlKSA9PiBtYXRjaGVzQ2hhbmdlZChlLm1hdGNoZXMpO1xuICBtcWwuYWRkTGlzdGVuZXIobGlzdGVuZXIpO1xuICBtYXRjaGVzQ2hhbmdlZChtcWwubWF0Y2hlcyk7XG4gIHJldHVybiAoKSA9PiBtcWwucmVtb3ZlTGlzdGVuZXIobGlzdGVuZXIpO1xufTtcbiJdLCJtYXBwaW5ncyI6Ijs7OztBQUFBOzs7Ozs7QUFNQTtBQUlBO0FBQ0E7QUFBQTtBQUNBO0FBQUE7QUFDQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/common/dom/media_query.ts\n");

/***/ }),

/***/ "./src/common/dom/toggle_attribute.ts":
/*!********************************************!*\
  !*** ./src/common/dom/toggle_attribute.ts ***!
  \********************************************/
/*! namespace exports */
/*! export toggleAttribute [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"toggleAttribute\": () => /* binding */ toggleAttribute\n/* harmony export */ });\n// Toggle Attribute Polyfill because it's too new for some browsers\nconst toggleAttribute = (el, name, force) => {\n  if (force !== undefined) {\n    force = !!force;\n  }\n\n  if (el.hasAttribute(name)) {\n    if (force) {\n      return true;\n    }\n\n    el.removeAttribute(name);\n    return false;\n  }\n\n  if (force === false) {\n    return false;\n  }\n\n  el.setAttribute(name, \"\");\n  return true;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2RvbS90b2dnbGVfYXR0cmlidXRlLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvY29tbW9uL2RvbS90b2dnbGVfYXR0cmlidXRlLnRzPzMzYzciXSwic291cmNlc0NvbnRlbnQiOlsiLy8gVG9nZ2xlIEF0dHJpYnV0ZSBQb2x5ZmlsbCBiZWNhdXNlIGl0J3MgdG9vIG5ldyBmb3Igc29tZSBicm93c2Vyc1xuZXhwb3J0IGNvbnN0IHRvZ2dsZUF0dHJpYnV0ZSA9IChcbiAgZWw6IEhUTUxFbGVtZW50LFxuICBuYW1lOiBzdHJpbmcsXG4gIGZvcmNlPzogYm9vbGVhblxuKSA9PiB7XG4gIGlmIChmb3JjZSAhPT0gdW5kZWZpbmVkKSB7XG4gICAgZm9yY2UgPSAhIWZvcmNlO1xuICB9XG5cbiAgaWYgKGVsLmhhc0F0dHJpYnV0ZShuYW1lKSkge1xuICAgIGlmIChmb3JjZSkge1xuICAgICAgcmV0dXJuIHRydWU7XG4gICAgfVxuXG4gICAgZWwucmVtb3ZlQXR0cmlidXRlKG5hbWUpO1xuICAgIHJldHVybiBmYWxzZTtcbiAgfVxuICBpZiAoZm9yY2UgPT09IGZhbHNlKSB7XG4gICAgcmV0dXJuIGZhbHNlO1xuICB9XG5cbiAgZWwuc2V0QXR0cmlidXRlKG5hbWUsIFwiXCIpO1xuICByZXR1cm4gdHJ1ZTtcbn07XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTtBQUNBO0FBS0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/common/dom/toggle_attribute.ts\n");

/***/ }),

/***/ "./src/common/entity/compute_domain.ts":
/*!*********************************************!*\
  !*** ./src/common/entity/compute_domain.ts ***!
  \*********************************************/
/*! namespace exports */
/*! export computeDomain [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"computeDomain\": () => /* binding */ computeDomain\n/* harmony export */ });\nconst computeDomain = entityId => {\n  return entityId.substr(0, entityId.indexOf(\".\"));\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL2VudGl0eS9jb21wdXRlX2RvbWFpbi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbW1vbi9lbnRpdHkvY29tcHV0ZV9kb21haW4udHM/Y2JiOCJdLCJzb3VyY2VzQ29udGVudCI6WyJleHBvcnQgY29uc3QgY29tcHV0ZURvbWFpbiA9IChlbnRpdHlJZDogc3RyaW5nKTogc3RyaW5nID0+IHtcbiAgcmV0dXJuIGVudGl0eUlkLnN1YnN0cigwLCBlbnRpdHlJZC5pbmRleE9mKFwiLlwiKSk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBQUE7QUFDQTtBQUNBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/common/entity/compute_domain.ts\n");

/***/ }),

/***/ "./src/common/navigate.ts":
/*!********************************!*\
  !*** ./src/common/navigate.ts ***!
  \********************************/
/*! namespace exports */
/*! export navigate [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"navigate\": () => /* binding */ navigate\n/* harmony export */ });\n/* harmony import */ var _dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n\nconst navigate = (_node, path, replace = false) => {\n  if (false) {} else if (replace) {\n    history.replaceState(null, \"\", path);\n  } else {\n    history.pushState(null, \"\", path);\n  }\n\n  (0,_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(window, \"location-changed\", {\n    replace\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL25hdmlnYXRlLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvY29tbW9uL25hdmlnYXRlLnRzPzljMGIiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgZmlyZUV2ZW50IH0gZnJvbSBcIi4vZG9tL2ZpcmVfZXZlbnRcIjtcblxuZGVjbGFyZSBnbG9iYWwge1xuICAvLyBmb3IgZmlyZSBldmVudFxuICBpbnRlcmZhY2UgSEFTU0RvbUV2ZW50cyB7XG4gICAgXCJsb2NhdGlvbi1jaGFuZ2VkXCI6IHtcbiAgICAgIHJlcGxhY2U6IGJvb2xlYW47XG4gICAgfTtcbiAgfVxufVxuXG5leHBvcnQgY29uc3QgbmF2aWdhdGUgPSAoX25vZGU6IGFueSwgcGF0aDogc3RyaW5nLCByZXBsYWNlID0gZmFsc2UpID0+IHtcbiAgaWYgKF9fREVNT19fKSB7XG4gICAgaWYgKHJlcGxhY2UpIHtcbiAgICAgIGhpc3RvcnkucmVwbGFjZVN0YXRlKG51bGwsIFwiXCIsIGAke2xvY2F0aW9uLnBhdGhuYW1lfSMke3BhdGh9YCk7XG4gICAgfSBlbHNlIHtcbiAgICAgIHdpbmRvdy5sb2NhdGlvbi5oYXNoID0gcGF0aDtcbiAgICB9XG4gIH0gZWxzZSBpZiAocmVwbGFjZSkge1xuICAgIGhpc3RvcnkucmVwbGFjZVN0YXRlKG51bGwsIFwiXCIsIHBhdGgpO1xuICB9IGVsc2Uge1xuICAgIGhpc3RvcnkucHVzaFN0YXRlKG51bGwsIFwiXCIsIHBhdGgpO1xuICB9XG4gIGZpcmVFdmVudCh3aW5kb3csIFwibG9jYXRpb24tY2hhbmdlZFwiLCB7XG4gICAgcmVwbGFjZSxcbiAgfSk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7OztBQUFBO0FBV0E7QUFDQSxlQU1BO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFEQTtBQUdBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/common/navigate.ts\n");

/***/ }),

/***/ "./src/common/translations/localize.ts":
/*!*********************************************!*\
  !*** ./src/common/translations/localize.ts ***!
  \*********************************************/
/*! namespace exports */
/*! export computeLocalize [provided] [no usage info] [missing usage info prevents renaming] */
/*! export localizeKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.t, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"computeLocalize\": () => /* binding */ computeLocalize,\n/* harmony export */   \"localizeKey\": () => /* binding */ localizeKey\n/* harmony export */ });\n/* harmony import */ var intl_messageformat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! intl-messageformat */ \"./node_modules/intl-messageformat/lib/index.js\");\n/* harmony import */ var _formatjs_intl_pluralrules_should_polyfill__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @formatjs/intl-pluralrules/should-polyfill */ \"./node_modules/@formatjs/intl-pluralrules/should-polyfill.js\");\n\n\nlet polyfillLoaded = !(0,_formatjs_intl_pluralrules_should_polyfill__WEBPACK_IMPORTED_MODULE_0__.shouldPolyfill)();\nconst polyfillProm = polyfillLoaded ? undefined : __webpack_require__.e(/*! import() */ \"vendors-node_modules_formatjs_intl-pluralrules_polyfill-locales_js\").then(__webpack_require__.t.bind(__webpack_require__, /*! @formatjs/intl-pluralrules/polyfill-locales */ \"./node_modules/@formatjs/intl-pluralrules/polyfill-locales.js\", 7)).then(() => {\n  polyfillLoaded = true;\n});\n/**\n * Adapted from Polymer app-localize-behavior.\n *\n * Copyright (c) 2016 The Polymer Project Authors. All rights reserved.\n * This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\n * The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\n * The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\n * Code distributed by Google as part of the polymer project is also\n * subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n */\n\n/**\n * Optional dictionary of user defined formats, as explained here:\n * http://formatjs.io/guides/message-syntax/#custom-formats\n *\n * For example, a valid dictionary of formats would be:\n * this.formats = {\n *    number: { USD: { style: 'currency', currency: 'USD' } }\n * }\n */\n\nconst computeLocalize = async (cache, language, resources, formats) => {\n  if (!polyfillLoaded) {\n    await polyfillProm;\n  } // Everytime any of the parameters change, invalidate the strings cache.\n\n\n  cache._localizationCache = {};\n  return (key, ...args) => {\n    if (!key || !resources || !language || !resources[language]) {\n      return \"\";\n    } // Cache the key/value pairs for the same language, so that we don't\n    // do extra work if we're just reusing strings across an application.\n\n\n    const translatedValue = resources[language][key];\n\n    if (!translatedValue) {\n      return \"\";\n    }\n\n    const messageKey = key + translatedValue;\n    let translatedMessage = cache._localizationCache[messageKey];\n\n    if (!translatedMessage) {\n      translatedMessage = new intl_messageformat__WEBPACK_IMPORTED_MODULE_1__.default(translatedValue, language, formats);\n      cache._localizationCache[messageKey] = translatedMessage;\n    }\n\n    const argObject = {};\n\n    for (let i = 0; i < args.length; i += 2) {\n      argObject[args[i]] = args[i + 1];\n    }\n\n    try {\n      return translatedMessage.format(argObject);\n    } catch (err) {\n      return \"Translation \" + err;\n    }\n  };\n};\n/**\n * Silly helper function that converts an object of placeholders to array so we\n * can convert it back to an object again inside the localize func.\n * @param localize\n * @param key\n * @param placeholders\n */\n\nconst localizeKey = (localize, key, placeholders) => {\n  const args = [key];\n\n  if (placeholders) {\n    Object.keys(placeholders).forEach(placeholderKey => {\n      args.push(placeholderKey);\n      args.push(placeholders[placeholderKey]);\n    });\n  }\n\n  return localize(...args);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/common/translations/localize.ts\n");

/***/ }),

/***/ "./src/common/util/compute_rtl.ts":
/*!****************************************!*\
  !*** ./src/common/util/compute_rtl.ts ***!
  \****************************************/
/*! namespace exports */
/*! export computeRTL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export computeRTLDirection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export emitRTLDirection [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"computeRTL\": () => /* binding */ computeRTL,\n/* harmony export */   \"computeRTLDirection\": () => /* binding */ computeRTLDirection,\n/* harmony export */   \"emitRTLDirection\": () => /* binding */ emitRTLDirection\n/* harmony export */ });\nfunction computeRTL(hass) {\n  const lang = hass.language || \"en\";\n\n  if (hass.translationMetadata.translations[lang]) {\n    return hass.translationMetadata.translations[lang].isRTL || false;\n  }\n\n  return false;\n}\nfunction computeRTLDirection(hass) {\n  return emitRTLDirection(computeRTL(hass));\n}\nfunction emitRTLDirection(rtl) {\n  return rtl ? \"rtl\" : \"ltr\";\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL3V0aWwvY29tcHV0ZV9ydGwudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9jb21tb24vdXRpbC9jb21wdXRlX3J0bC50cz8yODZiIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IEhvbWVBc3Npc3RhbnQgfSBmcm9tIFwiLi4vLi4vdHlwZXNcIjtcblxuZXhwb3J0IGZ1bmN0aW9uIGNvbXB1dGVSVEwoaGFzczogSG9tZUFzc2lzdGFudCkge1xuICBjb25zdCBsYW5nID0gaGFzcy5sYW5ndWFnZSB8fCBcImVuXCI7XG4gIGlmIChoYXNzLnRyYW5zbGF0aW9uTWV0YWRhdGEudHJhbnNsYXRpb25zW2xhbmddKSB7XG4gICAgcmV0dXJuIGhhc3MudHJhbnNsYXRpb25NZXRhZGF0YS50cmFuc2xhdGlvbnNbbGFuZ10uaXNSVEwgfHwgZmFsc2U7XG4gIH1cbiAgcmV0dXJuIGZhbHNlO1xufVxuXG5leHBvcnQgZnVuY3Rpb24gY29tcHV0ZVJUTERpcmVjdGlvbihoYXNzOiBIb21lQXNzaXN0YW50KSB7XG4gIHJldHVybiBlbWl0UlRMRGlyZWN0aW9uKGNvbXB1dGVSVEwoaGFzcykpO1xufVxuXG5leHBvcnQgZnVuY3Rpb24gZW1pdFJUTERpcmVjdGlvbihydGw6IGJvb2xlYW4pIHtcbiAgcmV0dXJuIHJ0bCA/IFwicnRsXCIgOiBcImx0clwiO1xufVxuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7QUFFQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFFQTtBQUNBO0FBQ0E7QUFFQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/common/util/compute_rtl.ts\n");

/***/ }),

/***/ "./src/common/util/debounce.ts":
/*!*************************************!*\
  !*** ./src/common/util/debounce.ts ***!
  \*************************************/
/*! namespace exports */
/*! export debounce [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"debounce\": () => /* binding */ debounce\n/* harmony export */ });\n// From: https://davidwalsh.name/javascript-debounce-function\n// Returns a function, that, as long as it continues to be invoked, will not\n// be triggered. The function will be called after it stops being called for\n// N milliseconds. If `immediate` is passed, trigger the function on the\n// leading edge, instead of the trailing.\n// eslint-disable-next-line: ban-types\nconst debounce = (func, wait, immediate = false) => {\n  let timeout; // @ts-ignore\n\n  return function (...args) {\n    // @ts-ignore\n    // eslint-disable-next-line @typescript-eslint/no-this-alias\n    const context = this;\n\n    const later = () => {\n      timeout = null;\n\n      if (!immediate) {\n        func.apply(context, args);\n      }\n    };\n\n    const callNow = immediate && !timeout;\n    clearTimeout(timeout);\n    timeout = setTimeout(later, wait);\n\n    if (callNow) {\n      func.apply(context, args);\n    }\n  };\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tbW9uL3V0aWwvZGVib3VuY2UudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9jb21tb24vdXRpbC9kZWJvdW5jZS50cz9mNGU0Il0sInNvdXJjZXNDb250ZW50IjpbIi8vIEZyb206IGh0dHBzOi8vZGF2aWR3YWxzaC5uYW1lL2phdmFzY3JpcHQtZGVib3VuY2UtZnVuY3Rpb25cblxuLy8gUmV0dXJucyBhIGZ1bmN0aW9uLCB0aGF0LCBhcyBsb25nIGFzIGl0IGNvbnRpbnVlcyB0byBiZSBpbnZva2VkLCB3aWxsIG5vdFxuLy8gYmUgdHJpZ2dlcmVkLiBUaGUgZnVuY3Rpb24gd2lsbCBiZSBjYWxsZWQgYWZ0ZXIgaXQgc3RvcHMgYmVpbmcgY2FsbGVkIGZvclxuLy8gTiBtaWxsaXNlY29uZHMuIElmIGBpbW1lZGlhdGVgIGlzIHBhc3NlZCwgdHJpZ2dlciB0aGUgZnVuY3Rpb24gb24gdGhlXG4vLyBsZWFkaW5nIGVkZ2UsIGluc3RlYWQgb2YgdGhlIHRyYWlsaW5nLlxuLy8gZXNsaW50LWRpc2FibGUtbmV4dC1saW5lOiBiYW4tdHlwZXNcbmV4cG9ydCBjb25zdCBkZWJvdW5jZSA9IDxUIGV4dGVuZHMgKC4uLmFyZ3MpID0+IHVua25vd24+KFxuICBmdW5jOiBULFxuICB3YWl0LFxuICBpbW1lZGlhdGUgPSBmYWxzZVxuKTogVCA9PiB7XG4gIGxldCB0aW1lb3V0O1xuICAvLyBAdHMtaWdub3JlXG4gIHJldHVybiBmdW5jdGlvbiAoLi4uYXJncykge1xuICAgIC8vIEB0cy1pZ25vcmVcbiAgICAvLyBlc2xpbnQtZGlzYWJsZS1uZXh0LWxpbmUgQHR5cGVzY3JpcHQtZXNsaW50L25vLXRoaXMtYWxpYXNcbiAgICBjb25zdCBjb250ZXh0ID0gdGhpcztcbiAgICBjb25zdCBsYXRlciA9ICgpID0+IHtcbiAgICAgIHRpbWVvdXQgPSBudWxsO1xuICAgICAgaWYgKCFpbW1lZGlhdGUpIHtcbiAgICAgICAgZnVuYy5hcHBseShjb250ZXh0LCBhcmdzKTtcbiAgICAgIH1cbiAgICB9O1xuICAgIGNvbnN0IGNhbGxOb3cgPSBpbW1lZGlhdGUgJiYgIXRpbWVvdXQ7XG4gICAgY2xlYXJUaW1lb3V0KHRpbWVvdXQpO1xuICAgIHRpbWVvdXQgPSBzZXRUaW1lb3V0KGxhdGVyLCB3YWl0KTtcbiAgICBpZiAoY2FsbE5vdykge1xuICAgICAgZnVuYy5hcHBseShjb250ZXh0LCBhcmdzKTtcbiAgICB9XG4gIH07XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBQUE7QUFFQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFLQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/common/util/debounce.ts\n");

/***/ }),

/***/ "./src/common/util/deep-equal.ts":
/*!***************************************!*\
  !*** ./src/common/util/deep-equal.ts ***!
  \***************************************/
/*! namespace exports */
/*! export deepEqual [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"deepEqual\": () => /* binding */ deepEqual\n/* harmony export */ });\n// From https://github.com/epoberezkin/fast-deep-equal\n// MIT License - Copyright (c) 2017 Evgeny Poberezkin\nconst deepEqual = (a, b) => {\n  if (a === b) {\n    return true;\n  }\n\n  if (a && b && typeof a === \"object\" && typeof b === \"object\") {\n    if (a.constructor !== b.constructor) {\n      return false;\n    }\n\n    let i;\n    let length;\n\n    if (Array.isArray(a)) {\n      length = a.length;\n\n      if (length !== b.length) {\n        return false;\n      }\n\n      for (i = length; i-- !== 0;) {\n        if (!deepEqual(a[i], b[i])) {\n          return false;\n        }\n      }\n\n      return true;\n    }\n\n    if (a instanceof Map && b instanceof Map) {\n      if (a.size !== b.size) {\n        return false;\n      }\n\n      for (i of a.entries()) {\n        if (!b.has(i[0])) {\n          return false;\n        }\n      }\n\n      for (i of a.entries()) {\n        if (!deepEqual(i[1], b.get(i[0]))) {\n          return false;\n        }\n      }\n\n      return true;\n    }\n\n    if (a instanceof Set && b instanceof Set) {\n      if (a.size !== b.size) {\n        return false;\n      }\n\n      for (i of a.entries()) {\n        if (!b.has(i[0])) {\n          return false;\n        }\n      }\n\n      return true;\n    }\n\n    if (ArrayBuffer.isView(a) && ArrayBuffer.isView(b)) {\n      // @ts-ignore\n      length = a.length; // @ts-ignore\n\n      if (length !== b.length) {\n        return false;\n      }\n\n      for (i = length; i-- !== 0;) {\n        if (a[i] !== b[i]) {\n          return false;\n        }\n      }\n\n      return true;\n    }\n\n    if (a.constructor === RegExp) {\n      return a.source === b.source && a.flags === b.flags;\n    }\n\n    if (a.valueOf !== Object.prototype.valueOf) {\n      return a.valueOf() === b.valueOf();\n    }\n\n    if (a.toString !== Object.prototype.toString) {\n      return a.toString() === b.toString();\n    }\n\n    const keys = Object.keys(a);\n    length = keys.length;\n\n    if (length !== Object.keys(b).length) {\n      return false;\n    }\n\n    for (i = length; i-- !== 0;) {\n      if (!Object.prototype.hasOwnProperty.call(b, keys[i])) {\n        return false;\n      }\n    }\n\n    for (i = length; i-- !== 0;) {\n      const key = keys[i];\n\n      if (!deepEqual(a[key], b[key])) {\n        return false;\n      }\n    }\n\n    return true;\n  } // true if both NaN, false otherwise\n  // eslint-disable-next-line no-self-compare\n\n\n  return a !== a && b !== b;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/common/util/deep-equal.ts\n");

/***/ }),

/***/ "./src/components/ha-circular-progress.ts":
/*!************************************************!*\
  !*** ./src/components/ha-circular-progress.ts ***!
  \************************************************/
/*! namespace exports */
/*! export HaCircularProgress [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HaCircularProgress\": () => /* binding */ HaCircularProgress\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _material_mwc_circular_progress__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @material/mwc-circular-progress */ \"./node_modules/@material/mwc-circular-progress/mwc-circular-progress.js\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\nlet // @ts-ignore\nHaCircularProgress = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)(\"ha-circular-progress\")], function (_initialize, _CircularProgress) {\n  class HaCircularProgress extends _CircularProgress {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaCircularProgress,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        type: Boolean\n      })],\n      key: \"active\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"alt\",\n\n      value() {\n        return \"Loading\";\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"size\",\n\n      value() {\n        return \"medium\";\n      }\n\n    }, {\n      kind: \"set\",\n      key: \"density\",\n      value: // @ts-ignore\n      function density(_) {// just a dummy\n      }\n    }, {\n      kind: \"get\",\n      key: \"density\",\n      value: function density() {\n        switch (this.size) {\n          case \"tiny\":\n            return -8;\n\n          case \"small\":\n            return -5;\n\n          case \"medium\":\n            return 0;\n\n          case \"large\":\n            return 5;\n\n          default:\n            return 0;\n        }\n      } // @ts-ignore\n\n    }, {\n      kind: \"set\",\n      key: \"indeterminate\",\n      value: function indeterminate(_) {// just a dummy\n      }\n    }, {\n      kind: \"get\",\n      key: \"indeterminate\",\n      value: function indeterminate() {\n        return this.active;\n      }\n    }]\n  };\n}, _material_mwc_circular_progress__WEBPACK_IMPORTED_MODULE_1__.CircularProgress);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tcG9uZW50cy9oYS1jaXJjdWxhci1wcm9ncmVzcy50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbXBvbmVudHMvaGEtY2lyY3VsYXItcHJvZ3Jlc3MudHM/MjI2MiJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBjdXN0b21FbGVtZW50LCBwcm9wZXJ0eSB9IGZyb20gXCJsaXQtZWxlbWVudFwiO1xuaW1wb3J0IHsgQ2lyY3VsYXJQcm9ncmVzcyB9IGZyb20gXCJAbWF0ZXJpYWwvbXdjLWNpcmN1bGFyLXByb2dyZXNzXCI7XG5cbkBjdXN0b21FbGVtZW50KFwiaGEtY2lyY3VsYXItcHJvZ3Jlc3NcIilcbi8vIEB0cy1pZ25vcmVcbmV4cG9ydCBjbGFzcyBIYUNpcmN1bGFyUHJvZ3Jlc3MgZXh0ZW5kcyBDaXJjdWxhclByb2dyZXNzIHtcbiAgQHByb3BlcnR5KHsgdHlwZTogQm9vbGVhbiB9KVxuICBwdWJsaWMgYWN0aXZlID0gZmFsc2U7XG5cbiAgQHByb3BlcnR5KClcbiAgcHVibGljIGFsdCA9IFwiTG9hZGluZ1wiO1xuXG4gIEBwcm9wZXJ0eSgpXG4gIHB1YmxpYyBzaXplOiBcInRpbnlcIiB8IFwic21hbGxcIiB8IFwibWVkaXVtXCIgfCBcImxhcmdlXCIgPSBcIm1lZGl1bVwiO1xuXG4gIC8vIEB0cy1pZ25vcmVcbiAgcHVibGljIHNldCBkZW5zaXR5KF8pIHtcbiAgICAvLyBqdXN0IGEgZHVtbXlcbiAgfVxuXG4gIHB1YmxpYyBnZXQgZGVuc2l0eSgpIHtcbiAgICBzd2l0Y2ggKHRoaXMuc2l6ZSkge1xuICAgICAgY2FzZSBcInRpbnlcIjpcbiAgICAgICAgcmV0dXJuIC04O1xuICAgICAgY2FzZSBcInNtYWxsXCI6XG4gICAgICAgIHJldHVybiAtNTtcbiAgICAgIGNhc2UgXCJtZWRpdW1cIjpcbiAgICAgICAgcmV0dXJuIDA7XG4gICAgICBjYXNlIFwibGFyZ2VcIjpcbiAgICAgICAgcmV0dXJuIDU7XG4gICAgICBkZWZhdWx0OlxuICAgICAgICByZXR1cm4gMDtcbiAgICB9XG4gIH1cblxuICAvLyBAdHMtaWdub3JlXG4gIHB1YmxpYyBzZXQgaW5kZXRlcm1pbmF0ZShfKSB7XG4gICAgLy8ganVzdCBhIGR1bW15XG4gIH1cblxuICBwdWJsaWMgZ2V0IGluZGV0ZXJtaW5hdGUoKSB7XG4gICAgcmV0dXJuIHRoaXMuYWN0aXZlO1xuICB9XG59XG5cbmRlY2xhcmUgZ2xvYmFsIHtcbiAgaW50ZXJmYWNlIEhUTUxFbGVtZW50VGFnTmFtZU1hcCB7XG4gICAgXCJoYS1jaXJjdWxhci1wcm9ncmVzc1wiOiBIYUNpcmN1bGFyUHJvZ3Jlc3M7XG4gIH1cbn1cbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7QUFBQTtBQUNBO0FBSUE7QUFBQTtBQUZBO0FBRUE7QUFBQTtBQUNBO0FBREE7QUFBQTtBQUNBO0FBREE7QUFDQTtBQURBO0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFDQTtBQUFBO0FBREE7QUFDQTtBQURBO0FBQUE7QUFBQTtBQUNBO0FBREE7QUFBQTtBQUFBO0FBQUE7QUFDQTtBQURBO0FBQUE7QUFBQTtBQUNBO0FBREE7QUFBQTtBQUFBO0FBQUE7QUFDQTtBQURBO0FBQUE7QUFBQTtBQUNBO0FBREE7QUFBQTtBQUFBO0FBQUE7QUFXQTtBQUVBO0FBYkE7QUFBQTtBQUFBO0FBQUE7QUFnQkE7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBVkE7QUFZQTtBQUNBO0FBN0JBO0FBQUE7QUFBQTtBQUFBO0FBaUNBO0FBakNBO0FBQUE7QUFBQTtBQUFBO0FBb0NBO0FBQ0E7QUFyQ0E7QUFBQTtBQUFBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/components/ha-circular-progress.ts\n");

/***/ }),

/***/ "./src/components/ha-icon-button-arrow-prev.ts":
/*!*****************************************************!*\
  !*** ./src/components/ha-icon-button-arrow-prev.ts ***!
  \*****************************************************/
/*! namespace exports */
/*! export HaIconButtonArrowPrev [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HaIconButtonArrowPrev\": () => /* binding */ HaIconButtonArrowPrev\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _mdi_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @mdi/js */ \"./node_modules/@mdi/js/mdi.js\");\n/* harmony import */ var _material_mwc_icon_button_mwc_icon_button__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @material/mwc-icon-button/mwc-icon-button */ \"./node_modules/@material/mwc-icon-button/mwc-icon-button.js\");\n/* harmony import */ var _ha_svg_icon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ha-svg-icon */ \"./src/components/ha-svg-icon.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\nlet HaIconButtonArrowPrev = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)(\"ha-icon-button-arrow-prev\")], function (_initialize, _LitElement) {\n  class HaIconButtonArrowPrev extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaIconButtonArrowPrev,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        type: Boolean\n      })],\n      key: \"disabled\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"label\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.internalProperty)()],\n      key: \"_icon\",\n\n      value() {\n        return _mdi_js__WEBPACK_IMPORTED_MODULE_3__.mdiArrowLeft;\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"connectedCallback\",\n      value: function connectedCallback() {\n        _get(_getPrototypeOf(HaIconButtonArrowPrev.prototype), \"connectedCallback\", this).call(this); // wait to check for direction since otherwise direction is wrong even though top level is RTL\n\n\n        setTimeout(() => {\n          this._icon = window.getComputedStyle(this).direction === \"ltr\" ? _mdi_js__WEBPACK_IMPORTED_MODULE_3__.mdiArrowLeft : _mdi_js__WEBPACK_IMPORTED_MODULE_3__.mdiArrowRight;\n        }, 100);\n      }\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        var _this$hass;\n\n        return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n      <mwc-icon-button\n        .disabled=${this.disabled}\n        .label=${this.label || ((_this$hass = this.hass) === null || _this$hass === void 0 ? void 0 : _this$hass.localize(\"ui.common.back\")) || \"Back\"}\n      >\n        <ha-svg-icon .path=${this._icon}></ha-svg-icon>\n      </mwc-icon-button>\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/components/ha-icon-button-arrow-prev.ts\n");

/***/ }),

/***/ "./src/components/ha-menu-button.ts":
/*!******************************************!*\
  !*** ./src/components/ha-menu-button.ts ***!
  \******************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _material_mwc_icon_button__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-icon-button */ \"./node_modules/@material/mwc-icon-button/mwc-icon-button.js\");\n/* harmony import */ var _mdi_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @mdi/js */ \"./node_modules/@mdi/js/mdi.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n/* harmony import */ var _common_entity_compute_domain__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../common/entity/compute_domain */ \"./src/common/entity/compute_domain.ts\");\n/* harmony import */ var _data_persistent_notification__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../data/persistent_notification */ \"./src/data/persistent_notification.ts\");\n/* harmony import */ var _ha_svg_icon__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./ha-svg-icon */ \"./src/components/ha-svg-icon.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\n\n\n\n\nlet HaMenuButton = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.customElement)(\"ha-menu-button\")], function (_initialize, _LitElement) {\n  class HaMenuButton extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaMenuButton,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        type: Boolean\n      })],\n      key: \"hassio\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)()],\n      key: \"narrow\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_hasNotifications\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_alwaysVisible\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_attachNotifOnConnect\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_unsubNotifications\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"connectedCallback\",\n      value: function connectedCallback() {\n        _get(_getPrototypeOf(HaMenuButton.prototype), \"connectedCallback\", this).call(this);\n\n        if (this._attachNotifOnConnect) {\n          this._attachNotifOnConnect = false;\n\n          this._subscribeNotifications();\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"disconnectedCallback\",\n      value: function disconnectedCallback() {\n        _get(_getPrototypeOf(HaMenuButton.prototype), \"disconnectedCallback\", this).call(this);\n\n        if (this._unsubNotifications) {\n          this._attachNotifOnConnect = true;\n\n          this._unsubNotifications();\n\n          this._unsubNotifications = undefined;\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        const hasNotifications = (this.narrow || this.hass.dockedSidebar === \"always_hidden\") && (this._hasNotifications || Object.keys(this.hass.states).some(entityId => (0,_common_entity_compute_domain__WEBPACK_IMPORTED_MODULE_4__.computeDomain)(entityId) === \"configurator\"));\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n      <mwc-icon-button\n        aria-label=${this.hass.localize(\"ui.sidebar.sidebar_toggle\")}\n        @click=${this._toggleMenu}\n      >\n        <ha-svg-icon .path=${_mdi_js__WEBPACK_IMPORTED_MODULE_5__.mdiMenu}></ha-svg-icon>\n      </mwc-icon-button>\n      ${hasNotifications ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html` <div class=\"dot\"></div> ` : \"\"}\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated(changedProps) {\n        _get(_getPrototypeOf(HaMenuButton.prototype), \"firstUpdated\", this).call(this, changedProps);\n\n        if (!this.hassio) {\n          return;\n        } // This component is used on Hass.io too, but Hass.io might run the UI\n        // on older frontends too, that don't have an always visible menu button\n        // in the sidebar.\n\n\n        this._alwaysVisible = (Number(window.parent.frontendVersion) || 0) < 20190710;\n      }\n    }, {\n      kind: \"method\",\n      key: \"updated\",\n      value: function updated(changedProps) {\n        _get(_getPrototypeOf(HaMenuButton.prototype), \"updated\", this).call(this, changedProps);\n\n        if (!changedProps.has(\"narrow\") && !changedProps.has(\"hass\")) {\n          return;\n        }\n\n        const oldHass = changedProps.get(\"hass\");\n        const oldNarrow = changedProps.get(\"narrow\") || oldHass && oldHass.dockedSidebar === \"always_hidden\";\n        const newNarrow = this.narrow || this.hass.dockedSidebar === \"always_hidden\";\n\n        if (oldNarrow === newNarrow) {\n          return;\n        }\n\n        this.style.display = newNarrow || this._alwaysVisible ? \"initial\" : \"none\";\n\n        if (!newNarrow) {\n          this._hasNotifications = false;\n\n          if (this._unsubNotifications) {\n            this._unsubNotifications();\n\n            this._unsubNotifications = undefined;\n          }\n\n          return;\n        }\n\n        this._subscribeNotifications();\n      }\n    }, {\n      kind: \"method\",\n      key: \"_subscribeNotifications\",\n      value: function _subscribeNotifications() {\n        this._unsubNotifications = (0,_data_persistent_notification__WEBPACK_IMPORTED_MODULE_2__.subscribeNotifications)(this.hass.connection, notifications => {\n          this._hasNotifications = notifications.length > 0;\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"_toggleMenu\",\n      value: function _toggleMenu() {\n        (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_6__.fireEvent)(this, \"hass-toggle-menu\");\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.css`\n      :host {\n        position: relative;\n      }\n      .dot {\n        pointer-events: none;\n        position: absolute;\n        background-color: var(--accent-color);\n        width: 12px;\n        height: 12px;\n        top: 9px;\n        right: 7px;\n        border-radius: 50%;\n        border: 2px solid var(--app-header-background-color);\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/components/ha-menu-button.ts\n");

/***/ }),

/***/ "./src/components/ha-svg-icon.ts":
/*!***************************************!*\
  !*** ./src/components/ha-svg-icon.ts ***!
  \***************************************/
/*! namespace exports */
/*! export HaSvgIcon [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HaSvgIcon\": () => /* binding */ HaSvgIcon\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\nlet HaSvgIcon = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)(\"ha-svg-icon\")], function (_initialize, _LitElement) {\n  class HaSvgIcon extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaSvgIcon,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"path\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"viewBox\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_0__.svg`\n    <svg \n      viewBox=${this.viewBox || \"0 0 24 24\"}\n      preserveAspectRatio=\"xMidYMid meet\"\n      focusable=\"false\">\n      <g>\n      ${this.path ? lit_element__WEBPACK_IMPORTED_MODULE_0__.svg`<path d=${this.path}></path>` : \"\"}\n      </g>\n    </svg>`;\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_0__.css`\n      :host {\n        display: var(--ha-icon-display, inline-flex);\n        align-items: center;\n        justify-content: center;\n        position: relative;\n        vertical-align: middle;\n        fill: currentcolor;\n        width: var(--mdc-icon-size, 24px);\n        height: var(--mdc-icon-size, 24px);\n      }\n      svg {\n        width: 100%;\n        height: 100%;\n        pointer-events: none;\n        display: block;\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvY29tcG9uZW50cy9oYS1zdmctaWNvbi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2NvbXBvbmVudHMvaGEtc3ZnLWljb24udHM/ZTk2MSJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQge1xuICBjc3MsXG4gIENTU1Jlc3VsdCxcbiAgY3VzdG9tRWxlbWVudCxcbiAgTGl0RWxlbWVudCxcbiAgcHJvcGVydHksXG4gIHN2ZyxcbiAgU1ZHVGVtcGxhdGVSZXN1bHQsXG59IGZyb20gXCJsaXQtZWxlbWVudFwiO1xuXG5AY3VzdG9tRWxlbWVudChcImhhLXN2Zy1pY29uXCIpXG5leHBvcnQgY2xhc3MgSGFTdmdJY29uIGV4dGVuZHMgTGl0RWxlbWVudCB7XG4gIEBwcm9wZXJ0eSgpIHB1YmxpYyBwYXRoPzogc3RyaW5nO1xuXG4gIEBwcm9wZXJ0eSgpIHB1YmxpYyB2aWV3Qm94Pzogc3RyaW5nO1xuXG4gIHByb3RlY3RlZCByZW5kZXIoKTogU1ZHVGVtcGxhdGVSZXN1bHQge1xuICAgIHJldHVybiBzdmdgXG4gICAgPHN2ZyBcbiAgICAgIHZpZXdCb3g9JHt0aGlzLnZpZXdCb3ggfHwgXCIwIDAgMjQgMjRcIn1cbiAgICAgIHByZXNlcnZlQXNwZWN0UmF0aW89XCJ4TWlkWU1pZCBtZWV0XCJcbiAgICAgIGZvY3VzYWJsZT1cImZhbHNlXCI+XG4gICAgICA8Zz5cbiAgICAgICR7dGhpcy5wYXRoID8gc3ZnYDxwYXRoIGQ9JHt0aGlzLnBhdGh9PjwvcGF0aD5gIDogXCJcIn1cbiAgICAgIDwvZz5cbiAgICA8L3N2Zz5gO1xuICB9XG5cbiAgc3RhdGljIGdldCBzdHlsZXMoKTogQ1NTUmVzdWx0IHtcbiAgICByZXR1cm4gY3NzYFxuICAgICAgOmhvc3Qge1xuICAgICAgICBkaXNwbGF5OiB2YXIoLS1oYS1pY29uLWRpc3BsYXksIGlubGluZS1mbGV4KTtcbiAgICAgICAgYWxpZ24taXRlbXM6IGNlbnRlcjtcbiAgICAgICAganVzdGlmeS1jb250ZW50OiBjZW50ZXI7XG4gICAgICAgIHBvc2l0aW9uOiByZWxhdGl2ZTtcbiAgICAgICAgdmVydGljYWwtYWxpZ246IG1pZGRsZTtcbiAgICAgICAgZmlsbDogY3VycmVudGNvbG9yO1xuICAgICAgICB3aWR0aDogdmFyKC0tbWRjLWljb24tc2l6ZSwgMjRweCk7XG4gICAgICAgIGhlaWdodDogdmFyKC0tbWRjLWljb24tc2l6ZSwgMjRweCk7XG4gICAgICB9XG4gICAgICBzdmcge1xuICAgICAgICB3aWR0aDogMTAwJTtcbiAgICAgICAgaGVpZ2h0OiAxMDAlO1xuICAgICAgICBwb2ludGVyLWV2ZW50czogbm9uZTtcbiAgICAgICAgZGlzcGxheTogYmxvY2s7XG4gICAgICB9XG4gICAgYDtcbiAgfVxufVxuZGVjbGFyZSBnbG9iYWwge1xuICBpbnRlcmZhY2UgSFRNTEVsZW1lbnRUYWdOYW1lTWFwIHtcbiAgICBcImhhLXN2Zy1pY29uXCI6IEhhU3ZnSWNvbjtcbiAgfVxufVxuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBQUE7QUFXQTtBQURBO0FBQ0E7QUFBQTtBQUNBO0FBREE7QUFBQTtBQUNBO0FBREE7QUFDQTtBQURBO0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFBQTtBQUFBO0FBTUE7O0FBRUE7Ozs7QUFJQTs7QUFOQTtBQVNBO0FBZkE7QUFBQTtBQUFBO0FBQUE7QUFBQTtBQWtCQTs7Ozs7Ozs7Ozs7Ozs7Ozs7QUFBQTtBQWtCQTtBQXBDQTtBQUFBO0FBQUEiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/components/ha-svg-icon.ts\n");

/***/ }),

/***/ "./src/data/collection.ts":
/*!********************************!*\
  !*** ./src/data/collection.ts ***!
  \********************************/
/*! namespace exports */
/*! export getOptimisticCollection [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"getOptimisticCollection\": () => /* binding */ getOptimisticCollection\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n\n\n/**\n * Create an optimistic collection that includes a save function.\n * When the collection is saved, the collection is optimistically updated.\n * The update is reversed when the update failed.\n */\nconst getOptimisticCollection = (saveCollection, conn, key, fetchCollection, subscribeUpdates) => {\n  const updateKey = `${key}-optimistic`;\n  const collection = (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__.getCollection)(conn, key, fetchCollection, async (_conn, store) => {\n    // Subscribe to original updates\n    const subUpResult = subscribeUpdates ? subscribeUpdates(conn, store) : undefined; // Store the store\n\n    conn[updateKey] = store; // Unsub function to undo both\n\n    return () => {\n      if (subUpResult) {\n        subUpResult.then(unsub => unsub());\n      }\n\n      conn[updateKey] = undefined;\n    };\n  });\n  return { ...collection,\n\n    async save(data) {\n      const store = conn[updateKey];\n      let current; // Can be undefined if currently no subscribers\n\n      if (store) {\n        current = store.state;\n        store.setState(data, true);\n      }\n\n      try {\n        return await saveCollection(conn, data);\n      } catch (err) {\n        if (store) {\n          store.setState(current, true);\n        }\n\n        throw err;\n      }\n    }\n\n  };\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/data/collection.ts\n");

/***/ }),

/***/ "./src/data/connection-status.ts":
/*!***************************************!*\
  !*** ./src/data/connection-status.ts ***!
  \***************************************/
/*! namespace exports */
/*! export broadcastConnectionStatus [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"broadcastConnectionStatus\": () => /* binding */ broadcastConnectionStatus\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n/**\n * Broadcast connection status updates\n */\n\nconst broadcastConnectionStatus = status => {\n  (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(window, \"connection-status\", status);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS9jb25uZWN0aW9uLXN0YXR1cy50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2RhdGEvY29ubmVjdGlvbi1zdGF0dXMudHM/Yzc3OSJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbiAqIEJyb2FkY2FzdCBjb25uZWN0aW9uIHN0YXR1cyB1cGRhdGVzXG4gKi9cblxuaW1wb3J0IHsgZmlyZUV2ZW50LCBIQVNTRG9tRXZlbnQgfSBmcm9tIFwiLi4vY29tbW9uL2RvbS9maXJlX2V2ZW50XCI7XG5cbmV4cG9ydCB0eXBlIENvbm5lY3Rpb25TdGF0dXMgPSBcImNvbm5lY3RlZFwiIHwgXCJhdXRoLWludmFsaWRcIiB8IFwiZGlzY29ubmVjdGVkXCI7XG5cbmRlY2xhcmUgZ2xvYmFsIHtcbiAgLy8gZm9yIGZpcmUgZXZlbnRcbiAgaW50ZXJmYWNlIEhBU1NEb21FdmVudHMge1xuICAgIFwiY29ubmVjdGlvbi1zdGF0dXNcIjogQ29ubmVjdGlvblN0YXR1cztcbiAgfVxuXG4gIGludGVyZmFjZSBHbG9iYWxFdmVudEhhbmRsZXJzRXZlbnRNYXAge1xuICAgIFwiY29ubmVjdGlvbi1zdGF0dXNcIjogSEFTU0RvbUV2ZW50PENvbm5lY3Rpb25TdGF0dXM+O1xuICB9XG59XG5cbmV4cG9ydCBjb25zdCBicm9hZGNhc3RDb25uZWN0aW9uU3RhdHVzID0gKHN0YXR1czogQ29ubmVjdGlvblN0YXR1cykgPT4ge1xuICBmaXJlRXZlbnQod2luZG93LCBcImNvbm5lY3Rpb24tc3RhdHVzXCIsIHN0YXR1cyk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7OztBQUFBOzs7QUFJQTtBQWVBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/data/connection-status.ts\n");

/***/ }),

/***/ "./src/data/frontend.ts":
/*!******************************!*\
  !*** ./src/data/frontend.ts ***!
  \******************************/
/*! namespace exports */
/*! export fetchFrontendUserData [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getOptimisticFrontendUserDataCollection [provided] [no usage info] [missing usage info prevents renaming] */
/*! export saveFrontendUserData [provided] [no usage info] [missing usage info prevents renaming] */
/*! export subscribeFrontendUserData [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"fetchFrontendUserData\": () => /* binding */ fetchFrontendUserData,\n/* harmony export */   \"saveFrontendUserData\": () => /* binding */ saveFrontendUserData,\n/* harmony export */   \"getOptimisticFrontendUserDataCollection\": () => /* binding */ getOptimisticFrontendUserDataCollection,\n/* harmony export */   \"subscribeFrontendUserData\": () => /* binding */ subscribeFrontendUserData\n/* harmony export */ });\n/* harmony import */ var _collection__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./collection */ \"./src/data/collection.ts\");\n\nconst fetchFrontendUserData = async (conn, key) => {\n  const result = await conn.sendMessagePromise({\n    type: \"frontend/get_user_data\",\n    key\n  });\n  return result.value;\n};\nconst saveFrontendUserData = async (conn, key, value) => conn.sendMessagePromise({\n  type: \"frontend/set_user_data\",\n  key,\n  value\n});\nconst getOptimisticFrontendUserDataCollection = (conn, userDataKey) => (0,_collection__WEBPACK_IMPORTED_MODULE_0__.getOptimisticCollection)((_conn, data) => saveFrontendUserData(conn, userDataKey, // @ts-ignore\ndata), conn, `_frontendUserData-${userDataKey}`, () => fetchFrontendUserData(conn, userDataKey));\nconst subscribeFrontendUserData = (conn, userDataKey, onChange) => getOptimisticFrontendUserDataCollection(conn, userDataKey).subscribe(onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/data/frontend.ts\n");

/***/ }),

/***/ "./src/data/haptics.ts":
/*!*****************************!*\
  !*** ./src/data/haptics.ts ***!
  \*****************************/
/*! namespace exports */
/*! export forwardHaptic [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"forwardHaptic\": () => /* binding */ forwardHaptic\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n/**\n * Broadcast haptic feedback requests\n */\n // Allowed types are from iOS HIG.\n// https://developer.apple.com/design/human-interface-guidelines/ios/user-interaction/feedback/#haptics\n// Implementors on platforms other than iOS should attempt to match the patterns (shown in HIG) as closely as possible.\n\nconst forwardHaptic = hapticType => {\n  (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(window, \"haptic\", hapticType);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS9oYXB0aWNzLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvZGF0YS9oYXB0aWNzLnRzP2JmOGMiXSwic291cmNlc0NvbnRlbnQiOlsiLyoqXG4gKiBCcm9hZGNhc3QgaGFwdGljIGZlZWRiYWNrIHJlcXVlc3RzXG4gKi9cblxuaW1wb3J0IHsgZmlyZUV2ZW50LCBIQVNTRG9tRXZlbnQgfSBmcm9tIFwiLi4vY29tbW9uL2RvbS9maXJlX2V2ZW50XCI7XG5cbi8vIEFsbG93ZWQgdHlwZXMgYXJlIGZyb20gaU9TIEhJRy5cbi8vIGh0dHBzOi8vZGV2ZWxvcGVyLmFwcGxlLmNvbS9kZXNpZ24vaHVtYW4taW50ZXJmYWNlLWd1aWRlbGluZXMvaW9zL3VzZXItaW50ZXJhY3Rpb24vZmVlZGJhY2svI2hhcHRpY3Ncbi8vIEltcGxlbWVudG9ycyBvbiBwbGF0Zm9ybXMgb3RoZXIgdGhhbiBpT1Mgc2hvdWxkIGF0dGVtcHQgdG8gbWF0Y2ggdGhlIHBhdHRlcm5zIChzaG93biBpbiBISUcpIGFzIGNsb3NlbHkgYXMgcG9zc2libGUuXG5leHBvcnQgdHlwZSBIYXB0aWNUeXBlID1cbiAgfCBcInN1Y2Nlc3NcIlxuICB8IFwid2FybmluZ1wiXG4gIHwgXCJmYWlsdXJlXCJcbiAgfCBcImxpZ2h0XCJcbiAgfCBcIm1lZGl1bVwiXG4gIHwgXCJoZWF2eVwiXG4gIHwgXCJzZWxlY3Rpb25cIjtcblxuZGVjbGFyZSBnbG9iYWwge1xuICAvLyBmb3IgZmlyZSBldmVudFxuICBpbnRlcmZhY2UgSEFTU0RvbUV2ZW50cyB7XG4gICAgaGFwdGljOiBIYXB0aWNUeXBlO1xuICB9XG5cbiAgaW50ZXJmYWNlIEdsb2JhbEV2ZW50SGFuZGxlcnNFdmVudE1hcCB7XG4gICAgaGFwdGljOiBIQVNTRG9tRXZlbnQ8SGFwdGljVHlwZT47XG4gIH1cbn1cblxuZXhwb3J0IGNvbnN0IGZvcndhcmRIYXB0aWMgPSAoaGFwdGljVHlwZTogSGFwdGljVHlwZSkgPT4ge1xuICBmaXJlRXZlbnQod2luZG93LCBcImhhcHRpY1wiLCBoYXB0aWNUeXBlKTtcbn07XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7OztBQUlBO0FBR0E7QUFDQTtBQUNBO0FBb0JBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/data/haptics.ts\n");

/***/ }),

/***/ "./src/data/panel.ts":
/*!***************************!*\
  !*** ./src/data/panel.ts ***!
  \***************************/
/*! namespace exports */
/*! export DEFAULT_PANEL [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getDefaultPanel [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getPanelIcon [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getPanelNameTranslationKey [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getPanelTitle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getStorageDefaultPanelUrlPath [provided] [no usage info] [missing usage info prevents renaming] */
/*! export setDefaultPanel [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"DEFAULT_PANEL\": () => /* binding */ DEFAULT_PANEL,\n/* harmony export */   \"getStorageDefaultPanelUrlPath\": () => /* binding */ getStorageDefaultPanelUrlPath,\n/* harmony export */   \"setDefaultPanel\": () => /* binding */ setDefaultPanel,\n/* harmony export */   \"getDefaultPanel\": () => /* binding */ getDefaultPanel,\n/* harmony export */   \"getPanelNameTranslationKey\": () => /* binding */ getPanelNameTranslationKey,\n/* harmony export */   \"getPanelTitle\": () => /* binding */ getPanelTitle,\n/* harmony export */   \"getPanelIcon\": () => /* binding */ getPanelIcon\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n\n\n/** Panel to show when no panel is picked. */\nconst DEFAULT_PANEL = \"lovelace\";\nconst getStorageDefaultPanelUrlPath = () => localStorage.defaultPanel ? JSON.parse(localStorage.defaultPanel) : DEFAULT_PANEL;\nconst setDefaultPanel = (element, urlPath) => {\n  (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(element, \"hass-default-panel\", {\n    defaultPanel: urlPath\n  });\n};\nconst getDefaultPanel = hass => hass.panels[hass.defaultPanel] ? hass.panels[hass.defaultPanel] : hass.panels[DEFAULT_PANEL];\nconst getPanelNameTranslationKey = panel => {\n  if (panel.url_path === \"lovelace\") {\n    return \"panel.states\";\n  }\n\n  if (panel.url_path === \"profile\") {\n    return \"panel.profile\";\n  }\n\n  return `panel.${panel.title}`;\n};\nconst getPanelTitle = hass => {\n  if (!hass.panels) {\n    return undefined;\n  }\n\n  const panel = Object.values(hass.panels).find(p => p.url_path === hass.panelUrl);\n\n  if (!panel) {\n    return undefined;\n  }\n\n  const translationKey = getPanelNameTranslationKey(panel);\n  return hass.localize(translationKey) || panel.title || undefined;\n};\nconst getPanelIcon = panel => {\n  if (!panel.icon) {\n    switch (panel.component_name) {\n      case \"profile\":\n        return \"hass:account\";\n\n      case \"lovelace\":\n        return \"hass:view-dashboard\";\n    }\n  }\n\n  return panel.icon;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/data/panel.ts\n");

/***/ }),

/***/ "./src/data/persistent_notification.ts":
/*!*********************************************!*\
  !*** ./src/data/persistent_notification.ts ***!
  \*********************************************/
/*! namespace exports */
/*! export subscribeNotifications [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"subscribeNotifications\": () => /* binding */ subscribeNotifications\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n\n\nconst fetchNotifications = conn => conn.sendMessagePromise({\n  type: \"persistent_notification/get\"\n});\n\nconst subscribeUpdates = (conn, store) => conn.subscribeEvents(() => fetchNotifications(conn).then(ntf => store.setState(ntf, true)), \"persistent_notifications_updated\");\n\nconst subscribeNotifications = (conn, onChange) => (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__.createCollection)(\"_ntf\", fetchNotifications, subscribeUpdates, conn, onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS9wZXJzaXN0ZW50X25vdGlmaWNhdGlvbi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2RhdGEvcGVyc2lzdGVudF9ub3RpZmljYXRpb24udHM/ODIyYyJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQge1xuICBDb25uZWN0aW9uLFxuICBjcmVhdGVDb2xsZWN0aW9uLFxuICBIYXNzRW50aXR5LFxufSBmcm9tIFwiaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0XCI7XG5cbmV4cG9ydCBpbnRlcmZhY2UgUGVyc2l0ZW50Tm90aWZpY2F0aW9uRW50aXR5IGV4dGVuZHMgSGFzc0VudGl0eSB7XG4gIG5vdGlmaWNhdGlvbl9pZD86IHN0cmluZztcbiAgY3JlYXRlZF9hdD86IHN0cmluZztcbiAgdGl0bGU/OiBzdHJpbmc7XG4gIG1lc3NhZ2U/OiBzdHJpbmc7XG59XG5cbmV4cG9ydCBpbnRlcmZhY2UgUGVyc2lzdGVudE5vdGlmaWNhdGlvbiB7XG4gIGNyZWF0ZWRfYXQ6IHN0cmluZztcbiAgbWVzc2FnZTogc3RyaW5nO1xuICBub3RpZmljYXRpb25faWQ6IHN0cmluZztcbiAgdGl0bGU6IHN0cmluZztcbiAgc3RhdHVzOiBcInJlYWRcIiB8IFwidW5yZWFkXCI7XG59XG5cbmNvbnN0IGZldGNoTm90aWZpY2F0aW9ucyA9IChjb25uKSA9PlxuICBjb25uLnNlbmRNZXNzYWdlUHJvbWlzZSh7XG4gICAgdHlwZTogXCJwZXJzaXN0ZW50X25vdGlmaWNhdGlvbi9nZXRcIixcbiAgfSk7XG5cbmNvbnN0IHN1YnNjcmliZVVwZGF0ZXMgPSAoY29ubiwgc3RvcmUpID0+XG4gIGNvbm4uc3Vic2NyaWJlRXZlbnRzKFxuICAgICgpID0+IGZldGNoTm90aWZpY2F0aW9ucyhjb25uKS50aGVuKChudGYpID0+IHN0b3JlLnNldFN0YXRlKG50ZiwgdHJ1ZSkpLFxuICAgIFwicGVyc2lzdGVudF9ub3RpZmljYXRpb25zX3VwZGF0ZWRcIlxuICApO1xuXG5leHBvcnQgY29uc3Qgc3Vic2NyaWJlTm90aWZpY2F0aW9ucyA9IChcbiAgY29ubjogQ29ubmVjdGlvbixcbiAgb25DaGFuZ2U6IChub3RpZmljYXRpb25zOiBQZXJzaXN0ZW50Tm90aWZpY2F0aW9uW10pID0+IHZvaWRcbikgPT5cbiAgY3JlYXRlQ29sbGVjdGlvbjxQZXJzaXN0ZW50Tm90aWZpY2F0aW9uW10+KFxuICAgIFwiX250ZlwiLFxuICAgIGZldGNoTm90aWZpY2F0aW9ucyxcbiAgICBzdWJzY3JpYmVVcGRhdGVzLFxuICAgIGNvbm4sXG4gICAgb25DaGFuZ2VcbiAgKTtcbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7QUFBQTtBQUNBO0FBb0JBO0FBRUE7QUFEQTtBQUNBO0FBR0E7QUFDQTtBQUtBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/data/persistent_notification.ts\n");

/***/ }),

/***/ "./src/data/translation.ts":
/*!*********************************!*\
  !*** ./src/data/translation.ts ***!
  \*********************************/
/*! namespace exports */
/*! export fetchTranslationPreferences [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getHassTranslations [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getHassTranslationsPre109 [provided] [no usage info] [missing usage info prevents renaming] */
/*! export saveTranslationPreferences [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"fetchTranslationPreferences\": () => /* binding */ fetchTranslationPreferences,\n/* harmony export */   \"saveTranslationPreferences\": () => /* binding */ saveTranslationPreferences,\n/* harmony export */   \"getHassTranslations\": () => /* binding */ getHassTranslations,\n/* harmony export */   \"getHassTranslationsPre109\": () => /* binding */ getHassTranslationsPre109\n/* harmony export */ });\n/* harmony import */ var _frontend__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./frontend */ \"./src/data/frontend.ts\");\n\nconst fetchTranslationPreferences = hass => (0,_frontend__WEBPACK_IMPORTED_MODULE_0__.fetchFrontendUserData)(hass.connection, \"language\");\nconst saveTranslationPreferences = (hass, data) => (0,_frontend__WEBPACK_IMPORTED_MODULE_0__.saveFrontendUserData)(hass.connection, \"language\", data);\nconst getHassTranslations = async (hass, language, category, integration, config_flow) => {\n  const result = await hass.callWS({\n    type: \"frontend/get_translations\",\n    language,\n    category,\n    integration,\n    config_flow\n  });\n  return result.resources;\n};\nconst getHassTranslationsPre109 = async (hass, language) => {\n  const result = await hass.callWS({\n    type: \"frontend/get_translations\",\n    language\n  });\n  return result.resources;\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/data/translation.ts\n");

/***/ }),

/***/ "./src/data/ws-panels.ts":
/*!*******************************!*\
  !*** ./src/data/ws-panels.ts ***!
  \*******************************/
/*! namespace exports */
/*! export subscribePanels [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"subscribePanels\": () => /* binding */ subscribePanels\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n\n\nconst fetchPanels = conn => conn.sendMessagePromise({\n  type: \"get_panels\"\n});\n\nconst subscribeUpdates = (conn, store) => conn.subscribeEvents(() => fetchPanels(conn).then(panels => store.setState(panels, true)), \"panels_updated\");\n\nconst subscribePanels = (conn, onChange) => (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__.createCollection)(\"_pnl\", fetchPanels, subscribeUpdates, conn, onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS93cy1wYW5lbHMudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9kYXRhL3dzLXBhbmVscy50cz82ZWE0Il0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IENvbm5lY3Rpb24sIGNyZWF0ZUNvbGxlY3Rpb24gfSBmcm9tIFwiaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0XCI7XG5pbXBvcnQgeyBQYW5lbHMgfSBmcm9tIFwiLi4vdHlwZXNcIjtcblxuY29uc3QgZmV0Y2hQYW5lbHMgPSAoY29ubikgPT5cbiAgY29ubi5zZW5kTWVzc2FnZVByb21pc2Uoe1xuICAgIHR5cGU6IFwiZ2V0X3BhbmVsc1wiLFxuICB9KTtcblxuY29uc3Qgc3Vic2NyaWJlVXBkYXRlcyA9IChjb25uLCBzdG9yZSkgPT5cbiAgY29ubi5zdWJzY3JpYmVFdmVudHMoXG4gICAgKCkgPT4gZmV0Y2hQYW5lbHMoY29ubikudGhlbigocGFuZWxzKSA9PiBzdG9yZS5zZXRTdGF0ZShwYW5lbHMsIHRydWUpKSxcbiAgICBcInBhbmVsc191cGRhdGVkXCJcbiAgKTtcblxuZXhwb3J0IGNvbnN0IHN1YnNjcmliZVBhbmVscyA9IChcbiAgY29ubjogQ29ubmVjdGlvbixcbiAgb25DaGFuZ2U6IChwYW5lbHM6IFBhbmVscykgPT4gdm9pZFxuKSA9PlxuICBjcmVhdGVDb2xsZWN0aW9uPFBhbmVscz4oXG4gICAgXCJfcG5sXCIsXG4gICAgZmV0Y2hQYW5lbHMsXG4gICAgc3Vic2NyaWJlVXBkYXRlcyxcbiAgICBjb25uLFxuICAgIG9uQ2hhbmdlXG4gICk7XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7QUFDQTtBQUVBO0FBRUE7QUFEQTtBQUNBO0FBR0E7QUFDQTtBQUtBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/data/ws-panels.ts\n");

/***/ }),

/***/ "./src/data/ws-themes.ts":
/*!*******************************!*\
  !*** ./src/data/ws-themes.ts ***!
  \*******************************/
/*! namespace exports */
/*! export subscribeThemes [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"subscribeThemes\": () => /* binding */ subscribeThemes\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n\n\nconst fetchThemes = conn => conn.sendMessagePromise({\n  type: \"frontend/get_themes\"\n});\n\nconst subscribeUpdates = (conn, store) => conn.subscribeEvents(() => fetchThemes(conn).then(data => store.setState(data, true)), \"themes_updated\");\n\nconst subscribeThemes = (conn, onChange) => (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__.createCollection)(\"_thm\", fetchThemes, subscribeUpdates, conn, onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS93cy10aGVtZXMudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9kYXRhL3dzLXRoZW1lcy50cz9kMGQxIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IENvbm5lY3Rpb24sIGNyZWF0ZUNvbGxlY3Rpb24gfSBmcm9tIFwiaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0XCI7XG5pbXBvcnQgeyBUaGVtZXMgfSBmcm9tIFwiLi4vdHlwZXNcIjtcblxuY29uc3QgZmV0Y2hUaGVtZXMgPSAoY29ubikgPT5cbiAgY29ubi5zZW5kTWVzc2FnZVByb21pc2Uoe1xuICAgIHR5cGU6IFwiZnJvbnRlbmQvZ2V0X3RoZW1lc1wiLFxuICB9KTtcblxuY29uc3Qgc3Vic2NyaWJlVXBkYXRlcyA9IChjb25uLCBzdG9yZSkgPT5cbiAgY29ubi5zdWJzY3JpYmVFdmVudHMoXG4gICAgKCkgPT4gZmV0Y2hUaGVtZXMoY29ubikudGhlbigoZGF0YSkgPT4gc3RvcmUuc2V0U3RhdGUoZGF0YSwgdHJ1ZSkpLFxuICAgIFwidGhlbWVzX3VwZGF0ZWRcIlxuICApO1xuXG5leHBvcnQgY29uc3Qgc3Vic2NyaWJlVGhlbWVzID0gKFxuICBjb25uOiBDb25uZWN0aW9uLFxuICBvbkNoYW5nZTogKHRoZW1lczogVGhlbWVzKSA9PiB2b2lkXG4pID0+XG4gIGNyZWF0ZUNvbGxlY3Rpb248VGhlbWVzPihcbiAgICBcIl90aG1cIixcbiAgICBmZXRjaFRoZW1lcyxcbiAgICBzdWJzY3JpYmVVcGRhdGVzLFxuICAgIGNvbm4sXG4gICAgb25DaGFuZ2VcbiAgKTtcbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7QUFBQTtBQUNBO0FBRUE7QUFFQTtBQURBO0FBQ0E7QUFHQTtBQUNBO0FBS0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/data/ws-themes.ts\n");

/***/ }),

/***/ "./src/data/ws-user.ts":
/*!*****************************!*\
  !*** ./src/data/ws-user.ts ***!
  \*****************************/
/*! namespace exports */
/*! export subscribeUser [provided] [no usage info] [missing usage info prevents renaming] */
/*! export userCollection [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"userCollection\": () => /* binding */ userCollection,\n/* harmony export */   \"subscribeUser\": () => /* binding */ subscribeUser\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/collection.js\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/commands.js\");\n\nconst userCollection = conn => (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_0__.getCollection)(conn, \"_usr\", () => (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__.getUser)(conn), undefined);\nconst subscribeUser = (conn, onChange) => userCollection(conn).subscribe(onChange);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGF0YS93cy11c2VyLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvZGF0YS93cy11c2VyLnRzPzQ2NzUiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHtcbiAgQ29ubmVjdGlvbixcbiAgZ2V0Q29sbGVjdGlvbixcbiAgZ2V0VXNlcixcbn0gZnJvbSBcImhvbWUtYXNzaXN0YW50LWpzLXdlYnNvY2tldFwiO1xuaW1wb3J0IHsgQ3VycmVudFVzZXIgfSBmcm9tIFwiLi4vdHlwZXNcIjtcblxuZXhwb3J0IGNvbnN0IHVzZXJDb2xsZWN0aW9uID0gKGNvbm46IENvbm5lY3Rpb24pID0+XG4gIGdldENvbGxlY3Rpb24oXG4gICAgY29ubixcbiAgICBcIl91c3JcIixcbiAgICAoKSA9PiBnZXRVc2VyKGNvbm4pIGFzIFByb21pc2U8Q3VycmVudFVzZXI+LFxuICAgIHVuZGVmaW5lZFxuICApO1xuXG5leHBvcnQgY29uc3Qgc3Vic2NyaWJlVXNlciA9IChcbiAgY29ubjogQ29ubmVjdGlvbixcbiAgb25DaGFuZ2U6ICh1c2VyOiBDdXJyZW50VXNlcikgPT4gdm9pZFxuKSA9PiB1c2VyQ29sbGVjdGlvbihjb25uKS5zdWJzY3JpYmUob25DaGFuZ2UpO1xuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7O0FBQUE7QUFPQTtBQVFBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/data/ws-user.ts\n");

/***/ }),

/***/ "./src/dialogs/make-dialog-manager.ts":
/*!********************************************!*\
  !*** ./src/dialogs/make-dialog-manager.ts ***!
  \********************************************/
/*! namespace exports */
/*! export closeDialog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export makeDialogManager [provided] [no usage info] [missing usage info prevents renaming] */
/*! export showDialog [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"showDialog\": () => /* binding */ showDialog,\n/* harmony export */   \"closeDialog\": () => /* binding */ closeDialog,\n/* harmony export */   \"makeDialogManager\": () => /* binding */ makeDialogManager\n/* harmony export */ });\nconst LOADED = {};\nconst showDialog = async (element, root, dialogTag, dialogParams, dialogImport) => {\n  var _history$state, _history$state2;\n\n  if (!(dialogTag in LOADED)) {\n    if (!dialogImport) {\n      return;\n    }\n\n    LOADED[dialogTag] = dialogImport().then(() => {\n      const dialogEl = document.createElement(dialogTag);\n      element.provideHass(dialogEl);\n      root.appendChild(dialogEl);\n      return dialogEl;\n    });\n  }\n\n  history.replaceState({\n    dialog: dialogTag,\n    open: false,\n    oldState: ((_history$state = history.state) === null || _history$state === void 0 ? void 0 : _history$state.open) && ((_history$state2 = history.state) === null || _history$state2 === void 0 ? void 0 : _history$state2.dialog) !== dialogTag ? history.state : null\n  }, \"\");\n\n  try {\n    history.pushState({\n      dialog: dialogTag,\n      dialogParams: dialogParams,\n      open: true\n    }, \"\");\n  } catch (err) {\n    // dialogParams could not be cloned, probably contains callback\n    history.pushState({\n      dialog: dialogTag,\n      dialogParams: null,\n      open: true\n    }, \"\");\n  }\n\n  const dialogElement = await LOADED[dialogTag];\n  dialogElement.showDialog(dialogParams);\n};\nconst closeDialog = async dialogTag => {\n  if (!(dialogTag in LOADED)) {\n    return true;\n  }\n\n  const dialogElement = await LOADED[dialogTag];\n\n  if (dialogElement.closeDialog) {\n    return dialogElement.closeDialog() !== false;\n  }\n\n  return true;\n};\nconst makeDialogManager = (element, root) => {\n  element.addEventListener(\"show-dialog\", e => {\n    const {\n      dialogTag,\n      dialogImport,\n      dialogParams\n    } = e.detail;\n    showDialog(element, root, dialogTag, dialogParams, dialogImport);\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/dialogs/make-dialog-manager.ts\n");

/***/ }),

/***/ "./src/dialogs/notifications/show-notification-drawer.ts":
/*!***************************************************************!*\
  !*** ./src/dialogs/notifications/show-notification-drawer.ts ***!
  \***************************************************************/
/*! namespace exports */
/*! export showNotificationDrawer [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"showNotificationDrawer\": () => /* binding */ showNotificationDrawer\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n\nconst showNotificationDrawer = (element, dialogParams) => {\n  (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(element, \"show-dialog\", {\n    dialogTag: \"notification-drawer\",\n    // Not in TS yet\n    dialogImport: () => Promise.all(/*! import() */[__webpack_require__.e(\"vendors-node_modules_polymer_paper-tooltip_paper-tooltip_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-markdown_ts\"), __webpack_require__.e(\"node_modules_comlink_dist_esm_comlink_mjs-src_dialogs_notifications_notification-drawer_js\")]).then(__webpack_require__.bind(__webpack_require__, /*! ./notification-drawer */ \"./src/dialogs/notifications/notification-drawer.js\")),\n    dialogParams\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGlhbG9ncy9ub3RpZmljYXRpb25zL3Nob3ctbm90aWZpY2F0aW9uLWRyYXdlci50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL2RpYWxvZ3Mvbm90aWZpY2F0aW9ucy9zaG93LW5vdGlmaWNhdGlvbi1kcmF3ZXIudHM/MGYwMCJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBmaXJlRXZlbnQgfSBmcm9tIFwiLi4vLi4vY29tbW9uL2RvbS9maXJlX2V2ZW50XCI7XG5cbmV4cG9ydCBpbnRlcmZhY2UgTm90aWZpY2F0aW9uRHJhd2VyUGFyYW1zIHtcbiAgbmFycm93OiBib29sZWFuO1xufVxuXG5leHBvcnQgY29uc3Qgc2hvd05vdGlmaWNhdGlvbkRyYXdlciA9IChcbiAgZWxlbWVudDogSFRNTEVsZW1lbnQsXG4gIGRpYWxvZ1BhcmFtczogTm90aWZpY2F0aW9uRHJhd2VyUGFyYW1zXG4pOiB2b2lkID0+IHtcbiAgZmlyZUV2ZW50KGVsZW1lbnQsIFwic2hvdy1kaWFsb2dcIiwge1xuICAgIGRpYWxvZ1RhZzogXCJub3RpZmljYXRpb24tZHJhd2VyXCIgYXMgYW55LCAvLyBOb3QgaW4gVFMgeWV0XG4gICAgZGlhbG9nSW1wb3J0OiAoKSA9PiBpbXBvcnQoXCIuL25vdGlmaWNhdGlvbi1kcmF3ZXJcIiksXG4gICAgZGlhbG9nUGFyYW1zLFxuICB9KTtcbn07XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7QUFNQTtBQUlBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFIQTtBQUtBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/dialogs/notifications/show-notification-drawer.ts\n");

/***/ }),

/***/ "./src/dialogs/quick-bar/show-dialog-quick-bar.ts":
/*!********************************************************!*\
  !*** ./src/dialogs/quick-bar/show-dialog-quick-bar.ts ***!
  \********************************************************/
/*! namespace exports */
/*! export loadQuickBar [provided] [no usage info] [missing usage info prevents renaming] */
/*! export showQuickBar [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"loadQuickBar\": () => /* binding */ loadQuickBar,\n/* harmony export */   \"showQuickBar\": () => /* binding */ showQuickBar\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n\nconst loadQuickBar = () => Promise.all(/*! import() | quick-bar-dialog */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-dialog_mwc-dialog_js\"), __webpack_require__.e(\"vendors-node_modules_lit-virtualizer_lit-virtualizer_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-item_paper-item-body_js-node_modules_polymer_paper-item_pa-081ef1\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_iron-icon_iron-icon_j-af4999\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-dialog_ts\"), __webpack_require__.e(\"src_common_search_search-input_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_components_ha-header-bar_ts\"), __webpack_require__.e(\"panel-config\"), __webpack_require__.e(\"quick-bar-dialog\")]).then(__webpack_require__.bind(__webpack_require__, /*! ./ha-quick-bar */ \"./src/dialogs/quick-bar/ha-quick-bar.ts\"));\nconst showQuickBar = (element, dialogParams) => {\n  (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(element, \"show-dialog\", {\n    dialogTag: \"ha-quick-bar\",\n    dialogImport: loadQuickBar,\n    dialogParams\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZGlhbG9ncy9xdWljay1iYXIvc2hvdy1kaWFsb2ctcXVpY2stYmFyLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvZGlhbG9ncy9xdWljay1iYXIvc2hvdy1kaWFsb2ctcXVpY2stYmFyLnRzP2YyMGQiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgZmlyZUV2ZW50IH0gZnJvbSBcIi4uLy4uL2NvbW1vbi9kb20vZmlyZV9ldmVudFwiO1xuXG5leHBvcnQgaW50ZXJmYWNlIFF1aWNrQmFyUGFyYW1zIHtcbiAgZW50aXR5RmlsdGVyPzogc3RyaW5nO1xuICBjb21tYW5kTW9kZT86IGJvb2xlYW47XG59XG5cbmV4cG9ydCBjb25zdCBsb2FkUXVpY2tCYXIgPSAoKSA9PlxuICBpbXBvcnQoLyogd2VicGFja0NodW5rTmFtZTogXCJxdWljay1iYXItZGlhbG9nXCIgKi8gXCIuL2hhLXF1aWNrLWJhclwiKTtcblxuZXhwb3J0IGNvbnN0IHNob3dRdWlja0JhciA9IChcbiAgZWxlbWVudDogSFRNTEVsZW1lbnQsXG4gIGRpYWxvZ1BhcmFtczogUXVpY2tCYXJQYXJhbXNcbik6IHZvaWQgPT4ge1xuICBmaXJlRXZlbnQoZWxlbWVudCwgXCJzaG93LWRpYWxvZ1wiLCB7XG4gICAgZGlhbG9nVGFnOiBcImhhLXF1aWNrLWJhclwiLFxuICAgIGRpYWxvZ0ltcG9ydDogbG9hZFF1aWNrQmFyLFxuICAgIGRpYWxvZ1BhcmFtcyxcbiAgfSk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7QUFBQTtBQU9BLGc4Q0FDQTtBQUVBO0FBSUE7QUFDQTtBQUNBO0FBQ0E7QUFIQTtBQUtBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/dialogs/quick-bar/show-dialog-quick-bar.ts\n");

/***/ }),

/***/ "./src/entrypoints/app.ts":
/*!********************************!*\
  !*** ./src/entrypoints/app.ts ***!
  \********************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.n, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_lib_utils_settings__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/lib/utils/settings */ \"./node_modules/@polymer/polymer/lib/utils/settings.js\");\n/* harmony import */ var _resources_roboto__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../resources/roboto */ \"./src/resources/roboto.js\");\n/* harmony import */ var _resources_roboto__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_resources_roboto__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _resources_ha_style__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../resources/ha-style */ \"./src/resources/ha-style.ts\");\n/* harmony import */ var _layouts_home_assistant__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../layouts/home-assistant */ \"./src/layouts/home-assistant.ts\");\n/* harmony import */ var _util_legacy_support__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/legacy-support */ \"./src/util/legacy-support.js\");\n\n\n\n\n\n(0,_polymer_polymer_lib_utils_settings__WEBPACK_IMPORTED_MODULE_0__.setPassiveTouchGestures)(true);\nwindow.frontendVersion = \"20201111.2\";//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvZW50cnlwb2ludHMvYXBwLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvZW50cnlwb2ludHMvYXBwLnRzP2IwZjgiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgc2V0UGFzc2l2ZVRvdWNoR2VzdHVyZXMgfSBmcm9tIFwiQHBvbHltZXIvcG9seW1lci9saWIvdXRpbHMvc2V0dGluZ3NcIjtcbmltcG9ydCBcIi4uL3Jlc291cmNlcy9yb2JvdG9cIjtcbmltcG9ydCBcIi4uL3Jlc291cmNlcy9oYS1zdHlsZVwiO1xuaW1wb3J0IFwiLi4vbGF5b3V0cy9ob21lLWFzc2lzdGFudFwiO1xuaW1wb3J0IFwiLi4vdXRpbC9sZWdhY3ktc3VwcG9ydFwiO1xuXG5zZXRQYXNzaXZlVG91Y2hHZXN0dXJlcyh0cnVlKTtcblxuKHdpbmRvdyBhcyBhbnkpLmZyb250ZW5kVmVyc2lvbiA9IF9fVkVSU0lPTl9fO1xuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7O0FBQUE7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUVBO0FBRUEiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/entrypoints/app.ts\n");

/***/ }),

/***/ "./src/layouts/ha-init-page.ts":
/*!*************************************!*\
  !*** ./src/layouts/ha-init-page.ts ***!
  \*************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _material_mwc_button__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-button */ \"./node_modules/@material/mwc-button/mwc-button.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _util_init_skeleton__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/init-skeleton */ \"./src/util/init-skeleton.ts\");\n/* harmony import */ var _components_ha_circular_progress__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../components/ha-circular-progress */ \"./src/components/ha-circular-progress.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\n\n\n\nlet HaInitPage = _decorate(null, function (_initialize, _LitElement) {\n  class HaInitPage extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HaInitPage,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        type: Boolean\n      })],\n      key: \"error\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n      <div>\n        <img src=\"/static/icons/favicon-192x192.png\" height=\"192\" />\n        ${this.error ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n              <p>Czekam na połączenie z Asystentem domowym...</p>\n              <mwc-button @click=${this._retry}>Ponów</mwc-button>\n              ${location.host.includes(\"ui.nabu.casa\") ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n                    <p>\n                      It is possible that you are seeing this screen because\n                      your Home Assistant is not currently connected. You can\n                      ask it to come online via\n                      <a href=\"https://remote.nabucasa.com/\"\n                        >the Remote UI portal</a\n                      >.\n                    </p>\n                  ` : \"\"}\n            ` : lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n              <ha-circular-progress active></ha-circular-progress>\n              <p>Wczytuje dane</p>\n            `}\n      </div>\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated() {\n        (0,_util_init_skeleton__WEBPACK_IMPORTED_MODULE_3__.removeInitSkeleton)();\n      }\n    }, {\n      kind: \"method\",\n      key: \"_retry\",\n      value: function _retry() {\n        location.reload();\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.css`\n      div {\n        height: 100%;\n        display: flex;\n        flex-direction: column;\n        justify-content: center;\n        align-items: center;\n      }\n      ha-circular-progress {\n        margin-top: 9px;\n      }\n      a {\n        color: var(--primary-color);\n      }\n      p {\n        max-width: 350px;\n        color: var(--text-primary-color);\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement);\n\ncustomElements.define(\"ha-init-page\", HaInitPage);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/layouts/ha-init-page.ts\n");

/***/ }),

/***/ "./src/layouts/hass-error-screen.ts":
/*!******************************************!*\
  !*** ./src/layouts/hass-error-screen.ts ***!
  \******************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _material_mwc_button__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @material/mwc-button */ \"./node_modules/@material/mwc-button/mwc-button.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _hass_subpage__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./hass-subpage */ \"./src/layouts/hass-subpage.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\n\n\nlet HassErrorScreen = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.customElement)(\"hass-error-screen\")], function (_initialize, _LitElement) {\n  class HassErrorScreen extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HassErrorScreen,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        type: Boolean\n      })],\n      key: \"toolbar\",\n\n      value() {\n        return true;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)()],\n      key: \"error\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n      ${this.toolbar ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`<div class=\"toolbar\">\n            <ha-icon-button-arrow-prev\n              .hass=${this.hass}\n              @click=${this._handleBack}\n            ></ha-icon-button-arrow-prev>\n          </div>` : \"\"}\n      <div class=\"content\">\n        <h3>${this.error}</h3>\n        <slot>\n          <mwc-button @click=${this._handleBack}>go back</mwc-button>\n        </slot>\n      </div>\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"_handleBack\",\n      value: function _handleBack() {\n        history.back();\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return [lit_element__WEBPACK_IMPORTED_MODULE_1__.css`\n        :host {\n          display: block;\n          height: 100%;\n          background-color: var(--primary-background-color);\n        }\n        .toolbar {\n          display: flex;\n          align-items: center;\n          font-size: 20px;\n          height: var(--header-height);\n          padding: 0 16px;\n          pointer-events: none;\n          background-color: var(--app-header-background-color);\n          font-weight: 400;\n          color: var(--app-header-text-color, white);\n          border-bottom: var(--app-header-border-bottom, none);\n          box-sizing: border-box;\n        }\n        ha-icon-button-arrow-prev {\n          pointer-events: auto;\n        }\n        .content {\n          color: var(--primary-text-color);\n          height: calc(100% - var(--header-height));\n          display: flex;\n          align-items: center;\n          justify-content: center;\n          flex-direction: column;\n        }\n      `];\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/layouts/hass-error-screen.ts\n");

/***/ }),

/***/ "./src/layouts/hass-loading-screen.ts":
/*!********************************************!*\
  !*** ./src/layouts/hass-loading-screen.ts ***!
  \********************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_app_layout_app_toolbar_app_toolbar__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/app-layout/app-toolbar/app-toolbar */ \"./node_modules/@polymer/app-layout/app-toolbar/app-toolbar.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _components_ha_circular_progress__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../components/ha-circular-progress */ \"./src/components/ha-circular-progress.ts\");\n/* harmony import */ var _components_ha_menu_button__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../components/ha-menu-button */ \"./src/components/ha-menu-button.ts\");\n/* harmony import */ var _components_ha_icon_button_arrow_prev__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../components/ha-icon-button-arrow-prev */ \"./src/components/ha-icon-button-arrow-prev.ts\");\n/* harmony import */ var _resources_styles__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../resources/styles */ \"./src/resources/styles.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\n\n\n\n\n\nlet HassLoadingScreen = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.customElement)(\"hass-loading-screen\")], function (_initialize, _LitElement) {\n  class HassLoadingScreen extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HassLoadingScreen,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        type: Boolean,\n        attribute: \"no-toolbar\"\n      })],\n      key: \"noToolbar\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        type: Boolean\n      })],\n      key: \"rootnav\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.property)()],\n      key: \"narrow\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n      ${this.noToolbar ? \"\" : lit_element__WEBPACK_IMPORTED_MODULE_1__.html`<div class=\"toolbar\">\n            ${this.rootnav ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n                  <ha-menu-button\n                    .hass=${this.hass}\n                    .narrow=${this.narrow}\n                  ></ha-menu-button>\n                ` : lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n                  <ha-icon-button-arrow-prev\n                    .hass=${this.hass}\n                    @click=${this._handleBack}\n                  ></ha-icon-button-arrow-prev>\n                `}\n          </div>`}\n      <div class=\"content\">\n        <ha-circular-progress active></ha-circular-progress>\n      </div>\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"_handleBack\",\n      value: function _handleBack() {\n        history.back();\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return [_resources_styles__WEBPACK_IMPORTED_MODULE_5__.haStyle, lit_element__WEBPACK_IMPORTED_MODULE_1__.css`\n        :host {\n          display: block;\n          height: 100%;\n          background-color: var(--primary-background-color);\n        }\n        .toolbar {\n          display: flex;\n          align-items: center;\n          font-size: 20px;\n          height: var(--header-height);\n          padding: 0 16px;\n          pointer-events: none;\n          background-color: var(--app-header-background-color);\n          font-weight: 400;\n          color: var(--app-header-text-color, white);\n          border-bottom: var(--app-header-border-bottom, none);\n          box-sizing: border-box;\n        }\n        ha-menu-button,\n        ha-icon-button-arrow-prev {\n          pointer-events: auto;\n        }\n        .content {\n          height: calc(100% - var(--header-height));\n          display: flex;\n          align-items: center;\n          justify-content: center;\n        }\n      `];\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_1__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/hass-loading-screen.ts\n");

/***/ }),

/***/ "./src/layouts/hass-router-page.ts":
/*!*****************************************!*\
  !*** ./src/layouts/hass-router-page.ts ***!
  \*****************************************/
/*! namespace exports */
/*! export HassRouterPage [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HassRouterPage\": () => /* binding */ HassRouterPage\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var memoize_one__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! memoize-one */ \"./node_modules/memoize-one/dist/memoize-one.esm.js\");\n/* harmony import */ var _common_navigate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../common/navigate */ \"./src/common/navigate.ts\");\n/* harmony import */ var _hass_error_screen__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./hass-error-screen */ \"./src/layouts/hass-error-screen.ts\");\n/* harmony import */ var _hass_loading_screen__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./hass-loading-screen */ \"./src/layouts/hass-loading-screen.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\n\n\nconst extractPage = (path, defaultPage) => {\n  if (path === \"\") {\n    return defaultPage;\n  }\n\n  const subpathStart = path.indexOf(\"/\", 1);\n  return subpathStart === -1 ? path.substr(1) : path.substr(1, subpathStart - 1);\n};\n\n// Time to wait for code to load before we show loading screen.\nconst LOADING_SCREEN_THRESHOLD = 400; // ms\n\nlet HassRouterPage = _decorate(null, function (_initialize, _UpdatingElement) {\n  class HassRouterPage extends _UpdatingElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HassRouterPage,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"route\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"routerOptions\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_currentPage\",\n\n      value() {\n        return \"\";\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_currentLoadProm\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_cache\",\n\n      value() {\n        return {};\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_initialLoadDone\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_computeTail\",\n\n      value() {\n        return (0,memoize_one__WEBPACK_IMPORTED_MODULE_4__.default)(route => {\n          const dividerPos = route.path.indexOf(\"/\", 1);\n          return dividerPos === -1 ? {\n            prefix: route.prefix + route.path,\n            path: \"\"\n          } : {\n            prefix: route.prefix + route.path.substr(0, dividerPos),\n            path: route.path.substr(dividerPos)\n          };\n        });\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"update\",\n      value: function update(changedProps) {\n        _get(_getPrototypeOf(HassRouterPage.prototype), \"update\", this).call(this, changedProps);\n\n        const routerOptions = this.routerOptions || {\n          routes: {}\n        };\n\n        if (routerOptions && routerOptions.initialLoad && !this._initialLoadDone) {\n          return;\n        }\n\n        if (!changedProps.has(\"route\")) {\n          // Do not update if we have a currentLoadProm, because that means\n          // that there is still an old panel shown and we're moving to a new one.\n          if (this.lastChild && !this._currentLoadProm) {\n            this.updatePageEl(this.lastChild, changedProps);\n          }\n\n          return;\n        }\n\n        const route = this.route;\n        const defaultPage = routerOptions.defaultPage;\n\n        if (route && route.path === \"\" && defaultPage !== undefined) {\n          (0,_common_navigate__WEBPACK_IMPORTED_MODULE_1__.navigate)(this, `${route.prefix}/${defaultPage}`, true);\n        }\n\n        let newPage = route ? extractPage(route.path, defaultPage || \"\") : \"not_found\";\n        let routeOptions = routerOptions.routes[newPage]; // Handle redirects\n\n        while (typeof routeOptions === \"string\") {\n          newPage = routeOptions;\n          routeOptions = routerOptions.routes[newPage];\n        }\n\n        if (routerOptions.beforeRender) {\n          const result = routerOptions.beforeRender(newPage);\n\n          if (result !== undefined) {\n            newPage = result;\n            routeOptions = routerOptions.routes[newPage]; // Handle redirects\n\n            while (typeof routeOptions === \"string\") {\n              newPage = routeOptions;\n              routeOptions = routerOptions.routes[newPage];\n            } // Update the url if we know where we're mounted.\n\n\n            if (route) {\n              (0,_common_navigate__WEBPACK_IMPORTED_MODULE_1__.navigate)(this, `${route.prefix}/${result}`, true);\n            }\n          }\n        }\n\n        if (this._currentPage === newPage) {\n          if (this.lastChild) {\n            this.updatePageEl(this.lastChild, changedProps);\n          }\n\n          return;\n        }\n\n        if (!routeOptions) {\n          this._currentPage = \"\";\n\n          if (this.lastChild) {\n            this.removeChild(this.lastChild);\n          }\n\n          return;\n        }\n\n        this._currentPage = newPage;\n        const loadProm = routeOptions.load ? routeOptions.load() : Promise.resolve();\n        let showLoadingScreenTimeout; // Check when loading the page source failed.\n\n        loadProm.catch(err => {\n          // eslint-disable-next-line\n          console.error(\"Error loading page\", newPage, err); // Verify that we're still trying to show the same page.\n\n          if (this._currentPage !== newPage) {\n            return;\n          } // Removes either loading screen or the panel\n\n\n          if (this.lastChild) {\n            this.removeChild(this.lastChild);\n          }\n\n          if (showLoadingScreenTimeout) {\n            clearTimeout(showLoadingScreenTimeout);\n          } // Show error screen\n\n\n          this.appendChild(this.createErrorScreen(`Error while loading page ${newPage}.`));\n        }); // If we don't show loading screen, just show the panel.\n        // It will be automatically upgraded when loading done.\n\n        if (!routerOptions.showLoading) {\n          this._createPanel(routerOptions, newPage, routeOptions);\n\n          return;\n        } // We are only going to show the loading screen after some time.\n        // That way we won't have a double fast flash on fast connections.\n\n\n        let created = false;\n        showLoadingScreenTimeout = window.setTimeout(() => {\n          if (created || this._currentPage !== newPage) {\n            return;\n          } // Show a loading screen.\n\n\n          if (this.lastChild) {\n            this.removeChild(this.lastChild);\n          }\n\n          this.appendChild(this.createLoadingScreen());\n        }, LOADING_SCREEN_THRESHOLD);\n        this._currentLoadProm = loadProm.then(() => {\n          this._currentLoadProm = undefined; // Check if we're still trying to show the same page.\n\n          if (this._currentPage !== newPage) {\n            return;\n          }\n\n          created = true;\n\n          this._createPanel(routerOptions, newPage, // @ts-ignore TS forgot this is not a string.\n          routeOptions);\n        }, () => {\n          this._currentLoadProm = undefined;\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated(changedProps) {\n        _get(_getPrototypeOf(HassRouterPage.prototype), \"firstUpdated\", this).call(this, changedProps);\n\n        const options = this.routerOptions;\n\n        if (!options) {\n          return;\n        }\n\n        if (options.preloadAll) {\n          Object.values(options.routes).forEach(route => typeof route === \"object\" && route.load && route.load());\n        }\n\n        if (options.initialLoad) {\n          setTimeout(() => {\n            if (!this._initialLoadDone) {\n              this.appendChild(this.createLoadingScreen());\n            }\n          }, LOADING_SCREEN_THRESHOLD);\n          options.initialLoad().then(() => {\n            this._initialLoadDone = true;\n            this.requestUpdate(\"route\");\n          });\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"createLoadingScreen\",\n      value: function createLoadingScreen() {\n        return document.createElement(\"hass-loading-screen\");\n      }\n    }, {\n      kind: \"method\",\n      key: \"createErrorScreen\",\n      value: function createErrorScreen(error) {\n        const errorEl = document.createElement(\"hass-error-screen\");\n        errorEl.error = error;\n        return errorEl;\n      }\n      /**\n       * Rebuild the current panel.\n       *\n       * Promise will resolve when rebuilding is done and DOM updated.\n       */\n\n    }, {\n      kind: \"method\",\n      key: \"rebuild\",\n      value: async function rebuild() {\n        const oldRoute = this.route;\n\n        if (oldRoute === undefined) {\n          return;\n        }\n\n        this.route = undefined;\n        await this.updateComplete; // Make sure that the parent didn't override this in the meanwhile.\n\n        if (this.route === undefined) {\n          this.route = oldRoute;\n        }\n      }\n      /**\n       * Promise that resolves when the page has rendered.\n       */\n\n    }, {\n      kind: \"get\",\n      key: \"pageRendered\",\n      value: function pageRendered() {\n        return this.updateComplete.then(() => this._currentLoadProm);\n      }\n    }, {\n      kind: \"method\",\n      key: \"createElement\",\n      value: function createElement(tag) {\n        return document.createElement(tag);\n      }\n    }, {\n      kind: \"method\",\n      key: \"updatePageEl\",\n      value: function updatePageEl(_pageEl, _changedProps) {// default we do nothing\n      }\n    }, {\n      kind: \"get\",\n      key: \"routeTail\",\n      value: function routeTail() {\n        return this._computeTail(this.route);\n      }\n    }, {\n      kind: \"method\",\n      key: \"_createPanel\",\n      value: function _createPanel(routerOptions, page, routeOptions) {\n        if (this.lastChild) {\n          this.removeChild(this.lastChild);\n        }\n\n        const panelEl = this._cache[page] || this.createElement(routeOptions.tag);\n        this.updatePageEl(panelEl);\n        this.appendChild(panelEl);\n\n        if (routerOptions.cacheAll || routeOptions.cache) {\n          this._cache[page] = panelEl;\n        }\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_0__.UpdatingElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/hass-router-page.ts\n");

/***/ }),

/***/ "./src/layouts/hass-subpage.ts":
/*!*************************************!*\
  !*** ./src/layouts/hass-subpage.ts ***!
  \*************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-html/directives/class-map */ \"./node_modules/lit-html/directives/class-map.js\");\n/* harmony import */ var _components_ha_menu_button__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../components/ha-menu-button */ \"./src/components/ha-menu-button.ts\");\n/* harmony import */ var _components_ha_icon_button_arrow_prev__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../components/ha-icon-button-arrow-prev */ \"./src/components/ha-icon-button-arrow-prev.ts\");\n/* harmony import */ var _common_decorators_restore_scroll__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../common/decorators/restore-scroll */ \"./src/common/decorators/restore-scroll.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\n\n\n\n\n\nlet HassSubpage = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)(\"hass-subpage\")], function (_initialize, _LitElement) {\n  class HassSubpage extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HassSubpage,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"header\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        type: Boolean\n      })],\n      key: \"showBackButton\",\n\n      value() {\n        return true;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        type: Boolean\n      })],\n      key: \"hassio\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,_common_decorators_restore_scroll__WEBPACK_IMPORTED_MODULE_4__.restoreScroll)(\".content\")],\n      key: \"_savedScrollPos\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: // @ts-ignore\n      function render() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_0__.html`\n      <div class=\"toolbar\">\n        <ha-icon-button-arrow-prev\n          .hass=${this.hass}\n          @click=${this._backTapped}\n          class=${(0,lit_html_directives_class_map__WEBPACK_IMPORTED_MODULE_1__.classMap)({\n          hidden: !this.showBackButton\n        })}\n        ></ha-icon-button-arrow-prev>\n\n        <div class=\"main-title\">${this.header}</div>\n        <slot name=\"toolbar-icon\"></slot>\n      </div>\n      <div class=\"content\" @scroll=${this._saveScrollPos}><slot></slot></div>\n    `;\n      }\n    }, {\n      kind: \"method\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.eventOptions)({\n        passive: true\n      })],\n      key: \"_saveScrollPos\",\n      value: function _saveScrollPos(e) {\n        this._savedScrollPos = e.target.scrollTop;\n      }\n    }, {\n      kind: \"method\",\n      key: \"_backTapped\",\n      value: function _backTapped() {\n        history.back();\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_0__.css`\n      :host {\n        display: block;\n        height: 100%;\n        background-color: var(--primary-background-color);\n      }\n\n      :host([narrow]) {\n        width: 100%;\n        position: fixed;\n      }\n\n      .toolbar {\n        display: flex;\n        align-items: center;\n        font-size: 20px;\n        height: var(--header-height);\n        padding: 0 16px;\n        pointer-events: none;\n        background-color: var(--app-header-background-color);\n        font-weight: 400;\n        color: var(--app-header-text-color, white);\n        border-bottom: var(--app-header-border-bottom, none);\n        box-sizing: border-box;\n      }\n\n      ha-icon-button-arrow-prev,\n      ::slotted([slot=\"toolbar-icon\"]) {\n        pointer-events: auto;\n      }\n\n      ha-icon-button-arrow-prev.hidden {\n        visibility: hidden;\n      }\n\n      .main-title {\n        margin: 0 0 0 24px;\n        line-height: 20px;\n        flex-grow: 1;\n      }\n\n      .content {\n        position: relative;\n        width: 100%;\n        height: calc(100% - 1px - var(--header-height));\n        overflow-y: auto;\n        overflow: auto;\n        -webkit-overflow-scrolling: touch;\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/hass-subpage.ts\n");

/***/ }),

/***/ "./src/layouts/home-assistant-main.ts":
/*!********************************************!*\
  !*** ./src/layouts/home-assistant-main.ts ***!
  \********************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_app_layout_app_drawer_layout_app_drawer_layout__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/app-layout/app-drawer-layout/app-drawer-layout */ \"./node_modules/@polymer/app-layout/app-drawer-layout/app-drawer-layout.js\");\n/* harmony import */ var _polymer_app_layout_app_drawer_app_drawer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/app-layout/app-drawer/app-drawer */ \"./node_modules/@polymer/app-layout/app-drawer/app-drawer.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n/* harmony import */ var _common_dom_media_query__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../common/dom/media_query */ \"./src/common/dom/media_query.ts\");\n/* harmony import */ var _common_dom_toggle_attribute__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../common/dom/toggle_attribute */ \"./src/common/dom/toggle_attribute.ts\");\n/* harmony import */ var _dialogs_notifications_show_notification_drawer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../dialogs/notifications/show-notification-drawer */ \"./src/dialogs/notifications/show-notification-drawer.ts\");\n/* harmony import */ var _partial_panel_resolver__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./partial-panel-resolver */ \"./src/layouts/partial-panel-resolver.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\n\n\n\n\nconst NON_SWIPABLE_PANELS = [\"map\"];\n\nlet HomeAssistantMain = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.customElement)(\"home-assistant-main\")], function (_initialize, _LitElement) {\n  class HomeAssistantMain extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HomeAssistantMain,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)()],\n      key: \"route\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.property)({\n        type: Boolean\n      })],\n      key: \"narrow\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_2__.internalProperty)()],\n      key: \"_sidebarEditMode\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        const hass = this.hass;\n\n        if (!hass) {\n          return lit_element__WEBPACK_IMPORTED_MODULE_2__.html``;\n        }\n\n        const sidebarNarrow = this._sidebarNarrow;\n        const disableSwipe = this._sidebarEditMode || !sidebarNarrow || NON_SWIPABLE_PANELS.indexOf(hass.panelUrl) !== -1; // Style block in render because of the mixin that is not supported\n\n        return lit_element__WEBPACK_IMPORTED_MODULE_2__.html`\n      <style>\n        app-drawer {\n          --app-drawer-content-container: {\n            background-color: var(--primary-background-color, #fff);\n          }\n        }\n      </style>\n      <app-drawer-layout\n        fullbleed\n        .forceNarrow=${sidebarNarrow}\n        responsive-width=\"0\"\n      >\n        <app-drawer\n          id=\"drawer\"\n          align=\"start\"\n          slot=\"drawer\"\n          .disableSwipe=${disableSwipe}\n          .swipeOpen=${!disableSwipe}\n          .persistent=${!this.narrow && this.hass.dockedSidebar !== \"always_hidden\"}\n        >\n          <ha-sidebar\n            .hass=${hass}\n            .narrow=${sidebarNarrow}\n            .editMode=${this._sidebarEditMode}\n            .alwaysExpand=${sidebarNarrow || this.hass.dockedSidebar === \"docked\"}\n          ></ha-sidebar>\n        </app-drawer>\n\n        <partial-panel-resolver\n          .narrow=${this.narrow}\n          .hass=${hass}\n          .route=${this.route}\n        ></partial-panel-resolver>\n      </app-drawer-layout>\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated() {\n        Promise.all(/*! import() | ha-sidebar */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-icon_iron-icon_js-node_modules_idb-keyval_dist_idb-keyval_m-3035461\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-item_paper-icon-item_js-node_modules_polymer_paper-item_pa-d67f2a\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_user_ha-user-badge_ts\"), __webpack_require__.e(\"ha-sidebar\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../components/ha-sidebar */ \"./src/components/ha-sidebar.ts\"));\n        this.addEventListener(\"hass-edit-sidebar\", ev => {\n          this._sidebarEditMode = ev.detail.editMode;\n\n          if (this._sidebarEditMode) {\n            if (this._sidebarNarrow) {\n              this.drawer.open();\n            } else {\n              (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_5__.fireEvent)(this, \"hass-dock-sidebar\", {\n                dock: \"docked\"\n              });\n              setTimeout(() => this.appLayout.resetLayout());\n            }\n          }\n        });\n        this.addEventListener(\"hass-toggle-menu\", () => {\n          if (this._sidebarEditMode) {\n            return;\n          }\n\n          if (this._sidebarNarrow) {\n            if (this.drawer.opened) {\n              this.drawer.close();\n            } else {\n              this.drawer.open();\n            }\n          } else {\n            (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_5__.fireEvent)(this, \"hass-dock-sidebar\", {\n              dock: this.hass.dockedSidebar === \"auto\" ? \"docked\" : \"auto\"\n            });\n            setTimeout(() => this.appLayout.resetLayout());\n          }\n        });\n        this.addEventListener(\"hass-show-notifications\", () => {\n          (0,_dialogs_notifications_show_notification_drawer__WEBPACK_IMPORTED_MODULE_3__.showNotificationDrawer)(this, {\n            narrow: this.narrow\n          });\n        });\n        (0,_common_dom_media_query__WEBPACK_IMPORTED_MODULE_6__.listenMediaQuery)(\"(max-width: 870px)\", matches => {\n          this.narrow = matches;\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"updated\",\n      value: function updated(changedProps) {\n        _get(_getPrototypeOf(HomeAssistantMain.prototype), \"updated\", this).call(this, changedProps);\n\n        (0,_common_dom_toggle_attribute__WEBPACK_IMPORTED_MODULE_7__.toggleAttribute)(this, \"expanded\", this.narrow || this.hass.dockedSidebar !== \"auto\");\n\n        if (changedProps.has(\"route\") && this._sidebarNarrow) {\n          this.drawer.close();\n        }\n\n        const oldHass = changedProps.get(\"hass\"); // Make app-drawer adjust to a potential LTR/RTL change\n\n        if (oldHass && oldHass.language !== this.hass.language) {\n          this.drawer._resetPosition();\n        }\n      }\n    }, {\n      kind: \"get\",\n      key: \"_sidebarNarrow\",\n      value: function _sidebarNarrow() {\n        return this.narrow || this.hass.dockedSidebar === \"always_hidden\";\n      }\n    }, {\n      kind: \"get\",\n      key: \"drawer\",\n      value: function drawer() {\n        return this.shadowRoot.querySelector(\"app-drawer\");\n      }\n    }, {\n      kind: \"get\",\n      key: \"appLayout\",\n      value: function appLayout() {\n        return this.shadowRoot.querySelector(\"app-drawer-layout\");\n      }\n    }, {\n      kind: \"get\",\n      static: true,\n      key: \"styles\",\n      value: function styles() {\n        return lit_element__WEBPACK_IMPORTED_MODULE_2__.css`\n      :host {\n        color: var(--primary-text-color);\n        /* remove the grey tap highlights in iOS on the fullscreen touch targets */\n        -webkit-tap-highlight-color: rgba(0, 0, 0, 0);\n        --app-drawer-width: 56px;\n      }\n      :host([expanded]) {\n        --app-drawer-width: calc(256px + env(safe-area-inset-left));\n      }\n      partial-panel-resolver,\n      ha-sidebar {\n        /* allow a light tap highlight on the actual interface elements  */\n        -webkit-tap-highlight-color: rgba(0, 0, 0, 0.1);\n      }\n    `;\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_2__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/home-assistant-main.ts\n");

/***/ }),

/***/ "./src/layouts/home-assistant.ts":
/*!***************************************!*\
  !*** ./src/layouts/home-assistant.ts ***!
  \***************************************/
/*! namespace exports */
/*! export HomeAssistantAppEl [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.t, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HomeAssistantAppEl\": () => /* binding */ HomeAssistantAppEl\n/* harmony export */ });\n/* harmony import */ var _polymer_app_route_app_location__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/app-route/app-location */ \"./node_modules/@polymer/app-route/app-location.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _common_navigate__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../common/navigate */ \"./src/common/navigate.ts\");\n/* harmony import */ var _data_panel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../data/panel */ \"./src/data/panel.ts\");\n/* harmony import */ var _resources_custom_card_support__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../resources/custom-card-support */ \"./src/resources/custom-card-support.ts\");\n/* harmony import */ var _state_hass_element__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../state/hass-element */ \"./src/state/hass-element.ts\");\n/* harmony import */ var _util_register_service_worker__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/register-service-worker */ \"./src/util/register-service-worker.ts\");\n/* harmony import */ var _ha_init_page__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./ha-init-page */ \"./src/layouts/ha-init-page.ts\");\n/* harmony import */ var _home_assistant_main__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./home-assistant-main */ \"./src/layouts/home-assistant-main.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n/* harmony import */ var _state_quick_bar_mixin__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../state/quick-bar-mixin */ \"./src/state/quick-bar-mixin.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\n\n\n\n\n\n\n\nlet HomeAssistantAppEl = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.customElement)(\"home-assistant\")], function (_initialize, _QuickBarMixin) {\n  class HomeAssistantAppEl extends _QuickBarMixin {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HomeAssistantAppEl,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_route\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_error\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_1__.internalProperty)()],\n      key: \"_panelUrl\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_haVersion\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_hiddenTimeout\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_visiblePromiseResolve\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"render\",\n      value: function render() {\n        const hass = this.hass;\n        return lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n      <app-location\n        @route-changed=${this._routeChanged}\n        ?use-hash-as-path=${false}\n      ></app-location>\n      ${this._panelUrl === undefined || this._route === undefined ? \"\" : hass && hass.states && hass.config && hass.services ? lit_element__WEBPACK_IMPORTED_MODULE_1__.html`\n            <home-assistant-main\n              .hass=${this.hass}\n              .route=${this._route}\n            ></home-assistant-main>\n          ` : lit_element__WEBPACK_IMPORTED_MODULE_1__.html` <ha-init-page .error=${this._error}></ha-init-page> `}\n    `;\n      }\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated(changedProps) {\n        _get(_getPrototypeOf(HomeAssistantAppEl.prototype), \"firstUpdated\", this).call(this, changedProps);\n\n        this._initialize();\n\n        setTimeout(() => (0,_util_register_service_worker__WEBPACK_IMPORTED_MODULE_6__.registerServiceWorker)(this), 1000);\n        /* polyfill for paper-dropdown */\n\n        __webpack_require__.e(/*! import() | polyfill-web-animations-next */ \"polyfill-web-animations-next\").then(__webpack_require__.t.bind(__webpack_require__, /*! web-animations-js/web-animations-next-lite.min */ \"./node_modules/web-animations-js/web-animations-next-lite.min.js\", 7));\n        this.addEventListener(\"hass-suspend-when-hidden\", ev => {\n          this._updateHass({\n            suspendWhenHidden: ev.detail.suspend\n          });\n\n          (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_9__.storeState)(this.hass);\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"updated\",\n      value: function updated(changedProps) {\n        _get(_getPrototypeOf(HomeAssistantAppEl.prototype), \"updated\", this).call(this, changedProps);\n\n        if (changedProps.has(\"_panelUrl\")) {\n          this.panelUrlChanged(this._panelUrl);\n\n          this._updateHass({\n            panelUrl: this._panelUrl\n          });\n        }\n\n        if (changedProps.has(\"hass\")) {\n          this.hassChanged(this.hass, changedProps.get(\"hass\"));\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"hassConnected\",\n      value: function hassConnected() {\n        _get(_getPrototypeOf(HomeAssistantAppEl.prototype), \"hassConnected\", this).call(this); // @ts-ignore\n\n\n        this._loadHassTranslations(this.hass.language, \"state\");\n\n        document.addEventListener(\"visibilitychange\", () => this._checkVisibility(), false);\n        document.addEventListener(\"freeze\", () => this._suspendApp());\n        document.addEventListener(\"resume\", () => this._checkVisibility());\n      }\n    }, {\n      kind: \"method\",\n      key: \"hassReconnected\",\n      value: function hassReconnected() {\n        _get(_getPrototypeOf(HomeAssistantAppEl.prototype), \"hassReconnected\", this).call(this); // If backend has been upgraded, make sure we update frontend\n\n\n        if (this.hass.connection.haVersion !== this._haVersion) {\n          if ((0,_util_register_service_worker__WEBPACK_IMPORTED_MODULE_6__.supportsServiceWorker)()) {\n            navigator.serviceWorker.getRegistration().then(registration => {\n              if (registration) {\n                registration.update();\n              } else {\n                location.reload(true);\n              }\n            });\n          } else {\n            location.reload(true);\n          }\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_initialize\",\n      value: async function _initialize() {\n        try {\n          let result;\n\n          if (window.hassConnection) {\n            result = await window.hassConnection;\n          } else {\n            // In the edge case that\n            result = await new Promise(resolve => {\n              window.hassConnectionReady = resolve;\n            });\n          }\n\n          const {\n            auth,\n            conn\n          } = result;\n          this._haVersion = conn.haVersion;\n          this.initializeHass(auth, conn);\n        } catch (err) {\n          this._error = true;\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_routeChanged\",\n      value: async function _routeChanged(ev) {\n        // routeChangged event listener is called while we're doing the fist render,\n        // causing the update to be ignored. So delay it to next task (Lit render is sync).\n        await new Promise(resolve => setTimeout(resolve, 0));\n        const route = ev.detail.value; // If it's the first route that we process,\n        // check if we should navigate away from /\n\n        if (this._route === undefined && (route.path === \"\" || route.path === \"/\")) {\n          (0,_common_navigate__WEBPACK_IMPORTED_MODULE_2__.navigate)(window, `/${(0,_data_panel__WEBPACK_IMPORTED_MODULE_3__.getStorageDefaultPanelUrlPath)()}`, true);\n          return;\n        }\n\n        this._route = route;\n        const dividerPos = route.path.indexOf(\"/\", 1);\n        this._panelUrl = dividerPos === -1 ? route.path.substr(1) : route.path.substr(1, dividerPos - 1);\n      }\n    }, {\n      kind: \"method\",\n      key: \"_checkVisibility\",\n      value: function _checkVisibility() {\n        if (document.hidden) {\n          // If the document is hidden, we will prevent reconnects until we are visible again\n          this._onHidden();\n        } else {\n          this._onVisible();\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_onHidden\",\n      value: function _onHidden() {\n        if (this._visiblePromiseResolve) {\n          return;\n        }\n\n        this.hass.connection.suspendReconnectUntil(new Promise(resolve => {\n          this._visiblePromiseResolve = resolve;\n        }));\n\n        if (this.hass.suspendWhenHidden !== false) {\n          // We close the connection to Home Assistant after being hidden for 5 minutes\n          this._hiddenTimeout = window.setTimeout(() => {\n            this._hiddenTimeout = undefined; // setTimeout can be delayed in the background and only fire\n            // when we switch to the tab or app again (Hey Android!)\n\n            if (!document.hidden) {\n              this._suspendApp();\n            }\n          }, 300000);\n        }\n\n        window.addEventListener(\"focus\", () => this._onVisible(), {\n          once: true\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"_suspendApp\",\n      value: function _suspendApp() {\n        if (!this.hass.connection.connected) {\n          return;\n        }\n\n        this.hass.connection.suspend();\n      }\n    }, {\n      kind: \"method\",\n      key: \"_onVisible\",\n      value: function _onVisible() {\n        // Clear timer to close the connection\n        if (this._hiddenTimeout) {\n          clearTimeout(this._hiddenTimeout);\n          this._hiddenTimeout = undefined;\n        } // Unsuspend the reconnect\n\n\n        if (this._visiblePromiseResolve) {\n          this._visiblePromiseResolve();\n\n          this._visiblePromiseResolve = undefined;\n        }\n      }\n    }]\n  };\n}, (0,_state_quick_bar_mixin__WEBPACK_IMPORTED_MODULE_10__.default)(_state_hass_element__WEBPACK_IMPORTED_MODULE_5__.HassElement));//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/home-assistant.ts\n");

/***/ }),

/***/ "./src/layouts/partial-panel-resolver.ts":
/*!***********************************************!*\
  !*** ./src/layouts/partial-panel-resolver.ts ***!
  \***********************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.e, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/config.js\");\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n/* harmony import */ var _common_dom_deep_active_element__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../common/dom/deep-active-element */ \"./src/common/dom/deep-active-element.ts\");\n/* harmony import */ var _common_util_deep_equal__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../common/util/deep-equal */ \"./src/common/util/deep-equal.ts\");\n/* harmony import */ var _util_init_skeleton__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../util/init-skeleton */ \"./src/util/init-skeleton.ts\");\n/* harmony import */ var _hass_router_page__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./hass-router-page */ \"./src/layouts/hass-router-page.ts\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\nfunction _get(target, property, receiver) { if (typeof Reflect !== \"undefined\" && Reflect.get) { _get = Reflect.get; } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(receiver); } return desc.value; }; } return _get(target, property, receiver || target); }\n\nfunction _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\n\n\n\n\n\n\nconst CACHE_URL_PATHS = [\"lovelace\", \"developer-tools\"];\nconst COMPONENTS = {\n  calendar: () => Promise.all(/*! import() | panel-calendar */[__webpack_require__.e(\"vendors-node_modules_material_mwc-formfield_mwc-formfield_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-checkbox_mwc-checkbox_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-icon_iron-icon_js-node_modules_idb-keyval_dist_idb-keyval_m-3035461\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"panel-calendar\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/calendar/ha-panel-calendar */ \"./src/panels/calendar/ha-panel-calendar.ts\")),\n  config: () => Promise.all(/*! import() | panel-config */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-item_paper-item-body_js-node_modules_polymer_paper-item_pa-081ef1\"), __webpack_require__.e(\"panel-config\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/config/ha-panel-config */ \"./src/panels/config/ha-panel-config.ts\")),\n  custom: () => __webpack_require__.e(/*! import() | panel-custom */ \"panel-custom\").then(__webpack_require__.bind(__webpack_require__, /*! ../panels/custom/ha-panel-custom */ \"./src/panels/custom/ha-panel-custom.ts\")),\n  \"developer-tools\": () => Promise.all(/*! import() | panel-developer-tools */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tabs_paper-tabs_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header-layout_app-header-layout_js-node_modules_p-4f3a04\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-tabs_ts-src_layouts_ha-app-layout_js\"), __webpack_require__.e(\"panel-developer-tools\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/developer-tools/ha-panel-developer-tools */ \"./src/panels/developer-tools/ha-panel-developer-tools.ts\")),\n  lovelace: () => Promise.all(/*! import() | panel-lovelace */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-menu_mwc-menu_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_thomasloven_round-slider_src_main_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tabs_paper-tabs_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-1dcc6f0\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_components_ha-button-menu_ts\"), __webpack_require__.e(\"src_panels_lovelace_common_has-changed_ts-src_panels_lovelace_components_hui-generic-entity-row_ts\"), __webpack_require__.e(\"src_common_datetime_format_date_time_ts-src_common_string_compare_ts-src_components_entity_ha-a9c1ce\"), __webpack_require__.e(\"src_data_integration_ts-src_panels_lovelace_create-element_create-row-element_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"src_data_weather_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_hui-stack-card_ts-src_panels_lovelace_cards_hui-vertical-stack-card-53457d\"), __webpack_require__.e(\"src_components_ha-label-badge_ts\"), __webpack_require__.e(\"src_common_util_render-status_ts-src_components_entity_ha-state-label-badge_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_domain_ts-src_data_media-player_ts-src_panels_lovelace_common-c9c5b4\"), __webpack_require__.e(\"src_panels_lovelace_views_hui-view_ts\"), __webpack_require__.e(\"src_components_ha-tabs_ts-src_layouts_ha-app-layout_js\"), __webpack_require__.e(\"src_panels_lovelace_common_generate-lovelace-config_ts-src_panels_lovelace_editor_config-util_ts\"), __webpack_require__.e(\"panel-lovelace\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/lovelace/ha-panel-lovelace */ \"./src/panels/lovelace/ha-panel-lovelace.ts\")),\n  history: () => Promise.all(/*! import() | panel-history */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_polymer_lib_mixins_disable-upgrade-mixin_js-node_modules_vaadin_-35f9dd\"), __webpack_require__.e(\"vendors-node_modules_vaadin_vaadin-combo-box_theme_material_vaadin-combo-box-light_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-47fe59\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_entity_ha-entity-picker_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_common_entity_compute_state_display_ts-src_components_ha-date-range-picker_ts-src_layouts-276c1f\"), __webpack_require__.e(\"panel-history\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/history/ha-panel-history */ \"./src/panels/history/ha-panel-history.ts\")),\n  iframe: () => __webpack_require__.e(/*! import() | panel-iframe */ \"panel-iframe\").then(__webpack_require__.bind(__webpack_require__, /*! ../panels/iframe/ha-panel-iframe */ \"./src/panels/iframe/ha-panel-iframe.js\")),\n  logbook: () => Promise.all(/*! import() | panel-logbook */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_polymer_lib_mixins_disable-upgrade-mixin_js-node_modules_vaadin_-35f9dd\"), __webpack_require__.e(\"vendors-node_modules_vaadin_vaadin-combo-box_theme_material_vaadin-combo-box-light_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_lit-virtualizer_lit-virtualizer_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-47fe59\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_entity_ha-entity-picker_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"node_modules_lit-virtualizer_lib_uni-virtualizer_lib_polyfillLoaders_EventTarget_js-src_data_-d6a22a\"), __webpack_require__.e(\"src_common_entity_compute_state_display_ts-src_components_ha-date-range-picker_ts-src_layouts-276c1f\"), __webpack_require__.e(\"panel-logbook\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/logbook/ha-panel-logbook */ \"./src/panels/logbook/ha-panel-logbook.ts\")),\n  mailbox: () => Promise.all(/*! import() | panel-mailbox */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-textarea_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tabs_paper-tabs_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header-layout_app-header-layout_js-node_modules_p-4f111e\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-tabs_ts-src_layouts_ha-app-layout_js\"), __webpack_require__.e(\"panel-mailbox\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/mailbox/ha-panel-mailbox */ \"./src/panels/mailbox/ha-panel-mailbox.js\")),\n  map: () => Promise.all(/*! import() | panel-map */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-image_iron-image_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header-layout_app-header-layout_js-node_modules_p-febb62\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"panel-map\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/map/ha-panel-map */ \"./src/panels/map/ha-panel-map.js\")),\n  profile: () => Promise.all(/*! import() | panel-profile */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-icons_js-node_modules_po-1b093a\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tooltip_paper-tooltip_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-formfield_mwc-formfield_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dialog_paper-dialog_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-radio_mwc-radio_js-node_modules_polymer_app-layout_app-head-5f5110\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_form-element_js-node_modules_polymer_iron-flex-layout_-d61818\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-formfield_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_components_ha-paper-dropdown-menu_ts-src_components_ha-radio_ts-src_layouts_ha-app-layout-ae3b9b\"), __webpack_require__.e(\"src_components_ha-settings-row_ts-src_styles_polymer-ha-style_ts\"), __webpack_require__.e(\"panel-profile\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/profile/ha-panel-profile */ \"./src/panels/profile/ha-panel-profile.ts\")),\n  \"shopping-list\": () => Promise.all(/*! import() | panel-shopping-list */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_thomasloven_round-slider_src_main_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-1dcc6f0\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_panels_lovelace_common_has-changed_ts-src_panels_lovelace_components_hui-generic-entity-row_ts\"), __webpack_require__.e(\"src_common_datetime_format_date_time_ts-src_common_string_compare_ts-src_components_entity_ha-a9c1ce\"), __webpack_require__.e(\"src_data_integration_ts-src_panels_lovelace_create-element_create-row-element_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"src_data_weather_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_hui-stack-card_ts-src_panels_lovelace_cards_hui-vertical-stack-card-53457d\"), __webpack_require__.e(\"panel-shopping-list\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/shopping-list/ha-panel-shopping-list */ \"./src/panels/shopping-list/ha-panel-shopping-list.ts\")),\n  aishelp: () => Promise.all(/*! import() | panel-aishelp */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_panels_config_ha-config-section_ts\"), __webpack_require__.e(\"panel-aishelp\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/aishelp/ha-panel-aishelp */ \"./src/panels/aishelp/ha-panel-aishelp.ts\")),\n  aisdocs: () => __webpack_require__.e(/*! import() | panel-aisdocs */ \"panel-aisdocs\").then(__webpack_require__.bind(__webpack_require__, /*! ../panels/aisdocs/ha-panel-aisdocs */ \"./src/panels/aisdocs/ha-panel-aisdocs.js\")),\n  aisaudio: () => Promise.all(/*! import() | panel-aisaudio */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-formfield_mwc-formfield_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-checkbox_mwc-checkbox_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-checkbox_paper-checkbox_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_thomasloven_round-slider_src_main_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-1dcc6f0\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_panels_lovelace_common_has-changed_ts-src_panels_lovelace_components_hui-generic-entity-row_ts\"), __webpack_require__.e(\"src_common_datetime_format_date_time_ts-src_common_string_compare_ts-src_components_entity_ha-a9c1ce\"), __webpack_require__.e(\"src_data_integration_ts-src_panels_lovelace_create-element_create-row-element_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"src_data_weather_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_hui-stack-card_ts-src_panels_lovelace_cards_hui-vertical-stack-card-53457d\"), __webpack_require__.e(\"src_components_ha-label-badge_ts\"), __webpack_require__.e(\"src_common_util_render-status_ts-src_components_entity_ha-state-label-badge_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_domain_ts-src_data_media-player_ts-src_panels_lovelace_common-c9c5b4\"), __webpack_require__.e(\"src_panels_lovelace_views_hui-view_ts\"), __webpack_require__.e(\"panel-aisaudio\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/aisaudio/ha-panel-aisaudio */ \"./src/panels/aisaudio/ha-panel-aisaudio.ts\")),\n  aiszigbee: () => Promise.all(/*! import() | panel-aiszigbee */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-formfield_mwc-formfield_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-checkbox_mwc-checkbox_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_thomasloven_round-slider_src_main_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-1dcc6f1\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_panels_lovelace_common_has-changed_ts-src_panels_lovelace_components_hui-generic-entity-row_ts\"), __webpack_require__.e(\"src_common_datetime_format_date_time_ts-src_common_string_compare_ts-src_components_entity_ha-a9c1ce\"), __webpack_require__.e(\"src_data_integration_ts-src_panels_lovelace_create-element_create-row-element_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"src_data_weather_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_hui-stack-card_ts-src_panels_lovelace_cards_hui-vertical-stack-card-53457d\"), __webpack_require__.e(\"src_components_ha-label-badge_ts\"), __webpack_require__.e(\"src_common_util_render-status_ts-src_components_entity_ha-state-label-badge_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_domain_ts-src_data_media-player_ts-src_panels_lovelace_common-c9c5b4\"), __webpack_require__.e(\"src_panels_lovelace_views_hui-view_ts\"), __webpack_require__.e(\"panel-aiszigbee\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/aiszigbee/ha-panel-aiszigbee */ \"./src/panels/aiszigbee/ha-panel-aiszigbee.ts\")),\n  aistts: () => Promise.all(/*! import() | panel-aistts */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-icons_js-node_modules_po-1b093a\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-textarea_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-checkbox_paper-checkbox_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-menu_mwc-menu_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-radio-group_paper-radio-group_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-light_js-node_modules_po-edcc94\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-1dcc6f0\"), __webpack_require__.e(\"vendors-node_modules_lit-html_directives_repeat_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-iconset-svg_iron-iconset-svg_js-node_modules_polymer_paper--9e8a55\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-button-menu_ts\"), __webpack_require__.e(\"panel-aistts\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/aistts/ha-panel-aistts */ \"./src/panels/aistts/ha-panel-aistts.ts\")),\n  \"media-browser\": () => Promise.all(/*! import() | panel-media-browser */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-icons_js-node_modules_po-1b093a\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_polymer_lib_mixins_disable-upgrade-mixin_js-node_modules_vaadin_-35f9dd\"), __webpack_require__.e(\"vendors-node_modules_vaadin_vaadin-combo-box_theme_material_vaadin-combo-box-light_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tooltip_paper-tooltip_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_app-layout_app-header_app-header_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-fab_mwc-fab_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-list_mwc-list-item_js-node_modules_material_mwc-list_mwc-list_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-menu_mwc-menu_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-icon_iron-icon_js-node_modules_idb-keyval_dist_idb-keyval_m-3035461\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-iconset-svg_iron-iconset-svg_js-node_modules_polymer_paper--aee4f2\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_app-layout_app-header-326c18\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_entity_ha-entity-picker_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_components_ha-button-menu_ts\"), __webpack_require__.e(\"src_components_media-player_ha-media-player-browse_ts\"), __webpack_require__.e(\"panel-media-browser\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../panels/media-browser/ha-panel-media-browser */ \"./src/panels/media-browser/ha-panel-media-browser.ts\"))\n};\n\nconst getRoutes = panels => {\n  const routes = {};\n  Object.values(panels).forEach(panel => {\n    const data = {\n      tag: `ha-panel-${panel.component_name}`,\n      cache: CACHE_URL_PATHS.includes(panel.url_path)\n    };\n\n    if (panel.component_name in COMPONENTS) {\n      data.load = COMPONENTS[panel.component_name];\n    }\n\n    routes[panel.url_path] = data;\n  });\n  return {\n    showLoading: true,\n    routes\n  };\n};\n\nlet PartialPanelResolver = _decorate([(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.customElement)(\"partial-panel-resolver\")], function (_initialize, _HassRouterPage) {\n  class PartialPanelResolver extends _HassRouterPage {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: PartialPanelResolver,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)()],\n      key: \"narrow\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_waitForStart\",\n\n      value() {\n        return false;\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"_disconnectedPanel\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_disconnectedActiveElement\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_hiddenTimeout\",\n      value: void 0\n    }, {\n      kind: \"method\",\n      key: \"firstUpdated\",\n      value: function firstUpdated(changedProps) {\n        _get(_getPrototypeOf(PartialPanelResolver.prototype), \"firstUpdated\", this).call(this, changedProps); // Attach listeners for visibility\n\n\n        document.addEventListener(\"visibilitychange\", () => this._checkVisibility(), false);\n        document.addEventListener(\"resume\", () => this._checkVisibility());\n      }\n    }, {\n      kind: \"method\",\n      key: \"updated\",\n      value: function updated(changedProps) {\n        _get(_getPrototypeOf(PartialPanelResolver.prototype), \"updated\", this).call(this, changedProps);\n\n        if (!changedProps.has(\"hass\")) {\n          return;\n        }\n\n        const oldHass = changedProps.get(\"hass\");\n\n        if (this._waitForStart && (this.hass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_2__.STATE_STARTING || this.hass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_2__.STATE_RUNNING)) {\n          this._waitForStart = false;\n          this.rebuild();\n        }\n\n        if (this.hass.panels && (!oldHass || oldHass.panels !== this.hass.panels)) {\n          this._updateRoutes(oldHass === null || oldHass === void 0 ? void 0 : oldHass.panels);\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"createLoadingScreen\",\n      value: function createLoadingScreen() {\n        const el = _get(_getPrototypeOf(PartialPanelResolver.prototype), \"createLoadingScreen\", this).call(this);\n\n        el.rootnav = true;\n        el.hass = this.hass;\n        el.narrow = this.narrow;\n        return el;\n      }\n    }, {\n      kind: \"method\",\n      key: \"updatePageEl\",\n      value: function updatePageEl(el) {\n        const hass = this.hass;\n\n        if (\"setProperties\" in el) {\n          // As long as we have Polymer panels\n          el.setProperties({\n            hass: this.hass,\n            narrow: this.narrow,\n            route: this.routeTail,\n            panel: hass.panels[this._currentPage]\n          });\n        } else {\n          el.hass = hass;\n          el.narrow = this.narrow;\n          el.route = this.routeTail;\n          el.panel = hass.panels[this._currentPage];\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_checkVisibility\",\n      value: function _checkVisibility() {\n        if (this.hass.suspendWhenHidden === false) {\n          return;\n        }\n\n        if (document.hidden) {\n          this._onHidden();\n        } else {\n          this._onVisible();\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_onHidden\",\n      value: function _onHidden() {\n        this._hiddenTimeout = window.setTimeout(() => {\n          this._hiddenTimeout = undefined; // setTimeout can be delayed in the background and only fire\n          // when we switch to the tab or app again (Hey Android!)\n\n          if (!document.hidden) {\n            return;\n          }\n\n          const curPanel = this.hass.panels[this._currentPage];\n\n          if (this.lastChild && // iFrames will lose their state when disconnected\n          // Do not disconnect any iframe panel\n          curPanel.component_name !== \"iframe\" && ( // Do not disconnect any custom panel that embeds into iframe (ie hassio)\n          curPanel.component_name !== \"custom\" || !curPanel.config._panel_custom.embed_iframe)) {\n            this._disconnectedPanel = this.lastChild;\n            const activeEl = (0,_common_dom_deep_active_element__WEBPACK_IMPORTED_MODULE_3__.deepActiveElement)(this._disconnectedPanel.shadowRoot || undefined);\n\n            if (activeEl instanceof HTMLElement) {\n              this._disconnectedActiveElement = activeEl;\n            }\n\n            this.removeChild(this.lastChild);\n          }\n        }, 300000);\n        window.addEventListener(\"focus\", () => this._onVisible(), {\n          once: true\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"_onVisible\",\n      value: function _onVisible() {\n        if (this._hiddenTimeout) {\n          clearTimeout(this._hiddenTimeout);\n          this._hiddenTimeout = undefined;\n        }\n\n        if (this._disconnectedPanel) {\n          this.appendChild(this._disconnectedPanel);\n          this._disconnectedPanel = undefined;\n        }\n\n        if (this._disconnectedActiveElement) {\n          this._disconnectedActiveElement.focus();\n\n          this._disconnectedActiveElement = undefined;\n        }\n      }\n    }, {\n      kind: \"method\",\n      key: \"_updateRoutes\",\n      value: async function _updateRoutes(oldPanels) {\n        this.routerOptions = getRoutes(this.hass.panels);\n\n        if (!this._waitForStart && this._currentPage && !this.hass.panels[this._currentPage]) {\n          if (this.hass.config.state !== home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_2__.STATE_NOT_RUNNING) {\n            this._waitForStart = true;\n\n            if (this.lastChild) {\n              this.removeChild(this.lastChild);\n            }\n\n            this.appendChild(this.createLoadingScreen());\n            return;\n          }\n        }\n\n        if (!oldPanels || !(0,_common_util_deep_equal__WEBPACK_IMPORTED_MODULE_4__.deepEqual)(oldPanels[this._currentPage], this.hass.panels[this._currentPage])) {\n          await this.rebuild();\n          await this.pageRendered;\n          (0,_util_init_skeleton__WEBPACK_IMPORTED_MODULE_5__.removeInitSkeleton)();\n        }\n      }\n    }]\n  };\n}, _hass_router_page__WEBPACK_IMPORTED_MODULE_1__.HassRouterPage);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/layouts/partial-panel-resolver.ts\n");

/***/ }),

/***/ "./src/resources/custom-card-support.ts":
/*!**********************************************!*\
  !*** ./src/resources/custom-card-support.ts ***!
  \**********************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n\nlit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement.prototype.html = lit_element__WEBPACK_IMPORTED_MODULE_0__.html;\nlit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement.prototype.css = lit_element__WEBPACK_IMPORTED_MODULE_0__.css;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvcmVzb3VyY2VzL2N1c3RvbS1jYXJkLXN1cHBvcnQudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9yZXNvdXJjZXMvY3VzdG9tLWNhcmQtc3VwcG9ydC50cz9kYmVhIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IGNzcywgaHRtbCwgTGl0RWxlbWVudCB9IGZyb20gXCJsaXQtZWxlbWVudFwiO1xuXG4oTGl0RWxlbWVudC5wcm90b3R5cGUgYXMgYW55KS5odG1sID0gaHRtbDtcbihMaXRFbGVtZW50LnByb3RvdHlwZSBhcyBhbnkpLmNzcyA9IGNzcztcbiJdLCJtYXBwaW5ncyI6Ijs7QUFBQTtBQUVBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/resources/custom-card-support.ts\n");

/***/ }),

/***/ "./src/resources/ha-style.ts":
/*!***********************************!*\
  !*** ./src/resources/ha-style.ts ***!
  \***********************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_paper_styles_paper_styles__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/paper-styles/paper-styles */ \"./node_modules/@polymer/paper-styles/paper-styles.js\");\n/* harmony import */ var _polymer_polymer_lib_elements_custom_style__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/lib/elements/custom-style */ \"./node_modules/@polymer/polymer/lib/elements/custom-style.js\");\n/* harmony import */ var _styles__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./styles */ \"./src/resources/styles.ts\");\n\n\n\nconst documentContainer = document.createElement(\"template\");\ndocumentContainer.setAttribute(\"style\", \"display: none;\");\ndocumentContainer.innerHTML = `<custom-style>\n  <style>\n    /*\n      Home Assistant default styles.\n\n      In Polymer 2.0, default styles should to be set on the html selector.\n      (Setting all default styles only on body breaks shadyCSS polyfill.)\n      See: https://github.com/home-assistant/home-assistant-polymer/pull/901\n    */\n    html {\n      font-size: 14px;\n      height: 100vh;\n\n      /* text */\n      --primary-text-color: #ffffff;\n      --secondary-text-color: #FF9800;\n      --text-primary-color: #ffffff;\n      --text-light-primary-color: #212121;\n      --disabled-text-color: #bdbdbd;\n\n      /* main interface colors */\n      --primary-color: #FF9800;\n      --dark-primary-color: #c66900;\n      --light-primary-color: #ffc947;\n      --accent-color: #c66900;\n      --divider-color: rgba(0, 0, 0, .12);\n\n      --scrollbar-thumb-color: rgb(194, 194, 194);\n\n      --error-color: #db4437;\n      --warning-color: #FF9800;\n      --success-color: #0f9d58;\n      --info-color: #4285f4;\n\n      /* states and badges */\n      --state-icon-color: #727272;\n      --state-icon-active-color: #ff9800;\n\n      /* background and sidebar */\n      --card-background-color: #323232;\n      --primary-background-color: #4c4c4c;\n      --secondary-background-color: #4c4c4c; /* behind the cards on state */\n\n      /* for header */\n      --header-height: 56px;\n\n      /* for label-badge */\n      --label-badge-red: #d6520d;\n      --label-badge-blue: #039be5;\n      --label-badge-green: #0DA035;\n      --label-badge-yellow: #f4b400;\n\n      /*\n        Paper-styles color.html dependency is stripped on build.\n        When a default paper-style color is used, it needs to be copied\n        from paper-styles/color.html to here.\n      */\n\n      --paper-grey-50: #727272; /* default for: --mwc-switch-unchecked-button-color */\n      --paper-grey-200: #4c4c4c;  /* for ha-date-picker-style */\n      --paper-grey-500: #9e9e9e;  /* --label-badge-grey */\n\n      /* for paper-slider */\n      --paper-green-400: #66bb6a;\n      --paper-blue-400: #42a5f5;\n      --paper-orange-400: #ffa726;\n\n      /* opacity for dark text on a light background */\n      --dark-divider-opacity: 0.12;\n      --dark-disabled-opacity: 0.38; /* or hint text or icon */\n      --dark-secondary-opacity: 0.54;\n      --dark-primary-opacity: 0.87;\n\n      /* opacity for light text on a dark background */\n      --light-divider-opacity: 0.12;\n      --light-disabled-opacity: 0.3; /* or hint text or icon */\n      --light-secondary-opacity: 0.7;\n      --light-primary-opacity: 1.0;\n\n      /* set our slider style */\n      --ha-slider-pin-font-size: 15px;\n\n      /* rgb */\n      --rgb-primary-color: 3, 169, 244;\n      --rgb-accent-color: 255, 152, 0;\n      --rgb-primary-text-color: 255, 255, 255;\n      --rgb-secondary-text-color: 114, 114, 114;\n      --rgb-text-primary-color: 255, 255, 255;\n      --rgb-card-background-color: 255, 255, 255;\n\n      ${Object.entries(_styles__WEBPACK_IMPORTED_MODULE_2__.derivedStyles).map(([key, value]) => `--${key}: ${value};`).join(\"\")}\n    }\n\n    /*\n      prevent clipping of positioned elements in a small scrollable\n      force smooth scrolling if can scroll\n      use non-shady selectors so this only targets iOS 9\n      conditional mixin set in ha-style-dialog does not work with shadyCSS\n    */\n    paper-dialog-scrollable:not(.can-scroll) > .scrollable {\n      -webkit-overflow-scrolling: auto !important;\n    }\n\n    paper-dialog-scrollable.can-scroll > .scrollable {\n      -webkit-overflow-scrolling: touch !important;\n    }\n\n    /* for paper-dialog */\n    iron-overlay-backdrop {\n      backdrop-filter: var(--dialog-backdrop-filter, none);\n    }\n  </style>\n</custom-style>`;\ndocument.head.appendChild(documentContainer.content);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/resources/ha-style.ts\n");

/***/ }),

/***/ "./src/resources/roboto.js":
/*!*********************************!*\
  !*** ./src/resources/roboto.js ***!
  \*********************************/
/*! unknown exports (runtime-defined) */
/*! runtime requirements:  */
/***/ (() => {

eval("const documentContainer = document.createElement(\"template\");\ndocumentContainer.setAttribute(\"style\", \"display: none;\");\ndocumentContainer.innerHTML = `<style>\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Thin\"),\n  local(\"Roboto-Thin\"),\n  url(/static/fonts/roboto/Roboto-Thin.woff2) format(\"woff2\");\nfont-weight: 100;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Thin Italic\"),\n  local(\"Roboto-ThinItalic\"),\n  url(/static/fonts/roboto/Roboto-ThinItalic.woff2) format(\"woff2\");\nfont-weight: 100;\nfont-style: italic;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Light\"),\n  local(\"Roboto-Light\"),\n  url(/static/fonts/roboto/Roboto-Light.woff2) format(\"woff2\");\nfont-weight: 300;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Light Italic\"),\n  local(\"Roboto-LightItalic\"),\n  url(/static/fonts/roboto/Roboto-LightItalic.woff2) format(\"woff2\");\nfont-weight: 300;\nfont-style: italic;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Regular\"),\n  local(\"Roboto-Regular\"),\n  url(/static/fonts/roboto/Roboto-Regular.woff2) format(\"woff2\");\nfont-weight: 400;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Italic\"),\n  local(\"Roboto-Italic\"),\n  url(/static/fonts/roboto/Roboto-RegularItalic.woff2) format(\"woff2\");\nfont-weight: 400;\nfont-style: italic;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Medium\"),\n  local(\"Roboto-Medium\"),\n  url(/static/fonts/roboto/Roboto-Medium.woff2) format(\"woff2\");\nfont-weight: 500;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Medium Italic\"),\n  local(\"Roboto-MediumItalic\"),\n  url(/static/fonts/roboto/Roboto-MediumItalic.woff2) format(\"woff2\");\nfont-weight: 500;\nfont-style: italic;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Bold\"),\n  local(\"Roboto-Bold\"),\n  url(/static/fonts/roboto/Roboto-Bold.woff2) format(\"woff2\");\nfont-weight: 700;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Bold Italic\"),\n  local(\"Roboto-BoldItalic\"),\n  url(/static/fonts/roboto/Roboto-BoldItalic.woff2) format(\"woff2\");\nfont-weight: 700;\nfont-style: italic;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Black\"),\n  local(\"Roboto-Black\"),\n  url(/static/fonts/roboto/Roboto-Black.woff2) format(\"woff2\");\nfont-weight: 900;\nfont-style: normal;\n}\n@font-face {\nfont-family: \"Roboto\";\nsrc:\n  local(\"Roboto Black Italic\"),\n  local(\"Roboto-BlackItalic\"),\n  url(/static/fonts/roboto/Roboto-BlackItalic.woff2) format(\"woff2\");\nfont-weight: 900;\nfont-style: italic;\n}\n</style>`;\ndocument.head.appendChild(documentContainer.content);\n/**\n@license\nCopyright (c) 2015 The Polymer Project Authors. All rights reserved.\nThis code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt\nThe complete set of authors may be found at http://polymer.github.io/AUTHORS.txt\nThe complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt\nCode distributed by Google as part of the polymer project is also\nsubject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt\n*/\n\n/*\n  FIXME(polymer-modulizer): the above comments were extracted\n  from HTML and may be out of place here. Review them and\n  then delete this comment!\n*///# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/resources/roboto.js\n");

/***/ }),

/***/ "./src/resources/styles.ts":
/*!*********************************!*\
  !*** ./src/resources/styles.ts ***!
  \*********************************/
/*! namespace exports */
/*! export darkStyles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export derivedStyles [provided] [no usage info] [missing usage info prevents renaming] */
/*! export haStyle [provided] [no usage info] [missing usage info prevents renaming] */
/*! export haStyleDialog [provided] [no usage info] [missing usage info prevents renaming] */
/*! export haStyleScrollbar [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"darkStyles\": () => /* binding */ darkStyles,\n/* harmony export */   \"derivedStyles\": () => /* binding */ derivedStyles,\n/* harmony export */   \"haStyle\": () => /* binding */ haStyle,\n/* harmony export */   \"haStyleDialog\": () => /* binding */ haStyleDialog,\n/* harmony export */   \"haStyleScrollbar\": () => /* binding */ haStyleScrollbar\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\n\nconst darkStyles = {\n  \"primary-background-color\": \"#111111\",\n  \"card-background-color\": \"#1c1c1c\",\n  \"secondary-background-color\": \"#202020\",\n  \"primary-text-color\": \"#e1e1e1\",\n  \"secondary-text-color\": \"#9b9b9b\",\n  \"disabled-text-color\": \"#6f6f6f\",\n  \"app-header-text-color\": \"#e1e1e1\",\n  \"app-header-background-color\": \"#101e24\",\n  \"switch-unchecked-button-color\": \"#999999\",\n  \"switch-unchecked-track-color\": \"#9b9b9b\",\n  \"divider-color\": \"rgba(225, 225, 225, .12)\",\n  \"mdc-ripple-color\": \"#AAAAAA\",\n  \"codemirror-keyword\": \"#C792EA\",\n  \"codemirror-operator\": \"#89DDFF\",\n  \"codemirror-variable\": \"#f07178\",\n  \"codemirror-variable-2\": \"#EEFFFF\",\n  \"codemirror-variable-3\": \"#DECB6B\",\n  \"codemirror-builtin\": \"#FFCB6B\",\n  \"codemirror-atom\": \"#F78C6C\",\n  \"codemirror-number\": \"#FF5370\",\n  \"codemirror-def\": \"#82AAFF\",\n  \"codemirror-string\": \"#C3E88D\",\n  \"codemirror-string-2\": \"#f07178\",\n  \"codemirror-comment\": \"#545454\",\n  \"codemirror-tag\": \"#FF5370\",\n  \"codemirror-meta\": \"#FFCB6B\",\n  \"codemirror-attribute\": \"#C792EA\",\n  \"codemirror-property\": \"#C792EA\",\n  \"codemirror-qualifier\": \"#DECB6B\",\n  \"codemirror-type\": \"#DECB6B\"\n};\nconst derivedStyles = {\n  \"error-state-color\": \"var(--error-color)\",\n  \"state-icon-unavailable-color\": \"var(--disabled-text-color)\",\n  \"sidebar-text-color\": \"var(--primary-text-color)\",\n  \"sidebar-background-color\": \"var(--card-background-color)\",\n  \"sidebar-selected-text-color\": \"var(--primary-color)\",\n  \"sidebar-selected-icon-color\": \"var(--primary-color)\",\n  \"sidebar-icon-color\": \"rgba(var(--rgb-primary-text-color), 0.6)\",\n  \"switch-checked-color\": \"var(--primary-color)\",\n  \"switch-checked-button-color\": \"var(--switch-checked-color, var(--primary-background-color))\",\n  \"switch-checked-track-color\": \"var(--switch-checked-color, #000000)\",\n  \"switch-unchecked-button-color\": \"var(--switch-unchecked-color, var(--primary-background-color))\",\n  \"switch-unchecked-track-color\": \"var(--switch-unchecked-color, #000000)\",\n  \"slider-color\": \"var(--primary-color)\",\n  \"slider-secondary-color\": \"var(--light-primary-color)\",\n  \"slider-bar-color\": \"var(--disabled-text-color)\",\n  \"label-badge-grey\": \"var(--paper-grey-500)\",\n  \"label-badge-background-color\": \"var(--card-background-color)\",\n  \"label-badge-text-color\": \"rgba(var(--rgb-primary-text-color), 0.8)\",\n  \"paper-listbox-background-color\": \"var(--card-background-color)\",\n  \"paper-item-icon-color\": \"var(--state-icon-color)\",\n  \"paper-item-icon-active-color\": \"var(--state-icon-active-color)\",\n  \"table-row-background-color\": \"var(--primary-background-color)\",\n  \"table-row-alternative-background-color\": \"var(--secondary-background-color)\",\n  \"paper-slider-knob-color\": \"var(--slider-color)\",\n  \"paper-slider-knob-start-color\": \"var(--slider-color)\",\n  \"paper-slider-pin-color\": \"var(--slider-color)\",\n  \"paper-slider-pin-start-color\": \"var(--slider-color)\",\n  \"paper-slider-active-color\": \"var(--slider-color)\",\n  \"paper-slider-secondary-color\": \"var(--slider-secondary-color)\",\n  \"paper-slider-container-color\": \"var(--slider-bar-color)\",\n  \"data-table-background-color\": \"var(--card-background-color)\",\n  \"markdown-code-background-color\": \"var(--primary-background-color)\",\n  \"mdc-theme-primary\": \"var(--primary-color)\",\n  \"mdc-theme-secondary\": \"var(--accent-color)\",\n  \"mdc-theme-background\": \"var(--primary-background-color)\",\n  \"mdc-theme-surface\": \"var(--card-background-color)\",\n  \"mdc-theme-on-primary\": \"var(--text-primary-color)\",\n  \"mdc-theme-on-secondary\": \"var(--text-primary-color)\",\n  \"mdc-theme-on-surface\": \"var(--primary-text-color)\",\n  \"mdc-theme-text-primary-on-background\": \"var(--primary-text-color)\",\n  \"mdc-theme-text-secondary-on-background\": \"var(--secondary-text-color)\",\n  \"mdc-theme-text-icon-on-background\": \"var(--secondary-text-color)\",\n  \"app-header-text-color\": \"var(--text-primary-color)\",\n  \"app-header-background-color\": \"var(--primary-color)\",\n  \"material-body-text-color\": \"var(--primary-text-color)\",\n  \"material-background-color\": \"var(--card-background-color)\",\n  \"material-secondary-background-color\": \"var(--secondary-background-color)\",\n  \"material-secondary-text-color\": \"var(--secondary-text-color)\",\n  \"mdc-checkbox-unchecked-color\": \"rgba(var(--rgb-primary-text-color), 0.54)\",\n  \"mdc-checkbox-disabled-color\": \"var(--disabled-text-color)\",\n  \"mdc-radio-unchecked-color\": \"rgba(var(--rgb-primary-text-color), 0.54)\",\n  \"mdc-radio-disabled-color\": \"var(--disabled-text-color)\",\n  \"mdc-tab-text-label-color-default\": \"var(--primary-text-color)\",\n  \"mdc-button-disabled-ink-color\": \"var(--disabled-text-color)\",\n  \"mdc-button-outline-color\": \"var(--divider-color)\",\n  \"mdc-dialog-scroll-divider-color\": \"var(--divider-color)\"\n};\nconst haStyle = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`\n  :host {\n    font-family: var(--paper-font-body1_-_font-family);\n    -webkit-font-smoothing: var(--paper-font-body1_-_-webkit-font-smoothing);\n    font-size: var(--paper-font-body1_-_font-size);\n    font-weight: var(--paper-font-body1_-_font-weight);\n    line-height: var(--paper-font-body1_-_line-height);\n  }\n\n  app-header-layout,\n  ha-app-layout {\n    background-color: var(--primary-background-color);\n  }\n\n  app-header,\n  app-toolbar {\n    background-color: var(--app-header-background-color);\n    font-weight: 400;\n    color: var(--app-header-text-color, white);\n  }\n\n  app-toolbar {\n    height: var(--header-height);\n  }\n\n  app-header div[sticky] {\n    height: 48px;\n  }\n\n  app-toolbar [main-title] {\n    margin-left: 20px;\n  }\n\n  h1 {\n    font-family: var(--paper-font-headline_-_font-family);\n    -webkit-font-smoothing: var(--paper-font-headline_-_-webkit-font-smoothing);\n    white-space: var(--paper-font-headline_-_white-space);\n    overflow: var(--paper-font-headline_-_overflow);\n    text-overflow: var(--paper-font-headline_-_text-overflow);\n    font-size: var(--paper-font-headline_-_font-size);\n    font-weight: var(--paper-font-headline_-_font-weight);\n    line-height: var(--paper-font-headline_-_line-height);\n  }\n\n  h2 {\n    font-family: var(--paper-font-title_-_font-family);\n    -webkit-font-smoothing: var(--paper-font-title_-_-webkit-font-smoothing);\n    white-space: var(--paper-font-title_-_white-space);\n    overflow: var(--paper-font-title_-_overflow);\n    text-overflow: var(--paper-font-title_-_text-overflow);\n    font-size: var(--paper-font-title_-_font-size);\n    font-weight: var(--paper-font-title_-_font-weight);\n    line-height: var(--paper-font-title_-_line-height);\n  }\n\n  h3 {\n    font-family: var(--paper-font-subhead_-_font-family);\n    -webkit-font-smoothing: var(--paper-font-subhead_-_-webkit-font-smoothing);\n    white-space: var(--paper-font-subhead_-_white-space);\n    overflow: var(--paper-font-subhead_-_overflow);\n    text-overflow: var(--paper-font-subhead_-_text-overflow);\n    font-size: var(--paper-font-subhead_-_font-size);\n    font-weight: var(--paper-font-subhead_-_font-weight);\n    line-height: var(--paper-font-subhead_-_line-height);\n  }\n\n  a {\n    color: var(--primary-color);\n  }\n\n  .secondary {\n    color: var(--secondary-text-color);\n  }\n\n  .error {\n    color: var(--error-color);\n  }\n\n  .warning {\n    color: var(--error-color);\n  }\n\n  mwc-button.warning {\n    --mdc-theme-primary: var(--error-color);\n  }\n\n  button.link {\n    background: none;\n    color: inherit;\n    border: none;\n    padding: 0;\n    font: inherit;\n    text-align: left;\n    text-decoration: underline;\n    cursor: pointer;\n  }\n\n  .card-actions a {\n    text-decoration: none;\n  }\n\n  .card-actions .warning {\n    --mdc-theme-primary: var(--error-color);\n  }\n\n  .layout.horizontal,\n  .layout.vertical {\n    display: flex;\n  }\n  .layout.inline {\n    display: inline-flex;\n  }\n  .layout.horizontal {\n    flex-direction: row;\n  }\n  .layout.vertical {\n    flex-direction: column;\n  }\n  .layout.wrap {\n    flex-wrap: wrap;\n  }\n  .layout.no-wrap {\n    flex-wrap: nowrap;\n  }\n  .layout.center,\n  .layout.center-center {\n    align-items: center;\n  }\n  .layout.bottom {\n    align-items: flex-end;\n  }\n  .layout.center-justified,\n  .layout.center-center {\n    justify-content: center;\n  }\n  .flex {\n    flex: 1;\n    flex-basis: 0.000000001px;\n  }\n  .flex-auto {\n    flex: 1 1 auto;\n  }\n  .flex-none {\n    flex: none;\n  }\n  .layout.justified {\n    justify-content: space-between;\n  }\n`;\nconst haStyleDialog = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`\n  /* prevent clipping of positioned elements */\n  paper-dialog-scrollable {\n    --paper-dialog-scrollable: {\n      -webkit-overflow-scrolling: auto;\n    }\n  }\n\n  /* force smooth scrolling for iOS 10 */\n  paper-dialog-scrollable.can-scroll {\n    --paper-dialog-scrollable: {\n      -webkit-overflow-scrolling: touch;\n    }\n  }\n\n  .paper-dialog-buttons {\n    align-items: flex-end;\n    padding: 8px;\n    padding-bottom: max(env(safe-area-inset-bottom), 8px);\n  }\n\n  @media all and (min-width: 450px) and (min-height: 500px) {\n    ha-paper-dialog {\n      min-width: 400px;\n    }\n  }\n\n  @media all and (max-width: 450px), all and (max-height: 500px) {\n    paper-dialog,\n    ha-paper-dialog {\n      margin: 0;\n      width: calc(\n        100% - env(safe-area-inset-right) - env(safe-area-inset-left)\n      ) !important;\n      min-width: calc(\n        100% - env(safe-area-inset-right) - env(safe-area-inset-left)\n      ) !important;\n      max-width: calc(\n        100% - env(safe-area-inset-right) - env(safe-area-inset-left)\n      ) !important;\n      max-height: calc(100% - var(--header-height));\n\n      position: fixed !important;\n      bottom: 0px;\n      left: env(safe-area-inset-left);\n      right: env(safe-area-inset-right);\n      overflow: scroll;\n      border-bottom-left-radius: 0px;\n      border-bottom-right-radius: 0px;\n    }\n  }\n\n  /* mwc-dialog (ha-dialog) styles */\n  ha-dialog {\n    --mdc-dialog-min-width: 400px;\n    --mdc-dialog-max-width: 600px;\n    --mdc-dialog-heading-ink-color: var(--primary-text-color);\n    --mdc-dialog-content-ink-color: var(--primary-text-color);\n    --justify-action-buttons: space-between;\n  }\n\n  ha-dialog .form {\n    padding-bottom: 24px;\n    color: var(--primary-text-color);\n  }\n\n  a {\n    color: var(--primary-color);\n  }\n\n  /* make dialog fullscreen on small screens */\n  @media all and (max-width: 450px), all and (max-height: 500px) {\n    ha-dialog {\n      --mdc-dialog-min-width: calc(\n        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)\n      );\n      --mdc-dialog-max-width: calc(\n        100vw - env(safe-area-inset-right) - env(safe-area-inset-left)\n      );\n      --mdc-dialog-min-height: 100%;\n      --mdc-dialog-max-height: 100%;\n      --mdc-shape-medium: 0px;\n      --vertial-align-dialog: flex-end;\n    }\n  }\n  mwc-button.warning {\n    --mdc-theme-primary: var(--error-color);\n  }\n  .error {\n    color: var(--error-color);\n  }\n`;\nconst haStyleScrollbar = lit_element__WEBPACK_IMPORTED_MODULE_0__.css`\n  .ha-scrollbar::-webkit-scrollbar {\n    width: 0.4rem;\n    height: 0.4rem;\n  }\n\n  .ha-scrollbar::-webkit-scrollbar-thumb {\n    -webkit-border-radius: 4px;\n    border-radius: 4px;\n    background: var(--scrollbar-thumb-color);\n  }\n\n  .ha-scrollbar {\n    overflow-y: auto;\n    scrollbar-color: var(--scrollbar-thumb-color) transparent;\n    scrollbar-width: thin;\n  }\n`;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/resources/styles.ts\n");

/***/ }),

/***/ "./src/resources/translations-metadata.ts":
/*!************************************************!*\
  !*** ./src/resources/translations-metadata.ts ***!
  \************************************************/
/*! namespace exports */
/*! export translationMetadata [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"translationMetadata\": () => /* binding */ translationMetadata\n/* harmony export */ });\nObject(function webpackMissingModule() { var e = new Error(\"Cannot find module '../../build-translations/translationMetadata.json'\"); e.code = 'MODULE_NOT_FOUND'; throw e; }());\n\nconst translationMetadata = Object(function webpackMissingModule() { var e = new Error(\"Cannot find module '../../build-translations/translationMetadata.json'\"); e.code = 'MODULE_NOT_FOUND'; throw e; }());//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvcmVzb3VyY2VzL3RyYW5zbGF0aW9ucy1tZXRhZGF0YS50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL3Jlc291cmNlcy90cmFuc2xhdGlvbnMtbWV0YWRhdGEudHM/ZTVhNSJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgKiBhcyB0cmFuc2xhdGlvbk1ldGFkYXRhXyBmcm9tIFwiLi4vLi4vYnVpbGQtdHJhbnNsYXRpb25zL3RyYW5zbGF0aW9uTWV0YWRhdGEuanNvblwiO1xuaW1wb3J0IHsgVHJhbnNsYXRpb25NZXRhZGF0YSB9IGZyb20gXCIuLi90eXBlcy5qc1wiO1xuXG5leHBvcnQgY29uc3QgdHJhbnNsYXRpb25NZXRhZGF0YSA9ICh0cmFuc2xhdGlvbk1ldGFkYXRhXyBhcyBhbnkpXG4gIC5kZWZhdWx0IGFzIFRyYW5zbGF0aW9uTWV0YWRhdGE7XG4iXSwibWFwcGluZ3MiOiI7Ozs7O0FBQUE7QUFHQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/resources/translations-metadata.ts\n");

/***/ }),

/***/ "./src/state/auth-mixin.ts":
/*!*********************************!*\
  !*** ./src/state/auth-mixin.ts ***!
  \*********************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.e, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _common_auth_token_storage__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/auth/token_storage */ \"./src/common/auth/token_storage.ts\");\n/* harmony import */ var _data_ws_user__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../data/ws-user */ \"./src/data/ws-user.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"hass-logout\", () => this._handleLogout());\n    this.addEventListener(\"hass-refresh-current-user\", () => {\n      (0,_data_ws_user__WEBPACK_IMPORTED_MODULE_1__.userCollection)(this.hass.connection).refresh();\n    });\n  }\n\n  hassConnected() {\n    super.hassConnected();\n    (0,_data_ws_user__WEBPACK_IMPORTED_MODULE_1__.subscribeUser)(this.hass.connection, user => this._updateHass({\n      user\n    }));\n\n    if ((0,_common_auth_token_storage__WEBPACK_IMPORTED_MODULE_0__.askWrite)()) {\n      this.updateComplete.then(() => Promise.all(/*! import() | ha-store-auth-card */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-image_iron-image_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-card_paper-card_js\"), __webpack_require__.e(\"ha-store-auth-card\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../dialogs/ha-store-auth-card */ \"./src/dialogs/ha-store-auth-card.js\"))).then(() => {\n        const el = document.createElement(\"ha-store-auth-card\");\n        this.shadowRoot.appendChild(el);\n        this.provideHass(el);\n      });\n    }\n  }\n\n  async _handleLogout() {\n    try {\n      await this.hass.auth.revoke();\n      this.hass.connection.close();\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__.clearState)();\n      document.location.href = \"/\";\n    } catch (err) {\n      // eslint-disable-next-line\n      console.error(err);\n      alert(\"Log out failed\");\n    }\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/auth-mixin.ts\n");

/***/ }),

/***/ "./src/state/connection-mixin.ts":
/*!***************************************!*\
  !*** ./src/state/connection-mixin.ts ***!
  \***************************************/
/*! namespace exports */
/*! export connectionMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"connectionMixin\": () => /* binding */ connectionMixin\n/* harmony export */ });\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/commands.js\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/errors.js\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/entities.js\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/config.js\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/services.js\");\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n/* harmony import */ var _data_connection_status__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data/connection-status */ \"./src/data/connection-status.ts\");\n/* harmony import */ var _data_frontend__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../data/frontend */ \"./src/data/frontend.ts\");\n/* harmony import */ var _data_haptics__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../data/haptics */ \"./src/data/haptics.ts\");\n/* harmony import */ var _data_panel__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../data/panel */ \"./src/data/panel.ts\");\n/* harmony import */ var _data_ws_panels__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../data/ws-panels */ \"./src/data/ws-panels.ts\");\n/* harmony import */ var _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../resources/translations-metadata */ \"./src/resources/translations-metadata.ts\");\n/* harmony import */ var _util_fetch_with_auth__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../util/fetch-with-auth */ \"./src/util/fetch-with-auth.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n/* harmony import */ var _util_hass_call_api__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../util/hass-call-api */ \"./src/util/hass-call-api.ts\");\n/* harmony import */ var _util_hass_translation__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../util/hass-translation */ \"./src/util/hass-translation.ts\");\n\n\n\n\n\n\n\n\n\n\n\n\nconst connectionMixin = superClass => class extends superClass {\n  initializeHass(auth, conn) {\n    this.hass = {\n      auth,\n      connection: conn,\n      connected: true,\n      states: null,\n      config: null,\n      themes: null,\n      panels: null,\n      services: null,\n      user: null,\n      panelUrl: this._panelUrl,\n      defaultPanel: _data_panel__WEBPACK_IMPORTED_MODULE_3__.DEFAULT_PANEL,\n      language: (0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_8__.getLocalLanguage)(),\n      selectedLanguage: null,\n      resources: null,\n      localize: () => \"\",\n      translationMetadata: _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_5__.translationMetadata,\n      dockedSidebar: \"docked\",\n      vibrate: true,\n      suspendWhenHidden: true,\n      enableShortcuts: true,\n      moreInfoEntityId: null,\n      hassUrl: (path = \"\") => new URL(path, auth.data.hassUrl).toString(),\n      callService: async (domain, service, serviceData = {}) => {\n        if (true) {\n          // eslint-disable-next-line no-console\n          console.log(\"Calling service\", domain, service, serviceData);\n        }\n\n        try {\n          return await (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_9__.callService)(conn, domain, service, serviceData);\n        } catch (err) {\n          if (true) {\n            // eslint-disable-next-line no-console\n            console.error(\"Error calling service\", domain, service, serviceData, err);\n          }\n\n          (0,_data_haptics__WEBPACK_IMPORTED_MODULE_2__.forwardHaptic)(\"failure\");\n          const message = this.hass.localize(\"ui.notification_toast.service_call_failed\", \"service\", `${domain}/${service}`) + ` ${err.message}`;\n          (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_10__.fireEvent)(this, \"hass-notification\", {\n            message\n          });\n          throw err;\n        }\n      },\n      callApi: async (method, path, parameters) => (0,_util_hass_call_api__WEBPACK_IMPORTED_MODULE_7__.default)(auth, method, path, parameters),\n      fetchWithAuth: (path, init) => (0,_util_fetch_with_auth__WEBPACK_IMPORTED_MODULE_11__.fetchWithAuth)(auth, `${auth.data.hassUrl}${path}`, init),\n      // For messages that do not get a response\n      sendWS: msg => {\n        if (true) {\n          // eslint-disable-next-line no-console\n          console.log(\"Sending\", msg);\n        }\n\n        conn.sendMessage(msg);\n      },\n      // For messages that expect a response\n      callWS: msg => {\n        if (true) {\n          // eslint-disable-next-line no-console\n          console.log(\"Sending\", msg);\n        }\n\n        const resp = conn.sendMessagePromise(msg);\n\n        if (true) {\n          resp.then( // eslint-disable-next-line no-console\n          result => console.log(\"Received\", result), // eslint-disable-next-line no-console\n          err => console.error(\"Error\", err));\n        }\n\n        return resp;\n      },\n      loadBackendTranslation: (category, integration, configFlow) => {\n        var _this$hass;\n\n        return (// @ts-ignore\n          this._loadHassTranslations((_this$hass = this.hass) === null || _this$hass === void 0 ? void 0 : _this$hass.language, category, integration, configFlow)\n        );\n      },\n      ...(0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_6__.getState)(),\n      ...this._pendingHass\n    };\n    this.hassConnected();\n  }\n\n  hassConnected() {\n    super.hassConnected();\n    const conn = this.hass.connection;\n    (0,_data_connection_status__WEBPACK_IMPORTED_MODULE_0__.broadcastConnectionStatus)(\"connected\");\n    conn.addEventListener(\"ready\", () => this.hassReconnected());\n    conn.addEventListener(\"disconnected\", () => this.hassDisconnected()); // If we reconnect after losing connection and auth is no longer valid.\n\n    conn.addEventListener(\"reconnect-error\", (_conn, err) => {\n      if (err === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_12__.ERR_INVALID_AUTH) {\n        (0,_data_connection_status__WEBPACK_IMPORTED_MODULE_0__.broadcastConnectionStatus)(\"auth-invalid\");\n        location.reload();\n      }\n    });\n    (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_13__.subscribeEntities)(conn, states => this._updateHass({\n      states\n    }));\n    (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_14__.subscribeConfig)(conn, config => this._updateHass({\n      config\n    }));\n    (0,home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_15__.subscribeServices)(conn, services => this._updateHass({\n      services\n    }));\n    (0,_data_ws_panels__WEBPACK_IMPORTED_MODULE_4__.subscribePanels)(conn, panels => this._updateHass({\n      panels\n    }));\n    (0,_data_frontend__WEBPACK_IMPORTED_MODULE_1__.subscribeFrontendUserData)(conn, \"core\", userData => this._updateHass({\n      userData\n    }));\n  }\n\n  hassReconnected() {\n    super.hassReconnected();\n\n    this._updateHass({\n      connected: true\n    });\n\n    (0,_data_connection_status__WEBPACK_IMPORTED_MODULE_0__.broadcastConnectionStatus)(\"connected\"); // on reconnect always fetch config as we might miss an update while we were disconnected\n    // @ts-ignore\n\n    this.hass.callWS({\n      type: \"get_config\"\n    }).then(config => {\n      this._updateHass({\n        config\n      });\n    });\n  }\n\n  hassDisconnected() {\n    super.hassDisconnected();\n\n    this._updateHass({\n      connected: false\n    });\n\n    (0,_data_connection_status__WEBPACK_IMPORTED_MODULE_0__.broadcastConnectionStatus)(\"disconnected\");\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/state/connection-mixin.ts\n");

/***/ }),

/***/ "./src/state/dialog-manager-mixin.ts":
/*!*******************************************!*\
  !*** ./src/state/dialog-manager-mixin.ts ***!
  \*******************************************/
/*! namespace exports */
/*! export dialogManagerMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"dialogManagerMixin\": () => /* binding */ dialogManagerMixin\n/* harmony export */ });\n/* harmony import */ var _dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../dialogs/make-dialog-manager */ \"./src/dialogs/make-dialog-manager.ts\");\n\nconst dialogManagerMixin = superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps); // deprecated\n\n    this.addEventListener(\"register-dialog\", e => this.registerDialog(e.detail));\n    (0,_dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__.makeDialogManager)(this, this.shadowRoot);\n  }\n\n  registerDialog({\n    dialogShowEvent,\n    dialogTag,\n    dialogImport\n  }) {\n    this.addEventListener(dialogShowEvent, showEv => {\n      (0,_dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__.showDialog)(this, this.shadowRoot, dialogTag, showEv.detail, dialogImport);\n    });\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/dialog-manager-mixin.ts\n");

/***/ }),

/***/ "./src/state/disconnect-toast-mixin.ts":
/*!*********************************************!*\
  !*** ./src/state/disconnect-toast-mixin.ts ***!
  \*********************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.e, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _util_toast__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/toast */ \"./src/util/toast.ts\");\n/* harmony import */ var home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! home-assistant-js-websocket */ \"./node_modules/home-assistant-js-websocket/dist/config.js\");\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps); // Need to load in advance because when disconnected, can't dynamically load code.\n\n    Promise.all(/*! import() | notification-manager */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-resizable-behavior_iron-resizable-behavior_js-node_modules_-b64774\"), __webpack_require__.e(\"notification-manager\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../managers/notification-manager */ \"./src/managers/notification-manager.ts\"));\n  }\n\n  updated(changedProperties) {\n    var _oldHass$config;\n\n    super.updated(changedProperties);\n    const oldHass = changedProperties.get(\"hass\");\n\n    if (!changedProperties.has(\"hass\") || !this.hass.config || (oldHass === null || oldHass === void 0 ? void 0 : (_oldHass$config = oldHass.config) === null || _oldHass$config === void 0 ? void 0 : _oldHass$config.state) === this.hass.config.state) {\n      return;\n    }\n\n    if (this.hass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__.STATE_NOT_RUNNING) {\n      (0,_util_toast__WEBPACK_IMPORTED_MODULE_0__.showToast)(this, {\n        message: this.hass.localize(\"ui.notification_toast.starting\") || \"Home Assistant is starting, not everything will be available until it is finished.\",\n        duration: 0,\n        dismissable: false,\n        action: {\n          text: this.hass.localize(\"ui.notification_toast.dismiss\"),\n          action: () => {}\n        }\n      });\n    } else if ((oldHass === null || oldHass === void 0 ? void 0 : oldHass.config) && oldHass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__.STATE_NOT_RUNNING && (this.hass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__.STATE_STARTING || this.hass.config.state === home_assistant_js_websocket__WEBPACK_IMPORTED_MODULE_1__.STATE_RUNNING)) {\n      (0,_util_toast__WEBPACK_IMPORTED_MODULE_0__.showToast)(this, {\n        message: this.hass.localize(\"ui.notification_toast.started\"),\n        duration: 5000\n      });\n    }\n  }\n\n  hassReconnected() {\n    super.hassReconnected();\n    (0,_util_toast__WEBPACK_IMPORTED_MODULE_0__.showToast)(this, {\n      message: \"\",\n      duration: 1\n    });\n  }\n\n  hassDisconnected() {\n    super.hassDisconnected();\n    (0,_util_toast__WEBPACK_IMPORTED_MODULE_0__.showToast)(this, {\n      message: this.hass.localize(\"ui.notification_toast.connection_lost\"),\n      duration: 0,\n      dismissable: false\n    });\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/disconnect-toast-mixin.ts\n");

/***/ }),

/***/ "./src/state/haptic-mixin.ts":
/*!***********************************!*\
  !*** ./src/state/haptic-mixin.ts ***!
  \***********************************/
/*! namespace exports */
/*! export hapticMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"hapticMixin\": () => /* binding */ hapticMixin\n/* harmony export */ });\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n\nconst hapticPatterns = {\n  success: [50, 50, 50],\n  warning: [100, 50, 100],\n  failure: [200, 100, 200],\n  light: [50],\n  medium: [100],\n  heavy: [200],\n  selection: [20]\n};\n\nconst handleHaptic = hapticTypeEvent => {\n  navigator.vibrate(hapticPatterns[hapticTypeEvent.detail]);\n};\n\nconst hapticMixin = superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"hass-vibrate\", ev => {\n      const vibrate = ev.detail.vibrate;\n\n      if (navigator.vibrate && vibrate) {\n        window.addEventListener(\"haptic\", handleHaptic);\n      } else {\n        window.removeEventListener(\"haptic\", handleHaptic);\n      }\n\n      this._updateHass({\n        vibrate\n      });\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_0__.storeState)(this.hass);\n    });\n  }\n\n  hassConnected() {\n    super.hassConnected();\n\n    if (navigator.vibrate && this.hass.vibrate) {\n      window.addEventListener(\"haptic\", handleHaptic);\n    }\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/haptic-mixin.ts\n");

/***/ }),

/***/ "./src/state/hass-base-mixin.ts":
/*!**************************************!*\
  !*** ./src/state/hass-base-mixin.ts ***!
  \**************************************/
/*! namespace exports */
/*! export HassBaseEl [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HassBaseEl\": () => /* binding */ HassBaseEl\n/* harmony export */ });\n/* harmony import */ var lit_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lit-element */ \"./node_modules/lit-element/lit-element.js\");\nfunction _decorate(decorators, factory, superClass, mixins) { var api = _getDecoratorsApi(); if (mixins) { for (var i = 0; i < mixins.length; i++) { api = mixins[i](api); } } var r = factory(function initialize(O) { api.initializeInstanceElements(O, decorated.elements); }, superClass); var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators); api.initializeClassElements(r.F, decorated.elements); return api.runClassFinishers(r.F, decorated.finishers); }\n\nfunction _getDecoratorsApi() { _getDecoratorsApi = function () { return api; }; var api = { elementsDefinitionOrder: [[\"method\"], [\"field\"]], initializeInstanceElements: function (O, elements) { [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { if (element.kind === kind && element.placement === \"own\") { this.defineClassElement(O, element); } }, this); }, this); }, initializeClassElements: function (F, elements) { var proto = F.prototype; [\"method\", \"field\"].forEach(function (kind) { elements.forEach(function (element) { var placement = element.placement; if (element.kind === kind && (placement === \"static\" || placement === \"prototype\")) { var receiver = placement === \"static\" ? F : proto; this.defineClassElement(receiver, element); } }, this); }, this); }, defineClassElement: function (receiver, element) { var descriptor = element.descriptor; if (element.kind === \"field\") { var initializer = element.initializer; descriptor = { enumerable: descriptor.enumerable, writable: descriptor.writable, configurable: descriptor.configurable, value: initializer === void 0 ? void 0 : initializer.call(receiver) }; } Object.defineProperty(receiver, element.key, descriptor); }, decorateClass: function (elements, decorators) { var newElements = []; var finishers = []; var placements = { static: [], prototype: [], own: [] }; elements.forEach(function (element) { this.addElementPlacement(element, placements); }, this); elements.forEach(function (element) { if (!_hasDecorators(element)) return newElements.push(element); var elementFinishersExtras = this.decorateElement(element, placements); newElements.push(elementFinishersExtras.element); newElements.push.apply(newElements, elementFinishersExtras.extras); finishers.push.apply(finishers, elementFinishersExtras.finishers); }, this); if (!decorators) { return { elements: newElements, finishers: finishers }; } var result = this.decorateConstructor(newElements, decorators); finishers.push.apply(finishers, result.finishers); result.finishers = finishers; return result; }, addElementPlacement: function (element, placements, silent) { var keys = placements[element.placement]; if (!silent && keys.indexOf(element.key) !== -1) { throw new TypeError(\"Duplicated element (\" + element.key + \")\"); } keys.push(element.key); }, decorateElement: function (element, placements) { var extras = []; var finishers = []; for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) { var keys = placements[element.placement]; keys.splice(keys.indexOf(element.key), 1); var elementObject = this.fromElementDescriptor(element); var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject); element = elementFinisherExtras.element; this.addElementPlacement(element, placements); if (elementFinisherExtras.finisher) { finishers.push(elementFinisherExtras.finisher); } var newExtras = elementFinisherExtras.extras; if (newExtras) { for (var j = 0; j < newExtras.length; j++) { this.addElementPlacement(newExtras[j], placements); } extras.push.apply(extras, newExtras); } } return { element: element, finishers: finishers, extras: extras }; }, decorateConstructor: function (elements, decorators) { var finishers = []; for (var i = decorators.length - 1; i >= 0; i--) { var obj = this.fromClassDescriptor(elements); var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj); if (elementsAndFinisher.finisher !== undefined) { finishers.push(elementsAndFinisher.finisher); } if (elementsAndFinisher.elements !== undefined) { elements = elementsAndFinisher.elements; for (var j = 0; j < elements.length - 1; j++) { for (var k = j + 1; k < elements.length; k++) { if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) { throw new TypeError(\"Duplicated element (\" + elements[j].key + \")\"); } } } } } return { elements: elements, finishers: finishers }; }, fromElementDescriptor: function (element) { var obj = { kind: element.kind, key: element.key, placement: element.placement, descriptor: element.descriptor }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); if (element.kind === \"field\") obj.initializer = element.initializer; return obj; }, toElementDescriptors: function (elementObjects) { if (elementObjects === undefined) return; return _toArray(elementObjects).map(function (elementObject) { var element = this.toElementDescriptor(elementObject); this.disallowProperty(elementObject, \"finisher\", \"An element descriptor\"); this.disallowProperty(elementObject, \"extras\", \"An element descriptor\"); return element; }, this); }, toElementDescriptor: function (elementObject) { var kind = String(elementObject.kind); if (kind !== \"method\" && kind !== \"field\") { throw new TypeError('An element descriptor\\'s .kind property must be either \"method\" or' + ' \"field\", but a decorator created an element descriptor with' + ' .kind \"' + kind + '\"'); } var key = _toPropertyKey(elementObject.key); var placement = String(elementObject.placement); if (placement !== \"static\" && placement !== \"prototype\" && placement !== \"own\") { throw new TypeError('An element descriptor\\'s .placement property must be one of \"static\",' + ' \"prototype\" or \"own\", but a decorator created an element descriptor' + ' with .placement \"' + placement + '\"'); } var descriptor = elementObject.descriptor; this.disallowProperty(elementObject, \"elements\", \"An element descriptor\"); var element = { kind: kind, key: key, placement: placement, descriptor: Object.assign({}, descriptor) }; if (kind !== \"field\") { this.disallowProperty(elementObject, \"initializer\", \"A method descriptor\"); } else { this.disallowProperty(descriptor, \"get\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"set\", \"The property descriptor of a field descriptor\"); this.disallowProperty(descriptor, \"value\", \"The property descriptor of a field descriptor\"); element.initializer = elementObject.initializer; } return element; }, toElementFinisherExtras: function (elementObject) { var element = this.toElementDescriptor(elementObject); var finisher = _optionalCallableProperty(elementObject, \"finisher\"); var extras = this.toElementDescriptors(elementObject.extras); return { element: element, finisher: finisher, extras: extras }; }, fromClassDescriptor: function (elements) { var obj = { kind: \"class\", elements: elements.map(this.fromElementDescriptor, this) }; var desc = { value: \"Descriptor\", configurable: true }; Object.defineProperty(obj, Symbol.toStringTag, desc); return obj; }, toClassDescriptor: function (obj) { var kind = String(obj.kind); if (kind !== \"class\") { throw new TypeError('A class descriptor\\'s .kind property must be \"class\", but a decorator' + ' created a class descriptor with .kind \"' + kind + '\"'); } this.disallowProperty(obj, \"key\", \"A class descriptor\"); this.disallowProperty(obj, \"placement\", \"A class descriptor\"); this.disallowProperty(obj, \"descriptor\", \"A class descriptor\"); this.disallowProperty(obj, \"initializer\", \"A class descriptor\"); this.disallowProperty(obj, \"extras\", \"A class descriptor\"); var finisher = _optionalCallableProperty(obj, \"finisher\"); var elements = this.toElementDescriptors(obj.elements); return { elements: elements, finisher: finisher }; }, runClassFinishers: function (constructor, finishers) { for (var i = 0; i < finishers.length; i++) { var newConstructor = (0, finishers[i])(constructor); if (newConstructor !== undefined) { if (typeof newConstructor !== \"function\") { throw new TypeError(\"Finishers must return a constructor.\"); } constructor = newConstructor; } } return constructor; }, disallowProperty: function (obj, name, objectType) { if (obj[name] !== undefined) { throw new TypeError(objectType + \" can't have a .\" + name + \" property.\"); } } }; return api; }\n\nfunction _createElementDescriptor(def) { var key = _toPropertyKey(def.key); var descriptor; if (def.kind === \"method\") { descriptor = { value: def.value, writable: true, configurable: true, enumerable: false }; } else if (def.kind === \"get\") { descriptor = { get: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"set\") { descriptor = { set: def.value, configurable: true, enumerable: false }; } else if (def.kind === \"field\") { descriptor = { configurable: true, writable: true, enumerable: true }; } var element = { kind: def.kind === \"field\" ? \"field\" : \"method\", key: key, placement: def.static ? \"static\" : def.kind === \"field\" ? \"own\" : \"prototype\", descriptor: descriptor }; if (def.decorators) element.decorators = def.decorators; if (def.kind === \"field\") element.initializer = def.value; return element; }\n\nfunction _coalesceGetterSetter(element, other) { if (element.descriptor.get !== undefined) { other.descriptor.get = element.descriptor.get; } else { other.descriptor.set = element.descriptor.set; } }\n\nfunction _coalesceClassElements(elements) { var newElements = []; var isSameElement = function (other) { return other.kind === \"method\" && other.key === element.key && other.placement === element.placement; }; for (var i = 0; i < elements.length; i++) { var element = elements[i]; var other; if (element.kind === \"method\" && (other = newElements.find(isSameElement))) { if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) { if (_hasDecorators(element) || _hasDecorators(other)) { throw new ReferenceError(\"Duplicated methods (\" + element.key + \") can't be decorated.\"); } other.descriptor = element.descriptor; } else { if (_hasDecorators(element)) { if (_hasDecorators(other)) { throw new ReferenceError(\"Decorators can't be placed on different accessors with for \" + \"the same property (\" + element.key + \").\"); } other.decorators = element.decorators; } _coalesceGetterSetter(element, other); } } else { newElements.push(element); } } return newElements; }\n\nfunction _hasDecorators(element) { return element.decorators && element.decorators.length; }\n\nfunction _isDataDescriptor(desc) { return desc !== undefined && !(desc.value === undefined && desc.writable === undefined); }\n\nfunction _optionalCallableProperty(obj, name) { var value = obj[name]; if (value !== undefined && typeof value !== \"function\") { throw new TypeError(\"Expected '\" + name + \"' to be a function\"); } return value; }\n\nfunction _toPropertyKey(arg) { var key = _toPrimitive(arg, \"string\"); return typeof key === \"symbol\" ? key : String(key); }\n\nfunction _toPrimitive(input, hint) { if (typeof input !== \"object\" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || \"default\"); if (typeof res !== \"object\") return res; throw new TypeError(\"@@toPrimitive must return a primitive value.\"); } return (hint === \"string\" ? String : Number)(input); }\n\nfunction _toArray(arr) { return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n\nlet HassBaseEl = _decorate(null, function (_initialize, _LitElement) {\n  class HassBaseEl extends _LitElement {\n    constructor(...args) {\n      super(...args);\n\n      _initialize(this);\n    }\n\n  }\n\n  return {\n    F: HassBaseEl,\n    d: [{\n      kind: \"field\",\n      decorators: [(0,lit_element__WEBPACK_IMPORTED_MODULE_0__.property)({\n        attribute: false\n      })],\n      key: \"hass\",\n      value: void 0\n    }, {\n      kind: \"field\",\n      key: \"_pendingHass\",\n\n      value() {\n        return {};\n      }\n\n    }, {\n      kind: \"field\",\n      key: \"__provideHass\",\n\n      value() {\n        return [];\n      }\n\n    }, {\n      kind: \"method\",\n      key: \"provideHass\",\n      value: // eslint-disable-next-line: variable-name\n      function provideHass(el) {\n        this.__provideHass.push(el);\n\n        el.hass = this.hass;\n      }\n    }, {\n      kind: \"method\",\n      key: \"initializeHass\",\n      value: function initializeHass(_auth, _conn) {// implemented in connection-mixin\n        // eslint-disable-next-line\n      } // Exists so all methods can safely call super method\n\n    }, {\n      kind: \"method\",\n      key: \"hassConnected\",\n      value: function hassConnected() {// eslint-disable-next-line\n      }\n    }, {\n      kind: \"method\",\n      key: \"hassReconnected\",\n      value: function hassReconnected() {// eslint-disable-next-line\n      }\n    }, {\n      kind: \"method\",\n      key: \"hassDisconnected\",\n      value: function hassDisconnected() {// eslint-disable-next-line\n      }\n    }, {\n      kind: \"method\",\n      key: \"panelUrlChanged\",\n      value: function panelUrlChanged(_newPanelUrl) {// eslint-disable-next-line\n      }\n    }, {\n      kind: \"method\",\n      key: \"hassChanged\",\n      value: function hassChanged(hass, _oldHass) {\n        this.__provideHass.forEach(el => {\n          el.hass = hass;\n        });\n      }\n    }, {\n      kind: \"method\",\n      key: \"_updateHass\",\n      value: function _updateHass(obj) {\n        if (!this.hass) {\n          this._pendingHass = { ...this._pendingHass,\n            ...obj\n          };\n          return;\n        }\n\n        this.hass = { ...this.hass,\n          ...obj\n        };\n      }\n    }]\n  };\n}, lit_element__WEBPACK_IMPORTED_MODULE_0__.LitElement);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/hass-base-mixin.ts\n");

/***/ }),

/***/ "./src/state/hass-element.ts":
/*!***********************************!*\
  !*** ./src/state/hass-element.ts ***!
  \***********************************/
/*! namespace exports */
/*! export HassElement [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"HassElement\": () => /* binding */ HassElement\n/* harmony export */ });\n/* harmony import */ var _auth_mixin__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./auth-mixin */ \"./src/state/auth-mixin.ts\");\n/* harmony import */ var _connection_mixin__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./connection-mixin */ \"./src/state/connection-mixin.ts\");\n/* harmony import */ var _dialog_manager_mixin__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./dialog-manager-mixin */ \"./src/state/dialog-manager-mixin.ts\");\n/* harmony import */ var _disconnect_toast_mixin__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./disconnect-toast-mixin */ \"./src/state/disconnect-toast-mixin.ts\");\n/* harmony import */ var _haptic_mixin__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./haptic-mixin */ \"./src/state/haptic-mixin.ts\");\n/* harmony import */ var _hass_base_mixin__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./hass-base-mixin */ \"./src/state/hass-base-mixin.ts\");\n/* harmony import */ var _more_info_mixin__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./more-info-mixin */ \"./src/state/more-info-mixin.ts\");\n/* harmony import */ var _notification_mixin__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./notification-mixin */ \"./src/state/notification-mixin.ts\");\n/* harmony import */ var _panel_title_mixin__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./panel-title-mixin */ \"./src/state/panel-title-mixin.ts\");\n/* harmony import */ var _sidebar_mixin__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./sidebar-mixin */ \"./src/state/sidebar-mixin.ts\");\n/* harmony import */ var _themes_mixin__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./themes-mixin */ \"./src/state/themes-mixin.ts\");\n/* harmony import */ var _translations_mixin__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./translations-mixin */ \"./src/state/translations-mixin.ts\");\n/* harmony import */ var _url_sync_mixin__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./url-sync-mixin */ \"./src/state/url-sync-mixin.ts\");\n/* harmony import */ var _logging_mixin__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./logging-mixin */ \"./src/state/logging-mixin.ts\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst ext = (baseClass, mixins) => mixins.reduceRight((base, mixin) => mixin(base), baseClass);\n\nclass HassElement extends ext(_hass_base_mixin__WEBPACK_IMPORTED_MODULE_5__.HassBaseEl, [_auth_mixin__WEBPACK_IMPORTED_MODULE_0__.default, _themes_mixin__WEBPACK_IMPORTED_MODULE_9__.default, _translations_mixin__WEBPACK_IMPORTED_MODULE_10__.default, _more_info_mixin__WEBPACK_IMPORTED_MODULE_6__.default, _sidebar_mixin__WEBPACK_IMPORTED_MODULE_8__.default, _disconnect_toast_mixin__WEBPACK_IMPORTED_MODULE_3__.default, _connection_mixin__WEBPACK_IMPORTED_MODULE_1__.connectionMixin, _notification_mixin__WEBPACK_IMPORTED_MODULE_12__.default, _dialog_manager_mixin__WEBPACK_IMPORTED_MODULE_2__.dialogManagerMixin, _url_sync_mixin__WEBPACK_IMPORTED_MODULE_11__.urlSyncMixin, _haptic_mixin__WEBPACK_IMPORTED_MODULE_4__.hapticMixin, _panel_title_mixin__WEBPACK_IMPORTED_MODULE_7__.panelTitleMixin, _logging_mixin__WEBPACK_IMPORTED_MODULE_13__.loggingMixin]) {}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvc3RhdGUvaGFzcy1lbGVtZW50LnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvc3RhdGUvaGFzcy1lbGVtZW50LnRzP2UwYmMiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgQ29uc3RydWN0b3IgfSBmcm9tIFwiLi4vdHlwZXNcIjtcbmltcG9ydCBBdXRoTWl4aW4gZnJvbSBcIi4vYXV0aC1taXhpblwiO1xuaW1wb3J0IHsgY29ubmVjdGlvbk1peGluIH0gZnJvbSBcIi4vY29ubmVjdGlvbi1taXhpblwiO1xuaW1wb3J0IHsgZGlhbG9nTWFuYWdlck1peGluIH0gZnJvbSBcIi4vZGlhbG9nLW1hbmFnZXItbWl4aW5cIjtcbmltcG9ydCBEaXNjb25uZWN0VG9hc3RNaXhpbiBmcm9tIFwiLi9kaXNjb25uZWN0LXRvYXN0LW1peGluXCI7XG5pbXBvcnQgeyBoYXB0aWNNaXhpbiB9IGZyb20gXCIuL2hhcHRpYy1taXhpblwiO1xuaW1wb3J0IHsgSGFzc0Jhc2VFbCB9IGZyb20gXCIuL2hhc3MtYmFzZS1taXhpblwiO1xuaW1wb3J0IE1vcmVJbmZvTWl4aW4gZnJvbSBcIi4vbW9yZS1pbmZvLW1peGluXCI7XG5pbXBvcnQgTm90aWZpY2F0aW9uTWl4aW4gZnJvbSBcIi4vbm90aWZpY2F0aW9uLW1peGluXCI7XG5pbXBvcnQgeyBwYW5lbFRpdGxlTWl4aW4gfSBmcm9tIFwiLi9wYW5lbC10aXRsZS1taXhpblwiO1xuaW1wb3J0IFNpZGViYXJNaXhpbiBmcm9tIFwiLi9zaWRlYmFyLW1peGluXCI7XG5pbXBvcnQgVGhlbWVzTWl4aW4gZnJvbSBcIi4vdGhlbWVzLW1peGluXCI7XG5pbXBvcnQgVHJhbnNsYXRpb25zTWl4aW4gZnJvbSBcIi4vdHJhbnNsYXRpb25zLW1peGluXCI7XG5pbXBvcnQgeyB1cmxTeW5jTWl4aW4gfSBmcm9tIFwiLi91cmwtc3luYy1taXhpblwiO1xuaW1wb3J0IHsgbG9nZ2luZ01peGluIH0gZnJvbSBcIi4vbG9nZ2luZy1taXhpblwiO1xuXG5jb25zdCBleHQgPSA8VCBleHRlbmRzIENvbnN0cnVjdG9yPihiYXNlQ2xhc3M6IFQsIG1peGlucyk6IFQgPT5cbiAgbWl4aW5zLnJlZHVjZVJpZ2h0KChiYXNlLCBtaXhpbikgPT4gbWl4aW4oYmFzZSksIGJhc2VDbGFzcyk7XG5cbmV4cG9ydCBjbGFzcyBIYXNzRWxlbWVudCBleHRlbmRzIGV4dChIYXNzQmFzZUVsLCBbXG4gIEF1dGhNaXhpbixcbiAgVGhlbWVzTWl4aW4sXG4gIFRyYW5zbGF0aW9uc01peGluLFxuICBNb3JlSW5mb01peGluLFxuICBTaWRlYmFyTWl4aW4sXG4gIERpc2Nvbm5lY3RUb2FzdE1peGluLFxuICBjb25uZWN0aW9uTWl4aW4sXG4gIE5vdGlmaWNhdGlvbk1peGluLFxuICBkaWFsb2dNYW5hZ2VyTWl4aW4sXG4gIHVybFN5bmNNaXhpbixcbiAgaGFwdGljTWl4aW4sXG4gIHBhbmVsVGl0bGVNaXhpbixcbiAgbG9nZ2luZ01peGluLFxuXSkge31cbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUVBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/state/hass-element.ts\n");

/***/ }),

/***/ "./src/state/logging-mixin.ts":
/*!************************************!*\
  !*** ./src/state/logging-mixin.ts ***!
  \************************************/
/*! namespace exports */
/*! export loggingMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"loggingMixin\": () => /* binding */ loggingMixin\n/* harmony export */ });\nconst loggingMixin = superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"write_log\", ev => {\n      this._writeLog(ev.detail);\n    });\n  }\n\n  _writeLog(log) {\n    var _this$hass;\n\n    (_this$hass = this.hass) === null || _this$hass === void 0 ? void 0 : _this$hass.callService(\"system_log\", \"write\", {\n      logger: `frontend.${ true ? \"js_dev\" : 0}.${\"latest\"}.${\"20201111.2\".replace(\".\", \"\")}`,\n      message: log.message,\n      level: log.level || \"error\"\n    });\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvc3RhdGUvbG9nZ2luZy1taXhpbi50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL3N0YXRlL2xvZ2dpbmctbWl4aW4udHM/OTNlNyJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBIQVNTRG9tRXZlbnQgfSBmcm9tIFwiLi4vY29tbW9uL2RvbS9maXJlX2V2ZW50XCI7XG5pbXBvcnQgeyBDb25zdHJ1Y3RvciB9IGZyb20gXCIuLi90eXBlc1wiO1xuaW1wb3J0IHsgSGFzc0Jhc2VFbCB9IGZyb20gXCIuL2hhc3MtYmFzZS1taXhpblwiO1xuXG5pbnRlcmZhY2UgV3JpdGVMb2dQYXJhbXMge1xuICBsZXZlbD86IFwiZGVidWdcIiB8IFwiaW5mb1wiIHwgXCJ3YXJuaW5nXCIgfCBcImVycm9yXCIgfCBcImNyaXRpY2FsXCI7XG4gIG1lc3NhZ2U6IHN0cmluZztcbn1cblxuZGVjbGFyZSBnbG9iYWwge1xuICAvLyBmb3IgZmlyZSBldmVudFxuICBpbnRlcmZhY2UgSEFTU0RvbUV2ZW50cyB7XG4gICAgd3JpdGVfbG9nOiBXcml0ZUxvZ1BhcmFtcztcbiAgfVxuICBpbnRlcmZhY2UgSFRNTEVsZW1lbnRFdmVudE1hcCB7XG4gICAgd3JpdGVfbG9nOiBIQVNTRG9tRXZlbnQ8V3JpdGVMb2dQYXJhbXM+O1xuICB9XG59XG5cbmV4cG9ydCBjb25zdCBsb2dnaW5nTWl4aW4gPSA8VCBleHRlbmRzIENvbnN0cnVjdG9yPEhhc3NCYXNlRWw+PihcbiAgc3VwZXJDbGFzczogVFxuKSA9PlxuICBjbGFzcyBleHRlbmRzIHN1cGVyQ2xhc3Mge1xuICAgIHByb3RlY3RlZCBmaXJzdFVwZGF0ZWQoY2hhbmdlZFByb3BzKSB7XG4gICAgICBzdXBlci5maXJzdFVwZGF0ZWQoY2hhbmdlZFByb3BzKTtcbiAgICAgIHRoaXMuYWRkRXZlbnRMaXN0ZW5lcihcIndyaXRlX2xvZ1wiLCAoZXYpID0+IHtcbiAgICAgICAgdGhpcy5fd3JpdGVMb2coZXYuZGV0YWlsKTtcbiAgICAgIH0pO1xuICAgIH1cblxuICAgIHByaXZhdGUgX3dyaXRlTG9nKGxvZzogV3JpdGVMb2dQYXJhbXMpIHtcbiAgICAgIHRoaXMuaGFzcz8uY2FsbFNlcnZpY2UoXCJzeXN0ZW1fbG9nXCIsIFwid3JpdGVcIiwge1xuICAgICAgICBsb2dnZXI6IGBmcm9udGVuZC4ke1xuICAgICAgICAgIF9fREVWX18gPyBcImpzX2RldlwiIDogXCJqc1wiXG4gICAgICAgIH0uJHtfX0JVSUxEX199LiR7X19WRVJTSU9OX18ucmVwbGFjZShcIi5cIiwgXCJcIil9YCxcbiAgICAgICAgbWVzc2FnZTogbG9nLm1lc3NhZ2UsXG4gICAgICAgIGxldmVsOiBsb2cubGV2ZWwgfHwgXCJlcnJvclwiLFxuICAgICAgfSk7XG4gICAgfVxuICB9O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBbUJBO0FBSUE7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFBQTtBQUNBO0FBR0E7QUFDQTtBQUxBO0FBT0E7QUFDQTtBQWpCQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/state/logging-mixin.ts\n");

/***/ }),

/***/ "./src/state/more-info-mixin.ts":
/*!**************************************!*\
  !*** ./src/state/more-info-mixin.ts ***!
  \**************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.e, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../dialogs/make-dialog-manager */ \"./src/dialogs/make-dialog-manager.ts\");\n\nlet moreInfoImportPromise;\n\nconst importMoreInfo = () => {\n  if (!moreInfoImportPromise) {\n    moreInfoImportPromise = Promise.all(/*! import() | more-info-dialog */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-menu-behavior_iron-menu-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-icons_js-node_modules_po-1b093a\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-form-element-behavior_iron-form-element-behavior_js-node_mo-2e54fd\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-input_paper-input_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-tooltip_paper-tooltip_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-dialog_mwc-dialog_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-ripple_paper-ripple_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-switch_mwc-switch_js\"), __webpack_require__.e(\"vendors-node_modules_lit-virtualizer_lit-virtualizer_js\"), __webpack_require__.e(\"vendors-node_modules_fecha_lib_fecha_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-slider_paper-slider_js\"), __webpack_require__.e(\"vendors-node_modules_mdi_js_mdi_js\"), __webpack_require__.e(\"vendors-node_modules_fullcalendar_core_locales-all_js-node_modules_fullcalendar_core_main_js--31c88c\"), __webpack_require__.e(\"vendors-node_modules_polymer_paper-dropdown-menu_paper-dropdown-menu-light_js-node_modules_po-edcc94\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-circular-progress_mwc-circular-progress_js-node_modules_mat-1faafa\"), __webpack_require__.e(\"vendors-node_modules_thomasloven_round-slider_src_main_js\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-tab-bar_mwc-tab-bar_js\"), __webpack_require__.e(\"vendors-node_modules_lit-html_directives_cache_js-node_modules_material_top-app-bar_dist_mdc_-e07546\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-flex-layout_iron-flex-layout-classes_js-node_modules_polyme-6c0f78\"), __webpack_require__.e(\"vendors-node_modules_material_mwc-base_observer_js-node_modules_polymer_iron-behaviors_iron-b-6e7eda\"), __webpack_require__.e(\"src_components_ha-icon_ts\"), __webpack_require__.e(\"src_components_ha-card_ts\"), __webpack_require__.e(\"src_components_ha-icon-button_ts\"), __webpack_require__.e(\"src_components_ha-dialog_ts\"), __webpack_require__.e(\"src_components_ha-switch_ts\"), __webpack_require__.e(\"src_common_entity_domain_icon_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_name_ts-src_components_entity_state-badge_ts\"), __webpack_require__.e(\"src_components_buttons_ha-progress-button_ts-src_mixins_events-mixin_js\"), __webpack_require__.e(\"src_panels_lovelace_common_has-changed_ts-src_panels_lovelace_components_hui-generic-entity-row_ts\"), __webpack_require__.e(\"src_common_datetime_format_date_time_ts-src_common_string_compare_ts-src_components_entity_ha-a9c1ce\"), __webpack_require__.e(\"src_data_integration_ts-src_panels_lovelace_create-element_create-row-element_ts\"), __webpack_require__.e(\"src_components_state-history-charts_js\"), __webpack_require__.e(\"src_components_ha-hls-player_ts\"), __webpack_require__.e(\"src_data_calendar_ts-src_panels_calendar_ha-full-calendar_ts\"), __webpack_require__.e(\"src_components_ha-attributes_ts\"), __webpack_require__.e(\"src_data_weather_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_hui-stack-card_ts-src_panels_lovelace_cards_hui-vertical-stack-card-53457d\"), __webpack_require__.e(\"src_components_ha-circular-progress_ts\"), __webpack_require__.e(\"src_components_ha-label-badge_ts\"), __webpack_require__.e(\"src_components_ha-header-bar_ts\"), __webpack_require__.e(\"src_panels_lovelace_components_hui-image_ts\"), __webpack_require__.e(\"src_common_util_render-status_ts-src_components_entity_ha-state-label-badge_ts\"), __webpack_require__.e(\"src_common_entity_compute_state_domain_ts-src_data_media-player_ts-src_panels_lovelace_common-c9c5b4\"), __webpack_require__.e(\"src_components_ha-cover-tilt-controls_ts\"), __webpack_require__.e(\"src_panels_lovelace_cards_picture-elements_create-styled-hui-element_ts-src_panels_lovelace_c-5490ee\"), __webpack_require__.e(\"node_modules_lit-virtualizer_lib_uni-virtualizer_lib_polyfillLoaders_EventTarget_js-src_data_-d6a22a\"), __webpack_require__.e(\"src_components_ha-climate-state_ts\"), __webpack_require__.e(\"src_state-summary_state-card-content_js\"), __webpack_require__.e(\"more-info-dialog\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../dialogs/more-info/ha-more-info-dialog */ \"./src/dialogs/more-info/ha-more-info-dialog.ts\"));\n  }\n\n  return moreInfoImportPromise;\n};\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"hass-more-info\", ev => this._handleMoreInfo(ev)); // Load it once we are having the initial rendering done.\n\n    importMoreInfo();\n  }\n\n  async _handleMoreInfo(ev) {\n    (0,_dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__.showDialog)(this, this.shadowRoot, \"ha-more-info-dialog\", {\n      entityId: ev.detail.entityId\n    }, importMoreInfo);\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/more-info-mixin.ts\n");

/***/ }),

/***/ "./src/state/notification-mixin.ts":
/*!*****************************************!*\
  !*** ./src/state/notification-mixin.ts ***!
  \*****************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_exports__, __webpack_require__.r, __webpack_require__.e, __webpack_require__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps); // @ts-ignore\n\n    this.registerDialog({\n      dialogShowEvent: \"hass-notification\",\n      dialogTag: \"notification-manager\",\n      dialogImport: () => Promise.all(/*! import() | notification-manager */[__webpack_require__.e(\"vendors-node_modules_polymer_iron-overlay-behavior_iron-overlay-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-a11y-keys-behavior_iron-a11y-keys-behavior_js\"), __webpack_require__.e(\"vendors-node_modules_polymer_iron-resizable-behavior_iron-resizable-behavior_js-node_modules_-b64774\"), __webpack_require__.e(\"notification-manager\")]).then(__webpack_require__.bind(__webpack_require__, /*! ../managers/notification-manager */ \"./src/managers/notification-manager.ts\"))\n    });\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvc3RhdGUvbm90aWZpY2F0aW9uLW1peGluLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvc3RhdGUvbm90aWZpY2F0aW9uLW1peGluLnRzPzA5MmUiXSwic291cmNlc0NvbnRlbnQiOlsiaW1wb3J0IHsgQ29uc3RydWN0b3IgfSBmcm9tIFwiLi4vdHlwZXNcIjtcbmltcG9ydCB7IEhhc3NCYXNlRWwgfSBmcm9tIFwiLi9oYXNzLWJhc2UtbWl4aW5cIjtcblxuZXhwb3J0IGRlZmF1bHQgPFQgZXh0ZW5kcyBDb25zdHJ1Y3RvcjxIYXNzQmFzZUVsPj4oc3VwZXJDbGFzczogVCkgPT5cbiAgY2xhc3MgZXh0ZW5kcyBzdXBlckNsYXNzIHtcbiAgICBwcm90ZWN0ZWQgZmlyc3RVcGRhdGVkKGNoYW5nZWRQcm9wcykge1xuICAgICAgc3VwZXIuZmlyc3RVcGRhdGVkKGNoYW5nZWRQcm9wcyk7XG4gICAgICAvLyBAdHMtaWdub3JlXG4gICAgICB0aGlzLnJlZ2lzdGVyRGlhbG9nKHtcbiAgICAgICAgZGlhbG9nU2hvd0V2ZW50OiBcImhhc3Mtbm90aWZpY2F0aW9uXCIsXG4gICAgICAgIGRpYWxvZ1RhZzogXCJub3RpZmljYXRpb24tbWFuYWdlclwiLFxuICAgICAgICBkaWFsb2dJbXBvcnQ6ICgpID0+XG4gICAgICAgICAgaW1wb3J0KFxuICAgICAgICAgICAgLyogd2VicGFja0NodW5rTmFtZTogXCJub3RpZmljYXRpb24tbWFuYWdlclwiICovIFwiLi4vbWFuYWdlcnMvbm90aWZpY2F0aW9uLW1hbmFnZXJcIlxuICAgICAgICAgICksXG4gICAgICB9KTtcbiAgICB9XG4gIH07XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFHQTtBQUVBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBLGlsQkFFQTtBQUxBO0FBUUE7QUFDQTtBQWJBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/state/notification-mixin.ts\n");

/***/ }),

/***/ "./src/state/panel-title-mixin.ts":
/*!****************************************!*\
  !*** ./src/state/panel-title-mixin.ts ***!
  \****************************************/
/*! namespace exports */
/*! export panelTitleMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"panelTitleMixin\": () => /* binding */ panelTitleMixin\n/* harmony export */ });\n/* harmony import */ var _data_panel__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data/panel */ \"./src/data/panel.ts\");\n\n\nconst setTitle = title => {\n  document.title = title ? `${title} - Home Assistant` : \"Home Assistant\";\n};\n\nconst panelTitleMixin = superClass => class extends superClass {\n  updated(changedProps) {\n    super.updated(changedProps);\n\n    if (!changedProps.has(\"hass\") || !this.hass) {\n      return;\n    }\n\n    const oldHass = changedProps.get(\"hass\");\n\n    if (!oldHass || oldHass.panels !== this.hass.panels || oldHass.panelUrl !== this.hass.panelUrl) {\n      setTitle((0,_data_panel__WEBPACK_IMPORTED_MODULE_0__.getPanelTitle)(this.hass));\n    }\n  }\n\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvc3RhdGUvcGFuZWwtdGl0bGUtbWl4aW4udHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy9zdGF0ZS9wYW5lbC10aXRsZS1taXhpbi50cz8yNjcxIl0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IGdldFBhbmVsVGl0bGUgfSBmcm9tIFwiLi4vZGF0YS9wYW5lbFwiO1xuaW1wb3J0IHsgQ29uc3RydWN0b3IsIEhvbWVBc3Npc3RhbnQgfSBmcm9tIFwiLi4vdHlwZXNcIjtcbmltcG9ydCB7IEhhc3NCYXNlRWwgfSBmcm9tIFwiLi9oYXNzLWJhc2UtbWl4aW5cIjtcblxuY29uc3Qgc2V0VGl0bGUgPSAodGl0bGU6IHN0cmluZyB8IHVuZGVmaW5lZCkgPT4ge1xuICBkb2N1bWVudC50aXRsZSA9IHRpdGxlID8gYCR7dGl0bGV9IC0gSG9tZSBBc3Npc3RhbnRgIDogXCJIb21lIEFzc2lzdGFudFwiO1xufTtcblxuZXhwb3J0IGNvbnN0IHBhbmVsVGl0bGVNaXhpbiA9IDxUIGV4dGVuZHMgQ29uc3RydWN0b3I8SGFzc0Jhc2VFbD4+KFxuICBzdXBlckNsYXNzOiBUXG4pID0+XG4gIGNsYXNzIGV4dGVuZHMgc3VwZXJDbGFzcyB7XG4gICAgcHJvdGVjdGVkIHVwZGF0ZWQoY2hhbmdlZFByb3BzKSB7XG4gICAgICBzdXBlci51cGRhdGVkKGNoYW5nZWRQcm9wcyk7XG4gICAgICBpZiAoIWNoYW5nZWRQcm9wcy5oYXMoXCJoYXNzXCIpIHx8ICF0aGlzLmhhc3MpIHtcbiAgICAgICAgcmV0dXJuO1xuICAgICAgfVxuXG4gICAgICBjb25zdCBvbGRIYXNzID0gY2hhbmdlZFByb3BzLmdldChcImhhc3NcIikgYXMgSG9tZUFzc2lzdGFudCB8IHVuZGVmaW5lZDtcblxuICAgICAgaWYgKFxuICAgICAgICAhb2xkSGFzcyB8fFxuICAgICAgICBvbGRIYXNzLnBhbmVscyAhPT0gdGhpcy5oYXNzLnBhbmVscyB8fFxuICAgICAgICBvbGRIYXNzLnBhbmVsVXJsICE9PSB0aGlzLmhhc3MucGFuZWxVcmxcbiAgICAgICkge1xuICAgICAgICBzZXRUaXRsZShnZXRQYW5lbFRpdGxlKHRoaXMuaGFzcykpO1xuICAgICAgfVxuICAgIH1cbiAgfTtcbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7QUFBQTtBQUNBO0FBR0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUlBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFDQTtBQUNBO0FBS0E7QUFDQTtBQUNBO0FBQ0E7QUFqQkEiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/state/panel-title-mixin.ts\n");

/***/ }),

/***/ "./src/state/quick-bar-mixin.ts":
/*!**************************************!*\
  !*** ./src/state/quick-bar-mixin.ts ***!
  \**************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var tinykeys__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! tinykeys */ \"./node_modules/tinykeys/dist/tinykeys.module.js\");\n/* harmony import */ var _dialogs_quick_bar_show_dialog_quick_bar__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../dialogs/quick-bar/show-dialog-quick-bar */ \"./src/dialogs/quick-bar/show-dialog-quick-bar.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n\n\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"hass-enable-shortcuts\", ev => {\n      this._updateHass({\n        enableShortcuts: ev.detail\n      });\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__.storeState)(this.hass);\n    });\n\n    this._registerShortcut();\n  }\n\n  _registerShortcut() {\n    (0,tinykeys__WEBPACK_IMPORTED_MODULE_0__.default)(window, {\n      e: ev => this._showQuickBar(ev),\n      c: ev => this._showQuickBar(ev, true)\n    });\n  }\n\n  _showQuickBar(e, commandMode = false) {\n    if (!this._canShowQuickBar(e)) {\n      return;\n    }\n\n    (0,_dialogs_quick_bar_show_dialog_quick_bar__WEBPACK_IMPORTED_MODULE_1__.showQuickBar)(this, {\n      commandMode\n    });\n  }\n\n  _canShowQuickBar(e) {\n    var _this$hass, _this$hass$user;\n\n    return ((_this$hass = this.hass) === null || _this$hass === void 0 ? void 0 : (_this$hass$user = _this$hass.user) === null || _this$hass$user === void 0 ? void 0 : _this$hass$user.is_admin) && this.hass.enableShortcuts && this._canOverrideAlphanumericInput(e);\n  }\n\n  _canOverrideAlphanumericInput(e) {\n    const el = e.composedPath()[0];\n\n    if (el.tagName === \"TEXTAREA\") {\n      return false;\n    }\n\n    if (el.tagName !== \"INPUT\") {\n      return true;\n    }\n\n    switch (el.type) {\n      case \"button\":\n      case \"checkbox\":\n      case \"hidden\":\n      case \"radio\":\n      case \"range\":\n        return true;\n\n      default:\n        return false;\n    }\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/quick-bar-mixin.ts\n");

/***/ }),

/***/ "./src/state/sidebar-mixin.ts":
/*!************************************!*\
  !*** ./src/state/sidebar-mixin.ts ***!
  \************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"hass-dock-sidebar\", ev => {\n      this._updateHass({\n        dockedSidebar: ev.detail.dock\n      });\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_0__.storeState)(this.hass);\n    });\n    this.addEventListener(\"hass-default-panel\", ev => {\n      this._updateHass({\n        defaultPanel: ev.detail.defaultPanel\n      });\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_0__.storeState)(this.hass);\n    });\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/state/sidebar-mixin.ts\n");

/***/ }),

/***/ "./src/state/themes-mixin.ts":
/*!***********************************!*\
  !*** ./src/state/themes-mixin.ts ***!
  \***********************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _common_dom_apply_themes_on_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/dom/apply_themes_on_element */ \"./src/common/dom/apply_themes_on_element.ts\");\n/* harmony import */ var _data_ws_themes__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../data/ws-themes */ \"./src/data/ws-themes.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n\n\n\nconst mql = matchMedia(\"(prefers-color-scheme: dark)\");\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => class extends superClass {\n  firstUpdated(changedProps) {\n    super.firstUpdated(changedProps);\n    this.addEventListener(\"settheme\", ev => {\n      this._updateHass({\n        selectedTheme: { ...this.hass.selectedTheme,\n          ...ev.detail\n        }\n      });\n\n      this._applyTheme(mql.matches);\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_2__.storeState)(this.hass);\n    });\n    mql.addListener(ev => this._applyTheme(ev.matches));\n  }\n\n  hassConnected() {\n    super.hassConnected();\n    (0,_data_ws_themes__WEBPACK_IMPORTED_MODULE_1__.subscribeThemes)(this.hass.connection, themes => {\n      this._updateHass({\n        themes\n      });\n\n      (0,_common_dom_apply_themes_on_element__WEBPACK_IMPORTED_MODULE_0__.invalidateThemeCache)();\n\n      this._applyTheme(mql.matches);\n    });\n  }\n\n  _applyTheme(dark) {\n    var _this$hass$selectedTh, _options, _options2;\n\n    if (!this.hass) {\n      return;\n    }\n\n    const themeName = ((_this$hass$selectedTh = this.hass.selectedTheme) === null || _this$hass$selectedTh === void 0 ? void 0 : _this$hass$selectedTh.theme) || (dark && this.hass.themes.default_dark_theme ? this.hass.themes.default_dark_theme : this.hass.themes.default_theme);\n    let options = this.hass.selectedTheme;\n\n    if (themeName === \"default\" && ((_options = options) === null || _options === void 0 ? void 0 : _options.dark) === undefined) {\n      options = { ...this.hass.selectedTheme,\n        dark\n      };\n    }\n\n    (0,_common_dom_apply_themes_on_element__WEBPACK_IMPORTED_MODULE_0__.applyThemesOnElement)(document.documentElement, this.hass.themes, themeName, options);\n    const darkMode = themeName === \"default\" ? !!((_options2 = options) === null || _options2 === void 0 ? void 0 : _options2.dark) : !!(dark && this.hass.themes.default_dark_theme);\n\n    if (darkMode !== this.hass.themes.darkMode) {\n      this._updateHass({\n        themes: { ...this.hass.themes,\n          darkMode\n        }\n      });\n\n      const schemeMeta = document.querySelector(\"meta[name=color-scheme]\");\n\n      if (schemeMeta) {\n        schemeMeta.setAttribute(\"content\", darkMode ? \"dark\" : themeName === \"default\" ? \"light\" : \"dark light\");\n      }\n    }\n\n    const themeMeta = document.querySelector(\"meta[name=theme-color]\");\n    const computedStyles = getComputedStyle(document.documentElement);\n    const headerColor = computedStyles.getPropertyValue(\"--app-header-background-color\");\n    document.documentElement.style.backgroundColor = computedStyles.getPropertyValue(\"--primary-background-color\");\n\n    if (themeMeta) {\n      if (!themeMeta.hasAttribute(\"default-content\")) {\n        themeMeta.setAttribute(\"default-content\", themeMeta.getAttribute(\"content\"));\n      }\n\n      const themeColor = (headerColor === null || headerColor === void 0 ? void 0 : headerColor.trim()) || themeMeta.getAttribute(\"default-content\");\n      themeMeta.setAttribute(\"content\", themeColor);\n    }\n  }\n\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/state/themes-mixin.ts\n");

/***/ }),

/***/ "./src/state/translations-mixin.ts":
/*!*****************************************!*\
  !*** ./src/state/translations-mixin.ts ***!
  \*****************************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_exports__, __webpack_require__.r, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => __WEBPACK_DEFAULT_EXPORT__\n/* harmony export */ });\n/* harmony import */ var _common_translations_localize__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/translations/localize */ \"./src/common/translations/localize.ts\");\n/* harmony import */ var _common_util_compute_rtl__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../common/util/compute_rtl */ \"./src/common/util/compute_rtl.ts\");\n/* harmony import */ var _common_util_debounce__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../common/util/debounce */ \"./src/common/util/debounce.ts\");\n/* harmony import */ var _data_translation__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../data/translation */ \"./src/data/translation.ts\");\n/* harmony import */ var _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../resources/translations-metadata */ \"./src/resources/translations-metadata.ts\");\n/* harmony import */ var _util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../util/ha-pref-storage */ \"./src/util/ha-pref-storage.ts\");\n/* harmony import */ var _util_hass_translation__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../util/hass-translation */ \"./src/util/hass-translation.ts\");\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\n\n\n\n\n\n\n\n\n\n/*\n * superClass needs to contain `this.hass` and `this._updateHass`.\n */\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (superClass => {\n  var _temp;\n\n  return _temp = class extends superClass {\n    constructor(...args) {\n      super(...args);\n\n      _defineProperty(this, \"__coreProgress\", void 0);\n\n      _defineProperty(this, \"__loadedTranslations\", {});\n    }\n\n    firstUpdated(changedProps) {\n      super.firstUpdated(changedProps);\n      this.addEventListener(\"hass-language-select\", e => this._selectLanguage(e.detail.language, true));\n\n      this._loadCoreTranslations((0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_4__.getLocalLanguage)());\n    }\n\n    hassConnected() {\n      super.hassConnected();\n      (0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_4__.getUserLanguage)(this.hass).then(language => {\n        if (language && this.hass.language !== language) {\n          // We just get language from backend, no need to save back\n          this._selectLanguage(language, false);\n        }\n      });\n      this.hass.connection.subscribeEvents((0,_common_util_debounce__WEBPACK_IMPORTED_MODULE_5__.debounce)(() => {\n        this._refetchCachedHassTranslations(false, false);\n      }, 500), \"component_loaded\");\n\n      this._applyTranslations(this.hass);\n    }\n\n    hassReconnected() {\n      super.hassReconnected();\n\n      this._refetchCachedHassTranslations(true, false);\n\n      this._applyTranslations(this.hass);\n    }\n\n    panelUrlChanged(newPanelUrl) {\n      super.panelUrlChanged(newPanelUrl); // this may be triggered before hassConnected\n\n      this._loadFragmentTranslations(this.hass ? this.hass.language : (0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_4__.getLocalLanguage)(), newPanelUrl);\n    }\n\n    _selectLanguage(language, saveToBackend) {\n      if (!this.hass) {\n        // should not happen, do it to avoid use this.hass!\n        return;\n      } // update selectedLanguage so that it can be saved to local storage\n\n\n      this._updateHass({\n        language,\n        selectedLanguage: language\n      });\n\n      (0,_util_ha_pref_storage__WEBPACK_IMPORTED_MODULE_3__.storeState)(this.hass);\n\n      if (saveToBackend) {\n        (0,_data_translation__WEBPACK_IMPORTED_MODULE_1__.saveTranslationPreferences)(this.hass, {\n          language\n        });\n      }\n\n      this._applyTranslations(this.hass);\n\n      this._refetchCachedHassTranslations(true, true);\n    }\n\n    _applyTranslations(hass) {\n      document.querySelector(\"html\").setAttribute(\"lang\", hass.language);\n      this.style.direction = (0,_common_util_compute_rtl__WEBPACK_IMPORTED_MODULE_6__.computeRTL)(hass) ? \"rtl\" : \"ltr\";\n\n      this._loadCoreTranslations(hass.language);\n\n      this._loadFragmentTranslations(hass.language, hass.panelUrl);\n    }\n    /**\n     * Load translations from the backend\n     * @param language language to fetch\n     * @param category category to fetch\n     * @param integration optional, if having to fetch for specific integration\n     * @param configFlow optional, if having to fetch for all integrations with a config flow\n     * @param force optional, load even if already cached\n     */\n\n\n    async _loadHassTranslations(language, category, integration, configFlow, force = false) {\n      if (false) {}\n\n      let alreadyLoaded;\n\n      if (category in this.__loadedTranslations) {\n        alreadyLoaded = this.__loadedTranslations[category];\n      } else {\n        alreadyLoaded = this.__loadedTranslations[category] = {\n          integrations: [],\n          setup: false,\n          configFlow: false\n        };\n      } // Check if already loaded\n\n\n      if (!force) {\n        if (integration) {\n          if (alreadyLoaded.integrations.includes(integration)) {\n            return this.hass.localize;\n          }\n        } else if (configFlow ? alreadyLoaded.configFlow : alreadyLoaded.setup) {\n          return this.hass.localize;\n        }\n      } // Add to cache\n\n\n      if (integration) {\n        if (!alreadyLoaded.integrations.includes(integration)) {\n          alreadyLoaded.integrations.push(integration);\n        }\n      } else {\n        alreadyLoaded.setup = true;\n\n        if (configFlow) {\n          alreadyLoaded.configFlow = true;\n        }\n      }\n\n      const resources = await (0,_data_translation__WEBPACK_IMPORTED_MODULE_1__.getHassTranslations)(this.hass, language, category, integration, configFlow); // Ignore the repsonse if user switched languages before we got response\n\n      if (this.hass.language !== language) {\n        return this.hass.localize;\n      }\n\n      await this._updateResources(language, resources);\n      return this.hass.localize;\n    }\n\n    async _loadFragmentTranslations(language, panelUrl) {\n      if (_resources_translations_metadata__WEBPACK_IMPORTED_MODULE_2__.translationMetadata.fragments.includes(panelUrl)) {\n        const result = await (0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_4__.getTranslation)(panelUrl, language);\n\n        this._updateResources(result.language, result.data);\n      }\n    }\n\n    async _loadCoreTranslations(language) {\n      // Check if already in progress\n      // Necessary as we call this in firstUpdated and hassConnected\n      if (this.__coreProgress === language) {\n        return;\n      }\n\n      this.__coreProgress = language;\n\n      try {\n        const result = await (0,_util_hass_translation__WEBPACK_IMPORTED_MODULE_4__.getTranslation)(null, language);\n\n        this._updateResources(result.language, result.data);\n      } finally {\n        this.__coreProgress = undefined;\n      }\n    }\n\n    async _updateResources(language, data) {\n      var _this$hass, _baseHass$resources;\n\n      // Update the language in hass, and update the resources with the newly\n      // loaded resources. This merges the new data on top of the old data for\n      // this language, so that the full translation set can be loaded across\n      // multiple fragments.\n      //\n      // Beware of a subtle race condition: it is possible to get here twice\n      // before this.hass is even created. In this case our base state comes\n      // from this._pendingHass instead. Otherwise the first set of strings is\n      // overwritten when we call _updateHass the second time!\n      const baseHass = (_this$hass = this.hass) !== null && _this$hass !== void 0 ? _this$hass : this._pendingHass;\n      const resources = {\n        [language]: { ...(baseHass === null || baseHass === void 0 ? void 0 : (_baseHass$resources = baseHass.resources) === null || _baseHass$resources === void 0 ? void 0 : _baseHass$resources[language]),\n          ...data\n        }\n      };\n      const changes = {\n        resources\n      };\n\n      if (this.hass && language === this.hass.language) {\n        changes.localize = await (0,_common_translations_localize__WEBPACK_IMPORTED_MODULE_0__.computeLocalize)(this, language, resources);\n      }\n\n      this._updateHass(changes);\n    }\n\n    _refetchCachedHassTranslations(includeConfigFlow, clearIntegrations) {\n      for (const [category, cache] of Object.entries(this.__loadedTranslations)) {\n        if (clearIntegrations) {\n          cache.integrations = [];\n        }\n\n        if (cache.setup) {\n          this._loadHassTranslations(this.hass.language, category, undefined, includeConfigFlow && cache.configFlow, true);\n        }\n      }\n    }\n\n  }, _temp;\n});//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/state/translations-mixin.ts\n");

/***/ }),

/***/ "./src/state/url-sync-mixin.ts":
/*!*************************************!*\
  !*** ./src/state/url-sync-mixin.ts ***!
  \*************************************/
/*! namespace exports */
/*! export urlSyncMixin [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"urlSyncMixin\": () => /* binding */ urlSyncMixin\n/* harmony export */ });\n/* harmony import */ var _dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../dialogs/make-dialog-manager */ \"./src/dialogs/make-dialog-manager.ts\");\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\n/* eslint-disable no-console */\n\nconst DEBUG = false;\nconst urlSyncMixin = superClass => {\n  var _temp;\n\n  return (// Disable this functionality in the demo.\n     false ? 0 : (_temp = class extends superClass {\n      constructor(...args) {\n        super(...args);\n\n        _defineProperty(this, \"_ignoreNextPopState\", false);\n\n        _defineProperty(this, \"_dialogClosedListener\", ev => {\n          var _history$state, _history$state2;\n\n          if (DEBUG) {\n            console.log(\"dialog closed\", ev.detail.dialog);\n          } // If not closed by navigating back, and not a new dialog is open, remove the open state from history\n\n\n          if (((_history$state = history.state) === null || _history$state === void 0 ? void 0 : _history$state.open) && ((_history$state2 = history.state) === null || _history$state2 === void 0 ? void 0 : _history$state2.dialog) === ev.detail.dialog) {\n            if (DEBUG) {\n              console.log(\"remove state\", ev.detail.dialog);\n            }\n\n            this._ignoreNextPopState = true;\n            history.back();\n          }\n        });\n\n        _defineProperty(this, \"_popstateChangeListener\", ev => {\n          if (this._ignoreNextPopState) {\n            this._ignoreNextPopState = false;\n            return;\n          }\n\n          if (ev.state && \"dialog\" in ev.state) {\n            if (DEBUG) {\n              console.log(\"popstate\", ev);\n            }\n\n            this._handleDialogStateChange(ev.state);\n          }\n        });\n      }\n\n      connectedCallback() {\n        super.connectedCallback();\n        window.addEventListener(\"popstate\", this._popstateChangeListener);\n        this.addEventListener(\"dialog-closed\", this._dialogClosedListener);\n      }\n\n      disconnectedCallback() {\n        super.disconnectedCallback();\n        window.removeEventListener(\"popstate\", this._popstateChangeListener);\n        this.removeEventListener(\"dialog-closed\", this._dialogClosedListener);\n      }\n\n      async _handleDialogStateChange(state) {\n        if (DEBUG) {\n          console.log(\"handle state\", state);\n        }\n\n        if (!state.open) {\n          const closed = await (0,_dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__.closeDialog)(state.dialog);\n\n          if (!closed) {\n            if (DEBUG) {\n              console.log(\"dialog could not be closed\");\n            } // dialog could not be closed, push state again\n\n\n            history.pushState({\n              dialog: state.dialog,\n              open: true,\n              dialogParams: null,\n              oldState: null\n            }, \"\");\n            return;\n          }\n\n          if (state.oldState) {\n            if (DEBUG) {\n              console.log(\"handle old state\");\n            }\n\n            this._handleDialogStateChange(state.oldState);\n          }\n\n          return;\n        }\n\n        if (state.dialogParams !== null) {\n          (0,_dialogs_make_dialog_manager__WEBPACK_IMPORTED_MODULE_0__.showDialog)(this, this.shadowRoot, state.dialog, state.dialogParams);\n        }\n      }\n\n    }, _temp)\n  );\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/state/url-sync-mixin.ts\n");

/***/ }),

/***/ "./src/util/fetch-with-auth.ts":
/*!*************************************!*\
  !*** ./src/util/fetch-with-auth.ts ***!
  \*************************************/
/*! namespace exports */
/*! export fetchWithAuth [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"fetchWithAuth\": () => /* binding */ fetchWithAuth\n/* harmony export */ });\nconst fetchWithAuth = async (auth, input, init = {}) => {\n  if (auth.expired) {\n    await auth.refreshAccessToken();\n  }\n\n  init.credentials = \"same-origin\";\n\n  if (!init.headers) {\n    init.headers = {};\n  }\n\n  if (!init.headers) {\n    init.headers = {};\n  } // @ts-ignore\n\n\n  init.headers.authorization = `Bearer ${auth.accessToken}`;\n  return fetch(input, init);\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvdXRpbC9mZXRjaC13aXRoLWF1dGgudHMuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly9ob21lLWFzc2lzdGFudC1mcm9udGVuZC8uL3NyYy91dGlsL2ZldGNoLXdpdGgtYXV0aC50cz9lNzM3Il0sInNvdXJjZXNDb250ZW50IjpbImltcG9ydCB7IEF1dGggfSBmcm9tIFwiaG9tZS1hc3Npc3RhbnQtanMtd2Vic29ja2V0XCI7XG5cbmV4cG9ydCBjb25zdCBmZXRjaFdpdGhBdXRoID0gYXN5bmMgKFxuICBhdXRoOiBBdXRoLFxuICBpbnB1dDogUmVxdWVzdEluZm8sXG4gIGluaXQ6IFJlcXVlc3RJbml0ID0ge31cbikgPT4ge1xuICBpZiAoYXV0aC5leHBpcmVkKSB7XG4gICAgYXdhaXQgYXV0aC5yZWZyZXNoQWNjZXNzVG9rZW4oKTtcbiAgfVxuICBpbml0LmNyZWRlbnRpYWxzID0gXCJzYW1lLW9yaWdpblwiO1xuICBpZiAoIWluaXQuaGVhZGVycykge1xuICAgIGluaXQuaGVhZGVycyA9IHt9O1xuICB9XG4gIGlmICghaW5pdC5oZWFkZXJzKSB7XG4gICAgaW5pdC5oZWFkZXJzID0ge307XG4gIH1cbiAgLy8gQHRzLWlnbm9yZVxuICBpbml0LmhlYWRlcnMuYXV0aG9yaXphdGlvbiA9IGBCZWFyZXIgJHthdXRoLmFjY2Vzc1Rva2VufWA7XG4gIHJldHVybiBmZXRjaChpbnB1dCwgaW5pdCk7XG59O1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBRUE7QUFLQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQTtBQUFBO0FBQ0E7QUFDQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/util/fetch-with-auth.ts\n");

/***/ }),

/***/ "./src/util/ha-pref-storage.ts":
/*!*************************************!*\
  !*** ./src/util/ha-pref-storage.ts ***!
  \*************************************/
/*! namespace exports */
/*! export clearState [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getState [provided] [no usage info] [missing usage info prevents renaming] */
/*! export storeState [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"storeState\": () => /* binding */ storeState,\n/* harmony export */   \"getState\": () => /* binding */ getState,\n/* harmony export */   \"clearState\": () => /* binding */ clearState\n/* harmony export */ });\nconst STORED_STATE = [\"dockedSidebar\", \"selectedTheme\", \"selectedLanguage\", \"vibrate\", \"suspendWhenHidden\", \"enableShortcuts\", \"defaultPanel\"];\nconst STORAGE = window.localStorage || {};\nfunction storeState(hass) {\n  try {\n    STORED_STATE.forEach(key => {\n      const value = hass[key];\n      STORAGE[key] = JSON.stringify(value === undefined ? null : value);\n    });\n  } catch (err) {// Safari throws exception in private mode\n  }\n}\nfunction getState() {\n  const state = {};\n  STORED_STATE.forEach(key => {\n    if (key in STORAGE) {\n      let value = JSON.parse(STORAGE[key]); // selectedTheme went from string to object on 20200718\n\n      if (key === \"selectedTheme\" && typeof value === \"string\") {\n        value = {\n          theme: value\n        };\n      } // dockedSidebar went from boolean to enum on 20190720\n\n\n      if (key === \"dockedSidebar\" && typeof value === \"boolean\") {\n        value = value ? \"docked\" : \"auto\";\n      }\n\n      state[key] = value;\n    }\n  });\n  return state;\n}\nfunction clearState() {\n  // STORAGE is an object if localStorage not available.\n  if (STORAGE.clear) {\n    STORAGE.clear();\n  }\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/util/ha-pref-storage.ts\n");

/***/ }),

/***/ "./src/util/hass-call-api.ts":
/*!***********************************!*\
  !*** ./src/util/hass-call-api.ts ***!
  \***********************************/
/*! namespace exports */
/*! export default [provided] [no usage info] [missing usage info prevents renaming] */
/*! export handleFetchPromise [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"handleFetchPromise\": () => /* binding */ handleFetchPromise,\n/* harmony export */   \"default\": () => /* binding */ hassCallApi\n/* harmony export */ });\n/* harmony import */ var _fetch_with_auth__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./fetch-with-auth */ \"./src/util/fetch-with-auth.ts\");\n\nconst handleFetchPromise = async (fetchPromise) => {\n  let response;\n\n  try {\n    response = await fetchPromise;\n  } catch (err) {\n    // eslint-disable-next-line @typescript-eslint/no-throw-literal\n    throw {\n      error: \"Request error\",\n      status_code: undefined,\n      body: undefined\n    };\n  }\n\n  let body = null;\n  const contentType = response.headers.get(\"content-type\");\n\n  if (contentType && contentType.includes(\"application/json\")) {\n    try {\n      body = await response.json();\n    } catch (err) {\n      // eslint-disable-next-line @typescript-eslint/no-throw-literal\n      throw {\n        error: \"Unable to parse JSON response\",\n        status_code: err.status,\n        body: null\n      };\n    }\n  } else {\n    body = await response.text();\n  }\n\n  if (!response.ok) {\n    // eslint-disable-next-line @typescript-eslint/no-throw-literal\n    throw {\n      error: `Response error: ${response.status}`,\n      status_code: response.status,\n      body\n    };\n  }\n\n  return body;\n};\nasync function hassCallApi(auth, method, path, parameters) {\n  const url = `${auth.data.hassUrl}/api/${path}`;\n  const init = {\n    method,\n    headers: {}\n  };\n\n  if (parameters) {\n    // @ts-ignore\n    init.headers[\"Content-Type\"] = \"application/json;charset=UTF-8\";\n    init.body = JSON.stringify(parameters);\n  }\n\n  return handleFetchPromise((0,_fetch_with_auth__WEBPACK_IMPORTED_MODULE_0__.fetchWithAuth)(auth, url, init));\n}//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/util/hass-call-api.ts\n");

/***/ }),

/***/ "./src/util/hass-translation.ts":
/*!**************************************!*\
  !*** ./src/util/hass-translation.ts ***!
  \**************************************/
/*! namespace exports */
/*! export getLocalLanguage [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getTranslation [provided] [no usage info] [missing usage info prevents renaming] */
/*! export getUserLanguage [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"getUserLanguage\": () => /* binding */ getUserLanguage,\n/* harmony export */   \"getLocalLanguage\": () => /* binding */ getLocalLanguage,\n/* harmony export */   \"getTranslation\": () => /* binding */ getTranslation\n/* harmony export */ });\n/* harmony import */ var _data_translation__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../data/translation */ \"./src/data/translation.ts\");\n/* harmony import */ var _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../resources/translations-metadata */ \"./src/resources/translations-metadata.ts\");\n\n\nconst STORAGE = window.localStorage || {}; // Chinese locales need map to Simplified or Traditional Chinese\n\nconst LOCALE_LOOKUP = {\n  \"zh-cn\": \"zh-Hans\",\n  \"zh-sg\": \"zh-Hans\",\n  \"zh-my\": \"zh-Hans\",\n  \"zh-tw\": \"zh-Hant\",\n  \"zh-hk\": \"zh-Hant\",\n  \"zh-mo\": \"zh-Hant\",\n  zh: \"zh-Hant\" // all other Chinese locales map to Traditional Chinese\n\n};\n/**\n * Search for a matching translation from most specific to general\n */\n\nfunction findAvailableLanguage(language) {\n  // In most case, the language has the same format with our translation meta data\n  if (language in _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_1__.translationMetadata.translations) {\n    return language;\n  } // Perform case-insenstive comparison since browser isn't required to\n  // report languages with specific cases.\n\n\n  const langLower = language.toLowerCase();\n\n  if (langLower in LOCALE_LOOKUP) {\n    return LOCALE_LOOKUP[langLower];\n  }\n\n  return Object.keys(_resources_translations_metadata__WEBPACK_IMPORTED_MODULE_1__.translationMetadata.translations).find(lang => lang.toLowerCase() === langLower);\n}\n/**\n * Get user selected language from backend\n */\n\n\nasync function getUserLanguage(hass) {\n  const result = await (0,_data_translation__WEBPACK_IMPORTED_MODULE_0__.fetchTranslationPreferences)(hass);\n  const language = result ? result.language : null;\n\n  if (language) {\n    const availableLanguage = findAvailableLanguage(language);\n\n    if (availableLanguage) {\n      return availableLanguage;\n    }\n  }\n\n  return null;\n}\n/**\n * Get browser specific language\n */\n\nfunction getLocalLanguage() {\n  let language = null;\n\n  if (STORAGE.selectedLanguage) {\n    try {\n      const stored = JSON.parse(STORAGE.selectedLanguage);\n\n      if (stored) {\n        language = findAvailableLanguage(stored);\n\n        if (language) {\n          return language;\n        }\n      }\n    } catch (e) {// Ignore parsing error.\n    }\n  }\n\n  if (navigator.languages) {\n    for (const locale of navigator.languages) {\n      language = findAvailableLanguage(locale);\n\n      if (language) {\n        return language;\n      }\n    }\n  }\n\n  language = findAvailableLanguage(navigator.language);\n\n  if (language) {\n    return language;\n  }\n\n  if (navigator.language && navigator.language.includes(\"-\")) {\n    language = findAvailableLanguage(navigator.language.split(\"-\")[0]);\n\n    if (language) {\n      return language;\n    }\n  } // Final fallback\n\n\n  return \"en\";\n} // Store loaded translations in memory so translations are available immediately\n// when DOM is created in Polymer. Even a cache lookup creates noticeable latency.\n\nconst translations = {};\n\nasync function fetchTranslation(fingerprint) {\n  const response = await fetch(`/static/translations/${fingerprint}`, {\n    credentials: \"same-origin\"\n  });\n\n  if (!response.ok) {\n    throw new Error(`Fail to fetch translation ${fingerprint}: HTTP response status is ${response.status}`);\n  }\n\n  return response.json();\n}\n\nasync function getTranslation(fragment, language) {\n  const metadata = _resources_translations_metadata__WEBPACK_IMPORTED_MODULE_1__.translationMetadata.translations[language];\n\n  if (!metadata) {\n    if (language !== \"en\") {\n      return getTranslation(fragment, \"en\");\n    }\n\n    throw new Error(\"Language en is not found in metadata\");\n  } // nl-abcd.jon or logbook/nl-abcd.json\n\n\n  const fingerprint = `${fragment ? fragment + \"/\" : \"\"}${language}-${metadata.hash}.json`; // Fetch translation from the server\n\n  if (!translations[fingerprint]) {\n    translations[fingerprint] = fetchTranslation(fingerprint).then(data => ({\n      language,\n      data\n    })).catch(error => {\n      delete translations[fingerprint];\n\n      if (language !== \"en\") {\n        // Couldn't load selected translation. Try a fall back to en before failing.\n        return getTranslation(fragment, \"en\");\n      }\n\n      return Promise.reject(error);\n    });\n  }\n\n  return translations[fingerprint];\n} // Load selected translation into memory immediately so it is ready when Polymer\n// initializes.\n\ngetTranslation(null, getLocalLanguage());//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64, \n//# sourceURL=webpack-internal:///./src/util/hass-translation.ts\n");

/***/ }),

/***/ "./src/util/init-skeleton.ts":
/*!***********************************!*\
  !*** ./src/util/init-skeleton.ts ***!
  \***********************************/
/*! namespace exports */
/*! export removeInitSkeleton [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"removeInitSkeleton\": () => /* binding */ removeInitSkeleton\n/* harmony export */ });\nconst removeInitSkeleton = () => {\n  const initEl = document.getElementById(\"ha-init-skeleton\");\n\n  if (initEl) {\n    initEl.parentElement.removeChild(initEl);\n  }\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvdXRpbC9pbml0LXNrZWxldG9uLnRzLmpzIiwic291cmNlcyI6WyJ3ZWJwYWNrOi8vaG9tZS1hc3Npc3RhbnQtZnJvbnRlbmQvLi9zcmMvdXRpbC9pbml0LXNrZWxldG9uLnRzPzdhMWIiXSwic291cmNlc0NvbnRlbnQiOlsiZXhwb3J0IGNvbnN0IHJlbW92ZUluaXRTa2VsZXRvbiA9ICgpID0+IHtcbiAgY29uc3QgaW5pdEVsID0gZG9jdW1lbnQuZ2V0RWxlbWVudEJ5SWQoXCJoYS1pbml0LXNrZWxldG9uXCIpO1xuICBpZiAoaW5pdEVsKSB7XG4gICAgaW5pdEVsLnBhcmVudEVsZW1lbnQhLnJlbW92ZUNoaWxkKGluaXRFbCk7XG4gIH1cbn07XG4iXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTtBQUNBO0FBQ0E7QUFBQTtBQUNBO0FBQ0E7QUFDQSIsInNvdXJjZVJvb3QiOiIifQ==\n//# sourceURL=webpack-internal:///./src/util/init-skeleton.ts\n");

/***/ }),

/***/ "./src/util/legacy-support.js":
/*!************************************!*\
  !*** ./src/util/legacy-support.js ***!
  \************************************/
/*! namespace exports */
/*! exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _polymer_polymer_lib_utils_html_tag__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag */ \"./node_modules/@polymer/polymer/lib/utils/html-tag.js\");\n/* harmony import */ var _polymer_polymer_polymer_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/polymer-element */ \"./node_modules/@polymer/polymer/polymer-element.js\");\n/* harmony import */ var _polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy */ \"./node_modules/@polymer/polymer/polymer-legacy.js\");\n/**\n * Provide legacy support to HTML imports by exposing Polymer and\n * Polymer.Element on the window object.\n */\n\n/* eslint-plugin-disable lit */\n\n\n\n_polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_2__.Polymer.Element = _polymer_polymer_polymer_element__WEBPACK_IMPORTED_MODULE_1__.PolymerElement;\n_polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_2__.Polymer.html = _polymer_polymer_lib_utils_html_tag__WEBPACK_IMPORTED_MODULE_0__.html;\nwindow.Polymer = _polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_2__.Polymer;//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvdXRpbC9sZWdhY3ktc3VwcG9ydC5qcy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL3V0aWwvbGVnYWN5LXN1cHBvcnQuanM/MzBiNSJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbiAqIFByb3ZpZGUgbGVnYWN5IHN1cHBvcnQgdG8gSFRNTCBpbXBvcnRzIGJ5IGV4cG9zaW5nIFBvbHltZXIgYW5kXG4gKiBQb2x5bWVyLkVsZW1lbnQgb24gdGhlIHdpbmRvdyBvYmplY3QuXG4gKi9cbi8qIGVzbGludC1wbHVnaW4tZGlzYWJsZSBsaXQgKi9cbmltcG9ydCB7IGh0bWwgfSBmcm9tIFwiQHBvbHltZXIvcG9seW1lci9saWIvdXRpbHMvaHRtbC10YWdcIjtcbmltcG9ydCB7IFBvbHltZXJFbGVtZW50IH0gZnJvbSBcIkBwb2x5bWVyL3BvbHltZXIvcG9seW1lci1lbGVtZW50XCI7XG5pbXBvcnQgeyBQb2x5bWVyIH0gZnJvbSBcIkBwb2x5bWVyL3BvbHltZXIvcG9seW1lci1sZWdhY3lcIjtcblxuUG9seW1lci5FbGVtZW50ID0gUG9seW1lckVsZW1lbnQ7XG5Qb2x5bWVyLmh0bWwgPSBodG1sO1xud2luZG93LlBvbHltZXIgPSBQb2x5bWVyO1xuIl0sIm1hcHBpbmdzIjoiOzs7O0FBQUE7Ozs7O0FBSUE7QUFDQTtBQUNBO0FBQ0E7QUFFQTtBQUNBO0FBQ0EiLCJzb3VyY2VSb290IjoiIn0=\n//# sourceURL=webpack-internal:///./src/util/legacy-support.js\n");

/***/ }),

/***/ "./src/util/register-service-worker.ts":
/*!*********************************************!*\
  !*** ./src/util/register-service-worker.ts ***!
  \*********************************************/
/*! namespace exports */
/*! export registerServiceWorker [provided] [no usage info] [missing usage info prevents renaming] */
/*! export supportsServiceWorker [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"supportsServiceWorker\": () => /* binding */ supportsServiceWorker,\n/* harmony export */   \"registerServiceWorker\": () => /* binding */ registerServiceWorker\n/* harmony export */ });\n/* harmony import */ var _toast__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./toast */ \"./src/util/toast.ts\");\n\nconst supportsServiceWorker = () => \"serviceWorker\" in navigator && (location.protocol === \"https:\" || location.hostname === \"localhost\");\nconst registerServiceWorker = async (rootEl, notifyUpdate = true) => {\n  if (!supportsServiceWorker()) {\n    return;\n  } // If the active service worker changes, refresh the page because the cache has changed\n\n\n  navigator.serviceWorker.addEventListener(\"controllerchange\", () => {\n    location.reload();\n  });\n  const reg = await navigator.serviceWorker.register(\"/service_worker.js\");\n\n  if (!notifyUpdate || true || false) {\n    return;\n  }\n\n  reg.addEventListener(\"updatefound\", () => {\n    const installingWorker = reg.installing;\n\n    if (!installingWorker) {\n      return;\n    }\n\n    installingWorker.addEventListener(\"statechange\", () => {\n      if (installingWorker.state !== \"installed\" || !navigator.serviceWorker.controller) {\n        return;\n      } // Notify users a new frontend is available.\n      // When\n\n\n      (0,_toast__WEBPACK_IMPORTED_MODULE_0__.showToast)(rootEl, {\n        message: \"A new version of the frontend is available.\",\n        action: {\n          // We tell the service worker to call skipWaiting, which activates\n          // the new service worker. Above we listen for `controllerchange`\n          // so we reload the page once a new servic worker activates.\n          action: () => installingWorker.postMessage({\n            type: \"skipWaiting\"\n          }),\n          text: \"reload\"\n        },\n        duration: 0,\n        dismissable: false\n      });\n    });\n  });\n};//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,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\n//# sourceURL=webpack-internal:///./src/util/register-service-worker.ts\n");

/***/ }),

/***/ "./src/util/toast.ts":
/*!***************************!*\
  !*** ./src/util/toast.ts ***!
  \***************************/
/*! namespace exports */
/*! export showToast [provided] [no usage info] [missing usage info prevents renaming] */
/*! other exports [not provided] [no usage info] */
/*! runtime requirements: __webpack_require__, __webpack_require__.r, __webpack_exports__, __webpack_require__.d, __webpack_require__.* */
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"showToast\": () => /* binding */ showToast\n/* harmony export */ });\n/* harmony import */ var _common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../common/dom/fire_event */ \"./src/common/dom/fire_event.ts\");\n\nconst showToast = (el, params) => (0,_common_dom_fire_event__WEBPACK_IMPORTED_MODULE_0__.fireEvent)(el, \"hass-notification\", params);//# sourceURL=[module]\n//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiLi9zcmMvdXRpbC90b2FzdC50cy5qcyIsInNvdXJjZXMiOlsid2VicGFjazovL2hvbWUtYXNzaXN0YW50LWZyb250ZW5kLy4vc3JjL3V0aWwvdG9hc3QudHM/N2M0MiJdLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgeyBmaXJlRXZlbnQgfSBmcm9tIFwiLi4vY29tbW9uL2RvbS9maXJlX2V2ZW50XCI7XG5pbXBvcnQgeyBTaG93VG9hc3RQYXJhbXMgfSBmcm9tIFwiLi4vbWFuYWdlcnMvbm90aWZpY2F0aW9uLW1hbmFnZXJcIjtcblxuZXhwb3J0IGNvbnN0IHNob3dUb2FzdCA9IChlbDogSFRNTEVsZW1lbnQsIHBhcmFtczogU2hvd1RvYXN0UGFyYW1zKSA9PlxuICBmaXJlRXZlbnQoZWwsIFwiaGFzcy1ub3RpZmljYXRpb25cIiwgcGFyYW1zKTtcbiJdLCJtYXBwaW5ncyI6Ijs7Ozs7QUFBQTtBQUdBIiwic291cmNlUm9vdCI6IiJ9\n//# sourceURL=webpack-internal:///./src/util/toast.ts\n");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		if(__webpack_module_cache__[moduleId]) {
/******/ 			return __webpack_module_cache__[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			id: moduleId,
/******/ 			loaded: false,
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = __webpack_modules__;
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => module['default'] :
/******/ 				() => module;
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/create fake namespace object */
/******/ 	(() => {
/******/ 		// create a fake namespace object
/******/ 		// mode & 1: value is a module id, require it
/******/ 		// mode & 2: merge all properties of value into the ns
/******/ 		// mode & 4: return value when already ns object
/******/ 		// mode & 8|1: behave like require
/******/ 		__webpack_require__.t = function(value, mode) {
/******/ 			if(mode & 1) value = this(value);
/******/ 			if(mode & 8) return value;
/******/ 			if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 			var ns = Object.create(null);
/******/ 			__webpack_require__.r(ns);
/******/ 			var def = {};
/******/ 			if(mode & 2 && typeof value == 'object' && value) {
/******/ 				for(const key in value) def[key] = () => value[key];
/******/ 			}
/******/ 			def['default'] = () => value;
/******/ 			__webpack_require__.d(ns, def);
/******/ 			return ns;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/ensure chunk */
/******/ 	(() => {
/******/ 		__webpack_require__.f = {};
/******/ 		// This file contains only the entry chunk.
/******/ 		// The chunk loading function for additional chunks
/******/ 		__webpack_require__.e = (chunkId) => {
/******/ 			return Promise.all(Object.keys(__webpack_require__.f).reduce((promises, key) => {
/******/ 				__webpack_require__.f[key](chunkId, promises);
/******/ 				return promises;
/******/ 			}, []));
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/get javascript chunk filename */
/******/ 	(() => {
/******/ 		// This function allow to reference async chunks
/******/ 		__webpack_require__.u = (chunkId) => {
/******/ 			// return url for filenames based on template
/******/ 			return "" + chunkId + ".chunk.js";
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => Object.prototype.hasOwnProperty.call(obj, prop)
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/load script */
/******/ 	(() => {
/******/ 		var inProgress = {};
/******/ 		var dataWebpackPrefix = "home-assistant-frontend:";
/******/ 		// loadScript function to load a script via script tag
/******/ 		__webpack_require__.l = (url, done, key) => {
/******/ 			if(inProgress[url]) { inProgress[url].push(done); return; }
/******/ 			var script, needAttach;
/******/ 			if(key !== undefined) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				for(var i = 0; i < scripts.length; i++) {
/******/ 					var s = scripts[i];
/******/ 					if(s.getAttribute("src") == url || s.getAttribute("data-webpack") == dataWebpackPrefix + key) { script = s; break; }
/******/ 				}
/******/ 			}
/******/ 			if(!script) {
/******/ 				needAttach = true;
/******/ 				script = document.createElement('script');
/******/ 		
/******/ 				script.charset = 'utf-8';
/******/ 				script.timeout = 120;
/******/ 				if (__webpack_require__.nc) {
/******/ 					script.setAttribute("nonce", __webpack_require__.nc);
/******/ 				}
/******/ 				script.setAttribute("data-webpack", dataWebpackPrefix + key);
/******/ 				script.src = url;
/******/ 			}
/******/ 			inProgress[url] = [done];
/******/ 			var onScriptComplete = (prev, event) => {
/******/ 				// avoid mem leaks in IE.
/******/ 				script.onerror = script.onload = null;
/******/ 				clearTimeout(timeout);
/******/ 				var doneFns = inProgress[url];
/******/ 				delete inProgress[url];
/******/ 				script.parentNode && script.parentNode.removeChild(script);
/******/ 				doneFns && doneFns.forEach((fn) => fn(event));
/******/ 				if(prev) return prev(event);
/******/ 			}
/******/ 			;
/******/ 			var timeout = setTimeout(onScriptComplete.bind(null, undefined, { type: 'timeout', target: script }), 120000);
/******/ 			script.onerror = onScriptComplete.bind(null, script.onerror);
/******/ 			script.onload = onScriptComplete.bind(null, script.onload);
/******/ 			needAttach && document.head.appendChild(script);
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/node module decorator */
/******/ 	(() => {
/******/ 		__webpack_require__.nmd = (module) => {
/******/ 			module.paths = [];
/******/ 			if (!module.children) module.children = [];
/******/ 			return module;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/publicPath */
/******/ 	(() => {
/******/ 		__webpack_require__.p = "/frontend_latest/";
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/jsonp chunk loading */
/******/ 	(() => {
/******/ 		__webpack_require__.b = document.baseURI || self.location.href;
/******/ 		
/******/ 		// object to store loaded and loading chunks
/******/ 		// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 		// Promise = chunk loading, 0 = chunk loaded
/******/ 		var installedChunks = {
/******/ 			"app": 0
/******/ 		};
/******/ 		
/******/ 		
/******/ 		__webpack_require__.f.j = (chunkId, promises) => {
/******/ 				// JSONP chunk loading for javascript
/******/ 				var installedChunkData = __webpack_require__.o(installedChunks, chunkId) ? installedChunks[chunkId] : undefined;
/******/ 				if(installedChunkData !== 0) { // 0 means "already installed".
/******/ 		
/******/ 					// a Promise means "currently loading".
/******/ 					if(installedChunkData) {
/******/ 						promises.push(installedChunkData[2]);
/******/ 					} else {
/******/ 						if(true) { // all chunks have JS
/******/ 							// setup Promise in chunk cache
/******/ 							var promise = new Promise((resolve, reject) => {
/******/ 								installedChunkData = installedChunks[chunkId] = [resolve, reject];
/******/ 							});
/******/ 							promises.push(installedChunkData[2] = promise);
/******/ 		
/******/ 							// start chunk loading
/******/ 							var url = __webpack_require__.p + __webpack_require__.u(chunkId);
/******/ 							// create error before stack unwound to get useful stacktrace later
/******/ 							var error = new Error();
/******/ 							var loadingEnded = (event) => {
/******/ 								if(__webpack_require__.o(installedChunks, chunkId)) {
/******/ 									installedChunkData = installedChunks[chunkId];
/******/ 									if(installedChunkData !== 0) installedChunks[chunkId] = undefined;
/******/ 									if(installedChunkData) {
/******/ 										var errorType = event && (event.type === 'load' ? 'missing' : event.type);
/******/ 										var realSrc = event && event.target && event.target.src;
/******/ 										error.message = 'Loading chunk ' + chunkId + ' failed.\n(' + errorType + ': ' + realSrc + ')';
/******/ 										error.name = 'ChunkLoadError';
/******/ 										error.type = errorType;
/******/ 										error.request = realSrc;
/******/ 										installedChunkData[1](error);
/******/ 									}
/******/ 								}
/******/ 							};
/******/ 							__webpack_require__.l(url, loadingEnded, "chunk-" + chunkId);
/******/ 						} else installedChunks[chunkId] = 0;
/******/ 					}
/******/ 				}
/******/ 		};
/******/ 		
/******/ 		// no prefetching
/******/ 		
/******/ 		// no preloaded
/******/ 		
/******/ 		// no HMR
/******/ 		
/******/ 		// no HMR manifest
/******/ 		
/******/ 		// no deferred startup
/******/ 		
/******/ 		// install a JSONP callback for chunk loading
/******/ 		var webpackJsonpCallback = (data) => {
/******/ 			var [chunkIds, moreModules, runtime] = data;
/******/ 			// add "moreModules" to the modules object,
/******/ 			// then flag all "chunkIds" as loaded and fire callback
/******/ 			var moduleId, chunkId, i = 0, resolves = [];
/******/ 			for(;i < chunkIds.length; i++) {
/******/ 				chunkId = chunkIds[i];
/******/ 				if(__webpack_require__.o(installedChunks, chunkId) && installedChunks[chunkId]) {
/******/ 					resolves.push(installedChunks[chunkId][0]);
/******/ 				}
/******/ 				installedChunks[chunkId] = 0;
/******/ 			}
/******/ 			for(moduleId in moreModules) {
/******/ 				if(__webpack_require__.o(moreModules, moduleId)) {
/******/ 					__webpack_require__.m[moduleId] = moreModules[moduleId];
/******/ 				}
/******/ 			}
/******/ 			if(runtime) runtime(__webpack_require__);
/******/ 			parentChunkLoadingFunction(data);
/******/ 			while(resolves.length) {
/******/ 				resolves.shift()();
/******/ 			}
/******/ 		
/******/ 		}
/******/ 		
/******/ 		var chunkLoadingGlobal = self["webpackChunkhome_assistant_frontend"] = self["webpackChunkhome_assistant_frontend"] || [];
/******/ 		var parentChunkLoadingFunction = chunkLoadingGlobal.push.bind(chunkLoadingGlobal);
/******/ 		chunkLoadingGlobal.push = webpackJsonpCallback;
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	// startup
/******/ 	// Load entry module
/******/ 	__webpack_require__("./src/entrypoints/app.ts");
/******/ 	// This entry module used 'exports' so it can't be inlined
/******/ })()
;